/* Copyright (C) 2010 Atsushi Togo */
/* All rights reserved. */

/* This file is part of spglib. */

/* Redistribution and use in source and binary forms, with or without */
/* modification, are permitted provided that the following conditions */
/* are met: */

/* * Redistributions of source code must retain the above copyright */
/*   notice, this list of conditions and the following disclaimer. */

/* * Redistributions in binary form must reproduce the above copyright */
/*   notice, this list of conditions and the following disclaimer in */
/*   the documentation and/or other materials provided with the */
/*   distribution. */

/* * Neither the name of the spglib project nor the names of its */
/*   contributors may be used to endorse or promote products derived */
/*   from this software without specific prior written permission. */

/* THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS */
/* "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT */
/* LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS */
/* FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE */
/* COPYRIGHT HOLDER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, */
/* INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, */
/* BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; */
/* LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER */
/* CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT */
/* LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN */
/* ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE */
/* POSSIBILITY OF SUCH DAMAGE. */

#include "msg_database.h"

#include <stdlib.h>

#include "debug.h"
#include "mathfunc.h"
#include "spg_database.h"

// This file should not be processed in clang-format or clang-tidy
/* clang-format off */

static int get_hall_number_offset(const int uni_number, const int hall_number);

/* { UNI number, Litvin number, BNS number, OG number, Number of maximal space
 * subgroup, type } */
static const MagneticSpacegroupType magnetic_spacegroup_types[] = {
    {0, 0, "", "", 0, 0},                           /* Error */
    {1, 1, "1.1", "1.1.1", 1, 1},                   /*    1 */
    {2, 2, "1.2", "1.2.2", 1, 2},                   /*    2 */
    {3, 3, "1.3", "1.3.3", 1, 4},                   /*    3 */
    {4, 4, "2.4", "2.1.4", 2, 1},                   /*    4 */
    {5, 5, "2.5", "2.2.5", 2, 2},                   /*    5 */
    {6, 6, "2.6", "2.3.6", 2, 3},                   /*    6 */
    {7, 7, "2.7", "2.4.7", 2, 4},                   /*    7 */
    {8, 8, "3.1", "3.1.8", 3, 1},                   /*    8 */
    {9, 9, "3.2", "3.2.9", 3, 2},                   /*    9 */
    {10, 10, "3.3", "3.3.10", 3, 3},                /*   10 */
    {11, 11, "3.4", "3.4.11", 3, 4},                /*   11 */
    {12, 12, "3.5", "3.5.12", 3, 4},                /*   12 */
    {13, 23, "3.6", "5.5.23", 3, 4},                /*   13 */
    {14, 15, "4.7", "4.1.15", 4, 1},                /*   14 */
    {15, 16, "4.8", "4.2.16", 4, 2},                /*   15 */
    {16, 17, "4.9", "4.3.17", 4, 3},                /*   16 */
    {17, 18, "4.10", "4.4.18", 4, 4},               /*   17 */
    {18, 14, "4.11", "3.7.14", 4, 4},               /*   18 */
    {19, 24, "4.12", "5.6.24", 4, 4},               /*   19 */
    {20, 19, "5.13", "5.1.19", 5, 1},               /*   20 */
    {21, 20, "5.14", "5.2.20", 5, 2},               /*   21 */
    {22, 21, "5.15", "5.3.21", 5, 3},               /*   22 */
    {23, 22, "5.16", "5.4.22", 5, 4},               /*   23 */
    {24, 13, "5.17", "3.6.13", 5, 4},               /*   24 */
    {25, 25, "6.18", "6.1.25", 6, 1},               /*   25 */
    {26, 26, "6.19", "6.2.26", 6, 2},               /*   26 */
    {27, 27, "6.20", "6.3.27", 6, 3},               /*   27 */
    {28, 28, "6.21", "6.4.28", 6, 4},               /*   28 */
    {29, 29, "6.22", "6.5.29", 6, 4},               /*   29 */
    {30, 42, "6.23", "8.5.42", 6, 4},               /*   30 */
    {31, 32, "7.24", "7.1.32", 7, 1},               /*   31 */
    {32, 33, "7.25", "7.2.33", 7, 2},               /*   32 */
    {33, 34, "7.26", "7.3.34", 7, 3},               /*   33 */
    {34, 35, "7.27", "7.4.35", 7, 4},               /*   34 */
    {35, 31, "7.28", "6.7.31", 7, 4},               /*   35 */
    {36, 36, "7.29", "7.5.36", 7, 4},               /*   36 */
    {37, 48, "7.30", "9.4.48", 7, 4},               /*   37 */
    {38, 44, "7.31", "8.7.44", 7, 4},               /*   38 */
    {39, 38, "8.32", "8.1.38", 8, 1},               /*   39 */
    {40, 39, "8.33", "8.2.39", 8, 2},               /*   40 */
    {41, 40, "8.34", "8.3.40", 8, 3},               /*   41 */
    {42, 41, "8.35", "8.4.41", 8, 4},               /*   42 */
    {43, 30, "8.36", "6.6.30", 8, 4},               /*   43 */
    {44, 45, "9.37", "9.1.45", 9, 1},               /*   44 */
    {45, 46, "9.38", "9.2.46", 9, 2},               /*   45 */
    {46, 47, "9.39", "9.3.47", 9, 3},               /*   46 */
    {47, 43, "9.40", "8.6.43", 9, 4},               /*   47 */
    {48, 37, "9.41", "7.6.37", 9, 4},               /*   48 */
    {49, 49, "10.42", "10.1.49", 10, 1},            /*   49 */
    {50, 50, "10.43", "10.2.50", 10, 2},            /*   50 */
    {51, 51, "10.44", "10.3.51", 10, 3},            /*   51 */
    {52, 52, "10.45", "10.4.52", 10, 3},            /*   52 */
    {53, 53, "10.46", "10.5.53", 10, 3},            /*   53 */
    {54, 54, "10.47", "10.6.54", 10, 4},            /*   54 */
    {55, 55, "10.48", "10.7.55", 10, 4},            /*   55 */
    {56, 72, "10.49", "12.7.72", 10, 4},            /*   56 */
    {57, 59, "11.50", "11.1.59", 11, 1},            /*   57 */
    {58, 60, "11.51", "11.2.60", 11, 2},            /*   58 */
    {59, 61, "11.52", "11.3.61", 11, 3},            /*   59 */
    {60, 62, "11.53", "11.4.62", 11, 3},            /*   60 */
    {61, 63, "11.54", "11.5.63", 11, 3},            /*   61 */
    {62, 64, "11.55", "11.6.64", 11, 4},            /*   62 */
    {63, 57, "11.56", "10.9.57", 11, 4},            /*   63 */
    {64, 74, "11.57", "12.9.74", 11, 4},            /*   64 */
    {65, 66, "12.58", "12.1.66", 12, 1},            /*   65 */
    {66, 67, "12.59", "12.2.67", 12, 2},            /*   66 */
    {67, 68, "12.60", "12.3.68", 12, 3},            /*   67 */
    {68, 69, "12.61", "12.4.69", 12, 3},            /*   68 */
    {69, 70, "12.62", "12.5.70", 12, 3},            /*   69 */
    {70, 71, "12.63", "12.6.71", 12, 4},            /*   70 */
    {71, 56, "12.64", "10.8.56", 12, 4},            /*   71 */
    {72, 77, "13.65", "13.1.77", 13, 1},            /*   72 */
    {73, 78, "13.66", "13.2.78", 13, 2},            /*   73 */
    {74, 79, "13.67", "13.3.79", 13, 3},            /*   74 */
    {75, 80, "13.68", "13.4.80", 13, 3},            /*   75 */
    {76, 81, "13.69", "13.5.81", 13, 3},            /*   76 */
    {77, 82, "13.70", "13.6.82", 13, 4},            /*   77 */
    {78, 83, "13.71", "13.7.83", 13, 4},            /*   78 */
    {79, 58, "13.72", "10.10.58", 13, 4},           /*   79 */
    {80, 75, "13.73", "12.10.75", 13, 4},           /*   80 */
    {81, 97, "13.74", "15.6.97", 13, 4},            /*   81 */
    {82, 86, "14.75", "14.1.86", 14, 1},            /*   82 */
    {83, 87, "14.76", "14.2.87", 14, 2},            /*   83 */
    {84, 88, "14.77", "14.3.88", 14, 3},            /*   84 */
    {85, 89, "14.78", "14.4.89", 14, 3},            /*   85 */
    {86, 90, "14.79", "14.5.90", 14, 3},            /*   86 */
    {87, 91, "14.80", "14.6.91", 14, 4},            /*   87 */
    {88, 85, "14.81", "13.9.85", 14, 4},            /*   88 */
    {89, 65, "14.82", "11.7.65", 14, 4},            /*   89 */
    {90, 76, "14.83", "12.11.76", 14, 4},           /*   90 */
    {91, 98, "14.84", "15.7.98", 14, 4},            /*   91 */
    {92, 92, "15.85", "15.1.92", 15, 1},            /*   92 */
    {93, 93, "15.86", "15.2.93", 15, 2},            /*   93 */
    {94, 94, "15.87", "15.3.94", 15, 3},            /*   94 */
    {95, 95, "15.88", "15.4.95", 15, 3},            /*   95 */
    {96, 96, "15.89", "15.5.96", 15, 3},            /*   96 */
    {97, 73, "15.90", "12.8.73", 15, 4},            /*   97 */
    {98, 84, "15.91", "13.8.84", 15, 4},            /*   98 */
    {99, 99, "16.1", "16.1.99", 16, 1},             /*   99 */
    {100, 100, "16.2", "16.2.100", 16, 2},          /*  100 */
    {101, 101, "16.3", "16.3.101", 16, 3},          /*  101 */
    {102, 102, "16.4", "16.4.102", 16, 4},          /*  102 */
    {103, 134, "16.5", "21.6.134", 16, 4},          /*  103 */
    {104, 148, "16.6", "23.4.148", 16, 4},          /*  104 */
    {105, 106, "17.7", "17.1.106", 17, 1},          /*  105 */
    {106, 107, "17.8", "17.2.107", 17, 2},          /*  106 */
    {107, 108, "17.9", "17.3.108", 17, 3},          /*  107 */
    {108, 109, "17.10", "17.4.109", 17, 3},         /*  108 */
    {109, 110, "17.11", "17.5.110", 17, 4},         /*  109 */
    {110, 105, "17.12", "16.7.105", 17, 4},         /*  110 */
    {111, 138, "17.13", "21.10.138", 17, 4},        /*  111 */
    {112, 126, "17.14", "20.5.126", 17, 4},         /*  112 */
    {113, 154, "17.15", "24.5.154", 17, 4},         /*  113 */
    {114, 113, "18.16", "18.1.113", 18, 1},         /*  114 */
    {115, 114, "18.17", "18.2.114", 18, 2},         /*  115 */
    {116, 115, "18.18", "18.3.115", 18, 3},         /*  116 */
    {117, 116, "18.19", "18.4.116", 18, 3},         /*  117 */
    {118, 112, "18.20", "17.7.112", 18, 4},         /*  118 */
    {119, 117, "18.21", "18.5.117", 18, 4},         /*  119 */
    {120, 128, "18.22", "20.7.128", 18, 4},         /*  120 */
    {121, 137, "18.23", "21.9.137", 18, 4},         /*  121 */
    {122, 149, "18.24", "23.5.149", 18, 4},         /*  122 */
    {123, 119, "19.25", "19.1.119", 19, 1},         /*  123 */
    {124, 120, "19.26", "19.2.120", 19, 2},         /*  124 */
    {125, 121, "19.27", "19.3.121", 19, 3},         /*  125 */
    {126, 118, "19.28", "18.6.118", 19, 4},         /*  126 */
    {127, 127, "19.29", "20.6.127", 19, 4},         /*  127 */
    {128, 153, "19.30", "24.4.153", 19, 4},         /*  128 */
    {129, 122, "20.31", "20.1.122", 20, 1},         /*  129 */
    {130, 123, "20.32", "20.2.123", 20, 2},         /*  130 */
    {131, 124, "20.33", "20.3.124", 20, 3},         /*  131 */
    {132, 125, "20.34", "20.4.125", 20, 3},         /*  132 */
    {133, 136, "20.35", "21.8.136", 20, 4},         /*  133 */
    {134, 111, "20.36", "17.6.111", 20, 4},         /*  134 */
    {135, 144, "20.37", "22.5.144", 20, 4},         /*  135 */
    {136, 129, "21.38", "21.1.129", 21, 1},         /*  136 */
    {137, 130, "21.39", "21.2.130", 21, 2},         /*  137 */
    {138, 131, "21.40", "21.3.131", 21, 3},         /*  138 */
    {139, 132, "21.41", "21.4.132", 21, 3},         /*  139 */
    {140, 133, "21.42", "21.5.133", 21, 4},         /*  140 */
    {141, 103, "21.43", "16.5.103", 21, 4},         /*  141 */
    {142, 143, "21.44", "22.4.143", 21, 4},         /*  142 */
    {143, 140, "22.45", "22.1.140", 22, 1},         /*  143 */
    {144, 141, "22.46", "22.2.141", 22, 2},         /*  144 */
    {145, 142, "22.47", "22.3.142", 22, 3},         /*  145 */
    {146, 104, "22.48", "16.6.104", 22, 4},         /*  146 */
    {147, 145, "23.49", "23.1.145", 23, 1},         /*  147 */
    {148, 146, "23.50", "23.2.146", 23, 2},         /*  148 */
    {149, 147, "23.51", "23.3.147", 23, 3},         /*  149 */
    {150, 135, "23.52", "21.7.135", 23, 4},         /*  150 */
    {151, 150, "24.53", "24.1.150", 24, 1},         /*  151 */
    {152, 151, "24.54", "24.2.151", 24, 2},         /*  152 */
    {153, 152, "24.55", "24.3.152", 24, 3},         /*  153 */
    {154, 139, "24.56", "21.11.139", 24, 4},        /*  154 */
    {155, 155, "25.57", "25.1.155", 25, 1},         /*  155 */
    {156, 156, "25.58", "25.2.156", 25, 2},         /*  156 */
    {157, 157, "25.59", "25.3.157", 25, 3},         /*  157 */
    {158, 158, "25.60", "25.4.158", 25, 3},         /*  158 */
    {159, 159, "25.61", "25.5.159", 25, 4},         /*  159 */
    {160, 160, "25.62", "25.6.160", 25, 4},         /*  160 */
    {161, 241, "25.63", "35.6.241", 25, 4},         /*  161 */
    {162, 271, "25.64", "38.7.271", 25, 4},         /*  162 */
    {163, 328, "25.65", "44.5.328", 25, 4},         /*  163 */
    {164, 168, "26.66", "26.1.168", 26, 1},         /*  164 */
    {165, 169, "26.67", "26.2.169", 26, 2},         /*  165 */
    {166, 170, "26.68", "26.3.170", 26, 3},         /*  166 */
    {167, 171, "26.69", "26.4.171", 26, 3},         /*  167 */
    {168, 172, "26.70", "26.5.172", 26, 3},         /*  168 */
    {169, 173, "26.71", "26.6.173", 26, 4},         /*  169 */
    {170, 174, "26.72", "26.7.174", 26, 4},         /*  170 */
    {171, 164, "26.73", "25.10.164", 26, 4},        /*  171 */
    {172, 275, "26.74", "38.11.275", 26, 4},        /*  172 */
    {173, 287, "26.75", "39.10.287", 26, 4},        /*  173 */
    {174, 254, "26.76", "36.6.254", 26, 4},         /*  174 */
    {175, 345, "26.77", "46.8.345", 26, 4},         /*  175 */
    {176, 178, "27.78", "27.1.178", 27, 1},         /*  176 */
    {177, 179, "27.79", "27.2.179", 27, 2},         /*  177 */
    {178, 180, "27.80", "27.3.180", 27, 3},         /*  178 */
    {179, 181, "27.81", "27.4.181", 27, 3},         /*  179 */
    {180, 165, "27.82", "25.11.165", 27, 4},        /*  180 */
    {181, 182, "27.83", "27.5.182", 27, 4},         /*  181 */
    {182, 262, "27.84", "37.5.262", 27, 4},         /*  182 */
    {183, 289, "27.85", "39.12.289", 27, 4},        /*  183 */
    {184, 335, "27.86", "45.5.335", 27, 4},         /*  184 */
    {185, 185, "28.87", "28.1.185", 28, 1},         /*  185 */
    {186, 186, "28.88", "28.2.186", 28, 2},         /*  186 */
    {187, 187, "28.89", "28.3.187", 28, 3},         /*  187 */
    {188, 188, "28.90", "28.4.188", 28, 3},         /*  188 */
    {189, 189, "28.91", "28.5.189", 28, 3},         /*  189 */
    {190, 166, "28.92", "25.12.166", 28, 4},        /*  190 */
    {191, 190, "28.93", "28.6.190", 28, 4},         /*  191 */
    {192, 191, "28.94", "28.7.191", 28, 4},         /*  192 */
    {193, 296, "28.95", "40.6.296", 28, 4},         /*  193 */
    {194, 284, "28.96", "39.7.284", 28, 4},         /*  194 */
    {195, 245, "28.97", "35.10.245", 28, 4},        /*  195 */
    {196, 343, "28.98", "46.6.343", 28, 4},         /*  196 */
    {197, 198, "29.99", "29.1.198", 29, 1},         /*  197 */
    {198, 199, "29.100", "29.2.199", 29, 2},        /*  198 */
    {199, 200, "29.101", "29.3.200", 29, 3},        /*  199 */
    {200, 201, "29.102", "29.4.201", 29, 3},        /*  200 */
    {201, 202, "29.103", "29.5.202", 29, 3},        /*  201 */
    {202, 177, "29.104", "26.10.177", 29, 4},       /*  202 */
    {203, 203, "29.105", "29.6.203", 29, 4},        /*  203 */
    {204, 194, "29.106", "28.10.194", 29, 4},       /*  204 */
    {205, 306, "29.107", "41.7.306", 29, 4},        /*  205 */
    {206, 288, "29.108", "39.11.288", 29, 4},       /*  206 */
    {207, 255, "29.109", "36.7.255", 29, 4},        /*  207 */
    {208, 336, "29.110", "45.6.336", 29, 4},        /*  208 */
    {209, 205, "30.111", "30.1.205", 30, 1},        /*  209 */
    {210, 206, "30.112", "30.2.206", 30, 2},        /*  210 */
    {211, 207, "30.113", "30.3.207", 30, 3},        /*  211 */
    {212, 208, "30.114", "30.4.208", 30, 3},        /*  212 */
    {213, 209, "30.115", "30.5.209", 30, 3},        /*  213 */
    {214, 210, "30.116", "30.6.210", 30, 4},        /*  214 */
    {215, 184, "30.117", "27.7.184", 30, 4},        /*  215 */
    {216, 196, "30.118", "28.12.196", 30, 4},       /*  216 */
    {217, 276, "30.119", "38.12.276", 30, 4},       /*  217 */
    {218, 308, "30.120", "41.9.308", 30, 4},        /*  218 */
    {219, 263, "30.121", "37.6.263", 30, 4},        /*  219 */
    {220, 346, "30.122", "46.9.346", 30, 4},        /*  220 */
    {221, 212, "31.123", "31.1.212", 31, 1},        /*  221 */
    {222, 213, "31.124", "31.2.213", 31, 2},        /*  222 */
    {223, 214, "31.125", "31.3.214", 31, 3},        /*  223 */
    {224, 215, "31.126", "31.4.215", 31, 3},        /*  224 */
    {225, 216, "31.127", "31.5.216", 31, 3},        /*  225 */
    {226, 176, "31.128", "26.9.176", 31, 4},        /*  226 */
    {227, 217, "31.129", "31.6.217", 31, 4},        /*  227 */
    {228, 195, "31.130", "28.11.195", 31, 4},       /*  228 */
    {229, 298, "31.131", "40.8.298", 31, 4},        /*  229 */
    {230, 274, "31.132", "38.10.274", 31, 4},       /*  230 */
    {231, 256, "31.133", "36.8.256", 31, 4},        /*  231 */
    {232, 329, "31.134", "44.6.329", 31, 4},        /*  232 */
    {233, 219, "32.135", "32.1.219", 32, 1},        /*  233 */
    {234, 220, "32.136", "32.2.220", 32, 2},        /*  234 */
    {235, 221, "32.137", "32.3.221", 32, 3},        /*  235 */
    {236, 222, "32.138", "32.4.222", 32, 3},        /*  236 */
    {237, 223, "32.139", "32.5.223", 32, 4},        /*  237 */
    {238, 193, "32.140", "28.9.193", 32, 4},        /*  238 */
    {239, 246, "32.141", "35.11.246", 32, 4},       /*  239 */
    {240, 305, "32.142", "41.6.305", 32, 4},        /*  240 */
    {241, 337, "32.143", "45.7.337", 32, 4},        /*  241 */
    {242, 226, "33.144", "33.1.226", 33, 1},        /*  242 */
    {243, 227, "33.145", "33.2.227", 33, 2},        /*  243 */
    {244, 228, "33.146", "33.3.228", 33, 3},        /*  244 */
    {245, 229, "33.147", "33.4.229", 33, 3},        /*  245 */
    {246, 230, "33.148", "33.5.230", 33, 3},        /*  246 */
    {247, 218, "33.149", "31.7.218", 33, 4},        /*  247 */
    {248, 204, "33.150", "29.7.204", 33, 4},        /*  248 */
    {249, 224, "33.151", "32.6.224", 33, 4},        /*  249 */
    {250, 297, "33.152", "40.7.297", 33, 4},        /*  250 */
    {251, 307, "33.153", "41.8.307", 33, 4},        /*  251 */
    {252, 257, "33.154", "36.9.257", 33, 4},        /*  252 */
    {253, 344, "33.155", "46.7.344", 33, 4},        /*  253 */
    {254, 231, "34.156", "34.1.231", 34, 1},        /*  254 */
    {255, 232, "34.157", "34.2.232", 34, 2},        /*  255 */
    {256, 233, "34.158", "34.3.233", 34, 3},        /*  256 */
    {257, 234, "34.159", "34.4.234", 34, 3},        /*  257 */
    {258, 211, "34.160", "30.7.211", 34, 4},        /*  258 */
    {259, 225, "34.161", "32.7.225", 34, 4},        /*  259 */
    {260, 299, "34.162", "40.9.299", 34, 4},        /*  260 */
    {261, 264, "34.163", "37.7.264", 34, 4},        /*  261 */
    {262, 330, "34.164", "44.7.330", 34, 4},        /*  262 */
    {263, 236, "35.165", "35.1.236", 35, 1},        /*  263 */
    {264, 237, "35.166", "35.2.237", 35, 2},        /*  264 */
    {265, 238, "35.167", "35.3.238", 35, 3},        /*  265 */
    {266, 239, "35.168", "35.4.239", 35, 3},        /*  266 */
    {267, 240, "35.169", "35.5.240", 35, 4},        /*  267 */
    {268, 161, "35.170", "25.7.161", 35, 4},        /*  268 */
    {269, 313, "35.171", "42.5.313", 35, 4},        /*  269 */
    {270, 249, "36.172", "36.1.249", 36, 1},        /*  270 */
    {271, 250, "36.173", "36.2.250", 36, 2},        /*  271 */
    {272, 251, "36.174", "36.3.251", 36, 3},        /*  272 */
    {273, 252, "36.175", "36.4.252", 36, 3},        /*  273 */
    {274, 253, "36.176", "36.5.253", 36, 3},        /*  274 */
    {275, 243, "36.177", "35.8.243", 36, 4},        /*  275 */
    {276, 175, "36.178", "26.8.175", 36, 4},        /*  276 */
    {277, 315, "36.179", "42.7.315", 36, 4},        /*  277 */
    {278, 258, "37.180", "37.1.258", 37, 1},        /*  278 */
    {279, 259, "37.181", "37.2.259", 37, 2},        /*  279 */
    {280, 260, "37.182", "37.3.260", 37, 3},        /*  280 */
    {281, 261, "37.183", "37.4.261", 37, 3},        /*  281 */
    {282, 244, "37.184", "35.9.244", 37, 4},        /*  282 */
    {283, 183, "37.185", "27.6.183", 37, 4},        /*  283 */
    {284, 316, "37.186", "42.8.316", 37, 4},        /*  284 */
    {285, 265, "38.187", "38.1.265", 38, 1},        /*  285 */
    {286, 266, "38.188", "38.2.266", 38, 2},        /*  286 */
    {287, 267, "38.189", "38.3.267", 38, 3},        /*  287 */
    {288, 268, "38.190", "38.4.268", 38, 3},        /*  288 */
    {289, 269, "38.191", "38.5.269", 38, 3},        /*  289 */
    {290, 270, "38.192", "38.6.270", 38, 4},        /*  290 */
    {291, 162, "38.193", "25.8.162", 38, 4},        /*  291 */
    {292, 314, "38.194", "42.6.314", 38, 4},        /*  292 */
    {293, 278, "39.195", "39.1.278", 39, 1},        /*  293 */
    {294, 279, "39.196", "39.2.279", 39, 2},        /*  294 */
    {295, 280, "39.197", "39.3.280", 39, 3},        /*  295 */
    {296, 281, "39.198", "39.4.281", 39, 3},        /*  296 */
    {297, 282, "39.199", "39.5.282", 39, 3},        /*  297 */
    {298, 283, "39.200", "39.6.283", 39, 4},        /*  298 */
    {299, 167, "39.201", "25.13.167", 39, 4},       /*  299 */
    {300, 317, "39.202", "42.9.317", 39, 4},        /*  300 */
    {301, 291, "40.203", "40.1.291", 40, 1},        /*  301 */
    {302, 292, "40.204", "40.2.292", 40, 2},        /*  302 */
    {303, 293, "40.205", "40.3.293", 40, 3},        /*  303 */
    {304, 294, "40.206", "40.4.294", 40, 3},        /*  304 */
    {305, 295, "40.207", "40.5.295", 40, 3},        /*  305 */
    {306, 273, "40.208", "38.9.273", 40, 4},        /*  306 */
    {307, 192, "40.209", "28.8.192", 40, 4},        /*  307 */
    {308, 318, "40.210", "42.10.318", 40, 4},       /*  308 */
    {309, 300, "41.211", "41.1.300", 41, 1},        /*  309 */
    {310, 301, "41.212", "41.2.301", 41, 2},        /*  310 */
    {311, 302, "41.213", "41.3.302", 41, 3},        /*  311 */
    {312, 303, "41.214", "41.4.303", 41, 3},        /*  312 */
    {313, 304, "41.215", "41.5.304", 41, 3},        /*  313 */
    {314, 286, "41.216", "39.9.286", 41, 4},        /*  314 */
    {315, 197, "41.217", "28.13.197", 41, 4},       /*  315 */
    {316, 319, "41.218", "42.11.319", 41, 4},       /*  316 */
    {317, 309, "42.219", "42.1.309", 42, 1},        /*  317 */
    {318, 310, "42.220", "42.2.310", 42, 2},        /*  318 */
    {319, 311, "42.221", "42.3.311", 42, 3},        /*  319 */
    {320, 312, "42.222", "42.4.312", 42, 3},        /*  320 */
    {321, 163, "42.223", "25.9.163", 42, 4},        /*  321 */
    {322, 320, "43.224", "43.1.320", 43, 1},        /*  322 */
    {323, 321, "43.225", "43.2.321", 43, 2},        /*  323 */
    {324, 322, "43.226", "43.3.322", 43, 3},        /*  324 */
    {325, 323, "43.227", "43.4.323", 43, 3},        /*  325 */
    {326, 235, "43.228", "34.5.235", 43, 4},        /*  326 */
    {327, 324, "44.229", "44.1.324", 44, 1},        /*  327 */
    {328, 325, "44.230", "44.2.325", 44, 2},        /*  328 */
    {329, 326, "44.231", "44.3.326", 44, 3},        /*  329 */
    {330, 327, "44.232", "44.4.327", 44, 3},        /*  330 */
    {331, 242, "44.233", "35.7.242", 44, 4},        /*  331 */
    {332, 272, "44.234", "38.8.272", 44, 4},        /*  332 */
    {333, 331, "45.235", "45.1.331", 45, 1},        /*  333 */
    {334, 332, "45.236", "45.2.332", 45, 2},        /*  334 */
    {335, 333, "45.237", "45.3.333", 45, 3},        /*  335 */
    {336, 334, "45.238", "45.4.334", 45, 3},        /*  336 */
    {337, 248, "45.239", "35.13.248", 45, 4},       /*  337 */
    {338, 290, "45.240", "39.13.290", 45, 4},       /*  338 */
    {339, 338, "46.241", "46.1.338", 46, 1},        /*  339 */
    {340, 339, "46.242", "46.2.339", 46, 2},        /*  340 */
    {341, 340, "46.243", "46.3.340", 46, 3},        /*  341 */
    {342, 341, "46.244", "46.4.341", 46, 3},        /*  342 */
    {343, 342, "46.245", "46.5.342", 46, 3},        /*  343 */
    {344, 247, "46.246", "35.12.247", 46, 4},       /*  344 */
    {345, 277, "46.247", "38.13.277", 46, 4},       /*  345 */
    {346, 285, "46.248", "39.8.285", 46, 4},        /*  346 */
    {347, 347, "47.249", "47.1.347", 47, 1},        /*  347 */
    {348, 348, "47.250", "47.2.348", 47, 2},        /*  348 */
    {349, 349, "47.251", "47.3.349", 47, 3},        /*  349 */
    {350, 350, "47.252", "47.4.350", 47, 3},        /*  350 */
    {351, 351, "47.253", "47.5.351", 47, 3},        /*  351 */
    {352, 352, "47.254", "47.6.352", 47, 4},        /*  352 */
    {353, 553, "47.255", "65.9.553", 47, 4},        /*  353 */
    {354, 626, "47.256", "71.6.626", 47, 4},        /*  354 */
    {355, 358, "48.257", "48.1.358", 48, 1},        /*  355 */
    {356, 359, "48.258", "48.2.359", 48, 2},        /*  356 */
    {357, 360, "48.259", "48.3.360", 48, 3},        /*  357 */
    {358, 361, "48.260", "48.4.361", 48, 3},        /*  358 */
    {359, 362, "48.261", "48.5.362", 48, 3},        /*  359 */
    {360, 386, "48.262", "50.10.386", 48, 4},       /*  360 */
    {361, 576, "48.263", "66.13.576", 48, 4},       /*  361 */
    {362, 629, "48.264", "71.9.629", 48, 4},        /*  362 */
    {363, 364, "49.265", "49.1.364", 49, 1},        /*  363 */
    {364, 365, "49.266", "49.2.365", 49, 2},        /*  364 */
    {365, 366, "49.267", "49.3.366", 49, 3},        /*  365 */
    {366, 367, "49.268", "49.4.367", 49, 3},        /*  366 */
    {367, 368, "49.269", "49.5.368", 49, 3},        /*  367 */
    {368, 369, "49.270", "49.6.369", 49, 3},        /*  368 */
    {369, 370, "49.271", "49.7.370", 49, 3},        /*  369 */
    {370, 371, "49.272", "49.8.371", 49, 4},        /*  370 */
    {371, 356, "49.273", "47.10.356", 49, 4},       /*  371 */
    {372, 585, "49.274", "67.9.585", 49, 4},        /*  372 */
    {373, 571, "49.275", "66.8.571", 49, 4},        /*  373 */
    {374, 637, "49.276", "72.8.637", 49, 4},        /*  374 */
    {375, 377, "50.277", "50.1.377", 50, 1},        /*  375 */
    {376, 378, "50.278", "50.2.378", 50, 2},        /*  376 */
    {377, 379, "50.279", "50.3.379", 50, 3},        /*  377 */
    {378, 380, "50.280", "50.4.380", 50, 3},        /*  378 */
    {379, 381, "50.281", "50.5.381", 50, 3},        /*  379 */
    {380, 382, "50.282", "50.6.382", 50, 3},        /*  380 */
    {381, 383, "50.283", "50.7.383", 50, 3},        /*  381 */
    {382, 375, "50.284", "49.12.375", 50, 4},       /*  382 */
    {383, 384, "50.285", "50.8.384", 50, 4},        /*  383 */
    {384, 601, "50.286", "68.8.601", 50, 4},        /*  384 */
    {385, 561, "50.287", "65.17.561", 50, 4},       /*  385 */
    {386, 642, "50.288", "72.13.642", 50, 4},       /*  386 */
    {387, 387, "51.289", "51.1.387", 51, 1},        /*  387 */
    {388, 388, "51.290", "51.2.388", 51, 2},        /*  388 */
    {389, 389, "51.291", "51.3.389", 51, 3},        /*  389 */
    {390, 390, "51.292", "51.4.390", 51, 3},        /*  390 */
    {391, 391, "51.293", "51.5.391", 51, 3},        /*  391 */
    {392, 392, "51.294", "51.6.392", 51, 3},        /*  392 */
    {393, 393, "51.295", "51.7.393", 51, 3},        /*  393 */
    {394, 394, "51.296", "51.8.394", 51, 3},        /*  394 */
    {395, 395, "51.297", "51.9.395", 51, 3},        /*  395 */
    {396, 355, "51.298", "47.9.355", 51, 4},        /*  396 */
    {397, 396, "51.299", "51.10.396", 51, 4},       /*  397 */
    {398, 397, "51.300", "51.11.397", 51, 4},       /*  398 */
    {399, 520, "51.301", "63.10.520", 51, 4},       /*  399 */
    {400, 557, "51.302", "65.13.557", 51, 4},       /*  400 */
    {401, 590, "51.303", "67.14.590", 51, 4},       /*  401 */
    {402, 657, "51.304", "74.8.657", 51, 4},        /*  402 */
    {403, 406, "52.305", "52.1.406", 52, 1},        /*  403 */
    {404, 407, "52.306", "52.2.407", 52, 2},        /*  404 */
    {405, 408, "52.307", "52.3.408", 52, 3},        /*  405 */
    {406, 409, "52.308", "52.4.409", 52, 3},        /*  406 */
    {407, 410, "52.309", "52.5.410", 52, 3},        /*  407 */
    {408, 411, "52.310", "52.6.411", 52, 3},        /*  408 */
    {409, 412, "52.311", "52.7.412", 52, 3},        /*  409 */
    {410, 413, "52.312", "52.8.413", 52, 3},        /*  410 */
    {411, 414, "52.313", "52.9.414", 52, 3},        /*  411 */
    {412, 427, "52.314", "53.13.427", 52, 4},       /*  412 */
    {413, 385, "52.315", "50.9.385", 52, 4},        /*  413 */
    {414, 440, "52.316", "54.13.440", 52, 4},       /*  414 */
    {415, 575, "52.317", "66.12.575", 52, 4},       /*  415 */
    {416, 527, "52.318", "63.17.527", 52, 4},       /*  416 */
    {417, 604, "52.319", "68.11.604", 52, 4},       /*  417 */
    {418, 658, "52.320", "74.9.658", 52, 4},        /*  418 */
    {419, 415, "53.321", "53.1.415", 53, 1},        /*  419 */
    {420, 416, "53.322", "53.2.416", 53, 2},        /*  420 */
    {421, 417, "53.323", "53.3.417", 53, 3},        /*  421 */
    {422, 418, "53.324", "53.4.418", 53, 3},        /*  422 */
    {423, 419, "53.325", "53.5.419", 53, 3},        /*  423 */
    {424, 420, "53.326", "53.6.420", 53, 3},        /*  424 */
    {425, 421, "53.327", "53.7.421", 53, 3},        /*  425 */
    {426, 422, "53.328", "53.8.422", 53, 3},        /*  426 */
    {427, 423, "53.329", "53.9.423", 53, 3},        /*  427 */
    {428, 401, "53.330", "51.15.401", 53, 4},       /*  428 */
    {429, 424, "53.331", "53.10.424", 53, 4},       /*  429 */
    {430, 374, "53.332", "49.11.374", 53, 4},       /*  430 */
    {431, 572, "53.333", "66.9.572", 53, 4},        /*  431 */
    {432, 560, "53.334", "65.16.560", 53, 4},       /*  432 */
    {433, 542, "53.335", "64.15.542", 53, 4},       /*  433 */
    {434, 659, "53.336", "74.10.659", 53, 4},       /*  434 */
    {435, 428, "54.337", "54.1.428", 54, 1},        /*  435 */
    {436, 429, "54.338", "54.2.429", 54, 2},        /*  436 */
    {437, 430, "54.339", "54.3.430", 54, 3},        /*  437 */
    {438, 431, "54.340", "54.4.431", 54, 3},        /*  438 */
    {439, 432, "54.341", "54.5.432", 54, 3},        /*  439 */
    {440, 433, "54.342", "54.6.433", 54, 3},        /*  440 */
    {441, 434, "54.343", "54.7.434", 54, 3},        /*  441 */
    {442, 435, "54.344", "54.8.435", 54, 3},        /*  442 */
    {443, 436, "54.345", "54.9.436", 54, 3},        /*  443 */
    {444, 373, "54.346", "49.10.373", 54, 4},       /*  444 */
    {445, 437, "54.347", "54.10.437", 54, 4},       /*  445 */
    {446, 404, "54.348", "51.18.404", 54, 4},       /*  446 */
    {447, 538, "54.349", "64.11.538", 54, 4},       /*  447 */
    {448, 589, "54.350", "67.13.589", 54, 4},       /*  448 */
    {449, 602, "54.351", "68.9.602", 54, 4},        /*  449 */
    {450, 649, "54.352", "73.7.649", 54, 4},        /*  450 */
    {451, 441, "55.353", "55.1.441", 55, 1},        /*  451 */
    {452, 442, "55.354", "55.2.442", 55, 2},        /*  452 */
    {453, 443, "55.355", "55.3.443", 55, 3},        /*  453 */
    {454, 444, "55.356", "55.4.444", 55, 3},        /*  454 */
    {455, 445, "55.357", "55.5.445", 55, 3},        /*  455 */
    {456, 446, "55.358", "55.6.446", 55, 3},        /*  456 */
    {457, 447, "55.359", "55.7.447", 55, 3},        /*  457 */
    {458, 402, "55.360", "51.16.402", 55, 4},       /*  458 */
    {459, 448, "55.361", "55.8.448", 55, 4},        /*  459 */
    {460, 537, "55.362", "64.10.537", 55, 4},       /*  460 */
    {461, 559, "55.363", "65.15.559", 55, 4},       /*  461 */
    {462, 640, "55.364", "72.11.640", 55, 4},       /*  462 */
    {463, 451, "56.365", "56.1.451", 56, 1},        /*  463 */
    {464, 452, "56.366", "56.2.452", 56, 2},        /*  464 */
    {465, 453, "56.367", "56.3.453", 56, 3},        /*  465 */
    {466, 454, "56.368", "56.4.454", 56, 3},        /*  466 */
    {467, 455, "56.369", "56.5.455", 56, 3},        /*  467 */
    {468, 456, "56.370", "56.6.456", 56, 3},        /*  468 */
    {469, 457, "56.371", "56.7.457", 56, 3},        /*  469 */
    {470, 439, "56.372", "54.12.439", 56, 4},       /*  470 */
    {471, 487, "56.373", "59.10.487", 56, 4},       /*  471 */
    {472, 541, "56.374", "64.14.541", 56, 4},       /*  472 */
    {473, 573, "56.375", "66.10.573", 56, 4},       /*  473 */
    {474, 639, "56.376", "72.10.639", 56, 4},       /*  474 */
    {475, 458, "57.377", "57.1.458", 57, 1},        /*  475 */
    {476, 459, "57.378", "57.2.459", 57, 2},        /*  476 */
    {477, 460, "57.379", "57.3.460", 57, 3},        /*  477 */
    {478, 461, "57.380", "57.4.461", 57, 3},        /*  478 */
    {479, 462, "57.381", "57.5.462", 57, 3},        /*  479 */
    {480, 463, "57.382", "57.6.463", 57, 3},        /*  480 */
    {481, 464, "57.383", "57.7.464", 57, 3},        /*  481 */
    {482, 465, "57.384", "57.8.465", 57, 3},        /*  482 */
    {483, 466, "57.385", "57.9.466", 57, 3},        /*  483 */
    {484, 467, "57.386", "57.10.467", 57, 4},       /*  484 */
    {485, 403, "57.387", "51.17.403", 57, 4},       /*  485 */
    {486, 399, "57.388", "51.13.399", 57, 4},       /*  486 */
    {487, 591, "57.389", "67.15.591", 57, 4},       /*  487 */
    {488, 540, "57.390", "64.13.540", 57, 4},       /*  488 */
    {489, 521, "57.391", "63.11.521", 57, 4},       /*  489 */
    {490, 638, "57.392", "72.9.638", 57, 4},        /*  490 */
    {491, 471, "58.393", "58.1.471", 58, 1},        /*  491 */
    {492, 472, "58.394", "58.2.472", 58, 2},        /*  492 */
    {493, 473, "58.395", "58.3.473", 58, 3},        /*  493 */
    {494, 474, "58.396", "58.4.474", 58, 3},        /*  494 */
    {495, 475, "58.397", "58.5.475", 58, 3},        /*  495 */
    {496, 476, "58.398", "58.6.476", 58, 3},        /*  496 */
    {497, 477, "58.399", "58.7.477", 58, 3},        /*  497 */
    {498, 426, "58.400", "53.12.426", 58, 4},       /*  498 */
    {499, 450, "58.401", "55.10.450", 58, 4},       /*  499 */
    {500, 525, "58.402", "63.15.525", 58, 4},       /*  500 */
    {501, 574, "58.403", "66.11.574", 58, 4},       /*  501 */
    {502, 628, "58.404", "71.8.628", 58, 4},        /*  502 */
    {503, 478, "59.405", "59.1.478", 59, 1},        /*  503 */
    {504, 479, "59.406", "59.2.479", 59, 2},        /*  504 */
    {505, 480, "59.407", "59.3.480", 59, 3},        /*  505 */
    {506, 481, "59.408", "59.4.481", 59, 3},        /*  506 */
    {507, 482, "59.409", "59.5.482", 59, 3},        /*  507 */
    {508, 483, "59.410", "59.6.483", 59, 3},        /*  508 */
    {509, 484, "59.411", "59.7.484", 59, 3},        /*  509 */
    {510, 400, "59.412", "51.14.400", 59, 4},       /*  510 */
    {511, 485, "59.413", "59.8.485", 59, 4},        /*  511 */
    {512, 522, "59.414", "63.12.522", 59, 4},       /*  512 */
    {513, 558, "59.415", "65.14.558", 59, 4},       /*  513 */
    {514, 627, "59.416", "71.7.627", 59, 4},        /*  514 */
    {515, 488, "60.417", "60.1.488", 60, 1},        /*  515 */
    {516, 489, "60.418", "60.2.489", 60, 2},        /*  516 */
    {517, 490, "60.419", "60.3.490", 60, 3},        /*  517 */
    {518, 491, "60.420", "60.4.491", 60, 3},        /*  518 */
    {519, 492, "60.421", "60.5.492", 60, 3},        /*  519 */
    {520, 493, "60.422", "60.6.493", 60, 3},        /*  520 */
    {521, 494, "60.423", "60.7.494", 60, 3},        /*  521 */
    {522, 495, "60.424", "60.8.495", 60, 3},        /*  522 */
    {523, 496, "60.425", "60.9.496", 60, 3},        /*  523 */
    {524, 438, "60.426", "54.11.438", 60, 4},       /*  524 */
    {525, 470, "60.427", "57.13.470", 60, 4},       /*  525 */
    {526, 425, "60.428", "53.11.425", 60, 4},       /*  526 */
    {527, 544, "60.429", "64.17.544", 60, 4},       /*  527 */
    {528, 603, "60.430", "68.10.603", 60, 4},       /*  528 */
    {529, 526, "60.431", "63.16.526", 60, 4},       /*  529 */
    {530, 641, "60.432", "72.12.641", 60, 4},       /*  530 */
    {531, 497, "61.433", "61.1.497", 61, 1},        /*  531 */
    {532, 498, "61.434", "61.2.498", 61, 2},        /*  532 */
    {533, 499, "61.435", "61.3.499", 61, 3},        /*  533 */
    {534, 500, "61.436", "61.4.500", 61, 3},        /*  534 */
    {535, 501, "61.437", "61.5.501", 61, 3},        /*  535 */
    {536, 469, "61.438", "57.12.469", 61, 4},       /*  536 */
    {537, 543, "61.439", "64.16.543", 61, 4},       /*  537 */
    {538, 648, "61.440", "73.6.648", 61, 4},        /*  538 */
    {539, 502, "62.441", "62.1.502", 62, 1},        /*  539 */
    {540, 503, "62.442", "62.2.503", 62, 2},        /*  540 */
    {541, 504, "62.443", "62.3.504", 62, 3},        /*  541 */
    {542, 505, "62.444", "62.4.505", 62, 3},        /*  542 */
    {543, 506, "62.445", "62.5.506", 62, 3},        /*  543 */
    {544, 507, "62.446", "62.6.507", 62, 3},        /*  544 */
    {545, 508, "62.447", "62.7.508", 62, 3},        /*  545 */
    {546, 509, "62.448", "62.8.509", 62, 3},        /*  546 */
    {547, 510, "62.449", "62.9.510", 62, 3},        /*  547 */
    {548, 486, "62.450", "59.9.486", 62, 4},        /*  548 */
    {549, 449, "62.451", "55.9.449", 62, 4},        /*  549 */
    {550, 468, "62.452", "57.11.468", 62, 4},       /*  550 */
    {551, 523, "62.453", "63.13.523", 62, 4},       /*  551 */
    {552, 524, "62.454", "63.14.524", 62, 4},       /*  552 */
    {553, 539, "62.455", "64.12.539", 62, 4},       /*  553 */
    {554, 660, "62.456", "74.11.660", 62, 4},       /*  554 */
    {555, 511, "63.457", "63.1.511", 63, 1},        /*  555 */
    {556, 512, "63.458", "63.2.512", 63, 2},        /*  556 */
    {557, 513, "63.459", "63.3.513", 63, 3},        /*  557 */
    {558, 514, "63.460", "63.4.514", 63, 3},        /*  558 */
    {559, 515, "63.461", "63.5.515", 63, 3},        /*  559 */
    {560, 516, "63.462", "63.6.516", 63, 3},        /*  560 */
    {561, 517, "63.463", "63.7.517", 63, 3},        /*  561 */
    {562, 518, "63.464", "63.8.518", 63, 3},        /*  562 */
    {563, 519, "63.465", "63.9.519", 63, 3},        /*  563 */
    {564, 556, "63.466", "65.12.556", 63, 4},       /*  564 */
    {565, 398, "63.467", "51.12.398", 63, 4},       /*  565 */
    {566, 611, "63.468", "69.7.611", 63, 4},        /*  566 */
    {567, 528, "64.469", "64.1.528", 64, 1},        /*  567 */
    {568, 529, "64.470", "64.2.529", 64, 2},        /*  568 */
    {569, 530, "64.471", "64.3.530", 64, 3},        /*  569 */
    {570, 531, "64.472", "64.4.531", 64, 3},        /*  570 */
    {571, 532, "64.473", "64.5.532", 64, 3},        /*  571 */
    {572, 533, "64.474", "64.6.533", 64, 3},        /*  572 */
    {573, 534, "64.475", "64.7.534", 64, 3},        /*  573 */
    {574, 535, "64.476", "64.8.535", 64, 3},        /*  574 */
    {575, 536, "64.477", "64.9.536", 64, 3},        /*  575 */
    {576, 587, "64.478", "67.11.587", 64, 4},       /*  576 */
    {577, 405, "64.479", "51.19.405", 64, 4},       /*  577 */
    {578, 614, "64.480", "69.10.614", 64, 4},       /*  578 */
    {579, 545, "65.481", "65.1.545", 65, 1},        /*  579 */
    {580, 546, "65.482", "65.2.546", 65, 2},        /*  580 */
    {581, 547, "65.483", "65.3.547", 65, 3},        /*  581 */
    {582, 548, "65.484", "65.4.548", 65, 3},        /*  582 */
    {583, 549, "65.485", "65.5.549", 65, 3},        /*  583 */
    {584, 550, "65.486", "65.6.550", 65, 3},        /*  584 */
    {585, 551, "65.487", "65.7.551", 65, 3},        /*  585 */
    {586, 552, "65.488", "65.8.552", 65, 4},        /*  586 */
    {587, 353, "65.489", "47.7.353", 65, 4},        /*  587 */
    {588, 610, "65.490", "69.6.610", 65, 4},        /*  588 */
    {589, 564, "66.491", "66.1.564", 66, 1},        /*  589 */
    {590, 565, "66.492", "66.2.565", 66, 2},        /*  590 */
    {591, 566, "66.493", "66.3.566", 66, 3},        /*  591 */
    {592, 567, "66.494", "66.4.567", 66, 3},        /*  592 */
    {593, 568, "66.495", "66.5.568", 66, 3},        /*  593 */
    {594, 569, "66.496", "66.6.569", 66, 3},        /*  594 */
    {595, 570, "66.497", "66.7.570", 66, 3},        /*  595 */
    {596, 555, "66.498", "65.11.555", 66, 4},       /*  596 */
    {597, 372, "66.499", "49.9.372", 66, 4},        /*  597 */
    {598, 613, "66.500", "69.9.613", 66, 4},        /*  598 */
    {599, 577, "67.501", "67.1.577", 67, 1},        /*  599 */
    {600, 578, "67.502", "67.2.578", 67, 2},        /*  600 */
    {601, 579, "67.503", "67.3.579", 67, 3},        /*  601 */
    {602, 580, "67.504", "67.4.580", 67, 3},        /*  602 */
    {603, 581, "67.505", "67.5.581", 67, 3},        /*  603 */
    {604, 582, "67.506", "67.6.582", 67, 3},        /*  604 */
    {605, 583, "67.507", "67.7.583", 67, 3},        /*  605 */
    {606, 584, "67.508", "67.8.584", 67, 4},        /*  606 */
    {607, 357, "67.509", "47.11.357", 67, 4},       /*  607 */
    {608, 612, "67.510", "69.8.612", 67, 4},        /*  608 */
    {609, 594, "68.511", "68.1.594", 68, 1},        /*  609 */
    {610, 595, "68.512", "68.2.595", 68, 2},        /*  610 */
    {611, 596, "68.513", "68.3.596", 68, 3},        /*  611 */
    {612, 597, "68.514", "68.4.597", 68, 3},        /*  612 */
    {613, 598, "68.515", "68.5.598", 68, 3},        /*  613 */
    {614, 599, "68.516", "68.6.599", 68, 3},        /*  614 */
    {615, 600, "68.517", "68.7.600", 68, 3},        /*  615 */
    {616, 588, "68.518", "67.12.588", 68, 4},       /*  616 */
    {617, 376, "68.519", "49.13.376", 68, 4},       /*  617 */
    {618, 615, "68.520", "69.11.615", 68, 4},       /*  618 */
    {619, 605, "69.521", "69.1.605", 69, 1},        /*  619 */
    {620, 606, "69.522", "69.2.606", 69, 2},        /*  620 */
    {621, 607, "69.523", "69.3.607", 69, 3},        /*  621 */
    {622, 608, "69.524", "69.4.608", 69, 3},        /*  622 */
    {623, 609, "69.525", "69.5.609", 69, 3},        /*  623 */
    {624, 354, "69.526", "47.8.354", 69, 4},        /*  624 */
    {625, 616, "70.527", "70.1.616", 70, 1},        /*  625 */
    {626, 617, "70.528", "70.2.617", 70, 2},        /*  626 */
    {627, 618, "70.529", "70.3.618", 70, 3},        /*  627 */
    {628, 619, "70.530", "70.4.619", 70, 3},        /*  628 */
    {629, 620, "70.531", "70.5.620", 70, 3},        /*  629 */
    {630, 363, "70.532", "48.6.363", 70, 4},        /*  630 */
    {631, 621, "71.533", "71.1.621", 71, 1},        /*  631 */
    {632, 622, "71.534", "71.2.622", 71, 2},        /*  632 */
    {633, 623, "71.535", "71.3.623", 71, 3},        /*  633 */
    {634, 624, "71.536", "71.4.624", 71, 3},        /*  634 */
    {635, 625, "71.537", "71.5.625", 71, 3},        /*  635 */
    {636, 554, "71.538", "65.10.554", 71, 4},       /*  636 */
    {637, 630, "72.539", "72.1.630", 72, 1},        /*  637 */
    {638, 631, "72.540", "72.2.631", 72, 2},        /*  638 */
    {639, 632, "72.541", "72.3.632", 72, 3},        /*  639 */
    {640, 633, "72.542", "72.4.633", 72, 3},        /*  640 */
    {641, 634, "72.543", "72.5.634", 72, 3},        /*  641 */
    {642, 635, "72.544", "72.6.635", 72, 3},        /*  642 */
    {643, 636, "72.545", "72.7.636", 72, 3},        /*  643 */
    {644, 563, "72.546", "65.19.563", 72, 4},       /*  644 */
    {645, 586, "72.547", "67.10.586", 72, 4},       /*  645 */
    {646, 643, "73.548", "73.1.643", 73, 1},        /*  646 */
    {647, 644, "73.549", "73.2.644", 73, 2},        /*  647 */
    {648, 645, "73.550", "73.3.645", 73, 3},        /*  648 */
    {649, 646, "73.551", "73.4.646", 73, 3},        /*  649 */
    {650, 647, "73.552", "73.5.647", 73, 3},        /*  650 */
    {651, 593, "73.553", "67.17.593", 73, 4},       /*  651 */
    {652, 650, "74.554", "74.1.650", 74, 1},        /*  652 */
    {653, 651, "74.555", "74.2.651", 74, 2},        /*  653 */
    {654, 652, "74.556", "74.3.652", 74, 3},        /*  654 */
    {655, 653, "74.557", "74.4.653", 74, 3},        /*  655 */
    {656, 654, "74.558", "74.5.654", 74, 3},        /*  656 */
    {657, 655, "74.559", "74.6.655", 74, 3},        /*  657 */
    {658, 656, "74.560", "74.7.656", 74, 3},        /*  658 */
    {659, 592, "74.561", "67.16.592", 74, 4},       /*  659 */
    {660, 562, "74.562", "65.18.562", 74, 4},       /*  660 */
    {661, 661, "75.1", "75.1.661", 75, 1},          /*  661 */
    {662, 662, "75.2", "75.2.662", 75, 2},          /*  662 */
    {663, 663, "75.3", "75.3.663", 75, 3},          /*  663 */
    {664, 664, "75.4", "75.4.664", 75, 4},          /*  664 */
    {665, 665, "75.5", "75.5.665", 75, 4},          /*  665 */
    {666, 686, "75.6", "79.4.686", 75, 4},          /*  666 */
    {667, 668, "76.7", "76.1.668", 76, 1},          /*  667 */
    {668, 669, "76.8", "76.2.669", 76, 2},          /*  668 */
    {669, 670, "76.9", "76.3.670", 76, 3},          /*  669 */
    {670, 675, "76.10", "77.4.675", 76, 4},         /*  670 */
    {671, 671, "76.11", "76.4.671", 76, 4},         /*  671 */
    {672, 691, "76.12", "80.4.691", 76, 4},         /*  672 */
    {673, 672, "77.13", "77.1.672", 77, 1},         /*  673 */
    {674, 673, "77.14", "77.2.673", 77, 2},         /*  674 */
    {675, 674, "77.15", "77.3.674", 77, 3},         /*  675 */
    {676, 667, "77.16", "75.7.667", 77, 4},         /*  676 */
    {677, 676, "77.17", "77.5.676", 77, 4},         /*  677 */
    {678, 687, "77.18", "79.5.687", 77, 4},         /*  678 */
    {679, 679, "78.19", "78.1.679", 78, 1},         /*  679 */
    {680, 680, "78.20", "78.2.680", 78, 2},         /*  680 */
    {681, 681, "78.21", "78.3.681", 78, 3},         /*  681 */
    {682, 678, "78.22", "77.7.678", 78, 4},         /*  682 */
    {683, 682, "78.23", "78.4.682", 78, 4},         /*  683 */
    {684, 692, "78.24", "80.5.692", 78, 4},         /*  684 */
    {685, 683, "79.25", "79.1.683", 79, 1},         /*  685 */
    {686, 684, "79.26", "79.2.684", 79, 2},         /*  686 */
    {687, 685, "79.27", "79.3.685", 79, 3},         /*  687 */
    {688, 666, "79.28", "75.6.666", 79, 4},         /*  688 */
    {689, 688, "80.29", "80.1.688", 80, 1},         /*  689 */
    {690, 689, "80.30", "80.2.689", 80, 2},         /*  690 */
    {691, 690, "80.31", "80.3.690", 80, 3},         /*  691 */
    {692, 677, "80.32", "77.6.677", 80, 4},         /*  692 */
    {693, 693, "81.33", "81.1.693", 81, 1},         /*  693 */
    {694, 694, "81.34", "81.2.694", 81, 2},         /*  694 */
    {695, 695, "81.35", "81.3.695", 81, 3},         /*  695 */
    {696, 696, "81.36", "81.4.696", 81, 4},         /*  696 */
    {697, 697, "81.37", "81.5.697", 81, 4},         /*  697 */
    {698, 702, "81.38", "82.4.702", 81, 4},         /*  698 */
    {699, 699, "82.39", "82.1.699", 82, 1},         /*  699 */
    {700, 700, "82.40", "82.2.700", 82, 2},         /*  700 */
    {701, 701, "82.41", "82.3.701", 82, 3},         /*  701 */
    {702, 698, "82.42", "81.6.698", 82, 4},         /*  702 */
    {703, 703, "83.43", "83.1.703", 83, 1},         /*  703 */
    {704, 704, "83.44", "83.2.704", 83, 2},         /*  704 */
    {705, 705, "83.45", "83.3.705", 83, 3},         /*  705 */
    {706, 706, "83.46", "83.4.706", 83, 3},         /*  706 */
    {707, 707, "83.47", "83.5.707", 83, 3},         /*  707 */
    {708, 708, "83.48", "83.6.708", 83, 4},         /*  708 */
    {709, 709, "83.49", "83.7.709", 83, 4},         /*  709 */
    {710, 738, "83.50", "87.6.738", 83, 4},         /*  710 */
    {711, 713, "84.51", "84.1.713", 84, 1},         /*  711 */
    {712, 714, "84.52", "84.2.714", 84, 2},         /*  712 */
    {713, 715, "84.53", "84.3.715", 84, 3},         /*  713 */
    {714, 716, "84.54", "84.4.716", 84, 3},         /*  714 */
    {715, 717, "84.55", "84.5.717", 84, 3},         /*  715 */
    {716, 711, "84.56", "83.9.711", 84, 4},         /*  716 */
    {717, 718, "84.57", "84.6.718", 84, 4},         /*  717 */
    {718, 739, "84.58", "87.7.739", 84, 4},         /*  718 */
    {719, 720, "85.59", "85.1.720", 85, 1},         /*  719 */
    {720, 721, "85.60", "85.2.721", 85, 2},         /*  720 */
    {721, 722, "85.61", "85.3.722", 85, 3},         /*  721 */
    {722, 723, "85.62", "85.4.723", 85, 3},         /*  722 */
    {723, 724, "85.63", "85.5.724", 85, 3},         /*  723 */
    {724, 725, "85.64", "85.6.725", 85, 4},         /*  724 */
    {725, 712, "85.65", "83.10.712", 85, 4},        /*  725 */
    {726, 740, "85.66", "87.8.740", 85, 4},         /*  726 */
    {727, 727, "86.67", "86.1.727", 86, 1},         /*  727 */
    {728, 728, "86.68", "86.2.728", 86, 2},         /*  728 */
    {729, 729, "86.69", "86.3.729", 86, 3},         /*  729 */
    {730, 730, "86.70", "86.4.730", 86, 3},         /*  730 */
    {731, 731, "86.71", "86.5.731", 86, 3},         /*  731 */
    {732, 726, "86.72", "85.7.726", 86, 4},         /*  732 */
    {733, 719, "86.73", "84.7.719", 86, 4},         /*  733 */
    {734, 741, "86.74", "87.9.741", 86, 4},         /*  734 */
    {735, 733, "87.75", "87.1.733", 87, 1},         /*  735 */
    {736, 734, "87.76", "87.2.734", 87, 2},         /*  736 */
    {737, 735, "87.77", "87.3.735", 87, 3},         /*  737 */
    {738, 736, "87.78", "87.4.736", 87, 3},         /*  738 */
    {739, 737, "87.79", "87.5.737", 87, 3},         /*  739 */
    {740, 710, "87.80", "83.8.710", 87, 4},         /*  740 */
    {741, 742, "88.81", "88.1.742", 88, 1},         /*  741 */
    {742, 743, "88.82", "88.2.743", 88, 2},         /*  742 */
    {743, 744, "88.83", "88.3.744", 88, 3},         /*  743 */
    {744, 745, "88.84", "88.4.745", 88, 3},         /*  744 */
    {745, 746, "88.85", "88.5.746", 88, 3},         /*  745 */
    {746, 732, "88.86", "86.6.732", 88, 4},         /*  746 */
    {747, 747, "89.87", "89.1.747", 89, 1},         /*  747 */
    {748, 748, "89.88", "89.2.748", 89, 2},         /*  748 */
    {749, 749, "89.89", "89.3.749", 89, 3},         /*  749 */
    {750, 750, "89.90", "89.4.750", 89, 3},         /*  750 */
    {751, 751, "89.91", "89.5.751", 89, 3},         /*  751 */
    {752, 752, "89.92", "89.6.752", 89, 4},         /*  752 */
    {753, 753, "89.93", "89.7.753", 89, 4},         /*  753 */
    {754, 810, "89.94", "97.6.810", 89, 4},         /*  754 */
    {755, 757, "90.95", "90.1.757", 90, 1},         /*  755 */
    {756, 758, "90.96", "90.2.758", 90, 2},         /*  756 */
    {757, 759, "90.97", "90.3.759", 90, 3},         /*  757 */
    {758, 760, "90.98", "90.4.760", 90, 3},         /*  758 */
    {759, 761, "90.99", "90.5.761", 90, 3},         /*  759 */
    {760, 762, "90.100", "90.6.762", 90, 4},        /*  760 */
    {761, 756, "90.101", "89.10.756", 90, 4},       /*  761 */
    {762, 812, "90.102", "97.8.812", 90, 4},        /*  762 */
    {763, 764, "91.103", "91.1.764", 91, 1},        /*  763 */
    {764, 765, "91.104", "91.2.765", 91, 2},        /*  764 */
    {765, 766, "91.105", "91.3.766", 91, 3},        /*  765 */
    {766, 767, "91.106", "91.4.767", 91, 3},        /*  766 */
    {767, 768, "91.107", "91.5.768", 91, 3},        /*  767 */
    {768, 781, "91.108", "93.6.781", 91, 4},        /*  768 */
    {769, 769, "91.109", "91.6.769", 91, 4},        /*  769 */
    {770, 819, "91.110", "98.6.819", 91, 4},        /*  770 */
    {771, 771, "92.111", "92.1.771", 92, 1},        /*  771 */
    {772, 772, "92.112", "92.2.772", 92, 2},        /*  772 */
    {773, 773, "92.113", "92.3.773", 92, 3},        /*  773 */
    {774, 774, "92.114", "92.4.774", 92, 3},        /*  774 */
    {775, 775, "92.115", "92.5.775", 92, 3},        /*  775 */
    {776, 791, "92.116", "94.6.791", 92, 4},        /*  776 */
    {777, 770, "92.117", "91.7.770", 92, 4},        /*  777 */
    {778, 821, "92.118", "98.8.821", 92, 4},        /*  778 */
    {779, 776, "93.119", "93.1.776", 93, 1},        /*  779 */
    {780, 777, "93.120", "93.2.777", 93, 2},        /*  780 */
    {781, 778, "93.121", "93.3.778", 93, 3},        /*  781 */
    {782, 779, "93.122", "93.4.779", 93, 3},        /*  782 */
    {783, 780, "93.123", "93.5.780", 93, 3},        /*  783 */
    {784, 755, "93.124", "89.9.755", 93, 4},        /*  784 */
    {785, 782, "93.125", "93.7.782", 93, 4},        /*  785 */
    {786, 811, "93.126", "97.7.811", 93, 4},        /*  786 */
    {787, 786, "94.127", "94.1.786", 94, 1},        /*  787 */
    {788, 787, "94.128", "94.2.787", 94, 2},        /*  788 */
    {789, 788, "94.129", "94.3.788", 94, 3},        /*  789 */
    {790, 789, "94.130", "94.4.789", 94, 3},        /*  790 */
    {791, 790, "94.131", "94.5.790", 94, 3},        /*  791 */
    {792, 763, "94.132", "90.7.763", 94, 4},        /*  792 */
    {793, 785, "94.133", "93.10.785", 94, 4},       /*  793 */
    {794, 813, "94.134", "97.9.813", 94, 4},        /*  794 */
    {795, 793, "95.135", "95.1.793", 95, 1},        /*  795 */
    {796, 794, "95.136", "95.2.794", 95, 2},        /*  796 */
    {797, 795, "95.137", "95.3.795", 95, 3},        /*  797 */
    {798, 796, "95.138", "95.4.796", 95, 3},        /*  798 */
    {799, 797, "95.139", "95.5.797", 95, 3},        /*  799 */
    {800, 784, "95.140", "93.9.784", 95, 4},        /*  800 */
    {801, 798, "95.141", "95.6.798", 95, 4},        /*  801 */
    {802, 820, "95.142", "98.7.820", 95, 4},        /*  802 */
    {803, 800, "96.143", "96.1.800", 96, 1},        /*  803 */
    {804, 801, "96.144", "96.2.801", 96, 2},        /*  804 */
    {805, 802, "96.145", "96.3.802", 96, 3},        /*  805 */
    {806, 803, "96.146", "96.4.803", 96, 3},        /*  806 */
    {807, 804, "96.147", "96.5.804", 96, 3},        /*  807 */
    {808, 792, "96.148", "94.7.792", 96, 4},        /*  808 */
    {809, 799, "96.149", "95.7.799", 96, 4},        /*  809 */
    {810, 822, "96.150", "98.9.822", 96, 4},        /*  810 */
    {811, 805, "97.151", "97.1.805", 97, 1},        /*  811 */
    {812, 806, "97.152", "97.2.806", 97, 2},        /*  812 */
    {813, 807, "97.153", "97.3.807", 97, 3},        /*  813 */
    {814, 808, "97.154", "97.4.808", 97, 3},        /*  814 */
    {815, 809, "97.155", "97.5.809", 97, 3},        /*  815 */
    {816, 754, "97.156", "89.8.754", 97, 4},        /*  816 */
    {817, 814, "98.157", "98.1.814", 98, 1},        /*  817 */
    {818, 815, "98.158", "98.2.815", 98, 2},        /*  818 */
    {819, 816, "98.159", "98.3.816", 98, 3},        /*  819 */
    {820, 817, "98.160", "98.4.817", 98, 3},        /*  820 */
    {821, 818, "98.161", "98.5.818", 98, 3},        /*  821 */
    {822, 783, "98.162", "93.8.783", 98, 4},        /*  822 */
    {823, 823, "99.163", "99.1.823", 99, 1},        /*  823 */
    {824, 824, "99.164", "99.2.824", 99, 2},        /*  824 */
    {825, 825, "99.165", "99.3.825", 99, 3},        /*  825 */
    {826, 826, "99.166", "99.4.826", 99, 3},        /*  826 */
    {827, 827, "99.167", "99.5.827", 99, 3},        /*  827 */
    {828, 828, "99.168", "99.6.828", 99, 4},        /*  828 */
    {829, 829, "99.169", "99.7.829", 99, 4},        /*  829 */
    {830, 888, "99.170", "107.6.888", 99, 4},       /*  830 */
    {831, 836, "100.171", "100.1.836", 100, 1},     /*  831 */
    {832, 837, "100.172", "100.2.837", 100, 2},     /*  832 */
    {833, 838, "100.173", "100.3.838", 100, 3},     /*  833 */
    {834, 839, "100.174", "100.4.839", 100, 3},     /*  834 */
    {835, 840, "100.175", "100.5.840", 100, 3},     /*  835 */
    {836, 841, "100.176", "100.6.841", 100, 4},     /*  836 */
    {837, 834, "100.177", "99.12.834", 100, 4},     /*  837 */
    {838, 897, "100.178", "108.6.897", 100, 4},     /*  838 */
    {839, 845, "101.179", "101.1.845", 101, 1},     /*  839 */
    {840, 846, "101.180", "101.2.846", 101, 2},     /*  840 */
    {841, 847, "101.181", "101.3.847", 101, 3},     /*  841 */
    {842, 848, "101.182", "101.4.848", 101, 3},     /*  842 */
    {843, 849, "101.183", "101.5.849", 101, 3},     /*  843 */
    {844, 831, "101.184", "99.9.831", 101, 4},      /*  844 */
    {845, 876, "101.185", "105.6.876", 101, 4},     /*  845 */
    {846, 898, "101.186", "108.7.898", 101, 4},     /*  846 */
    {847, 852, "102.187", "102.1.852", 102, 1},     /*  847 */
    {848, 853, "102.188", "102.2.853", 102, 2},     /*  848 */
    {849, 854, "102.189", "102.3.854", 102, 3},     /*  849 */
    {850, 855, "102.190", "102.4.855", 102, 3},     /*  850 */
    {851, 856, "102.191", "102.5.856", 102, 3},     /*  851 */
    {852, 842, "102.192", "100.7.842", 102, 4},     /*  852 */
    {853, 877, "102.193", "105.7.877", 102, 4},     /*  853 */
    {854, 889, "102.194", "107.7.889", 102, 4},     /*  854 */
    {855, 859, "103.195", "103.1.859", 103, 1},     /*  855 */
    {856, 860, "103.196", "103.2.860", 103, 2},     /*  856 */
    {857, 861, "103.197", "103.3.861", 103, 3},     /*  857 */
    {858, 862, "103.198", "103.4.862", 103, 3},     /*  858 */
    {859, 863, "103.199", "103.5.863", 103, 3},     /*  859 */
    {860, 833, "103.200", "99.11.833", 103, 4},     /*  860 */
    {861, 864, "103.201", "103.6.864", 103, 4},     /*  861 */
    {862, 900, "103.202", "108.9.900", 103, 4},     /*  862 */
    {863, 866, "104.203", "104.1.866", 104, 1},     /*  863 */
    {864, 867, "104.204", "104.2.867", 104, 2},     /*  864 */
    {865, 868, "104.205", "104.3.868", 104, 3},     /*  865 */
    {866, 869, "104.206", "104.4.869", 104, 3},     /*  866 */
    {867, 870, "104.207", "104.5.870", 104, 3},     /*  867 */
    {868, 844, "104.208", "100.9.844", 104, 4},     /*  868 */
    {869, 865, "104.209", "103.7.865", 104, 4},     /*  869 */
    {870, 891, "104.210", "107.9.891", 104, 4},     /*  870 */
    {871, 871, "105.211", "105.1.871", 105, 1},     /*  871 */
    {872, 872, "105.212", "105.2.872", 105, 2},     /*  872 */
    {873, 873, "105.213", "105.3.873", 105, 3},     /*  873 */
    {874, 874, "105.214", "105.4.874", 105, 3},     /*  874 */
    {875, 875, "105.215", "105.5.875", 105, 3},     /*  875 */
    {876, 832, "105.216", "99.10.832", 105, 4},     /*  876 */
    {877, 850, "105.217", "101.6.850", 105, 4},     /*  877 */
    {878, 890, "105.218", "107.8.890", 105, 4},     /*  878 */
    {879, 878, "106.219", "106.1.878", 106, 1},     /*  879 */
    {880, 879, "106.220", "106.2.879", 106, 2},     /*  880 */
    {881, 880, "106.221", "106.3.880", 106, 3},     /*  881 */
    {882, 881, "106.222", "106.4.881", 106, 3},     /*  882 */
    {883, 882, "106.223", "106.5.882", 106, 3},     /*  883 */
    {884, 843, "106.224", "100.8.843", 106, 4},     /*  884 */
    {885, 851, "106.225", "101.7.851", 106, 4},     /*  885 */
    {886, 899, "106.226", "108.8.899", 106, 4},     /*  886 */
    {887, 883, "107.227", "107.1.883", 107, 1},     /*  887 */
    {888, 884, "107.228", "107.2.884", 107, 2},     /*  888 */
    {889, 885, "107.229", "107.3.885", 107, 3},     /*  889 */
    {890, 886, "107.230", "107.4.886", 107, 3},     /*  890 */
    {891, 887, "107.231", "107.5.887", 107, 3},     /*  891 */
    {892, 830, "107.232", "99.8.830", 107, 4},      /*  892 */
    {893, 892, "108.233", "108.1.892", 108, 1},     /*  893 */
    {894, 893, "108.234", "108.2.893", 108, 2},     /*  894 */
    {895, 894, "108.235", "108.3.894", 108, 3},     /*  895 */
    {896, 895, "108.236", "108.4.895", 108, 3},     /*  896 */
    {897, 896, "108.237", "108.5.896", 108, 3},     /*  897 */
    {898, 835, "108.238", "99.13.835", 108, 4},     /*  898 */
    {899, 901, "109.239", "109.1.901", 109, 1},     /*  899 */
    {900, 902, "109.240", "109.2.902", 109, 2},     /*  900 */
    {901, 903, "109.241", "109.3.903", 109, 3},     /*  901 */
    {902, 904, "109.242", "109.4.904", 109, 3},     /*  902 */
    {903, 905, "109.243", "109.5.905", 109, 3},     /*  903 */
    {904, 857, "109.244", "102.6.857", 109, 4},     /*  904 */
    {905, 906, "110.245", "110.1.906", 110, 1},     /*  905 */
    {906, 907, "110.246", "110.2.907", 110, 2},     /*  906 */
    {907, 908, "110.247", "110.3.908", 110, 3},     /*  907 */
    {908, 909, "110.248", "110.4.909", 110, 3},     /*  908 */
    {909, 910, "110.249", "110.5.910", 110, 3},     /*  909 */
    {910, 858, "110.250", "102.7.858", 110, 4},     /*  910 */
    {911, 911, "111.251", "111.1.911", 111, 1},     /*  911 */
    {912, 912, "111.252", "111.2.912", 111, 2},     /*  912 */
    {913, 913, "111.253", "111.3.913", 111, 3},     /*  913 */
    {914, 914, "111.254", "111.4.914", 111, 3},     /*  914 */
    {915, 915, "111.255", "111.5.915", 111, 3},     /*  915 */
    {916, 916, "111.256", "111.6.916", 111, 4},     /*  916 */
    {917, 947, "111.257", "115.7.947", 111, 4},     /*  917 */
    {918, 990, "111.258", "121.6.990", 111, 4},     /*  918 */
    {919, 922, "112.259", "112.1.922", 112, 1},     /*  919 */
    {920, 923, "112.260", "112.2.923", 112, 2},     /*  920 */
    {921, 924, "112.261", "112.3.924", 112, 3},     /*  921 */
    {922, 925, "112.262", "112.4.925", 112, 3},     /*  922 */
    {923, 926, "112.263", "112.5.926", 112, 3},     /*  923 */
    {924, 919, "112.264", "111.9.919", 112, 4},     /*  924 */
    {925, 956, "112.265", "116.6.956", 112, 4},     /*  925 */
    {926, 992, "112.266", "121.8.992", 112, 4},     /*  926 */
    {927, 929, "113.267", "113.1.929", 113, 1},     /*  927 */
    {928, 930, "113.268", "113.2.930", 113, 2},     /*  928 */
    {929, 931, "113.269", "113.3.931", 113, 3},     /*  929 */
    {930, 932, "113.270", "113.4.932", 113, 3},     /*  930 */
    {931, 933, "113.271", "113.5.933", 113, 3},     /*  931 */
    {932, 934, "113.272", "113.6.934", 113, 4},     /*  932 */
    {933, 950, "113.273", "115.10.950", 113, 4},    /*  933 */
    {934, 991, "113.274", "121.7.991", 113, 4},     /*  934 */
    {935, 936, "114.275", "114.1.936", 114, 1},     /*  935 */
    {936, 937, "114.276", "114.2.937", 114, 2},     /*  936 */
    {937, 938, "114.277", "114.3.938", 114, 3},     /*  937 */
    {938, 939, "114.278", "114.4.939", 114, 3},     /*  938 */
    {939, 940, "114.279", "114.5.940", 114, 3},     /*  939 */
    {940, 935, "114.280", "113.7.935", 114, 4},     /*  940 */
    {941, 957, "114.281", "116.7.957", 114, 4},     /*  941 */
    {942, 993, "114.282", "121.9.993", 114, 4},     /*  942 */
    {943, 941, "115.283", "115.1.941", 115, 1},     /*  943 */
    {944, 942, "115.284", "115.2.942", 115, 2},     /*  944 */
    {945, 943, "115.285", "115.3.943", 115, 3},     /*  945 */
    {946, 944, "115.286", "115.4.944", 115, 3},     /*  946 */
    {947, 945, "115.287", "115.5.945", 115, 3},     /*  947 */
    {948, 946, "115.288", "115.6.946", 115, 4},     /*  948 */
    {949, 917, "115.289", "111.7.917", 115, 4},     /*  949 */
    {950, 976, "115.290", "119.6.976", 115, 4},     /*  950 */
    {951, 951, "116.291", "116.1.951", 116, 1},     /*  951 */
    {952, 952, "116.292", "116.2.952", 116, 2},     /*  952 */
    {953, 953, "116.293", "116.3.953", 116, 3},     /*  953 */
    {954, 954, "116.294", "116.4.954", 116, 3},     /*  954 */
    {955, 955, "116.295", "116.5.955", 116, 3},     /*  955 */
    {956, 949, "116.296", "115.9.949", 116, 4},     /*  956 */
    {957, 927, "116.297", "112.6.927", 116, 4},     /*  957 */
    {958, 983, "116.298", "120.6.983", 116, 4},     /*  958 */
    {959, 958, "117.299", "117.1.958", 117, 1},     /*  959 */
    {960, 959, "117.300", "117.2.959", 117, 2},     /*  960 */
    {961, 960, "117.301", "117.3.960", 117, 3},     /*  961 */
    {962, 961, "117.302", "117.4.961", 117, 3},     /*  962 */
    {963, 962, "117.303", "117.5.962", 117, 3},     /*  963 */
    {964, 963, "117.304", "117.6.963", 117, 4},     /*  964 */
    {965, 920, "117.305", "111.10.920", 117, 4},    /*  965 */
    {966, 984, "117.306", "120.7.984", 117, 4},     /*  966 */
    {967, 965, "118.307", "118.1.965", 118, 1},     /*  967 */
    {968, 966, "118.308", "118.2.966", 118, 2},     /*  968 */
    {969, 967, "118.309", "118.3.967", 118, 3},     /*  969 */
    {970, 968, "118.310", "118.4.968", 118, 3},     /*  970 */
    {971, 969, "118.311", "118.5.969", 118, 3},     /*  971 */
    {972, 964, "118.312", "117.7.964", 118, 4},     /*  972 */
    {973, 928, "118.313", "112.7.928", 118, 4},     /*  973 */
    {974, 977, "118.314", "119.7.977", 118, 4},     /*  974 */
    {975, 971, "119.315", "119.1.971", 119, 1},     /*  975 */
    {976, 972, "119.316", "119.2.972", 119, 2},     /*  976 */
    {977, 973, "119.317", "119.3.973", 119, 3},     /*  977 */
    {978, 974, "119.318", "119.4.974", 119, 3},     /*  978 */
    {979, 975, "119.319", "119.5.975", 119, 3},     /*  979 */
    {980, 918, "119.320", "111.8.918", 119, 4},     /*  980 */
    {981, 978, "120.321", "120.1.978", 120, 1},     /*  981 */
    {982, 979, "120.322", "120.2.979", 120, 2},     /*  982 */
    {983, 980, "120.323", "120.3.980", 120, 3},     /*  983 */
    {984, 981, "120.324", "120.4.981", 120, 3},     /*  984 */
    {985, 982, "120.325", "120.5.982", 120, 3},     /*  985 */
    {986, 921, "120.326", "111.11.921", 120, 4},    /*  986 */
    {987, 985, "121.327", "121.1.985", 121, 1},     /*  987 */
    {988, 986, "121.328", "121.2.986", 121, 2},     /*  988 */
    {989, 987, "121.329", "121.3.987", 121, 3},     /*  989 */
    {990, 988, "121.330", "121.4.988", 121, 3},     /*  990 */
    {991, 989, "121.331", "121.5.989", 121, 3},     /*  991 */
    {992, 948, "121.332", "115.8.948", 121, 4},     /*  992 */
    {993, 994, "122.333", "122.1.994", 122, 1},     /*  993 */
    {994, 995, "122.334", "122.2.995", 122, 2},     /*  994 */
    {995, 996, "122.335", "122.3.996", 122, 3},     /*  995 */
    {996, 997, "122.336", "122.4.997", 122, 3},     /*  996 */
    {997, 998, "122.337", "122.5.998", 122, 3},     /*  997 */
    {998, 970, "122.338", "118.6.970", 122, 4},     /*  998 */
    {999, 999, "123.339", "123.1.999", 123, 1},     /*  999 */
    {1000, 1000, "123.340", "123.2.1000", 123, 2},  /* 1000 */
    {1001, 1001, "123.341", "123.3.1001", 123, 3},  /* 1001 */
    {1002, 1002, "123.342", "123.4.1002", 123, 3},  /* 1002 */
    {1003, 1003, "123.343", "123.5.1003", 123, 3},  /* 1003 */
    {1004, 1004, "123.344", "123.6.1004", 123, 3},  /* 1004 */
    {1005, 1005, "123.345", "123.7.1005", 123, 3},  /* 1005 */
    {1006, 1006, "123.346", "123.8.1006", 123, 3},  /* 1006 */
    {1007, 1007, "123.347", "123.9.1007", 123, 3},  /* 1007 */
    {1008, 1008, "123.348", "123.10.1008", 123, 4}, /* 1008 */
    {1009, 1009, "123.349", "123.11.1009", 123, 4}, /* 1009 */
    {1010, 1188, "123.350", "139.10.1188", 123, 4}, /* 1010 */
    {1011, 1018, "124.351", "124.1.1018", 124, 1},  /* 1011 */
    {1012, 1019, "124.352", "124.2.1019", 124, 2},  /* 1012 */
    {1013, 1020, "124.353", "124.3.1020", 124, 3},  /* 1013 */
    {1014, 1021, "124.354", "124.4.1021", 124, 3},  /* 1014 */
    {1015, 1022, "124.355", "124.5.1022", 124, 3},  /* 1015 */
    {1016, 1023, "124.356", "124.6.1023", 124, 3},  /* 1016 */
    {1017, 1024, "124.357", "124.7.1024", 124, 3},  /* 1017 */
    {1018, 1025, "124.358", "124.8.1025", 124, 3},  /* 1018 */
    {1019, 1026, "124.359", "124.9.1026", 124, 3},  /* 1019 */
    {1020, 1013, "124.360", "123.15.1013", 124, 4}, /* 1020 */
    {1021, 1027, "124.361", "124.10.1027", 124, 4}, /* 1021 */
    {1022, 1205, "124.362", "140.10.1205", 124, 4}, /* 1022 */
    {1023, 1031, "125.363", "125.1.1031", 125, 1},  /* 1023 */
    {1024, 1032, "125.364", "125.2.1032", 125, 2},  /* 1024 */
    {1025, 1033, "125.365", "125.3.1033", 125, 3},  /* 1025 */
    {1026, 1034, "125.366", "125.4.1034", 125, 3},  /* 1026 */
    {1027, 1035, "125.367", "125.5.1035", 125, 3},  /* 1027 */
    {1028, 1036, "125.368", "125.6.1036", 125, 3},  /* 1028 */
    {1029, 1037, "125.369", "125.7.1037", 125, 3},  /* 1029 */
    {1030, 1038, "125.370", "125.8.1038", 125, 3},  /* 1030 */
    {1031, 1039, "125.371", "125.9.1039", 125, 3},  /* 1031 */
    {1032, 1040, "125.372", "125.10.1040", 125, 4}, /* 1032 */
    {1033, 1016, "125.373", "123.18.1016", 125, 4}, /* 1033 */
    {1034, 1212, "125.374", "140.17.1212", 125, 4}, /* 1034 */
    {1035, 1044, "126.375", "126.1.1044", 126, 1},  /* 1035 */
    {1036, 1045, "126.376", "126.2.1045", 126, 2},  /* 1036 */
    {1037, 1046, "126.377", "126.3.1046", 126, 3},  /* 1037 */
    {1038, 1047, "126.378", "126.4.1047", 126, 3},  /* 1038 */
    {1039, 1048, "126.379", "126.5.1048", 126, 3},  /* 1039 */
    {1040, 1049, "126.380", "126.6.1049", 126, 3},  /* 1040 */
    {1041, 1050, "126.381", "126.7.1050", 126, 3},  /* 1041 */
    {1042, 1051, "126.382", "126.8.1051", 126, 3},  /* 1042 */
    {1043, 1052, "126.383", "126.9.1052", 126, 3},  /* 1043 */
    {1044, 1043, "126.384", "125.13.1043", 126, 4}, /* 1044 */
    {1045, 1030, "126.385", "124.13.1030", 126, 4}, /* 1045 */
    {1046, 1195, "126.386", "139.17.1195", 126, 4}, /* 1046 */
    {1047, 1053, "127.387", "127.1.1053", 127, 1},  /* 1047 */
    {1048, 1054, "127.388", "127.2.1054", 127, 2},  /* 1048 */
    {1049, 1055, "127.389", "127.3.1055", 127, 3},  /* 1049 */
    {1050, 1056, "127.390", "127.4.1056", 127, 3},  /* 1050 */
    {1051, 1057, "127.391", "127.5.1057", 127, 3},  /* 1051 */
    {1052, 1058, "127.392", "127.6.1058", 127, 3},  /* 1052 */
    {1053, 1059, "127.393", "127.7.1059", 127, 3},  /* 1053 */
    {1054, 1060, "127.394", "127.8.1060", 127, 3},  /* 1054 */
    {1055, 1061, "127.395", "127.9.1061", 127, 3},  /* 1055 */
    {1056, 1062, "127.396", "127.10.1062", 127, 4}, /* 1056 */
    {1057, 1015, "127.397", "123.17.1015", 127, 4}, /* 1057 */
    {1058, 1210, "127.398", "140.15.1210", 127, 4}, /* 1058 */
    {1059, 1066, "128.399", "128.1.1066", 128, 1},  /* 1059 */
    {1060, 1067, "128.400", "128.2.1067", 128, 2},  /* 1060 */
    {1061, 1068, "128.401", "128.3.1068", 128, 3},  /* 1061 */
    {1062, 1069, "128.402", "128.4.1069", 128, 3},  /* 1062 */
    {1063, 1070, "128.403", "128.5.1070", 128, 3},  /* 1063 */
    {1064, 1071, "128.404", "128.6.1071", 128, 3},  /* 1064 */
    {1065, 1072, "128.405", "128.7.1072", 128, 3},  /* 1065 */
    {1066, 1073, "128.406", "128.8.1073", 128, 3},  /* 1066 */
    {1067, 1074, "128.407", "128.9.1074", 128, 3},  /* 1067 */
    {1068, 1065, "128.408", "127.13.1065", 128, 4}, /* 1068 */
    {1069, 1029, "128.409", "124.12.1029", 128, 4}, /* 1069 */
    {1070, 1193, "128.410", "139.15.1193", 128, 4}, /* 1070 */
    {1071, 1075, "129.411", "129.1.1075", 129, 1},  /* 1071 */
    {1072, 1076, "129.412", "129.2.1076", 129, 2},  /* 1072 */
    {1073, 1077, "129.413", "129.3.1077", 129, 3},  /* 1073 */
    {1074, 1078, "129.414", "129.4.1078", 129, 3},  /* 1074 */
    {1075, 1079, "129.415", "129.5.1079", 129, 3},  /* 1075 */
    {1076, 1080, "129.416", "129.6.1080", 129, 3},  /* 1076 */
    {1077, 1081, "129.417", "129.7.1081", 129, 3},  /* 1077 */
    {1078, 1082, "129.418", "129.8.1082", 129, 3},  /* 1078 */
    {1079, 1083, "129.419", "129.9.1083", 129, 3},  /* 1079 */
    {1080, 1084, "129.420", "129.10.1084", 129, 4}, /* 1080 */
    {1081, 1014, "129.421", "123.16.1014", 129, 4}, /* 1081 */
    {1082, 1189, "129.422", "139.11.1189", 129, 4}, /* 1082 */
    {1083, 1088, "130.423", "130.1.1088", 130, 1},  /* 1083 */
    {1084, 1089, "130.424", "130.2.1089", 130, 2},  /* 1084 */
    {1085, 1090, "130.425", "130.3.1090", 130, 3},  /* 1085 */
    {1086, 1091, "130.426", "130.4.1091", 130, 3},  /* 1086 */
    {1087, 1092, "130.427", "130.5.1092", 130, 3},  /* 1087 */
    {1088, 1093, "130.428", "130.6.1093", 130, 3},  /* 1088 */
    {1089, 1094, "130.429", "130.7.1094", 130, 3},  /* 1089 */
    {1090, 1095, "130.430", "130.8.1095", 130, 3},  /* 1090 */
    {1091, 1096, "130.431", "130.9.1096", 130, 3},  /* 1091 */
    {1092, 1087, "130.432", "129.13.1087", 130, 4}, /* 1092 */
    {1093, 1028, "130.433", "124.11.1028", 130, 4}, /* 1093 */
    {1094, 1206, "130.434", "140.11.1206", 130, 4}, /* 1094 */
    {1095, 1097, "131.435", "131.1.1097", 131, 1},  /* 1095 */
    {1096, 1098, "131.436", "131.2.1098", 131, 2},  /* 1096 */
    {1097, 1099, "131.437", "131.3.1099", 131, 3},  /* 1097 */
    {1098, 1100, "131.438", "131.4.1100", 131, 3},  /* 1098 */
    {1099, 1101, "131.439", "131.5.1101", 131, 3},  /* 1099 */
    {1100, 1102, "131.440", "131.6.1102", 131, 3},  /* 1100 */
    {1101, 1103, "131.441", "131.7.1103", 131, 3},  /* 1101 */
    {1102, 1104, "131.442", "131.8.1104", 131, 3},  /* 1102 */
    {1103, 1105, "131.443", "131.9.1105", 131, 3},  /* 1103 */
    {1104, 1012, "131.444", "123.14.1012", 131, 4}, /* 1104 */
    {1105, 1119, "131.445", "132.10.1119", 131, 4}, /* 1105 */
    {1106, 1191, "131.446", "139.13.1191", 131, 4}, /* 1106 */
    {1107, 1110, "132.447", "132.1.1110", 132, 1},  /* 1107 */
    {1108, 1111, "132.448", "132.2.1111", 132, 2},  /* 1108 */
    {1109, 1112, "132.449", "132.3.1112", 132, 3},  /* 1109 */
    {1110, 1113, "132.450", "132.4.1113", 132, 3},  /* 1110 */
    {1111, 1114, "132.451", "132.5.1114", 132, 3},  /* 1111 */
    {1112, 1115, "132.452", "132.6.1115", 132, 3},  /* 1112 */
    {1113, 1116, "132.453", "132.7.1116", 132, 3},  /* 1113 */
    {1114, 1117, "132.454", "132.8.1117", 132, 3},  /* 1114 */
    {1115, 1118, "132.455", "132.9.1118", 132, 3},  /* 1115 */
    {1116, 1011, "132.456", "123.13.1011", 132, 4}, /* 1116 */
    {1117, 1106, "132.457", "131.10.1106", 132, 4}, /* 1117 */
    {1118, 1208, "132.458", "140.13.1208", 132, 4}, /* 1118 */
    {1119, 1123, "133.459", "133.1.1123", 133, 1},  /* 1119 */
    {1120, 1124, "133.460", "133.2.1124", 133, 2},  /* 1120 */
    {1121, 1125, "133.461", "133.3.1125", 133, 3},  /* 1121 */
    {1122, 1126, "133.462", "133.4.1126", 133, 3},  /* 1122 */
    {1123, 1127, "133.463", "133.5.1127", 133, 3},  /* 1123 */
    {1124, 1128, "133.464", "133.6.1128", 133, 3},  /* 1124 */
    {1125, 1129, "133.465", "133.7.1129", 133, 3},  /* 1125 */
    {1126, 1130, "133.466", "133.8.1130", 133, 3},  /* 1126 */
    {1127, 1131, "133.467", "133.9.1131", 133, 3},  /* 1127 */
    {1128, 1042, "133.468", "125.12.1042", 133, 4}, /* 1128 */
    {1129, 1122, "133.469", "132.13.1122", 133, 4}, /* 1129 */
    {1130, 1209, "133.470", "140.14.1209", 133, 4}, /* 1130 */
    {1131, 1132, "134.471", "134.1.1132", 134, 1},  /* 1131 */
    {1132, 1133, "134.472", "134.2.1133", 134, 2},  /* 1132 */
    {1133, 1134, "134.473", "134.3.1134", 134, 3},  /* 1133 */
    {1134, 1135, "134.474", "134.4.1135", 134, 3},  /* 1134 */
    {1135, 1136, "134.475", "134.5.1136", 134, 3},  /* 1135 */
    {1136, 1137, "134.476", "134.6.1137", 134, 3},  /* 1136 */
    {1137, 1138, "134.477", "134.7.1138", 134, 3},  /* 1137 */
    {1138, 1139, "134.478", "134.8.1139", 134, 3},  /* 1138 */
    {1139, 1140, "134.479", "134.9.1140", 134, 3},  /* 1139 */
    {1140, 1041, "134.480", "125.11.1041", 134, 4}, /* 1140 */
    {1141, 1109, "134.481", "131.13.1109", 134, 4}, /* 1141 */
    {1142, 1192, "134.482", "139.14.1192", 134, 4}, /* 1142 */
    {1143, 1143, "135.483", "135.1.1143", 135, 1},  /* 1143 */
    {1144, 1144, "135.484", "135.2.1144", 135, 2},  /* 1144 */
    {1145, 1145, "135.485", "135.3.1145", 135, 3},  /* 1145 */
    {1146, 1146, "135.486", "135.4.1146", 135, 3},  /* 1146 */
    {1147, 1147, "135.487", "135.5.1147", 135, 3},  /* 1147 */
    {1148, 1148, "135.488", "135.6.1148", 135, 3},  /* 1148 */
    {1149, 1149, "135.489", "135.7.1149", 135, 3},  /* 1149 */
    {1150, 1150, "135.490", "135.8.1150", 135, 3},  /* 1150 */
    {1151, 1151, "135.491", "135.9.1151", 135, 3},  /* 1151 */
    {1152, 1064, "135.492", "127.12.1064", 135, 4}, /* 1152 */
    {1153, 1121, "135.493", "132.12.1121", 135, 4}, /* 1153 */
    {1154, 1207, "135.494", "140.12.1207", 135, 4}, /* 1154 */
    {1155, 1152, "136.495", "136.1.1152", 136, 1},  /* 1155 */
    {1156, 1153, "136.496", "136.2.1153", 136, 2},  /* 1156 */
    {1157, 1154, "136.497", "136.3.1154", 136, 3},  /* 1157 */
    {1158, 1155, "136.498", "136.4.1155", 136, 3},  /* 1158 */
    {1159, 1156, "136.499", "136.5.1156", 136, 3},  /* 1159 */
    {1160, 1157, "136.500", "136.6.1157", 136, 3},  /* 1160 */
    {1161, 1158, "136.501", "136.7.1158", 136, 3},  /* 1161 */
    {1162, 1159, "136.502", "136.8.1159", 136, 3},  /* 1162 */
    {1163, 1160, "136.503", "136.9.1160", 136, 3},  /* 1163 */
    {1164, 1063, "136.504", "127.11.1063", 136, 4}, /* 1164 */
    {1165, 1108, "136.505", "131.12.1108", 136, 4}, /* 1165 */
    {1166, 1190, "136.506", "139.12.1190", 136, 4}, /* 1166 */
    {1167, 1161, "137.507", "137.1.1161", 137, 1},  /* 1167 */
    {1168, 1162, "137.508", "137.2.1162", 137, 2},  /* 1168 */
    {1169, 1163, "137.509", "137.3.1163", 137, 3},  /* 1169 */
    {1170, 1164, "137.510", "137.4.1164", 137, 3},  /* 1170 */
    {1171, 1165, "137.511", "137.5.1165", 137, 3},  /* 1171 */
    {1172, 1166, "137.512", "137.6.1166", 137, 3},  /* 1172 */
    {1173, 1167, "137.513", "137.7.1167", 137, 3},  /* 1173 */
    {1174, 1168, "137.514", "137.8.1168", 137, 3},  /* 1174 */
    {1175, 1169, "137.515", "137.9.1169", 137, 3},  /* 1175 */
    {1176, 1086, "137.516", "129.12.1086", 137, 4}, /* 1176 */
    {1177, 1120, "137.517", "132.11.1120", 137, 4}, /* 1177 */
    {1178, 1194, "137.518", "139.16.1194", 137, 4}, /* 1178 */
    {1179, 1170, "138.519", "138.1.1170", 138, 1},  /* 1179 */
    {1180, 1171, "138.520", "138.2.1171", 138, 2},  /* 1180 */
    {1181, 1172, "138.521", "138.3.1172", 138, 3},  /* 1181 */
    {1182, 1173, "138.522", "138.4.1173", 138, 3},  /* 1182 */
    {1183, 1174, "138.523", "138.5.1174", 138, 3},  /* 1183 */
    {1184, 1175, "138.524", "138.6.1175", 138, 3},  /* 1184 */
    {1185, 1176, "138.525", "138.7.1176", 138, 3},  /* 1185 */
    {1186, 1177, "138.526", "138.8.1177", 138, 3},  /* 1186 */
    {1187, 1178, "138.527", "138.9.1178", 138, 3},  /* 1187 */
    {1188, 1085, "138.528", "129.11.1085", 138, 4}, /* 1188 */
    {1189, 1107, "138.529", "131.11.1107", 138, 4}, /* 1189 */
    {1190, 1211, "138.530", "140.16.1211", 138, 4}, /* 1190 */
    {1191, 1179, "139.531", "139.1.1179", 139, 1},  /* 1191 */
    {1192, 1180, "139.532", "139.2.1180", 139, 2},  /* 1192 */
    {1193, 1181, "139.533", "139.3.1181", 139, 3},  /* 1193 */
    {1194, 1182, "139.534", "139.4.1182", 139, 3},  /* 1194 */
    {1195, 1183, "139.535", "139.5.1183", 139, 3},  /* 1195 */
    {1196, 1184, "139.536", "139.6.1184", 139, 3},  /* 1196 */
    {1197, 1185, "139.537", "139.7.1185", 139, 3},  /* 1197 */
    {1198, 1186, "139.538", "139.8.1186", 139, 3},  /* 1198 */
    {1199, 1187, "139.539", "139.9.1187", 139, 3},  /* 1199 */
    {1200, 1010, "139.540", "123.12.1010", 139, 4}, /* 1200 */
    {1201, 1196, "140.541", "140.1.1196", 140, 1},  /* 1201 */
    {1202, 1197, "140.542", "140.2.1197", 140, 2},  /* 1202 */
    {1203, 1198, "140.543", "140.3.1198", 140, 3},  /* 1203 */
    {1204, 1199, "140.544", "140.4.1199", 140, 3},  /* 1204 */
    {1205, 1200, "140.545", "140.5.1200", 140, 3},  /* 1205 */
    {1206, 1201, "140.546", "140.6.1201", 140, 3},  /* 1206 */
    {1207, 1202, "140.547", "140.7.1202", 140, 3},  /* 1207 */
    {1208, 1203, "140.548", "140.8.1203", 140, 3},  /* 1208 */
    {1209, 1204, "140.549", "140.9.1204", 140, 3},  /* 1209 */
    {1210, 1017, "140.550", "123.19.1017", 140, 4}, /* 1210 */
    {1211, 1213, "141.551", "141.1.1213", 141, 1},  /* 1211 */
    {1212, 1214, "141.552", "141.2.1214", 141, 2},  /* 1212 */
    {1213, 1215, "141.553", "141.3.1215", 141, 3},  /* 1213 */
    {1214, 1216, "141.554", "141.4.1216", 141, 3},  /* 1214 */
    {1215, 1217, "141.555", "141.5.1217", 141, 3},  /* 1215 */
    {1216, 1218, "141.556", "141.6.1218", 141, 3},  /* 1216 */
    {1217, 1219, "141.557", "141.7.1219", 141, 3},  /* 1217 */
    {1218, 1220, "141.558", "141.8.1220", 141, 3},  /* 1218 */
    {1219, 1221, "141.559", "141.9.1221", 141, 3},  /* 1219 */
    {1220, 1141, "141.560", "134.10.1141", 141, 4}, /* 1220 */
    {1221, 1222, "142.561", "142.1.1222", 142, 1},  /* 1221 */
    {1222, 1223, "142.562", "142.2.1223", 142, 2},  /* 1222 */
    {1223, 1224, "142.563", "142.3.1224", 142, 3},  /* 1223 */
    {1224, 1225, "142.564", "142.4.1225", 142, 3},  /* 1224 */
    {1225, 1226, "142.565", "142.5.1226", 142, 3},  /* 1225 */
    {1226, 1227, "142.566", "142.6.1227", 142, 3},  /* 1226 */
    {1227, 1228, "142.567", "142.7.1228", 142, 3},  /* 1227 */
    {1228, 1229, "142.568", "142.8.1229", 142, 3},  /* 1228 */
    {1229, 1230, "142.569", "142.9.1230", 142, 3},  /* 1229 */
    {1230, 1142, "142.570", "134.11.1142", 142, 4}, /* 1230 */
    {1231, 1231, "143.1", "143.1.1231", 143, 1},    /* 1231 */
    {1232, 1232, "143.2", "143.2.1232", 143, 2},    /* 1232 */
    {1233, 1233, "143.3", "143.3.1233", 143, 4},    /* 1233 */
    {1234, 1234, "144.4", "144.1.1234", 144, 1},    /* 1234 */
    {1235, 1235, "144.5", "144.2.1235", 144, 2},    /* 1235 */
    {1236, 1239, "144.6", "145.3.1239", 144, 4},    /* 1236 */
    {1237, 1237, "145.7", "145.1.1237", 145, 1},    /* 1237 */
    {1238, 1238, "145.8", "145.2.1238", 145, 2},    /* 1238 */
    {1239, 1236, "145.9", "144.3.1236", 145, 4},    /* 1239 */
    {1240, 1240, "146.10", "146.1.1240", 146, 1},   /* 1240 */
    {1241, 1241, "146.11", "146.2.1241", 146, 2},   /* 1241 */
    {1242, 1242, "146.12", "146.3.1242", 146, 4},   /* 1242 */
    {1243, 1243, "147.13", "147.1.1243", 147, 1},   /* 1243 */
    {1244, 1244, "147.14", "147.2.1244", 147, 2},   /* 1244 */
    {1245, 1245, "147.15", "147.3.1245", 147, 3},   /* 1245 */
    {1246, 1246, "147.16", "147.4.1246", 147, 4},   /* 1246 */
    {1247, 1247, "148.17", "148.1.1247", 148, 1},   /* 1247 */
    {1248, 1248, "148.18", "148.2.1248", 148, 2},   /* 1248 */
    {1249, 1249, "148.19", "148.3.1249", 148, 3},   /* 1249 */
    {1250, 1250, "148.20", "148.4.1250", 148, 4},   /* 1250 */
    {1251, 1251, "149.21", "149.1.1251", 149, 1},   /* 1251 */
    {1252, 1252, "149.22", "149.2.1252", 149, 2},   /* 1252 */
    {1253, 1253, "149.23", "149.3.1253", 149, 3},   /* 1253 */
    {1254, 1254, "149.24", "149.4.1254", 149, 4},   /* 1254 */
    {1255, 1255, "150.25", "150.1.1255", 150, 1},   /* 1255 */
    {1256, 1256, "150.26", "150.2.1256", 150, 2},   /* 1256 */
    {1257, 1257, "150.27", "150.3.1257", 150, 3},   /* 1257 */
    {1258, 1258, "150.28", "150.4.1258", 150, 4},   /* 1258 */
    {1259, 1259, "151.29", "151.1.1259", 151, 1},   /* 1259 */
    {1260, 1260, "151.30", "151.2.1260", 151, 2},   /* 1260 */
    {1261, 1261, "151.31", "151.3.1261", 151, 3},   /* 1261 */
    {1262, 1270, "151.32", "153.4.1270", 151, 4},   /* 1262 */
    {1263, 1263, "152.33", "152.1.1263", 152, 1},   /* 1263 */
    {1264, 1264, "152.34", "152.2.1264", 152, 2},   /* 1264 */
    {1265, 1265, "152.35", "152.3.1265", 152, 3},   /* 1265 */
    {1266, 1274, "152.36", "154.4.1274", 152, 4},   /* 1266 */
    {1267, 1267, "153.37", "153.1.1267", 153, 1},   /* 1267 */
    {1268, 1268, "153.38", "153.2.1268", 153, 2},   /* 1268 */
    {1269, 1269, "153.39", "153.3.1269", 153, 3},   /* 1269 */
    {1270, 1262, "153.40", "151.4.1262", 153, 4},   /* 1270 */
    {1271, 1271, "154.41", "154.1.1271", 154, 1},   /* 1271 */
    {1272, 1272, "154.42", "154.2.1272", 154, 2},   /* 1272 */
    {1273, 1273, "154.43", "154.3.1273", 154, 3},   /* 1273 */
    {1274, 1266, "154.44", "152.4.1266", 154, 4},   /* 1274 */
    {1275, 1275, "155.45", "155.1.1275", 155, 1},   /* 1275 */
    {1276, 1276, "155.46", "155.2.1276", 155, 2},   /* 1276 */
    {1277, 1277, "155.47", "155.3.1277", 155, 3},   /* 1277 */
    {1278, 1278, "155.48", "155.4.1278", 155, 4},   /* 1278 */
    {1279, 1279, "156.49", "156.1.1279", 156, 1},   /* 1279 */
    {1280, 1280, "156.50", "156.2.1280", 156, 2},   /* 1280 */
    {1281, 1281, "156.51", "156.3.1281", 156, 3},   /* 1281 */
    {1282, 1282, "156.52", "156.4.1282", 156, 4},   /* 1282 */
    {1283, 1284, "157.53", "157.1.1284", 157, 1},   /* 1283 */
    {1284, 1285, "157.54", "157.2.1285", 157, 2},   /* 1284 */
    {1285, 1286, "157.55", "157.3.1286", 157, 3},   /* 1285 */
    {1286, 1287, "157.56", "157.4.1287", 157, 4},   /* 1286 */
    {1287, 1289, "158.57", "158.1.1289", 158, 1},   /* 1287 */
    {1288, 1290, "158.58", "158.2.1290", 158, 2},   /* 1288 */
    {1289, 1291, "158.59", "158.3.1291", 158, 3},   /* 1289 */
    {1290, 1283, "158.60", "156.5.1283", 158, 4},   /* 1290 */
    {1291, 1292, "159.61", "159.1.1292", 159, 1},   /* 1291 */
    {1292, 1293, "159.62", "159.2.1293", 159, 2},   /* 1292 */
    {1293, 1294, "159.63", "159.3.1294", 159, 3},   /* 1293 */
    {1294, 1288, "159.64", "157.5.1288", 159, 4},   /* 1294 */
    {1295, 1295, "160.65", "160.1.1295", 160, 1},   /* 1295 */
    {1296, 1296, "160.66", "160.2.1296", 160, 2},   /* 1296 */
    {1297, 1297, "160.67", "160.3.1297", 160, 3},   /* 1297 */
    {1298, 1298, "160.68", "160.4.1298", 160, 4},   /* 1298 */
    {1299, 1300, "161.69", "161.1.1300", 161, 1},   /* 1299 */
    {1300, 1301, "161.70", "161.2.1301", 161, 2},   /* 1300 */
    {1301, 1302, "161.71", "161.3.1302", 161, 3},   /* 1301 */
    {1302, 1299, "161.72", "160.5.1299", 161, 4},   /* 1302 */
    {1303, 1303, "162.73", "162.1.1303", 162, 1},   /* 1303 */
    {1304, 1304, "162.74", "162.2.1304", 162, 2},   /* 1304 */
    {1305, 1305, "162.75", "162.3.1305", 162, 3},   /* 1305 */
    {1306, 1306, "162.76", "162.4.1306", 162, 3},   /* 1306 */
    {1307, 1307, "162.77", "162.5.1307", 162, 3},   /* 1307 */
    {1308, 1308, "162.78", "162.6.1308", 162, 4},   /* 1308 */
    {1309, 1310, "163.79", "163.1.1310", 163, 1},   /* 1309 */
    {1310, 1311, "163.80", "163.2.1311", 163, 2},   /* 1310 */
    {1311, 1312, "163.81", "163.3.1312", 163, 3},   /* 1311 */
    {1312, 1313, "163.82", "163.4.1313", 163, 3},   /* 1312 */
    {1313, 1314, "163.83", "163.5.1314", 163, 3},   /* 1313 */
    {1314, 1309, "163.84", "162.7.1309", 163, 4},   /* 1314 */
    {1315, 1315, "164.85", "164.1.1315", 164, 1},   /* 1315 */
    {1316, 1316, "164.86", "164.2.1316", 164, 2},   /* 1316 */
    {1317, 1317, "164.87", "164.3.1317", 164, 3},   /* 1317 */
    {1318, 1318, "164.88", "164.4.1318", 164, 3},   /* 1318 */
    {1319, 1319, "164.89", "164.5.1319", 164, 3},   /* 1319 */
    {1320, 1320, "164.90", "164.6.1320", 164, 4},   /* 1320 */
    {1321, 1322, "165.91", "165.1.1322", 165, 1},   /* 1321 */
    {1322, 1323, "165.92", "165.2.1323", 165, 2},   /* 1322 */
    {1323, 1324, "165.93", "165.3.1324", 165, 3},   /* 1323 */
    {1324, 1325, "165.94", "165.4.1325", 165, 3},   /* 1324 */
    {1325, 1326, "165.95", "165.5.1326", 165, 3},   /* 1325 */
    {1326, 1321, "165.96", "164.7.1321", 165, 4},   /* 1326 */
    {1327, 1327, "166.97", "166.1.1327", 166, 1},   /* 1327 */
    {1328, 1328, "166.98", "166.2.1328", 166, 2},   /* 1328 */
    {1329, 1329, "166.99", "166.3.1329", 166, 3},   /* 1329 */
    {1330, 1330, "166.100", "166.4.1330", 166, 3},  /* 1330 */
    {1331, 1331, "166.101", "166.5.1331", 166, 3},  /* 1331 */
    {1332, 1332, "166.102", "166.6.1332", 166, 4},  /* 1332 */
    {1333, 1334, "167.103", "167.1.1334", 167, 1},  /* 1333 */
    {1334, 1335, "167.104", "167.2.1335", 167, 2},  /* 1334 */
    {1335, 1336, "167.105", "167.3.1336", 167, 3},  /* 1335 */
    {1336, 1337, "167.106", "167.4.1337", 167, 3},  /* 1336 */
    {1337, 1338, "167.107", "167.5.1338", 167, 3},  /* 1337 */
    {1338, 1333, "167.108", "166.7.1333", 167, 4},  /* 1338 */
    {1339, 1339, "168.109", "168.1.1339", 168, 1},  /* 1339 */
    {1340, 1340, "168.110", "168.2.1340", 168, 2},  /* 1340 */
    {1341, 1341, "168.111", "168.3.1341", 168, 3},  /* 1341 */
    {1342, 1342, "168.112", "168.4.1342", 168, 4},  /* 1342 */
    {1343, 1344, "169.113", "169.1.1344", 169, 1},  /* 1343 */
    {1344, 1345, "169.114", "169.2.1345", 169, 2},  /* 1344 */
    {1345, 1346, "169.115", "169.3.1346", 169, 3},  /* 1345 */
    {1346, 1353, "169.116", "171.4.1353", 169, 4},  /* 1346 */
    {1347, 1347, "170.117", "170.1.1347", 170, 1},  /* 1347 */
    {1348, 1348, "170.118", "170.2.1348", 170, 2},  /* 1348 */
    {1349, 1349, "170.119", "170.3.1349", 170, 3},  /* 1349 */
    {1350, 1359, "170.120", "172.5.1359", 170, 4},  /* 1350 */
    {1351, 1350, "171.121", "171.1.1350", 171, 1},  /* 1351 */
    {1352, 1351, "171.122", "171.2.1351", 171, 2},  /* 1352 */
    {1353, 1352, "171.123", "171.3.1352", 171, 3},  /* 1353 */
    {1354, 1358, "171.124", "172.4.1358", 171, 4},  /* 1354 */
    {1355, 1355, "172.125", "172.1.1355", 172, 1},  /* 1355 */
    {1356, 1356, "172.126", "172.2.1356", 172, 2},  /* 1356 */
    {1357, 1357, "172.127", "172.3.1357", 172, 3},  /* 1357 */
    {1358, 1354, "172.128", "171.5.1354", 172, 4},  /* 1358 */
    {1359, 1360, "173.129", "173.1.1360", 173, 1},  /* 1359 */
    {1360, 1361, "173.130", "173.2.1361", 173, 2},  /* 1360 */
    {1361, 1362, "173.131", "173.3.1362", 173, 3},  /* 1361 */
    {1362, 1343, "173.132", "168.5.1343", 173, 4},  /* 1362 */
    {1363, 1363, "174.133", "174.1.1363", 174, 1},  /* 1363 */
    {1364, 1364, "174.134", "174.2.1364", 174, 2},  /* 1364 */
    {1365, 1365, "174.135", "174.3.1365", 174, 3},  /* 1365 */
    {1366, 1366, "174.136", "174.4.1366", 174, 4},  /* 1366 */
    {1367, 1367, "175.137", "175.1.1367", 175, 1},  /* 1367 */
    {1368, 1368, "175.138", "175.2.1368", 175, 2},  /* 1368 */
    {1369, 1369, "175.139", "175.3.1369", 175, 3},  /* 1369 */
    {1370, 1370, "175.140", "175.4.1370", 175, 3},  /* 1370 */
    {1371, 1371, "175.141", "175.5.1371", 175, 3},  /* 1371 */
    {1372, 1372, "175.142", "175.6.1372", 175, 4},  /* 1372 */
    {1373, 1374, "176.143", "176.1.1374", 176, 1},  /* 1373 */
    {1374, 1375, "176.144", "176.2.1375", 176, 2},  /* 1374 */
    {1375, 1376, "176.145", "176.3.1376", 176, 3},  /* 1375 */
    {1376, 1377, "176.146", "176.4.1377", 176, 3},  /* 1376 */
    {1377, 1378, "176.147", "176.5.1378", 176, 3},  /* 1377 */
    {1378, 1373, "176.148", "175.7.1373", 176, 4},  /* 1378 */
    {1379, 1379, "177.149", "177.1.1379", 177, 1},  /* 1379 */
    {1380, 1380, "177.150", "177.2.1380", 177, 2},  /* 1380 */
    {1381, 1381, "177.151", "177.3.1381", 177, 3},  /* 1381 */
    {1382, 1382, "177.152", "177.4.1382", 177, 3},  /* 1382 */
    {1383, 1383, "177.153", "177.5.1383", 177, 3},  /* 1383 */
    {1384, 1384, "177.154", "177.6.1384", 177, 4},  /* 1384 */
    {1385, 1386, "178.155", "178.1.1386", 178, 1},  /* 1385 */
    {1386, 1387, "178.156", "178.2.1387", 178, 2},  /* 1386 */
    {1387, 1388, "178.157", "178.3.1388", 178, 3},  /* 1387 */
    {1388, 1389, "178.158", "178.4.1389", 178, 3},  /* 1388 */
    {1389, 1390, "178.159", "178.5.1390", 178, 3},  /* 1389 */
    {1390, 1401, "178.160", "180.6.1401", 178, 4},  /* 1390 */
    {1391, 1391, "179.161", "179.1.1391", 179, 1},  /* 1391 */
    {1392, 1392, "179.162", "179.2.1392", 179, 2},  /* 1392 */
    {1393, 1393, "179.163", "179.3.1393", 179, 3},  /* 1393 */
    {1394, 1394, "179.164", "179.4.1394", 179, 3},  /* 1394 */
    {1395, 1395, "179.165", "179.5.1395", 179, 3},  /* 1395 */
    {1396, 1409, "179.166", "181.7.1409", 179, 4},  /* 1396 */
    {1397, 1396, "180.167", "180.1.1396", 180, 1},  /* 1397 */
    {1398, 1397, "180.168", "180.2.1397", 180, 2},  /* 1398 */
    {1399, 1398, "180.169", "180.3.1398", 180, 3},  /* 1399 */
    {1400, 1399, "180.170", "180.4.1399", 180, 3},  /* 1400 */
    {1401, 1400, "180.171", "180.5.1400", 180, 3},  /* 1401 */
    {1402, 1408, "180.172", "181.6.1408", 180, 4},  /* 1402 */
    {1403, 1403, "181.173", "181.1.1403", 181, 1},  /* 1403 */
    {1404, 1404, "181.174", "181.2.1404", 181, 2},  /* 1404 */
    {1405, 1405, "181.175", "181.3.1405", 181, 3},  /* 1405 */
    {1406, 1406, "181.176", "181.4.1406", 181, 3},  /* 1406 */
    {1407, 1407, "181.177", "181.5.1407", 181, 3},  /* 1407 */
    {1408, 1402, "181.178", "180.7.1402", 181, 4},  /* 1408 */
    {1409, 1410, "182.179", "182.1.1410", 182, 1},  /* 1409 */
    {1410, 1411, "182.180", "182.2.1411", 182, 2},  /* 1410 */
    {1411, 1412, "182.181", "182.3.1412", 182, 3},  /* 1411 */
    {1412, 1413, "182.182", "182.4.1413", 182, 3},  /* 1412 */
    {1413, 1414, "182.183", "182.5.1414", 182, 3},  /* 1413 */
    {1414, 1385, "182.184", "177.7.1385", 182, 4},  /* 1414 */
    {1415, 1415, "183.185", "183.1.1415", 183, 1},  /* 1415 */
    {1416, 1416, "183.186", "183.2.1416", 183, 2},  /* 1416 */
    {1417, 1417, "183.187", "183.3.1417", 183, 3},  /* 1417 */
    {1418, 1418, "183.188", "183.4.1418", 183, 3},  /* 1418 */
    {1419, 1419, "183.189", "183.5.1419", 183, 3},  /* 1419 */
    {1420, 1420, "183.190", "183.6.1420", 183, 4},  /* 1420 */
    {1421, 1424, "184.191", "184.1.1424", 184, 1},  /* 1421 */
    {1422, 1425, "184.192", "184.2.1425", 184, 2},  /* 1422 */
    {1423, 1426, "184.193", "184.3.1426", 184, 3},  /* 1423 */
    {1424, 1427, "184.194", "184.4.1427", 184, 3},  /* 1424 */
    {1425, 1428, "184.195", "184.5.1428", 184, 3},  /* 1425 */
    {1426, 1423, "184.196", "183.9.1423", 184, 4},  /* 1426 */
    {1427, 1429, "185.197", "185.1.1429", 185, 1},  /* 1427 */
    {1428, 1430, "185.198", "185.2.1430", 185, 2},  /* 1428 */
    {1429, 1431, "185.199", "185.3.1431", 185, 3},  /* 1429 */
    {1430, 1432, "185.200", "185.4.1432", 185, 3},  /* 1430 */
    {1431, 1433, "185.201", "185.5.1433", 185, 3},  /* 1431 */
    {1432, 1421, "185.202", "183.7.1421", 185, 4},  /* 1432 */
    {1433, 1434, "186.203", "186.1.1434", 186, 1},  /* 1433 */
    {1434, 1435, "186.204", "186.2.1435", 186, 2},  /* 1434 */
    {1435, 1436, "186.205", "186.3.1436", 186, 3},  /* 1435 */
    {1436, 1437, "186.206", "186.4.1437", 186, 3},  /* 1436 */
    {1437, 1438, "186.207", "186.5.1438", 186, 3},  /* 1437 */
    {1438, 1422, "186.208", "183.8.1422", 186, 4},  /* 1438 */
    {1439, 1439, "187.209", "187.1.1439", 187, 1},  /* 1439 */
    {1440, 1440, "187.210", "187.2.1440", 187, 2},  /* 1440 */
    {1441, 1441, "187.211", "187.3.1441", 187, 3},  /* 1441 */
    {1442, 1442, "187.212", "187.4.1442", 187, 3},  /* 1442 */
    {1443, 1443, "187.213", "187.5.1443", 187, 3},  /* 1443 */
    {1444, 1444, "187.214", "187.6.1444", 187, 4},  /* 1444 */
    {1445, 1446, "188.215", "188.1.1446", 188, 1},  /* 1445 */
    {1446, 1447, "188.216", "188.2.1447", 188, 2},  /* 1446 */
    {1447, 1448, "188.217", "188.3.1448", 188, 3},  /* 1447 */
    {1448, 1449, "188.218", "188.4.1449", 188, 3},  /* 1448 */
    {1449, 1450, "188.219", "188.5.1450", 188, 3},  /* 1449 */
    {1450, 1445, "188.220", "187.7.1445", 188, 4},  /* 1450 */
    {1451, 1451, "189.221", "189.1.1451", 189, 1},  /* 1451 */
    {1452, 1452, "189.222", "189.2.1452", 189, 2},  /* 1452 */
    {1453, 1453, "189.223", "189.3.1453", 189, 3},  /* 1453 */
    {1454, 1454, "189.224", "189.4.1454", 189, 3},  /* 1454 */
    {1455, 1455, "189.225", "189.5.1455", 189, 3},  /* 1455 */
    {1456, 1456, "189.226", "189.6.1456", 189, 4},  /* 1456 */
    {1457, 1458, "190.227", "190.1.1458", 190, 1},  /* 1457 */
    {1458, 1459, "190.228", "190.2.1459", 190, 2},  /* 1458 */
    {1459, 1460, "190.229", "190.3.1460", 190, 3},  /* 1459 */
    {1460, 1461, "190.230", "190.4.1461", 190, 3},  /* 1460 */
    {1461, 1462, "190.231", "190.5.1462", 190, 3},  /* 1461 */
    {1462, 1457, "190.232", "189.7.1457", 190, 4},  /* 1462 */
    {1463, 1463, "191.233", "191.1.1463", 191, 1},  /* 1463 */
    {1464, 1464, "191.234", "191.2.1464", 191, 2},  /* 1464 */
    {1465, 1465, "191.235", "191.3.1465", 191, 3},  /* 1465 */
    {1466, 1466, "191.236", "191.4.1466", 191, 3},  /* 1466 */
    {1467, 1467, "191.237", "191.5.1467", 191, 3},  /* 1467 */
    {1468, 1468, "191.238", "191.6.1468", 191, 3},  /* 1468 */
    {1469, 1469, "191.239", "191.7.1469", 191, 3},  /* 1469 */
    {1470, 1470, "191.240", "191.8.1470", 191, 3},  /* 1470 */
    {1471, 1471, "191.241", "191.9.1471", 191, 3},  /* 1471 */
    {1472, 1472, "191.242", "191.10.1472", 191, 4}, /* 1472 */
    {1473, 1476, "192.243", "192.1.1476", 192, 1},  /* 1473 */
    {1474, 1477, "192.244", "192.2.1477", 192, 2},  /* 1474 */
    {1475, 1478, "192.245", "192.3.1478", 192, 3},  /* 1475 */
    {1476, 1479, "192.246", "192.4.1479", 192, 3},  /* 1476 */
    {1477, 1480, "192.247", "192.5.1480", 192, 3},  /* 1477 */
    {1478, 1481, "192.248", "192.6.1481", 192, 3},  /* 1478 */
    {1479, 1482, "192.249", "192.7.1482", 192, 3},  /* 1479 */
    {1480, 1483, "192.250", "192.8.1483", 192, 3},  /* 1480 */
    {1481, 1484, "192.251", "192.9.1484", 192, 3},  /* 1481 */
    {1482, 1475, "192.252", "191.13.1475", 192, 4}, /* 1482 */
    {1483, 1485, "193.253", "193.1.1485", 193, 1},  /* 1483 */
    {1484, 1486, "193.254", "193.2.1486", 193, 2},  /* 1484 */
    {1485, 1487, "193.255", "193.3.1487", 193, 3},  /* 1485 */
    {1486, 1488, "193.256", "193.4.1488", 193, 3},  /* 1486 */
    {1487, 1489, "193.257", "193.5.1489", 193, 3},  /* 1487 */
    {1488, 1490, "193.258", "193.6.1490", 193, 3},  /* 1488 */
    {1489, 1491, "193.259", "193.7.1491", 193, 3},  /* 1489 */
    {1490, 1492, "193.260", "193.8.1492", 193, 3},  /* 1490 */
    {1491, 1493, "193.261", "193.9.1493", 193, 3},  /* 1491 */
    {1492, 1473, "193.262", "191.11.1473", 193, 4}, /* 1492 */
    {1493, 1494, "194.263", "194.1.1494", 194, 1},  /* 1493 */
    {1494, 1495, "194.264", "194.2.1495", 194, 2},  /* 1494 */
    {1495, 1496, "194.265", "194.3.1496", 194, 3},  /* 1495 */
    {1496, 1497, "194.266", "194.4.1497", 194, 3},  /* 1496 */
    {1497, 1498, "194.267", "194.5.1498", 194, 3},  /* 1497 */
    {1498, 1499, "194.268", "194.6.1499", 194, 3},  /* 1498 */
    {1499, 1500, "194.269", "194.7.1500", 194, 3},  /* 1499 */
    {1500, 1501, "194.270", "194.8.1501", 194, 3},  /* 1500 */
    {1501, 1502, "194.271", "194.9.1502", 194, 3},  /* 1501 */
    {1502, 1474, "194.272", "191.12.1474", 194, 4}, /* 1502 */
    {1503, 1503, "195.1", "195.1.1503", 195, 1},    /* 1503 */
    {1504, 1504, "195.2", "195.2.1504", 195, 2},    /* 1504 */
    {1505, 1510, "195.3", "197.3.1510", 195, 4},    /* 1505 */
    {1506, 1506, "196.4", "196.1.1506", 196, 1},    /* 1506 */
    {1507, 1507, "196.5", "196.2.1507", 196, 2},    /* 1507 */
    {1508, 1505, "196.6", "195.3.1505", 196, 4},    /* 1508 */
    {1509, 1508, "197.7", "197.1.1508", 197, 1},    /* 1509 */
    {1510, 1509, "197.8", "197.2.1509", 197, 2},    /* 1510 */
    {1511, 1511, "198.9", "198.1.1511", 198, 1},    /* 1511 */
    {1512, 1512, "198.10", "198.2.1512", 198, 2},   /* 1512 */
    {1513, 1515, "198.11", "199.3.1515", 198, 4},   /* 1513 */
    {1514, 1513, "199.12", "199.1.1513", 199, 1},   /* 1514 */
    {1515, 1514, "199.13", "199.2.1514", 199, 2},   /* 1515 */
    {1516, 1516, "200.14", "200.1.1516", 200, 1},   /* 1516 */
    {1517, 1517, "200.15", "200.2.1517", 200, 2},   /* 1517 */
    {1518, 1518, "200.16", "200.3.1518", 200, 3},   /* 1518 */
    {1519, 1533, "200.17", "204.4.1533", 200, 4},   /* 1519 */
    {1520, 1520, "201.18", "201.1.1520", 201, 1},   /* 1520 */
    {1521, 1521, "201.19", "201.2.1521", 201, 2},   /* 1521 */
    {1522, 1522, "201.20", "201.3.1522", 201, 3},   /* 1522 */
    {1523, 1534, "201.21", "204.5.1534", 201, 4},   /* 1523 */
    {1524, 1524, "202.22", "202.1.1524", 202, 1},   /* 1524 */
    {1525, 1525, "202.23", "202.2.1525", 202, 2},   /* 1525 */
    {1526, 1526, "202.24", "202.3.1526", 202, 3},   /* 1526 */
    {1527, 1519, "202.25", "200.4.1519", 202, 4},   /* 1527 */
    {1528, 1527, "203.26", "203.1.1527", 203, 1},   /* 1528 */
    {1529, 1528, "203.27", "203.2.1528", 203, 2},   /* 1529 */
    {1530, 1529, "203.28", "203.3.1529", 203, 3},   /* 1530 */
    {1531, 1523, "203.29", "201.4.1523", 203, 4},   /* 1531 */
    {1532, 1530, "204.30", "204.1.1530", 204, 1},   /* 1532 */
    {1533, 1531, "204.31", "204.2.1531", 204, 2},   /* 1533 */
    {1534, 1532, "204.32", "204.3.1532", 204, 3},   /* 1534 */
    {1535, 1535, "205.33", "205.1.1535", 205, 1},   /* 1535 */
    {1536, 1536, "205.34", "205.2.1536", 205, 2},   /* 1536 */
    {1537, 1537, "205.35", "205.3.1537", 205, 3},   /* 1537 */
    {1538, 1541, "205.36", "206.4.1541", 205, 4},   /* 1538 */
    {1539, 1538, "206.37", "206.1.1538", 206, 1},   /* 1539 */
    {1540, 1539, "206.38", "206.2.1539", 206, 2},   /* 1540 */
    {1541, 1540, "206.39", "206.3.1540", 206, 3},   /* 1541 */
    {1542, 1542, "207.40", "207.1.1542", 207, 1},   /* 1542 */
    {1543, 1543, "207.41", "207.2.1543", 207, 2},   /* 1543 */
    {1544, 1544, "207.42", "207.3.1544", 207, 3},   /* 1544 */
    {1545, 1559, "207.43", "211.4.1559", 207, 4},   /* 1545 */
    {1546, 1546, "208.44", "208.1.1546", 208, 1},   /* 1546 */
    {1547, 1547, "208.45", "208.2.1547", 208, 2},   /* 1547 */
    {1548, 1548, "208.46", "208.3.1548", 208, 3},   /* 1548 */
    {1549, 1560, "208.47", "211.5.1560", 208, 4},   /* 1549 */
    {1550, 1550, "209.48", "209.1.1550", 209, 1},   /* 1550 */
    {1551, 1551, "209.49", "209.2.1551", 209, 2},   /* 1551 */
    {1552, 1552, "209.50", "209.3.1552", 209, 3},   /* 1552 */
    {1553, 1545, "209.51", "207.4.1545", 209, 4},   /* 1553 */
    {1554, 1553, "210.52", "210.1.1553", 210, 1},   /* 1554 */
    {1555, 1554, "210.53", "210.2.1554", 210, 2},   /* 1555 */
    {1556, 1555, "210.54", "210.3.1555", 210, 3},   /* 1556 */
    {1557, 1549, "210.55", "208.4.1549", 210, 4},   /* 1557 */
    {1558, 1556, "211.56", "211.1.1556", 211, 1},   /* 1558 */
    {1559, 1557, "211.57", "211.2.1557", 211, 2},   /* 1559 */
    {1560, 1558, "211.58", "211.3.1558", 211, 3},   /* 1560 */
    {1561, 1561, "212.59", "212.1.1561", 212, 1},   /* 1561 */
    {1562, 1562, "212.60", "212.2.1562", 212, 2},   /* 1562 */
    {1563, 1563, "212.61", "212.3.1563", 212, 3},   /* 1563 */
    {1564, 1570, "212.62", "214.4.1570", 212, 4},   /* 1564 */
    {1565, 1564, "213.63", "213.1.1564", 213, 1},   /* 1565 */
    {1566, 1565, "213.64", "213.2.1565", 213, 2},   /* 1566 */
    {1567, 1566, "213.65", "213.3.1566", 213, 3},   /* 1567 */
    {1568, 1571, "213.66", "214.5.1571", 213, 4},   /* 1568 */
    {1569, 1567, "214.67", "214.1.1567", 214, 1},   /* 1569 */
    {1570, 1568, "214.68", "214.2.1568", 214, 2},   /* 1570 */
    {1571, 1569, "214.69", "214.3.1569", 214, 3},   /* 1571 */
    {1572, 1572, "215.70", "215.1.1572", 215, 1},   /* 1572 */
    {1573, 1573, "215.71", "215.2.1573", 215, 2},   /* 1573 */
    {1574, 1574, "215.72", "215.3.1574", 215, 3},   /* 1574 */
    {1575, 1583, "215.73", "217.4.1583", 215, 4},   /* 1575 */
    {1576, 1577, "216.74", "216.1.1577", 216, 1},   /* 1576 */
    {1577, 1578, "216.75", "216.2.1578", 216, 2},   /* 1577 */
    {1578, 1579, "216.76", "216.3.1579", 216, 3},   /* 1578 */
    {1579, 1575, "216.77", "215.4.1575", 216, 4},   /* 1579 */
    {1580, 1580, "217.78", "217.1.1580", 217, 1},   /* 1580 */
    {1581, 1581, "217.79", "217.2.1581", 217, 2},   /* 1581 */
    {1582, 1582, "217.80", "217.3.1582", 217, 3},   /* 1582 */
    {1583, 1585, "218.81", "218.1.1585", 218, 1},   /* 1583 */
    {1584, 1586, "218.82", "218.2.1586", 218, 2},   /* 1584 */
    {1585, 1587, "218.83", "218.3.1587", 218, 3},   /* 1585 */
    {1586, 1584, "218.84", "217.5.1584", 218, 4},   /* 1586 */
    {1587, 1588, "219.85", "219.1.1588", 219, 1},   /* 1587 */
    {1588, 1589, "219.86", "219.2.1589", 219, 2},   /* 1588 */
    {1589, 1590, "219.87", "219.3.1590", 219, 3},   /* 1589 */
    {1590, 1576, "219.88", "215.5.1576", 219, 4},   /* 1590 */
    {1591, 1591, "220.89", "220.1.1591", 220, 1},   /* 1591 */
    {1592, 1592, "220.90", "220.2.1592", 220, 2},   /* 1592 */
    {1593, 1593, "220.91", "220.3.1593", 220, 3},   /* 1593 */
    {1594, 1594, "221.92", "221.1.1594", 221, 1},   /* 1594 */
    {1595, 1595, "221.93", "221.2.1595", 221, 2},   /* 1595 */
    {1596, 1596, "221.94", "221.3.1596", 221, 3},   /* 1596 */
    {1597, 1597, "221.95", "221.4.1597", 221, 3},   /* 1597 */
    {1598, 1598, "221.96", "221.5.1598", 221, 3},   /* 1598 */
    {1599, 1643, "221.97", "229.6.1643", 221, 4},   /* 1599 */
    {1600, 1601, "222.98", "222.1.1601", 222, 1},   /* 1600 */
    {1601, 1602, "222.99", "222.2.1602", 222, 2},   /* 1601 */
    {1602, 1603, "222.100", "222.3.1603", 222, 3},  /* 1602 */
    {1603, 1604, "222.101", "222.4.1604", 222, 3},  /* 1603 */
    {1604, 1605, "222.102", "222.5.1605", 222, 3},  /* 1604 */
    {1605, 1646, "222.103", "229.9.1646", 222, 4},  /* 1605 */
    {1606, 1606, "223.104", "223.1.1606", 223, 1},  /* 1606 */
    {1607, 1607, "223.105", "223.2.1607", 223, 2},  /* 1607 */
    {1608, 1608, "223.106", "223.3.1608", 223, 3},  /* 1608 */
    {1609, 1609, "223.107", "223.4.1609", 223, 3},  /* 1609 */
    {1610, 1610, "223.108", "223.5.1610", 223, 3},  /* 1610 */
    {1611, 1645, "223.109", "229.8.1645", 223, 4},  /* 1611 */
    {1612, 1611, "224.110", "224.1.1611", 224, 1},  /* 1612 */
    {1613, 1612, "224.111", "224.2.1612", 224, 2},  /* 1613 */
    {1614, 1613, "224.112", "224.3.1613", 224, 3},  /* 1614 */
    {1615, 1614, "224.113", "224.4.1614", 224, 3},  /* 1615 */
    {1616, 1615, "224.114", "224.5.1615", 224, 3},  /* 1616 */
    {1617, 1644, "224.115", "229.7.1644", 224, 4},  /* 1617 */
    {1618, 1618, "225.116", "225.1.1618", 225, 1},  /* 1618 */
    {1619, 1619, "225.117", "225.2.1619", 225, 2},  /* 1619 */
    {1620, 1620, "225.118", "225.3.1620", 225, 3},  /* 1620 */
    {1621, 1621, "225.119", "225.4.1621", 225, 3},  /* 1621 */
    {1622, 1622, "225.120", "225.5.1622", 225, 3},  /* 1622 */
    {1623, 1599, "225.121", "221.6.1599", 225, 4},  /* 1623 */
    {1624, 1623, "226.122", "226.1.1623", 226, 1},  /* 1624 */
    {1625, 1624, "226.123", "226.2.1624", 226, 2},  /* 1625 */
    {1626, 1625, "226.124", "226.3.1625", 226, 3},  /* 1626 */
    {1627, 1626, "226.125", "226.4.1626", 226, 3},  /* 1627 */
    {1628, 1627, "226.126", "226.5.1627", 226, 3},  /* 1628 */
    {1629, 1600, "226.127", "221.7.1600", 226, 4},  /* 1629 */
    {1630, 1628, "227.128", "227.1.1628", 227, 1},  /* 1630 */
    {1631, 1629, "227.129", "227.2.1629", 227, 2},  /* 1631 */
    {1632, 1630, "227.130", "227.3.1630", 227, 3},  /* 1632 */
    {1633, 1631, "227.131", "227.4.1631", 227, 3},  /* 1633 */
    {1634, 1632, "227.132", "227.5.1632", 227, 3},  /* 1634 */
    {1635, 1616, "227.133", "224.6.1616", 227, 4},  /* 1635 */
    {1636, 1633, "228.134", "228.1.1633", 228, 1},  /* 1636 */
    {1637, 1634, "228.135", "228.2.1634", 228, 2},  /* 1637 */
    {1638, 1635, "228.136", "228.3.1635", 228, 3},  /* 1638 */
    {1639, 1636, "228.137", "228.4.1636", 228, 3},  /* 1639 */
    {1640, 1637, "228.138", "228.5.1637", 228, 3},  /* 1640 */
    {1641, 1617, "228.139", "224.7.1617", 228, 4},  /* 1641 */
    {1642, 1638, "229.140", "229.1.1638", 229, 1},  /* 1642 */
    {1643, 1639, "229.141", "229.2.1639", 229, 2},  /* 1643 */
    {1644, 1640, "229.142", "229.3.1640", 229, 3},  /* 1644 */
    {1645, 1641, "229.143", "229.4.1641", 229, 3},  /* 1645 */
    {1646, 1642, "229.144", "229.5.1642", 229, 3},  /* 1646 */
    {1647, 1647, "230.145", "230.1.1647", 230, 1},  /* 1647 */
    {1648, 1648, "230.146", "230.2.1648", 230, 2},  /* 1648 */
    {1649, 1649, "230.147", "230.3.1649", 230, 3},  /* 1649 */
    {1650, 1650, "230.148", "230.4.1650", 230, 3},  /* 1650 */
    {1651, 1651, "230.149", "230.5.1651", 230, 3},  /* 1651 */
};

/* {smallest UNI number, largest UNI number} for each Hall number */
static const int magnetic_spacegroup_hall_mapping[][2] = {
    {    0,    0 }, /* dummy */
    {    1,    3 }, /*   1 */
    {    4,    7 }, /*   2 */
    {    8,   13 }, /*   3 */
    {    8,   13 }, /*   4 */
    {    8,   13 }, /*   5 */
    {   14,   19 }, /*   6 */
    {   14,   19 }, /*   7 */
    {   14,   19 }, /*   8 */
    {   20,   24 }, /*   9 */
    {   20,   24 }, /*  10 */
    {   20,   24 }, /*  11 */
    {   20,   24 }, /*  12 */
    {   20,   24 }, /*  13 */
    {   20,   24 }, /*  14 */
    {   20,   24 }, /*  15 */
    {   20,   24 }, /*  16 */
    {   20,   24 }, /*  17 */
    {   25,   30 }, /*  18 */
    {   25,   30 }, /*  19 */
    {   25,   30 }, /*  20 */
    {   31,   38 }, /*  21 */
    {   31,   38 }, /*  22 */
    {   31,   38 }, /*  23 */
    {   31,   38 }, /*  24 */
    {   31,   38 }, /*  25 */
    {   31,   38 }, /*  26 */
    {   31,   38 }, /*  27 */
    {   31,   38 }, /*  28 */
    {   31,   38 }, /*  29 */
    {   39,   43 }, /*  30 */
    {   39,   43 }, /*  31 */
    {   39,   43 }, /*  32 */
    {   39,   43 }, /*  33 */
    {   39,   43 }, /*  34 */
    {   39,   43 }, /*  35 */
    {   39,   43 }, /*  36 */
    {   39,   43 }, /*  37 */
    {   39,   43 }, /*  38 */
    {   44,   48 }, /*  39 */
    {   44,   48 }, /*  40 */
    {   44,   48 }, /*  41 */
    {   44,   48 }, /*  42 */
    {   44,   48 }, /*  43 */
    {   44,   48 }, /*  44 */
    {   44,   48 }, /*  45 */
    {   44,   48 }, /*  46 */
    {   44,   48 }, /*  47 */
    {   44,   48 }, /*  48 */
    {   44,   48 }, /*  49 */
    {   44,   48 }, /*  50 */
    {   44,   48 }, /*  51 */
    {   44,   48 }, /*  52 */
    {   44,   48 }, /*  53 */
    {   44,   48 }, /*  54 */
    {   44,   48 }, /*  55 */
    {   44,   48 }, /*  56 */
    {   49,   56 }, /*  57 */
    {   49,   56 }, /*  58 */
    {   49,   56 }, /*  59 */
    {   57,   64 }, /*  60 */
    {   57,   64 }, /*  61 */
    {   57,   64 }, /*  62 */
    {   65,   71 }, /*  63 */
    {   65,   71 }, /*  64 */
    {   65,   71 }, /*  65 */
    {   65,   71 }, /*  66 */
    {   65,   71 }, /*  67 */
    {   65,   71 }, /*  68 */
    {   65,   71 }, /*  69 */
    {   65,   71 }, /*  70 */
    {   65,   71 }, /*  71 */
    {   72,   81 }, /*  72 */
    {   72,   81 }, /*  73 */
    {   72,   81 }, /*  74 */
    {   72,   81 }, /*  75 */
    {   72,   81 }, /*  76 */
    {   72,   81 }, /*  77 */
    {   72,   81 }, /*  78 */
    {   72,   81 }, /*  79 */
    {   72,   81 }, /*  80 */
    {   82,   91 }, /*  81 */
    {   82,   91 }, /*  82 */
    {   82,   91 }, /*  83 */
    {   82,   91 }, /*  84 */
    {   82,   91 }, /*  85 */
    {   82,   91 }, /*  86 */
    {   82,   91 }, /*  87 */
    {   82,   91 }, /*  88 */
    {   82,   91 }, /*  89 */
    {   92,   98 }, /*  90 */
    {   92,   98 }, /*  91 */
    {   92,   98 }, /*  92 */
    {   92,   98 }, /*  93 */
    {   92,   98 }, /*  94 */
    {   92,   98 }, /*  95 */
    {   92,   98 }, /*  96 */
    {   92,   98 }, /*  97 */
    {   92,   98 }, /*  98 */
    {   92,   98 }, /*  99 */
    {   92,   98 }, /* 100 */
    {   92,   98 }, /* 101 */
    {   92,   98 }, /* 102 */
    {   92,   98 }, /* 103 */
    {   92,   98 }, /* 104 */
    {   92,   98 }, /* 105 */
    {   92,   98 }, /* 106 */
    {   92,   98 }, /* 107 */
    {   99,  104 }, /* 108 */
    {  105,  113 }, /* 109 */
    {  105,  113 }, /* 110 */
    {  105,  113 }, /* 111 */
    {  114,  122 }, /* 112 */
    {  114,  122 }, /* 113 */
    {  114,  122 }, /* 114 */
    {  123,  128 }, /* 115 */
    {  129,  135 }, /* 116 */
    {  129,  135 }, /* 117 */
    {  129,  135 }, /* 118 */
    {  136,  142 }, /* 119 */
    {  136,  142 }, /* 120 */
    {  136,  142 }, /* 121 */
    {  143,  146 }, /* 122 */
    {  147,  150 }, /* 123 */
    {  151,  154 }, /* 124 */
    {  155,  163 }, /* 125 */
    {  155,  163 }, /* 126 */
    {  155,  163 }, /* 127 */
    {  164,  175 }, /* 128 */
    {  164,  175 }, /* 129 */
    {  164,  175 }, /* 130 */
    {  164,  175 }, /* 131 */
    {  164,  175 }, /* 132 */
    {  164,  175 }, /* 133 */
    {  176,  184 }, /* 134 */
    {  176,  184 }, /* 135 */
    {  176,  184 }, /* 136 */
    {  185,  196 }, /* 137 */
    {  185,  196 }, /* 138 */
    {  185,  196 }, /* 139 */
    {  185,  196 }, /* 140 */
    {  185,  196 }, /* 141 */
    {  185,  196 }, /* 142 */
    {  197,  208 }, /* 143 */
    {  197,  208 }, /* 144 */
    {  197,  208 }, /* 145 */
    {  197,  208 }, /* 146 */
    {  197,  208 }, /* 147 */
    {  197,  208 }, /* 148 */
    {  209,  220 }, /* 149 */
    {  209,  220 }, /* 150 */
    {  209,  220 }, /* 151 */
    {  209,  220 }, /* 152 */
    {  209,  220 }, /* 153 */
    {  209,  220 }, /* 154 */
    {  221,  232 }, /* 155 */
    {  221,  232 }, /* 156 */
    {  221,  232 }, /* 157 */
    {  221,  232 }, /* 158 */
    {  221,  232 }, /* 159 */
    {  221,  232 }, /* 160 */
    {  233,  241 }, /* 161 */
    {  233,  241 }, /* 162 */
    {  233,  241 }, /* 163 */
    {  242,  253 }, /* 164 */
    {  242,  253 }, /* 165 */
    {  242,  253 }, /* 166 */
    {  242,  253 }, /* 167 */
    {  242,  253 }, /* 168 */
    {  242,  253 }, /* 169 */
    {  254,  262 }, /* 170 */
    {  254,  262 }, /* 171 */
    {  254,  262 }, /* 172 */
    {  263,  269 }, /* 173 */
    {  263,  269 }, /* 174 */
    {  263,  269 }, /* 175 */
    {  270,  277 }, /* 176 */
    {  270,  277 }, /* 177 */
    {  270,  277 }, /* 178 */
    {  270,  277 }, /* 179 */
    {  270,  277 }, /* 180 */
    {  270,  277 }, /* 181 */
    {  278,  284 }, /* 182 */
    {  278,  284 }, /* 183 */
    {  278,  284 }, /* 184 */
    {  285,  292 }, /* 185 */
    {  285,  292 }, /* 186 */
    {  285,  292 }, /* 187 */
    {  285,  292 }, /* 188 */
    {  285,  292 }, /* 189 */
    {  285,  292 }, /* 190 */
    {  293,  300 }, /* 191 */
    {  293,  300 }, /* 192 */
    {  293,  300 }, /* 193 */
    {  293,  300 }, /* 194 */
    {  293,  300 }, /* 195 */
    {  293,  300 }, /* 196 */
    {  301,  308 }, /* 197 */
    {  301,  308 }, /* 198 */
    {  301,  308 }, /* 199 */
    {  301,  308 }, /* 200 */
    {  301,  308 }, /* 201 */
    {  301,  308 }, /* 202 */
    {  309,  316 }, /* 203 */
    {  309,  316 }, /* 204 */
    {  309,  316 }, /* 205 */
    {  309,  316 }, /* 206 */
    {  309,  316 }, /* 207 */
    {  309,  316 }, /* 208 */
    {  317,  321 }, /* 209 */
    {  317,  321 }, /* 210 */
    {  317,  321 }, /* 211 */
    {  322,  326 }, /* 212 */
    {  322,  326 }, /* 213 */
    {  322,  326 }, /* 214 */
    {  327,  332 }, /* 215 */
    {  327,  332 }, /* 216 */
    {  327,  332 }, /* 217 */
    {  333,  338 }, /* 218 */
    {  333,  338 }, /* 219 */
    {  333,  338 }, /* 220 */
    {  339,  346 }, /* 221 */
    {  339,  346 }, /* 222 */
    {  339,  346 }, /* 223 */
    {  339,  346 }, /* 224 */
    {  339,  346 }, /* 225 */
    {  339,  346 }, /* 226 */
    {  347,  354 }, /* 227 */
    {  355,  362 }, /* 228 */
    {  355,  362 }, /* 229 */
    {  363,  374 }, /* 230 */
    {  363,  374 }, /* 231 */
    {  363,  374 }, /* 232 */
    {  375,  386 }, /* 233 */
    {  375,  386 }, /* 234 */
    {  375,  386 }, /* 235 */
    {  375,  386 }, /* 236 */
    {  375,  386 }, /* 237 */
    {  375,  386 }, /* 238 */
    {  387,  402 }, /* 239 */
    {  387,  402 }, /* 240 */
    {  387,  402 }, /* 241 */
    {  387,  402 }, /* 242 */
    {  387,  402 }, /* 243 */
    {  387,  402 }, /* 244 */
    {  403,  418 }, /* 245 */
    {  403,  418 }, /* 246 */
    {  403,  418 }, /* 247 */
    {  403,  418 }, /* 248 */
    {  403,  418 }, /* 249 */
    {  403,  418 }, /* 250 */
    {  419,  434 }, /* 251 */
    {  419,  434 }, /* 252 */
    {  419,  434 }, /* 253 */
    {  419,  434 }, /* 254 */
    {  419,  434 }, /* 255 */
    {  419,  434 }, /* 256 */
    {  435,  450 }, /* 257 */
    {  435,  450 }, /* 258 */
    {  435,  450 }, /* 259 */
    {  435,  450 }, /* 260 */
    {  435,  450 }, /* 261 */
    {  435,  450 }, /* 262 */
    {  451,  462 }, /* 263 */
    {  451,  462 }, /* 264 */
    {  451,  462 }, /* 265 */
    {  463,  474 }, /* 266 */
    {  463,  474 }, /* 267 */
    {  463,  474 }, /* 268 */
    {  475,  490 }, /* 269 */
    {  475,  490 }, /* 270 */
    {  475,  490 }, /* 271 */
    {  475,  490 }, /* 272 */
    {  475,  490 }, /* 273 */
    {  475,  490 }, /* 274 */
    {  491,  502 }, /* 275 */
    {  491,  502 }, /* 276 */
    {  491,  502 }, /* 277 */
    {  503,  514 }, /* 278 */
    {  503,  514 }, /* 279 */
    {  503,  514 }, /* 280 */
    {  503,  514 }, /* 281 */
    {  503,  514 }, /* 282 */
    {  503,  514 }, /* 283 */
    {  515,  530 }, /* 284 */
    {  515,  530 }, /* 285 */
    {  515,  530 }, /* 286 */
    {  515,  530 }, /* 287 */
    {  515,  530 }, /* 288 */
    {  515,  530 }, /* 289 */
    {  531,  538 }, /* 290 */
    {  531,  538 }, /* 291 */
    {  539,  554 }, /* 292 */
    {  539,  554 }, /* 293 */
    {  539,  554 }, /* 294 */
    {  539,  554 }, /* 295 */
    {  539,  554 }, /* 296 */
    {  539,  554 }, /* 297 */
    {  555,  566 }, /* 298 */
    {  555,  566 }, /* 299 */
    {  555,  566 }, /* 300 */
    {  555,  566 }, /* 301 */
    {  555,  566 }, /* 302 */
    {  555,  566 }, /* 303 */
    {  567,  578 }, /* 304 */
    {  567,  578 }, /* 305 */
    {  567,  578 }, /* 306 */
    {  567,  578 }, /* 307 */
    {  567,  578 }, /* 308 */
    {  567,  578 }, /* 309 */
    {  579,  588 }, /* 310 */
    {  579,  588 }, /* 311 */
    {  579,  588 }, /* 312 */
    {  589,  598 }, /* 313 */
    {  589,  598 }, /* 314 */
    {  589,  598 }, /* 315 */
    {  599,  608 }, /* 316 */
    {  599,  608 }, /* 317 */
    {  599,  608 }, /* 318 */
    {  599,  608 }, /* 319 */
    {  599,  608 }, /* 320 */
    {  599,  608 }, /* 321 */
    {  609,  618 }, /* 322 */
    {  609,  618 }, /* 323 */
    {  609,  618 }, /* 324 */
    {  609,  618 }, /* 325 */
    {  609,  618 }, /* 326 */
    {  609,  618 }, /* 327 */
    {  609,  618 }, /* 328 */
    {  609,  618 }, /* 329 */
    {  609,  618 }, /* 330 */
    {  609,  618 }, /* 331 */
    {  609,  618 }, /* 332 */
    {  609,  618 }, /* 333 */
    {  619,  624 }, /* 334 */
    {  625,  630 }, /* 335 */
    {  625,  630 }, /* 336 */
    {  631,  636 }, /* 337 */
    {  637,  645 }, /* 338 */
    {  637,  645 }, /* 339 */
    {  637,  645 }, /* 340 */
    {  646,  651 }, /* 341 */
    {  646,  651 }, /* 342 */
    {  652,  660 }, /* 343 */
    {  652,  660 }, /* 344 */
    {  652,  660 }, /* 345 */
    {  652,  660 }, /* 346 */
    {  652,  660 }, /* 347 */
    {  652,  660 }, /* 348 */
    {  661,  666 }, /* 349 */
    {  667,  672 }, /* 350 */
    {  673,  678 }, /* 351 */
    {  679,  684 }, /* 352 */
    {  685,  688 }, /* 353 */
    {  689,  692 }, /* 354 */
    {  693,  698 }, /* 355 */
    {  699,  702 }, /* 356 */
    {  703,  710 }, /* 357 */
    {  711,  718 }, /* 358 */
    {  719,  726 }, /* 359 */
    {  719,  726 }, /* 360 */
    {  727,  734 }, /* 361 */
    {  727,  734 }, /* 362 */
    {  735,  740 }, /* 363 */
    {  741,  746 }, /* 364 */
    {  741,  746 }, /* 365 */
    {  747,  754 }, /* 366 */
    {  755,  762 }, /* 367 */
    {  763,  770 }, /* 368 */
    {  771,  778 }, /* 369 */
    {  779,  786 }, /* 370 */
    {  787,  794 }, /* 371 */
    {  795,  802 }, /* 372 */
    {  803,  810 }, /* 373 */
    {  811,  816 }, /* 374 */
    {  817,  822 }, /* 375 */
    {  823,  830 }, /* 376 */
    {  831,  838 }, /* 377 */
    {  839,  846 }, /* 378 */
    {  847,  854 }, /* 379 */
    {  855,  862 }, /* 380 */
    {  863,  870 }, /* 381 */
    {  871,  878 }, /* 382 */
    {  879,  886 }, /* 383 */
    {  887,  892 }, /* 384 */
    {  893,  898 }, /* 385 */
    {  899,  904 }, /* 386 */
    {  905,  910 }, /* 387 */
    {  911,  918 }, /* 388 */
    {  919,  926 }, /* 389 */
    {  927,  934 }, /* 390 */
    {  935,  942 }, /* 391 */
    {  943,  950 }, /* 392 */
    {  951,  958 }, /* 393 */
    {  959,  966 }, /* 394 */
    {  967,  974 }, /* 395 */
    {  975,  980 }, /* 396 */
    {  981,  986 }, /* 397 */
    {  987,  992 }, /* 398 */
    {  993,  998 }, /* 399 */
    {  999, 1010 }, /* 400 */
    { 1011, 1022 }, /* 401 */
    { 1023, 1034 }, /* 402 */
    { 1023, 1034 }, /* 403 */
    { 1035, 1046 }, /* 404 */
    { 1035, 1046 }, /* 405 */
    { 1047, 1058 }, /* 406 */
    { 1059, 1070 }, /* 407 */
    { 1071, 1082 }, /* 408 */
    { 1071, 1082 }, /* 409 */
    { 1083, 1094 }, /* 410 */
    { 1083, 1094 }, /* 411 */
    { 1095, 1106 }, /* 412 */
    { 1107, 1118 }, /* 413 */
    { 1119, 1130 }, /* 414 */
    { 1119, 1130 }, /* 415 */
    { 1131, 1142 }, /* 416 */
    { 1131, 1142 }, /* 417 */
    { 1143, 1154 }, /* 418 */
    { 1155, 1166 }, /* 419 */
    { 1167, 1178 }, /* 420 */
    { 1167, 1178 }, /* 421 */
    { 1179, 1190 }, /* 422 */
    { 1179, 1190 }, /* 423 */
    { 1191, 1200 }, /* 424 */
    { 1201, 1210 }, /* 425 */
    { 1211, 1220 }, /* 426 */
    { 1211, 1220 }, /* 427 */
    { 1221, 1230 }, /* 428 */
    { 1221, 1230 }, /* 429 */
    { 1231, 1233 }, /* 430 */
    { 1234, 1236 }, /* 431 */
    { 1237, 1239 }, /* 432 */
    { 1240, 1242 }, /* 433 */
    { 1240, 1242 }, /* 434 */
    { 1243, 1246 }, /* 435 */
    { 1247, 1250 }, /* 436 */
    { 1247, 1250 }, /* 437 */
    { 1251, 1254 }, /* 438 */
    { 1255, 1258 }, /* 439 */
    { 1259, 1262 }, /* 440 */
    { 1263, 1266 }, /* 441 */
    { 1267, 1270 }, /* 442 */
    { 1271, 1274 }, /* 443 */
    { 1275, 1278 }, /* 444 */
    { 1275, 1278 }, /* 445 */
    { 1279, 1282 }, /* 446 */
    { 1283, 1286 }, /* 447 */
    { 1287, 1290 }, /* 448 */
    { 1291, 1294 }, /* 449 */
    { 1295, 1298 }, /* 450 */
    { 1295, 1298 }, /* 451 */
    { 1299, 1302 }, /* 452 */
    { 1299, 1302 }, /* 453 */
    { 1303, 1308 }, /* 454 */
    { 1309, 1314 }, /* 455 */
    { 1315, 1320 }, /* 456 */
    { 1321, 1326 }, /* 457 */
    { 1327, 1332 }, /* 458 */
    { 1327, 1332 }, /* 459 */
    { 1333, 1338 }, /* 460 */
    { 1333, 1338 }, /* 461 */
    { 1339, 1342 }, /* 462 */
    { 1343, 1346 }, /* 463 */
    { 1347, 1350 }, /* 464 */
    { 1351, 1354 }, /* 465 */
    { 1355, 1358 }, /* 466 */
    { 1359, 1362 }, /* 467 */
    { 1363, 1366 }, /* 468 */
    { 1367, 1372 }, /* 469 */
    { 1373, 1378 }, /* 470 */
    { 1379, 1384 }, /* 471 */
    { 1385, 1390 }, /* 472 */
    { 1391, 1396 }, /* 473 */
    { 1397, 1402 }, /* 474 */
    { 1403, 1408 }, /* 475 */
    { 1409, 1414 }, /* 476 */
    { 1415, 1420 }, /* 477 */
    { 1421, 1426 }, /* 478 */
    { 1427, 1432 }, /* 479 */
    { 1433, 1438 }, /* 480 */
    { 1439, 1444 }, /* 481 */
    { 1445, 1450 }, /* 482 */
    { 1451, 1456 }, /* 483 */
    { 1457, 1462 }, /* 484 */
    { 1463, 1472 }, /* 485 */
    { 1473, 1482 }, /* 486 */
    { 1483, 1492 }, /* 487 */
    { 1493, 1502 }, /* 488 */
    { 1503, 1505 }, /* 489 */
    { 1506, 1508 }, /* 490 */
    { 1509, 1510 }, /* 491 */
    { 1511, 1513 }, /* 492 */
    { 1514, 1515 }, /* 493 */
    { 1516, 1519 }, /* 494 */
    { 1520, 1523 }, /* 495 */
    { 1520, 1523 }, /* 496 */
    { 1524, 1527 }, /* 497 */
    { 1528, 1531 }, /* 498 */
    { 1528, 1531 }, /* 499 */
    { 1532, 1534 }, /* 500 */
    { 1535, 1538 }, /* 501 */
    { 1539, 1541 }, /* 502 */
    { 1542, 1545 }, /* 503 */
    { 1546, 1549 }, /* 504 */
    { 1550, 1553 }, /* 505 */
    { 1554, 1557 }, /* 506 */
    { 1558, 1560 }, /* 507 */
    { 1561, 1564 }, /* 508 */
    { 1565, 1568 }, /* 509 */
    { 1569, 1571 }, /* 510 */
    { 1572, 1575 }, /* 511 */
    { 1576, 1579 }, /* 512 */
    { 1580, 1582 }, /* 513 */
    { 1583, 1586 }, /* 514 */
    { 1587, 1590 }, /* 515 */
    { 1591, 1593 }, /* 516 */
    { 1594, 1599 }, /* 517 */
    { 1600, 1605 }, /* 518 */
    { 1600, 1605 }, /* 519 */
    { 1606, 1611 }, /* 520 */
    { 1612, 1617 }, /* 521 */
    { 1612, 1617 }, /* 522 */
    { 1618, 1623 }, /* 523 */
    { 1624, 1629 }, /* 524 */
    { 1630, 1635 }, /* 525 */
    { 1630, 1635 }, /* 526 */
    { 1636, 1641 }, /* 527 */
    { 1636, 1641 }, /* 528 */
    { 1642, 1646 }, /* 529 */
    { 1647, 1651 }, /* 530 */
};

MagneticSpacegroupType msgdb_get_magnetic_spacegroup_type(
    const int uni_number) {
    MagneticSpacegroupType msgtype;

    if (uni_number > 0 && uni_number <= 1651) {
        msgtype = magnetic_spacegroup_types[uni_number];
    } else {
        /* out of range */
        msgtype = magnetic_spacegroup_types[0];
    }

    return msgtype;
}

/* Return smallest and largest UNI numbers for Hall number */
void msgdb_get_uni_candidates(int uni_number_range[2], const int hall_number) {
   uni_number_range[0] = magnetic_spacegroup_hall_mapping[hall_number][0];
   uni_number_range[1] = magnetic_spacegroup_hall_mapping[hall_number][1];
}

/* {number of Hall symbols, the smallest Hall number} for each UNI number */
static const int magnetic_spacegroup_uni_mapping[][2] = {
    {0, 0},    /* dummy */
    {1, 1},    /* 1 */
    {1, 1},    /* 2 */
    {1, 1},    /* 3 */
    {1, 2},    /* 4 */
    {1, 2},    /* 5 */
    {1, 2},    /* 6 */
    {1, 2},    /* 7 */
    {3, 3},    /* 8 */
    {3, 3},    /* 9 */
    {3, 3},    /* 10 */
    {3, 3},    /* 11 */
    {3, 3},    /* 12 */
    {3, 3},    /* 13 */
    {3, 6},    /* 14 */
    {3, 6},    /* 15 */
    {3, 6},    /* 16 */
    {3, 6},    /* 17 */
    {3, 6},    /* 18 */
    {3, 6},    /* 19 */
    {9, 9},    /* 20 */
    {9, 9},    /* 21 */
    {9, 9},    /* 22 */
    {9, 9},    /* 23 */
    {9, 9},    /* 24 */
    {3, 18},   /* 25 */
    {3, 18},   /* 26 */
    {3, 18},   /* 27 */
    {3, 18},   /* 28 */
    {3, 18},   /* 29 */
    {3, 18},   /* 30 */
    {9, 21},   /* 31 */
    {9, 21},   /* 32 */
    {9, 21},   /* 33 */
    {9, 21},   /* 34 */
    {9, 21},   /* 35 */
    {9, 21},   /* 36 */
    {9, 21},   /* 37 */
    {9, 21},   /* 38 */
    {9, 30},   /* 39 */
    {9, 30},   /* 40 */
    {9, 30},   /* 41 */
    {9, 30},   /* 42 */
    {9, 30},   /* 43 */
    {18, 39},  /* 44 */
    {18, 39},  /* 45 */
    {18, 39},  /* 46 */
    {18, 39},  /* 47 */
    {18, 39},  /* 48 */
    {3, 57},   /* 49 */
    {3, 57},   /* 50 */
    {3, 57},   /* 51 */
    {3, 57},   /* 52 */
    {3, 57},   /* 53 */
    {3, 57},   /* 54 */
    {3, 57},   /* 55 */
    {3, 57},   /* 56 */
    {3, 60},   /* 57 */
    {3, 60},   /* 58 */
    {3, 60},   /* 59 */
    {3, 60},   /* 60 */
    {3, 60},   /* 61 */
    {3, 60},   /* 62 */
    {3, 60},   /* 63 */
    {3, 60},   /* 64 */
    {9, 63},   /* 65 */
    {9, 63},   /* 66 */
    {9, 63},   /* 67 */
    {9, 63},   /* 68 */
    {9, 63},   /* 69 */
    {9, 63},   /* 70 */
    {9, 63},   /* 71 */
    {9, 72},   /* 72 */
    {9, 72},   /* 73 */
    {9, 72},   /* 74 */
    {9, 72},   /* 75 */
    {9, 72},   /* 76 */
    {9, 72},   /* 77 */
    {9, 72},   /* 78 */
    {9, 72},   /* 79 */
    {9, 72},   /* 80 */
    {9, 72},   /* 81 */
    {9, 81},   /* 82 */
    {9, 81},   /* 83 */
    {9, 81},   /* 84 */
    {9, 81},   /* 85 */
    {9, 81},   /* 86 */
    {9, 81},   /* 87 */
    {9, 81},   /* 88 */
    {9, 81},   /* 89 */
    {9, 81},   /* 90 */
    {9, 81},   /* 91 */
    {18, 90},  /* 92 */
    {18, 90},  /* 93 */
    {18, 90},  /* 94 */
    {18, 90},  /* 95 */
    {18, 90},  /* 96 */
    {18, 90},  /* 97 */
    {18, 90},  /* 98 */
    {1, 108},  /* 99 */
    {1, 108},  /* 100 */
    {1, 108},  /* 101 */
    {1, 108},  /* 102 */
    {1, 108},  /* 103 */
    {1, 108},  /* 104 */
    {3, 109},  /* 105 */
    {3, 109},  /* 106 */
    {3, 109},  /* 107 */
    {3, 109},  /* 108 */
    {3, 109},  /* 109 */
    {3, 109},  /* 110 */
    {3, 109},  /* 111 */
    {3, 109},  /* 112 */
    {3, 109},  /* 113 */
    {3, 112},  /* 114 */
    {3, 112},  /* 115 */
    {3, 112},  /* 116 */
    {3, 112},  /* 117 */
    {3, 112},  /* 118 */
    {3, 112},  /* 119 */
    {3, 112},  /* 120 */
    {3, 112},  /* 121 */
    {3, 112},  /* 122 */
    {1, 115},  /* 123 */
    {1, 115},  /* 124 */
    {1, 115},  /* 125 */
    {1, 115},  /* 126 */
    {1, 115},  /* 127 */
    {1, 115},  /* 128 */
    {3, 116},  /* 129 */
    {3, 116},  /* 130 */
    {3, 116},  /* 131 */
    {3, 116},  /* 132 */
    {3, 116},  /* 133 */
    {3, 116},  /* 134 */
    {3, 116},  /* 135 */
    {3, 119},  /* 136 */
    {3, 119},  /* 137 */
    {3, 119},  /* 138 */
    {3, 119},  /* 139 */
    {3, 119},  /* 140 */
    {3, 119},  /* 141 */
    {3, 119},  /* 142 */
    {1, 122},  /* 143 */
    {1, 122},  /* 144 */
    {1, 122},  /* 145 */
    {1, 122},  /* 146 */
    {1, 123},  /* 147 */
    {1, 123},  /* 148 */
    {1, 123},  /* 149 */
    {1, 123},  /* 150 */
    {1, 124},  /* 151 */
    {1, 124},  /* 152 */
    {1, 124},  /* 153 */
    {1, 124},  /* 154 */
    {3, 125},  /* 155 */
    {3, 125},  /* 156 */
    {3, 125},  /* 157 */
    {3, 125},  /* 158 */
    {3, 125},  /* 159 */
    {3, 125},  /* 160 */
    {3, 125},  /* 161 */
    {3, 125},  /* 162 */
    {3, 125},  /* 163 */
    {6, 128},  /* 164 */
    {6, 128},  /* 165 */
    {6, 128},  /* 166 */
    {6, 128},  /* 167 */
    {6, 128},  /* 168 */
    {6, 128},  /* 169 */
    {6, 128},  /* 170 */
    {6, 128},  /* 171 */
    {6, 128},  /* 172 */
    {6, 128},  /* 173 */
    {6, 128},  /* 174 */
    {6, 128},  /* 175 */
    {3, 134},  /* 176 */
    {3, 134},  /* 177 */
    {3, 134},  /* 178 */
    {3, 134},  /* 179 */
    {3, 134},  /* 180 */
    {3, 134},  /* 181 */
    {3, 134},  /* 182 */
    {3, 134},  /* 183 */
    {3, 134},  /* 184 */
    {6, 137},  /* 185 */
    {6, 137},  /* 186 */
    {6, 137},  /* 187 */
    {6, 137},  /* 188 */
    {6, 137},  /* 189 */
    {6, 137},  /* 190 */
    {6, 137},  /* 191 */
    {6, 137},  /* 192 */
    {6, 137},  /* 193 */
    {6, 137},  /* 194 */
    {6, 137},  /* 195 */
    {6, 137},  /* 196 */
    {6, 143},  /* 197 */
    {6, 143},  /* 198 */
    {6, 143},  /* 199 */
    {6, 143},  /* 200 */
    {6, 143},  /* 201 */
    {6, 143},  /* 202 */
    {6, 143},  /* 203 */
    {6, 143},  /* 204 */
    {6, 143},  /* 205 */
    {6, 143},  /* 206 */
    {6, 143},  /* 207 */
    {6, 143},  /* 208 */
    {6, 149},  /* 209 */
    {6, 149},  /* 210 */
    {6, 149},  /* 211 */
    {6, 149},  /* 212 */
    {6, 149},  /* 213 */
    {6, 149},  /* 214 */
    {6, 149},  /* 215 */
    {6, 149},  /* 216 */
    {6, 149},  /* 217 */
    {6, 149},  /* 218 */
    {6, 149},  /* 219 */
    {6, 149},  /* 220 */
    {6, 155},  /* 221 */
    {6, 155},  /* 222 */
    {6, 155},  /* 223 */
    {6, 155},  /* 224 */
    {6, 155},  /* 225 */
    {6, 155},  /* 226 */
    {6, 155},  /* 227 */
    {6, 155},  /* 228 */
    {6, 155},  /* 229 */
    {6, 155},  /* 230 */
    {6, 155},  /* 231 */
    {6, 155},  /* 232 */
    {3, 161},  /* 233 */
    {3, 161},  /* 234 */
    {3, 161},  /* 235 */
    {3, 161},  /* 236 */
    {3, 161},  /* 237 */
    {3, 161},  /* 238 */
    {3, 161},  /* 239 */
    {3, 161},  /* 240 */
    {3, 161},  /* 241 */
    {6, 164},  /* 242 */
    {6, 164},  /* 243 */
    {6, 164},  /* 244 */
    {6, 164},  /* 245 */
    {6, 164},  /* 246 */
    {6, 164},  /* 247 */
    {6, 164},  /* 248 */
    {6, 164},  /* 249 */
    {6, 164},  /* 250 */
    {6, 164},  /* 251 */
    {6, 164},  /* 252 */
    {6, 164},  /* 253 */
    {3, 170},  /* 254 */
    {3, 170},  /* 255 */
    {3, 170},  /* 256 */
    {3, 170},  /* 257 */
    {3, 170},  /* 258 */
    {3, 170},  /* 259 */
    {3, 170},  /* 260 */
    {3, 170},  /* 261 */
    {3, 170},  /* 262 */
    {3, 173},  /* 263 */
    {3, 173},  /* 264 */
    {3, 173},  /* 265 */
    {3, 173},  /* 266 */
    {3, 173},  /* 267 */
    {3, 173},  /* 268 */
    {3, 173},  /* 269 */
    {6, 176},  /* 270 */
    {6, 176},  /* 271 */
    {6, 176},  /* 272 */
    {6, 176},  /* 273 */
    {6, 176},  /* 274 */
    {6, 176},  /* 275 */
    {6, 176},  /* 276 */
    {6, 176},  /* 277 */
    {3, 182},  /* 278 */
    {3, 182},  /* 279 */
    {3, 182},  /* 280 */
    {3, 182},  /* 281 */
    {3, 182},  /* 282 */
    {3, 182},  /* 283 */
    {3, 182},  /* 284 */
    {6, 185},  /* 285 */
    {6, 185},  /* 286 */
    {6, 185},  /* 287 */
    {6, 185},  /* 288 */
    {6, 185},  /* 289 */
    {6, 185},  /* 290 */
    {6, 185},  /* 291 */
    {6, 185},  /* 292 */
    {6, 191},  /* 293 */
    {6, 191},  /* 294 */
    {6, 191},  /* 295 */
    {6, 191},  /* 296 */
    {6, 191},  /* 297 */
    {6, 191},  /* 298 */
    {6, 191},  /* 299 */
    {6, 191},  /* 300 */
    {6, 197},  /* 301 */
    {6, 197},  /* 302 */
    {6, 197},  /* 303 */
    {6, 197},  /* 304 */
    {6, 197},  /* 305 */
    {6, 197},  /* 306 */
    {6, 197},  /* 307 */
    {6, 197},  /* 308 */
    {6, 203},  /* 309 */
    {6, 203},  /* 310 */
    {6, 203},  /* 311 */
    {6, 203},  /* 312 */
    {6, 203},  /* 313 */
    {6, 203},  /* 314 */
    {6, 203},  /* 315 */
    {6, 203},  /* 316 */
    {3, 209},  /* 317 */
    {3, 209},  /* 318 */
    {3, 209},  /* 319 */
    {3, 209},  /* 320 */
    {3, 209},  /* 321 */
    {3, 212},  /* 322 */
    {3, 212},  /* 323 */
    {3, 212},  /* 324 */
    {3, 212},  /* 325 */
    {3, 212},  /* 326 */
    {3, 215},  /* 327 */
    {3, 215},  /* 328 */
    {3, 215},  /* 329 */
    {3, 215},  /* 330 */
    {3, 215},  /* 331 */
    {3, 215},  /* 332 */
    {3, 218},  /* 333 */
    {3, 218},  /* 334 */
    {3, 218},  /* 335 */
    {3, 218},  /* 336 */
    {3, 218},  /* 337 */
    {3, 218},  /* 338 */
    {6, 221},  /* 339 */
    {6, 221},  /* 340 */
    {6, 221},  /* 341 */
    {6, 221},  /* 342 */
    {6, 221},  /* 343 */
    {6, 221},  /* 344 */
    {6, 221},  /* 345 */
    {6, 221},  /* 346 */
    {1, 227},  /* 347 */
    {1, 227},  /* 348 */
    {1, 227},  /* 349 */
    {1, 227},  /* 350 */
    {1, 227},  /* 351 */
    {1, 227},  /* 352 */
    {1, 227},  /* 353 */
    {1, 227},  /* 354 */
    {2, 228},  /* 355 */
    {2, 228},  /* 356 */
    {2, 228},  /* 357 */
    {2, 228},  /* 358 */
    {2, 228},  /* 359 */
    {2, 228},  /* 360 */
    {2, 228},  /* 361 */
    {2, 228},  /* 362 */
    {3, 230},  /* 363 */
    {3, 230},  /* 364 */
    {3, 230},  /* 365 */
    {3, 230},  /* 366 */
    {3, 230},  /* 367 */
    {3, 230},  /* 368 */
    {3, 230},  /* 369 */
    {3, 230},  /* 370 */
    {3, 230},  /* 371 */
    {3, 230},  /* 372 */
    {3, 230},  /* 373 */
    {3, 230},  /* 374 */
    {6, 233},  /* 375 */
    {6, 233},  /* 376 */
    {6, 233},  /* 377 */
    {6, 233},  /* 378 */
    {6, 233},  /* 379 */
    {6, 233},  /* 380 */
    {6, 233},  /* 381 */
    {6, 233},  /* 382 */
    {6, 233},  /* 383 */
    {6, 233},  /* 384 */
    {6, 233},  /* 385 */
    {6, 233},  /* 386 */
    {6, 239},  /* 387 */
    {6, 239},  /* 388 */
    {6, 239},  /* 389 */
    {6, 239},  /* 390 */
    {6, 239},  /* 391 */
    {6, 239},  /* 392 */
    {6, 239},  /* 393 */
    {6, 239},  /* 394 */
    {6, 239},  /* 395 */
    {6, 239},  /* 396 */
    {6, 239},  /* 397 */
    {6, 239},  /* 398 */
    {6, 239},  /* 399 */
    {6, 239},  /* 400 */
    {6, 239},  /* 401 */
    {6, 239},  /* 402 */
    {6, 245},  /* 403 */
    {6, 245},  /* 404 */
    {6, 245},  /* 405 */
    {6, 245},  /* 406 */
    {6, 245},  /* 407 */
    {6, 245},  /* 408 */
    {6, 245},  /* 409 */
    {6, 245},  /* 410 */
    {6, 245},  /* 411 */
    {6, 245},  /* 412 */
    {6, 245},  /* 413 */
    {6, 245},  /* 414 */
    {6, 245},  /* 415 */
    {6, 245},  /* 416 */
    {6, 245},  /* 417 */
    {6, 245},  /* 418 */
    {6, 251},  /* 419 */
    {6, 251},  /* 420 */
    {6, 251},  /* 421 */
    {6, 251},  /* 422 */
    {6, 251},  /* 423 */
    {6, 251},  /* 424 */
    {6, 251},  /* 425 */
    {6, 251},  /* 426 */
    {6, 251},  /* 427 */
    {6, 251},  /* 428 */
    {6, 251},  /* 429 */
    {6, 251},  /* 430 */
    {6, 251},  /* 431 */
    {6, 251},  /* 432 */
    {6, 251},  /* 433 */
    {6, 251},  /* 434 */
    {6, 257},  /* 435 */
    {6, 257},  /* 436 */
    {6, 257},  /* 437 */
    {6, 257},  /* 438 */
    {6, 257},  /* 439 */
    {6, 257},  /* 440 */
    {6, 257},  /* 441 */
    {6, 257},  /* 442 */
    {6, 257},  /* 443 */
    {6, 257},  /* 444 */
    {6, 257},  /* 445 */
    {6, 257},  /* 446 */
    {6, 257},  /* 447 */
    {6, 257},  /* 448 */
    {6, 257},  /* 449 */
    {6, 257},  /* 450 */
    {3, 263},  /* 451 */
    {3, 263},  /* 452 */
    {3, 263},  /* 453 */
    {3, 263},  /* 454 */
    {3, 263},  /* 455 */
    {3, 263},  /* 456 */
    {3, 263},  /* 457 */
    {3, 263},  /* 458 */
    {3, 263},  /* 459 */
    {3, 263},  /* 460 */
    {3, 263},  /* 461 */
    {3, 263},  /* 462 */
    {3, 266},  /* 463 */
    {3, 266},  /* 464 */
    {3, 266},  /* 465 */
    {3, 266},  /* 466 */
    {3, 266},  /* 467 */
    {3, 266},  /* 468 */
    {3, 266},  /* 469 */
    {3, 266},  /* 470 */
    {3, 266},  /* 471 */
    {3, 266},  /* 472 */
    {3, 266},  /* 473 */
    {3, 266},  /* 474 */
    {6, 269},  /* 475 */
    {6, 269},  /* 476 */
    {6, 269},  /* 477 */
    {6, 269},  /* 478 */
    {6, 269},  /* 479 */
    {6, 269},  /* 480 */
    {6, 269},  /* 481 */
    {6, 269},  /* 482 */
    {6, 269},  /* 483 */
    {6, 269},  /* 484 */
    {6, 269},  /* 485 */
    {6, 269},  /* 486 */
    {6, 269},  /* 487 */
    {6, 269},  /* 488 */
    {6, 269},  /* 489 */
    {6, 269},  /* 490 */
    {3, 275},  /* 491 */
    {3, 275},  /* 492 */
    {3, 275},  /* 493 */
    {3, 275},  /* 494 */
    {3, 275},  /* 495 */
    {3, 275},  /* 496 */
    {3, 275},  /* 497 */
    {3, 275},  /* 498 */
    {3, 275},  /* 499 */
    {3, 275},  /* 500 */
    {3, 275},  /* 501 */
    {3, 275},  /* 502 */
    {6, 278},  /* 503 */
    {6, 278},  /* 504 */
    {6, 278},  /* 505 */
    {6, 278},  /* 506 */
    {6, 278},  /* 507 */
    {6, 278},  /* 508 */
    {6, 278},  /* 509 */
    {6, 278},  /* 510 */
    {6, 278},  /* 511 */
    {6, 278},  /* 512 */
    {6, 278},  /* 513 */
    {6, 278},  /* 514 */
    {6, 284},  /* 515 */
    {6, 284},  /* 516 */
    {6, 284},  /* 517 */
    {6, 284},  /* 518 */
    {6, 284},  /* 519 */
    {6, 284},  /* 520 */
    {6, 284},  /* 521 */
    {6, 284},  /* 522 */
    {6, 284},  /* 523 */
    {6, 284},  /* 524 */
    {6, 284},  /* 525 */
    {6, 284},  /* 526 */
    {6, 284},  /* 527 */
    {6, 284},  /* 528 */
    {6, 284},  /* 529 */
    {6, 284},  /* 530 */
    {2, 290},  /* 531 */
    {2, 290},  /* 532 */
    {2, 290},  /* 533 */
    {2, 290},  /* 534 */
    {2, 290},  /* 535 */
    {2, 290},  /* 536 */
    {2, 290},  /* 537 */
    {2, 290},  /* 538 */
    {6, 292},  /* 539 */
    {6, 292},  /* 540 */
    {6, 292},  /* 541 */
    {6, 292},  /* 542 */
    {6, 292},  /* 543 */
    {6, 292},  /* 544 */
    {6, 292},  /* 545 */
    {6, 292},  /* 546 */
    {6, 292},  /* 547 */
    {6, 292},  /* 548 */
    {6, 292},  /* 549 */
    {6, 292},  /* 550 */
    {6, 292},  /* 551 */
    {6, 292},  /* 552 */
    {6, 292},  /* 553 */
    {6, 292},  /* 554 */
    {6, 298},  /* 555 */
    {6, 298},  /* 556 */
    {6, 298},  /* 557 */
    {6, 298},  /* 558 */
    {6, 298},  /* 559 */
    {6, 298},  /* 560 */
    {6, 298},  /* 561 */
    {6, 298},  /* 562 */
    {6, 298},  /* 563 */
    {6, 298},  /* 564 */
    {6, 298},  /* 565 */
    {6, 298},  /* 566 */
    {6, 304},  /* 567 */
    {6, 304},  /* 568 */
    {6, 304},  /* 569 */
    {6, 304},  /* 570 */
    {6, 304},  /* 571 */
    {6, 304},  /* 572 */
    {6, 304},  /* 573 */
    {6, 304},  /* 574 */
    {6, 304},  /* 575 */
    {6, 304},  /* 576 */
    {6, 304},  /* 577 */
    {6, 304},  /* 578 */
    {3, 310},  /* 579 */
    {3, 310},  /* 580 */
    {3, 310},  /* 581 */
    {3, 310},  /* 582 */
    {3, 310},  /* 583 */
    {3, 310},  /* 584 */
    {3, 310},  /* 585 */
    {3, 310},  /* 586 */
    {3, 310},  /* 587 */
    {3, 310},  /* 588 */
    {3, 313},  /* 589 */
    {3, 313},  /* 590 */
    {3, 313},  /* 591 */
    {3, 313},  /* 592 */
    {3, 313},  /* 593 */
    {3, 313},  /* 594 */
    {3, 313},  /* 595 */
    {3, 313},  /* 596 */
    {3, 313},  /* 597 */
    {3, 313},  /* 598 */
    {6, 316},  /* 599 */
    {6, 316},  /* 600 */
    {6, 316},  /* 601 */
    {6, 316},  /* 602 */
    {6, 316},  /* 603 */
    {6, 316},  /* 604 */
    {6, 316},  /* 605 */
    {6, 316},  /* 606 */
    {6, 316},  /* 607 */
    {6, 316},  /* 608 */
    {12, 322}, /* 609 */
    {12, 322}, /* 610 */
    {12, 322}, /* 611 */
    {12, 322}, /* 612 */
    {12, 322}, /* 613 */
    {12, 322}, /* 614 */
    {12, 322}, /* 615 */
    {12, 322}, /* 616 */
    {12, 322}, /* 617 */
    {12, 322}, /* 618 */
    {1, 334},  /* 619 */
    {1, 334},  /* 620 */
    {1, 334},  /* 621 */
    {1, 334},  /* 622 */
    {1, 334},  /* 623 */
    {1, 334},  /* 624 */
    {2, 335},  /* 625 */
    {2, 335},  /* 626 */
    {2, 335},  /* 627 */
    {2, 335},  /* 628 */
    {2, 335},  /* 629 */
    {2, 335},  /* 630 */
    {1, 337},  /* 631 */
    {1, 337},  /* 632 */
    {1, 337},  /* 633 */
    {1, 337},  /* 634 */
    {1, 337},  /* 635 */
    {1, 337},  /* 636 */
    {3, 338},  /* 637 */
    {3, 338},  /* 638 */
    {3, 338},  /* 639 */
    {3, 338},  /* 640 */
    {3, 338},  /* 641 */
    {3, 338},  /* 642 */
    {3, 338},  /* 643 */
    {3, 338},  /* 644 */
    {3, 338},  /* 645 */
    {2, 341},  /* 646 */
    {2, 341},  /* 647 */
    {2, 341},  /* 648 */
    {2, 341},  /* 649 */
    {2, 341},  /* 650 */
    {2, 341},  /* 651 */
    {6, 343},  /* 652 */
    {6, 343},  /* 653 */
    {6, 343},  /* 654 */
    {6, 343},  /* 655 */
    {6, 343},  /* 656 */
    {6, 343},  /* 657 */
    {6, 343},  /* 658 */
    {6, 343},  /* 659 */
    {6, 343},  /* 660 */
    {1, 349},  /* 661 */
    {1, 349},  /* 662 */
    {1, 349},  /* 663 */
    {1, 349},  /* 664 */
    {1, 349},  /* 665 */
    {1, 349},  /* 666 */
    {1, 350},  /* 667 */
    {1, 350},  /* 668 */
    {1, 350},  /* 669 */
    {1, 350},  /* 670 */
    {1, 350},  /* 671 */
    {1, 350},  /* 672 */
    {1, 351},  /* 673 */
    {1, 351},  /* 674 */
    {1, 351},  /* 675 */
    {1, 351},  /* 676 */
    {1, 351},  /* 677 */
    {1, 351},  /* 678 */
    {1, 352},  /* 679 */
    {1, 352},  /* 680 */
    {1, 352},  /* 681 */
    {1, 352},  /* 682 */
    {1, 352},  /* 683 */
    {1, 352},  /* 684 */
    {1, 353},  /* 685 */
    {1, 353},  /* 686 */
    {1, 353},  /* 687 */
    {1, 353},  /* 688 */
    {1, 354},  /* 689 */
    {1, 354},  /* 690 */
    {1, 354},  /* 691 */
    {1, 354},  /* 692 */
    {1, 355},  /* 693 */
    {1, 355},  /* 694 */
    {1, 355},  /* 695 */
    {1, 355},  /* 696 */
    {1, 355},  /* 697 */
    {1, 355},  /* 698 */
    {1, 356},  /* 699 */
    {1, 356},  /* 700 */
    {1, 356},  /* 701 */
    {1, 356},  /* 702 */
    {1, 357},  /* 703 */
    {1, 357},  /* 704 */
    {1, 357},  /* 705 */
    {1, 357},  /* 706 */
    {1, 357},  /* 707 */
    {1, 357},  /* 708 */
    {1, 357},  /* 709 */
    {1, 357},  /* 710 */
    {1, 358},  /* 711 */
    {1, 358},  /* 712 */
    {1, 358},  /* 713 */
    {1, 358},  /* 714 */
    {1, 358},  /* 715 */
    {1, 358},  /* 716 */
    {1, 358},  /* 717 */
    {1, 358},  /* 718 */
    {2, 359},  /* 719 */
    {2, 359},  /* 720 */
    {2, 359},  /* 721 */
    {2, 359},  /* 722 */
    {2, 359},  /* 723 */
    {2, 359},  /* 724 */
    {2, 359},  /* 725 */
    {2, 359},  /* 726 */
    {2, 361},  /* 727 */
    {2, 361},  /* 728 */
    {2, 361},  /* 729 */
    {2, 361},  /* 730 */
    {2, 361},  /* 731 */
    {2, 361},  /* 732 */
    {2, 361},  /* 733 */
    {2, 361},  /* 734 */
    {1, 363},  /* 735 */
    {1, 363},  /* 736 */
    {1, 363},  /* 737 */
    {1, 363},  /* 738 */
    {1, 363},  /* 739 */
    {1, 363},  /* 740 */
    {2, 364},  /* 741 */
    {2, 364},  /* 742 */
    {2, 364},  /* 743 */
    {2, 364},  /* 744 */
    {2, 364},  /* 745 */
    {2, 364},  /* 746 */
    {1, 366},  /* 747 */
    {1, 366},  /* 748 */
    {1, 366},  /* 749 */
    {1, 366},  /* 750 */
    {1, 366},  /* 751 */
    {1, 366},  /* 752 */
    {1, 366},  /* 753 */
    {1, 366},  /* 754 */
    {1, 367},  /* 755 */
    {1, 367},  /* 756 */
    {1, 367},  /* 757 */
    {1, 367},  /* 758 */
    {1, 367},  /* 759 */
    {1, 367},  /* 760 */
    {1, 367},  /* 761 */
    {1, 367},  /* 762 */
    {1, 368},  /* 763 */
    {1, 368},  /* 764 */
    {1, 368},  /* 765 */
    {1, 368},  /* 766 */
    {1, 368},  /* 767 */
    {1, 368},  /* 768 */
    {1, 368},  /* 769 */
    {1, 368},  /* 770 */
    {1, 369},  /* 771 */
    {1, 369},  /* 772 */
    {1, 369},  /* 773 */
    {1, 369},  /* 774 */
    {1, 369},  /* 775 */
    {1, 369},  /* 776 */
    {1, 369},  /* 777 */
    {1, 369},  /* 778 */
    {1, 370},  /* 779 */
    {1, 370},  /* 780 */
    {1, 370},  /* 781 */
    {1, 370},  /* 782 */
    {1, 370},  /* 783 */
    {1, 370},  /* 784 */
    {1, 370},  /* 785 */
    {1, 370},  /* 786 */
    {1, 371},  /* 787 */
    {1, 371},  /* 788 */
    {1, 371},  /* 789 */
    {1, 371},  /* 790 */
    {1, 371},  /* 791 */
    {1, 371},  /* 792 */
    {1, 371},  /* 793 */
    {1, 371},  /* 794 */
    {1, 372},  /* 795 */
    {1, 372},  /* 796 */
    {1, 372},  /* 797 */
    {1, 372},  /* 798 */
    {1, 372},  /* 799 */
    {1, 372},  /* 800 */
    {1, 372},  /* 801 */
    {1, 372},  /* 802 */
    {1, 373},  /* 803 */
    {1, 373},  /* 804 */
    {1, 373},  /* 805 */
    {1, 373},  /* 806 */
    {1, 373},  /* 807 */
    {1, 373},  /* 808 */
    {1, 373},  /* 809 */
    {1, 373},  /* 810 */
    {1, 374},  /* 811 */
    {1, 374},  /* 812 */
    {1, 374},  /* 813 */
    {1, 374},  /* 814 */
    {1, 374},  /* 815 */
    {1, 374},  /* 816 */
    {1, 375},  /* 817 */
    {1, 375},  /* 818 */
    {1, 375},  /* 819 */
    {1, 375},  /* 820 */
    {1, 375},  /* 821 */
    {1, 375},  /* 822 */
    {1, 376},  /* 823 */
    {1, 376},  /* 824 */
    {1, 376},  /* 825 */
    {1, 376},  /* 826 */
    {1, 376},  /* 827 */
    {1, 376},  /* 828 */
    {1, 376},  /* 829 */
    {1, 376},  /* 830 */
    {1, 377},  /* 831 */
    {1, 377},  /* 832 */
    {1, 377},  /* 833 */
    {1, 377},  /* 834 */
    {1, 377},  /* 835 */
    {1, 377},  /* 836 */
    {1, 377},  /* 837 */
    {1, 377},  /* 838 */
    {1, 378},  /* 839 */
    {1, 378},  /* 840 */
    {1, 378},  /* 841 */
    {1, 378},  /* 842 */
    {1, 378},  /* 843 */
    {1, 378},  /* 844 */
    {1, 378},  /* 845 */
    {1, 378},  /* 846 */
    {1, 379},  /* 847 */
    {1, 379},  /* 848 */
    {1, 379},  /* 849 */
    {1, 379},  /* 850 */
    {1, 379},  /* 851 */
    {1, 379},  /* 852 */
    {1, 379},  /* 853 */
    {1, 379},  /* 854 */
    {1, 380},  /* 855 */
    {1, 380},  /* 856 */
    {1, 380},  /* 857 */
    {1, 380},  /* 858 */
    {1, 380},  /* 859 */
    {1, 380},  /* 860 */
    {1, 380},  /* 861 */
    {1, 380},  /* 862 */
    {1, 381},  /* 863 */
    {1, 381},  /* 864 */
    {1, 381},  /* 865 */
    {1, 381},  /* 866 */
    {1, 381},  /* 867 */
    {1, 381},  /* 868 */
    {1, 381},  /* 869 */
    {1, 381},  /* 870 */
    {1, 382},  /* 871 */
    {1, 382},  /* 872 */
    {1, 382},  /* 873 */
    {1, 382},  /* 874 */
    {1, 382},  /* 875 */
    {1, 382},  /* 876 */
    {1, 382},  /* 877 */
    {1, 382},  /* 878 */
    {1, 383},  /* 879 */
    {1, 383},  /* 880 */
    {1, 383},  /* 881 */
    {1, 383},  /* 882 */
    {1, 383},  /* 883 */
    {1, 383},  /* 884 */
    {1, 383},  /* 885 */
    {1, 383},  /* 886 */
    {1, 384},  /* 887 */
    {1, 384},  /* 888 */
    {1, 384},  /* 889 */
    {1, 384},  /* 890 */
    {1, 384},  /* 891 */
    {1, 384},  /* 892 */
    {1, 385},  /* 893 */
    {1, 385},  /* 894 */
    {1, 385},  /* 895 */
    {1, 385},  /* 896 */
    {1, 385},  /* 897 */
    {1, 385},  /* 898 */
    {1, 386},  /* 899 */
    {1, 386},  /* 900 */
    {1, 386},  /* 901 */
    {1, 386},  /* 902 */
    {1, 386},  /* 903 */
    {1, 386},  /* 904 */
    {1, 387},  /* 905 */
    {1, 387},  /* 906 */
    {1, 387},  /* 907 */
    {1, 387},  /* 908 */
    {1, 387},  /* 909 */
    {1, 387},  /* 910 */
    {1, 388},  /* 911 */
    {1, 388},  /* 912 */
    {1, 388},  /* 913 */
    {1, 388},  /* 914 */
    {1, 388},  /* 915 */
    {1, 388},  /* 916 */
    {1, 388},  /* 917 */
    {1, 388},  /* 918 */
    {1, 389},  /* 919 */
    {1, 389},  /* 920 */
    {1, 389},  /* 921 */
    {1, 389},  /* 922 */
    {1, 389},  /* 923 */
    {1, 389},  /* 924 */
    {1, 389},  /* 925 */
    {1, 389},  /* 926 */
    {1, 390},  /* 927 */
    {1, 390},  /* 928 */
    {1, 390},  /* 929 */
    {1, 390},  /* 930 */
    {1, 390},  /* 931 */
    {1, 390},  /* 932 */
    {1, 390},  /* 933 */
    {1, 390},  /* 934 */
    {1, 391},  /* 935 */
    {1, 391},  /* 936 */
    {1, 391},  /* 937 */
    {1, 391},  /* 938 */
    {1, 391},  /* 939 */
    {1, 391},  /* 940 */
    {1, 391},  /* 941 */
    {1, 391},  /* 942 */
    {1, 392},  /* 943 */
    {1, 392},  /* 944 */
    {1, 392},  /* 945 */
    {1, 392},  /* 946 */
    {1, 392},  /* 947 */
    {1, 392},  /* 948 */
    {1, 392},  /* 949 */
    {1, 392},  /* 950 */
    {1, 393},  /* 951 */
    {1, 393},  /* 952 */
    {1, 393},  /* 953 */
    {1, 393},  /* 954 */
    {1, 393},  /* 955 */
    {1, 393},  /* 956 */
    {1, 393},  /* 957 */
    {1, 393},  /* 958 */
    {1, 394},  /* 959 */
    {1, 394},  /* 960 */
    {1, 394},  /* 961 */
    {1, 394},  /* 962 */
    {1, 394},  /* 963 */
    {1, 394},  /* 964 */
    {1, 394},  /* 965 */
    {1, 394},  /* 966 */
    {1, 395},  /* 967 */
    {1, 395},  /* 968 */
    {1, 395},  /* 969 */
    {1, 395},  /* 970 */
    {1, 395},  /* 971 */
    {1, 395},  /* 972 */
    {1, 395},  /* 973 */
    {1, 395},  /* 974 */
    {1, 396},  /* 975 */
    {1, 396},  /* 976 */
    {1, 396},  /* 977 */
    {1, 396},  /* 978 */
    {1, 396},  /* 979 */
    {1, 396},  /* 980 */
    {1, 397},  /* 981 */
    {1, 397},  /* 982 */
    {1, 397},  /* 983 */
    {1, 397},  /* 984 */
    {1, 397},  /* 985 */
    {1, 397},  /* 986 */
    {1, 398},  /* 987 */
    {1, 398},  /* 988 */
    {1, 398},  /* 989 */
    {1, 398},  /* 990 */
    {1, 398},  /* 991 */
    {1, 398},  /* 992 */
    {1, 399},  /* 993 */
    {1, 399},  /* 994 */
    {1, 399},  /* 995 */
    {1, 399},  /* 996 */
    {1, 399},  /* 997 */
    {1, 399},  /* 998 */
    {1, 400},  /* 999 */
    {1, 400},  /* 1000 */
    {1, 400},  /* 1001 */
    {1, 400},  /* 1002 */
    {1, 400},  /* 1003 */
    {1, 400},  /* 1004 */
    {1, 400},  /* 1005 */
    {1, 400},  /* 1006 */
    {1, 400},  /* 1007 */
    {1, 400},  /* 1008 */
    {1, 400},  /* 1009 */
    {1, 400},  /* 1010 */
    {1, 401},  /* 1011 */
    {1, 401},  /* 1012 */
    {1, 401},  /* 1013 */
    {1, 401},  /* 1014 */
    {1, 401},  /* 1015 */
    {1, 401},  /* 1016 */
    {1, 401},  /* 1017 */
    {1, 401},  /* 1018 */
    {1, 401},  /* 1019 */
    {1, 401},  /* 1020 */
    {1, 401},  /* 1021 */
    {1, 401},  /* 1022 */
    {2, 402},  /* 1023 */
    {2, 402},  /* 1024 */
    {2, 402},  /* 1025 */
    {2, 402},  /* 1026 */
    {2, 402},  /* 1027 */
    {2, 402},  /* 1028 */
    {2, 402},  /* 1029 */
    {2, 402},  /* 1030 */
    {2, 402},  /* 1031 */
    {2, 402},  /* 1032 */
    {2, 402},  /* 1033 */
    {2, 402},  /* 1034 */
    {2, 404},  /* 1035 */
    {2, 404},  /* 1036 */
    {2, 404},  /* 1037 */
    {2, 404},  /* 1038 */
    {2, 404},  /* 1039 */
    {2, 404},  /* 1040 */
    {2, 404},  /* 1041 */
    {2, 404},  /* 1042 */
    {2, 404},  /* 1043 */
    {2, 404},  /* 1044 */
    {2, 404},  /* 1045 */
    {2, 404},  /* 1046 */
    {1, 406},  /* 1047 */
    {1, 406},  /* 1048 */
    {1, 406},  /* 1049 */
    {1, 406},  /* 1050 */
    {1, 406},  /* 1051 */
    {1, 406},  /* 1052 */
    {1, 406},  /* 1053 */
    {1, 406},  /* 1054 */
    {1, 406},  /* 1055 */
    {1, 406},  /* 1056 */
    {1, 406},  /* 1057 */
    {1, 406},  /* 1058 */
    {1, 407},  /* 1059 */
    {1, 407},  /* 1060 */
    {1, 407},  /* 1061 */
    {1, 407},  /* 1062 */
    {1, 407},  /* 1063 */
    {1, 407},  /* 1064 */
    {1, 407},  /* 1065 */
    {1, 407},  /* 1066 */
    {1, 407},  /* 1067 */
    {1, 407},  /* 1068 */
    {1, 407},  /* 1069 */
    {1, 407},  /* 1070 */
    {2, 408},  /* 1071 */
    {2, 408},  /* 1072 */
    {2, 408},  /* 1073 */
    {2, 408},  /* 1074 */
    {2, 408},  /* 1075 */
    {2, 408},  /* 1076 */
    {2, 408},  /* 1077 */
    {2, 408},  /* 1078 */
    {2, 408},  /* 1079 */
    {2, 408},  /* 1080 */
    {2, 408},  /* 1081 */
    {2, 408},  /* 1082 */
    {2, 410},  /* 1083 */
    {2, 410},  /* 1084 */
    {2, 410},  /* 1085 */
    {2, 410},  /* 1086 */
    {2, 410},  /* 1087 */
    {2, 410},  /* 1088 */
    {2, 410},  /* 1089 */
    {2, 410},  /* 1090 */
    {2, 410},  /* 1091 */
    {2, 410},  /* 1092 */
    {2, 410},  /* 1093 */
    {2, 410},  /* 1094 */
    {1, 412},  /* 1095 */
    {1, 412},  /* 1096 */
    {1, 412},  /* 1097 */
    {1, 412},  /* 1098 */
    {1, 412},  /* 1099 */
    {1, 412},  /* 1100 */
    {1, 412},  /* 1101 */
    {1, 412},  /* 1102 */
    {1, 412},  /* 1103 */
    {1, 412},  /* 1104 */
    {1, 412},  /* 1105 */
    {1, 412},  /* 1106 */
    {1, 413},  /* 1107 */
    {1, 413},  /* 1108 */
    {1, 413},  /* 1109 */
    {1, 413},  /* 1110 */
    {1, 413},  /* 1111 */
    {1, 413},  /* 1112 */
    {1, 413},  /* 1113 */
    {1, 413},  /* 1114 */
    {1, 413},  /* 1115 */
    {1, 413},  /* 1116 */
    {1, 413},  /* 1117 */
    {1, 413},  /* 1118 */
    {2, 414},  /* 1119 */
    {2, 414},  /* 1120 */
    {2, 414},  /* 1121 */
    {2, 414},  /* 1122 */
    {2, 414},  /* 1123 */
    {2, 414},  /* 1124 */
    {2, 414},  /* 1125 */
    {2, 414},  /* 1126 */
    {2, 414},  /* 1127 */
    {2, 414},  /* 1128 */
    {2, 414},  /* 1129 */
    {2, 414},  /* 1130 */
    {2, 416},  /* 1131 */
    {2, 416},  /* 1132 */
    {2, 416},  /* 1133 */
    {2, 416},  /* 1134 */
    {2, 416},  /* 1135 */
    {2, 416},  /* 1136 */
    {2, 416},  /* 1137 */
    {2, 416},  /* 1138 */
    {2, 416},  /* 1139 */
    {2, 416},  /* 1140 */
    {2, 416},  /* 1141 */
    {2, 416},  /* 1142 */
    {1, 418},  /* 1143 */
    {1, 418},  /* 1144 */
    {1, 418},  /* 1145 */
    {1, 418},  /* 1146 */
    {1, 418},  /* 1147 */
    {1, 418},  /* 1148 */
    {1, 418},  /* 1149 */
    {1, 418},  /* 1150 */
    {1, 418},  /* 1151 */
    {1, 418},  /* 1152 */
    {1, 418},  /* 1153 */
    {1, 418},  /* 1154 */
    {1, 419},  /* 1155 */
    {1, 419},  /* 1156 */
    {1, 419},  /* 1157 */
    {1, 419},  /* 1158 */
    {1, 419},  /* 1159 */
    {1, 419},  /* 1160 */
    {1, 419},  /* 1161 */
    {1, 419},  /* 1162 */
    {1, 419},  /* 1163 */
    {1, 419},  /* 1164 */
    {1, 419},  /* 1165 */
    {1, 419},  /* 1166 */
    {2, 420},  /* 1167 */
    {2, 420},  /* 1168 */
    {2, 420},  /* 1169 */
    {2, 420},  /* 1170 */
    {2, 420},  /* 1171 */
    {2, 420},  /* 1172 */
    {2, 420},  /* 1173 */
    {2, 420},  /* 1174 */
    {2, 420},  /* 1175 */
    {2, 420},  /* 1176 */
    {2, 420},  /* 1177 */
    {2, 420},  /* 1178 */
    {2, 422},  /* 1179 */
    {2, 422},  /* 1180 */
    {2, 422},  /* 1181 */
    {2, 422},  /* 1182 */
    {2, 422},  /* 1183 */
    {2, 422},  /* 1184 */
    {2, 422},  /* 1185 */
    {2, 422},  /* 1186 */
    {2, 422},  /* 1187 */
    {2, 422},  /* 1188 */
    {2, 422},  /* 1189 */
    {2, 422},  /* 1190 */
    {1, 424},  /* 1191 */
    {1, 424},  /* 1192 */
    {1, 424},  /* 1193 */
    {1, 424},  /* 1194 */
    {1, 424},  /* 1195 */
    {1, 424},  /* 1196 */
    {1, 424},  /* 1197 */
    {1, 424},  /* 1198 */
    {1, 424},  /* 1199 */
    {1, 424},  /* 1200 */
    {1, 425},  /* 1201 */
    {1, 425},  /* 1202 */
    {1, 425},  /* 1203 */
    {1, 425},  /* 1204 */
    {1, 425},  /* 1205 */
    {1, 425},  /* 1206 */
    {1, 425},  /* 1207 */
    {1, 425},  /* 1208 */
    {1, 425},  /* 1209 */
    {1, 425},  /* 1210 */
    {2, 426},  /* 1211 */
    {2, 426},  /* 1212 */
    {2, 426},  /* 1213 */
    {2, 426},  /* 1214 */
    {2, 426},  /* 1215 */
    {2, 426},  /* 1216 */
    {2, 426},  /* 1217 */
    {2, 426},  /* 1218 */
    {2, 426},  /* 1219 */
    {2, 426},  /* 1220 */
    {2, 428},  /* 1221 */
    {2, 428},  /* 1222 */
    {2, 428},  /* 1223 */
    {2, 428},  /* 1224 */
    {2, 428},  /* 1225 */
    {2, 428},  /* 1226 */
    {2, 428},  /* 1227 */
    {2, 428},  /* 1228 */
    {2, 428},  /* 1229 */
    {2, 428},  /* 1230 */
    {1, 430},  /* 1231 */
    {1, 430},  /* 1232 */
    {1, 430},  /* 1233 */
    {1, 431},  /* 1234 */
    {1, 431},  /* 1235 */
    {1, 431},  /* 1236 */
    {1, 432},  /* 1237 */
    {1, 432},  /* 1238 */
    {1, 432},  /* 1239 */
    {2, 433},  /* 1240 */
    {2, 433},  /* 1241 */
    {2, 433},  /* 1242 */
    {1, 435},  /* 1243 */
    {1, 435},  /* 1244 */
    {1, 435},  /* 1245 */
    {1, 435},  /* 1246 */
    {2, 436},  /* 1247 */
    {2, 436},  /* 1248 */
    {2, 436},  /* 1249 */
    {2, 436},  /* 1250 */
    {1, 438},  /* 1251 */
    {1, 438},  /* 1252 */
    {1, 438},  /* 1253 */
    {1, 438},  /* 1254 */
    {1, 439},  /* 1255 */
    {1, 439},  /* 1256 */
    {1, 439},  /* 1257 */
    {1, 439},  /* 1258 */
    {1, 440},  /* 1259 */
    {1, 440},  /* 1260 */
    {1, 440},  /* 1261 */
    {1, 440},  /* 1262 */
    {1, 441},  /* 1263 */
    {1, 441},  /* 1264 */
    {1, 441},  /* 1265 */
    {1, 441},  /* 1266 */
    {1, 442},  /* 1267 */
    {1, 442},  /* 1268 */
    {1, 442},  /* 1269 */
    {1, 442},  /* 1270 */
    {1, 443},  /* 1271 */
    {1, 443},  /* 1272 */
    {1, 443},  /* 1273 */
    {1, 443},  /* 1274 */
    {2, 444},  /* 1275 */
    {2, 444},  /* 1276 */
    {2, 444},  /* 1277 */
    {2, 444},  /* 1278 */
    {1, 446},  /* 1279 */
    {1, 446},  /* 1280 */
    {1, 446},  /* 1281 */
    {1, 446},  /* 1282 */
    {1, 447},  /* 1283 */
    {1, 447},  /* 1284 */
    {1, 447},  /* 1285 */
    {1, 447},  /* 1286 */
    {1, 448},  /* 1287 */
    {1, 448},  /* 1288 */
    {1, 448},  /* 1289 */
    {1, 448},  /* 1290 */
    {1, 449},  /* 1291 */
    {1, 449},  /* 1292 */
    {1, 449},  /* 1293 */
    {1, 449},  /* 1294 */
    {2, 450},  /* 1295 */
    {2, 450},  /* 1296 */
    {2, 450},  /* 1297 */
    {2, 450},  /* 1298 */
    {2, 452},  /* 1299 */
    {2, 452},  /* 1300 */
    {2, 452},  /* 1301 */
    {2, 452},  /* 1302 */
    {1, 454},  /* 1303 */
    {1, 454},  /* 1304 */
    {1, 454},  /* 1305 */
    {1, 454},  /* 1306 */
    {1, 454},  /* 1307 */
    {1, 454},  /* 1308 */
    {1, 455},  /* 1309 */
    {1, 455},  /* 1310 */
    {1, 455},  /* 1311 */
    {1, 455},  /* 1312 */
    {1, 455},  /* 1313 */
    {1, 455},  /* 1314 */
    {1, 456},  /* 1315 */
    {1, 456},  /* 1316 */
    {1, 456},  /* 1317 */
    {1, 456},  /* 1318 */
    {1, 456},  /* 1319 */
    {1, 456},  /* 1320 */
    {1, 457},  /* 1321 */
    {1, 457},  /* 1322 */
    {1, 457},  /* 1323 */
    {1, 457},  /* 1324 */
    {1, 457},  /* 1325 */
    {1, 457},  /* 1326 */
    {2, 458},  /* 1327 */
    {2, 458},  /* 1328 */
    {2, 458},  /* 1329 */
    {2, 458},  /* 1330 */
    {2, 458},  /* 1331 */
    {2, 458},  /* 1332 */
    {2, 460},  /* 1333 */
    {2, 460},  /* 1334 */
    {2, 460},  /* 1335 */
    {2, 460},  /* 1336 */
    {2, 460},  /* 1337 */
    {2, 460},  /* 1338 */
    {1, 462},  /* 1339 */
    {1, 462},  /* 1340 */
    {1, 462},  /* 1341 */
    {1, 462},  /* 1342 */
    {1, 463},  /* 1343 */
    {1, 463},  /* 1344 */
    {1, 463},  /* 1345 */
    {1, 463},  /* 1346 */
    {1, 464},  /* 1347 */
    {1, 464},  /* 1348 */
    {1, 464},  /* 1349 */
    {1, 464},  /* 1350 */
    {1, 465},  /* 1351 */
    {1, 465},  /* 1352 */
    {1, 465},  /* 1353 */
    {1, 465},  /* 1354 */
    {1, 466},  /* 1355 */
    {1, 466},  /* 1356 */
    {1, 466},  /* 1357 */
    {1, 466},  /* 1358 */
    {1, 467},  /* 1359 */
    {1, 467},  /* 1360 */
    {1, 467},  /* 1361 */
    {1, 467},  /* 1362 */
    {1, 468},  /* 1363 */
    {1, 468},  /* 1364 */
    {1, 468},  /* 1365 */
    {1, 468},  /* 1366 */
    {1, 469},  /* 1367 */
    {1, 469},  /* 1368 */
    {1, 469},  /* 1369 */
    {1, 469},  /* 1370 */
    {1, 469},  /* 1371 */
    {1, 469},  /* 1372 */
    {1, 470},  /* 1373 */
    {1, 470},  /* 1374 */
    {1, 470},  /* 1375 */
    {1, 470},  /* 1376 */
    {1, 470},  /* 1377 */
    {1, 470},  /* 1378 */
    {1, 471},  /* 1379 */
    {1, 471},  /* 1380 */
    {1, 471},  /* 1381 */
    {1, 471},  /* 1382 */
    {1, 471},  /* 1383 */
    {1, 471},  /* 1384 */
    {1, 472},  /* 1385 */
    {1, 472},  /* 1386 */
    {1, 472},  /* 1387 */
    {1, 472},  /* 1388 */
    {1, 472},  /* 1389 */
    {1, 472},  /* 1390 */
    {1, 473},  /* 1391 */
    {1, 473},  /* 1392 */
    {1, 473},  /* 1393 */
    {1, 473},  /* 1394 */
    {1, 473},  /* 1395 */
    {1, 473},  /* 1396 */
    {1, 474},  /* 1397 */
    {1, 474},  /* 1398 */
    {1, 474},  /* 1399 */
    {1, 474},  /* 1400 */
    {1, 474},  /* 1401 */
    {1, 474},  /* 1402 */
    {1, 475},  /* 1403 */
    {1, 475},  /* 1404 */
    {1, 475},  /* 1405 */
    {1, 475},  /* 1406 */
    {1, 475},  /* 1407 */
    {1, 475},  /* 1408 */
    {1, 476},  /* 1409 */
    {1, 476},  /* 1410 */
    {1, 476},  /* 1411 */
    {1, 476},  /* 1412 */
    {1, 476},  /* 1413 */
    {1, 476},  /* 1414 */
    {1, 477},  /* 1415 */
    {1, 477},  /* 1416 */
    {1, 477},  /* 1417 */
    {1, 477},  /* 1418 */
    {1, 477},  /* 1419 */
    {1, 477},  /* 1420 */
    {1, 478},  /* 1421 */
    {1, 478},  /* 1422 */
    {1, 478},  /* 1423 */
    {1, 478},  /* 1424 */
    {1, 478},  /* 1425 */
    {1, 478},  /* 1426 */
    {1, 479},  /* 1427 */
    {1, 479},  /* 1428 */
    {1, 479},  /* 1429 */
    {1, 479},  /* 1430 */
    {1, 479},  /* 1431 */
    {1, 479},  /* 1432 */
    {1, 480},  /* 1433 */
    {1, 480},  /* 1434 */
    {1, 480},  /* 1435 */
    {1, 480},  /* 1436 */
    {1, 480},  /* 1437 */
    {1, 480},  /* 1438 */
    {1, 481},  /* 1439 */
    {1, 481},  /* 1440 */
    {1, 481},  /* 1441 */
    {1, 481},  /* 1442 */
    {1, 481},  /* 1443 */
    {1, 481},  /* 1444 */
    {1, 482},  /* 1445 */
    {1, 482},  /* 1446 */
    {1, 482},  /* 1447 */
    {1, 482},  /* 1448 */
    {1, 482},  /* 1449 */
    {1, 482},  /* 1450 */
    {1, 483},  /* 1451 */
    {1, 483},  /* 1452 */
    {1, 483},  /* 1453 */
    {1, 483},  /* 1454 */
    {1, 483},  /* 1455 */
    {1, 483},  /* 1456 */
    {1, 484},  /* 1457 */
    {1, 484},  /* 1458 */
    {1, 484},  /* 1459 */
    {1, 484},  /* 1460 */
    {1, 484},  /* 1461 */
    {1, 484},  /* 1462 */
    {1, 485},  /* 1463 */
    {1, 485},  /* 1464 */
    {1, 485},  /* 1465 */
    {1, 485},  /* 1466 */
    {1, 485},  /* 1467 */
    {1, 485},  /* 1468 */
    {1, 485},  /* 1469 */
    {1, 485},  /* 1470 */
    {1, 485},  /* 1471 */
    {1, 485},  /* 1472 */
    {1, 486},  /* 1473 */
    {1, 486},  /* 1474 */
    {1, 486},  /* 1475 */
    {1, 486},  /* 1476 */
    {1, 486},  /* 1477 */
    {1, 486},  /* 1478 */
    {1, 486},  /* 1479 */
    {1, 486},  /* 1480 */
    {1, 486},  /* 1481 */
    {1, 486},  /* 1482 */
    {1, 487},  /* 1483 */
    {1, 487},  /* 1484 */
    {1, 487},  /* 1485 */
    {1, 487},  /* 1486 */
    {1, 487},  /* 1487 */
    {1, 487},  /* 1488 */
    {1, 487},  /* 1489 */
    {1, 487},  /* 1490 */
    {1, 487},  /* 1491 */
    {1, 487},  /* 1492 */
    {1, 488},  /* 1493 */
    {1, 488},  /* 1494 */
    {1, 488},  /* 1495 */
    {1, 488},  /* 1496 */
    {1, 488},  /* 1497 */
    {1, 488},  /* 1498 */
    {1, 488},  /* 1499 */
    {1, 488},  /* 1500 */
    {1, 488},  /* 1501 */
    {1, 488},  /* 1502 */
    {1, 489},  /* 1503 */
    {1, 489},  /* 1504 */
    {1, 489},  /* 1505 */
    {1, 490},  /* 1506 */
    {1, 490},  /* 1507 */
    {1, 490},  /* 1508 */
    {1, 491},  /* 1509 */
    {1, 491},  /* 1510 */
    {1, 492},  /* 1511 */
    {1, 492},  /* 1512 */
    {1, 492},  /* 1513 */
    {1, 493},  /* 1514 */
    {1, 493},  /* 1515 */
    {1, 494},  /* 1516 */
    {1, 494},  /* 1517 */
    {1, 494},  /* 1518 */
    {1, 494},  /* 1519 */
    {2, 495},  /* 1520 */
    {2, 495},  /* 1521 */
    {2, 495},  /* 1522 */
    {2, 495},  /* 1523 */
    {1, 497},  /* 1524 */
    {1, 497},  /* 1525 */
    {1, 497},  /* 1526 */
    {1, 497},  /* 1527 */
    {2, 498},  /* 1528 */
    {2, 498},  /* 1529 */
    {2, 498},  /* 1530 */
    {2, 498},  /* 1531 */
    {1, 500},  /* 1532 */
    {1, 500},  /* 1533 */
    {1, 500},  /* 1534 */
    {1, 501},  /* 1535 */
    {1, 501},  /* 1536 */
    {1, 501},  /* 1537 */
    {1, 501},  /* 1538 */
    {1, 502},  /* 1539 */
    {1, 502},  /* 1540 */
    {1, 502},  /* 1541 */
    {1, 503},  /* 1542 */
    {1, 503},  /* 1543 */
    {1, 503},  /* 1544 */
    {1, 503},  /* 1545 */
    {1, 504},  /* 1546 */
    {1, 504},  /* 1547 */
    {1, 504},  /* 1548 */
    {1, 504},  /* 1549 */
    {1, 505},  /* 1550 */
    {1, 505},  /* 1551 */
    {1, 505},  /* 1552 */
    {1, 505},  /* 1553 */
    {1, 506},  /* 1554 */
    {1, 506},  /* 1555 */
    {1, 506},  /* 1556 */
    {1, 506},  /* 1557 */
    {1, 507},  /* 1558 */
    {1, 507},  /* 1559 */
    {1, 507},  /* 1560 */
    {1, 508},  /* 1561 */
    {1, 508},  /* 1562 */
    {1, 508},  /* 1563 */
    {1, 508},  /* 1564 */
    {1, 509},  /* 1565 */
    {1, 509},  /* 1566 */
    {1, 509},  /* 1567 */
    {1, 509},  /* 1568 */
    {1, 510},  /* 1569 */
    {1, 510},  /* 1570 */
    {1, 510},  /* 1571 */
    {1, 511},  /* 1572 */
    {1, 511},  /* 1573 */
    {1, 511},  /* 1574 */
    {1, 511},  /* 1575 */
    {1, 512},  /* 1576 */
    {1, 512},  /* 1577 */
    {1, 512},  /* 1578 */
    {1, 512},  /* 1579 */
    {1, 513},  /* 1580 */
    {1, 513},  /* 1581 */
    {1, 513},  /* 1582 */
    {1, 514},  /* 1583 */
    {1, 514},  /* 1584 */
    {1, 514},  /* 1585 */
    {1, 514},  /* 1586 */
    {1, 515},  /* 1587 */
    {1, 515},  /* 1588 */
    {1, 515},  /* 1589 */
    {1, 515},  /* 1590 */
    {1, 516},  /* 1591 */
    {1, 516},  /* 1592 */
    {1, 516},  /* 1593 */
    {1, 517},  /* 1594 */
    {1, 517},  /* 1595 */
    {1, 517},  /* 1596 */
    {1, 517},  /* 1597 */
    {1, 517},  /* 1598 */
    {1, 517},  /* 1599 */
    {2, 518},  /* 1600 */
    {2, 518},  /* 1601 */
    {2, 518},  /* 1602 */
    {2, 518},  /* 1603 */
    {2, 518},  /* 1604 */
    {2, 518},  /* 1605 */
    {1, 520},  /* 1606 */
    {1, 520},  /* 1607 */
    {1, 520},  /* 1608 */
    {1, 520},  /* 1609 */
    {1, 520},  /* 1610 */
    {1, 520},  /* 1611 */
    {2, 521},  /* 1612 */
    {2, 521},  /* 1613 */
    {2, 521},  /* 1614 */
    {2, 521},  /* 1615 */
    {2, 521},  /* 1616 */
    {2, 521},  /* 1617 */
    {1, 523},  /* 1618 */
    {1, 523},  /* 1619 */
    {1, 523},  /* 1620 */
    {1, 523},  /* 1621 */
    {1, 523},  /* 1622 */
    {1, 523},  /* 1623 */
    {1, 524},  /* 1624 */
    {1, 524},  /* 1625 */
    {1, 524},  /* 1626 */
    {1, 524},  /* 1627 */
    {1, 524},  /* 1628 */
    {1, 524},  /* 1629 */
    {2, 525},  /* 1630 */
    {2, 525},  /* 1631 */
    {2, 525},  /* 1632 */
    {2, 525},  /* 1633 */
    {2, 525},  /* 1634 */
    {2, 525},  /* 1635 */
    {2, 527},  /* 1636 */
    {2, 527},  /* 1637 */
    {2, 527},  /* 1638 */
    {2, 527},  /* 1639 */
    {2, 527},  /* 1640 */
    {2, 527},  /* 1641 */
    {1, 529},  /* 1642 */
    {1, 529},  /* 1643 */
    {1, 529},  /* 1644 */
    {1, 529},  /* 1645 */
    {1, 529},  /* 1646 */
    {1, 530},  /* 1647 */
    {1, 530},  /* 1648 */
    {1, 530},  /* 1649 */
    {1, 530},  /* 1650 */
    {1, 530},  /* 1651 */
};

/* { order, offset in `magnetic_symmetry_operations` } for each pair of UNI
 * number and Hall number */
static const int magnetic_spacegroup_operation_index[][18][2] = {
    { {0, 0} }, /* dummy */
    { { 1, 1 } }, /* 1 */
    { { 2, 2 } }, /* 2 */
    { { 2, 4 } }, /* 3 */
    { { 2, 6 } }, /* 4 */
    { { 4, 8 } }, /* 5 */
    { { 2, 12 } }, /* 6 */
    { { 4, 14 } }, /* 7 */
    { { 2, 18 }, { 2, 38 }, { 2, 58 } }, /* 8 */
    { { 4, 20 }, { 4, 40 }, { 4, 60 } }, /* 9 */
    { { 2, 24 }, { 2, 44 }, { 2, 64 } }, /* 10 */
    { { 4, 26 }, { 4, 46 }, { 4, 66 } }, /* 11 */
    { { 4, 30 }, { 4, 50 }, { 4, 70 } }, /* 12 */
    { { 4, 34 }, { 4, 54 }, { 4, 74 } }, /* 13 */
    { { 2, 78 }, { 2, 98 }, { 2, 118 } }, /* 14 */
    { { 4, 80 }, { 4, 100 }, { 4, 120 } }, /* 15 */
    { { 2, 84 }, { 2, 104 }, { 2, 124 } }, /* 16 */
    { { 4, 86 }, { 4, 106 }, { 4, 126 } }, /* 17 */
    { { 4, 90 }, { 4, 110 }, { 4, 130 } }, /* 18 */
    { { 4, 94 }, { 4, 114 }, { 4, 134 } }, /* 19 */
    { { 4, 138 }, { 4, 170 }, { 4, 202 }, { 4, 234 }, { 4, 266 }, { 4, 298 }, { 4, 330 }, { 4, 362 }, { 4, 394 } }, /* 20 */
    { { 8, 142 }, { 8, 174 }, { 8, 206 }, { 8, 238 }, { 8, 270 }, { 8, 302 }, { 8, 334 }, { 8, 366 }, { 8, 398 } }, /* 21 */
    { { 4, 150 }, { 4, 182 }, { 4, 214 }, { 4, 246 }, { 4, 278 }, { 4, 310 }, { 4, 342 }, { 4, 374 }, { 4, 406 } }, /* 22 */
    { { 8, 154 }, { 8, 186 }, { 8, 218 }, { 8, 250 }, { 8, 282 }, { 8, 314 }, { 8, 346 }, { 8, 378 }, { 8, 410 } }, /* 23 */
    { { 8, 162 }, { 8, 194 }, { 8, 226 }, { 8, 258 }, { 8, 290 }, { 8, 322 }, { 8, 354 }, { 8, 386 }, { 8, 418 } }, /* 24 */
    { { 2, 426 }, { 2, 446 }, { 2, 466 } }, /* 25 */
    { { 4, 428 }, { 4, 448 }, { 4, 468 } }, /* 26 */
    { { 2, 432 }, { 2, 452 }, { 2, 472 } }, /* 27 */
    { { 4, 434 }, { 4, 454 }, { 4, 474 } }, /* 28 */
    { { 4, 438 }, { 4, 458 }, { 4, 478 } }, /* 29 */
    { { 4, 442 }, { 4, 462 }, { 4, 482 } }, /* 30 */
    { { 2, 486 }, { 2, 514 }, { 2, 542 }, { 2, 570 }, { 2, 598 }, { 2, 626 }, { 2, 654 }, { 2, 682 }, { 2, 710 } }, /* 31 */
    { { 4, 488 }, { 4, 516 }, { 4, 544 }, { 4, 572 }, { 4, 600 }, { 4, 628 }, { 4, 656 }, { 4, 684 }, { 4, 712 } }, /* 32 */
    { { 2, 492 }, { 2, 520 }, { 2, 548 }, { 2, 576 }, { 2, 604 }, { 2, 632 }, { 2, 660 }, { 2, 688 }, { 2, 716 } }, /* 33 */
    { { 4, 494 }, { 4, 522 }, { 4, 550 }, { 4, 578 }, { 4, 606 }, { 4, 634 }, { 4, 662 }, { 4, 690 }, { 4, 718 } }, /* 34 */
    { { 4, 498 }, { 4, 526 }, { 4, 554 }, { 4, 582 }, { 4, 610 }, { 4, 638 }, { 4, 666 }, { 4, 694 }, { 4, 722 } }, /* 35 */
    { { 4, 502 }, { 4, 530 }, { 4, 558 }, { 4, 586 }, { 4, 614 }, { 4, 642 }, { 4, 670 }, { 4, 698 }, { 4, 726 } }, /* 36 */
    { { 4, 506 }, { 4, 534 }, { 4, 562 }, { 4, 590 }, { 4, 618 }, { 4, 646 }, { 4, 674 }, { 4, 702 }, { 4, 730 } }, /* 37 */
    { { 4, 510 }, { 4, 538 }, { 4, 566 }, { 4, 594 }, { 4, 622 }, { 4, 650 }, { 4, 678 }, { 4, 706 }, { 4, 734 } }, /* 38 */
    { { 4, 738 }, { 4, 770 }, { 4, 802 }, { 4, 834 }, { 4, 866 }, { 4, 898 }, { 4, 930 }, { 4, 962 }, { 4, 994 } }, /* 39 */
    { { 8, 742 }, { 8, 774 }, { 8, 806 }, { 8, 838 }, { 8, 870 }, { 8, 902 }, { 8, 934 }, { 8, 966 }, { 8, 998 } }, /* 40 */
    { { 4, 750 }, { 4, 782 }, { 4, 814 }, { 4, 846 }, { 4, 878 }, { 4, 910 }, { 4, 942 }, { 4, 974 }, { 4, 1006 } }, /* 41 */
    { { 8, 754 }, { 8, 786 }, { 8, 818 }, { 8, 850 }, { 8, 882 }, { 8, 914 }, { 8, 946 }, { 8, 978 }, { 8, 1010 } }, /* 42 */
    { { 8, 762 }, { 8, 794 }, { 8, 826 }, { 8, 858 }, { 8, 890 }, { 8, 922 }, { 8, 954 }, { 8, 986 }, { 8, 1018 } }, /* 43 */
    { { 4, 1026 }, { 4, 1058 }, { 4, 1090 }, { 4, 1122 }, { 4, 1154 }, { 4, 1186 }, { 4, 1218 }, { 4, 1250 }, { 4, 1282 }, { 4, 1314 }, { 4, 1346 }, { 4, 1378 }, { 4, 1410 }, { 4, 1442 }, { 4, 1474 }, { 4, 1506 }, { 4, 1538 }, { 4, 1570 } }, /* 44 */
    { { 8, 1030 }, { 8, 1062 }, { 8, 1094 }, { 8, 1126 }, { 8, 1158 }, { 8, 1190 }, { 8, 1222 }, { 8, 1254 }, { 8, 1286 }, { 8, 1318 }, { 8, 1350 }, { 8, 1382 }, { 8, 1414 }, { 8, 1446 }, { 8, 1478 }, { 8, 1510 }, { 8, 1542 }, { 8, 1574 } }, /* 45 */
    { { 4, 1038 }, { 4, 1070 }, { 4, 1102 }, { 4, 1134 }, { 4, 1166 }, { 4, 1198 }, { 4, 1230 }, { 4, 1262 }, { 4, 1294 }, { 4, 1326 }, { 4, 1358 }, { 4, 1390 }, { 4, 1422 }, { 4, 1454 }, { 4, 1486 }, { 4, 1518 }, { 4, 1550 }, { 4, 1582 } }, /* 46 */
    { { 8, 1042 }, { 8, 1074 }, { 8, 1106 }, { 8, 1138 }, { 8, 1170 }, { 8, 1202 }, { 8, 1234 }, { 8, 1266 }, { 8, 1298 }, { 8, 1330 }, { 8, 1362 }, { 8, 1394 }, { 8, 1426 }, { 8, 1458 }, { 8, 1490 }, { 8, 1522 }, { 8, 1554 }, { 8, 1586 } }, /* 47 */
    { { 8, 1050 }, { 8, 1082 }, { 8, 1114 }, { 8, 1146 }, { 8, 1178 }, { 8, 1210 }, { 8, 1242 }, { 8, 1274 }, { 8, 1306 }, { 8, 1338 }, { 8, 1370 }, { 8, 1402 }, { 8, 1434 }, { 8, 1466 }, { 8, 1498 }, { 8, 1530 }, { 8, 1562 }, { 8, 1594 } }, /* 48 */
    { { 4, 1602 }, { 4, 1650 }, { 4, 1698 } }, /* 49 */
    { { 8, 1606 }, { 8, 1654 }, { 8, 1702 } }, /* 50 */
    { { 4, 1614 }, { 4, 1662 }, { 4, 1710 } }, /* 51 */
    { { 4, 1618 }, { 4, 1666 }, { 4, 1714 } }, /* 52 */
    { { 4, 1622 }, { 4, 1670 }, { 4, 1718 } }, /* 53 */
    { { 8, 1626 }, { 8, 1674 }, { 8, 1722 } }, /* 54 */
    { { 8, 1634 }, { 8, 1682 }, { 8, 1730 } }, /* 55 */
    { { 8, 1642 }, { 8, 1690 }, { 8, 1738 } }, /* 56 */
    { { 4, 1746 }, { 4, 1794 }, { 4, 1842 } }, /* 57 */
    { { 8, 1750 }, { 8, 1798 }, { 8, 1846 } }, /* 58 */
    { { 4, 1758 }, { 4, 1806 }, { 4, 1854 } }, /* 59 */
    { { 4, 1762 }, { 4, 1810 }, { 4, 1858 } }, /* 60 */
    { { 4, 1766 }, { 4, 1814 }, { 4, 1862 } }, /* 61 */
    { { 8, 1770 }, { 8, 1818 }, { 8, 1866 } }, /* 62 */
    { { 8, 1778 }, { 8, 1826 }, { 8, 1874 } }, /* 63 */
    { { 8, 1786 }, { 8, 1834 }, { 8, 1882 } }, /* 64 */
    { { 8, 1890 }, { 8, 1970 }, { 8, 2050 }, { 8, 2130 }, { 8, 2210 }, { 8, 2290 }, { 8, 2370 }, { 8, 2450 }, { 8, 2530 } }, /* 65 */
    { { 16, 1898 }, { 16, 1978 }, { 16, 2058 }, { 16, 2138 }, { 16, 2218 }, { 16, 2298 }, { 16, 2378 }, { 16, 2458 }, { 16, 2538 } }, /* 66 */
    { { 8, 1914 }, { 8, 1994 }, { 8, 2074 }, { 8, 2154 }, { 8, 2234 }, { 8, 2314 }, { 8, 2394 }, { 8, 2474 }, { 8, 2554 } }, /* 67 */
    { { 8, 1922 }, { 8, 2002 }, { 8, 2082 }, { 8, 2162 }, { 8, 2242 }, { 8, 2322 }, { 8, 2402 }, { 8, 2482 }, { 8, 2562 } }, /* 68 */
    { { 8, 1930 }, { 8, 2010 }, { 8, 2090 }, { 8, 2170 }, { 8, 2250 }, { 8, 2330 }, { 8, 2410 }, { 8, 2490 }, { 8, 2570 } }, /* 69 */
    { { 16, 1938 }, { 16, 2018 }, { 16, 2098 }, { 16, 2178 }, { 16, 2258 }, { 16, 2338 }, { 16, 2418 }, { 16, 2498 }, { 16, 2578 } }, /* 70 */
    { { 16, 1954 }, { 16, 2034 }, { 16, 2114 }, { 16, 2194 }, { 16, 2274 }, { 16, 2354 }, { 16, 2434 }, { 16, 2514 }, { 16, 2594 } }, /* 71 */
    { { 4, 2610 }, { 4, 2674 }, { 4, 2738 }, { 4, 2802 }, { 4, 2866 }, { 4, 2930 }, { 4, 2994 }, { 4, 3058 }, { 4, 3122 } }, /* 72 */
    { { 8, 2614 }, { 8, 2678 }, { 8, 2742 }, { 8, 2806 }, { 8, 2870 }, { 8, 2934 }, { 8, 2998 }, { 8, 3062 }, { 8, 3126 } }, /* 73 */
    { { 4, 2622 }, { 4, 2686 }, { 4, 2750 }, { 4, 2814 }, { 4, 2878 }, { 4, 2942 }, { 4, 3006 }, { 4, 3070 }, { 4, 3134 } }, /* 74 */
    { { 4, 2626 }, { 4, 2690 }, { 4, 2754 }, { 4, 2818 }, { 4, 2882 }, { 4, 2946 }, { 4, 3010 }, { 4, 3074 }, { 4, 3138 } }, /* 75 */
    { { 4, 2630 }, { 4, 2694 }, { 4, 2758 }, { 4, 2822 }, { 4, 2886 }, { 4, 2950 }, { 4, 3014 }, { 4, 3078 }, { 4, 3142 } }, /* 76 */
    { { 8, 2634 }, { 8, 2698 }, { 8, 2762 }, { 8, 2826 }, { 8, 2890 }, { 8, 2954 }, { 8, 3018 }, { 8, 3082 }, { 8, 3146 } }, /* 77 */
    { { 8, 2642 }, { 8, 2706 }, { 8, 2770 }, { 8, 2834 }, { 8, 2898 }, { 8, 2962 }, { 8, 3026 }, { 8, 3090 }, { 8, 3154 } }, /* 78 */
    { { 8, 2650 }, { 8, 2714 }, { 8, 2778 }, { 8, 2842 }, { 8, 2906 }, { 8, 2970 }, { 8, 3034 }, { 8, 3098 }, { 8, 3162 } }, /* 79 */
    { { 8, 2658 }, { 8, 2722 }, { 8, 2786 }, { 8, 2850 }, { 8, 2914 }, { 8, 2978 }, { 8, 3042 }, { 8, 3106 }, { 8, 3170 } }, /* 80 */
    { { 8, 2666 }, { 8, 2730 }, { 8, 2794 }, { 8, 2858 }, { 8, 2922 }, { 8, 2986 }, { 8, 3050 }, { 8, 3114 }, { 8, 3178 } }, /* 81 */
    { { 4, 3186 }, { 4, 3250 }, { 4, 3314 }, { 4, 3378 }, { 4, 3442 }, { 4, 3506 }, { 4, 3570 }, { 4, 3634 }, { 4, 3698 } }, /* 82 */
    { { 8, 3190 }, { 8, 3254 }, { 8, 3318 }, { 8, 3382 }, { 8, 3446 }, { 8, 3510 }, { 8, 3574 }, { 8, 3638 }, { 8, 3702 } }, /* 83 */
    { { 4, 3198 }, { 4, 3262 }, { 4, 3326 }, { 4, 3390 }, { 4, 3454 }, { 4, 3518 }, { 4, 3582 }, { 4, 3646 }, { 4, 3710 } }, /* 84 */
    { { 4, 3202 }, { 4, 3266 }, { 4, 3330 }, { 4, 3394 }, { 4, 3458 }, { 4, 3522 }, { 4, 3586 }, { 4, 3650 }, { 4, 3714 } }, /* 85 */
    { { 4, 3206 }, { 4, 3270 }, { 4, 3334 }, { 4, 3398 }, { 4, 3462 }, { 4, 3526 }, { 4, 3590 }, { 4, 3654 }, { 4, 3718 } }, /* 86 */
    { { 8, 3210 }, { 8, 3274 }, { 8, 3338 }, { 8, 3402 }, { 8, 3466 }, { 8, 3530 }, { 8, 3594 }, { 8, 3658 }, { 8, 3722 } }, /* 87 */
    { { 8, 3218 }, { 8, 3282 }, { 8, 3346 }, { 8, 3410 }, { 8, 3474 }, { 8, 3538 }, { 8, 3602 }, { 8, 3666 }, { 8, 3730 } }, /* 88 */
    { { 8, 3226 }, { 8, 3290 }, { 8, 3354 }, { 8, 3418 }, { 8, 3482 }, { 8, 3546 }, { 8, 3610 }, { 8, 3674 }, { 8, 3738 } }, /* 89 */
    { { 8, 3234 }, { 8, 3298 }, { 8, 3362 }, { 8, 3426 }, { 8, 3490 }, { 8, 3554 }, { 8, 3618 }, { 8, 3682 }, { 8, 3746 } }, /* 90 */
    { { 8, 3242 }, { 8, 3306 }, { 8, 3370 }, { 8, 3434 }, { 8, 3498 }, { 8, 3562 }, { 8, 3626 }, { 8, 3690 }, { 8, 3754 } }, /* 91 */
    { { 8, 3762 }, { 8, 3842 }, { 8, 3922 }, { 8, 4002 }, { 8, 4082 }, { 8, 4162 }, { 8, 4242 }, { 8, 4322 }, { 8, 4402 }, { 8, 4482 }, { 8, 4562 }, { 8, 4642 }, { 8, 4722 }, { 8, 4802 }, { 8, 4882 }, { 8, 4962 }, { 8, 5042 }, { 8, 5122 } }, /* 92 */
    { { 16, 3770 }, { 16, 3850 }, { 16, 3930 }, { 16, 4010 }, { 16, 4090 }, { 16, 4170 }, { 16, 4250 }, { 16, 4330 }, { 16, 4410 }, { 16, 4490 }, { 16, 4570 }, { 16, 4650 }, { 16, 4730 }, { 16, 4810 }, { 16, 4890 }, { 16, 4970 }, { 16, 5050 }, { 16, 5130 } }, /* 93 */
    { { 8, 3786 }, { 8, 3866 }, { 8, 3946 }, { 8, 4026 }, { 8, 4106 }, { 8, 4186 }, { 8, 4266 }, { 8, 4346 }, { 8, 4426 }, { 8, 4506 }, { 8, 4586 }, { 8, 4666 }, { 8, 4746 }, { 8, 4826 }, { 8, 4906 }, { 8, 4986 }, { 8, 5066 }, { 8, 5146 } }, /* 94 */
    { { 8, 3794 }, { 8, 3874 }, { 8, 3954 }, { 8, 4034 }, { 8, 4114 }, { 8, 4194 }, { 8, 4274 }, { 8, 4354 }, { 8, 4434 }, { 8, 4514 }, { 8, 4594 }, { 8, 4674 }, { 8, 4754 }, { 8, 4834 }, { 8, 4914 }, { 8, 4994 }, { 8, 5074 }, { 8, 5154 } }, /* 95 */
    { { 8, 3802 }, { 8, 3882 }, { 8, 3962 }, { 8, 4042 }, { 8, 4122 }, { 8, 4202 }, { 8, 4282 }, { 8, 4362 }, { 8, 4442 }, { 8, 4522 }, { 8, 4602 }, { 8, 4682 }, { 8, 4762 }, { 8, 4842 }, { 8, 4922 }, { 8, 5002 }, { 8, 5082 }, { 8, 5162 } }, /* 96 */
    { { 16, 3810 }, { 16, 3890 }, { 16, 3970 }, { 16, 4050 }, { 16, 4130 }, { 16, 4210 }, { 16, 4290 }, { 16, 4370 }, { 16, 4450 }, { 16, 4530 }, { 16, 4610 }, { 16, 4690 }, { 16, 4770 }, { 16, 4850 }, { 16, 4930 }, { 16, 5010 }, { 16, 5090 }, { 16, 5170 } }, /* 97 */
    { { 16, 3826 }, { 16, 3906 }, { 16, 3986 }, { 16, 4066 }, { 16, 4146 }, { 16, 4226 }, { 16, 4306 }, { 16, 4386 }, { 16, 4466 }, { 16, 4546 }, { 16, 4626 }, { 16, 4706 }, { 16, 4786 }, { 16, 4866 }, { 16, 4946 }, { 16, 5026 }, { 16, 5106 }, { 16, 5186 } }, /* 98 */
    { { 4, 5202 } }, /* 99 */
    { { 8, 5206 } }, /* 100 */
    { { 4, 5214 } }, /* 101 */
    { { 8, 5218 } }, /* 102 */
    { { 8, 5226 } }, /* 103 */
    { { 8, 5234 } }, /* 104 */
    { { 4, 5242 }, { 4, 5302 }, { 4, 5362 } }, /* 105 */
    { { 8, 5246 }, { 8, 5306 }, { 8, 5366 } }, /* 106 */
    { { 4, 5254 }, { 4, 5314 }, { 4, 5374 } }, /* 107 */
    { { 4, 5258 }, { 4, 5318 }, { 4, 5378 } }, /* 108 */
    { { 8, 5262 }, { 8, 5322 }, { 8, 5382 } }, /* 109 */
    { { 8, 5270 }, { 8, 5330 }, { 8, 5390 } }, /* 110 */
    { { 8, 5278 }, { 8, 5338 }, { 8, 5398 } }, /* 111 */
    { { 8, 5286 }, { 8, 5346 }, { 8, 5406 } }, /* 112 */
    { { 8, 5294 }, { 8, 5354 }, { 8, 5414 } }, /* 113 */
    { { 4, 5422 }, { 4, 5482 }, { 4, 5542 } }, /* 114 */
    { { 8, 5426 }, { 8, 5486 }, { 8, 5546 } }, /* 115 */
    { { 4, 5434 }, { 4, 5494 }, { 4, 5554 } }, /* 116 */
    { { 4, 5438 }, { 4, 5498 }, { 4, 5558 } }, /* 117 */
    { { 8, 5442 }, { 8, 5502 }, { 8, 5562 } }, /* 118 */
    { { 8, 5450 }, { 8, 5510 }, { 8, 5570 } }, /* 119 */
    { { 8, 5458 }, { 8, 5518 }, { 8, 5578 } }, /* 120 */
    { { 8, 5466 }, { 8, 5526 }, { 8, 5586 } }, /* 121 */
    { { 8, 5474 }, { 8, 5534 }, { 8, 5594 } }, /* 122 */
    { { 4, 5602 } }, /* 123 */
    { { 8, 5606 } }, /* 124 */
    { { 4, 5614 } }, /* 125 */
    { { 8, 5618 } }, /* 126 */
    { { 8, 5626 } }, /* 127 */
    { { 8, 5634 } }, /* 128 */
    { { 8, 5642 }, { 8, 5730 }, { 8, 5818 } }, /* 129 */
    { { 16, 5650 }, { 16, 5738 }, { 16, 5826 } }, /* 130 */
    { { 8, 5666 }, { 8, 5754 }, { 8, 5842 } }, /* 131 */
    { { 8, 5674 }, { 8, 5762 }, { 8, 5850 } }, /* 132 */
    { { 16, 5682 }, { 16, 5770 }, { 16, 5858 } }, /* 133 */
    { { 16, 5698 }, { 16, 5786 }, { 16, 5874 } }, /* 134 */
    { { 16, 5714 }, { 16, 5802 }, { 16, 5890 } }, /* 135 */
    { { 8, 5906 }, { 8, 5994 }, { 8, 6082 } }, /* 136 */
    { { 16, 5914 }, { 16, 6002 }, { 16, 6090 } }, /* 137 */
    { { 8, 5930 }, { 8, 6018 }, { 8, 6106 } }, /* 138 */
    { { 8, 5938 }, { 8, 6026 }, { 8, 6114 } }, /* 139 */
    { { 16, 5946 }, { 16, 6034 }, { 16, 6122 } }, /* 140 */
    { { 16, 5962 }, { 16, 6050 }, { 16, 6138 } }, /* 141 */
    { { 16, 5978 }, { 16, 6066 }, { 16, 6154 } }, /* 142 */
    { { 16, 6170 } }, /* 143 */
    { { 32, 6186 } }, /* 144 */
    { { 16, 6218 } }, /* 145 */
    { { 32, 6234 } }, /* 146 */
    { { 8, 6266 } }, /* 147 */
    { { 16, 6274 } }, /* 148 */
    { { 8, 6290 } }, /* 149 */
    { { 16, 6298 } }, /* 150 */
    { { 8, 6314 } }, /* 151 */
    { { 16, 6322 } }, /* 152 */
    { { 8, 6338 } }, /* 153 */
    { { 16, 6346 } }, /* 154 */
    { { 4, 6362 }, { 4, 6422 }, { 4, 6482 } }, /* 155 */
    { { 8, 6366 }, { 8, 6426 }, { 8, 6486 } }, /* 156 */
    { { 4, 6374 }, { 4, 6434 }, { 4, 6494 } }, /* 157 */
    { { 4, 6378 }, { 4, 6438 }, { 4, 6498 } }, /* 158 */
    { { 8, 6382 }, { 8, 6442 }, { 8, 6502 } }, /* 159 */
    { { 8, 6390 }, { 8, 6450 }, { 8, 6510 } }, /* 160 */
    { { 8, 6398 }, { 8, 6458 }, { 8, 6518 } }, /* 161 */
    { { 8, 6406 }, { 8, 6466 }, { 8, 6526 } }, /* 162 */
    { { 8, 6414 }, { 8, 6474 }, { 8, 6534 } }, /* 163 */
    { { 4, 6542 }, { 4, 6622 }, { 4, 6702 }, { 4, 6782 }, { 4, 6862 }, { 4, 6942 } }, /* 164 */
    { { 8, 6546 }, { 8, 6626 }, { 8, 6706 }, { 8, 6786 }, { 8, 6866 }, { 8, 6946 } }, /* 165 */
    { { 4, 6554 }, { 4, 6634 }, { 4, 6714 }, { 4, 6794 }, { 4, 6874 }, { 4, 6954 } }, /* 166 */
    { { 4, 6558 }, { 4, 6638 }, { 4, 6718 }, { 4, 6798 }, { 4, 6878 }, { 4, 6958 } }, /* 167 */
    { { 4, 6562 }, { 4, 6642 }, { 4, 6722 }, { 4, 6802 }, { 4, 6882 }, { 4, 6962 } }, /* 168 */
    { { 8, 6566 }, { 8, 6646 }, { 8, 6726 }, { 8, 6806 }, { 8, 6886 }, { 8, 6966 } }, /* 169 */
    { { 8, 6574 }, { 8, 6654 }, { 8, 6734 }, { 8, 6814 }, { 8, 6894 }, { 8, 6974 } }, /* 170 */
    { { 8, 6582 }, { 8, 6662 }, { 8, 6742 }, { 8, 6822 }, { 8, 6902 }, { 8, 6982 } }, /* 171 */
    { { 8, 6590 }, { 8, 6670 }, { 8, 6750 }, { 8, 6830 }, { 8, 6910 }, { 8, 6990 } }, /* 172 */
    { { 8, 6598 }, { 8, 6678 }, { 8, 6758 }, { 8, 6838 }, { 8, 6918 }, { 8, 6998 } }, /* 173 */
    { { 8, 6606 }, { 8, 6686 }, { 8, 6766 }, { 8, 6846 }, { 8, 6926 }, { 8, 7006 } }, /* 174 */
    { { 8, 6614 }, { 8, 6694 }, { 8, 6774 }, { 8, 6854 }, { 8, 6934 }, { 8, 7014 } }, /* 175 */
    { { 4, 7022 }, { 4, 7082 }, { 4, 7142 } }, /* 176 */
    { { 8, 7026 }, { 8, 7086 }, { 8, 7146 } }, /* 177 */
    { { 4, 7034 }, { 4, 7094 }, { 4, 7154 } }, /* 178 */
    { { 4, 7038 }, { 4, 7098 }, { 4, 7158 } }, /* 179 */
    { { 8, 7042 }, { 8, 7102 }, { 8, 7162 } }, /* 180 */
    { { 8, 7050 }, { 8, 7110 }, { 8, 7170 } }, /* 181 */
    { { 8, 7058 }, { 8, 7118 }, { 8, 7178 } }, /* 182 */
    { { 8, 7066 }, { 8, 7126 }, { 8, 7186 } }, /* 183 */
    { { 8, 7074 }, { 8, 7134 }, { 8, 7194 } }, /* 184 */
    { { 4, 7202 }, { 4, 7282 }, { 4, 7362 }, { 4, 7442 }, { 4, 7522 }, { 4, 7602 } }, /* 185 */
    { { 8, 7206 }, { 8, 7286 }, { 8, 7366 }, { 8, 7446 }, { 8, 7526 }, { 8, 7606 } }, /* 186 */
    { { 4, 7214 }, { 4, 7294 }, { 4, 7374 }, { 4, 7454 }, { 4, 7534 }, { 4, 7614 } }, /* 187 */
    { { 4, 7218 }, { 4, 7298 }, { 4, 7378 }, { 4, 7458 }, { 4, 7538 }, { 4, 7618 } }, /* 188 */
    { { 4, 7222 }, { 4, 7302 }, { 4, 7382 }, { 4, 7462 }, { 4, 7542 }, { 4, 7622 } }, /* 189 */
    { { 8, 7226 }, { 8, 7306 }, { 8, 7386 }, { 8, 7466 }, { 8, 7546 }, { 8, 7626 } }, /* 190 */
    { { 8, 7234 }, { 8, 7314 }, { 8, 7394 }, { 8, 7474 }, { 8, 7554 }, { 8, 7634 } }, /* 191 */
    { { 8, 7242 }, { 8, 7322 }, { 8, 7402 }, { 8, 7482 }, { 8, 7562 }, { 8, 7642 } }, /* 192 */
    { { 8, 7250 }, { 8, 7330 }, { 8, 7410 }, { 8, 7490 }, { 8, 7570 }, { 8, 7650 } }, /* 193 */
    { { 8, 7258 }, { 8, 7338 }, { 8, 7418 }, { 8, 7498 }, { 8, 7578 }, { 8, 7658 } }, /* 194 */
    { { 8, 7266 }, { 8, 7346 }, { 8, 7426 }, { 8, 7506 }, { 8, 7586 }, { 8, 7666 } }, /* 195 */
    { { 8, 7274 }, { 8, 7354 }, { 8, 7434 }, { 8, 7514 }, { 8, 7594 }, { 8, 7674 } }, /* 196 */
    { { 4, 7682 }, { 4, 7762 }, { 4, 7842 }, { 4, 7922 }, { 4, 8002 }, { 4, 8082 } }, /* 197 */
    { { 8, 7686 }, { 8, 7766 }, { 8, 7846 }, { 8, 7926 }, { 8, 8006 }, { 8, 8086 } }, /* 198 */
    { { 4, 7694 }, { 4, 7774 }, { 4, 7854 }, { 4, 7934 }, { 4, 8014 }, { 4, 8094 } }, /* 199 */
    { { 4, 7698 }, { 4, 7778 }, { 4, 7858 }, { 4, 7938 }, { 4, 8018 }, { 4, 8098 } }, /* 200 */
    { { 4, 7702 }, { 4, 7782 }, { 4, 7862 }, { 4, 7942 }, { 4, 8022 }, { 4, 8102 } }, /* 201 */
    { { 8, 7706 }, { 8, 7786 }, { 8, 7866 }, { 8, 7946 }, { 8, 8026 }, { 8, 8106 } }, /* 202 */
    { { 8, 7714 }, { 8, 7794 }, { 8, 7874 }, { 8, 7954 }, { 8, 8034 }, { 8, 8114 } }, /* 203 */
    { { 8, 7722 }, { 8, 7802 }, { 8, 7882 }, { 8, 7962 }, { 8, 8042 }, { 8, 8122 } }, /* 204 */
    { { 8, 7730 }, { 8, 7810 }, { 8, 7890 }, { 8, 7970 }, { 8, 8050 }, { 8, 8130 } }, /* 205 */
    { { 8, 7738 }, { 8, 7818 }, { 8, 7898 }, { 8, 7978 }, { 8, 8058 }, { 8, 8138 } }, /* 206 */
    { { 8, 7746 }, { 8, 7826 }, { 8, 7906 }, { 8, 7986 }, { 8, 8066 }, { 8, 8146 } }, /* 207 */
    { { 8, 7754 }, { 8, 7834 }, { 8, 7914 }, { 8, 7994 }, { 8, 8074 }, { 8, 8154 } }, /* 208 */
    { { 4, 8162 }, { 4, 8242 }, { 4, 8322 }, { 4, 8402 }, { 4, 8482 }, { 4, 8562 } }, /* 209 */
    { { 8, 8166 }, { 8, 8246 }, { 8, 8326 }, { 8, 8406 }, { 8, 8486 }, { 8, 8566 } }, /* 210 */
    { { 4, 8174 }, { 4, 8254 }, { 4, 8334 }, { 4, 8414 }, { 4, 8494 }, { 4, 8574 } }, /* 211 */
    { { 4, 8178 }, { 4, 8258 }, { 4, 8338 }, { 4, 8418 }, { 4, 8498 }, { 4, 8578 } }, /* 212 */
    { { 4, 8182 }, { 4, 8262 }, { 4, 8342 }, { 4, 8422 }, { 4, 8502 }, { 4, 8582 } }, /* 213 */
    { { 8, 8186 }, { 8, 8266 }, { 8, 8346 }, { 8, 8426 }, { 8, 8506 }, { 8, 8586 } }, /* 214 */
    { { 8, 8194 }, { 8, 8274 }, { 8, 8354 }, { 8, 8434 }, { 8, 8514 }, { 8, 8594 } }, /* 215 */
    { { 8, 8202 }, { 8, 8282 }, { 8, 8362 }, { 8, 8442 }, { 8, 8522 }, { 8, 8602 } }, /* 216 */
    { { 8, 8210 }, { 8, 8290 }, { 8, 8370 }, { 8, 8450 }, { 8, 8530 }, { 8, 8610 } }, /* 217 */
    { { 8, 8218 }, { 8, 8298 }, { 8, 8378 }, { 8, 8458 }, { 8, 8538 }, { 8, 8618 } }, /* 218 */
    { { 8, 8226 }, { 8, 8306 }, { 8, 8386 }, { 8, 8466 }, { 8, 8546 }, { 8, 8626 } }, /* 219 */
    { { 8, 8234 }, { 8, 8314 }, { 8, 8394 }, { 8, 8474 }, { 8, 8554 }, { 8, 8634 } }, /* 220 */
    { { 4, 8642 }, { 4, 8722 }, { 4, 8802 }, { 4, 8882 }, { 4, 8962 }, { 4, 9042 } }, /* 221 */
    { { 8, 8646 }, { 8, 8726 }, { 8, 8806 }, { 8, 8886 }, { 8, 8966 }, { 8, 9046 } }, /* 222 */
    { { 4, 8654 }, { 4, 8734 }, { 4, 8814 }, { 4, 8894 }, { 4, 8974 }, { 4, 9054 } }, /* 223 */
    { { 4, 8658 }, { 4, 8738 }, { 4, 8818 }, { 4, 8898 }, { 4, 8978 }, { 4, 9058 } }, /* 224 */
    { { 4, 8662 }, { 4, 8742 }, { 4, 8822 }, { 4, 8902 }, { 4, 8982 }, { 4, 9062 } }, /* 225 */
    { { 8, 8666 }, { 8, 8746 }, { 8, 8826 }, { 8, 8906 }, { 8, 8986 }, { 8, 9066 } }, /* 226 */
    { { 8, 8674 }, { 8, 8754 }, { 8, 8834 }, { 8, 8914 }, { 8, 8994 }, { 8, 9074 } }, /* 227 */
    { { 8, 8682 }, { 8, 8762 }, { 8, 8842 }, { 8, 8922 }, { 8, 9002 }, { 8, 9082 } }, /* 228 */
    { { 8, 8690 }, { 8, 8770 }, { 8, 8850 }, { 8, 8930 }, { 8, 9010 }, { 8, 9090 } }, /* 229 */
    { { 8, 8698 }, { 8, 8778 }, { 8, 8858 }, { 8, 8938 }, { 8, 9018 }, { 8, 9098 } }, /* 230 */
    { { 8, 8706 }, { 8, 8786 }, { 8, 8866 }, { 8, 8946 }, { 8, 9026 }, { 8, 9106 } }, /* 231 */
    { { 8, 8714 }, { 8, 8794 }, { 8, 8874 }, { 8, 8954 }, { 8, 9034 }, { 8, 9114 } }, /* 232 */
    { { 4, 9122 }, { 4, 9182 }, { 4, 9242 } }, /* 233 */
    { { 8, 9126 }, { 8, 9186 }, { 8, 9246 } }, /* 234 */
    { { 4, 9134 }, { 4, 9194 }, { 4, 9254 } }, /* 235 */
    { { 4, 9138 }, { 4, 9198 }, { 4, 9258 } }, /* 236 */
    { { 8, 9142 }, { 8, 9202 }, { 8, 9262 } }, /* 237 */
    { { 8, 9150 }, { 8, 9210 }, { 8, 9270 } }, /* 238 */
    { { 8, 9158 }, { 8, 9218 }, { 8, 9278 } }, /* 239 */
    { { 8, 9166 }, { 8, 9226 }, { 8, 9286 } }, /* 240 */
    { { 8, 9174 }, { 8, 9234 }, { 8, 9294 } }, /* 241 */
    { { 4, 9302 }, { 4, 9382 }, { 4, 9462 }, { 4, 9542 }, { 4, 9622 }, { 4, 9702 } }, /* 242 */
    { { 8, 9306 }, { 8, 9386 }, { 8, 9466 }, { 8, 9546 }, { 8, 9626 }, { 8, 9706 } }, /* 243 */
    { { 4, 9314 }, { 4, 9394 }, { 4, 9474 }, { 4, 9554 }, { 4, 9634 }, { 4, 9714 } }, /* 244 */
    { { 4, 9318 }, { 4, 9398 }, { 4, 9478 }, { 4, 9558 }, { 4, 9638 }, { 4, 9718 } }, /* 245 */
    { { 4, 9322 }, { 4, 9402 }, { 4, 9482 }, { 4, 9562 }, { 4, 9642 }, { 4, 9722 } }, /* 246 */
    { { 8, 9326 }, { 8, 9406 }, { 8, 9486 }, { 8, 9566 }, { 8, 9646 }, { 8, 9726 } }, /* 247 */
    { { 8, 9334 }, { 8, 9414 }, { 8, 9494 }, { 8, 9574 }, { 8, 9654 }, { 8, 9734 } }, /* 248 */
    { { 8, 9342 }, { 8, 9422 }, { 8, 9502 }, { 8, 9582 }, { 8, 9662 }, { 8, 9742 } }, /* 249 */
    { { 8, 9350 }, { 8, 9430 }, { 8, 9510 }, { 8, 9590 }, { 8, 9670 }, { 8, 9750 } }, /* 250 */
    { { 8, 9358 }, { 8, 9438 }, { 8, 9518 }, { 8, 9598 }, { 8, 9678 }, { 8, 9758 } }, /* 251 */
    { { 8, 9366 }, { 8, 9446 }, { 8, 9526 }, { 8, 9606 }, { 8, 9686 }, { 8, 9766 } }, /* 252 */
    { { 8, 9374 }, { 8, 9454 }, { 8, 9534 }, { 8, 9614 }, { 8, 9694 }, { 8, 9774 } }, /* 253 */
    { { 4, 9782 }, { 4, 9842 }, { 4, 9902 } }, /* 254 */
    { { 8, 9786 }, { 8, 9846 }, { 8, 9906 } }, /* 255 */
    { { 4, 9794 }, { 4, 9854 }, { 4, 9914 } }, /* 256 */
    { { 4, 9798 }, { 4, 9858 }, { 4, 9918 } }, /* 257 */
    { { 8, 9802 }, { 8, 9862 }, { 8, 9922 } }, /* 258 */
    { { 8, 9810 }, { 8, 9870 }, { 8, 9930 } }, /* 259 */
    { { 8, 9818 }, { 8, 9878 }, { 8, 9938 } }, /* 260 */
    { { 8, 9826 }, { 8, 9886 }, { 8, 9946 } }, /* 261 */
    { { 8, 9834 }, { 8, 9894 }, { 8, 9954 } }, /* 262 */
    { { 8, 9962 }, { 8, 10050 }, { 8, 10138 } }, /* 263 */
    { { 16, 9970 }, { 16, 10058 }, { 16, 10146 } }, /* 264 */
    { { 8, 9986 }, { 8, 10074 }, { 8, 10162 } }, /* 265 */
    { { 8, 9994 }, { 8, 10082 }, { 8, 10170 } }, /* 266 */
    { { 16, 10002 }, { 16, 10090 }, { 16, 10178 } }, /* 267 */
    { { 16, 10018 }, { 16, 10106 }, { 16, 10194 } }, /* 268 */
    { { 16, 10034 }, { 16, 10122 }, { 16, 10210 } }, /* 269 */
    { { 8, 10226 }, { 8, 10322 }, { 8, 10418 }, { 8, 10514 }, { 8, 10610 }, { 8, 10706 } }, /* 270 */
    { { 16, 10234 }, { 16, 10330 }, { 16, 10426 }, { 16, 10522 }, { 16, 10618 }, { 16, 10714 } }, /* 271 */
    { { 8, 10250 }, { 8, 10346 }, { 8, 10442 }, { 8, 10538 }, { 8, 10634 }, { 8, 10730 } }, /* 272 */
    { { 8, 10258 }, { 8, 10354 }, { 8, 10450 }, { 8, 10546 }, { 8, 10642 }, { 8, 10738 } }, /* 273 */
    { { 8, 10266 }, { 8, 10362 }, { 8, 10458 }, { 8, 10554 }, { 8, 10650 }, { 8, 10746 } }, /* 274 */
    { { 16, 10274 }, { 16, 10370 }, { 16, 10466 }, { 16, 10562 }, { 16, 10658 }, { 16, 10754 } }, /* 275 */
    { { 16, 10290 }, { 16, 10386 }, { 16, 10482 }, { 16, 10578 }, { 16, 10674 }, { 16, 10770 } }, /* 276 */
    { { 16, 10306 }, { 16, 10402 }, { 16, 10498 }, { 16, 10594 }, { 16, 10690 }, { 16, 10786 } }, /* 277 */
    { { 8, 10802 }, { 8, 10890 }, { 8, 10978 } }, /* 278 */
    { { 16, 10810 }, { 16, 10898 }, { 16, 10986 } }, /* 279 */
    { { 8, 10826 }, { 8, 10914 }, { 8, 11002 } }, /* 280 */
    { { 8, 10834 }, { 8, 10922 }, { 8, 11010 } }, /* 281 */
    { { 16, 10842 }, { 16, 10930 }, { 16, 11018 } }, /* 282 */
    { { 16, 10858 }, { 16, 10946 }, { 16, 11034 } }, /* 283 */
    { { 16, 10874 }, { 16, 10962 }, { 16, 11050 } }, /* 284 */
    { { 8, 11066 }, { 8, 11162 }, { 8, 11258 }, { 8, 11354 }, { 8, 11450 }, { 8, 11546 } }, /* 285 */
    { { 16, 11074 }, { 16, 11170 }, { 16, 11266 }, { 16, 11362 }, { 16, 11458 }, { 16, 11554 } }, /* 286 */
    { { 8, 11090 }, { 8, 11186 }, { 8, 11282 }, { 8, 11378 }, { 8, 11474 }, { 8, 11570 } }, /* 287 */
    { { 8, 11098 }, { 8, 11194 }, { 8, 11290 }, { 8, 11386 }, { 8, 11482 }, { 8, 11578 } }, /* 288 */
    { { 8, 11106 }, { 8, 11202 }, { 8, 11298 }, { 8, 11394 }, { 8, 11490 }, { 8, 11586 } }, /* 289 */
    { { 16, 11114 }, { 16, 11210 }, { 16, 11306 }, { 16, 11402 }, { 16, 11498 }, { 16, 11594 } }, /* 290 */
    { { 16, 11130 }, { 16, 11226 }, { 16, 11322 }, { 16, 11418 }, { 16, 11514 }, { 16, 11610 } }, /* 291 */
    { { 16, 11146 }, { 16, 11242 }, { 16, 11338 }, { 16, 11434 }, { 16, 11530 }, { 16, 11626 } }, /* 292 */
    { { 8, 11642 }, { 8, 11738 }, { 8, 11834 }, { 8, 11930 }, { 8, 12026 }, { 8, 12122 } }, /* 293 */
    { { 16, 11650 }, { 16, 11746 }, { 16, 11842 }, { 16, 11938 }, { 16, 12034 }, { 16, 12130 } }, /* 294 */
    { { 8, 11666 }, { 8, 11762 }, { 8, 11858 }, { 8, 11954 }, { 8, 12050 }, { 8, 12146 } }, /* 295 */
    { { 8, 11674 }, { 8, 11770 }, { 8, 11866 }, { 8, 11962 }, { 8, 12058 }, { 8, 12154 } }, /* 296 */
    { { 8, 11682 }, { 8, 11778 }, { 8, 11874 }, { 8, 11970 }, { 8, 12066 }, { 8, 12162 } }, /* 297 */
    { { 16, 11690 }, { 16, 11786 }, { 16, 11882 }, { 16, 11978 }, { 16, 12074 }, { 16, 12170 } }, /* 298 */
    { { 16, 11706 }, { 16, 11802 }, { 16, 11898 }, { 16, 11994 }, { 16, 12090 }, { 16, 12186 } }, /* 299 */
    { { 16, 11722 }, { 16, 11818 }, { 16, 11914 }, { 16, 12010 }, { 16, 12106 }, { 16, 12202 } }, /* 300 */
    { { 8, 12218 }, { 8, 12314 }, { 8, 12410 }, { 8, 12506 }, { 8, 12602 }, { 8, 12698 } }, /* 301 */
    { { 16, 12226 }, { 16, 12322 }, { 16, 12418 }, { 16, 12514 }, { 16, 12610 }, { 16, 12706 } }, /* 302 */
    { { 8, 12242 }, { 8, 12338 }, { 8, 12434 }, { 8, 12530 }, { 8, 12626 }, { 8, 12722 } }, /* 303 */
    { { 8, 12250 }, { 8, 12346 }, { 8, 12442 }, { 8, 12538 }, { 8, 12634 }, { 8, 12730 } }, /* 304 */
    { { 8, 12258 }, { 8, 12354 }, { 8, 12450 }, { 8, 12546 }, { 8, 12642 }, { 8, 12738 } }, /* 305 */
    { { 16, 12266 }, { 16, 12362 }, { 16, 12458 }, { 16, 12554 }, { 16, 12650 }, { 16, 12746 } }, /* 306 */
    { { 16, 12282 }, { 16, 12378 }, { 16, 12474 }, { 16, 12570 }, { 16, 12666 }, { 16, 12762 } }, /* 307 */
    { { 16, 12298 }, { 16, 12394 }, { 16, 12490 }, { 16, 12586 }, { 16, 12682 }, { 16, 12778 } }, /* 308 */
    { { 8, 12794 }, { 8, 12890 }, { 8, 12986 }, { 8, 13082 }, { 8, 13178 }, { 8, 13274 } }, /* 309 */
    { { 16, 12802 }, { 16, 12898 }, { 16, 12994 }, { 16, 13090 }, { 16, 13186 }, { 16, 13282 } }, /* 310 */
    { { 8, 12818 }, { 8, 12914 }, { 8, 13010 }, { 8, 13106 }, { 8, 13202 }, { 8, 13298 } }, /* 311 */
    { { 8, 12826 }, { 8, 12922 }, { 8, 13018 }, { 8, 13114 }, { 8, 13210 }, { 8, 13306 } }, /* 312 */
    { { 8, 12834 }, { 8, 12930 }, { 8, 13026 }, { 8, 13122 }, { 8, 13218 }, { 8, 13314 } }, /* 313 */
    { { 16, 12842 }, { 16, 12938 }, { 16, 13034 }, { 16, 13130 }, { 16, 13226 }, { 16, 13322 } }, /* 314 */
    { { 16, 12858 }, { 16, 12954 }, { 16, 13050 }, { 16, 13146 }, { 16, 13242 }, { 16, 13338 } }, /* 315 */
    { { 16, 12874 }, { 16, 12970 }, { 16, 13066 }, { 16, 13162 }, { 16, 13258 }, { 16, 13354 } }, /* 316 */
    { { 16, 13370 }, { 16, 13482 }, { 16, 13594 } }, /* 317 */
    { { 32, 13386 }, { 32, 13498 }, { 32, 13610 } }, /* 318 */
    { { 16, 13418 }, { 16, 13530 }, { 16, 13642 } }, /* 319 */
    { { 16, 13434 }, { 16, 13546 }, { 16, 13658 } }, /* 320 */
    { { 32, 13450 }, { 32, 13562 }, { 32, 13674 } }, /* 321 */
    { { 16, 13706 }, { 16, 13818 }, { 16, 13930 } }, /* 322 */
    { { 32, 13722 }, { 32, 13834 }, { 32, 13946 } }, /* 323 */
    { { 16, 13754 }, { 16, 13866 }, { 16, 13978 } }, /* 324 */
    { { 16, 13770 }, { 16, 13882 }, { 16, 13994 } }, /* 325 */
    { { 32, 13786 }, { 32, 13898 }, { 32, 14010 } }, /* 326 */
    { { 8, 14042 }, { 8, 14114 }, { 8, 14186 } }, /* 327 */
    { { 16, 14050 }, { 16, 14122 }, { 16, 14194 } }, /* 328 */
    { { 8, 14066 }, { 8, 14138 }, { 8, 14210 } }, /* 329 */
    { { 8, 14074 }, { 8, 14146 }, { 8, 14218 } }, /* 330 */
    { { 16, 14082 }, { 16, 14154 }, { 16, 14226 } }, /* 331 */
    { { 16, 14098 }, { 16, 14170 }, { 16, 14242 } }, /* 332 */
    { { 8, 14258 }, { 8, 14330 }, { 8, 14402 } }, /* 333 */
    { { 16, 14266 }, { 16, 14338 }, { 16, 14410 } }, /* 334 */
    { { 8, 14282 }, { 8, 14354 }, { 8, 14426 } }, /* 335 */
    { { 8, 14290 }, { 8, 14362 }, { 8, 14434 } }, /* 336 */
    { { 16, 14298 }, { 16, 14370 }, { 16, 14442 } }, /* 337 */
    { { 16, 14314 }, { 16, 14386 }, { 16, 14458 } }, /* 338 */
    { { 8, 14474 }, { 8, 14570 }, { 8, 14666 }, { 8, 14762 }, { 8, 14858 }, { 8, 14954 } }, /* 339 */
    { { 16, 14482 }, { 16, 14578 }, { 16, 14674 }, { 16, 14770 }, { 16, 14866 }, { 16, 14962 } }, /* 340 */
    { { 8, 14498 }, { 8, 14594 }, { 8, 14690 }, { 8, 14786 }, { 8, 14882 }, { 8, 14978 } }, /* 341 */
    { { 8, 14506 }, { 8, 14602 }, { 8, 14698 }, { 8, 14794 }, { 8, 14890 }, { 8, 14986 } }, /* 342 */
    { { 8, 14514 }, { 8, 14610 }, { 8, 14706 }, { 8, 14802 }, { 8, 14898 }, { 8, 14994 } }, /* 343 */
    { { 16, 14522 }, { 16, 14618 }, { 16, 14714 }, { 16, 14810 }, { 16, 14906 }, { 16, 15002 } }, /* 344 */
    { { 16, 14538 }, { 16, 14634 }, { 16, 14730 }, { 16, 14826 }, { 16, 14922 }, { 16, 15018 } }, /* 345 */
    { { 16, 14554 }, { 16, 14650 }, { 16, 14746 }, { 16, 14842 }, { 16, 14938 }, { 16, 15034 } }, /* 346 */
    { { 8, 15050 } }, /* 347 */
    { { 16, 15058 } }, /* 348 */
    { { 8, 15074 } }, /* 349 */
    { { 8, 15082 } }, /* 350 */
    { { 8, 15090 } }, /* 351 */
    { { 16, 15098 } }, /* 352 */
    { { 16, 15114 } }, /* 353 */
    { { 16, 15130 } }, /* 354 */
    { { 8, 15146 }, { 8, 15242 } }, /* 355 */
    { { 16, 15154 }, { 16, 15250 } }, /* 356 */
    { { 8, 15170 }, { 8, 15266 } }, /* 357 */
    { { 8, 15178 }, { 8, 15274 } }, /* 358 */
    { { 8, 15186 }, { 8, 15282 } }, /* 359 */
    { { 16, 15194 }, { 16, 15290 } }, /* 360 */
    { { 16, 15210 }, { 16, 15306 } }, /* 361 */
    { { 16, 15226 }, { 16, 15322 } }, /* 362 */
    { { 8, 15338 }, { 8, 15482 }, { 8, 15626 } }, /* 363 */
    { { 16, 15346 }, { 16, 15490 }, { 16, 15634 } }, /* 364 */
    { { 8, 15362 }, { 8, 15506 }, { 8, 15650 } }, /* 365 */
    { { 8, 15370 }, { 8, 15514 }, { 8, 15658 } }, /* 366 */
    { { 8, 15378 }, { 8, 15522 }, { 8, 15666 } }, /* 367 */
    { { 8, 15386 }, { 8, 15530 }, { 8, 15674 } }, /* 368 */
    { { 8, 15394 }, { 8, 15538 }, { 8, 15682 } }, /* 369 */
    { { 16, 15402 }, { 16, 15546 }, { 16, 15690 } }, /* 370 */
    { { 16, 15418 }, { 16, 15562 }, { 16, 15706 } }, /* 371 */
    { { 16, 15434 }, { 16, 15578 }, { 16, 15722 } }, /* 372 */
    { { 16, 15450 }, { 16, 15594 }, { 16, 15738 } }, /* 373 */
    { { 16, 15466 }, { 16, 15610 }, { 16, 15754 } }, /* 374 */
    { { 8, 15770 }, { 8, 15914 }, { 8, 16058 }, { 8, 16202 }, { 8, 16346 }, { 8, 16490 } }, /* 375 */
    { { 16, 15778 }, { 16, 15922 }, { 16, 16066 }, { 16, 16210 }, { 16, 16354 }, { 16, 16498 } }, /* 376 */
    { { 8, 15794 }, { 8, 15938 }, { 8, 16082 }, { 8, 16226 }, { 8, 16370 }, { 8, 16514 } }, /* 377 */
    { { 8, 15802 }, { 8, 15946 }, { 8, 16090 }, { 8, 16234 }, { 8, 16378 }, { 8, 16522 } }, /* 378 */
    { { 8, 15810 }, { 8, 15954 }, { 8, 16098 }, { 8, 16242 }, { 8, 16386 }, { 8, 16530 } }, /* 379 */
    { { 8, 15818 }, { 8, 15962 }, { 8, 16106 }, { 8, 16250 }, { 8, 16394 }, { 8, 16538 } }, /* 380 */
    { { 8, 15826 }, { 8, 15970 }, { 8, 16114 }, { 8, 16258 }, { 8, 16402 }, { 8, 16546 } }, /* 381 */
    { { 16, 15834 }, { 16, 15978 }, { 16, 16122 }, { 16, 16266 }, { 16, 16410 }, { 16, 16554 } }, /* 382 */
    { { 16, 15850 }, { 16, 15994 }, { 16, 16138 }, { 16, 16282 }, { 16, 16426 }, { 16, 16570 } }, /* 383 */
    { { 16, 15866 }, { 16, 16010 }, { 16, 16154 }, { 16, 16298 }, { 16, 16442 }, { 16, 16586 } }, /* 384 */
    { { 16, 15882 }, { 16, 16026 }, { 16, 16170 }, { 16, 16314 }, { 16, 16458 }, { 16, 16602 } }, /* 385 */
    { { 16, 15898 }, { 16, 16042 }, { 16, 16186 }, { 16, 16330 }, { 16, 16474 }, { 16, 16618 } }, /* 386 */
    { { 8, 16634 }, { 8, 16826 }, { 8, 17018 }, { 8, 17210 }, { 8, 17402 }, { 8, 17594 } }, /* 387 */
    { { 16, 16642 }, { 16, 16834 }, { 16, 17026 }, { 16, 17218 }, { 16, 17410 }, { 16, 17602 } }, /* 388 */
    { { 8, 16658 }, { 8, 16850 }, { 8, 17042 }, { 8, 17234 }, { 8, 17426 }, { 8, 17618 } }, /* 389 */
    { { 8, 16666 }, { 8, 16858 }, { 8, 17050 }, { 8, 17242 }, { 8, 17434 }, { 8, 17626 } }, /* 390 */
    { { 8, 16674 }, { 8, 16866 }, { 8, 17058 }, { 8, 17250 }, { 8, 17442 }, { 8, 17634 } }, /* 391 */
    { { 8, 16682 }, { 8, 16874 }, { 8, 17066 }, { 8, 17258 }, { 8, 17450 }, { 8, 17642 } }, /* 392 */
    { { 8, 16690 }, { 8, 16882 }, { 8, 17074 }, { 8, 17266 }, { 8, 17458 }, { 8, 17650 } }, /* 393 */
    { { 8, 16698 }, { 8, 16890 }, { 8, 17082 }, { 8, 17274 }, { 8, 17466 }, { 8, 17658 } }, /* 394 */
    { { 8, 16706 }, { 8, 16898 }, { 8, 17090 }, { 8, 17282 }, { 8, 17474 }, { 8, 17666 } }, /* 395 */
    { { 16, 16714 }, { 16, 16906 }, { 16, 17098 }, { 16, 17290 }, { 16, 17482 }, { 16, 17674 } }, /* 396 */
    { { 16, 16730 }, { 16, 16922 }, { 16, 17114 }, { 16, 17306 }, { 16, 17498 }, { 16, 17690 } }, /* 397 */
    { { 16, 16746 }, { 16, 16938 }, { 16, 17130 }, { 16, 17322 }, { 16, 17514 }, { 16, 17706 } }, /* 398 */
    { { 16, 16762 }, { 16, 16954 }, { 16, 17146 }, { 16, 17338 }, { 16, 17530 }, { 16, 17722 } }, /* 399 */
    { { 16, 16778 }, { 16, 16970 }, { 16, 17162 }, { 16, 17354 }, { 16, 17546 }, { 16, 17738 } }, /* 400 */
    { { 16, 16794 }, { 16, 16986 }, { 16, 17178 }, { 16, 17370 }, { 16, 17562 }, { 16, 17754 } }, /* 401 */
    { { 16, 16810 }, { 16, 17002 }, { 16, 17194 }, { 16, 17386 }, { 16, 17578 }, { 16, 17770 } }, /* 402 */
    { { 8, 17786 }, { 8, 17978 }, { 8, 18170 }, { 8, 18362 }, { 8, 18554 }, { 8, 18746 } }, /* 403 */
    { { 16, 17794 }, { 16, 17986 }, { 16, 18178 }, { 16, 18370 }, { 16, 18562 }, { 16, 18754 } }, /* 404 */
    { { 8, 17810 }, { 8, 18002 }, { 8, 18194 }, { 8, 18386 }, { 8, 18578 }, { 8, 18770 } }, /* 405 */
    { { 8, 17818 }, { 8, 18010 }, { 8, 18202 }, { 8, 18394 }, { 8, 18586 }, { 8, 18778 } }, /* 406 */
    { { 8, 17826 }, { 8, 18018 }, { 8, 18210 }, { 8, 18402 }, { 8, 18594 }, { 8, 18786 } }, /* 407 */
    { { 8, 17834 }, { 8, 18026 }, { 8, 18218 }, { 8, 18410 }, { 8, 18602 }, { 8, 18794 } }, /* 408 */
    { { 8, 17842 }, { 8, 18034 }, { 8, 18226 }, { 8, 18418 }, { 8, 18610 }, { 8, 18802 } }, /* 409 */
    { { 8, 17850 }, { 8, 18042 }, { 8, 18234 }, { 8, 18426 }, { 8, 18618 }, { 8, 18810 } }, /* 410 */
    { { 8, 17858 }, { 8, 18050 }, { 8, 18242 }, { 8, 18434 }, { 8, 18626 }, { 8, 18818 } }, /* 411 */
    { { 16, 17866 }, { 16, 18058 }, { 16, 18250 }, { 16, 18442 }, { 16, 18634 }, { 16, 18826 } }, /* 412 */
    { { 16, 17882 }, { 16, 18074 }, { 16, 18266 }, { 16, 18458 }, { 16, 18650 }, { 16, 18842 } }, /* 413 */
    { { 16, 17898 }, { 16, 18090 }, { 16, 18282 }, { 16, 18474 }, { 16, 18666 }, { 16, 18858 } }, /* 414 */
    { { 16, 17914 }, { 16, 18106 }, { 16, 18298 }, { 16, 18490 }, { 16, 18682 }, { 16, 18874 } }, /* 415 */
    { { 16, 17930 }, { 16, 18122 }, { 16, 18314 }, { 16, 18506 }, { 16, 18698 }, { 16, 18890 } }, /* 416 */
    { { 16, 17946 }, { 16, 18138 }, { 16, 18330 }, { 16, 18522 }, { 16, 18714 }, { 16, 18906 } }, /* 417 */
    { { 16, 17962 }, { 16, 18154 }, { 16, 18346 }, { 16, 18538 }, { 16, 18730 }, { 16, 18922 } }, /* 418 */
    { { 8, 18938 }, { 8, 19130 }, { 8, 19322 }, { 8, 19514 }, { 8, 19706 }, { 8, 19898 } }, /* 419 */
    { { 16, 18946 }, { 16, 19138 }, { 16, 19330 }, { 16, 19522 }, { 16, 19714 }, { 16, 19906 } }, /* 420 */
    { { 8, 18962 }, { 8, 19154 }, { 8, 19346 }, { 8, 19538 }, { 8, 19730 }, { 8, 19922 } }, /* 421 */
    { { 8, 18970 }, { 8, 19162 }, { 8, 19354 }, { 8, 19546 }, { 8, 19738 }, { 8, 19930 } }, /* 422 */
    { { 8, 18978 }, { 8, 19170 }, { 8, 19362 }, { 8, 19554 }, { 8, 19746 }, { 8, 19938 } }, /* 423 */
    { { 8, 18986 }, { 8, 19178 }, { 8, 19370 }, { 8, 19562 }, { 8, 19754 }, { 8, 19946 } }, /* 424 */
    { { 8, 18994 }, { 8, 19186 }, { 8, 19378 }, { 8, 19570 }, { 8, 19762 }, { 8, 19954 } }, /* 425 */
    { { 8, 19002 }, { 8, 19194 }, { 8, 19386 }, { 8, 19578 }, { 8, 19770 }, { 8, 19962 } }, /* 426 */
    { { 8, 19010 }, { 8, 19202 }, { 8, 19394 }, { 8, 19586 }, { 8, 19778 }, { 8, 19970 } }, /* 427 */
    { { 16, 19018 }, { 16, 19210 }, { 16, 19402 }, { 16, 19594 }, { 16, 19786 }, { 16, 19978 } }, /* 428 */
    { { 16, 19034 }, { 16, 19226 }, { 16, 19418 }, { 16, 19610 }, { 16, 19802 }, { 16, 19994 } }, /* 429 */
    { { 16, 19050 }, { 16, 19242 }, { 16, 19434 }, { 16, 19626 }, { 16, 19818 }, { 16, 20010 } }, /* 430 */
    { { 16, 19066 }, { 16, 19258 }, { 16, 19450 }, { 16, 19642 }, { 16, 19834 }, { 16, 20026 } }, /* 431 */
    { { 16, 19082 }, { 16, 19274 }, { 16, 19466 }, { 16, 19658 }, { 16, 19850 }, { 16, 20042 } }, /* 432 */
    { { 16, 19098 }, { 16, 19290 }, { 16, 19482 }, { 16, 19674 }, { 16, 19866 }, { 16, 20058 } }, /* 433 */
    { { 16, 19114 }, { 16, 19306 }, { 16, 19498 }, { 16, 19690 }, { 16, 19882 }, { 16, 20074 } }, /* 434 */
    { { 8, 20090 }, { 8, 20282 }, { 8, 20474 }, { 8, 20666 }, { 8, 20858 }, { 8, 21050 } }, /* 435 */
    { { 16, 20098 }, { 16, 20290 }, { 16, 20482 }, { 16, 20674 }, { 16, 20866 }, { 16, 21058 } }, /* 436 */
    { { 8, 20114 }, { 8, 20306 }, { 8, 20498 }, { 8, 20690 }, { 8, 20882 }, { 8, 21074 } }, /* 437 */
    { { 8, 20122 }, { 8, 20314 }, { 8, 20506 }, { 8, 20698 }, { 8, 20890 }, { 8, 21082 } }, /* 438 */
    { { 8, 20130 }, { 8, 20322 }, { 8, 20514 }, { 8, 20706 }, { 8, 20898 }, { 8, 21090 } }, /* 439 */
    { { 8, 20138 }, { 8, 20330 }, { 8, 20522 }, { 8, 20714 }, { 8, 20906 }, { 8, 21098 } }, /* 440 */
    { { 8, 20146 }, { 8, 20338 }, { 8, 20530 }, { 8, 20722 }, { 8, 20914 }, { 8, 21106 } }, /* 441 */
    { { 8, 20154 }, { 8, 20346 }, { 8, 20538 }, { 8, 20730 }, { 8, 20922 }, { 8, 21114 } }, /* 442 */
    { { 8, 20162 }, { 8, 20354 }, { 8, 20546 }, { 8, 20738 }, { 8, 20930 }, { 8, 21122 } }, /* 443 */
    { { 16, 20170 }, { 16, 20362 }, { 16, 20554 }, { 16, 20746 }, { 16, 20938 }, { 16, 21130 } }, /* 444 */
    { { 16, 20186 }, { 16, 20378 }, { 16, 20570 }, { 16, 20762 }, { 16, 20954 }, { 16, 21146 } }, /* 445 */
    { { 16, 20202 }, { 16, 20394 }, { 16, 20586 }, { 16, 20778 }, { 16, 20970 }, { 16, 21162 } }, /* 446 */
    { { 16, 20218 }, { 16, 20410 }, { 16, 20602 }, { 16, 20794 }, { 16, 20986 }, { 16, 21178 } }, /* 447 */
    { { 16, 20234 }, { 16, 20426 }, { 16, 20618 }, { 16, 20810 }, { 16, 21002 }, { 16, 21194 } }, /* 448 */
    { { 16, 20250 }, { 16, 20442 }, { 16, 20634 }, { 16, 20826 }, { 16, 21018 }, { 16, 21210 } }, /* 449 */
    { { 16, 20266 }, { 16, 20458 }, { 16, 20650 }, { 16, 20842 }, { 16, 21034 }, { 16, 21226 } }, /* 450 */
    { { 8, 21242 }, { 8, 21386 }, { 8, 21530 } }, /* 451 */
    { { 16, 21250 }, { 16, 21394 }, { 16, 21538 } }, /* 452 */
    { { 8, 21266 }, { 8, 21410 }, { 8, 21554 } }, /* 453 */
    { { 8, 21274 }, { 8, 21418 }, { 8, 21562 } }, /* 454 */
    { { 8, 21282 }, { 8, 21426 }, { 8, 21570 } }, /* 455 */
    { { 8, 21290 }, { 8, 21434 }, { 8, 21578 } }, /* 456 */
    { { 8, 21298 }, { 8, 21442 }, { 8, 21586 } }, /* 457 */
    { { 16, 21306 }, { 16, 21450 }, { 16, 21594 } }, /* 458 */
    { { 16, 21322 }, { 16, 21466 }, { 16, 21610 } }, /* 459 */
    { { 16, 21338 }, { 16, 21482 }, { 16, 21626 } }, /* 460 */
    { { 16, 21354 }, { 16, 21498 }, { 16, 21642 } }, /* 461 */
    { { 16, 21370 }, { 16, 21514 }, { 16, 21658 } }, /* 462 */
    { { 8, 21674 }, { 8, 21818 }, { 8, 21962 } }, /* 463 */
    { { 16, 21682 }, { 16, 21826 }, { 16, 21970 } }, /* 464 */
    { { 8, 21698 }, { 8, 21842 }, { 8, 21986 } }, /* 465 */
    { { 8, 21706 }, { 8, 21850 }, { 8, 21994 } }, /* 466 */
    { { 8, 21714 }, { 8, 21858 }, { 8, 22002 } }, /* 467 */
    { { 8, 21722 }, { 8, 21866 }, { 8, 22010 } }, /* 468 */
    { { 8, 21730 }, { 8, 21874 }, { 8, 22018 } }, /* 469 */
    { { 16, 21738 }, { 16, 21882 }, { 16, 22026 } }, /* 470 */
    { { 16, 21754 }, { 16, 21898 }, { 16, 22042 } }, /* 471 */
    { { 16, 21770 }, { 16, 21914 }, { 16, 22058 } }, /* 472 */
    { { 16, 21786 }, { 16, 21930 }, { 16, 22074 } }, /* 473 */
    { { 16, 21802 }, { 16, 21946 }, { 16, 22090 } }, /* 474 */
    { { 8, 22106 }, { 8, 22298 }, { 8, 22490 }, { 8, 22682 }, { 8, 22874 }, { 8, 23066 } }, /* 475 */
    { { 16, 22114 }, { 16, 22306 }, { 16, 22498 }, { 16, 22690 }, { 16, 22882 }, { 16, 23074 } }, /* 476 */
    { { 8, 22130 }, { 8, 22322 }, { 8, 22514 }, { 8, 22706 }, { 8, 22898 }, { 8, 23090 } }, /* 477 */
    { { 8, 22138 }, { 8, 22330 }, { 8, 22522 }, { 8, 22714 }, { 8, 22906 }, { 8, 23098 } }, /* 478 */
    { { 8, 22146 }, { 8, 22338 }, { 8, 22530 }, { 8, 22722 }, { 8, 22914 }, { 8, 23106 } }, /* 479 */
    { { 8, 22154 }, { 8, 22346 }, { 8, 22538 }, { 8, 22730 }, { 8, 22922 }, { 8, 23114 } }, /* 480 */
    { { 8, 22162 }, { 8, 22354 }, { 8, 22546 }, { 8, 22738 }, { 8, 22930 }, { 8, 23122 } }, /* 481 */
    { { 8, 22170 }, { 8, 22362 }, { 8, 22554 }, { 8, 22746 }, { 8, 22938 }, { 8, 23130 } }, /* 482 */
    { { 8, 22178 }, { 8, 22370 }, { 8, 22562 }, { 8, 22754 }, { 8, 22946 }, { 8, 23138 } }, /* 483 */
    { { 16, 22186 }, { 16, 22378 }, { 16, 22570 }, { 16, 22762 }, { 16, 22954 }, { 16, 23146 } }, /* 484 */
    { { 16, 22202 }, { 16, 22394 }, { 16, 22586 }, { 16, 22778 }, { 16, 22970 }, { 16, 23162 } }, /* 485 */
    { { 16, 22218 }, { 16, 22410 }, { 16, 22602 }, { 16, 22794 }, { 16, 22986 }, { 16, 23178 } }, /* 486 */
    { { 16, 22234 }, { 16, 22426 }, { 16, 22618 }, { 16, 22810 }, { 16, 23002 }, { 16, 23194 } }, /* 487 */
    { { 16, 22250 }, { 16, 22442 }, { 16, 22634 }, { 16, 22826 }, { 16, 23018 }, { 16, 23210 } }, /* 488 */
    { { 16, 22266 }, { 16, 22458 }, { 16, 22650 }, { 16, 22842 }, { 16, 23034 }, { 16, 23226 } }, /* 489 */
    { { 16, 22282 }, { 16, 22474 }, { 16, 22666 }, { 16, 22858 }, { 16, 23050 }, { 16, 23242 } }, /* 490 */
    { { 8, 23258 }, { 8, 23402 }, { 8, 23546 } }, /* 491 */
    { { 16, 23266 }, { 16, 23410 }, { 16, 23554 } }, /* 492 */
    { { 8, 23282 }, { 8, 23426 }, { 8, 23570 } }, /* 493 */
    { { 8, 23290 }, { 8, 23434 }, { 8, 23578 } }, /* 494 */
    { { 8, 23298 }, { 8, 23442 }, { 8, 23586 } }, /* 495 */
    { { 8, 23306 }, { 8, 23450 }, { 8, 23594 } }, /* 496 */
    { { 8, 23314 }, { 8, 23458 }, { 8, 23602 } }, /* 497 */
    { { 16, 23322 }, { 16, 23466 }, { 16, 23610 } }, /* 498 */
    { { 16, 23338 }, { 16, 23482 }, { 16, 23626 } }, /* 499 */
    { { 16, 23354 }, { 16, 23498 }, { 16, 23642 } }, /* 500 */
    { { 16, 23370 }, { 16, 23514 }, { 16, 23658 } }, /* 501 */
    { { 16, 23386 }, { 16, 23530 }, { 16, 23674 } }, /* 502 */
    { { 8, 23690 }, { 8, 23834 }, { 8, 23978 }, { 8, 24122 }, { 8, 24266 }, { 8, 24410 } }, /* 503 */
    { { 16, 23698 }, { 16, 23842 }, { 16, 23986 }, { 16, 24130 }, { 16, 24274 }, { 16, 24418 } }, /* 504 */
    { { 8, 23714 }, { 8, 23858 }, { 8, 24002 }, { 8, 24146 }, { 8, 24290 }, { 8, 24434 } }, /* 505 */
    { { 8, 23722 }, { 8, 23866 }, { 8, 24010 }, { 8, 24154 }, { 8, 24298 }, { 8, 24442 } }, /* 506 */
    { { 8, 23730 }, { 8, 23874 }, { 8, 24018 }, { 8, 24162 }, { 8, 24306 }, { 8, 24450 } }, /* 507 */
    { { 8, 23738 }, { 8, 23882 }, { 8, 24026 }, { 8, 24170 }, { 8, 24314 }, { 8, 24458 } }, /* 508 */
    { { 8, 23746 }, { 8, 23890 }, { 8, 24034 }, { 8, 24178 }, { 8, 24322 }, { 8, 24466 } }, /* 509 */
    { { 16, 23754 }, { 16, 23898 }, { 16, 24042 }, { 16, 24186 }, { 16, 24330 }, { 16, 24474 } }, /* 510 */
    { { 16, 23770 }, { 16, 23914 }, { 16, 24058 }, { 16, 24202 }, { 16, 24346 }, { 16, 24490 } }, /* 511 */
    { { 16, 23786 }, { 16, 23930 }, { 16, 24074 }, { 16, 24218 }, { 16, 24362 }, { 16, 24506 } }, /* 512 */
    { { 16, 23802 }, { 16, 23946 }, { 16, 24090 }, { 16, 24234 }, { 16, 24378 }, { 16, 24522 } }, /* 513 */
    { { 16, 23818 }, { 16, 23962 }, { 16, 24106 }, { 16, 24250 }, { 16, 24394 }, { 16, 24538 } }, /* 514 */
    { { 8, 24554 }, { 8, 24746 }, { 8, 24938 }, { 8, 25130 }, { 8, 25322 }, { 8, 25514 } }, /* 515 */
    { { 16, 24562 }, { 16, 24754 }, { 16, 24946 }, { 16, 25138 }, { 16, 25330 }, { 16, 25522 } }, /* 516 */
    { { 8, 24578 }, { 8, 24770 }, { 8, 24962 }, { 8, 25154 }, { 8, 25346 }, { 8, 25538 } }, /* 517 */
    { { 8, 24586 }, { 8, 24778 }, { 8, 24970 }, { 8, 25162 }, { 8, 25354 }, { 8, 25546 } }, /* 518 */
    { { 8, 24594 }, { 8, 24786 }, { 8, 24978 }, { 8, 25170 }, { 8, 25362 }, { 8, 25554 } }, /* 519 */
    { { 8, 24602 }, { 8, 24794 }, { 8, 24986 }, { 8, 25178 }, { 8, 25370 }, { 8, 25562 } }, /* 520 */
    { { 8, 24610 }, { 8, 24802 }, { 8, 24994 }, { 8, 25186 }, { 8, 25378 }, { 8, 25570 } }, /* 521 */
    { { 8, 24618 }, { 8, 24810 }, { 8, 25002 }, { 8, 25194 }, { 8, 25386 }, { 8, 25578 } }, /* 522 */
    { { 8, 24626 }, { 8, 24818 }, { 8, 25010 }, { 8, 25202 }, { 8, 25394 }, { 8, 25586 } }, /* 523 */
    { { 16, 24634 }, { 16, 24826 }, { 16, 25018 }, { 16, 25210 }, { 16, 25402 }, { 16, 25594 } }, /* 524 */
    { { 16, 24650 }, { 16, 24842 }, { 16, 25034 }, { 16, 25226 }, { 16, 25418 }, { 16, 25610 } }, /* 525 */
    { { 16, 24666 }, { 16, 24858 }, { 16, 25050 }, { 16, 25242 }, { 16, 25434 }, { 16, 25626 } }, /* 526 */
    { { 16, 24682 }, { 16, 24874 }, { 16, 25066 }, { 16, 25258 }, { 16, 25450 }, { 16, 25642 } }, /* 527 */
    { { 16, 24698 }, { 16, 24890 }, { 16, 25082 }, { 16, 25274 }, { 16, 25466 }, { 16, 25658 } }, /* 528 */
    { { 16, 24714 }, { 16, 24906 }, { 16, 25098 }, { 16, 25290 }, { 16, 25482 }, { 16, 25674 } }, /* 529 */
    { { 16, 24730 }, { 16, 24922 }, { 16, 25114 }, { 16, 25306 }, { 16, 25498 }, { 16, 25690 } }, /* 530 */
    { { 8, 25706 }, { 8, 25802 } }, /* 531 */
    { { 16, 25714 }, { 16, 25810 } }, /* 532 */
    { { 8, 25730 }, { 8, 25826 } }, /* 533 */
    { { 8, 25738 }, { 8, 25834 } }, /* 534 */
    { { 8, 25746 }, { 8, 25842 } }, /* 535 */
    { { 16, 25754 }, { 16, 25850 } }, /* 536 */
    { { 16, 25770 }, { 16, 25866 } }, /* 537 */
    { { 16, 25786 }, { 16, 25882 } }, /* 538 */
    { { 8, 25898 }, { 8, 26090 }, { 8, 26282 }, { 8, 26474 }, { 8, 26666 }, { 8, 26858 } }, /* 539 */
    { { 16, 25906 }, { 16, 26098 }, { 16, 26290 }, { 16, 26482 }, { 16, 26674 }, { 16, 26866 } }, /* 540 */
    { { 8, 25922 }, { 8, 26114 }, { 8, 26306 }, { 8, 26498 }, { 8, 26690 }, { 8, 26882 } }, /* 541 */
    { { 8, 25930 }, { 8, 26122 }, { 8, 26314 }, { 8, 26506 }, { 8, 26698 }, { 8, 26890 } }, /* 542 */
    { { 8, 25938 }, { 8, 26130 }, { 8, 26322 }, { 8, 26514 }, { 8, 26706 }, { 8, 26898 } }, /* 543 */
    { { 8, 25946 }, { 8, 26138 }, { 8, 26330 }, { 8, 26522 }, { 8, 26714 }, { 8, 26906 } }, /* 544 */
    { { 8, 25954 }, { 8, 26146 }, { 8, 26338 }, { 8, 26530 }, { 8, 26722 }, { 8, 26914 } }, /* 545 */
    { { 8, 25962 }, { 8, 26154 }, { 8, 26346 }, { 8, 26538 }, { 8, 26730 }, { 8, 26922 } }, /* 546 */
    { { 8, 25970 }, { 8, 26162 }, { 8, 26354 }, { 8, 26546 }, { 8, 26738 }, { 8, 26930 } }, /* 547 */
    { { 16, 25978 }, { 16, 26170 }, { 16, 26362 }, { 16, 26554 }, { 16, 26746 }, { 16, 26938 } }, /* 548 */
    { { 16, 25994 }, { 16, 26186 }, { 16, 26378 }, { 16, 26570 }, { 16, 26762 }, { 16, 26954 } }, /* 549 */
    { { 16, 26010 }, { 16, 26202 }, { 16, 26394 }, { 16, 26586 }, { 16, 26778 }, { 16, 26970 } }, /* 550 */
    { { 16, 26026 }, { 16, 26218 }, { 16, 26410 }, { 16, 26602 }, { 16, 26794 }, { 16, 26986 } }, /* 551 */
    { { 16, 26042 }, { 16, 26234 }, { 16, 26426 }, { 16, 26618 }, { 16, 26810 }, { 16, 27002 } }, /* 552 */
    { { 16, 26058 }, { 16, 26250 }, { 16, 26442 }, { 16, 26634 }, { 16, 26826 }, { 16, 27018 } }, /* 553 */
    { { 16, 26074 }, { 16, 26266 }, { 16, 26458 }, { 16, 26650 }, { 16, 26842 }, { 16, 27034 } }, /* 554 */
    { { 16, 27050 }, { 16, 27306 }, { 16, 27562 }, { 16, 27818 }, { 16, 28074 }, { 16, 28330 } }, /* 555 */
    { { 32, 27066 }, { 32, 27322 }, { 32, 27578 }, { 32, 27834 }, { 32, 28090 }, { 32, 28346 } }, /* 556 */
    { { 16, 27098 }, { 16, 27354 }, { 16, 27610 }, { 16, 27866 }, { 16, 28122 }, { 16, 28378 } }, /* 557 */
    { { 16, 27114 }, { 16, 27370 }, { 16, 27626 }, { 16, 27882 }, { 16, 28138 }, { 16, 28394 } }, /* 558 */
    { { 16, 27130 }, { 16, 27386 }, { 16, 27642 }, { 16, 27898 }, { 16, 28154 }, { 16, 28410 } }, /* 559 */
    { { 16, 27146 }, { 16, 27402 }, { 16, 27658 }, { 16, 27914 }, { 16, 28170 }, { 16, 28426 } }, /* 560 */
    { { 16, 27162 }, { 16, 27418 }, { 16, 27674 }, { 16, 27930 }, { 16, 28186 }, { 16, 28442 } }, /* 561 */
    { { 16, 27178 }, { 16, 27434 }, { 16, 27690 }, { 16, 27946 }, { 16, 28202 }, { 16, 28458 } }, /* 562 */
    { { 16, 27194 }, { 16, 27450 }, { 16, 27706 }, { 16, 27962 }, { 16, 28218 }, { 16, 28474 } }, /* 563 */
    { { 32, 27210 }, { 32, 27466 }, { 32, 27722 }, { 32, 27978 }, { 32, 28234 }, { 32, 28490 } }, /* 564 */
    { { 32, 27242 }, { 32, 27498 }, { 32, 27754 }, { 32, 28010 }, { 32, 28266 }, { 32, 28522 } }, /* 565 */
    { { 32, 27274 }, { 32, 27530 }, { 32, 27786 }, { 32, 28042 }, { 32, 28298 }, { 32, 28554 } }, /* 566 */
    { { 16, 28586 }, { 16, 28842 }, { 16, 29098 }, { 16, 29354 }, { 16, 29610 }, { 16, 29866 } }, /* 567 */
    { { 32, 28602 }, { 32, 28858 }, { 32, 29114 }, { 32, 29370 }, { 32, 29626 }, { 32, 29882 } }, /* 568 */
    { { 16, 28634 }, { 16, 28890 }, { 16, 29146 }, { 16, 29402 }, { 16, 29658 }, { 16, 29914 } }, /* 569 */
    { { 16, 28650 }, { 16, 28906 }, { 16, 29162 }, { 16, 29418 }, { 16, 29674 }, { 16, 29930 } }, /* 570 */
    { { 16, 28666 }, { 16, 28922 }, { 16, 29178 }, { 16, 29434 }, { 16, 29690 }, { 16, 29946 } }, /* 571 */
    { { 16, 28682 }, { 16, 28938 }, { 16, 29194 }, { 16, 29450 }, { 16, 29706 }, { 16, 29962 } }, /* 572 */
    { { 16, 28698 }, { 16, 28954 }, { 16, 29210 }, { 16, 29466 }, { 16, 29722 }, { 16, 29978 } }, /* 573 */
    { { 16, 28714 }, { 16, 28970 }, { 16, 29226 }, { 16, 29482 }, { 16, 29738 }, { 16, 29994 } }, /* 574 */
    { { 16, 28730 }, { 16, 28986 }, { 16, 29242 }, { 16, 29498 }, { 16, 29754 }, { 16, 30010 } }, /* 575 */
    { { 32, 28746 }, { 32, 29002 }, { 32, 29258 }, { 32, 29514 }, { 32, 29770 }, { 32, 30026 } }, /* 576 */
    { { 32, 28778 }, { 32, 29034 }, { 32, 29290 }, { 32, 29546 }, { 32, 29802 }, { 32, 30058 } }, /* 577 */
    { { 32, 28810 }, { 32, 29066 }, { 32, 29322 }, { 32, 29578 }, { 32, 29834 }, { 32, 30090 } }, /* 578 */
    { { 16, 30122 }, { 16, 30346 }, { 16, 30570 } }, /* 579 */
    { { 32, 30138 }, { 32, 30362 }, { 32, 30586 } }, /* 580 */
    { { 16, 30170 }, { 16, 30394 }, { 16, 30618 } }, /* 581 */
    { { 16, 30186 }, { 16, 30410 }, { 16, 30634 } }, /* 582 */
    { { 16, 30202 }, { 16, 30426 }, { 16, 30650 } }, /* 583 */
    { { 16, 30218 }, { 16, 30442 }, { 16, 30666 } }, /* 584 */
    { { 16, 30234 }, { 16, 30458 }, { 16, 30682 } }, /* 585 */
    { { 32, 30250 }, { 32, 30474 }, { 32, 30698 } }, /* 586 */
    { { 32, 30282 }, { 32, 30506 }, { 32, 30730 } }, /* 587 */
    { { 32, 30314 }, { 32, 30538 }, { 32, 30762 } }, /* 588 */
    { { 16, 30794 }, { 16, 31018 }, { 16, 31242 } }, /* 589 */
    { { 32, 30810 }, { 32, 31034 }, { 32, 31258 } }, /* 590 */
    { { 16, 30842 }, { 16, 31066 }, { 16, 31290 } }, /* 591 */
    { { 16, 30858 }, { 16, 31082 }, { 16, 31306 } }, /* 592 */
    { { 16, 30874 }, { 16, 31098 }, { 16, 31322 } }, /* 593 */
    { { 16, 30890 }, { 16, 31114 }, { 16, 31338 } }, /* 594 */
    { { 16, 30906 }, { 16, 31130 }, { 16, 31354 } }, /* 595 */
    { { 32, 30922 }, { 32, 31146 }, { 32, 31370 } }, /* 596 */
    { { 32, 30954 }, { 32, 31178 }, { 32, 31402 } }, /* 597 */
    { { 32, 30986 }, { 32, 31210 }, { 32, 31434 } }, /* 598 */
    { { 16, 31466 }, { 16, 31690 }, { 16, 31914 }, { 16, 32138 }, { 16, 32362 }, { 16, 32586 } }, /* 599 */
    { { 32, 31482 }, { 32, 31706 }, { 32, 31930 }, { 32, 32154 }, { 32, 32378 }, { 32, 32602 } }, /* 600 */
    { { 16, 31514 }, { 16, 31738 }, { 16, 31962 }, { 16, 32186 }, { 16, 32410 }, { 16, 32634 } }, /* 601 */
    { { 16, 31530 }, { 16, 31754 }, { 16, 31978 }, { 16, 32202 }, { 16, 32426 }, { 16, 32650 } }, /* 602 */
    { { 16, 31546 }, { 16, 31770 }, { 16, 31994 }, { 16, 32218 }, { 16, 32442 }, { 16, 32666 } }, /* 603 */
    { { 16, 31562 }, { 16, 31786 }, { 16, 32010 }, { 16, 32234 }, { 16, 32458 }, { 16, 32682 } }, /* 604 */
    { { 16, 31578 }, { 16, 31802 }, { 16, 32026 }, { 16, 32250 }, { 16, 32474 }, { 16, 32698 } }, /* 605 */
    { { 32, 31594 }, { 32, 31818 }, { 32, 32042 }, { 32, 32266 }, { 32, 32490 }, { 32, 32714 } }, /* 606 */
    { { 32, 31626 }, { 32, 31850 }, { 32, 32074 }, { 32, 32298 }, { 32, 32522 }, { 32, 32746 } }, /* 607 */
    { { 32, 31658 }, { 32, 31882 }, { 32, 32106 }, { 32, 32330 }, { 32, 32554 }, { 32, 32778 } }, /* 608 */
    { { 16, 32810 }, { 16, 33034 }, { 16, 33258 }, { 16, 33482 }, { 16, 33706 }, { 16, 33930 }, { 16, 34154 }, { 16, 34378 }, { 16, 34602 }, { 16, 34826 }, { 16, 35050 }, { 16, 35274 } }, /* 609 */
    { { 32, 32826 }, { 32, 33050 }, { 32, 33274 }, { 32, 33498 }, { 32, 33722 }, { 32, 33946 }, { 32, 34170 }, { 32, 34394 }, { 32, 34618 }, { 32, 34842 }, { 32, 35066 }, { 32, 35290 } }, /* 610 */
    { { 16, 32858 }, { 16, 33082 }, { 16, 33306 }, { 16, 33530 }, { 16, 33754 }, { 16, 33978 }, { 16, 34202 }, { 16, 34426 }, { 16, 34650 }, { 16, 34874 }, { 16, 35098 }, { 16, 35322 } }, /* 611 */
    { { 16, 32874 }, { 16, 33098 }, { 16, 33322 }, { 16, 33546 }, { 16, 33770 }, { 16, 33994 }, { 16, 34218 }, { 16, 34442 }, { 16, 34666 }, { 16, 34890 }, { 16, 35114 }, { 16, 35338 } }, /* 612 */
    { { 16, 32890 }, { 16, 33114 }, { 16, 33338 }, { 16, 33562 }, { 16, 33786 }, { 16, 34010 }, { 16, 34234 }, { 16, 34458 }, { 16, 34682 }, { 16, 34906 }, { 16, 35130 }, { 16, 35354 } }, /* 613 */
    { { 16, 32906 }, { 16, 33130 }, { 16, 33354 }, { 16, 33578 }, { 16, 33802 }, { 16, 34026 }, { 16, 34250 }, { 16, 34474 }, { 16, 34698 }, { 16, 34922 }, { 16, 35146 }, { 16, 35370 } }, /* 614 */
    { { 16, 32922 }, { 16, 33146 }, { 16, 33370 }, { 16, 33594 }, { 16, 33818 }, { 16, 34042 }, { 16, 34266 }, { 16, 34490 }, { 16, 34714 }, { 16, 34938 }, { 16, 35162 }, { 16, 35386 } }, /* 615 */
    { { 32, 32938 }, { 32, 33162 }, { 32, 33386 }, { 32, 33610 }, { 32, 33834 }, { 32, 34058 }, { 32, 34282 }, { 32, 34506 }, { 32, 34730 }, { 32, 34954 }, { 32, 35178 }, { 32, 35402 } }, /* 616 */
    { { 32, 32970 }, { 32, 33194 }, { 32, 33418 }, { 32, 33642 }, { 32, 33866 }, { 32, 34090 }, { 32, 34314 }, { 32, 34538 }, { 32, 34762 }, { 32, 34986 }, { 32, 35210 }, { 32, 35434 } }, /* 617 */
    { { 32, 33002 }, { 32, 33226 }, { 32, 33450 }, { 32, 33674 }, { 32, 33898 }, { 32, 34122 }, { 32, 34346 }, { 32, 34570 }, { 32, 34794 }, { 32, 35018 }, { 32, 35242 }, { 32, 35466 } }, /* 618 */
    { { 32, 35498 } }, /* 619 */
    { { 64, 35530 } }, /* 620 */
    { { 32, 35594 } }, /* 621 */
    { { 32, 35626 } }, /* 622 */
    { { 32, 35658 } }, /* 623 */
    { { 64, 35690 } }, /* 624 */
    { { 32, 35754 }, { 32, 36010 } }, /* 625 */
    { { 64, 35786 }, { 64, 36042 } }, /* 626 */
    { { 32, 35850 }, { 32, 36106 } }, /* 627 */
    { { 32, 35882 }, { 32, 36138 } }, /* 628 */
    { { 32, 35914 }, { 32, 36170 } }, /* 629 */
    { { 64, 35946 }, { 64, 36202 } }, /* 630 */
    { { 16, 36266 } }, /* 631 */
    { { 32, 36282 } }, /* 632 */
    { { 16, 36314 } }, /* 633 */
    { { 16, 36330 } }, /* 634 */
    { { 16, 36346 } }, /* 635 */
    { { 32, 36362 } }, /* 636 */
    { { 16, 36394 }, { 16, 36586 }, { 16, 36778 } }, /* 637 */
    { { 32, 36410 }, { 32, 36602 }, { 32, 36794 } }, /* 638 */
    { { 16, 36442 }, { 16, 36634 }, { 16, 36826 } }, /* 639 */
    { { 16, 36458 }, { 16, 36650 }, { 16, 36842 } }, /* 640 */
    { { 16, 36474 }, { 16, 36666 }, { 16, 36858 } }, /* 641 */
    { { 16, 36490 }, { 16, 36682 }, { 16, 36874 } }, /* 642 */
    { { 16, 36506 }, { 16, 36698 }, { 16, 36890 } }, /* 643 */
    { { 32, 36522 }, { 32, 36714 }, { 32, 36906 } }, /* 644 */
    { { 32, 36554 }, { 32, 36746 }, { 32, 36938 } }, /* 645 */
    { { 16, 36970 }, { 16, 37098 } }, /* 646 */
    { { 32, 36986 }, { 32, 37114 } }, /* 647 */
    { { 16, 37018 }, { 16, 37146 } }, /* 648 */
    { { 16, 37034 }, { 16, 37162 } }, /* 649 */
    { { 16, 37050 }, { 16, 37178 } }, /* 650 */
    { { 32, 37066 }, { 32, 37194 } }, /* 651 */
    { { 16, 37226 }, { 16, 37418 }, { 16, 37610 }, { 16, 37802 }, { 16, 37994 }, { 16, 38186 } }, /* 652 */
    { { 32, 37242 }, { 32, 37434 }, { 32, 37626 }, { 32, 37818 }, { 32, 38010 }, { 32, 38202 } }, /* 653 */
    { { 16, 37274 }, { 16, 37466 }, { 16, 37658 }, { 16, 37850 }, { 16, 38042 }, { 16, 38234 } }, /* 654 */
    { { 16, 37290 }, { 16, 37482 }, { 16, 37674 }, { 16, 37866 }, { 16, 38058 }, { 16, 38250 } }, /* 655 */
    { { 16, 37306 }, { 16, 37498 }, { 16, 37690 }, { 16, 37882 }, { 16, 38074 }, { 16, 38266 } }, /* 656 */
    { { 16, 37322 }, { 16, 37514 }, { 16, 37706 }, { 16, 37898 }, { 16, 38090 }, { 16, 38282 } }, /* 657 */
    { { 16, 37338 }, { 16, 37530 }, { 16, 37722 }, { 16, 37914 }, { 16, 38106 }, { 16, 38298 } }, /* 658 */
    { { 32, 37354 }, { 32, 37546 }, { 32, 37738 }, { 32, 37930 }, { 32, 38122 }, { 32, 38314 } }, /* 659 */
    { { 32, 37386 }, { 32, 37578 }, { 32, 37770 }, { 32, 37962 }, { 32, 38154 }, { 32, 38346 } }, /* 660 */
    { { 4, 38378 } }, /* 661 */
    { { 8, 38382 } }, /* 662 */
    { { 4, 38390 } }, /* 663 */
    { { 8, 38394 } }, /* 664 */
    { { 8, 38402 } }, /* 665 */
    { { 8, 38410 } }, /* 666 */
    { { 4, 38418 } }, /* 667 */
    { { 8, 38422 } }, /* 668 */
    { { 4, 38430 } }, /* 669 */
    { { 8, 38434 } }, /* 670 */
    { { 8, 38442 } }, /* 671 */
    { { 8, 38450 } }, /* 672 */
    { { 4, 38458 } }, /* 673 */
    { { 8, 38462 } }, /* 674 */
    { { 4, 38470 } }, /* 675 */
    { { 8, 38474 } }, /* 676 */
    { { 8, 38482 } }, /* 677 */
    { { 8, 38490 } }, /* 678 */
    { { 4, 38498 } }, /* 679 */
    { { 8, 38502 } }, /* 680 */
    { { 4, 38510 } }, /* 681 */
    { { 8, 38514 } }, /* 682 */
    { { 8, 38522 } }, /* 683 */
    { { 8, 38530 } }, /* 684 */
    { { 8, 38538 } }, /* 685 */
    { { 16, 38546 } }, /* 686 */
    { { 8, 38562 } }, /* 687 */
    { { 16, 38570 } }, /* 688 */
    { { 8, 38586 } }, /* 689 */
    { { 16, 38594 } }, /* 690 */
    { { 8, 38610 } }, /* 691 */
    { { 16, 38618 } }, /* 692 */
    { { 4, 38634 } }, /* 693 */
    { { 8, 38638 } }, /* 694 */
    { { 4, 38646 } }, /* 695 */
    { { 8, 38650 } }, /* 696 */
    { { 8, 38658 } }, /* 697 */
    { { 8, 38666 } }, /* 698 */
    { { 8, 38674 } }, /* 699 */
    { { 16, 38682 } }, /* 700 */
    { { 8, 38698 } }, /* 701 */
    { { 16, 38706 } }, /* 702 */
    { { 8, 38722 } }, /* 703 */
    { { 16, 38730 } }, /* 704 */
    { { 8, 38746 } }, /* 705 */
    { { 8, 38754 } }, /* 706 */
    { { 8, 38762 } }, /* 707 */
    { { 16, 38770 } }, /* 708 */
    { { 16, 38786 } }, /* 709 */
    { { 16, 38802 } }, /* 710 */
    { { 8, 38818 } }, /* 711 */
    { { 16, 38826 } }, /* 712 */
    { { 8, 38842 } }, /* 713 */
    { { 8, 38850 } }, /* 714 */
    { { 8, 38858 } }, /* 715 */
    { { 16, 38866 } }, /* 716 */
    { { 16, 38882 } }, /* 717 */
    { { 16, 38898 } }, /* 718 */
    { { 8, 38914 }, { 8, 39010 } }, /* 719 */
    { { 16, 38922 }, { 16, 39018 } }, /* 720 */
    { { 8, 38938 }, { 8, 39034 } }, /* 721 */
    { { 8, 38946 }, { 8, 39042 } }, /* 722 */
    { { 8, 38954 }, { 8, 39050 } }, /* 723 */
    { { 16, 38962 }, { 16, 39058 } }, /* 724 */
    { { 16, 38978 }, { 16, 39074 } }, /* 725 */
    { { 16, 38994 }, { 16, 39090 } }, /* 726 */
    { { 8, 39106 }, { 8, 39202 } }, /* 727 */
    { { 16, 39114 }, { 16, 39210 } }, /* 728 */
    { { 8, 39130 }, { 8, 39226 } }, /* 729 */
    { { 8, 39138 }, { 8, 39234 } }, /* 730 */
    { { 8, 39146 }, { 8, 39242 } }, /* 731 */
    { { 16, 39154 }, { 16, 39250 } }, /* 732 */
    { { 16, 39170 }, { 16, 39266 } }, /* 733 */
    { { 16, 39186 }, { 16, 39282 } }, /* 734 */
    { { 16, 39298 } }, /* 735 */
    { { 32, 39314 } }, /* 736 */
    { { 16, 39346 } }, /* 737 */
    { { 16, 39362 } }, /* 738 */
    { { 16, 39378 } }, /* 739 */
    { { 32, 39394 } }, /* 740 */
    { { 16, 39426 }, { 16, 39554 } }, /* 741 */
    { { 32, 39442 }, { 32, 39570 } }, /* 742 */
    { { 16, 39474 }, { 16, 39602 } }, /* 743 */
    { { 16, 39490 }, { 16, 39618 } }, /* 744 */
    { { 16, 39506 }, { 16, 39634 } }, /* 745 */
    { { 32, 39522 }, { 32, 39650 } }, /* 746 */
    { { 8, 39682 } }, /* 747 */
    { { 16, 39690 } }, /* 748 */
    { { 8, 39706 } }, /* 749 */
    { { 8, 39714 } }, /* 750 */
    { { 8, 39722 } }, /* 751 */
    { { 16, 39730 } }, /* 752 */
    { { 16, 39746 } }, /* 753 */
    { { 16, 39762 } }, /* 754 */
    { { 8, 39778 } }, /* 755 */
    { { 16, 39786 } }, /* 756 */
    { { 8, 39802 } }, /* 757 */
    { { 8, 39810 } }, /* 758 */
    { { 8, 39818 } }, /* 759 */
    { { 16, 39826 } }, /* 760 */
    { { 16, 39842 } }, /* 761 */
    { { 16, 39858 } }, /* 762 */
    { { 8, 39874 } }, /* 763 */
    { { 16, 39882 } }, /* 764 */
    { { 8, 39898 } }, /* 765 */
    { { 8, 39906 } }, /* 766 */
    { { 8, 39914 } }, /* 767 */
    { { 16, 39922 } }, /* 768 */
    { { 16, 39938 } }, /* 769 */
    { { 16, 39954 } }, /* 770 */
    { { 8, 39970 } }, /* 771 */
    { { 16, 39978 } }, /* 772 */
    { { 8, 39994 } }, /* 773 */
    { { 8, 40002 } }, /* 774 */
    { { 8, 40010 } }, /* 775 */
    { { 16, 40018 } }, /* 776 */
    { { 16, 40034 } }, /* 777 */
    { { 16, 40050 } }, /* 778 */
    { { 8, 40066 } }, /* 779 */
    { { 16, 40074 } }, /* 780 */
    { { 8, 40090 } }, /* 781 */
    { { 8, 40098 } }, /* 782 */
    { { 8, 40106 } }, /* 783 */
    { { 16, 40114 } }, /* 784 */
    { { 16, 40130 } }, /* 785 */
    { { 16, 40146 } }, /* 786 */
    { { 8, 40162 } }, /* 787 */
    { { 16, 40170 } }, /* 788 */
    { { 8, 40186 } }, /* 789 */
    { { 8, 40194 } }, /* 790 */
    { { 8, 40202 } }, /* 791 */
    { { 16, 40210 } }, /* 792 */
    { { 16, 40226 } }, /* 793 */
    { { 16, 40242 } }, /* 794 */
    { { 8, 40258 } }, /* 795 */
    { { 16, 40266 } }, /* 796 */
    { { 8, 40282 } }, /* 797 */
    { { 8, 40290 } }, /* 798 */
    { { 8, 40298 } }, /* 799 */
    { { 16, 40306 } }, /* 800 */
    { { 16, 40322 } }, /* 801 */
    { { 16, 40338 } }, /* 802 */
    { { 8, 40354 } }, /* 803 */
    { { 16, 40362 } }, /* 804 */
    { { 8, 40378 } }, /* 805 */
    { { 8, 40386 } }, /* 806 */
    { { 8, 40394 } }, /* 807 */
    { { 16, 40402 } }, /* 808 */
    { { 16, 40418 } }, /* 809 */
    { { 16, 40434 } }, /* 810 */
    { { 16, 40450 } }, /* 811 */
    { { 32, 40466 } }, /* 812 */
    { { 16, 40498 } }, /* 813 */
    { { 16, 40514 } }, /* 814 */
    { { 16, 40530 } }, /* 815 */
    { { 32, 40546 } }, /* 816 */
    { { 16, 40578 } }, /* 817 */
    { { 32, 40594 } }, /* 818 */
    { { 16, 40626 } }, /* 819 */
    { { 16, 40642 } }, /* 820 */
    { { 16, 40658 } }, /* 821 */
    { { 32, 40674 } }, /* 822 */
    { { 8, 40706 } }, /* 823 */
    { { 16, 40714 } }, /* 824 */
    { { 8, 40730 } }, /* 825 */
    { { 8, 40738 } }, /* 826 */
    { { 8, 40746 } }, /* 827 */
    { { 16, 40754 } }, /* 828 */
    { { 16, 40770 } }, /* 829 */
    { { 16, 40786 } }, /* 830 */
    { { 8, 40802 } }, /* 831 */
    { { 16, 40810 } }, /* 832 */
    { { 8, 40826 } }, /* 833 */
    { { 8, 40834 } }, /* 834 */
    { { 8, 40842 } }, /* 835 */
    { { 16, 40850 } }, /* 836 */
    { { 16, 40866 } }, /* 837 */
    { { 16, 40882 } }, /* 838 */
    { { 8, 40898 } }, /* 839 */
    { { 16, 40906 } }, /* 840 */
    { { 8, 40922 } }, /* 841 */
    { { 8, 40930 } }, /* 842 */
    { { 8, 40938 } }, /* 843 */
    { { 16, 40946 } }, /* 844 */
    { { 16, 40962 } }, /* 845 */
    { { 16, 40978 } }, /* 846 */
    { { 8, 40994 } }, /* 847 */
    { { 16, 41002 } }, /* 848 */
    { { 8, 41018 } }, /* 849 */
    { { 8, 41026 } }, /* 850 */
    { { 8, 41034 } }, /* 851 */
    { { 16, 41042 } }, /* 852 */
    { { 16, 41058 } }, /* 853 */
    { { 16, 41074 } }, /* 854 */
    { { 8, 41090 } }, /* 855 */
    { { 16, 41098 } }, /* 856 */
    { { 8, 41114 } }, /* 857 */
    { { 8, 41122 } }, /* 858 */
    { { 8, 41130 } }, /* 859 */
    { { 16, 41138 } }, /* 860 */
    { { 16, 41154 } }, /* 861 */
    { { 16, 41170 } }, /* 862 */
    { { 8, 41186 } }, /* 863 */
    { { 16, 41194 } }, /* 864 */
    { { 8, 41210 } }, /* 865 */
    { { 8, 41218 } }, /* 866 */
    { { 8, 41226 } }, /* 867 */
    { { 16, 41234 } }, /* 868 */
    { { 16, 41250 } }, /* 869 */
    { { 16, 41266 } }, /* 870 */
    { { 8, 41282 } }, /* 871 */
    { { 16, 41290 } }, /* 872 */
    { { 8, 41306 } }, /* 873 */
    { { 8, 41314 } }, /* 874 */
    { { 8, 41322 } }, /* 875 */
    { { 16, 41330 } }, /* 876 */
    { { 16, 41346 } }, /* 877 */
    { { 16, 41362 } }, /* 878 */
    { { 8, 41378 } }, /* 879 */
    { { 16, 41386 } }, /* 880 */
    { { 8, 41402 } }, /* 881 */
    { { 8, 41410 } }, /* 882 */
    { { 8, 41418 } }, /* 883 */
    { { 16, 41426 } }, /* 884 */
    { { 16, 41442 } }, /* 885 */
    { { 16, 41458 } }, /* 886 */
    { { 16, 41474 } }, /* 887 */
    { { 32, 41490 } }, /* 888 */
    { { 16, 41522 } }, /* 889 */
    { { 16, 41538 } }, /* 890 */
    { { 16, 41554 } }, /* 891 */
    { { 32, 41570 } }, /* 892 */
    { { 16, 41602 } }, /* 893 */
    { { 32, 41618 } }, /* 894 */
    { { 16, 41650 } }, /* 895 */
    { { 16, 41666 } }, /* 896 */
    { { 16, 41682 } }, /* 897 */
    { { 32, 41698 } }, /* 898 */
    { { 16, 41730 } }, /* 899 */
    { { 32, 41746 } }, /* 900 */
    { { 16, 41778 } }, /* 901 */
    { { 16, 41794 } }, /* 902 */
    { { 16, 41810 } }, /* 903 */
    { { 32, 41826 } }, /* 904 */
    { { 16, 41858 } }, /* 905 */
    { { 32, 41874 } }, /* 906 */
    { { 16, 41906 } }, /* 907 */
    { { 16, 41922 } }, /* 908 */
    { { 16, 41938 } }, /* 909 */
    { { 32, 41954 } }, /* 910 */
    { { 8, 41986 } }, /* 911 */
    { { 16, 41994 } }, /* 912 */
    { { 8, 42010 } }, /* 913 */
    { { 8, 42018 } }, /* 914 */
    { { 8, 42026 } }, /* 915 */
    { { 16, 42034 } }, /* 916 */
    { { 16, 42050 } }, /* 917 */
    { { 16, 42066 } }, /* 918 */
    { { 8, 42082 } }, /* 919 */
    { { 16, 42090 } }, /* 920 */
    { { 8, 42106 } }, /* 921 */
    { { 8, 42114 } }, /* 922 */
    { { 8, 42122 } }, /* 923 */
    { { 16, 42130 } }, /* 924 */
    { { 16, 42146 } }, /* 925 */
    { { 16, 42162 } }, /* 926 */
    { { 8, 42178 } }, /* 927 */
    { { 16, 42186 } }, /* 928 */
    { { 8, 42202 } }, /* 929 */
    { { 8, 42210 } }, /* 930 */
    { { 8, 42218 } }, /* 931 */
    { { 16, 42226 } }, /* 932 */
    { { 16, 42242 } }, /* 933 */
    { { 16, 42258 } }, /* 934 */
    { { 8, 42274 } }, /* 935 */
    { { 16, 42282 } }, /* 936 */
    { { 8, 42298 } }, /* 937 */
    { { 8, 42306 } }, /* 938 */
    { { 8, 42314 } }, /* 939 */
    { { 16, 42322 } }, /* 940 */
    { { 16, 42338 } }, /* 941 */
    { { 16, 42354 } }, /* 942 */
    { { 8, 42370 } }, /* 943 */
    { { 16, 42378 } }, /* 944 */
    { { 8, 42394 } }, /* 945 */
    { { 8, 42402 } }, /* 946 */
    { { 8, 42410 } }, /* 947 */
    { { 16, 42418 } }, /* 948 */
    { { 16, 42434 } }, /* 949 */
    { { 16, 42450 } }, /* 950 */
    { { 8, 42466 } }, /* 951 */
    { { 16, 42474 } }, /* 952 */
    { { 8, 42490 } }, /* 953 */
    { { 8, 42498 } }, /* 954 */
    { { 8, 42506 } }, /* 955 */
    { { 16, 42514 } }, /* 956 */
    { { 16, 42530 } }, /* 957 */
    { { 16, 42546 } }, /* 958 */
    { { 8, 42562 } }, /* 959 */
    { { 16, 42570 } }, /* 960 */
    { { 8, 42586 } }, /* 961 */
    { { 8, 42594 } }, /* 962 */
    { { 8, 42602 } }, /* 963 */
    { { 16, 42610 } }, /* 964 */
    { { 16, 42626 } }, /* 965 */
    { { 16, 42642 } }, /* 966 */
    { { 8, 42658 } }, /* 967 */
    { { 16, 42666 } }, /* 968 */
    { { 8, 42682 } }, /* 969 */
    { { 8, 42690 } }, /* 970 */
    { { 8, 42698 } }, /* 971 */
    { { 16, 42706 } }, /* 972 */
    { { 16, 42722 } }, /* 973 */
    { { 16, 42738 } }, /* 974 */
    { { 16, 42754 } }, /* 975 */
    { { 32, 42770 } }, /* 976 */
    { { 16, 42802 } }, /* 977 */
    { { 16, 42818 } }, /* 978 */
    { { 16, 42834 } }, /* 979 */
    { { 32, 42850 } }, /* 980 */
    { { 16, 42882 } }, /* 981 */
    { { 32, 42898 } }, /* 982 */
    { { 16, 42930 } }, /* 983 */
    { { 16, 42946 } }, /* 984 */
    { { 16, 42962 } }, /* 985 */
    { { 32, 42978 } }, /* 986 */
    { { 16, 43010 } }, /* 987 */
    { { 32, 43026 } }, /* 988 */
    { { 16, 43058 } }, /* 989 */
    { { 16, 43074 } }, /* 990 */
    { { 16, 43090 } }, /* 991 */
    { { 32, 43106 } }, /* 992 */
    { { 16, 43138 } }, /* 993 */
    { { 32, 43154 } }, /* 994 */
    { { 16, 43186 } }, /* 995 */
    { { 16, 43202 } }, /* 996 */
    { { 16, 43218 } }, /* 997 */
    { { 32, 43234 } }, /* 998 */
    { { 16, 43266 } }, /* 999 */
    { { 32, 43282 } }, /* 1000 */
    { { 16, 43314 } }, /* 1001 */
    { { 16, 43330 } }, /* 1002 */
    { { 16, 43346 } }, /* 1003 */
    { { 16, 43362 } }, /* 1004 */
    { { 16, 43378 } }, /* 1005 */
    { { 16, 43394 } }, /* 1006 */
    { { 16, 43410 } }, /* 1007 */
    { { 32, 43426 } }, /* 1008 */
    { { 32, 43458 } }, /* 1009 */
    { { 32, 43490 } }, /* 1010 */
    { { 16, 43522 } }, /* 1011 */
    { { 32, 43538 } }, /* 1012 */
    { { 16, 43570 } }, /* 1013 */
    { { 16, 43586 } }, /* 1014 */
    { { 16, 43602 } }, /* 1015 */
    { { 16, 43618 } }, /* 1016 */
    { { 16, 43634 } }, /* 1017 */
    { { 16, 43650 } }, /* 1018 */
    { { 16, 43666 } }, /* 1019 */
    { { 32, 43682 } }, /* 1020 */
    { { 32, 43714 } }, /* 1021 */
    { { 32, 43746 } }, /* 1022 */
    { { 16, 43778 }, { 16, 44034 } }, /* 1023 */
    { { 32, 43794 }, { 32, 44050 } }, /* 1024 */
    { { 16, 43826 }, { 16, 44082 } }, /* 1025 */
    { { 16, 43842 }, { 16, 44098 } }, /* 1026 */
    { { 16, 43858 }, { 16, 44114 } }, /* 1027 */
    { { 16, 43874 }, { 16, 44130 } }, /* 1028 */
    { { 16, 43890 }, { 16, 44146 } }, /* 1029 */
    { { 16, 43906 }, { 16, 44162 } }, /* 1030 */
    { { 16, 43922 }, { 16, 44178 } }, /* 1031 */
    { { 32, 43938 }, { 32, 44194 } }, /* 1032 */
    { { 32, 43970 }, { 32, 44226 } }, /* 1033 */
    { { 32, 44002 }, { 32, 44258 } }, /* 1034 */
    { { 16, 44290 }, { 16, 44546 } }, /* 1035 */
    { { 32, 44306 }, { 32, 44562 } }, /* 1036 */
    { { 16, 44338 }, { 16, 44594 } }, /* 1037 */
    { { 16, 44354 }, { 16, 44610 } }, /* 1038 */
    { { 16, 44370 }, { 16, 44626 } }, /* 1039 */
    { { 16, 44386 }, { 16, 44642 } }, /* 1040 */
    { { 16, 44402 }, { 16, 44658 } }, /* 1041 */
    { { 16, 44418 }, { 16, 44674 } }, /* 1042 */
    { { 16, 44434 }, { 16, 44690 } }, /* 1043 */
    { { 32, 44450 }, { 32, 44706 } }, /* 1044 */
    { { 32, 44482 }, { 32, 44738 } }, /* 1045 */
    { { 32, 44514 }, { 32, 44770 } }, /* 1046 */
    { { 16, 44802 } }, /* 1047 */
    { { 32, 44818 } }, /* 1048 */
    { { 16, 44850 } }, /* 1049 */
    { { 16, 44866 } }, /* 1050 */
    { { 16, 44882 } }, /* 1051 */
    { { 16, 44898 } }, /* 1052 */
    { { 16, 44914 } }, /* 1053 */
    { { 16, 44930 } }, /* 1054 */
    { { 16, 44946 } }, /* 1055 */
    { { 32, 44962 } }, /* 1056 */
    { { 32, 44994 } }, /* 1057 */
    { { 32, 45026 } }, /* 1058 */
    { { 16, 45058 } }, /* 1059 */
    { { 32, 45074 } }, /* 1060 */
    { { 16, 45106 } }, /* 1061 */
    { { 16, 45122 } }, /* 1062 */
    { { 16, 45138 } }, /* 1063 */
    { { 16, 45154 } }, /* 1064 */
    { { 16, 45170 } }, /* 1065 */
    { { 16, 45186 } }, /* 1066 */
    { { 16, 45202 } }, /* 1067 */
    { { 32, 45218 } }, /* 1068 */
    { { 32, 45250 } }, /* 1069 */
    { { 32, 45282 } }, /* 1070 */
    { { 16, 45314 }, { 16, 45570 } }, /* 1071 */
    { { 32, 45330 }, { 32, 45586 } }, /* 1072 */
    { { 16, 45362 }, { 16, 45618 } }, /* 1073 */
    { { 16, 45378 }, { 16, 45634 } }, /* 1074 */
    { { 16, 45394 }, { 16, 45650 } }, /* 1075 */
    { { 16, 45410 }, { 16, 45666 } }, /* 1076 */
    { { 16, 45426 }, { 16, 45682 } }, /* 1077 */
    { { 16, 45442 }, { 16, 45698 } }, /* 1078 */
    { { 16, 45458 }, { 16, 45714 } }, /* 1079 */
    { { 32, 45474 }, { 32, 45730 } }, /* 1080 */
    { { 32, 45506 }, { 32, 45762 } }, /* 1081 */
    { { 32, 45538 }, { 32, 45794 } }, /* 1082 */
    { { 16, 45826 }, { 16, 46082 } }, /* 1083 */
    { { 32, 45842 }, { 32, 46098 } }, /* 1084 */
    { { 16, 45874 }, { 16, 46130 } }, /* 1085 */
    { { 16, 45890 }, { 16, 46146 } }, /* 1086 */
    { { 16, 45906 }, { 16, 46162 } }, /* 1087 */
    { { 16, 45922 }, { 16, 46178 } }, /* 1088 */
    { { 16, 45938 }, { 16, 46194 } }, /* 1089 */
    { { 16, 45954 }, { 16, 46210 } }, /* 1090 */
    { { 16, 45970 }, { 16, 46226 } }, /* 1091 */
    { { 32, 45986 }, { 32, 46242 } }, /* 1092 */
    { { 32, 46018 }, { 32, 46274 } }, /* 1093 */
    { { 32, 46050 }, { 32, 46306 } }, /* 1094 */
    { { 16, 46338 } }, /* 1095 */
    { { 32, 46354 } }, /* 1096 */
    { { 16, 46386 } }, /* 1097 */
    { { 16, 46402 } }, /* 1098 */
    { { 16, 46418 } }, /* 1099 */
    { { 16, 46434 } }, /* 1100 */
    { { 16, 46450 } }, /* 1101 */
    { { 16, 46466 } }, /* 1102 */
    { { 16, 46482 } }, /* 1103 */
    { { 32, 46498 } }, /* 1104 */
    { { 32, 46530 } }, /* 1105 */
    { { 32, 46562 } }, /* 1106 */
    { { 16, 46594 } }, /* 1107 */
    { { 32, 46610 } }, /* 1108 */
    { { 16, 46642 } }, /* 1109 */
    { { 16, 46658 } }, /* 1110 */
    { { 16, 46674 } }, /* 1111 */
    { { 16, 46690 } }, /* 1112 */
    { { 16, 46706 } }, /* 1113 */
    { { 16, 46722 } }, /* 1114 */
    { { 16, 46738 } }, /* 1115 */
    { { 32, 46754 } }, /* 1116 */
    { { 32, 46786 } }, /* 1117 */
    { { 32, 46818 } }, /* 1118 */
    { { 16, 46850 }, { 16, 47106 } }, /* 1119 */
    { { 32, 46866 }, { 32, 47122 } }, /* 1120 */
    { { 16, 46898 }, { 16, 47154 } }, /* 1121 */
    { { 16, 46914 }, { 16, 47170 } }, /* 1122 */
    { { 16, 46930 }, { 16, 47186 } }, /* 1123 */
    { { 16, 46946 }, { 16, 47202 } }, /* 1124 */
    { { 16, 46962 }, { 16, 47218 } }, /* 1125 */
    { { 16, 46978 }, { 16, 47234 } }, /* 1126 */
    { { 16, 46994 }, { 16, 47250 } }, /* 1127 */
    { { 32, 47010 }, { 32, 47266 } }, /* 1128 */
    { { 32, 47042 }, { 32, 47298 } }, /* 1129 */
    { { 32, 47074 }, { 32, 47330 } }, /* 1130 */
    { { 16, 47362 }, { 16, 47618 } }, /* 1131 */
    { { 32, 47378 }, { 32, 47634 } }, /* 1132 */
    { { 16, 47410 }, { 16, 47666 } }, /* 1133 */
    { { 16, 47426 }, { 16, 47682 } }, /* 1134 */
    { { 16, 47442 }, { 16, 47698 } }, /* 1135 */
    { { 16, 47458 }, { 16, 47714 } }, /* 1136 */
    { { 16, 47474 }, { 16, 47730 } }, /* 1137 */
    { { 16, 47490 }, { 16, 47746 } }, /* 1138 */
    { { 16, 47506 }, { 16, 47762 } }, /* 1139 */
    { { 32, 47522 }, { 32, 47778 } }, /* 1140 */
    { { 32, 47554 }, { 32, 47810 } }, /* 1141 */
    { { 32, 47586 }, { 32, 47842 } }, /* 1142 */
    { { 16, 47874 } }, /* 1143 */
    { { 32, 47890 } }, /* 1144 */
    { { 16, 47922 } }, /* 1145 */
    { { 16, 47938 } }, /* 1146 */
    { { 16, 47954 } }, /* 1147 */
    { { 16, 47970 } }, /* 1148 */
    { { 16, 47986 } }, /* 1149 */
    { { 16, 48002 } }, /* 1150 */
    { { 16, 48018 } }, /* 1151 */
    { { 32, 48034 } }, /* 1152 */
    { { 32, 48066 } }, /* 1153 */
    { { 32, 48098 } }, /* 1154 */
    { { 16, 48130 } }, /* 1155 */
    { { 32, 48146 } }, /* 1156 */
    { { 16, 48178 } }, /* 1157 */
    { { 16, 48194 } }, /* 1158 */
    { { 16, 48210 } }, /* 1159 */
    { { 16, 48226 } }, /* 1160 */
    { { 16, 48242 } }, /* 1161 */
    { { 16, 48258 } }, /* 1162 */
    { { 16, 48274 } }, /* 1163 */
    { { 32, 48290 } }, /* 1164 */
    { { 32, 48322 } }, /* 1165 */
    { { 32, 48354 } }, /* 1166 */
    { { 16, 48386 }, { 16, 48642 } }, /* 1167 */
    { { 32, 48402 }, { 32, 48658 } }, /* 1168 */
    { { 16, 48434 }, { 16, 48690 } }, /* 1169 */
    { { 16, 48450 }, { 16, 48706 } }, /* 1170 */
    { { 16, 48466 }, { 16, 48722 } }, /* 1171 */
    { { 16, 48482 }, { 16, 48738 } }, /* 1172 */
    { { 16, 48498 }, { 16, 48754 } }, /* 1173 */
    { { 16, 48514 }, { 16, 48770 } }, /* 1174 */
    { { 16, 48530 }, { 16, 48786 } }, /* 1175 */
    { { 32, 48546 }, { 32, 48802 } }, /* 1176 */
    { { 32, 48578 }, { 32, 48834 } }, /* 1177 */
    { { 32, 48610 }, { 32, 48866 } }, /* 1178 */
    { { 16, 48898 }, { 16, 49154 } }, /* 1179 */
    { { 32, 48914 }, { 32, 49170 } }, /* 1180 */
    { { 16, 48946 }, { 16, 49202 } }, /* 1181 */
    { { 16, 48962 }, { 16, 49218 } }, /* 1182 */
    { { 16, 48978 }, { 16, 49234 } }, /* 1183 */
    { { 16, 48994 }, { 16, 49250 } }, /* 1184 */
    { { 16, 49010 }, { 16, 49266 } }, /* 1185 */
    { { 16, 49026 }, { 16, 49282 } }, /* 1186 */
    { { 16, 49042 }, { 16, 49298 } }, /* 1187 */
    { { 32, 49058 }, { 32, 49314 } }, /* 1188 */
    { { 32, 49090 }, { 32, 49346 } }, /* 1189 */
    { { 32, 49122 }, { 32, 49378 } }, /* 1190 */
    { { 32, 49410 } }, /* 1191 */
    { { 64, 49442 } }, /* 1192 */
    { { 32, 49506 } }, /* 1193 */
    { { 32, 49538 } }, /* 1194 */
    { { 32, 49570 } }, /* 1195 */
    { { 32, 49602 } }, /* 1196 */
    { { 32, 49634 } }, /* 1197 */
    { { 32, 49666 } }, /* 1198 */
    { { 32, 49698 } }, /* 1199 */
    { { 64, 49730 } }, /* 1200 */
    { { 32, 49794 } }, /* 1201 */
    { { 64, 49826 } }, /* 1202 */
    { { 32, 49890 } }, /* 1203 */
    { { 32, 49922 } }, /* 1204 */
    { { 32, 49954 } }, /* 1205 */
    { { 32, 49986 } }, /* 1206 */
    { { 32, 50018 } }, /* 1207 */
    { { 32, 50050 } }, /* 1208 */
    { { 32, 50082 } }, /* 1209 */
    { { 64, 50114 } }, /* 1210 */
    { { 32, 50178 }, { 32, 50562 } }, /* 1211 */
    { { 64, 50210 }, { 64, 50594 } }, /* 1212 */
    { { 32, 50274 }, { 32, 50658 } }, /* 1213 */
    { { 32, 50306 }, { 32, 50690 } }, /* 1214 */
    { { 32, 50338 }, { 32, 50722 } }, /* 1215 */
    { { 32, 50370 }, { 32, 50754 } }, /* 1216 */
    { { 32, 50402 }, { 32, 50786 } }, /* 1217 */
    { { 32, 50434 }, { 32, 50818 } }, /* 1218 */
    { { 32, 50466 }, { 32, 50850 } }, /* 1219 */
    { { 64, 50498 }, { 64, 50882 } }, /* 1220 */
    { { 32, 50946 }, { 32, 51330 } }, /* 1221 */
    { { 64, 50978 }, { 64, 51362 } }, /* 1222 */
    { { 32, 51042 }, { 32, 51426 } }, /* 1223 */
    { { 32, 51074 }, { 32, 51458 } }, /* 1224 */
    { { 32, 51106 }, { 32, 51490 } }, /* 1225 */
    { { 32, 51138 }, { 32, 51522 } }, /* 1226 */
    { { 32, 51170 }, { 32, 51554 } }, /* 1227 */
    { { 32, 51202 }, { 32, 51586 } }, /* 1228 */
    { { 32, 51234 }, { 32, 51618 } }, /* 1229 */
    { { 64, 51266 }, { 64, 51650 } }, /* 1230 */
    { { 3, 51714 } }, /* 1231 */
    { { 6, 51717 } }, /* 1232 */
    { { 6, 51723 } }, /* 1233 */
    { { 3, 51729 } }, /* 1234 */
    { { 6, 51732 } }, /* 1235 */
    { { 6, 51738 } }, /* 1236 */
    { { 3, 51744 } }, /* 1237 */
    { { 6, 51747 } }, /* 1238 */
    { { 6, 51753 } }, /* 1239 */
    { { 9, 51759 }, { 3, 51804 } }, /* 1240 */
    { { 18, 51768 }, { 6, 51807 } }, /* 1241 */
    { { 18, 51786 }, { 6, 51813 } }, /* 1242 */
    { { 6, 51819 } }, /* 1243 */
    { { 12, 51825 } }, /* 1244 */
    { { 6, 51837 } }, /* 1245 */
    { { 12, 51843 } }, /* 1246 */
    { { 18, 51855 }, { 6, 51963 } }, /* 1247 */
    { { 36, 51873 }, { 12, 51969 } }, /* 1248 */
    { { 18, 51909 }, { 6, 51981 } }, /* 1249 */
    { { 36, 51927 }, { 12, 51987 } }, /* 1250 */
    { { 6, 51999 } }, /* 1251 */
    { { 12, 52005 } }, /* 1252 */
    { { 6, 52017 } }, /* 1253 */
    { { 12, 52023 } }, /* 1254 */
    { { 6, 52035 } }, /* 1255 */
    { { 12, 52041 } }, /* 1256 */
    { { 6, 52053 } }, /* 1257 */
    { { 12, 52059 } }, /* 1258 */
    { { 6, 52071 } }, /* 1259 */
    { { 12, 52077 } }, /* 1260 */
    { { 6, 52089 } }, /* 1261 */
    { { 12, 52095 } }, /* 1262 */
    { { 6, 52107 } }, /* 1263 */
    { { 12, 52113 } }, /* 1264 */
    { { 6, 52125 } }, /* 1265 */
    { { 12, 52131 } }, /* 1266 */
    { { 6, 52143 } }, /* 1267 */
    { { 12, 52149 } }, /* 1268 */
    { { 6, 52161 } }, /* 1269 */
    { { 12, 52167 } }, /* 1270 */
    { { 6, 52179 } }, /* 1271 */
    { { 12, 52185 } }, /* 1272 */
    { { 6, 52197 } }, /* 1273 */
    { { 12, 52203 } }, /* 1274 */
    { { 18, 52215 }, { 6, 52323 } }, /* 1275 */
    { { 36, 52233 }, { 12, 52329 } }, /* 1276 */
    { { 18, 52269 }, { 6, 52341 } }, /* 1277 */
    { { 36, 52287 }, { 12, 52347 } }, /* 1278 */
    { { 6, 52359 } }, /* 1279 */
    { { 12, 52365 } }, /* 1280 */
    { { 6, 52377 } }, /* 1281 */
    { { 12, 52383 } }, /* 1282 */
    { { 6, 52395 } }, /* 1283 */
    { { 12, 52401 } }, /* 1284 */
    { { 6, 52413 } }, /* 1285 */
    { { 12, 52419 } }, /* 1286 */
    { { 6, 52431 } }, /* 1287 */
    { { 12, 52437 } }, /* 1288 */
    { { 6, 52449 } }, /* 1289 */
    { { 12, 52455 } }, /* 1290 */
    { { 6, 52467 } }, /* 1291 */
    { { 12, 52473 } }, /* 1292 */
    { { 6, 52485 } }, /* 1293 */
    { { 12, 52491 } }, /* 1294 */
    { { 18, 52503 }, { 6, 52611 } }, /* 1295 */
    { { 36, 52521 }, { 12, 52617 } }, /* 1296 */
    { { 18, 52557 }, { 6, 52629 } }, /* 1297 */
    { { 36, 52575 }, { 12, 52635 } }, /* 1298 */
    { { 18, 52647 }, { 6, 52755 } }, /* 1299 */
    { { 36, 52665 }, { 12, 52761 } }, /* 1300 */
    { { 18, 52701 }, { 6, 52773 } }, /* 1301 */
    { { 36, 52719 }, { 12, 52779 } }, /* 1302 */
    { { 12, 52791 } }, /* 1303 */
    { { 24, 52803 } }, /* 1304 */
    { { 12, 52827 } }, /* 1305 */
    { { 12, 52839 } }, /* 1306 */
    { { 12, 52851 } }, /* 1307 */
    { { 24, 52863 } }, /* 1308 */
    { { 12, 52887 } }, /* 1309 */
    { { 24, 52899 } }, /* 1310 */
    { { 12, 52923 } }, /* 1311 */
    { { 12, 52935 } }, /* 1312 */
    { { 12, 52947 } }, /* 1313 */
    { { 24, 52959 } }, /* 1314 */
    { { 12, 52983 } }, /* 1315 */
    { { 24, 52995 } }, /* 1316 */
    { { 12, 53019 } }, /* 1317 */
    { { 12, 53031 } }, /* 1318 */
    { { 12, 53043 } }, /* 1319 */
    { { 24, 53055 } }, /* 1320 */
    { { 12, 53079 } }, /* 1321 */
    { { 24, 53091 } }, /* 1322 */
    { { 12, 53115 } }, /* 1323 */
    { { 12, 53127 } }, /* 1324 */
    { { 12, 53139 } }, /* 1325 */
    { { 24, 53151 } }, /* 1326 */
    { { 36, 53175 }, { 12, 53463 } }, /* 1327 */
    { { 72, 53211 }, { 24, 53475 } }, /* 1328 */
    { { 36, 53283 }, { 12, 53499 } }, /* 1329 */
    { { 36, 53319 }, { 12, 53511 } }, /* 1330 */
    { { 36, 53355 }, { 12, 53523 } }, /* 1331 */
    { { 72, 53391 }, { 24, 53535 } }, /* 1332 */
    { { 36, 53559 }, { 12, 53847 } }, /* 1333 */
    { { 72, 53595 }, { 24, 53859 } }, /* 1334 */
    { { 36, 53667 }, { 12, 53883 } }, /* 1335 */
    { { 36, 53703 }, { 12, 53895 } }, /* 1336 */
    { { 36, 53739 }, { 12, 53907 } }, /* 1337 */
    { { 72, 53775 }, { 24, 53919 } }, /* 1338 */
    { { 6, 53943 } }, /* 1339 */
    { { 12, 53949 } }, /* 1340 */
    { { 6, 53961 } }, /* 1341 */
    { { 12, 53967 } }, /* 1342 */
    { { 6, 53979 } }, /* 1343 */
    { { 12, 53985 } }, /* 1344 */
    { { 6, 53997 } }, /* 1345 */
    { { 12, 54003 } }, /* 1346 */
    { { 6, 54015 } }, /* 1347 */
    { { 12, 54021 } }, /* 1348 */
    { { 6, 54033 } }, /* 1349 */
    { { 12, 54039 } }, /* 1350 */
    { { 6, 54051 } }, /* 1351 */
    { { 12, 54057 } }, /* 1352 */
    { { 6, 54069 } }, /* 1353 */
    { { 12, 54075 } }, /* 1354 */
    { { 6, 54087 } }, /* 1355 */
    { { 12, 54093 } }, /* 1356 */
    { { 6, 54105 } }, /* 1357 */
    { { 12, 54111 } }, /* 1358 */
    { { 6, 54123 } }, /* 1359 */
    { { 12, 54129 } }, /* 1360 */
    { { 6, 54141 } }, /* 1361 */
    { { 12, 54147 } }, /* 1362 */
    { { 6, 54159 } }, /* 1363 */
    { { 12, 54165 } }, /* 1364 */
    { { 6, 54177 } }, /* 1365 */
    { { 12, 54183 } }, /* 1366 */
    { { 12, 54195 } }, /* 1367 */
    { { 24, 54207 } }, /* 1368 */
    { { 12, 54231 } }, /* 1369 */
    { { 12, 54243 } }, /* 1370 */
    { { 12, 54255 } }, /* 1371 */
    { { 24, 54267 } }, /* 1372 */
    { { 12, 54291 } }, /* 1373 */
    { { 24, 54303 } }, /* 1374 */
    { { 12, 54327 } }, /* 1375 */
    { { 12, 54339 } }, /* 1376 */
    { { 12, 54351 } }, /* 1377 */
    { { 24, 54363 } }, /* 1378 */
    { { 12, 54387 } }, /* 1379 */
    { { 24, 54399 } }, /* 1380 */
    { { 12, 54423 } }, /* 1381 */
    { { 12, 54435 } }, /* 1382 */
    { { 12, 54447 } }, /* 1383 */
    { { 24, 54459 } }, /* 1384 */
    { { 12, 54483 } }, /* 1385 */
    { { 24, 54495 } }, /* 1386 */
    { { 12, 54519 } }, /* 1387 */
    { { 12, 54531 } }, /* 1388 */
    { { 12, 54543 } }, /* 1389 */
    { { 24, 54555 } }, /* 1390 */
    { { 12, 54579 } }, /* 1391 */
    { { 24, 54591 } }, /* 1392 */
    { { 12, 54615 } }, /* 1393 */
    { { 12, 54627 } }, /* 1394 */
    { { 12, 54639 } }, /* 1395 */
    { { 24, 54651 } }, /* 1396 */
    { { 12, 54675 } }, /* 1397 */
    { { 24, 54687 } }, /* 1398 */
    { { 12, 54711 } }, /* 1399 */
    { { 12, 54723 } }, /* 1400 */
    { { 12, 54735 } }, /* 1401 */
    { { 24, 54747 } }, /* 1402 */
    { { 12, 54771 } }, /* 1403 */
    { { 24, 54783 } }, /* 1404 */
    { { 12, 54807 } }, /* 1405 */
    { { 12, 54819 } }, /* 1406 */
    { { 12, 54831 } }, /* 1407 */
    { { 24, 54843 } }, /* 1408 */
    { { 12, 54867 } }, /* 1409 */
    { { 24, 54879 } }, /* 1410 */
    { { 12, 54903 } }, /* 1411 */
    { { 12, 54915 } }, /* 1412 */
    { { 12, 54927 } }, /* 1413 */
    { { 24, 54939 } }, /* 1414 */
    { { 12, 54963 } }, /* 1415 */
    { { 24, 54975 } }, /* 1416 */
    { { 12, 54999 } }, /* 1417 */
    { { 12, 55011 } }, /* 1418 */
    { { 12, 55023 } }, /* 1419 */
    { { 24, 55035 } }, /* 1420 */
    { { 12, 55059 } }, /* 1421 */
    { { 24, 55071 } }, /* 1422 */
    { { 12, 55095 } }, /* 1423 */
    { { 12, 55107 } }, /* 1424 */
    { { 12, 55119 } }, /* 1425 */
    { { 24, 55131 } }, /* 1426 */
    { { 12, 55155 } }, /* 1427 */
    { { 24, 55167 } }, /* 1428 */
    { { 12, 55191 } }, /* 1429 */
    { { 12, 55203 } }, /* 1430 */
    { { 12, 55215 } }, /* 1431 */
    { { 24, 55227 } }, /* 1432 */
    { { 12, 55251 } }, /* 1433 */
    { { 24, 55263 } }, /* 1434 */
    { { 12, 55287 } }, /* 1435 */
    { { 12, 55299 } }, /* 1436 */
    { { 12, 55311 } }, /* 1437 */
    { { 24, 55323 } }, /* 1438 */
    { { 12, 55347 } }, /* 1439 */
    { { 24, 55359 } }, /* 1440 */
    { { 12, 55383 } }, /* 1441 */
    { { 12, 55395 } }, /* 1442 */
    { { 12, 55407 } }, /* 1443 */
    { { 24, 55419 } }, /* 1444 */
    { { 12, 55443 } }, /* 1445 */
    { { 24, 55455 } }, /* 1446 */
    { { 12, 55479 } }, /* 1447 */
    { { 12, 55491 } }, /* 1448 */
    { { 12, 55503 } }, /* 1449 */
    { { 24, 55515 } }, /* 1450 */
    { { 12, 55539 } }, /* 1451 */
    { { 24, 55551 } }, /* 1452 */
    { { 12, 55575 } }, /* 1453 */
    { { 12, 55587 } }, /* 1454 */
    { { 12, 55599 } }, /* 1455 */
    { { 24, 55611 } }, /* 1456 */
    { { 12, 55635 } }, /* 1457 */
    { { 24, 55647 } }, /* 1458 */
    { { 12, 55671 } }, /* 1459 */
    { { 12, 55683 } }, /* 1460 */
    { { 12, 55695 } }, /* 1461 */
    { { 24, 55707 } }, /* 1462 */
    { { 24, 55731 } }, /* 1463 */
    { { 48, 55755 } }, /* 1464 */
    { { 24, 55803 } }, /* 1465 */
    { { 24, 55827 } }, /* 1466 */
    { { 24, 55851 } }, /* 1467 */
    { { 24, 55875 } }, /* 1468 */
    { { 24, 55899 } }, /* 1469 */
    { { 24, 55923 } }, /* 1470 */
    { { 24, 55947 } }, /* 1471 */
    { { 48, 55971 } }, /* 1472 */
    { { 24, 56019 } }, /* 1473 */
    { { 48, 56043 } }, /* 1474 */
    { { 24, 56091 } }, /* 1475 */
    { { 24, 56115 } }, /* 1476 */
    { { 24, 56139 } }, /* 1477 */
    { { 24, 56163 } }, /* 1478 */
    { { 24, 56187 } }, /* 1479 */
    { { 24, 56211 } }, /* 1480 */
    { { 24, 56235 } }, /* 1481 */
    { { 48, 56259 } }, /* 1482 */
    { { 24, 56307 } }, /* 1483 */
    { { 48, 56331 } }, /* 1484 */
    { { 24, 56379 } }, /* 1485 */
    { { 24, 56403 } }, /* 1486 */
    { { 24, 56427 } }, /* 1487 */
    { { 24, 56451 } }, /* 1488 */
    { { 24, 56475 } }, /* 1489 */
    { { 24, 56499 } }, /* 1490 */
    { { 24, 56523 } }, /* 1491 */
    { { 48, 56547 } }, /* 1492 */
    { { 24, 56595 } }, /* 1493 */
    { { 48, 56619 } }, /* 1494 */
    { { 24, 56667 } }, /* 1495 */
    { { 24, 56691 } }, /* 1496 */
    { { 24, 56715 } }, /* 1497 */
    { { 24, 56739 } }, /* 1498 */
    { { 24, 56763 } }, /* 1499 */
    { { 24, 56787 } }, /* 1500 */
    { { 24, 56811 } }, /* 1501 */
    { { 48, 56835 } }, /* 1502 */
    { { 12, 56883 } }, /* 1503 */
    { { 24, 56895 } }, /* 1504 */
    { { 24, 56919 } }, /* 1505 */
    { { 48, 56943 } }, /* 1506 */
    { { 96, 56991 } }, /* 1507 */
    { { 96, 57087 } }, /* 1508 */
    { { 24, 57183 } }, /* 1509 */
    { { 48, 57207 } }, /* 1510 */
    { { 12, 57255 } }, /* 1511 */
    { { 24, 57267 } }, /* 1512 */
    { { 24, 57291 } }, /* 1513 */
    { { 24, 57315 } }, /* 1514 */
    { { 48, 57339 } }, /* 1515 */
    { { 24, 57387 } }, /* 1516 */
    { { 48, 57411 } }, /* 1517 */
    { { 24, 57459 } }, /* 1518 */
    { { 48, 57483 } }, /* 1519 */
    { { 24, 57531 }, { 24, 57675 } }, /* 1520 */
    { { 48, 57555 }, { 48, 57699 } }, /* 1521 */
    { { 24, 57603 }, { 24, 57747 } }, /* 1522 */
    { { 48, 57627 }, { 48, 57771 } }, /* 1523 */
    { { 96, 57819 } }, /* 1524 */
    { { 192, 57915 } }, /* 1525 */
    { { 96, 58107 } }, /* 1526 */
    { { 192, 58203 } }, /* 1527 */
    { { 96, 58395 }, { 96, 58971 } }, /* 1528 */
    { { 192, 58491 }, { 192, 59067 } }, /* 1529 */
    { { 96, 58683 }, { 96, 59259 } }, /* 1530 */
    { { 192, 58779 }, { 192, 59355 } }, /* 1531 */
    { { 48, 59547 } }, /* 1532 */
    { { 96, 59595 } }, /* 1533 */
    { { 48, 59691 } }, /* 1534 */
    { { 24, 59739 } }, /* 1535 */
    { { 48, 59763 } }, /* 1536 */
    { { 24, 59811 } }, /* 1537 */
    { { 48, 59835 } }, /* 1538 */
    { { 48, 59883 } }, /* 1539 */
    { { 96, 59931 } }, /* 1540 */
    { { 48, 60027 } }, /* 1541 */
    { { 24, 60075 } }, /* 1542 */
    { { 48, 60099 } }, /* 1543 */
    { { 24, 60147 } }, /* 1544 */
    { { 48, 60171 } }, /* 1545 */
    { { 24, 60219 } }, /* 1546 */
    { { 48, 60243 } }, /* 1547 */
    { { 24, 60291 } }, /* 1548 */
    { { 48, 60315 } }, /* 1549 */
    { { 96, 60363 } }, /* 1550 */
    { { 192, 60459 } }, /* 1551 */
    { { 96, 60651 } }, /* 1552 */
    { { 192, 60747 } }, /* 1553 */
    { { 96, 60939 } }, /* 1554 */
    { { 192, 61035 } }, /* 1555 */
    { { 96, 61227 } }, /* 1556 */
    { { 192, 61323 } }, /* 1557 */
    { { 48, 61515 } }, /* 1558 */
    { { 96, 61563 } }, /* 1559 */
    { { 48, 61659 } }, /* 1560 */
    { { 24, 61707 } }, /* 1561 */
    { { 48, 61731 } }, /* 1562 */
    { { 24, 61779 } }, /* 1563 */
    { { 48, 61803 } }, /* 1564 */
    { { 24, 61851 } }, /* 1565 */
    { { 48, 61875 } }, /* 1566 */
    { { 24, 61923 } }, /* 1567 */
    { { 48, 61947 } }, /* 1568 */
    { { 48, 61995 } }, /* 1569 */
    { { 96, 62043 } }, /* 1570 */
    { { 48, 62139 } }, /* 1571 */
    { { 24, 62187 } }, /* 1572 */
    { { 48, 62211 } }, /* 1573 */
    { { 24, 62259 } }, /* 1574 */
    { { 48, 62283 } }, /* 1575 */
    { { 96, 62331 } }, /* 1576 */
    { { 192, 62427 } }, /* 1577 */
    { { 96, 62619 } }, /* 1578 */
    { { 192, 62715 } }, /* 1579 */
    { { 48, 62907 } }, /* 1580 */
    { { 96, 62955 } }, /* 1581 */
    { { 48, 63051 } }, /* 1582 */
    { { 24, 63099 } }, /* 1583 */
    { { 48, 63123 } }, /* 1584 */
    { { 24, 63171 } }, /* 1585 */
    { { 48, 63195 } }, /* 1586 */
    { { 96, 63243 } }, /* 1587 */
    { { 192, 63339 } }, /* 1588 */
    { { 96, 63531 } }, /* 1589 */
    { { 192, 63627 } }, /* 1590 */
    { { 48, 63819 } }, /* 1591 */
    { { 96, 63867 } }, /* 1592 */
    { { 48, 63963 } }, /* 1593 */
    { { 48, 64011 } }, /* 1594 */
    { { 96, 64059 } }, /* 1595 */
    { { 48, 64155 } }, /* 1596 */
    { { 48, 64203 } }, /* 1597 */
    { { 48, 64251 } }, /* 1598 */
    { { 96, 64299 } }, /* 1599 */
    { { 48, 64395 }, { 48, 64779 } }, /* 1600 */
    { { 96, 64443 }, { 96, 64827 } }, /* 1601 */
    { { 48, 64539 }, { 48, 64923 } }, /* 1602 */
    { { 48, 64587 }, { 48, 64971 } }, /* 1603 */
    { { 48, 64635 }, { 48, 65019 } }, /* 1604 */
    { { 96, 64683 }, { 96, 65067 } }, /* 1605 */
    { { 48, 65163 } }, /* 1606 */
    { { 96, 65211 } }, /* 1607 */
    { { 48, 65307 } }, /* 1608 */
    { { 48, 65355 } }, /* 1609 */
    { { 48, 65403 } }, /* 1610 */
    { { 96, 65451 } }, /* 1611 */
    { { 48, 65547 }, { 48, 65931 } }, /* 1612 */
    { { 96, 65595 }, { 96, 65979 } }, /* 1613 */
    { { 48, 65691 }, { 48, 66075 } }, /* 1614 */
    { { 48, 65739 }, { 48, 66123 } }, /* 1615 */
    { { 48, 65787 }, { 48, 66171 } }, /* 1616 */
    { { 96, 65835 }, { 96, 66219 } }, /* 1617 */
    { { 192, 66315 } }, /* 1618 */
    { { 384, 66507 } }, /* 1619 */
    { { 192, 66891 } }, /* 1620 */
    { { 192, 67083 } }, /* 1621 */
    { { 192, 67275 } }, /* 1622 */
    { { 384, 67467 } }, /* 1623 */
    { { 192, 67851 } }, /* 1624 */
    { { 384, 68043 } }, /* 1625 */
    { { 192, 68427 } }, /* 1626 */
    { { 192, 68619 } }, /* 1627 */
    { { 192, 68811 } }, /* 1628 */
    { { 384, 69003 } }, /* 1629 */
    { { 192, 69387 }, { 192, 70923 } }, /* 1630 */
    { { 384, 69579 }, { 384, 71115 } }, /* 1631 */
    { { 192, 69963 }, { 192, 71499 } }, /* 1632 */
    { { 192, 70155 }, { 192, 71691 } }, /* 1633 */
    { { 192, 70347 }, { 192, 71883 } }, /* 1634 */
    { { 384, 70539 }, { 384, 72075 } }, /* 1635 */
    { { 192, 72459 }, { 192, 73995 } }, /* 1636 */
    { { 384, 72651 }, { 384, 74187 } }, /* 1637 */
    { { 192, 73035 }, { 192, 74571 } }, /* 1638 */
    { { 192, 73227 }, { 192, 74763 } }, /* 1639 */
    { { 192, 73419 }, { 192, 74955 } }, /* 1640 */
    { { 384, 73611 }, { 384, 75147 } }, /* 1641 */
    { { 96, 75531 } }, /* 1642 */
    { { 192, 75627 } }, /* 1643 */
    { { 96, 75819 } }, /* 1644 */
    { { 96, 75915 } }, /* 1645 */
    { { 96, 76011 } }, /* 1646 */
    { { 96, 76107 } }, /* 1647 */
    { { 192, 76203 } }, /* 1648 */
    { { 96, 76395 } }, /* 1649 */
    { { 96, 76491 } }, /* 1650 */
    { { 96, 76587 } }, /* 1651 */
};

/* clang-format off */
static const int magnetic_symmetry_operations[] = {
           0, /*dummy*/
       16484, /*     1 (   1) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
       16484, /*     2 (   2) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34028708, /*     3 (   2) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
       16484, /*     4 (   3) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34146806, /*     5 (   3) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
       16484, /*     6 (   4) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
        3198, /*     7 (   4) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
       16484, /*     8 (   5) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34028708, /*     9 (   5) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
        3198, /*    10 (   5) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    34015422, /*    11 (   5) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
       16484, /*    12 (   6) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34015422, /*    13 (   6) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
       16484, /*    14 (   7) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
        3198, /*    15 (   7) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    34146806, /*    16 (   7) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    34133520, /*    17 (   7) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
       16484, /*    18 (   8) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
        3360, /*    19 (   8) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
       16484, /*    20 (   9) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
        3360, /*    21 (   9) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    34028708, /*    22 (   9) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    34015584, /*    23 (   9) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
       16484, /*    24 (  10) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34015584, /*    25 (  10) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
       16484, /*    26 (  11) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
        3360, /*    27 (  11) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    51034820, /*    28 (  11) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  0] -1 */
    51021696, /*    29 (  11) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  0] -1 */
       16484, /*    30 (  12) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
        3360, /*    31 (  12) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    35432760, /*    32 (  12) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  0] -1 */
    35445884, /*    33 (  12) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  0] -1 */
       16484, /*    34 (  13) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
        3360, /*    35 (  13) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    52438872, /*    36 (  13) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
    52451996, /*    37 (  13) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
       16484, /*    38 (   8) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
        3200, /*    39 (   8) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
       16484, /*    40 (   9) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
        3200, /*    41 (   9) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34028708, /*    42 (   9) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    34015424, /*    43 (   9) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
       16484, /*    44 (  10) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34015424, /*    45 (  10) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
       16484, /*    46 (  11) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
        3200, /*    47 (  11) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    35445884, /*    48 (  11) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  0] -1 */
    35432600, /*    49 (  11) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  0] -1 */
       16484, /*    50 (  12) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
        3200, /*    51 (  12) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34133522, /*    52 (  12) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    34146806, /*    53 (  12) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
       16484, /*    54 (  13) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
        3200, /*    55 (  13) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    35550698, /*    56 (  13) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
    35563982, /*    57 (  13) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
       16484, /*    58 (   8) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
       16320, /*    59 (   8) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
       16484, /*    60 (   9) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
       16320, /*    61 (   9) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    34028708, /*    62 (   9) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    34028544, /*    63 (   9) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
       16484, /*    64 (  10) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34028544, /*    65 (  10) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
       16484, /*    66 (  11) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
       16320, /*    67 (  11) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    34146806, /*    68 (  11) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    34146642, /*    69 (  11) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
       16484, /*    70 (  12) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
       16320, /*    71 (  12) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    51034656, /*    72 (  12) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  0] -1 */
    51034820, /*    73 (  12) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  0] -1 */
       16484, /*    74 (  13) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
       16320, /*    75 (  13) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    51152754, /*    76 (  13) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  6] -1 */
    51152918, /*    77 (  13) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
       16484, /*    78 (  14) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
     1420536, /*    79 (  14) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  0]  1 */
       16484, /*    80 (  15) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34028708, /*    81 (  15) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
     1420536, /*    82 (  15) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  0]  1 */
    35432760, /*    83 (  15) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  0] -1 */
       16484, /*    84 (  16) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    35432760, /*    85 (  16) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  0] -1 */
       16484, /*    86 (  17) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    51034820, /*    87 (  17) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  0] -1 */
    52438872, /*    88 (  17) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
     1420536, /*    89 (  17) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  0]  1 */
       16484, /*    90 (  18) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34015584, /*    91 (  18) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
     1420536, /*    92 (  18) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  0]  1 */
    35445884, /*    93 (  18) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  0] -1 */
       16484, /*    94 (  19) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    51021696, /*    95 (  19) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  0] -1 */
     1420536, /*    96 (  19) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  0]  1 */
    52451996, /*    97 (  19) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
       16484, /*    98 (  14) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
      121298, /*    99 (  14) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6]  1 */
       16484, /*   100 (  15) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34028708, /*   101 (  15) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
      121298, /*   102 (  15) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6]  1 */
    34133522, /*   103 (  15) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
       16484, /*   104 (  16) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34133522, /*   105 (  16) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
       16484, /*   106 (  17) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    35445884, /*   107 (  17) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  0] -1 */
    35550698, /*   108 (  17) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
      121298, /*   109 (  17) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6]  1 */
       16484, /*   110 (  18) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34015424, /*   111 (  18) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
      121298, /*   112 (  18) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6]  1 */
    34146806, /*   113 (  18) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
       16484, /*   114 (  19) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    35432600, /*   115 (  19) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  0] -1 */
      121298, /*   116 (  19) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6]  1 */
    35563982, /*   117 (  19) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
       16484, /*   118 (  14) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    17022432, /*   119 (  14) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  0]  1 */
       16484, /*   120 (  15) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34028708, /*   121 (  15) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    17022432, /*   122 (  15) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  0]  1 */
    51034656, /*   123 (  15) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  0] -1 */
       16484, /*   124 (  16) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    51034656, /*   125 (  16) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  0] -1 */
       16484, /*   126 (  17) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34146806, /*   127 (  17) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    51152754, /*   128 (  17) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  6] -1 */
    17022432, /*   129 (  17) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  0]  1 */
       16484, /*   130 (  18) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34028544, /*   131 (  18) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    17022432, /*   132 (  18) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  0]  1 */
    51034820, /*   133 (  18) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  0] -1 */
       16484, /*   134 (  19) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34146642, /*   135 (  19) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
    17022432, /*   136 (  19) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  0]  1 */
    51152918, /*   137 (  19) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
       16484, /*   138 (  20) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    18439772, /*   139 (  20) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
        3360, /*   140 (  20) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    18426648, /*   141 (  20) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
       16484, /*   142 (  21) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    18426648, /*   143 (  21) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
    34015584, /*   144 (  21) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    52438872, /*   145 (  21) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
    52451996, /*   146 (  21) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
    18439772, /*   147 (  21) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
        3360, /*   148 (  21) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    34028708, /*   149 (  21) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
       16484, /*   150 (  22) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    18439772, /*   151 (  22) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    52438872, /*   152 (  22) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
    34015584, /*   153 (  22) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
       16484, /*   154 (  23) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    18426648, /*   155 (  23) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
    34146806, /*   156 (  23) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    52556970, /*   157 (  23) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    34133682, /*   158 (  23) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
    18439772, /*   159 (  23) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
        3360, /*   160 (  23) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    52570094, /*   161 (  23) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
       16484, /*   162 (  24) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    18426648, /*   163 (  24) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
    51034820, /*   164 (  24) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  0] -1 */
    51021696, /*   165 (  24) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  0] -1 */
    35432760, /*   166 (  24) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  0] -1 */
    35445884, /*   167 (  24) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  0] -1 */
    18439772, /*   168 (  24) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
        3360, /*   169 (  24) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
       16484, /*   170 (  20) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
     1551758, /*   171 (  20) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
        3360, /*   172 (  20) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
     1538634, /*   173 (  20) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
       16484, /*   174 (  21) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
     1538634, /*   175 (  21) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
    34015584, /*   176 (  21) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    35550858, /*   177 (  21) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6] -1 */
    35563982, /*   178 (  21) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
     1551758, /*   179 (  21) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
        3360, /*   180 (  21) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    34028708, /*   181 (  21) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
       16484, /*   182 (  22) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
     1551758, /*   183 (  22) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
    35550858, /*   184 (  22) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6] -1 */
    34015584, /*   185 (  22) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
       16484, /*   186 (  23) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
     1538634, /*   187 (  23) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
    51152918, /*   188 (  23) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
    52438872, /*   189 (  23) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
    51139794, /*   190 (  23) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6] -1 */
     1551758, /*   191 (  23) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
        3360, /*   192 (  23) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    52451996, /*   193 (  23) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
       16484, /*   194 (  24) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
     1538634, /*   195 (  24) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
    34146806, /*   196 (  24) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    34133682, /*   197 (  24) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
    35432760, /*   198 (  24) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  0] -1 */
    35445884, /*   199 (  24) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  0] -1 */
     1551758, /*   200 (  24) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
        3360, /*   201 (  24) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
       16484, /*   202 (  20) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    18557870, /*   203 (  20) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
        3360, /*   204 (  20) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    18544746, /*   205 (  20) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
       16484, /*   206 (  21) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    18544746, /*   207 (  21) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
    34015584, /*   208 (  21) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    52556970, /*   209 (  21) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    52570094, /*   210 (  21) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    18557870, /*   211 (  21) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
        3360, /*   212 (  21) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    34028708, /*   213 (  21) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
       16484, /*   214 (  22) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    18557870, /*   215 (  22) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    52556970, /*   216 (  22) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    34015584, /*   217 (  22) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
       16484, /*   218 (  23) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    18544746, /*   219 (  23) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
    51034820, /*   220 (  23) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  0] -1 */
    35550858, /*   221 (  23) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6] -1 */
    51021696, /*   222 (  23) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  0] -1 */
    18557870, /*   223 (  23) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
        3360, /*   224 (  23) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    35563982, /*   225 (  23) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
       16484, /*   226 (  24) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    18544746, /*   227 (  24) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
    51152918, /*   228 (  24) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
    51139794, /*   229 (  24) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6] -1 */
    35432760, /*   230 (  24) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  0] -1 */
    35445884, /*   231 (  24) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  0] -1 */
    18557870, /*   232 (  24) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
        3360, /*   233 (  24) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
       16484, /*   234 (  20) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
     1551758, /*   235 (  20) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
        3200, /*   236 (  20) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
     1538474, /*   237 (  20) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
       16484, /*   238 (  21) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
     1538474, /*   239 (  21) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
    34015424, /*   240 (  21) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    35550698, /*   241 (  21) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
    35563982, /*   242 (  21) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
     1551758, /*   243 (  21) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
        3200, /*   244 (  21) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34028708, /*   245 (  21) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
       16484, /*   246 (  22) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
     1551758, /*   247 (  22) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
    35550698, /*   248 (  22) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
    34015424, /*   249 (  22) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
       16484, /*   250 (  23) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
     1538474, /*   251 (  23) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
    51034820, /*   252 (  23) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  0] -1 */
    52556810, /*   253 (  23) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    51021536, /*   254 (  23) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  0] -1 */
     1551758, /*   255 (  23) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
        3200, /*   256 (  23) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    52570094, /*   257 (  23) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
       16484, /*   258 (  24) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
     1538474, /*   259 (  24) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
    35445884, /*   260 (  24) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  0] -1 */
    35432600, /*   261 (  24) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  0] -1 */
    34133522, /*   262 (  24) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    34146806, /*   263 (  24) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
     1551758, /*   264 (  24) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
        3200, /*   265 (  24) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
       16484, /*   266 (  20) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    17140694, /*   267 (  20) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
        3200, /*   268 (  20) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    17127410, /*   269 (  20) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
       16484, /*   270 (  21) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    17127410, /*   271 (  21) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
    34015424, /*   272 (  21) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    51139634, /*   273 (  21) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
    51152918, /*   274 (  21) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
    17140694, /*   275 (  21) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
        3200, /*   276 (  21) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34028708, /*   277 (  21) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
       16484, /*   278 (  22) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    17140694, /*   279 (  22) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
    51139634, /*   280 (  22) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
    34015424, /*   281 (  22) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
       16484, /*   282 (  23) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    17127410, /*   283 (  23) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
    52451996, /*   284 (  23) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
    35550698, /*   285 (  23) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
    52438712, /*   286 (  23) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
    17140694, /*   287 (  23) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
        3200, /*   288 (  23) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    35563982, /*   289 (  23) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
       16484, /*   290 (  24) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    17127410, /*   291 (  24) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
    51034820, /*   292 (  24) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  0] -1 */
    51021536, /*   293 (  24) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  0] -1 */
    34133522, /*   294 (  24) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    34146806, /*   295 (  24) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    17140694, /*   296 (  24) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
        3200, /*   297 (  24) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
       16484, /*   298 (  20) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    18557870, /*   299 (  20) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
        3200, /*   300 (  20) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    18544586, /*   301 (  20) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
       16484, /*   302 (  21) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    18544586, /*   303 (  21) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    34015424, /*   304 (  21) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    52556810, /*   305 (  21) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    52570094, /*   306 (  21) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    18557870, /*   307 (  21) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
        3200, /*   308 (  21) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34028708, /*   309 (  21) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
       16484, /*   310 (  22) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    18557870, /*   311 (  22) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    52556810, /*   312 (  22) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    34015424, /*   313 (  22) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
       16484, /*   314 (  23) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    18544586, /*   315 (  23) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    35445884, /*   316 (  23) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  0] -1 */
    51139634, /*   317 (  23) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
    35432600, /*   318 (  23) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  0] -1 */
    18557870, /*   319 (  23) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
        3200, /*   320 (  23) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    51152918, /*   321 (  23) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
       16484, /*   322 (  24) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    18544586, /*   323 (  24) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    52451996, /*   324 (  24) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
    52438712, /*   325 (  24) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
    34133522, /*   326 (  24) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    34146806, /*   327 (  24) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    18557870, /*   328 (  24) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
        3200, /*   329 (  24) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
       16484, /*   330 (  20) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    17140694, /*   331 (  20) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
       16320, /*   332 (  20) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    17140530, /*   333 (  20) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  6]  1 */
       16484, /*   334 (  21) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    17140530, /*   335 (  21) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  6]  1 */
    34028544, /*   336 (  21) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    51152754, /*   337 (  21) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  6] -1 */
    51152918, /*   338 (  21) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
    17140694, /*   339 (  21) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
       16320, /*   340 (  21) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    34028708, /*   341 (  21) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
       16484, /*   342 (  22) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    17140694, /*   343 (  22) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
    51152754, /*   344 (  22) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  6] -1 */
    34028544, /*   345 (  22) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
       16484, /*   346 (  23) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    17140530, /*   347 (  23) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  6]  1 */
    35445884, /*   348 (  23) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  0] -1 */
    52569930, /*   349 (  23) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    35445720, /*   350 (  23) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  0] -1 */
    17140694, /*   351 (  23) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
       16320, /*   352 (  23) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    52570094, /*   353 (  23) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
       16484, /*   354 (  24) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    17140530, /*   355 (  24) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  6]  1 */
    34146806, /*   356 (  24) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    34146642, /*   357 (  24) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
    51034656, /*   358 (  24) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  0] -1 */
    51034820, /*   359 (  24) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  0] -1 */
    17140694, /*   360 (  24) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
       16320, /*   361 (  24) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
       16484, /*   362 (  20) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    18439772, /*   363 (  20) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
       16320, /*   364 (  20) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    18439608, /*   365 (  20) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
       16484, /*   366 (  21) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    18439608, /*   367 (  21) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
    34028544, /*   368 (  21) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    52451832, /*   369 (  21) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
    52451996, /*   370 (  21) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
    18439772, /*   371 (  21) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
       16320, /*   372 (  21) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    34028708, /*   373 (  21) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
       16484, /*   374 (  22) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    18439772, /*   375 (  22) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    52451832, /*   376 (  22) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
    34028544, /*   377 (  22) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
       16484, /*   378 (  23) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    18439608, /*   379 (  23) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
    35563982, /*   380 (  23) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
    51152754, /*   381 (  23) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  6] -1 */
    35563818, /*   382 (  23) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  6] -1 */
    18439772, /*   383 (  23) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
       16320, /*   384 (  23) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    51152918, /*   385 (  23) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
       16484, /*   386 (  24) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    18439608, /*   387 (  24) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
    35445884, /*   388 (  24) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  0] -1 */
    35445720, /*   389 (  24) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  0] -1 */
    51034656, /*   390 (  24) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  0] -1 */
    51034820, /*   391 (  24) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  0] -1 */
    18439772, /*   392 (  24) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
       16320, /*   393 (  24) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
       16484, /*   394 (  20) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    18557870, /*   395 (  20) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
       16320, /*   396 (  20) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    18557706, /*   397 (  20) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
       16484, /*   398 (  21) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    18557706, /*   399 (  21) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
    34028544, /*   400 (  21) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    52569930, /*   401 (  21) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    52570094, /*   402 (  21) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    18557870, /*   403 (  21) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
       16320, /*   404 (  21) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    34028708, /*   405 (  21) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
       16484, /*   406 (  22) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    18557870, /*   407 (  22) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    52569930, /*   408 (  22) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    34028544, /*   409 (  22) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
       16484, /*   410 (  23) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    18557706, /*   411 (  23) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
    34146806, /*   412 (  23) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    52451832, /*   413 (  23) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
    34146642, /*   414 (  23) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
    18557870, /*   415 (  23) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
       16320, /*   416 (  23) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    52451996, /*   417 (  23) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
       16484, /*   418 (  24) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    18557706, /*   419 (  24) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
    35563982, /*   420 (  24) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
    35563818, /*   421 (  24) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  6] -1 */
    51034656, /*   422 (  24) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  0] -1 */
    51034820, /*   423 (  24) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  0] -1 */
    18557870, /*   424 (  24) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
       16320, /*   425 (  24) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
       16484, /*   426 (  25) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
       16322, /*   427 (  25) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
       16484, /*   428 (  26) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34028546, /*   429 (  26) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    34028708, /*   430 (  26) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
       16322, /*   431 (  26) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
       16484, /*   432 (  27) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34028546, /*   433 (  27) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
       16484, /*   434 (  28) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    51034820, /*   435 (  28) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  0] -1 */
    51034658, /*   436 (  28) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  0] -1 */
       16322, /*   437 (  28) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
       16484, /*   438 (  29) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    35445722, /*   439 (  29) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  0] -1 */
    35445884, /*   440 (  29) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  0] -1 */
       16322, /*   441 (  29) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
       16484, /*   442 (  30) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    52451834, /*   443 (  30) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
    52451996, /*   444 (  30) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
       16322, /*   445 (  30) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
       16484, /*   446 (  25) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
       16482, /*   447 (  25) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
       16484, /*   448 (  26) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34028706, /*   449 (  26) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    34028708, /*   450 (  26) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
       16482, /*   451 (  26) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
       16484, /*   452 (  27) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34028706, /*   453 (  27) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
       16484, /*   454 (  28) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    35445884, /*   455 (  28) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  0] -1 */
    35445882, /*   456 (  28) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  0] -1 */
       16482, /*   457 (  28) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
       16484, /*   458 (  29) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34146804, /*   459 (  29) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
    34146806, /*   460 (  29) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
       16482, /*   461 (  29) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
       16484, /*   462 (  30) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    35563980, /*   463 (  30) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6] -1 */
    35563982, /*   464 (  30) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
       16482, /*   465 (  30) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
       16484, /*   466 (  25) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
        3362, /*   467 (  25) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
       16484, /*   468 (  26) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34015586, /*   469 (  26) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    34028708, /*   470 (  26) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
        3362, /*   471 (  26) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
       16484, /*   472 (  27) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34015586, /*   473 (  27) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
       16484, /*   474 (  28) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34146806, /*   475 (  28) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    34133684, /*   476 (  28) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
        3362, /*   477 (  28) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
       16484, /*   478 (  29) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    51021698, /*   479 (  29) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  0] -1 */
    51034820, /*   480 (  29) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  0] -1 */
        3362, /*   481 (  29) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
       16484, /*   482 (  30) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    51139796, /*   483 (  30) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
    51152918, /*   484 (  30) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
        3362, /*   485 (  30) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
       16484, /*   486 (  31) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
      134420, /*   487 (  31) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6]  1 */
       16484, /*   488 (  32) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
      134420, /*   489 (  32) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6]  1 */
    34028708, /*   490 (  32) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    34146644, /*   491 (  32) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
       16484, /*   492 (  33) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34146644, /*   493 (  33) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
       16484, /*   494 (  34) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
      134420, /*   495 (  34) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6]  1 */
    51034820, /*   496 (  34) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  0] -1 */
    51152756, /*   497 (  34) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
       16484, /*   498 (  35) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
      134420, /*   499 (  35) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6]  1 */
    34028546, /*   500 (  35) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    34146806, /*   501 (  35) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
       16484, /*   502 (  36) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
      134420, /*   503 (  36) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6]  1 */
    35445884, /*   504 (  36) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  0] -1 */
    35563820, /*   505 (  36) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
       16484, /*   506 (  37) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
      134420, /*   507 (  37) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6]  1 */
    52569932, /*   508 (  37) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    52451996, /*   509 (  37) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
       16484, /*   510 (  38) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
      134420, /*   511 (  38) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6]  1 */
    35445722, /*   512 (  38) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  0] -1 */
    35563982, /*   513 (  38) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
       16484, /*   514 (  31) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    17140532, /*   515 (  31) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
       16484, /*   516 (  32) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    17140532, /*   517 (  32) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
    34028708, /*   518 (  32) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    51152756, /*   519 (  32) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
       16484, /*   520 (  33) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    51152756, /*   521 (  33) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
       16484, /*   522 (  34) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    17140532, /*   523 (  34) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
    34146806, /*   524 (  34) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    51034658, /*   525 (  34) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  0] -1 */
       16484, /*   526 (  35) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    17140532, /*   527 (  35) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
    34028546, /*   528 (  35) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    51152918, /*   529 (  35) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
       16484, /*   530 (  36) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    17140532, /*   531 (  36) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
    35445884, /*   532 (  36) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  0] -1 */
    52569932, /*   533 (  36) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
       16484, /*   534 (  37) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    17140532, /*   535 (  37) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
    52451834, /*   536 (  37) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
    35563982, /*   537 (  37) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
       16484, /*   538 (  38) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    17140532, /*   539 (  38) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
    35445722, /*   540 (  38) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  0] -1 */
    52570094, /*   541 (  38) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
       16484, /*   542 (  31) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    17022434, /*   543 (  31) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  0]  1 */
       16484, /*   544 (  32) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    17022434, /*   545 (  32) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  0]  1 */
    34028708, /*   546 (  32) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    51034658, /*   547 (  32) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  0] -1 */
       16484, /*   548 (  33) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    51034658, /*   549 (  33) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  0] -1 */
       16484, /*   550 (  34) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    17022434, /*   551 (  34) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  0]  1 */
    51152918, /*   552 (  34) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
    34146644, /*   553 (  34) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
       16484, /*   554 (  35) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    17022434, /*   555 (  35) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  0]  1 */
    34028546, /*   556 (  35) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    51034820, /*   557 (  35) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  0] -1 */
       16484, /*   558 (  36) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    17022434, /*   559 (  36) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  0]  1 */
    35445884, /*   560 (  36) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  0] -1 */
    52451834, /*   561 (  36) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
       16484, /*   562 (  37) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    17022434, /*   563 (  37) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  0]  1 */
    35563820, /*   564 (  37) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
    52570094, /*   565 (  37) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
       16484, /*   566 (  38) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    17022434, /*   567 (  38) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  0]  1 */
    35445722, /*   568 (  38) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  0] -1 */
    52451996, /*   569 (  38) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
       16484, /*   570 (  31) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    17022594, /*   571 (  31) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  0]  1 */
       16484, /*   572 (  32) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    17022594, /*   573 (  32) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  0]  1 */
    34028708, /*   574 (  32) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    51034818, /*   575 (  32) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  0] -1 */
       16484, /*   576 (  33) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    51034818, /*   577 (  33) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  0] -1 */
       16484, /*   578 (  34) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    17022594, /*   579 (  34) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  0]  1 */
    35445884, /*   580 (  34) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  0] -1 */
    52451994, /*   581 (  34) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
       16484, /*   582 (  35) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    17022594, /*   583 (  35) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  0]  1 */
    34028706, /*   584 (  35) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    51034820, /*   585 (  35) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  0] -1 */
       16484, /*   586 (  36) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    17022594, /*   587 (  36) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  0]  1 */
    34146806, /*   588 (  36) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    51152916, /*   589 (  36) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6] -1 */
       16484, /*   590 (  37) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    17022594, /*   591 (  37) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  0]  1 */
    52570092, /*   592 (  37) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    35563982, /*   593 (  37) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
       16484, /*   594 (  38) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    17022594, /*   595 (  38) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  0]  1 */
    34146804, /*   596 (  38) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
    51152918, /*   597 (  38) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
       16484, /*   598 (  31) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    18439770, /*   599 (  31) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
       16484, /*   600 (  32) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    18439770, /*   601 (  32) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
    34028708, /*   602 (  32) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    52451994, /*   603 (  32) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
       16484, /*   604 (  33) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    52451994, /*   605 (  33) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
       16484, /*   606 (  34) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    18439770, /*   607 (  34) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
    51034820, /*   608 (  34) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  0] -1 */
    35445882, /*   609 (  34) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  0] -1 */
       16484, /*   610 (  35) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    18439770, /*   611 (  35) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
    34028706, /*   612 (  35) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    52451996, /*   613 (  35) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
       16484, /*   614 (  36) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    18439770, /*   615 (  36) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
    34146806, /*   616 (  36) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    52570092, /*   617 (  36) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
       16484, /*   618 (  37) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    18439770, /*   619 (  37) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
    35563980, /*   620 (  37) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6] -1 */
    51152918, /*   621 (  37) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
       16484, /*   622 (  38) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    18439770, /*   623 (  38) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
    34146804, /*   624 (  38) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
    52570094, /*   625 (  38) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
       16484, /*   626 (  31) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
     1433658, /*   627 (  31) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  0]  1 */
       16484, /*   628 (  32) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
     1433658, /*   629 (  32) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  0]  1 */
    34028708, /*   630 (  32) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    35445882, /*   631 (  32) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  0] -1 */
       16484, /*   632 (  33) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    35445882, /*   633 (  33) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  0] -1 */
       16484, /*   634 (  34) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
     1433658, /*   635 (  34) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  0]  1 */
    52451996, /*   636 (  34) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
    51034818, /*   637 (  34) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  0] -1 */
       16484, /*   638 (  35) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
     1433658, /*   639 (  35) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  0]  1 */
    34028706, /*   640 (  35) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    35445884, /*   641 (  35) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  0] -1 */
       16484, /*   642 (  36) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
     1433658, /*   643 (  36) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  0]  1 */
    34146806, /*   644 (  36) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    35563980, /*   645 (  36) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6] -1 */
       16484, /*   646 (  37) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
     1433658, /*   647 (  37) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  0]  1 */
    51152916, /*   648 (  37) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6] -1 */
    52570094, /*   649 (  37) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
       16484, /*   650 (  38) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
     1433658, /*   651 (  38) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  0]  1 */
    34146804, /*   652 (  38) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
    35563982, /*   653 (  38) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
       16484, /*   654 (  31) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
     1420538, /*   655 (  31) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  0]  1 */
       16484, /*   656 (  32) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
     1420538, /*   657 (  32) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  0]  1 */
    34028708, /*   658 (  32) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    35432762, /*   659 (  32) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  0] -1 */
       16484, /*   660 (  33) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    35432762, /*   661 (  33) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  0] -1 */
       16484, /*   662 (  34) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
     1420538, /*   663 (  34) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  0]  1 */
    34146806, /*   664 (  34) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    35550860, /*   665 (  34) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
       16484, /*   666 (  35) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
     1420538, /*   667 (  35) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  0]  1 */
    34015586, /*   668 (  35) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    35445884, /*   669 (  35) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  0] -1 */
       16484, /*   670 (  36) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
     1420538, /*   671 (  36) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  0]  1 */
    51034820, /*   672 (  36) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  0] -1 */
    52438874, /*   673 (  36) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
       16484, /*   674 (  37) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
     1420538, /*   675 (  37) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  0]  1 */
    52556972, /*   676 (  37) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    51152918, /*   677 (  37) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
       16484, /*   678 (  38) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
     1420538, /*   679 (  38) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  0]  1 */
    51021698, /*   680 (  38) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  0] -1 */
    52451996, /*   681 (  38) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
       16484, /*   682 (  31) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
     1538636, /*   683 (  31) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
       16484, /*   684 (  32) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
     1538636, /*   685 (  32) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
    34028708, /*   686 (  32) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    35550860, /*   687 (  32) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
       16484, /*   688 (  33) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    35550860, /*   689 (  33) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
       16484, /*   690 (  34) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
     1538636, /*   691 (  34) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
    35445884, /*   692 (  34) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  0] -1 */
    34133684, /*   693 (  34) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
       16484, /*   694 (  35) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
     1538636, /*   695 (  35) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
    34015586, /*   696 (  35) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    35563982, /*   697 (  35) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
       16484, /*   698 (  36) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
     1538636, /*   699 (  36) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
    51034820, /*   700 (  36) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  0] -1 */
    52556972, /*   701 (  36) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
       16484, /*   702 (  37) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
     1538636, /*   703 (  37) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
    51139796, /*   704 (  37) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
    52451996, /*   705 (  37) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
       16484, /*   706 (  38) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
     1538636, /*   707 (  38) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
    51021698, /*   708 (  38) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  0] -1 */
    52570094, /*   709 (  38) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
       16484, /*   710 (  31) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
      121460, /*   711 (  31) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6]  1 */
       16484, /*   712 (  32) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
      121460, /*   713 (  32) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6]  1 */
    34028708, /*   714 (  32) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    34133684, /*   715 (  32) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
       16484, /*   716 (  33) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34133684, /*   717 (  33) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
       16484, /*   718 (  34) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
      121460, /*   719 (  34) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6]  1 */
    35563982, /*   720 (  34) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
    35432762, /*   721 (  34) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  0] -1 */
       16484, /*   722 (  35) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
      121460, /*   723 (  35) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6]  1 */
    34015586, /*   724 (  35) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    34146806, /*   725 (  35) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
       16484, /*   726 (  36) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
      121460, /*   727 (  36) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6]  1 */
    51034820, /*   728 (  36) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  0] -1 */
    51139796, /*   729 (  36) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
       16484, /*   730 (  37) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
      121460, /*   731 (  37) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6]  1 */
    52438874, /*   732 (  37) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
    52570094, /*   733 (  37) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
       16484, /*   734 (  38) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
      121460, /*   735 (  38) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6]  1 */
    51021698, /*   736 (  38) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  0] -1 */
    51152918, /*   737 (  38) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
       16484, /*   738 (  39) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    18439772, /*   739 (  39) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    18439610, /*   740 (  39) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
       16322, /*   741 (  39) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
       16484, /*   742 (  40) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    52451834, /*   743 (  40) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
    34028546, /*   744 (  40) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    18439610, /*   745 (  40) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    52451996, /*   746 (  40) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
    18439772, /*   747 (  40) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    34028708, /*   748 (  40) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
       16322, /*   749 (  40) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
       16484, /*   750 (  41) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    18439772, /*   751 (  41) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    34028546, /*   752 (  41) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    52451834, /*   753 (  41) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
       16484, /*   754 (  42) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    18439610, /*   755 (  42) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    34146644, /*   756 (  42) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    52569932, /*   757 (  42) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    34146806, /*   758 (  42) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    18439772, /*   759 (  42) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    52570094, /*   760 (  42) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
       16322, /*   761 (  42) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
       16484, /*   762 (  43) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    18439610, /*   763 (  43) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    51034820, /*   764 (  43) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  0] -1 */
    51034658, /*   765 (  43) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  0] -1 */
    35445722, /*   766 (  43) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  0] -1 */
    35445884, /*   767 (  43) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  0] -1 */
    18439772, /*   768 (  43) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
       16322, /*   769 (  43) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
       16484, /*   770 (  39) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
     1551758, /*   771 (  39) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
     1551596, /*   772 (  39) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
       16322, /*   773 (  39) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
       16484, /*   774 (  40) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    35563820, /*   775 (  40) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
    34028546, /*   776 (  40) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
     1551596, /*   777 (  40) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
    35563982, /*   778 (  40) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
     1551758, /*   779 (  40) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
    34028708, /*   780 (  40) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
       16322, /*   781 (  40) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
       16484, /*   782 (  41) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
     1551758, /*   783 (  41) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
    34028546, /*   784 (  41) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    35563820, /*   785 (  41) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
       16484, /*   786 (  42) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
     1551596, /*   787 (  42) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
    51152756, /*   788 (  42) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
    52451834, /*   789 (  42) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
    51152918, /*   790 (  42) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
     1551758, /*   791 (  42) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
    52451996, /*   792 (  42) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
       16322, /*   793 (  42) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
       16484, /*   794 (  43) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
     1551596, /*   795 (  43) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
    34146806, /*   796 (  43) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    34146644, /*   797 (  43) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    35445722, /*   798 (  43) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  0] -1 */
    35445884, /*   799 (  43) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  0] -1 */
     1551758, /*   800 (  43) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
       16322, /*   801 (  43) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
       16484, /*   802 (  39) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    18557870, /*   803 (  39) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    18557708, /*   804 (  39) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
       16322, /*   805 (  39) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
       16484, /*   806 (  40) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    52569932, /*   807 (  40) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    34028546, /*   808 (  40) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    18557708, /*   809 (  40) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    52570094, /*   810 (  40) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    18557870, /*   811 (  40) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    34028708, /*   812 (  40) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
       16322, /*   813 (  40) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
       16484, /*   814 (  41) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    18557870, /*   815 (  41) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    34028546, /*   816 (  41) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    52569932, /*   817 (  41) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
       16484, /*   818 (  42) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    18557708, /*   819 (  42) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    51034658, /*   820 (  42) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  0] -1 */
    35563820, /*   821 (  42) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
    51034820, /*   822 (  42) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  0] -1 */
    18557870, /*   823 (  42) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    35563982, /*   824 (  42) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
       16322, /*   825 (  42) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
       16484, /*   826 (  43) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    18557708, /*   827 (  43) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    51152918, /*   828 (  43) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
    51152756, /*   829 (  43) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
    35445722, /*   830 (  43) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  0] -1 */
    35445884, /*   831 (  43) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  0] -1 */
    18557870, /*   832 (  43) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
       16322, /*   833 (  43) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
       16484, /*   834 (  39) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
     1551758, /*   835 (  39) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
     1551756, /*   836 (  39) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
       16482, /*   837 (  39) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
       16484, /*   838 (  40) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    35563980, /*   839 (  40) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6] -1 */
    34028706, /*   840 (  40) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
     1551756, /*   841 (  40) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
    35563982, /*   842 (  40) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
     1551758, /*   843 (  40) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
    34028708, /*   844 (  40) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
       16482, /*   845 (  40) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
       16484, /*   846 (  41) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
     1551758, /*   847 (  41) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
    34028706, /*   848 (  41) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    35563980, /*   849 (  41) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6] -1 */
       16484, /*   850 (  42) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
     1551756, /*   851 (  42) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
    51034818, /*   852 (  42) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  0] -1 */
    52570092, /*   853 (  42) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    51034820, /*   854 (  42) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  0] -1 */
     1551758, /*   855 (  42) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
    52570094, /*   856 (  42) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
       16482, /*   857 (  42) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
       16484, /*   858 (  43) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
     1551756, /*   859 (  43) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
    35445884, /*   860 (  43) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  0] -1 */
    35445882, /*   861 (  43) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  0] -1 */
    34146804, /*   862 (  43) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
    34146806, /*   863 (  43) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
     1551758, /*   864 (  43) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
       16482, /*   865 (  43) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
       16484, /*   866 (  39) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    17140694, /*   867 (  39) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
    17140692, /*   868 (  39) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6]  1 */
       16482, /*   869 (  39) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
       16484, /*   870 (  40) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    51152916, /*   871 (  40) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6] -1 */
    34028706, /*   872 (  40) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    17140692, /*   873 (  40) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6]  1 */
    51152918, /*   874 (  40) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
    17140694, /*   875 (  40) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
    34028708, /*   876 (  40) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
       16482, /*   877 (  40) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
       16484, /*   878 (  41) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    17140694, /*   879 (  41) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
    34028706, /*   880 (  41) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    51152916, /*   881 (  41) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6] -1 */
       16484, /*   882 (  42) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    17140692, /*   883 (  42) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6]  1 */
    52451994, /*   884 (  42) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
    35563980, /*   885 (  42) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6] -1 */
    52451996, /*   886 (  42) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
    17140694, /*   887 (  42) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
    35563982, /*   888 (  42) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
       16482, /*   889 (  42) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
       16484, /*   890 (  43) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    17140692, /*   891 (  43) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6]  1 */
    51034820, /*   892 (  43) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  0] -1 */
    51034818, /*   893 (  43) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  0] -1 */
    34146804, /*   894 (  43) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
    34146806, /*   895 (  43) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    17140694, /*   896 (  43) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
       16482, /*   897 (  43) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
       16484, /*   898 (  39) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    18557870, /*   899 (  39) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    18557868, /*   900 (  39) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
       16482, /*   901 (  39) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
       16484, /*   902 (  40) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    52570092, /*   903 (  40) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    34028706, /*   904 (  40) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    18557868, /*   905 (  40) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
    52570094, /*   906 (  40) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    18557870, /*   907 (  40) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    34028708, /*   908 (  40) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
       16482, /*   909 (  40) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
       16484, /*   910 (  41) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    18557870, /*   911 (  41) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    34028706, /*   912 (  41) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    52570092, /*   913 (  41) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
       16484, /*   914 (  42) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    18557868, /*   915 (  42) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
    35445882, /*   916 (  42) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  0] -1 */
    51152916, /*   917 (  42) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6] -1 */
    35445884, /*   918 (  42) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  0] -1 */
    18557870, /*   919 (  42) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    51152918, /*   920 (  42) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
       16482, /*   921 (  42) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
       16484, /*   922 (  43) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    18557868, /*   923 (  43) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
    52451996, /*   924 (  43) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
    52451994, /*   925 (  43) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
    34146804, /*   926 (  43) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
    34146806, /*   927 (  43) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    18557870, /*   928 (  43) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
       16482, /*   929 (  43) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
       16484, /*   930 (  39) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    17140694, /*   931 (  39) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
    17127572, /*   932 (  39) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
        3362, /*   933 (  39) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
       16484, /*   934 (  40) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    51139796, /*   935 (  40) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
    34015586, /*   936 (  40) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    17127572, /*   937 (  40) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
    51152918, /*   938 (  40) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
    17140694, /*   939 (  40) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
    34028708, /*   940 (  40) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
        3362, /*   941 (  40) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
       16484, /*   942 (  41) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    17140694, /*   943 (  41) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
    34015586, /*   944 (  41) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    51139796, /*   945 (  41) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
       16484, /*   946 (  42) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    17127572, /*   947 (  42) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
    35432762, /*   948 (  42) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  0] -1 */
    52556972, /*   949 (  42) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    35445884, /*   950 (  42) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  0] -1 */
    17140694, /*   951 (  42) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
    52570094, /*   952 (  42) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
        3362, /*   953 (  42) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
       16484, /*   954 (  43) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    17127572, /*   955 (  43) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
    34146806, /*   956 (  43) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    34133684, /*   957 (  43) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    51021698, /*   958 (  43) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  0] -1 */
    51034820, /*   959 (  43) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  0] -1 */
    17140694, /*   960 (  43) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
        3362, /*   961 (  43) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
       16484, /*   962 (  39) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    18439772, /*   963 (  39) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    18426650, /*   964 (  39) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
        3362, /*   965 (  39) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
       16484, /*   966 (  40) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    52438874, /*   967 (  40) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
    34015586, /*   968 (  40) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    18426650, /*   969 (  40) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    52451996, /*   970 (  40) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
    18439772, /*   971 (  40) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    34028708, /*   972 (  40) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
        3362, /*   973 (  40) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
       16484, /*   974 (  41) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    18439772, /*   975 (  41) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    34015586, /*   976 (  41) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    52438874, /*   977 (  41) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
       16484, /*   978 (  42) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    18426650, /*   979 (  42) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    35550860, /*   980 (  42) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
    51139796, /*   981 (  42) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
    35563982, /*   982 (  42) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
    18439772, /*   983 (  42) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    51152918, /*   984 (  42) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
        3362, /*   985 (  42) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
       16484, /*   986 (  43) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    18426650, /*   987 (  43) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    35445884, /*   988 (  43) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  0] -1 */
    35432762, /*   989 (  43) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  0] -1 */
    51021698, /*   990 (  43) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  0] -1 */
    51034820, /*   991 (  43) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  0] -1 */
    18439772, /*   992 (  43) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
        3362, /*   993 (  43) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
       16484, /*   994 (  39) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    18557870, /*   995 (  39) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    18544748, /*   996 (  39) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
        3362, /*   997 (  39) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
       16484, /*   998 (  40) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    52556972, /*   999 (  40) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    34015586, /*  1000 (  40) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    18544748, /*  1001 (  40) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    52570094, /*  1002 (  40) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    18557870, /*  1003 (  40) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    34028708, /*  1004 (  40) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
        3362, /*  1005 (  40) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
       16484, /*  1006 (  41) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    18557870, /*  1007 (  41) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    34015586, /*  1008 (  41) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    52556972, /*  1009 (  41) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
       16484, /*  1010 (  42) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    18544748, /*  1011 (  42) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    34133684, /*  1012 (  42) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    52438874, /*  1013 (  42) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
    34146806, /*  1014 (  42) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    18557870, /*  1015 (  42) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    52451996, /*  1016 (  42) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
        3362, /*  1017 (  42) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
       16484, /*  1018 (  43) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    18544748, /*  1019 (  43) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    35563982, /*  1020 (  43) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
    35550860, /*  1021 (  43) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
    51021698, /*  1022 (  43) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  0] -1 */
    51034820, /*  1023 (  43) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  0] -1 */
    18557870, /*  1024 (  43) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
        3362, /*  1025 (  43) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
       16484, /*  1026 (  44) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    18439772, /*  1027 (  44) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    18557708, /*  1028 (  44) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
      134420, /*  1029 (  44) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6]  1 */
       16484, /*  1030 (  45) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34146644, /*  1031 (  45) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    52569932, /*  1032 (  45) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
      134420, /*  1033 (  45) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6]  1 */
    52451996, /*  1034 (  45) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
    18439772, /*  1035 (  45) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    18557708, /*  1036 (  45) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    34028708, /*  1037 (  45) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
       16484, /*  1038 (  46) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    18439772, /*  1039 (  46) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    34146644, /*  1040 (  46) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    52569932, /*  1041 (  46) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
       16484, /*  1042 (  47) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    52451834, /*  1043 (  47) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
    34028546, /*  1044 (  47) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
      134420, /*  1045 (  47) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6]  1 */
    34146806, /*  1046 (  47) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    18439772, /*  1047 (  47) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    18557708, /*  1048 (  47) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    52570094, /*  1049 (  47) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
       16484, /*  1050 (  48) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    51152756, /*  1051 (  48) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
    51034820, /*  1052 (  48) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  0] -1 */
      134420, /*  1053 (  48) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6]  1 */
    35445884, /*  1054 (  48) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  0] -1 */
    18439772, /*  1055 (  48) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    18557708, /*  1056 (  48) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    35563820, /*  1057 (  48) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
       16484, /*  1058 (  44) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
     1551758, /*  1059 (  44) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
    18439610, /*  1060 (  44) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    17140532, /*  1061 (  44) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
       16484, /*  1062 (  45) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    51152756, /*  1063 (  45) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
    52451834, /*  1064 (  45) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
    17140532, /*  1065 (  45) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
    35563982, /*  1066 (  45) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
     1551758, /*  1067 (  45) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
    18439610, /*  1068 (  45) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    34028708, /*  1069 (  45) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
       16484, /*  1070 (  46) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
     1551758, /*  1071 (  46) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
    51152756, /*  1072 (  46) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
    52451834, /*  1073 (  46) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
       16484, /*  1074 (  47) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    35563820, /*  1075 (  47) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
    34028546, /*  1076 (  47) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    17140532, /*  1077 (  47) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
    51152918, /*  1078 (  47) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
     1551758, /*  1079 (  47) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
    18439610, /*  1080 (  47) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    52451996, /*  1081 (  47) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
       16484, /*  1082 (  48) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    51034658, /*  1083 (  48) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  0] -1 */
    34146806, /*  1084 (  48) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    17140532, /*  1085 (  48) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
    35445884, /*  1086 (  48) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  0] -1 */
     1551758, /*  1087 (  48) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
    18439610, /*  1088 (  48) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    52569932, /*  1089 (  48) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
       16484, /*  1090 (  44) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    18557870, /*  1091 (  44) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
     1551596, /*  1092 (  44) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
    17022434, /*  1093 (  44) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  0]  1 */
       16484, /*  1094 (  45) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    51034658, /*  1095 (  45) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  0] -1 */
    35563820, /*  1096 (  45) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
    17022434, /*  1097 (  45) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  0]  1 */
    52570094, /*  1098 (  45) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    18557870, /*  1099 (  45) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
     1551596, /*  1100 (  45) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
    34028708, /*  1101 (  45) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
       16484, /*  1102 (  46) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    18557870, /*  1103 (  46) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    51034658, /*  1104 (  46) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  0] -1 */
    35563820, /*  1105 (  46) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
       16484, /*  1106 (  47) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    52569932, /*  1107 (  47) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    34028546, /*  1108 (  47) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    17022434, /*  1109 (  47) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  0]  1 */
    51034820, /*  1110 (  47) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  0] -1 */
    18557870, /*  1111 (  47) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
     1551596, /*  1112 (  47) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
    35563982, /*  1113 (  47) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
       16484, /*  1114 (  48) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34146644, /*  1115 (  48) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    51152918, /*  1116 (  48) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
    17022434, /*  1117 (  48) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  0]  1 */
    35445884, /*  1118 (  48) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  0] -1 */
    18557870, /*  1119 (  48) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
     1551596, /*  1120 (  48) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
    52451834, /*  1121 (  48) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
       16484, /*  1122 (  44) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
     1551758, /*  1123 (  44) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
    18557708, /*  1124 (  44) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    17022434, /*  1125 (  44) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  0]  1 */
       16484, /*  1126 (  45) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    51034658, /*  1127 (  45) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  0] -1 */
    52569932, /*  1128 (  45) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    17022434, /*  1129 (  45) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  0]  1 */
    35563982, /*  1130 (  45) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
     1551758, /*  1131 (  45) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
    18557708, /*  1132 (  45) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    34028708, /*  1133 (  45) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
       16484, /*  1134 (  46) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
     1551758, /*  1135 (  46) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
    51034658, /*  1136 (  46) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  0] -1 */
    52569932, /*  1137 (  46) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
       16484, /*  1138 (  47) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    35563820, /*  1139 (  47) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
    34028546, /*  1140 (  47) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    17022434, /*  1141 (  47) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  0]  1 */
    51034820, /*  1142 (  47) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  0] -1 */
     1551758, /*  1143 (  47) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
    18557708, /*  1144 (  47) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    52570094, /*  1145 (  47) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
       16484, /*  1146 (  48) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    51152756, /*  1147 (  48) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
    34146806, /*  1148 (  48) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    17022434, /*  1149 (  48) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  0]  1 */
    35445884, /*  1150 (  48) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  0] -1 */
     1551758, /*  1151 (  48) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
    18557708, /*  1152 (  48) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    52451834, /*  1153 (  48) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
       16484, /*  1154 (  44) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    18439772, /*  1155 (  44) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
     1551596, /*  1156 (  44) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
    17140532, /*  1157 (  44) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
       16484, /*  1158 (  45) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    51152756, /*  1159 (  45) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
    35563820, /*  1160 (  45) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
    17140532, /*  1161 (  45) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
    52451996, /*  1162 (  45) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
    18439772, /*  1163 (  45) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
     1551596, /*  1164 (  45) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
    34028708, /*  1165 (  45) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
       16484, /*  1166 (  46) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    18439772, /*  1167 (  46) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    51152756, /*  1168 (  46) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
    35563820, /*  1169 (  46) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
       16484, /*  1170 (  47) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    52451834, /*  1171 (  47) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
    34028546, /*  1172 (  47) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    17140532, /*  1173 (  47) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
    51152918, /*  1174 (  47) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
    18439772, /*  1175 (  47) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
     1551596, /*  1176 (  47) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
    35563982, /*  1177 (  47) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
       16484, /*  1178 (  48) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34146644, /*  1179 (  48) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    51034820, /*  1180 (  48) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  0] -1 */
    17140532, /*  1181 (  48) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
    35445884, /*  1182 (  48) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  0] -1 */
    18439772, /*  1183 (  48) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
     1551596, /*  1184 (  48) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
    52569932, /*  1185 (  48) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
       16484, /*  1186 (  44) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    18557870, /*  1187 (  44) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    18439610, /*  1188 (  44) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
      134420, /*  1189 (  44) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6]  1 */
       16484, /*  1190 (  45) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34146644, /*  1191 (  45) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    52451834, /*  1192 (  45) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
      134420, /*  1193 (  45) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6]  1 */
    52570094, /*  1194 (  45) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    18557870, /*  1195 (  45) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    18439610, /*  1196 (  45) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    34028708, /*  1197 (  45) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
       16484, /*  1198 (  46) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    18557870, /*  1199 (  46) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    34146644, /*  1200 (  46) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    52451834, /*  1201 (  46) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
       16484, /*  1202 (  47) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    52569932, /*  1203 (  47) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    34028546, /*  1204 (  47) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
      134420, /*  1205 (  47) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6]  1 */
    34146806, /*  1206 (  47) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    18557870, /*  1207 (  47) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    18439610, /*  1208 (  47) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    52451996, /*  1209 (  47) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
       16484, /*  1210 (  48) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    51034658, /*  1211 (  48) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  0] -1 */
    51152918, /*  1212 (  48) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
      134420, /*  1213 (  48) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6]  1 */
    35445884, /*  1214 (  48) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  0] -1 */
    18557870, /*  1215 (  48) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    18439610, /*  1216 (  48) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    35563820, /*  1217 (  48) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
       16484, /*  1218 (  44) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
     1551758, /*  1219 (  44) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
    18557868, /*  1220 (  44) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
    17022594, /*  1221 (  44) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  0]  1 */
       16484, /*  1222 (  45) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    51034818, /*  1223 (  45) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  0] -1 */
    52570092, /*  1224 (  45) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    17022594, /*  1225 (  45) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  0]  1 */
    35563982, /*  1226 (  45) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
     1551758, /*  1227 (  45) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
    18557868, /*  1228 (  45) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
    34028708, /*  1229 (  45) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
       16484, /*  1230 (  46) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
     1551758, /*  1231 (  46) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
    51034818, /*  1232 (  46) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  0] -1 */
    52570092, /*  1233 (  46) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
       16484, /*  1234 (  47) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    35563980, /*  1235 (  47) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6] -1 */
    34028706, /*  1236 (  47) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    17022594, /*  1237 (  47) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  0]  1 */
    51034820, /*  1238 (  47) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  0] -1 */
     1551758, /*  1239 (  47) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
    18557868, /*  1240 (  47) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
    52570094, /*  1241 (  47) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
       16484, /*  1242 (  48) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    52451994, /*  1243 (  48) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
    35445884, /*  1244 (  48) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  0] -1 */
    17022594, /*  1245 (  48) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  0]  1 */
    34146806, /*  1246 (  48) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
     1551758, /*  1247 (  48) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
    18557868, /*  1248 (  48) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
    51152916, /*  1249 (  48) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6] -1 */
       16484, /*  1250 (  44) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    17140694, /*  1251 (  44) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
     1551756, /*  1252 (  44) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
    18439770, /*  1253 (  44) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
       16484, /*  1254 (  45) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    52451994, /*  1255 (  45) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
    35563980, /*  1256 (  45) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6] -1 */
    18439770, /*  1257 (  45) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
    51152918, /*  1258 (  45) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
    17140694, /*  1259 (  45) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
     1551756, /*  1260 (  45) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
    34028708, /*  1261 (  45) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
       16484, /*  1262 (  46) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    17140694, /*  1263 (  46) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
    52451994, /*  1264 (  46) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
    35563980, /*  1265 (  46) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6] -1 */
       16484, /*  1266 (  47) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    51152916, /*  1267 (  47) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6] -1 */
    34028706, /*  1268 (  47) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    18439770, /*  1269 (  47) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
    52451996, /*  1270 (  47) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
    17140694, /*  1271 (  47) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
     1551756, /*  1272 (  47) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
    35563982, /*  1273 (  47) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
       16484, /*  1274 (  48) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    35445882, /*  1275 (  48) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  0] -1 */
    51034820, /*  1276 (  48) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  0] -1 */
    18439770, /*  1277 (  48) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
    34146806, /*  1278 (  48) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    17140694, /*  1279 (  48) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
     1551756, /*  1280 (  48) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
    52570092, /*  1281 (  48) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
       16484, /*  1282 (  44) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    18557870, /*  1283 (  44) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    17140692, /*  1284 (  44) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6]  1 */
     1433658, /*  1285 (  44) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  0]  1 */
       16484, /*  1286 (  45) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    35445882, /*  1287 (  45) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  0] -1 */
    51152916, /*  1288 (  45) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6] -1 */
     1433658, /*  1289 (  45) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  0]  1 */
    52570094, /*  1290 (  45) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    18557870, /*  1291 (  45) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    17140692, /*  1292 (  45) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6]  1 */
    34028708, /*  1293 (  45) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
       16484, /*  1294 (  46) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    18557870, /*  1295 (  46) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    35445882, /*  1296 (  46) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  0] -1 */
    51152916, /*  1297 (  46) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6] -1 */
       16484, /*  1298 (  47) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    52570092, /*  1299 (  47) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    34028706, /*  1300 (  47) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
     1433658, /*  1301 (  47) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  0]  1 */
    35445884, /*  1302 (  47) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  0] -1 */
    18557870, /*  1303 (  47) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    17140692, /*  1304 (  47) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6]  1 */
    51152918, /*  1305 (  47) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
       16484, /*  1306 (  48) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    51034818, /*  1307 (  48) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  0] -1 */
    52451996, /*  1308 (  48) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
     1433658, /*  1309 (  48) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  0]  1 */
    34146806, /*  1310 (  48) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    18557870, /*  1311 (  48) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    17140692, /*  1312 (  48) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6]  1 */
    35563980, /*  1313 (  48) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6] -1 */
       16484, /*  1314 (  44) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    17140694, /*  1315 (  44) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
    18557868, /*  1316 (  44) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
     1433658, /*  1317 (  44) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  0]  1 */
       16484, /*  1318 (  45) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    35445882, /*  1319 (  45) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  0] -1 */
    52570092, /*  1320 (  45) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
     1433658, /*  1321 (  45) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  0]  1 */
    51152918, /*  1322 (  45) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
    17140694, /*  1323 (  45) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
    18557868, /*  1324 (  45) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
    34028708, /*  1325 (  45) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
       16484, /*  1326 (  46) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    17140694, /*  1327 (  46) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
    35445882, /*  1328 (  46) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  0] -1 */
    52570092, /*  1329 (  46) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
       16484, /*  1330 (  47) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    51152916, /*  1331 (  47) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6] -1 */
    34028706, /*  1332 (  47) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
     1433658, /*  1333 (  47) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  0]  1 */
    35445884, /*  1334 (  47) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  0] -1 */
    17140694, /*  1335 (  47) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
    18557868, /*  1336 (  47) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
    52570094, /*  1337 (  47) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
       16484, /*  1338 (  48) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    52451994, /*  1339 (  48) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
    51034820, /*  1340 (  48) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  0] -1 */
     1433658, /*  1341 (  48) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  0]  1 */
    34146806, /*  1342 (  48) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    17140694, /*  1343 (  48) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
    18557868, /*  1344 (  48) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
    35563980, /*  1345 (  48) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6] -1 */
       16484, /*  1346 (  44) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
     1551758, /*  1347 (  44) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
    17140692, /*  1348 (  44) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6]  1 */
    18439770, /*  1349 (  44) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
       16484, /*  1350 (  45) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    52451994, /*  1351 (  45) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
    51152916, /*  1352 (  45) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6] -1 */
    18439770, /*  1353 (  45) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
    35563982, /*  1354 (  45) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
     1551758, /*  1355 (  45) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
    17140692, /*  1356 (  45) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6]  1 */
    34028708, /*  1357 (  45) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
       16484, /*  1358 (  46) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
     1551758, /*  1359 (  46) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
    52451994, /*  1360 (  46) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
    51152916, /*  1361 (  46) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6] -1 */
       16484, /*  1362 (  47) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    35563980, /*  1363 (  47) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6] -1 */
    34028706, /*  1364 (  47) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    18439770, /*  1365 (  47) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
    52451996, /*  1366 (  47) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
     1551758, /*  1367 (  47) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
    17140692, /*  1368 (  47) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6]  1 */
    51152918, /*  1369 (  47) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
       16484, /*  1370 (  48) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    51034818, /*  1371 (  48) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  0] -1 */
    35445884, /*  1372 (  48) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  0] -1 */
    18439770, /*  1373 (  48) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
    34146806, /*  1374 (  48) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
     1551758, /*  1375 (  48) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
    17140692, /*  1376 (  48) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6]  1 */
    52570092, /*  1377 (  48) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
       16484, /*  1378 (  44) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    18557870, /*  1379 (  44) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
     1551756, /*  1380 (  44) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
    17022594, /*  1381 (  44) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  0]  1 */
       16484, /*  1382 (  45) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    51034818, /*  1383 (  45) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  0] -1 */
    35563980, /*  1384 (  45) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6] -1 */
    17022594, /*  1385 (  45) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  0]  1 */
    52570094, /*  1386 (  45) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    18557870, /*  1387 (  45) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
     1551756, /*  1388 (  45) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
    34028708, /*  1389 (  45) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
       16484, /*  1390 (  46) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    18557870, /*  1391 (  46) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    51034818, /*  1392 (  46) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  0] -1 */
    35563980, /*  1393 (  46) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6] -1 */
       16484, /*  1394 (  47) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    52570092, /*  1395 (  47) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    34028706, /*  1396 (  47) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    17022594, /*  1397 (  47) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  0]  1 */
    51034820, /*  1398 (  47) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  0] -1 */
    18557870, /*  1399 (  47) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
     1551756, /*  1400 (  47) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
    35563982, /*  1401 (  47) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
       16484, /*  1402 (  48) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    35445882, /*  1403 (  48) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  0] -1 */
    52451996, /*  1404 (  48) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
    17022594, /*  1405 (  48) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  0]  1 */
    34146806, /*  1406 (  48) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    18557870, /*  1407 (  48) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
     1551756, /*  1408 (  48) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
    51152916, /*  1409 (  48) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6] -1 */
       16484, /*  1410 (  44) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    17140694, /*  1411 (  44) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
    18544748, /*  1412 (  44) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
     1420538, /*  1413 (  44) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  0]  1 */
       16484, /*  1414 (  45) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    35432762, /*  1415 (  45) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  0] -1 */
    52556972, /*  1416 (  45) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
     1420538, /*  1417 (  45) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  0]  1 */
    51152918, /*  1418 (  45) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
    17140694, /*  1419 (  45) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
    18544748, /*  1420 (  45) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    34028708, /*  1421 (  45) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
       16484, /*  1422 (  46) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    17140694, /*  1423 (  46) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
    35432762, /*  1424 (  46) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  0] -1 */
    52556972, /*  1425 (  46) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
       16484, /*  1426 (  47) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    51139796, /*  1427 (  47) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
    34015586, /*  1428 (  47) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
     1420538, /*  1429 (  47) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  0]  1 */
    35445884, /*  1430 (  47) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  0] -1 */
    17140694, /*  1431 (  47) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
    18544748, /*  1432 (  47) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    52570094, /*  1433 (  47) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
       16484, /*  1434 (  48) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    35550860, /*  1435 (  48) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
    34146806, /*  1436 (  48) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
     1420538, /*  1437 (  48) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  0]  1 */
    51034820, /*  1438 (  48) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  0] -1 */
    17140694, /*  1439 (  48) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
    18544748, /*  1440 (  48) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    52438874, /*  1441 (  48) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
       16484, /*  1442 (  44) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    18439772, /*  1443 (  44) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    17127572, /*  1444 (  44) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
     1538636, /*  1445 (  44) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
       16484, /*  1446 (  45) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    35550860, /*  1447 (  45) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
    51139796, /*  1448 (  45) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
     1538636, /*  1449 (  45) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
    52451996, /*  1450 (  45) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
    18439772, /*  1451 (  45) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    17127572, /*  1452 (  45) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
    34028708, /*  1453 (  45) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
       16484, /*  1454 (  46) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    18439772, /*  1455 (  46) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    35550860, /*  1456 (  46) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
    51139796, /*  1457 (  46) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
       16484, /*  1458 (  47) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    52438874, /*  1459 (  47) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
    34015586, /*  1460 (  47) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
     1538636, /*  1461 (  47) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
    35563982, /*  1462 (  47) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
    18439772, /*  1463 (  47) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    17127572, /*  1464 (  47) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
    51152918, /*  1465 (  47) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
       16484, /*  1466 (  48) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34133684, /*  1467 (  48) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    35445884, /*  1468 (  48) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  0] -1 */
     1538636, /*  1469 (  48) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
    51034820, /*  1470 (  48) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  0] -1 */
    18439772, /*  1471 (  48) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    17127572, /*  1472 (  48) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
    52556972, /*  1473 (  48) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
       16484, /*  1474 (  44) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    18557870, /*  1475 (  44) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    18426650, /*  1476 (  44) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
      121460, /*  1477 (  44) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6]  1 */
       16484, /*  1478 (  45) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34133684, /*  1479 (  45) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    52438874, /*  1480 (  45) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
      121460, /*  1481 (  45) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6]  1 */
    52570094, /*  1482 (  45) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    18557870, /*  1483 (  45) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    18426650, /*  1484 (  45) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    34028708, /*  1485 (  45) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
       16484, /*  1486 (  46) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    18557870, /*  1487 (  46) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    34133684, /*  1488 (  46) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    52438874, /*  1489 (  46) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
       16484, /*  1490 (  47) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    52556972, /*  1491 (  47) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    34015586, /*  1492 (  47) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
      121460, /*  1493 (  47) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6]  1 */
    34146806, /*  1494 (  47) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    18557870, /*  1495 (  47) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    18426650, /*  1496 (  47) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    52451996, /*  1497 (  47) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
       16484, /*  1498 (  48) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    35432762, /*  1499 (  48) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  0] -1 */
    35563982, /*  1500 (  48) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
      121460, /*  1501 (  48) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6]  1 */
    51034820, /*  1502 (  48) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  0] -1 */
    18557870, /*  1503 (  48) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    18426650, /*  1504 (  48) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    51139796, /*  1505 (  48) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
       16484, /*  1506 (  44) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    18439772, /*  1507 (  44) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    18544748, /*  1508 (  44) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
      121460, /*  1509 (  44) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6]  1 */
       16484, /*  1510 (  45) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34133684, /*  1511 (  45) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    52556972, /*  1512 (  45) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
      121460, /*  1513 (  45) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6]  1 */
    52451996, /*  1514 (  45) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
    18439772, /*  1515 (  45) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    18544748, /*  1516 (  45) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    34028708, /*  1517 (  45) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
       16484, /*  1518 (  46) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    18439772, /*  1519 (  46) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    34133684, /*  1520 (  46) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    52556972, /*  1521 (  46) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
       16484, /*  1522 (  47) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    52438874, /*  1523 (  47) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
    34015586, /*  1524 (  47) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
      121460, /*  1525 (  47) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6]  1 */
    34146806, /*  1526 (  47) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    18439772, /*  1527 (  47) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    18544748, /*  1528 (  47) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    52570094, /*  1529 (  47) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
       16484, /*  1530 (  48) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    35550860, /*  1531 (  48) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
    35445884, /*  1532 (  48) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  0] -1 */
      121460, /*  1533 (  48) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6]  1 */
    51034820, /*  1534 (  48) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  0] -1 */
    18439772, /*  1535 (  48) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    18544748, /*  1536 (  48) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    51139796, /*  1537 (  48) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
       16484, /*  1538 (  44) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    17140694, /*  1539 (  44) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
    18426650, /*  1540 (  44) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
     1538636, /*  1541 (  44) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
       16484, /*  1542 (  45) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    35550860, /*  1543 (  45) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
    52438874, /*  1544 (  45) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
     1538636, /*  1545 (  45) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
    51152918, /*  1546 (  45) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
    17140694, /*  1547 (  45) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
    18426650, /*  1548 (  45) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    34028708, /*  1549 (  45) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
       16484, /*  1550 (  46) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    17140694, /*  1551 (  46) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
    35550860, /*  1552 (  46) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
    52438874, /*  1553 (  46) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
       16484, /*  1554 (  47) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    51139796, /*  1555 (  47) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
    34015586, /*  1556 (  47) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
     1538636, /*  1557 (  47) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
    35563982, /*  1558 (  47) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
    17140694, /*  1559 (  47) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
    18426650, /*  1560 (  47) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    52451996, /*  1561 (  47) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
       16484, /*  1562 (  48) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    35432762, /*  1563 (  48) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  0] -1 */
    34146806, /*  1564 (  48) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
     1538636, /*  1565 (  48) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
    51034820, /*  1566 (  48) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  0] -1 */
    17140694, /*  1567 (  48) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
    18426650, /*  1568 (  48) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    52556972, /*  1569 (  48) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
       16484, /*  1570 (  44) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    18557870, /*  1571 (  44) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    17127572, /*  1572 (  44) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
     1420538, /*  1573 (  44) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  0]  1 */
       16484, /*  1574 (  45) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    35432762, /*  1575 (  45) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  0] -1 */
    51139796, /*  1576 (  45) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
     1420538, /*  1577 (  45) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  0]  1 */
    52570094, /*  1578 (  45) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    18557870, /*  1579 (  45) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    17127572, /*  1580 (  45) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
    34028708, /*  1581 (  45) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
       16484, /*  1582 (  46) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    18557870, /*  1583 (  46) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    35432762, /*  1584 (  46) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  0] -1 */
    51139796, /*  1585 (  46) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
       16484, /*  1586 (  47) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    52556972, /*  1587 (  47) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    34015586, /*  1588 (  47) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
     1420538, /*  1589 (  47) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  0]  1 */
    35445884, /*  1590 (  47) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  0] -1 */
    18557870, /*  1591 (  47) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    17127572, /*  1592 (  47) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
    51152918, /*  1593 (  47) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
       16484, /*  1594 (  48) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34133684, /*  1595 (  48) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    35563982, /*  1596 (  48) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
     1420538, /*  1597 (  48) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  0]  1 */
    51034820, /*  1598 (  48) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  0] -1 */
    18557870, /*  1599 (  48) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    17127572, /*  1600 (  48) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
    52438874, /*  1601 (  48) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
       16484, /*  1602 (  49) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
        3360, /*  1603 (  49) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
        3198, /*  1604 (  49) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
       16322, /*  1605 (  49) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
       16484, /*  1606 (  50) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34015422, /*  1607 (  50) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    34015584, /*  1608 (  50) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
        3198, /*  1609 (  50) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    34028546, /*  1610 (  50) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
        3360, /*  1611 (  50) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    34028708, /*  1612 (  50) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
       16322, /*  1613 (  50) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
       16484, /*  1614 (  51) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34015584, /*  1615 (  51) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    34015422, /*  1616 (  51) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
       16322, /*  1617 (  51) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
       16484, /*  1618 (  52) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
        3360, /*  1619 (  52) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    34028546, /*  1620 (  52) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    34015422, /*  1621 (  52) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
       16484, /*  1622 (  53) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34028546, /*  1623 (  53) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
        3198, /*  1624 (  53) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    34015584, /*  1625 (  53) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
       16484, /*  1626 (  54) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    51034820, /*  1627 (  54) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  0] -1 */
    51021696, /*  1628 (  54) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  0] -1 */
    51034658, /*  1629 (  54) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  0] -1 */
        3198, /*  1630 (  54) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    51021534, /*  1631 (  54) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  0] -1 */
        3360, /*  1632 (  54) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
       16322, /*  1633 (  54) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
       16484, /*  1634 (  55) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    35432760, /*  1635 (  55) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  0] -1 */
        3198, /*  1636 (  55) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    35445722, /*  1637 (  55) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  0] -1 */
    35445884, /*  1638 (  55) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  0] -1 */
    35432598, /*  1639 (  55) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  0] -1 */
        3360, /*  1640 (  55) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
       16322, /*  1641 (  55) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
       16484, /*  1642 (  56) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    52451834, /*  1643 (  56) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
    52438710, /*  1644 (  56) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
    52451996, /*  1645 (  56) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
        3198, /*  1646 (  56) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
        3360, /*  1647 (  56) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    52438872, /*  1648 (  56) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
       16322, /*  1649 (  56) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
       16484, /*  1650 (  49) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
        3200, /*  1651 (  49) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
        3198, /*  1652 (  49) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
       16482, /*  1653 (  49) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
       16484, /*  1654 (  50) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34015422, /*  1655 (  50) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    34015424, /*  1656 (  50) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
        3198, /*  1657 (  50) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    34028706, /*  1658 (  50) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
        3200, /*  1659 (  50) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34028708, /*  1660 (  50) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
       16482, /*  1661 (  50) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
       16484, /*  1662 (  51) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34015424, /*  1663 (  51) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    34015422, /*  1664 (  51) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
       16482, /*  1665 (  51) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
       16484, /*  1666 (  52) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
        3200, /*  1667 (  52) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34028706, /*  1668 (  52) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    34015422, /*  1669 (  52) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
       16484, /*  1670 (  53) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34028706, /*  1671 (  53) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
        3198, /*  1672 (  53) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    34015424, /*  1673 (  53) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
       16484, /*  1674 (  54) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    35445884, /*  1675 (  54) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  0] -1 */
    35432600, /*  1676 (  54) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  0] -1 */
    35445882, /*  1677 (  54) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  0] -1 */
        3198, /*  1678 (  54) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    35432598, /*  1679 (  54) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  0] -1 */
        3200, /*  1680 (  54) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
       16482, /*  1681 (  54) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
       16484, /*  1682 (  55) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34133522, /*  1683 (  55) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
        3198, /*  1684 (  55) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    34146804, /*  1685 (  55) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
    34146806, /*  1686 (  55) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    34133520, /*  1687 (  55) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
        3200, /*  1688 (  55) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
       16482, /*  1689 (  55) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
       16484, /*  1690 (  56) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    35563980, /*  1691 (  56) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6] -1 */
    35550696, /*  1692 (  56) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  6] -1 */
    35563982, /*  1693 (  56) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
        3198, /*  1694 (  56) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
        3200, /*  1695 (  56) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    35550698, /*  1696 (  56) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
       16482, /*  1697 (  56) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
       16484, /*  1698 (  49) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
       16320, /*  1699 (  49) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
        3198, /*  1700 (  49) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
        3362, /*  1701 (  49) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
       16484, /*  1702 (  50) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34015422, /*  1703 (  50) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    34028544, /*  1704 (  50) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
        3198, /*  1705 (  50) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    34015586, /*  1706 (  50) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
       16320, /*  1707 (  50) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    34028708, /*  1708 (  50) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
        3362, /*  1709 (  50) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
       16484, /*  1710 (  51) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34028544, /*  1711 (  51) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    34015422, /*  1712 (  51) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
        3362, /*  1713 (  51) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
       16484, /*  1714 (  52) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
       16320, /*  1715 (  52) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    34015586, /*  1716 (  52) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    34015422, /*  1717 (  52) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
       16484, /*  1718 (  53) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34015586, /*  1719 (  53) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
        3198, /*  1720 (  53) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    34028544, /*  1721 (  53) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
       16484, /*  1722 (  54) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34146806, /*  1723 (  54) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    34146642, /*  1724 (  54) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
    34133684, /*  1725 (  54) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
        3198, /*  1726 (  54) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    34133520, /*  1727 (  54) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
       16320, /*  1728 (  54) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
        3362, /*  1729 (  54) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
       16484, /*  1730 (  55) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    51034656, /*  1731 (  55) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  0] -1 */
        3198, /*  1732 (  55) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    51021698, /*  1733 (  55) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  0] -1 */
    51034820, /*  1734 (  55) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  0] -1 */
    51021534, /*  1735 (  55) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  0] -1 */
       16320, /*  1736 (  55) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
        3362, /*  1737 (  55) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
       16484, /*  1738 (  56) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    51139796, /*  1739 (  56) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
    51139632, /*  1740 (  56) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  6] -1 */
    51152918, /*  1741 (  56) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
        3198, /*  1742 (  56) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
       16320, /*  1743 (  56) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    51152754, /*  1744 (  56) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  6] -1 */
        3362, /*  1745 (  56) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
       16484, /*  1746 (  57) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
        3198, /*  1747 (  57) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
     1420536, /*  1748 (  57) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  0]  1 */
     1433498, /*  1749 (  57) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  0]  1 */
       16484, /*  1750 (  58) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34015422, /*  1751 (  58) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    35432760, /*  1752 (  58) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  0] -1 */
     1433498, /*  1753 (  58) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  0]  1 */
        3198, /*  1754 (  58) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    35445722, /*  1755 (  58) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  0] -1 */
     1420536, /*  1756 (  58) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  0]  1 */
    34028708, /*  1757 (  58) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
       16484, /*  1758 (  59) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
     1433498, /*  1759 (  59) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  0]  1 */
    34015422, /*  1760 (  59) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    35432760, /*  1761 (  59) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  0] -1 */
       16484, /*  1762 (  60) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34015422, /*  1763 (  60) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    35445722, /*  1764 (  60) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  0] -1 */
     1420536, /*  1765 (  60) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  0]  1 */
       16484, /*  1766 (  61) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
        3198, /*  1767 (  61) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    35445722, /*  1768 (  61) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  0] -1 */
    35432760, /*  1769 (  61) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  0] -1 */
       16484, /*  1770 (  62) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    52451834, /*  1771 (  62) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
    51034820, /*  1772 (  62) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  0] -1 */
    52438872, /*  1773 (  62) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
        3198, /*  1774 (  62) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    51021534, /*  1775 (  62) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  0] -1 */
     1420536, /*  1776 (  62) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  0]  1 */
     1433498, /*  1777 (  62) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  0]  1 */
       16484, /*  1778 (  63) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34028546, /*  1779 (  63) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    34015584, /*  1780 (  63) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
        3198, /*  1781 (  63) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
     1420536, /*  1782 (  63) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  0]  1 */
    35445884, /*  1783 (  63) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  0] -1 */
    35432598, /*  1784 (  63) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  0] -1 */
     1433498, /*  1785 (  63) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  0]  1 */
       16484, /*  1786 (  64) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    52438710, /*  1787 (  64) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
    52451996, /*  1788 (  64) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
        3198, /*  1789 (  64) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
     1420536, /*  1790 (  64) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  0]  1 */
    51021696, /*  1791 (  64) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  0] -1 */
     1433498, /*  1792 (  64) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  0]  1 */
    51034658, /*  1793 (  64) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  0] -1 */
       16484, /*  1794 (  57) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
        3198, /*  1795 (  57) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
      121298, /*  1796 (  57) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6]  1 */
      134580, /*  1797 (  57) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  6]  1 */
       16484, /*  1798 (  58) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34015422, /*  1799 (  58) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    34133522, /*  1800 (  58) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
      134580, /*  1801 (  58) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  6]  1 */
        3198, /*  1802 (  58) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    34146804, /*  1803 (  58) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
      121298, /*  1804 (  58) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6]  1 */
    34028708, /*  1805 (  58) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
       16484, /*  1806 (  59) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
      134580, /*  1807 (  59) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  6]  1 */
    34015422, /*  1808 (  59) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    34133522, /*  1809 (  59) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
       16484, /*  1810 (  60) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34015422, /*  1811 (  60) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    34146804, /*  1812 (  60) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
      121298, /*  1813 (  60) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6]  1 */
       16484, /*  1814 (  61) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
        3198, /*  1815 (  61) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    34146804, /*  1816 (  61) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
    34133522, /*  1817 (  61) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
       16484, /*  1818 (  62) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    35563980, /*  1819 (  62) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6] -1 */
    35445884, /*  1820 (  62) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  0] -1 */
    35550698, /*  1821 (  62) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
        3198, /*  1822 (  62) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    35432598, /*  1823 (  62) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  0] -1 */
      121298, /*  1824 (  62) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6]  1 */
      134580, /*  1825 (  62) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  6]  1 */
       16484, /*  1826 (  63) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34028706, /*  1827 (  63) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    34015424, /*  1828 (  63) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
        3198, /*  1829 (  63) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
      121298, /*  1830 (  63) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6]  1 */
    34146806, /*  1831 (  63) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    34133520, /*  1832 (  63) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
      134580, /*  1833 (  63) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  6]  1 */
       16484, /*  1834 (  64) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    35550696, /*  1835 (  64) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  6] -1 */
    35563982, /*  1836 (  64) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
        3198, /*  1837 (  64) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
      121298, /*  1838 (  64) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6]  1 */
    35432600, /*  1839 (  64) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  0] -1 */
      134580, /*  1840 (  64) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  6]  1 */
    35445882, /*  1841 (  64) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  0] -1 */
       16484, /*  1842 (  57) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
        3198, /*  1843 (  57) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    17022432, /*  1844 (  57) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  0]  1 */
    17009474, /*  1845 (  57) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  0]  1 */
       16484, /*  1846 (  58) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34015422, /*  1847 (  58) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    51034656, /*  1848 (  58) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  0] -1 */
    17009474, /*  1849 (  58) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  0]  1 */
        3198, /*  1850 (  58) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    51021698, /*  1851 (  58) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  0] -1 */
    17022432, /*  1852 (  58) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  0]  1 */
    34028708, /*  1853 (  58) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
       16484, /*  1854 (  59) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    17009474, /*  1855 (  59) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  0]  1 */
    34015422, /*  1856 (  59) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    51034656, /*  1857 (  59) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  0] -1 */
       16484, /*  1858 (  60) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34015422, /*  1859 (  60) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    51021698, /*  1860 (  60) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  0] -1 */
    17022432, /*  1861 (  60) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  0]  1 */
       16484, /*  1862 (  61) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
        3198, /*  1863 (  61) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    51021698, /*  1864 (  61) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  0] -1 */
    51034656, /*  1865 (  61) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  0] -1 */
       16484, /*  1866 (  62) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    51139796, /*  1867 (  62) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
    34146806, /*  1868 (  62) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    51152754, /*  1869 (  62) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  6] -1 */
        3198, /*  1870 (  62) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    34133520, /*  1871 (  62) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
    17022432, /*  1872 (  62) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  0]  1 */
    17009474, /*  1873 (  62) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  0]  1 */
       16484, /*  1874 (  63) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34015586, /*  1875 (  63) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    34028544, /*  1876 (  63) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
        3198, /*  1877 (  63) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    17022432, /*  1878 (  63) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  0]  1 */
    51034820, /*  1879 (  63) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  0] -1 */
    51021534, /*  1880 (  63) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  0] -1 */
    17009474, /*  1881 (  63) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  0]  1 */
       16484, /*  1882 (  64) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    51139632, /*  1883 (  64) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  6] -1 */
    51152918, /*  1884 (  64) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
        3198, /*  1885 (  64) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    17022432, /*  1886 (  64) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  0]  1 */
    34146642, /*  1887 (  64) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
    17009474, /*  1888 (  64) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  0]  1 */
    34133684, /*  1889 (  64) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
       16484, /*  1890 (  65) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    18426648, /*  1891 (  65) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
    18439610, /*  1892 (  65) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    18426486, /*  1893 (  65) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
        3198, /*  1894 (  65) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    18439772, /*  1895 (  65) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
        3360, /*  1896 (  65) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
       16322, /*  1897 (  65) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
       16484, /*  1898 (  66) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    52451834, /*  1899 (  66) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
    18426648, /*  1900 (  66) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
    34028546, /*  1901 (  66) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    34015422, /*  1902 (  66) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    52438710, /*  1903 (  66) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
    18439610, /*  1904 (  66) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    34015584, /*  1905 (  66) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    18426486, /*  1906 (  66) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
    52438872, /*  1907 (  66) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
    52451996, /*  1908 (  66) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
        3198, /*  1909 (  66) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    18439772, /*  1910 (  66) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
        3360, /*  1911 (  66) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    34028708, /*  1912 (  66) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
       16322, /*  1913 (  66) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
       16484, /*  1914 (  67) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34015422, /*  1915 (  67) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    52438710, /*  1916 (  67) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
    18439610, /*  1917 (  67) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    34015584, /*  1918 (  67) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    18439772, /*  1919 (  67) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    52438872, /*  1920 (  67) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
       16322, /*  1921 (  67) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
       16484, /*  1922 (  68) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    52451834, /*  1923 (  68) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
    18426648, /*  1924 (  68) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
    34028546, /*  1925 (  68) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    34015422, /*  1926 (  68) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    52438710, /*  1927 (  68) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
    18439772, /*  1928 (  68) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
        3360, /*  1929 (  68) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
       16484, /*  1930 (  69) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    52451834, /*  1931 (  69) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
    34028546, /*  1932 (  69) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    34015584, /*  1933 (  69) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    18426486, /*  1934 (  69) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
        3198, /*  1935 (  69) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    18439772, /*  1936 (  69) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    52438872, /*  1937 (  69) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
       16484, /*  1938 (  70) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    18426648, /*  1939 (  70) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
    18439610, /*  1940 (  70) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    34146644, /*  1941 (  70) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    52569932, /*  1942 (  70) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    18426486, /*  1943 (  70) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
    34133520, /*  1944 (  70) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
        3198, /*  1945 (  70) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    52556808, /*  1946 (  70) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    34146806, /*  1947 (  70) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    52556970, /*  1948 (  70) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    34133682, /*  1949 (  70) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
    18439772, /*  1950 (  70) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
        3360, /*  1951 (  70) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    52570094, /*  1952 (  70) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
       16322, /*  1953 (  70) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
       16484, /*  1954 (  71) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    18426648, /*  1955 (  71) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
    18439610, /*  1956 (  71) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    51034820, /*  1957 (  71) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  0] -1 */
    51021696, /*  1958 (  71) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  0] -1 */
    18426486, /*  1959 (  71) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
    35432760, /*  1960 (  71) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  0] -1 */
    51034658, /*  1961 (  71) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  0] -1 */
        3198, /*  1962 (  71) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    51021534, /*  1963 (  71) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  0] -1 */
    35445722, /*  1964 (  71) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  0] -1 */
    35445884, /*  1965 (  71) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  0] -1 */
    35432598, /*  1966 (  71) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  0] -1 */
    18439772, /*  1967 (  71) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
        3360, /*  1968 (  71) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
       16322, /*  1969 (  71) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
       16484, /*  1970 (  65) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
     1538634, /*  1971 (  65) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
     1551596, /*  1972 (  65) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
     1538472, /*  1973 (  65) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
        3198, /*  1974 (  65) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
     1551758, /*  1975 (  65) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
        3360, /*  1976 (  65) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
       16322, /*  1977 (  65) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
       16484, /*  1978 (  66) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    35563820, /*  1979 (  66) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
     1538634, /*  1980 (  66) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
    34028546, /*  1981 (  66) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    34015422, /*  1982 (  66) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    35550696, /*  1983 (  66) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  6] -1 */
     1551596, /*  1984 (  66) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
    34015584, /*  1985 (  66) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
     1538472, /*  1986 (  66) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
    35550858, /*  1987 (  66) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6] -1 */
    35563982, /*  1988 (  66) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
        3198, /*  1989 (  66) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
     1551758, /*  1990 (  66) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
        3360, /*  1991 (  66) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    34028708, /*  1992 (  66) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
       16322, /*  1993 (  66) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
       16484, /*  1994 (  67) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34015422, /*  1995 (  67) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    35550696, /*  1996 (  67) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  6] -1 */
     1551596, /*  1997 (  67) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
    34015584, /*  1998 (  67) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
     1551758, /*  1999 (  67) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
    35550858, /*  2000 (  67) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6] -1 */
       16322, /*  2001 (  67) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
       16484, /*  2002 (  68) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    35563820, /*  2003 (  68) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
     1538634, /*  2004 (  68) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
    34028546, /*  2005 (  68) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    34015422, /*  2006 (  68) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    35550696, /*  2007 (  68) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  6] -1 */
     1551758, /*  2008 (  68) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
        3360, /*  2009 (  68) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
       16484, /*  2010 (  69) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    35563820, /*  2011 (  69) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
    34028546, /*  2012 (  69) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    34015584, /*  2013 (  69) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
     1538472, /*  2014 (  69) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
        3198, /*  2015 (  69) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
     1551758, /*  2016 (  69) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
    35550858, /*  2017 (  69) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6] -1 */
       16484, /*  2018 (  70) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
     1538634, /*  2019 (  70) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
     1551596, /*  2020 (  70) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
    51152756, /*  2021 (  70) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
    52451834, /*  2022 (  70) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
     1538472, /*  2023 (  70) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
    51139632, /*  2024 (  70) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  6] -1 */
        3198, /*  2025 (  70) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    52438710, /*  2026 (  70) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
    51152918, /*  2027 (  70) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
    52438872, /*  2028 (  70) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
    51139794, /*  2029 (  70) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6] -1 */
     1551758, /*  2030 (  70) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
        3360, /*  2031 (  70) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    52451996, /*  2032 (  70) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
       16322, /*  2033 (  70) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
       16484, /*  2034 (  71) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
     1538634, /*  2035 (  71) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
     1551596, /*  2036 (  71) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
    34146806, /*  2037 (  71) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    34133682, /*  2038 (  71) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
     1538472, /*  2039 (  71) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
    35432760, /*  2040 (  71) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  0] -1 */
    34146644, /*  2041 (  71) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
        3198, /*  2042 (  71) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    34133520, /*  2043 (  71) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
    35445722, /*  2044 (  71) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  0] -1 */
    35445884, /*  2045 (  71) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  0] -1 */
    35432598, /*  2046 (  71) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  0] -1 */
     1551758, /*  2047 (  71) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
        3360, /*  2048 (  71) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
       16322, /*  2049 (  71) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
       16484, /*  2050 (  65) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    18544746, /*  2051 (  65) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
    18557708, /*  2052 (  65) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    18544584, /*  2053 (  65) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
        3198, /*  2054 (  65) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    18557870, /*  2055 (  65) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
        3360, /*  2056 (  65) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
       16322, /*  2057 (  65) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
       16484, /*  2058 (  66) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    52569932, /*  2059 (  66) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    18544746, /*  2060 (  66) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
    34028546, /*  2061 (  66) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    34015422, /*  2062 (  66) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    52556808, /*  2063 (  66) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    18557708, /*  2064 (  66) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    34015584, /*  2065 (  66) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    18544584, /*  2066 (  66) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
    52556970, /*  2067 (  66) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    52570094, /*  2068 (  66) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
        3198, /*  2069 (  66) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    18557870, /*  2070 (  66) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
        3360, /*  2071 (  66) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    34028708, /*  2072 (  66) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
       16322, /*  2073 (  66) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
       16484, /*  2074 (  67) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34015422, /*  2075 (  67) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    52556808, /*  2076 (  67) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    18557708, /*  2077 (  67) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    34015584, /*  2078 (  67) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    18557870, /*  2079 (  67) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    52556970, /*  2080 (  67) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
       16322, /*  2081 (  67) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
       16484, /*  2082 (  68) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    52569932, /*  2083 (  68) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    18544746, /*  2084 (  68) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
    34028546, /*  2085 (  68) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    34015422, /*  2086 (  68) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    52556808, /*  2087 (  68) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    18557870, /*  2088 (  68) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
        3360, /*  2089 (  68) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
       16484, /*  2090 (  69) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    52569932, /*  2091 (  69) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    34028546, /*  2092 (  69) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    34015584, /*  2093 (  69) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    18544584, /*  2094 (  69) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
        3198, /*  2095 (  69) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    18557870, /*  2096 (  69) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    52556970, /*  2097 (  69) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
       16484, /*  2098 (  70) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    18544746, /*  2099 (  70) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
    18557708, /*  2100 (  70) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    51034658, /*  2101 (  70) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  0] -1 */
    35563820, /*  2102 (  70) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
    18544584, /*  2103 (  70) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
    51021534, /*  2104 (  70) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  0] -1 */
        3198, /*  2105 (  70) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    35550696, /*  2106 (  70) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  6] -1 */
    51034820, /*  2107 (  70) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  0] -1 */
    35550858, /*  2108 (  70) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6] -1 */
    51021696, /*  2109 (  70) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  0] -1 */
    18557870, /*  2110 (  70) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
        3360, /*  2111 (  70) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    35563982, /*  2112 (  70) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
       16322, /*  2113 (  70) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
       16484, /*  2114 (  71) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    18544746, /*  2115 (  71) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
    18557708, /*  2116 (  71) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    51152918, /*  2117 (  71) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
    51139794, /*  2118 (  71) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6] -1 */
    18544584, /*  2119 (  71) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
    35432760, /*  2120 (  71) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  0] -1 */
    51152756, /*  2121 (  71) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
        3198, /*  2122 (  71) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    51139632, /*  2123 (  71) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  6] -1 */
    35445722, /*  2124 (  71) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  0] -1 */
    35445884, /*  2125 (  71) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  0] -1 */
    35432598, /*  2126 (  71) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  0] -1 */
    18557870, /*  2127 (  71) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
        3360, /*  2128 (  71) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
       16322, /*  2129 (  71) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
       16484, /*  2130 (  65) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
     1538474, /*  2131 (  65) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
     1551756, /*  2132 (  65) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
     1538472, /*  2133 (  65) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
        3198, /*  2134 (  65) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
     1551758, /*  2135 (  65) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
        3200, /*  2136 (  65) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
       16482, /*  2137 (  65) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
       16484, /*  2138 (  66) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    35563980, /*  2139 (  66) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6] -1 */
     1538474, /*  2140 (  66) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
    34028706, /*  2141 (  66) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    34015422, /*  2142 (  66) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    35550696, /*  2143 (  66) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  6] -1 */
     1551756, /*  2144 (  66) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
    34015424, /*  2145 (  66) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
     1538472, /*  2146 (  66) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
    35550698, /*  2147 (  66) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
    35563982, /*  2148 (  66) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
        3198, /*  2149 (  66) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
     1551758, /*  2150 (  66) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
        3200, /*  2151 (  66) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34028708, /*  2152 (  66) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
       16482, /*  2153 (  66) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
       16484, /*  2154 (  67) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34015422, /*  2155 (  67) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    35550696, /*  2156 (  67) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  6] -1 */
     1551756, /*  2157 (  67) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
    34015424, /*  2158 (  67) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
     1551758, /*  2159 (  67) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
    35550698, /*  2160 (  67) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
       16482, /*  2161 (  67) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
       16484, /*  2162 (  68) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    35563980, /*  2163 (  68) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6] -1 */
     1538474, /*  2164 (  68) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
    34028706, /*  2165 (  68) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    34015422, /*  2166 (  68) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    35550696, /*  2167 (  68) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  6] -1 */
     1551758, /*  2168 (  68) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
        3200, /*  2169 (  68) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
       16484, /*  2170 (  69) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    35563980, /*  2171 (  69) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6] -1 */
    34028706, /*  2172 (  69) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    34015424, /*  2173 (  69) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
     1538472, /*  2174 (  69) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
        3198, /*  2175 (  69) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
     1551758, /*  2176 (  69) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
    35550698, /*  2177 (  69) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
       16484, /*  2178 (  70) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
     1538474, /*  2179 (  70) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
     1551756, /*  2180 (  70) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
    51034818, /*  2181 (  70) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  0] -1 */
    52570092, /*  2182 (  70) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
     1538472, /*  2183 (  70) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
    51021534, /*  2184 (  70) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  0] -1 */
        3198, /*  2185 (  70) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    52556808, /*  2186 (  70) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    51034820, /*  2187 (  70) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  0] -1 */
    52556810, /*  2188 (  70) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    51021536, /*  2189 (  70) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  0] -1 */
     1551758, /*  2190 (  70) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
        3200, /*  2191 (  70) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    52570094, /*  2192 (  70) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
       16482, /*  2193 (  70) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
       16484, /*  2194 (  71) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
     1538474, /*  2195 (  71) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
     1551756, /*  2196 (  71) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
    35445884, /*  2197 (  71) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  0] -1 */
    35432600, /*  2198 (  71) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  0] -1 */
     1538472, /*  2199 (  71) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
    34133522, /*  2200 (  71) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    35445882, /*  2201 (  71) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  0] -1 */
        3198, /*  2202 (  71) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    35432598, /*  2203 (  71) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  0] -1 */
    34146804, /*  2204 (  71) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
    34146806, /*  2205 (  71) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    34133520, /*  2206 (  71) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
     1551758, /*  2207 (  71) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
        3200, /*  2208 (  71) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
       16482, /*  2209 (  71) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
       16484, /*  2210 (  65) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    17127410, /*  2211 (  65) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
    17140692, /*  2212 (  65) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6]  1 */
    17127408, /*  2213 (  65) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  6]  1 */
        3198, /*  2214 (  65) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    17140694, /*  2215 (  65) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
        3200, /*  2216 (  65) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
       16482, /*  2217 (  65) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
       16484, /*  2218 (  66) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    51152916, /*  2219 (  66) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6] -1 */
    17127410, /*  2220 (  66) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
    34028706, /*  2221 (  66) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    34015422, /*  2222 (  66) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    51139632, /*  2223 (  66) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  6] -1 */
    17140692, /*  2224 (  66) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6]  1 */
    34015424, /*  2225 (  66) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    17127408, /*  2226 (  66) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  6]  1 */
    51139634, /*  2227 (  66) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
    51152918, /*  2228 (  66) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
        3198, /*  2229 (  66) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    17140694, /*  2230 (  66) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
        3200, /*  2231 (  66) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34028708, /*  2232 (  66) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
       16482, /*  2233 (  66) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
       16484, /*  2234 (  67) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34015422, /*  2235 (  67) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    51139632, /*  2236 (  67) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  6] -1 */
    17140692, /*  2237 (  67) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6]  1 */
    34015424, /*  2238 (  67) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    17140694, /*  2239 (  67) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
    51139634, /*  2240 (  67) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
       16482, /*  2241 (  67) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
       16484, /*  2242 (  68) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    51152916, /*  2243 (  68) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6] -1 */
    17127410, /*  2244 (  68) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
    34028706, /*  2245 (  68) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    34015422, /*  2246 (  68) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    51139632, /*  2247 (  68) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  6] -1 */
    17140694, /*  2248 (  68) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
        3200, /*  2249 (  68) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
       16484, /*  2250 (  69) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    51152916, /*  2251 (  69) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6] -1 */
    34028706, /*  2252 (  69) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    34015424, /*  2253 (  69) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    17127408, /*  2254 (  69) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  6]  1 */
        3198, /*  2255 (  69) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    17140694, /*  2256 (  69) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
    51139634, /*  2257 (  69) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
       16484, /*  2258 (  70) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    17127410, /*  2259 (  70) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
    17140692, /*  2260 (  70) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6]  1 */
    52451994, /*  2261 (  70) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
    35563980, /*  2262 (  70) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6] -1 */
    17127408, /*  2263 (  70) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  6]  1 */
    52438710, /*  2264 (  70) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
        3198, /*  2265 (  70) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    35550696, /*  2266 (  70) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  6] -1 */
    52451996, /*  2267 (  70) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
    35550698, /*  2268 (  70) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
    52438712, /*  2269 (  70) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
    17140694, /*  2270 (  70) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
        3200, /*  2271 (  70) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    35563982, /*  2272 (  70) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
       16482, /*  2273 (  70) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
       16484, /*  2274 (  71) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    17127410, /*  2275 (  71) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
    17140692, /*  2276 (  71) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6]  1 */
    51034820, /*  2277 (  71) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  0] -1 */
    51021536, /*  2278 (  71) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  0] -1 */
    17127408, /*  2279 (  71) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  6]  1 */
    34133522, /*  2280 (  71) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    51034818, /*  2281 (  71) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  0] -1 */
        3198, /*  2282 (  71) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    51021534, /*  2283 (  71) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  0] -1 */
    34146804, /*  2284 (  71) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
    34146806, /*  2285 (  71) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    34133520, /*  2286 (  71) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
    17140694, /*  2287 (  71) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
        3200, /*  2288 (  71) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
       16482, /*  2289 (  71) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
       16484, /*  2290 (  65) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    18544586, /*  2291 (  65) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    18557868, /*  2292 (  65) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
    18544584, /*  2293 (  65) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
        3198, /*  2294 (  65) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    18557870, /*  2295 (  65) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
        3200, /*  2296 (  65) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
       16482, /*  2297 (  65) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
       16484, /*  2298 (  66) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    52570092, /*  2299 (  66) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    18544586, /*  2300 (  66) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    34028706, /*  2301 (  66) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    34015422, /*  2302 (  66) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    52556808, /*  2303 (  66) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    18557868, /*  2304 (  66) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
    34015424, /*  2305 (  66) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    18544584, /*  2306 (  66) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
    52556810, /*  2307 (  66) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    52570094, /*  2308 (  66) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
        3198, /*  2309 (  66) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    18557870, /*  2310 (  66) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
        3200, /*  2311 (  66) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34028708, /*  2312 (  66) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
       16482, /*  2313 (  66) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
       16484, /*  2314 (  67) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34015422, /*  2315 (  67) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    52556808, /*  2316 (  67) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    18557868, /*  2317 (  67) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
    34015424, /*  2318 (  67) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    18557870, /*  2319 (  67) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    52556810, /*  2320 (  67) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
       16482, /*  2321 (  67) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
       16484, /*  2322 (  68) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    52570092, /*  2323 (  68) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    18544586, /*  2324 (  68) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    34028706, /*  2325 (  68) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    34015422, /*  2326 (  68) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    52556808, /*  2327 (  68) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    18557870, /*  2328 (  68) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
        3200, /*  2329 (  68) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
       16484, /*  2330 (  69) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    52570092, /*  2331 (  69) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    34028706, /*  2332 (  69) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    34015424, /*  2333 (  69) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    18544584, /*  2334 (  69) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
        3198, /*  2335 (  69) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    18557870, /*  2336 (  69) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    52556810, /*  2337 (  69) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
       16484, /*  2338 (  70) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    18544586, /*  2339 (  70) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    18557868, /*  2340 (  70) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
    35445882, /*  2341 (  70) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  0] -1 */
    51152916, /*  2342 (  70) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6] -1 */
    18544584, /*  2343 (  70) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
    35432598, /*  2344 (  70) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  0] -1 */
        3198, /*  2345 (  70) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    51139632, /*  2346 (  70) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  6] -1 */
    35445884, /*  2347 (  70) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  0] -1 */
    51139634, /*  2348 (  70) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
    35432600, /*  2349 (  70) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  0] -1 */
    18557870, /*  2350 (  70) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
        3200, /*  2351 (  70) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    51152918, /*  2352 (  70) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
       16482, /*  2353 (  70) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
       16484, /*  2354 (  71) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    18544586, /*  2355 (  71) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    18557868, /*  2356 (  71) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
    52451996, /*  2357 (  71) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
    52438712, /*  2358 (  71) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
    18544584, /*  2359 (  71) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
    34133522, /*  2360 (  71) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    52451994, /*  2361 (  71) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
        3198, /*  2362 (  71) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    52438710, /*  2363 (  71) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
    34146804, /*  2364 (  71) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
    34146806, /*  2365 (  71) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    34133520, /*  2366 (  71) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
    18557870, /*  2367 (  71) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
        3200, /*  2368 (  71) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
       16482, /*  2369 (  71) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
       16484, /*  2370 (  65) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    17140530, /*  2371 (  65) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  6]  1 */
    17127572, /*  2372 (  65) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
    17127408, /*  2373 (  65) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  6]  1 */
        3198, /*  2374 (  65) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    17140694, /*  2375 (  65) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
       16320, /*  2376 (  65) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
        3362, /*  2377 (  65) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
       16484, /*  2378 (  66) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    51139796, /*  2379 (  66) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
    17140530, /*  2380 (  66) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  6]  1 */
    34015586, /*  2381 (  66) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    34015422, /*  2382 (  66) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    51139632, /*  2383 (  66) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  6] -1 */
    17127572, /*  2384 (  66) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
    34028544, /*  2385 (  66) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    17127408, /*  2386 (  66) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  6]  1 */
    51152754, /*  2387 (  66) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  6] -1 */
    51152918, /*  2388 (  66) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
        3198, /*  2389 (  66) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    17140694, /*  2390 (  66) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
       16320, /*  2391 (  66) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    34028708, /*  2392 (  66) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
        3362, /*  2393 (  66) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
       16484, /*  2394 (  67) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34015422, /*  2395 (  67) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    51139632, /*  2396 (  67) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  6] -1 */
    17127572, /*  2397 (  67) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
    34028544, /*  2398 (  67) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    17140694, /*  2399 (  67) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
    51152754, /*  2400 (  67) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  6] -1 */
        3362, /*  2401 (  67) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
       16484, /*  2402 (  68) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    51139796, /*  2403 (  68) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
    17140530, /*  2404 (  68) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  6]  1 */
    34015586, /*  2405 (  68) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    34015422, /*  2406 (  68) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    51139632, /*  2407 (  68) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  6] -1 */
    17140694, /*  2408 (  68) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
       16320, /*  2409 (  68) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
       16484, /*  2410 (  69) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    51139796, /*  2411 (  69) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
    34015586, /*  2412 (  69) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    34028544, /*  2413 (  69) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    17127408, /*  2414 (  69) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  6]  1 */
        3198, /*  2415 (  69) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    17140694, /*  2416 (  69) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
    51152754, /*  2417 (  69) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  6] -1 */
       16484, /*  2418 (  70) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    17140530, /*  2419 (  70) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  6]  1 */
    17127572, /*  2420 (  70) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
    35432762, /*  2421 (  70) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  0] -1 */
    52556972, /*  2422 (  70) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    17127408, /*  2423 (  70) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  6]  1 */
    35432598, /*  2424 (  70) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  0] -1 */
        3198, /*  2425 (  70) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    52556808, /*  2426 (  70) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    35445884, /*  2427 (  70) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  0] -1 */
    52569930, /*  2428 (  70) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    35445720, /*  2429 (  70) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  0] -1 */
    17140694, /*  2430 (  70) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
       16320, /*  2431 (  70) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    52570094, /*  2432 (  70) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
        3362, /*  2433 (  70) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
       16484, /*  2434 (  71) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    17140530, /*  2435 (  71) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  6]  1 */
    17127572, /*  2436 (  71) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
    34146806, /*  2437 (  71) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    34146642, /*  2438 (  71) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
    17127408, /*  2439 (  71) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  6]  1 */
    51034656, /*  2440 (  71) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  0] -1 */
    34133684, /*  2441 (  71) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
        3198, /*  2442 (  71) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    34133520, /*  2443 (  71) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
    51021698, /*  2444 (  71) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  0] -1 */
    51034820, /*  2445 (  71) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  0] -1 */
    51021534, /*  2446 (  71) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  0] -1 */
    17140694, /*  2447 (  71) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
       16320, /*  2448 (  71) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
        3362, /*  2449 (  71) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
       16484, /*  2450 (  65) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    18439608, /*  2451 (  65) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
    18426650, /*  2452 (  65) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    18426486, /*  2453 (  65) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
        3198, /*  2454 (  65) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    18439772, /*  2455 (  65) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
       16320, /*  2456 (  65) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
        3362, /*  2457 (  65) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
       16484, /*  2458 (  66) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    52438874, /*  2459 (  66) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
    18439608, /*  2460 (  66) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
    34015586, /*  2461 (  66) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    34015422, /*  2462 (  66) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    52438710, /*  2463 (  66) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
    18426650, /*  2464 (  66) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    34028544, /*  2465 (  66) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    18426486, /*  2466 (  66) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
    52451832, /*  2467 (  66) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
    52451996, /*  2468 (  66) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
        3198, /*  2469 (  66) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    18439772, /*  2470 (  66) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
       16320, /*  2471 (  66) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    34028708, /*  2472 (  66) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
        3362, /*  2473 (  66) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
       16484, /*  2474 (  67) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34015422, /*  2475 (  67) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    52438710, /*  2476 (  67) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
    18426650, /*  2477 (  67) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    34028544, /*  2478 (  67) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    18439772, /*  2479 (  67) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    52451832, /*  2480 (  67) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
        3362, /*  2481 (  67) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
       16484, /*  2482 (  68) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    52438874, /*  2483 (  68) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
    18439608, /*  2484 (  68) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
    34015586, /*  2485 (  68) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    34015422, /*  2486 (  68) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    52438710, /*  2487 (  68) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
    18439772, /*  2488 (  68) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
       16320, /*  2489 (  68) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
       16484, /*  2490 (  69) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    52438874, /*  2491 (  69) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
    34015586, /*  2492 (  69) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    34028544, /*  2493 (  69) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    18426486, /*  2494 (  69) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
        3198, /*  2495 (  69) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    18439772, /*  2496 (  69) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    52451832, /*  2497 (  69) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
       16484, /*  2498 (  70) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    18439608, /*  2499 (  70) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
    18426650, /*  2500 (  70) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    35550860, /*  2501 (  70) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
    51139796, /*  2502 (  70) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
    18426486, /*  2503 (  70) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
    35550696, /*  2504 (  70) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  6] -1 */
        3198, /*  2505 (  70) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    51139632, /*  2506 (  70) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  6] -1 */
    35563982, /*  2507 (  70) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
    51152754, /*  2508 (  70) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  6] -1 */
    35563818, /*  2509 (  70) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  6] -1 */
    18439772, /*  2510 (  70) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
       16320, /*  2511 (  70) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    51152918, /*  2512 (  70) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
        3362, /*  2513 (  70) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
       16484, /*  2514 (  71) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    18439608, /*  2515 (  71) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
    18426650, /*  2516 (  71) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    35445884, /*  2517 (  71) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  0] -1 */
    35445720, /*  2518 (  71) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  0] -1 */
    18426486, /*  2519 (  71) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
    51034656, /*  2520 (  71) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  0] -1 */
    35432762, /*  2521 (  71) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  0] -1 */
        3198, /*  2522 (  71) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    35432598, /*  2523 (  71) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  0] -1 */
    51021698, /*  2524 (  71) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  0] -1 */
    51034820, /*  2525 (  71) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  0] -1 */
    51021534, /*  2526 (  71) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  0] -1 */
    18439772, /*  2527 (  71) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
       16320, /*  2528 (  71) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
        3362, /*  2529 (  71) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
       16484, /*  2530 (  65) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    18557706, /*  2531 (  65) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
    18544748, /*  2532 (  65) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    18544584, /*  2533 (  65) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
        3198, /*  2534 (  65) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    18557870, /*  2535 (  65) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
       16320, /*  2536 (  65) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
        3362, /*  2537 (  65) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
       16484, /*  2538 (  66) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    52556972, /*  2539 (  66) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    18557706, /*  2540 (  66) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
    34015586, /*  2541 (  66) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    34015422, /*  2542 (  66) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    52556808, /*  2543 (  66) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    18544748, /*  2544 (  66) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    34028544, /*  2545 (  66) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    18544584, /*  2546 (  66) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
    52569930, /*  2547 (  66) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    52570094, /*  2548 (  66) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
        3198, /*  2549 (  66) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    18557870, /*  2550 (  66) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
       16320, /*  2551 (  66) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    34028708, /*  2552 (  66) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
        3362, /*  2553 (  66) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
       16484, /*  2554 (  67) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34015422, /*  2555 (  67) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    52556808, /*  2556 (  67) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    18544748, /*  2557 (  67) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    34028544, /*  2558 (  67) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    18557870, /*  2559 (  67) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    52569930, /*  2560 (  67) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
        3362, /*  2561 (  67) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
       16484, /*  2562 (  68) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    52556972, /*  2563 (  68) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    18557706, /*  2564 (  68) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
    34015586, /*  2565 (  68) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    34015422, /*  2566 (  68) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    52556808, /*  2567 (  68) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    18557870, /*  2568 (  68) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
       16320, /*  2569 (  68) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
       16484, /*  2570 (  69) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    52556972, /*  2571 (  69) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    34015586, /*  2572 (  69) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    34028544, /*  2573 (  69) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    18544584, /*  2574 (  69) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
        3198, /*  2575 (  69) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    18557870, /*  2576 (  69) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    52569930, /*  2577 (  69) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
       16484, /*  2578 (  70) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    18557706, /*  2579 (  70) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
    18544748, /*  2580 (  70) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    34133684, /*  2581 (  70) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    52438874, /*  2582 (  70) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
    18544584, /*  2583 (  70) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
    34133520, /*  2584 (  70) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
        3198, /*  2585 (  70) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    52438710, /*  2586 (  70) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
    34146806, /*  2587 (  70) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    52451832, /*  2588 (  70) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
    34146642, /*  2589 (  70) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
    18557870, /*  2590 (  70) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
       16320, /*  2591 (  70) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    52451996, /*  2592 (  70) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
        3362, /*  2593 (  70) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
       16484, /*  2594 (  71) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    18557706, /*  2595 (  71) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
    18544748, /*  2596 (  71) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    35563982, /*  2597 (  71) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
    35563818, /*  2598 (  71) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  6] -1 */
    18544584, /*  2599 (  71) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
    51034656, /*  2600 (  71) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  0] -1 */
    35550860, /*  2601 (  71) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
        3198, /*  2602 (  71) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    35550696, /*  2603 (  71) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  6] -1 */
    51021698, /*  2604 (  71) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  0] -1 */
    51034820, /*  2605 (  71) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  0] -1 */
    51021534, /*  2606 (  71) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  0] -1 */
    18557870, /*  2607 (  71) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
       16320, /*  2608 (  71) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
        3362, /*  2609 (  71) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
       16484, /*  2610 (  72) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
      134420, /*  2611 (  72) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6]  1 */
        3198, /*  2612 (  72) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
      121458, /*  2613 (  72) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  6]  1 */
       16484, /*  2614 (  73) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
      121458, /*  2615 (  73) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  6]  1 */
    34015422, /*  2616 (  73) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    34146644, /*  2617 (  73) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
        3198, /*  2618 (  73) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    34133682, /*  2619 (  73) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
      134420, /*  2620 (  73) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6]  1 */
    34028708, /*  2621 (  73) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
       16484, /*  2622 (  74) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
      134420, /*  2623 (  74) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6]  1 */
    34015422, /*  2624 (  74) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    34133682, /*  2625 (  74) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
       16484, /*  2626 (  75) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34146644, /*  2627 (  75) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    34015422, /*  2628 (  75) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
      121458, /*  2629 (  75) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  6]  1 */
       16484, /*  2630 (  76) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34146644, /*  2631 (  76) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
        3198, /*  2632 (  76) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    34133682, /*  2633 (  76) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
       16484, /*  2634 (  77) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    51139794, /*  2635 (  77) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6] -1 */
      121458, /*  2636 (  77) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  6]  1 */
    51152756, /*  2637 (  77) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
    51034820, /*  2638 (  77) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  0] -1 */
        3198, /*  2639 (  77) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    51021534, /*  2640 (  77) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  0] -1 */
      134420, /*  2641 (  77) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6]  1 */
       16484, /*  2642 (  78) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
      121458, /*  2643 (  78) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  6]  1 */
    35550858, /*  2644 (  78) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6] -1 */
        3198, /*  2645 (  78) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    35445884, /*  2646 (  78) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  0] -1 */
    35432598, /*  2647 (  78) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  0] -1 */
      134420, /*  2648 (  78) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6]  1 */
    35563820, /*  2649 (  78) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
       16484, /*  2650 (  79) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34028546, /*  2651 (  79) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
      121458, /*  2652 (  79) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  6]  1 */
    34015584, /*  2653 (  79) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    34133520, /*  2654 (  79) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
        3198, /*  2655 (  79) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    34146806, /*  2656 (  79) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
      134420, /*  2657 (  79) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6]  1 */
       16484, /*  2658 (  80) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    35550696, /*  2659 (  80) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  6] -1 */
      121458, /*  2660 (  80) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  6]  1 */
    35432760, /*  2661 (  80) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  0] -1 */
    35563982, /*  2662 (  80) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
        3198, /*  2663 (  80) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    35445722, /*  2664 (  80) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  0] -1 */
      134420, /*  2665 (  80) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6]  1 */
       16484, /*  2666 (  81) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
      121458, /*  2667 (  81) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  6]  1 */
    52438710, /*  2668 (  81) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
    52569932, /*  2669 (  81) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    52451996, /*  2670 (  81) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
        3198, /*  2671 (  81) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    52556970, /*  2672 (  81) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
      134420, /*  2673 (  81) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6]  1 */
       16484, /*  2674 (  72) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    17140532, /*  2675 (  72) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
        3198, /*  2676 (  72) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    17127570, /*  2677 (  72) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6]  1 */
       16484, /*  2678 (  73) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    17127570, /*  2679 (  73) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6]  1 */
    34015422, /*  2680 (  73) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    51152756, /*  2681 (  73) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
        3198, /*  2682 (  73) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    51139794, /*  2683 (  73) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6] -1 */
    17140532, /*  2684 (  73) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
    34028708, /*  2685 (  73) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
       16484, /*  2686 (  74) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    17140532, /*  2687 (  74) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
    34015422, /*  2688 (  74) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    51139794, /*  2689 (  74) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6] -1 */
       16484, /*  2690 (  75) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    51152756, /*  2691 (  75) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
    34015422, /*  2692 (  75) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    17127570, /*  2693 (  75) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6]  1 */
       16484, /*  2694 (  76) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    51152756, /*  2695 (  76) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
        3198, /*  2696 (  76) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    51139794, /*  2697 (  76) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6] -1 */
       16484, /*  2698 (  77) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    51021696, /*  2699 (  77) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  0] -1 */
    17127570, /*  2700 (  77) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6]  1 */
    51034658, /*  2701 (  77) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  0] -1 */
    34146806, /*  2702 (  77) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
        3198, /*  2703 (  77) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    34133520, /*  2704 (  77) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
    17140532, /*  2705 (  77) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
       16484, /*  2706 (  78) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    17127570, /*  2707 (  78) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6]  1 */
    52556970, /*  2708 (  78) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
        3198, /*  2709 (  78) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    35445884, /*  2710 (  78) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  0] -1 */
    35432598, /*  2711 (  78) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  0] -1 */
    17140532, /*  2712 (  78) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
    52569932, /*  2713 (  78) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
       16484, /*  2714 (  79) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34028546, /*  2715 (  79) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    17127570, /*  2716 (  79) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6]  1 */
    34015584, /*  2717 (  79) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    51139632, /*  2718 (  79) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  6] -1 */
        3198, /*  2719 (  79) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    51152918, /*  2720 (  79) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
    17140532, /*  2721 (  79) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
       16484, /*  2722 (  80) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    52556808, /*  2723 (  80) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    17127570, /*  2724 (  80) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6]  1 */
    35432760, /*  2725 (  80) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  0] -1 */
    52570094, /*  2726 (  80) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
        3198, /*  2727 (  80) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    35445722, /*  2728 (  80) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  0] -1 */
    17140532, /*  2729 (  80) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
       16484, /*  2730 (  81) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    17127570, /*  2731 (  81) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6]  1 */
    35550696, /*  2732 (  81) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  6] -1 */
    52451834, /*  2733 (  81) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
    35563982, /*  2734 (  81) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
        3198, /*  2735 (  81) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    52438872, /*  2736 (  81) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
    17140532, /*  2737 (  81) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
       16484, /*  2738 (  72) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    17022434, /*  2739 (  72) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  0]  1 */
        3198, /*  2740 (  72) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    17009472, /*  2741 (  72) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  0]  1 */
       16484, /*  2742 (  73) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    17009472, /*  2743 (  73) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  0]  1 */
    34015422, /*  2744 (  73) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    51034658, /*  2745 (  73) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  0] -1 */
        3198, /*  2746 (  73) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    51021696, /*  2747 (  73) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  0] -1 */
    17022434, /*  2748 (  73) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  0]  1 */
    34028708, /*  2749 (  73) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
       16484, /*  2750 (  74) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    17022434, /*  2751 (  74) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  0]  1 */
    34015422, /*  2752 (  74) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    51021696, /*  2753 (  74) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  0] -1 */
       16484, /*  2754 (  75) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    51034658, /*  2755 (  75) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  0] -1 */
    34015422, /*  2756 (  75) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    17009472, /*  2757 (  75) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  0]  1 */
       16484, /*  2758 (  76) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    51034658, /*  2759 (  76) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  0] -1 */
        3198, /*  2760 (  76) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    51021696, /*  2761 (  76) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  0] -1 */
       16484, /*  2762 (  77) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34133682, /*  2763 (  77) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
    17009472, /*  2764 (  77) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  0]  1 */
    34146644, /*  2765 (  77) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    51152918, /*  2766 (  77) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
        3198, /*  2767 (  77) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    51139632, /*  2768 (  77) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  6] -1 */
    17022434, /*  2769 (  77) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  0]  1 */
       16484, /*  2770 (  78) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    17009472, /*  2771 (  78) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  0]  1 */
    52438872, /*  2772 (  78) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
        3198, /*  2773 (  78) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    35445884, /*  2774 (  78) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  0] -1 */
    35432598, /*  2775 (  78) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  0] -1 */
    17022434, /*  2776 (  78) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  0]  1 */
    52451834, /*  2777 (  78) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
       16484, /*  2778 (  79) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34028546, /*  2779 (  79) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    17009472, /*  2780 (  79) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  0]  1 */
    34015584, /*  2781 (  79) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    51021534, /*  2782 (  79) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  0] -1 */
        3198, /*  2783 (  79) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    51034820, /*  2784 (  79) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  0] -1 */
    17022434, /*  2785 (  79) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  0]  1 */
       16484, /*  2786 (  80) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    52438710, /*  2787 (  80) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
    17009472, /*  2788 (  80) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  0]  1 */
    35432760, /*  2789 (  80) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  0] -1 */
    52451996, /*  2790 (  80) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
        3198, /*  2791 (  80) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    35445722, /*  2792 (  80) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  0] -1 */
    17022434, /*  2793 (  80) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  0]  1 */
       16484, /*  2794 (  81) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    17009472, /*  2795 (  81) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  0]  1 */
    52556808, /*  2796 (  81) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    35563820, /*  2797 (  81) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
    52570094, /*  2798 (  81) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
        3198, /*  2799 (  81) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    35550858, /*  2800 (  81) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6] -1 */
    17022434, /*  2801 (  81) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  0]  1 */
       16484, /*  2802 (  72) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    17022594, /*  2803 (  72) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  0]  1 */
        3198, /*  2804 (  72) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    17009312, /*  2805 (  72) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  0]  1 */
       16484, /*  2806 (  73) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    17009312, /*  2807 (  73) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  0]  1 */
    34015422, /*  2808 (  73) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    51034818, /*  2809 (  73) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  0] -1 */
        3198, /*  2810 (  73) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    51021536, /*  2811 (  73) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  0] -1 */
    17022594, /*  2812 (  73) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  0]  1 */
    34028708, /*  2813 (  73) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
       16484, /*  2814 (  74) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    17022594, /*  2815 (  74) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  0]  1 */
    34015422, /*  2816 (  74) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    51021536, /*  2817 (  74) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  0] -1 */
       16484, /*  2818 (  75) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    51034818, /*  2819 (  75) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  0] -1 */
    34015422, /*  2820 (  75) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    17009312, /*  2821 (  75) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  0]  1 */
       16484, /*  2822 (  76) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    51034818, /*  2823 (  76) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  0] -1 */
        3198, /*  2824 (  76) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    51021536, /*  2825 (  76) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  0] -1 */
       16484, /*  2826 (  77) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    52438712, /*  2827 (  77) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
    17009312, /*  2828 (  77) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  0]  1 */
    52451994, /*  2829 (  77) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
    35445884, /*  2830 (  77) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  0] -1 */
        3198, /*  2831 (  77) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    35432598, /*  2832 (  77) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  0] -1 */
    17022594, /*  2833 (  77) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  0]  1 */
       16484, /*  2834 (  78) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    17009312, /*  2835 (  78) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  0]  1 */
    51139634, /*  2836 (  78) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
        3198, /*  2837 (  78) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    34146806, /*  2838 (  78) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    34133520, /*  2839 (  78) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
    17022594, /*  2840 (  78) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  0]  1 */
    51152916, /*  2841 (  78) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6] -1 */
       16484, /*  2842 (  79) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34028706, /*  2843 (  79) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    17009312, /*  2844 (  79) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  0]  1 */
    34015424, /*  2845 (  79) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    51021534, /*  2846 (  79) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  0] -1 */
        3198, /*  2847 (  79) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    51034820, /*  2848 (  79) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  0] -1 */
    17022594, /*  2849 (  79) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  0]  1 */
       16484, /*  2850 (  80) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    51139632, /*  2851 (  80) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  6] -1 */
    17009312, /*  2852 (  80) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  0]  1 */
    34133522, /*  2853 (  80) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    51152918, /*  2854 (  80) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
        3198, /*  2855 (  80) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    34146804, /*  2856 (  80) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
    17022594, /*  2857 (  80) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  0]  1 */
       16484, /*  2858 (  81) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    17009312, /*  2859 (  81) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  0]  1 */
    35550696, /*  2860 (  81) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  6] -1 */
    52570092, /*  2861 (  81) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    35563982, /*  2862 (  81) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
        3198, /*  2863 (  81) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    52556810, /*  2864 (  81) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    17022594, /*  2865 (  81) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  0]  1 */
       16484, /*  2866 (  72) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    18439770, /*  2867 (  72) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
        3198, /*  2868 (  72) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    18426488, /*  2869 (  72) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
       16484, /*  2870 (  73) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    18426488, /*  2871 (  73) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    34015422, /*  2872 (  73) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    52451994, /*  2873 (  73) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
        3198, /*  2874 (  73) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    52438712, /*  2875 (  73) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
    18439770, /*  2876 (  73) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
    34028708, /*  2877 (  73) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
       16484, /*  2878 (  74) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    18439770, /*  2879 (  74) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
    34015422, /*  2880 (  74) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    52438712, /*  2881 (  74) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
       16484, /*  2882 (  75) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    52451994, /*  2883 (  75) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
    34015422, /*  2884 (  75) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    18426488, /*  2885 (  75) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
       16484, /*  2886 (  76) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    52451994, /*  2887 (  76) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
        3198, /*  2888 (  76) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    52438712, /*  2889 (  76) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
       16484, /*  2890 (  77) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    35432600, /*  2891 (  77) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  0] -1 */
    18426488, /*  2892 (  77) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    35445882, /*  2893 (  77) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  0] -1 */
    51034820, /*  2894 (  77) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  0] -1 */
        3198, /*  2895 (  77) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    51021534, /*  2896 (  77) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  0] -1 */
    18439770, /*  2897 (  77) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
       16484, /*  2898 (  78) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    18426488, /*  2899 (  78) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    52556810, /*  2900 (  78) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
        3198, /*  2901 (  78) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    34146806, /*  2902 (  78) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    34133520, /*  2903 (  78) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
    18439770, /*  2904 (  78) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
    52570092, /*  2905 (  78) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
       16484, /*  2906 (  79) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34028706, /*  2907 (  79) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    18426488, /*  2908 (  79) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    34015424, /*  2909 (  79) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    52438710, /*  2910 (  79) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
        3198, /*  2911 (  79) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    52451996, /*  2912 (  79) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
    18439770, /*  2913 (  79) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
       16484, /*  2914 (  80) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    52556808, /*  2915 (  80) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    18426488, /*  2916 (  80) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    34133522, /*  2917 (  80) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    52570094, /*  2918 (  80) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
        3198, /*  2919 (  80) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    34146804, /*  2920 (  80) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
    18439770, /*  2921 (  80) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
       16484, /*  2922 (  81) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    18426488, /*  2923 (  81) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    51139632, /*  2924 (  81) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  6] -1 */
    35563980, /*  2925 (  81) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6] -1 */
    51152918, /*  2926 (  81) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
        3198, /*  2927 (  81) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    35550698, /*  2928 (  81) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
    18439770, /*  2929 (  81) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
       16484, /*  2930 (  72) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
     1433658, /*  2931 (  72) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  0]  1 */
        3198, /*  2932 (  72) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
     1420376, /*  2933 (  72) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  0]  1 */
       16484, /*  2934 (  73) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
     1420376, /*  2935 (  73) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  0]  1 */
    34015422, /*  2936 (  73) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    35445882, /*  2937 (  73) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  0] -1 */
        3198, /*  2938 (  73) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    35432600, /*  2939 (  73) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  0] -1 */
     1433658, /*  2940 (  73) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  0]  1 */
    34028708, /*  2941 (  73) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
       16484, /*  2942 (  74) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
     1433658, /*  2943 (  74) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  0]  1 */
    34015422, /*  2944 (  74) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    35432600, /*  2945 (  74) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  0] -1 */
       16484, /*  2946 (  75) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    35445882, /*  2947 (  75) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  0] -1 */
    34015422, /*  2948 (  75) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
     1420376, /*  2949 (  75) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  0]  1 */
       16484, /*  2950 (  76) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    35445882, /*  2951 (  76) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  0] -1 */
        3198, /*  2952 (  76) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    35432600, /*  2953 (  76) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  0] -1 */
       16484, /*  2954 (  77) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    51021536, /*  2955 (  77) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  0] -1 */
     1420376, /*  2956 (  77) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  0]  1 */
    51034818, /*  2957 (  77) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  0] -1 */
    52451996, /*  2958 (  77) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
        3198, /*  2959 (  77) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    52438710, /*  2960 (  77) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
     1433658, /*  2961 (  77) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  0]  1 */
       16484, /*  2962 (  78) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
     1420376, /*  2963 (  78) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  0]  1 */
    35550698, /*  2964 (  78) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
        3198, /*  2965 (  78) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    34146806, /*  2966 (  78) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    34133520, /*  2967 (  78) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
     1433658, /*  2968 (  78) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  0]  1 */
    35563980, /*  2969 (  78) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6] -1 */
       16484, /*  2970 (  79) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34028706, /*  2971 (  79) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
     1420376, /*  2972 (  79) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  0]  1 */
    34015424, /*  2973 (  79) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    35432598, /*  2974 (  79) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  0] -1 */
        3198, /*  2975 (  79) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    35445884, /*  2976 (  79) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  0] -1 */
     1433658, /*  2977 (  79) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  0]  1 */
       16484, /*  2978 (  80) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    35550696, /*  2979 (  80) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  6] -1 */
     1420376, /*  2980 (  80) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  0]  1 */
    34133522, /*  2981 (  80) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    35563982, /*  2982 (  80) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
        3198, /*  2983 (  80) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    34146804, /*  2984 (  80) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
     1433658, /*  2985 (  80) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  0]  1 */
       16484, /*  2986 (  81) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
     1420376, /*  2987 (  81) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  0]  1 */
    52556808, /*  2988 (  81) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    51152916, /*  2989 (  81) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6] -1 */
    52570094, /*  2990 (  81) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
        3198, /*  2991 (  81) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    51139634, /*  2992 (  81) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
     1433658, /*  2993 (  81) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  0]  1 */
       16484, /*  2994 (  72) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
     1420538, /*  2995 (  72) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  0]  1 */
        3198, /*  2996 (  72) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
     1433496, /*  2997 (  72) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  0]  1 */
       16484, /*  2998 (  73) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
     1433496, /*  2999 (  73) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  0]  1 */
    34015422, /*  3000 (  73) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    35432762, /*  3001 (  73) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  0] -1 */
        3198, /*  3002 (  73) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    35445720, /*  3003 (  73) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  0] -1 */
     1420538, /*  3004 (  73) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  0]  1 */
    34028708, /*  3005 (  73) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
       16484, /*  3006 (  74) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
     1420538, /*  3007 (  74) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  0]  1 */
    34015422, /*  3008 (  74) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    35445720, /*  3009 (  74) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  0] -1 */
       16484, /*  3010 (  75) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    35432762, /*  3011 (  75) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  0] -1 */
    34015422, /*  3012 (  75) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
     1433496, /*  3013 (  75) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  0]  1 */
       16484, /*  3014 (  76) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    35432762, /*  3015 (  76) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  0] -1 */
        3198, /*  3016 (  76) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    35445720, /*  3017 (  76) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  0] -1 */
       16484, /*  3018 (  77) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    35563818, /*  3019 (  77) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  6] -1 */
     1433496, /*  3020 (  77) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  0]  1 */
    35550860, /*  3021 (  77) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
    34146806, /*  3022 (  77) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
        3198, /*  3023 (  77) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    34133520, /*  3024 (  77) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
     1420538, /*  3025 (  77) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  0]  1 */
       16484, /*  3026 (  78) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
     1433496, /*  3027 (  78) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  0]  1 */
    52451832, /*  3028 (  78) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
        3198, /*  3029 (  78) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    51034820, /*  3030 (  78) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  0] -1 */
    51021534, /*  3031 (  78) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  0] -1 */
     1420538, /*  3032 (  78) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  0]  1 */
    52438874, /*  3033 (  78) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
       16484, /*  3034 (  79) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34015586, /*  3035 (  79) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
     1433496, /*  3036 (  79) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  0]  1 */
    34028544, /*  3037 (  79) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    35432598, /*  3038 (  79) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  0] -1 */
        3198, /*  3039 (  79) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    35445884, /*  3040 (  79) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  0] -1 */
     1420538, /*  3041 (  79) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  0]  1 */
       16484, /*  3042 (  80) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    52438710, /*  3043 (  80) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
     1433496, /*  3044 (  80) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  0]  1 */
    51034656, /*  3045 (  80) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  0] -1 */
    52451996, /*  3046 (  80) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
        3198, /*  3047 (  80) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    51021698, /*  3048 (  80) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  0] -1 */
     1420538, /*  3049 (  80) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  0]  1 */
       16484, /*  3050 (  81) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
     1433496, /*  3051 (  81) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  0]  1 */
    51139632, /*  3052 (  81) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  6] -1 */
    52556972, /*  3053 (  81) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    51152918, /*  3054 (  81) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
        3198, /*  3055 (  81) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    52569930, /*  3056 (  81) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
     1420538, /*  3057 (  81) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  0]  1 */
       16484, /*  3058 (  72) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
     1538636, /*  3059 (  72) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
        3198, /*  3060 (  72) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
     1551594, /*  3061 (  72) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
       16484, /*  3062 (  73) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
     1551594, /*  3063 (  73) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
    34015422, /*  3064 (  73) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    35550860, /*  3065 (  73) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
        3198, /*  3066 (  73) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    35563818, /*  3067 (  73) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  6] -1 */
     1538636, /*  3068 (  73) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
    34028708, /*  3069 (  73) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
       16484, /*  3070 (  74) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
     1538636, /*  3071 (  74) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
    34015422, /*  3072 (  74) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    35563818, /*  3073 (  74) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  6] -1 */
       16484, /*  3074 (  75) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    35550860, /*  3075 (  75) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
    34015422, /*  3076 (  75) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
     1551594, /*  3077 (  75) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
       16484, /*  3078 (  76) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    35550860, /*  3079 (  76) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
        3198, /*  3080 (  76) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    35563818, /*  3081 (  76) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  6] -1 */
       16484, /*  3082 (  77) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34146642, /*  3083 (  77) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
     1551594, /*  3084 (  77) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
    34133684, /*  3085 (  77) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    35445884, /*  3086 (  77) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  0] -1 */
        3198, /*  3087 (  77) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    35432598, /*  3088 (  77) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  0] -1 */
     1538636, /*  3089 (  77) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
       16484, /*  3090 (  78) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
     1551594, /*  3091 (  78) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
    52569930, /*  3092 (  78) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
        3198, /*  3093 (  78) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    51034820, /*  3094 (  78) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  0] -1 */
    51021534, /*  3095 (  78) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  0] -1 */
     1538636, /*  3096 (  78) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
    52556972, /*  3097 (  78) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
       16484, /*  3098 (  79) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34015586, /*  3099 (  79) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
     1551594, /*  3100 (  79) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
    34028544, /*  3101 (  79) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    35550696, /*  3102 (  79) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  6] -1 */
        3198, /*  3103 (  79) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    35563982, /*  3104 (  79) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
     1538636, /*  3105 (  79) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
       16484, /*  3106 (  80) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    52556808, /*  3107 (  80) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
     1551594, /*  3108 (  80) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
    51034656, /*  3109 (  80) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  0] -1 */
    52570094, /*  3110 (  80) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
        3198, /*  3111 (  80) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    51021698, /*  3112 (  80) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  0] -1 */
     1538636, /*  3113 (  80) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
       16484, /*  3114 (  81) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
     1551594, /*  3115 (  81) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
    52438710, /*  3116 (  81) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
    51139796, /*  3117 (  81) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
    52451996, /*  3118 (  81) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
        3198, /*  3119 (  81) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    51152754, /*  3120 (  81) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  6] -1 */
     1538636, /*  3121 (  81) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
       16484, /*  3122 (  72) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
      121460, /*  3123 (  72) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6]  1 */
        3198, /*  3124 (  72) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
      134418, /*  3125 (  72) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  6]  1 */
       16484, /*  3126 (  73) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
      134418, /*  3127 (  73) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  6]  1 */
    34015422, /*  3128 (  73) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    34133684, /*  3129 (  73) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
        3198, /*  3130 (  73) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    34146642, /*  3131 (  73) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
      121460, /*  3132 (  73) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6]  1 */
    34028708, /*  3133 (  73) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
       16484, /*  3134 (  74) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
      121460, /*  3135 (  74) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6]  1 */
    34015422, /*  3136 (  74) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    34146642, /*  3137 (  74) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
       16484, /*  3138 (  75) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34133684, /*  3139 (  75) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    34015422, /*  3140 (  75) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
      134418, /*  3141 (  75) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  6]  1 */
       16484, /*  3142 (  76) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34133684, /*  3143 (  76) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
        3198, /*  3144 (  76) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    34146642, /*  3145 (  76) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
       16484, /*  3146 (  77) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    35445720, /*  3147 (  77) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  0] -1 */
      134418, /*  3148 (  77) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  6]  1 */
    35432762, /*  3149 (  77) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  0] -1 */
    35563982, /*  3150 (  77) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
        3198, /*  3151 (  77) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    35550696, /*  3152 (  77) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  6] -1 */
      121460, /*  3153 (  77) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6]  1 */
       16484, /*  3154 (  78) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
      134418, /*  3155 (  78) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  6]  1 */
    51152754, /*  3156 (  78) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  6] -1 */
        3198, /*  3157 (  78) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    51034820, /*  3158 (  78) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  0] -1 */
    51021534, /*  3159 (  78) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  0] -1 */
      121460, /*  3160 (  78) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6]  1 */
    51139796, /*  3161 (  78) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
       16484, /*  3162 (  79) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34015586, /*  3163 (  79) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
      134418, /*  3164 (  79) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  6]  1 */
    34028544, /*  3165 (  79) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    34133520, /*  3166 (  79) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
        3198, /*  3167 (  79) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    34146806, /*  3168 (  79) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
      121460, /*  3169 (  79) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6]  1 */
       16484, /*  3170 (  80) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    51139632, /*  3171 (  80) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  6] -1 */
      134418, /*  3172 (  80) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  6]  1 */
    51034656, /*  3173 (  80) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  0] -1 */
    51152918, /*  3174 (  80) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
        3198, /*  3175 (  80) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    51021698, /*  3176 (  80) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  0] -1 */
      121460, /*  3177 (  80) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6]  1 */
       16484, /*  3178 (  81) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
      134418, /*  3179 (  81) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  6]  1 */
    52556808, /*  3180 (  81) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    52438874, /*  3181 (  81) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
    52570094, /*  3182 (  81) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
        3198, /*  3183 (  81) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    52451832, /*  3184 (  81) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
      121460, /*  3185 (  81) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6]  1 */
       16484, /*  3186 (  82) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
        3198, /*  3187 (  82) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
     1551596, /*  3188 (  82) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
     1538634, /*  3189 (  82) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
       16484, /*  3190 (  83) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34015422, /*  3191 (  83) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
     1551596, /*  3192 (  83) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
        3198, /*  3193 (  83) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    35550858, /*  3194 (  83) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6] -1 */
    34028708, /*  3195 (  83) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    35563820, /*  3196 (  83) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
     1538634, /*  3197 (  83) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
       16484, /*  3198 (  84) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    35550858, /*  3199 (  84) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6] -1 */
    34015422, /*  3200 (  84) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
     1551596, /*  3201 (  84) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
       16484, /*  3202 (  85) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34015422, /*  3203 (  85) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    35563820, /*  3204 (  85) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
     1538634, /*  3205 (  85) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
       16484, /*  3206 (  86) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    35550858, /*  3207 (  86) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6] -1 */
        3198, /*  3208 (  86) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    35563820, /*  3209 (  86) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
       16484, /*  3210 (  87) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    51034820, /*  3211 (  87) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  0] -1 */
    52569932, /*  3212 (  87) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
     1551596, /*  3213 (  87) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
        3198, /*  3214 (  87) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    51021534, /*  3215 (  87) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  0] -1 */
    52556970, /*  3216 (  87) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
     1538634, /*  3217 (  87) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
       16484, /*  3218 (  88) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34146644, /*  3219 (  88) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
     1551596, /*  3220 (  88) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
        3198, /*  3221 (  88) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    35445884, /*  3222 (  88) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  0] -1 */
    34133682, /*  3223 (  88) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
    35432598, /*  3224 (  88) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  0] -1 */
     1538634, /*  3225 (  88) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
       16484, /*  3226 (  89) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
     1551596, /*  3227 (  89) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
    35432760, /*  3228 (  89) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  0] -1 */
    34133520, /*  3229 (  89) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
        3198, /*  3230 (  89) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    35445722, /*  3231 (  89) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  0] -1 */
    34146806, /*  3232 (  89) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
     1538634, /*  3233 (  89) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
       16484, /*  3234 (  90) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    35550696, /*  3235 (  90) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  6] -1 */
    34015584, /*  3236 (  90) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
     1551596, /*  3237 (  90) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
    35563982, /*  3238 (  90) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
        3198, /*  3239 (  90) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    34028546, /*  3240 (  90) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
     1538634, /*  3241 (  90) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
       16484, /*  3242 (  91) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    51139794, /*  3243 (  91) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6] -1 */
    52438710, /*  3244 (  91) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
    51152756, /*  3245 (  91) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
     1551596, /*  3246 (  91) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
    52451996, /*  3247 (  91) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
        3198, /*  3248 (  91) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
     1538634, /*  3249 (  91) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
       16484, /*  3250 (  82) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
        3198, /*  3251 (  82) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    18557708, /*  3252 (  82) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    18544746, /*  3253 (  82) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
       16484, /*  3254 (  83) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34015422, /*  3255 (  83) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    18557708, /*  3256 (  83) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
        3198, /*  3257 (  83) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    52556970, /*  3258 (  83) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    34028708, /*  3259 (  83) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    52569932, /*  3260 (  83) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    18544746, /*  3261 (  83) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
       16484, /*  3262 (  84) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    52556970, /*  3263 (  84) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    34015422, /*  3264 (  84) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    18557708, /*  3265 (  84) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
       16484, /*  3266 (  85) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34015422, /*  3267 (  85) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    52569932, /*  3268 (  85) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    18544746, /*  3269 (  85) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
       16484, /*  3270 (  86) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    52556970, /*  3271 (  86) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
        3198, /*  3272 (  86) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    52569932, /*  3273 (  86) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
       16484, /*  3274 (  87) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34146806, /*  3275 (  87) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    52451834, /*  3276 (  87) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
    18557708, /*  3277 (  87) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
        3198, /*  3278 (  87) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    34133520, /*  3279 (  87) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
    52438872, /*  3280 (  87) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
    18544746, /*  3281 (  87) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
       16484, /*  3282 (  88) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    51152756, /*  3283 (  88) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
    18557708, /*  3284 (  88) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
        3198, /*  3285 (  88) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    35445884, /*  3286 (  88) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  0] -1 */
    51139794, /*  3287 (  88) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6] -1 */
    35432598, /*  3288 (  88) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  0] -1 */
    18544746, /*  3289 (  88) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
       16484, /*  3290 (  89) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    18557708, /*  3291 (  89) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    35432760, /*  3292 (  89) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  0] -1 */
    51139632, /*  3293 (  89) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  6] -1 */
        3198, /*  3294 (  89) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    35445722, /*  3295 (  89) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  0] -1 */
    51152918, /*  3296 (  89) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
    18544746, /*  3297 (  89) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
       16484, /*  3298 (  90) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    52556808, /*  3299 (  90) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    34015584, /*  3300 (  90) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    18557708, /*  3301 (  90) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    52570094, /*  3302 (  90) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
        3198, /*  3303 (  90) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    34028546, /*  3304 (  90) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    18544746, /*  3305 (  90) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
       16484, /*  3306 (  91) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    51021696, /*  3307 (  91) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  0] -1 */
    35550696, /*  3308 (  91) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  6] -1 */
    51034658, /*  3309 (  91) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  0] -1 */
    18557708, /*  3310 (  91) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    35563982, /*  3311 (  91) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
        3198, /*  3312 (  91) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    18544746, /*  3313 (  91) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
       16484, /*  3314 (  82) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
        3198, /*  3315 (  82) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    18439610, /*  3316 (  82) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    18426648, /*  3317 (  82) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
       16484, /*  3318 (  83) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34015422, /*  3319 (  83) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    18439610, /*  3320 (  83) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
        3198, /*  3321 (  83) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    52438872, /*  3322 (  83) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
    34028708, /*  3323 (  83) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    52451834, /*  3324 (  83) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
    18426648, /*  3325 (  83) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
       16484, /*  3326 (  84) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    52438872, /*  3327 (  84) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
    34015422, /*  3328 (  84) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    18439610, /*  3329 (  84) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
       16484, /*  3330 (  85) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34015422, /*  3331 (  85) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    52451834, /*  3332 (  85) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
    18426648, /*  3333 (  85) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
       16484, /*  3334 (  86) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    52438872, /*  3335 (  86) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
        3198, /*  3336 (  86) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    52451834, /*  3337 (  86) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
       16484, /*  3338 (  87) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    51152918, /*  3339 (  87) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
    35563820, /*  3340 (  87) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
    18439610, /*  3341 (  87) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
        3198, /*  3342 (  87) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    51139632, /*  3343 (  87) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  6] -1 */
    35550858, /*  3344 (  87) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6] -1 */
    18426648, /*  3345 (  87) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
       16484, /*  3346 (  88) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    51034658, /*  3347 (  88) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  0] -1 */
    18439610, /*  3348 (  88) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
        3198, /*  3349 (  88) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    35445884, /*  3350 (  88) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  0] -1 */
    51021696, /*  3351 (  88) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  0] -1 */
    35432598, /*  3352 (  88) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  0] -1 */
    18426648, /*  3353 (  88) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
       16484, /*  3354 (  89) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    18439610, /*  3355 (  89) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    35432760, /*  3356 (  89) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  0] -1 */
    51021534, /*  3357 (  89) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  0] -1 */
        3198, /*  3358 (  89) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    35445722, /*  3359 (  89) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  0] -1 */
    51034820, /*  3360 (  89) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  0] -1 */
    18426648, /*  3361 (  89) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
       16484, /*  3362 (  90) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    52438710, /*  3363 (  90) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
    34015584, /*  3364 (  90) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    18439610, /*  3365 (  90) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    52451996, /*  3366 (  90) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
        3198, /*  3367 (  90) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    34028546, /*  3368 (  90) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    18426648, /*  3369 (  90) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
       16484, /*  3370 (  91) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34133682, /*  3371 (  91) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
    52556808, /*  3372 (  91) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    34146644, /*  3373 (  91) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    18439610, /*  3374 (  91) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    52570094, /*  3375 (  91) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
        3198, /*  3376 (  91) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    18426648, /*  3377 (  91) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
       16484, /*  3378 (  82) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
        3198, /*  3379 (  82) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    17140692, /*  3380 (  82) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6]  1 */
    17127410, /*  3381 (  82) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
       16484, /*  3382 (  83) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34015422, /*  3383 (  83) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    17140692, /*  3384 (  83) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6]  1 */
        3198, /*  3385 (  83) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    51139634, /*  3386 (  83) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
    34028708, /*  3387 (  83) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    51152916, /*  3388 (  83) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6] -1 */
    17127410, /*  3389 (  83) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
       16484, /*  3390 (  84) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    51139634, /*  3391 (  84) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
    34015422, /*  3392 (  84) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    17140692, /*  3393 (  84) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6]  1 */
       16484, /*  3394 (  85) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34015422, /*  3395 (  85) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    51152916, /*  3396 (  85) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6] -1 */
    17127410, /*  3397 (  85) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
       16484, /*  3398 (  86) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    51139634, /*  3399 (  86) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
        3198, /*  3400 (  86) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    51152916, /*  3401 (  86) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6] -1 */
       16484, /*  3402 (  87) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    35445884, /*  3403 (  87) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  0] -1 */
    52570092, /*  3404 (  87) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    17140692, /*  3405 (  87) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6]  1 */
        3198, /*  3406 (  87) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    35432598, /*  3407 (  87) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  0] -1 */
    52556810, /*  3408 (  87) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    17127410, /*  3409 (  87) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
       16484, /*  3410 (  88) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    51034818, /*  3411 (  88) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  0] -1 */
    17140692, /*  3412 (  88) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6]  1 */
        3198, /*  3413 (  88) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    34146806, /*  3414 (  88) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    51021536, /*  3415 (  88) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  0] -1 */
    34133520, /*  3416 (  88) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
    17127410, /*  3417 (  88) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
       16484, /*  3418 (  89) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    17140692, /*  3419 (  89) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6]  1 */
    34133522, /*  3420 (  89) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    51021534, /*  3421 (  89) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  0] -1 */
        3198, /*  3422 (  89) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    34146804, /*  3423 (  89) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
    51034820, /*  3424 (  89) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  0] -1 */
    17127410, /*  3425 (  89) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
       16484, /*  3426 (  90) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    51139632, /*  3427 (  90) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  6] -1 */
    34015424, /*  3428 (  90) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    17140692, /*  3429 (  90) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6]  1 */
    51152918, /*  3430 (  90) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
        3198, /*  3431 (  90) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    34028706, /*  3432 (  90) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    17127410, /*  3433 (  90) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
       16484, /*  3434 (  91) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    52438712, /*  3435 (  91) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
    35550696, /*  3436 (  91) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  6] -1 */
    52451994, /*  3437 (  91) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
    17140692, /*  3438 (  91) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6]  1 */
    35563982, /*  3439 (  91) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
        3198, /*  3440 (  91) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    17127410, /*  3441 (  91) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
       16484, /*  3442 (  82) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
        3198, /*  3443 (  82) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    18557868, /*  3444 (  82) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
    18544586, /*  3445 (  82) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
       16484, /*  3446 (  83) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34015422, /*  3447 (  83) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    18557868, /*  3448 (  83) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
        3198, /*  3449 (  83) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    52556810, /*  3450 (  83) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    34028708, /*  3451 (  83) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    52570092, /*  3452 (  83) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    18544586, /*  3453 (  83) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
       16484, /*  3454 (  84) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    52556810, /*  3455 (  84) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    34015422, /*  3456 (  84) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    18557868, /*  3457 (  84) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
       16484, /*  3458 (  85) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34015422, /*  3459 (  85) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    52570092, /*  3460 (  85) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    18544586, /*  3461 (  85) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
       16484, /*  3462 (  86) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    52556810, /*  3463 (  86) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
        3198, /*  3464 (  86) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    52570092, /*  3465 (  86) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
       16484, /*  3466 (  87) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    51034820, /*  3467 (  87) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  0] -1 */
    35563980, /*  3468 (  87) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6] -1 */
    18557868, /*  3469 (  87) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
        3198, /*  3470 (  87) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    51021534, /*  3471 (  87) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  0] -1 */
    35550698, /*  3472 (  87) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
    18544586, /*  3473 (  87) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
       16484, /*  3474 (  88) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    52451994, /*  3475 (  88) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
    18557868, /*  3476 (  88) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
        3198, /*  3477 (  88) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    34146806, /*  3478 (  88) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    52438712, /*  3479 (  88) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
    34133520, /*  3480 (  88) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
    18544586, /*  3481 (  88) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
       16484, /*  3482 (  89) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    18557868, /*  3483 (  89) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
    34133522, /*  3484 (  89) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    52438710, /*  3485 (  89) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
        3198, /*  3486 (  89) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    34146804, /*  3487 (  89) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
    52451996, /*  3488 (  89) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
    18544586, /*  3489 (  89) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
       16484, /*  3490 (  90) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    52556808, /*  3491 (  90) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    34015424, /*  3492 (  90) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    18557868, /*  3493 (  90) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
    52570094, /*  3494 (  90) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
        3198, /*  3495 (  90) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    34028706, /*  3496 (  90) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    18544586, /*  3497 (  90) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
       16484, /*  3498 (  91) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    35432600, /*  3499 (  91) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  0] -1 */
    51139632, /*  3500 (  91) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  6] -1 */
    35445882, /*  3501 (  91) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  0] -1 */
    18557868, /*  3502 (  91) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
    51152918, /*  3503 (  91) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
        3198, /*  3504 (  91) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    18544586, /*  3505 (  91) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
       16484, /*  3506 (  82) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
        3198, /*  3507 (  82) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
     1551756, /*  3508 (  82) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
     1538474, /*  3509 (  82) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
       16484, /*  3510 (  83) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34015422, /*  3511 (  83) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
     1551756, /*  3512 (  83) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
        3198, /*  3513 (  83) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    35550698, /*  3514 (  83) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
    34028708, /*  3515 (  83) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    35563980, /*  3516 (  83) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6] -1 */
     1538474, /*  3517 (  83) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
       16484, /*  3518 (  84) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    35550698, /*  3519 (  84) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
    34015422, /*  3520 (  84) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
     1551756, /*  3521 (  84) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
       16484, /*  3522 (  85) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34015422, /*  3523 (  85) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    35563980, /*  3524 (  85) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6] -1 */
     1538474, /*  3525 (  85) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
       16484, /*  3526 (  86) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    35550698, /*  3527 (  86) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
        3198, /*  3528 (  86) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    35563980, /*  3529 (  86) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6] -1 */
       16484, /*  3530 (  87) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    52451996, /*  3531 (  87) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
    51152916, /*  3532 (  87) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6] -1 */
     1551756, /*  3533 (  87) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
        3198, /*  3534 (  87) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    52438710, /*  3535 (  87) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
    51139634, /*  3536 (  87) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
     1538474, /*  3537 (  87) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
       16484, /*  3538 (  88) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    35445882, /*  3539 (  88) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  0] -1 */
     1551756, /*  3540 (  88) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
        3198, /*  3541 (  88) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    34146806, /*  3542 (  88) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    35432600, /*  3543 (  88) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  0] -1 */
    34133520, /*  3544 (  88) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
     1538474, /*  3545 (  88) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
       16484, /*  3546 (  89) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
     1551756, /*  3547 (  89) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
    34133522, /*  3548 (  89) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    35432598, /*  3549 (  89) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  0] -1 */
        3198, /*  3550 (  89) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    34146804, /*  3551 (  89) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
    35445884, /*  3552 (  89) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  0] -1 */
     1538474, /*  3553 (  89) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
       16484, /*  3554 (  90) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    35550696, /*  3555 (  90) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  6] -1 */
    34015424, /*  3556 (  90) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
     1551756, /*  3557 (  90) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
    35563982, /*  3558 (  90) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
        3198, /*  3559 (  90) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    34028706, /*  3560 (  90) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
     1538474, /*  3561 (  90) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
       16484, /*  3562 (  91) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    51021536, /*  3563 (  91) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  0] -1 */
    52556808, /*  3564 (  91) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    51034818, /*  3565 (  91) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  0] -1 */
     1551756, /*  3566 (  91) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
    52570094, /*  3567 (  91) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
        3198, /*  3568 (  91) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
     1538474, /*  3569 (  91) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
       16484, /*  3570 (  82) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
        3198, /*  3571 (  82) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    18426650, /*  3572 (  82) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    18439608, /*  3573 (  82) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
       16484, /*  3574 (  83) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34015422, /*  3575 (  83) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    18426650, /*  3576 (  83) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
        3198, /*  3577 (  83) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    52451832, /*  3578 (  83) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
    34028708, /*  3579 (  83) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    52438874, /*  3580 (  83) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
    18439608, /*  3581 (  83) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
       16484, /*  3582 (  84) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    52451832, /*  3583 (  84) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
    34015422, /*  3584 (  84) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    18426650, /*  3585 (  84) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
       16484, /*  3586 (  85) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34015422, /*  3587 (  85) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    52438874, /*  3588 (  85) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
    18439608, /*  3589 (  85) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
       16484, /*  3590 (  86) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    52451832, /*  3591 (  86) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
        3198, /*  3592 (  86) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    52438874, /*  3593 (  86) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
       16484, /*  3594 (  87) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34146806, /*  3595 (  87) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    52556972, /*  3596 (  87) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    18426650, /*  3597 (  87) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
        3198, /*  3598 (  87) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    34133520, /*  3599 (  87) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
    52569930, /*  3600 (  87) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    18439608, /*  3601 (  87) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
       16484, /*  3602 (  88) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    35432762, /*  3603 (  88) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  0] -1 */
    18426650, /*  3604 (  88) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
        3198, /*  3605 (  88) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    51034820, /*  3606 (  88) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  0] -1 */
    35445720, /*  3607 (  88) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  0] -1 */
    51021534, /*  3608 (  88) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  0] -1 */
    18439608, /*  3609 (  88) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
       16484, /*  3610 (  89) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    18426650, /*  3611 (  89) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    51034656, /*  3612 (  89) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  0] -1 */
    35432598, /*  3613 (  89) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  0] -1 */
        3198, /*  3614 (  89) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    51021698, /*  3615 (  89) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  0] -1 */
    35445884, /*  3616 (  89) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  0] -1 */
    18439608, /*  3617 (  89) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
       16484, /*  3618 (  90) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    52438710, /*  3619 (  90) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
    34028544, /*  3620 (  90) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    18426650, /*  3621 (  90) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    52451996, /*  3622 (  90) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
        3198, /*  3623 (  90) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    34015586, /*  3624 (  90) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    18439608, /*  3625 (  90) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
       16484, /*  3626 (  91) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    35563818, /*  3627 (  91) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  6] -1 */
    51139632, /*  3628 (  91) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  6] -1 */
    35550860, /*  3629 (  91) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
    18426650, /*  3630 (  91) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    51152918, /*  3631 (  91) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
        3198, /*  3632 (  91) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    18439608, /*  3633 (  91) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
       16484, /*  3634 (  82) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
        3198, /*  3635 (  82) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    18544748, /*  3636 (  82) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    18557706, /*  3637 (  82) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
       16484, /*  3638 (  83) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34015422, /*  3639 (  83) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    18544748, /*  3640 (  83) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
        3198, /*  3641 (  83) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    52569930, /*  3642 (  83) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    34028708, /*  3643 (  83) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    52556972, /*  3644 (  83) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    18557706, /*  3645 (  83) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
       16484, /*  3646 (  84) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    52569930, /*  3647 (  84) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    34015422, /*  3648 (  84) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    18544748, /*  3649 (  84) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
       16484, /*  3650 (  85) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34015422, /*  3651 (  85) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    52556972, /*  3652 (  85) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    18557706, /*  3653 (  85) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
       16484, /*  3654 (  86) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    52569930, /*  3655 (  86) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
        3198, /*  3656 (  86) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    52556972, /*  3657 (  86) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
       16484, /*  3658 (  87) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    35445884, /*  3659 (  87) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  0] -1 */
    51139796, /*  3660 (  87) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
    18544748, /*  3661 (  87) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
        3198, /*  3662 (  87) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    35432598, /*  3663 (  87) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  0] -1 */
    51152754, /*  3664 (  87) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  6] -1 */
    18557706, /*  3665 (  87) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
       16484, /*  3666 (  88) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    35550860, /*  3667 (  88) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
    18544748, /*  3668 (  88) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
        3198, /*  3669 (  88) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    51034820, /*  3670 (  88) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  0] -1 */
    35563818, /*  3671 (  88) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  6] -1 */
    51021534, /*  3672 (  88) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  0] -1 */
    18557706, /*  3673 (  88) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
       16484, /*  3674 (  89) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    18544748, /*  3675 (  89) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    51034656, /*  3676 (  89) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  0] -1 */
    35550696, /*  3677 (  89) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  6] -1 */
        3198, /*  3678 (  89) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    51021698, /*  3679 (  89) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  0] -1 */
    35563982, /*  3680 (  89) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
    18557706, /*  3681 (  89) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
       16484, /*  3682 (  90) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    52556808, /*  3683 (  90) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    34028544, /*  3684 (  90) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    18544748, /*  3685 (  90) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    52570094, /*  3686 (  90) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
        3198, /*  3687 (  90) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    34015586, /*  3688 (  90) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    18557706, /*  3689 (  90) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
       16484, /*  3690 (  91) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34146642, /*  3691 (  91) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
    52438710, /*  3692 (  91) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
    34133684, /*  3693 (  91) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    18544748, /*  3694 (  91) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    52451996, /*  3695 (  91) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
        3198, /*  3696 (  91) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    18557706, /*  3697 (  91) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
       16484, /*  3698 (  82) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
        3198, /*  3699 (  82) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    17127572, /*  3700 (  82) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
    17140530, /*  3701 (  82) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  6]  1 */
       16484, /*  3702 (  83) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34015422, /*  3703 (  83) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    17127572, /*  3704 (  83) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
        3198, /*  3705 (  83) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    51152754, /*  3706 (  83) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  6] -1 */
    34028708, /*  3707 (  83) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    51139796, /*  3708 (  83) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
    17140530, /*  3709 (  83) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  6]  1 */
       16484, /*  3710 (  84) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    51152754, /*  3711 (  84) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  6] -1 */
    34015422, /*  3712 (  84) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    17127572, /*  3713 (  84) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
       16484, /*  3714 (  85) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34015422, /*  3715 (  85) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    51139796, /*  3716 (  85) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
    17140530, /*  3717 (  85) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  6]  1 */
       16484, /*  3718 (  86) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    51152754, /*  3719 (  86) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  6] -1 */
        3198, /*  3720 (  86) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    51139796, /*  3721 (  86) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
       16484, /*  3722 (  87) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    35563982, /*  3723 (  87) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
    52438874, /*  3724 (  87) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
    17127572, /*  3725 (  87) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
        3198, /*  3726 (  87) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    35550696, /*  3727 (  87) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  6] -1 */
    52451832, /*  3728 (  87) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
    17140530, /*  3729 (  87) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  6]  1 */
       16484, /*  3730 (  88) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34133684, /*  3731 (  88) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    17127572, /*  3732 (  88) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
        3198, /*  3733 (  88) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    51034820, /*  3734 (  88) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  0] -1 */
    34146642, /*  3735 (  88) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
    51021534, /*  3736 (  88) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  0] -1 */
    17140530, /*  3737 (  88) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  6]  1 */
       16484, /*  3738 (  89) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    17127572, /*  3739 (  89) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
    51034656, /*  3740 (  89) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  0] -1 */
    34133520, /*  3741 (  89) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
        3198, /*  3742 (  89) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    51021698, /*  3743 (  89) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  0] -1 */
    34146806, /*  3744 (  89) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    17140530, /*  3745 (  89) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  6]  1 */
       16484, /*  3746 (  90) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    51139632, /*  3747 (  90) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  6] -1 */
    34028544, /*  3748 (  90) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    17127572, /*  3749 (  90) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
    51152918, /*  3750 (  90) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
        3198, /*  3751 (  90) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    34015586, /*  3752 (  90) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    17140530, /*  3753 (  90) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  6]  1 */
       16484, /*  3754 (  91) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    35445720, /*  3755 (  91) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  0] -1 */
    52556808, /*  3756 (  91) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    35432762, /*  3757 (  91) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  0] -1 */
    17127572, /*  3758 (  91) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
    52570094, /*  3759 (  91) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
        3198, /*  3760 (  91) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    17140530, /*  3761 (  91) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  6]  1 */
       16484, /*  3762 (  92) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
      121458, /*  3763 (  92) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  6]  1 */
    18426486, /*  3764 (  92) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
      134420, /*  3765 (  92) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6]  1 */
        3198, /*  3766 (  92) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    18439772, /*  3767 (  92) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    18557708, /*  3768 (  92) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    18544746, /*  3769 (  92) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
       16484, /*  3770 (  93) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
      121458, /*  3771 (  93) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  6]  1 */
    34015422, /*  3772 (  93) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    52438710, /*  3773 (  93) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
    34146644, /*  3774 (  93) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    52569932, /*  3775 (  93) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    18426486, /*  3776 (  93) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
      134420, /*  3777 (  93) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6]  1 */
    52451996, /*  3778 (  93) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
        3198, /*  3779 (  93) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    52556970, /*  3780 (  93) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    34133682, /*  3781 (  93) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
    18439772, /*  3782 (  93) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    18557708, /*  3783 (  93) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    34028708, /*  3784 (  93) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    18544746, /*  3785 (  93) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
       16484, /*  3786 (  94) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34015422, /*  3787 (  94) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    52438710, /*  3788 (  94) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
      134420, /*  3789 (  94) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6]  1 */
    52556970, /*  3790 (  94) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    34133682, /*  3791 (  94) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
    18439772, /*  3792 (  94) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    18557708, /*  3793 (  94) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
       16484, /*  3794 (  95) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34015422, /*  3795 (  95) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
      121458, /*  3796 (  95) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  6]  1 */
    52438710, /*  3797 (  95) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
    34146644, /*  3798 (  95) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    52569932, /*  3799 (  95) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    18439772, /*  3800 (  95) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    18544746, /*  3801 (  95) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
       16484, /*  3802 (  96) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34146644, /*  3803 (  96) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    52569932, /*  3804 (  96) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    18426486, /*  3805 (  96) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
        3198, /*  3806 (  96) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    52556970, /*  3807 (  96) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    34133682, /*  3808 (  96) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
    18439772, /*  3809 (  96) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
       16484, /*  3810 (  97) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    52451834, /*  3811 (  97) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
    34028546, /*  3812 (  97) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
      121458, /*  3813 (  97) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  6]  1 */
    34015584, /*  3814 (  97) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    18426486, /*  3815 (  97) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
      134420, /*  3816 (  97) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6]  1 */
    34133520, /*  3817 (  97) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
        3198, /*  3818 (  97) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    34146806, /*  3819 (  97) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    18439772, /*  3820 (  97) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    18557708, /*  3821 (  97) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    52438872, /*  3822 (  97) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
    18544746, /*  3823 (  97) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
    52570094, /*  3824 (  97) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    52556808, /*  3825 (  97) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
       16484, /*  3826 (  98) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    51139794, /*  3827 (  98) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6] -1 */
      121458, /*  3828 (  98) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  6]  1 */
    35550858, /*  3829 (  98) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6] -1 */
    51034820, /*  3830 (  98) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  0] -1 */
    51152756, /*  3831 (  98) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
    18426486, /*  3832 (  98) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
      134420, /*  3833 (  98) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6]  1 */
        3198, /*  3834 (  98) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    51021534, /*  3835 (  98) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  0] -1 */
    35445884, /*  3836 (  98) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  0] -1 */
    35432598, /*  3837 (  98) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  0] -1 */
    18439772, /*  3838 (  98) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    18557708, /*  3839 (  98) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    18544746, /*  3840 (  98) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
    35563820, /*  3841 (  98) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
       16484, /*  3842 (  92) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    17127570, /*  3843 (  92) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6]  1 */
     1538472, /*  3844 (  92) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
    17140532, /*  3845 (  92) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
        3198, /*  3846 (  92) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
     1551758, /*  3847 (  92) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
    18439610, /*  3848 (  92) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    18426648, /*  3849 (  92) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
       16484, /*  3850 (  93) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    17127570, /*  3851 (  93) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6]  1 */
    34015422, /*  3852 (  93) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    35550696, /*  3853 (  93) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  6] -1 */
    51152756, /*  3854 (  93) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
    52451834, /*  3855 (  93) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
     1538472, /*  3856 (  93) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
    17140532, /*  3857 (  93) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
    35563982, /*  3858 (  93) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
        3198, /*  3859 (  93) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    52438872, /*  3860 (  93) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
    51139794, /*  3861 (  93) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6] -1 */
     1551758, /*  3862 (  93) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
    18439610, /*  3863 (  93) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    34028708, /*  3864 (  93) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    18426648, /*  3865 (  93) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
       16484, /*  3866 (  94) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34015422, /*  3867 (  94) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    35550696, /*  3868 (  94) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  6] -1 */
    17140532, /*  3869 (  94) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
    52438872, /*  3870 (  94) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
    51139794, /*  3871 (  94) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6] -1 */
     1551758, /*  3872 (  94) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
    18439610, /*  3873 (  94) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
       16484, /*  3874 (  95) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34015422, /*  3875 (  95) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    17127570, /*  3876 (  95) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6]  1 */
    35550696, /*  3877 (  95) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  6] -1 */
    51152756, /*  3878 (  95) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
    52451834, /*  3879 (  95) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
     1551758, /*  3880 (  95) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
    18426648, /*  3881 (  95) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
       16484, /*  3882 (  96) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    51152756, /*  3883 (  96) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
    52451834, /*  3884 (  96) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
     1538472, /*  3885 (  96) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
        3198, /*  3886 (  96) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    52438872, /*  3887 (  96) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
    51139794, /*  3888 (  96) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6] -1 */
     1551758, /*  3889 (  96) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
       16484, /*  3890 (  97) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    35563820, /*  3891 (  97) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
    34028546, /*  3892 (  97) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    17127570, /*  3893 (  97) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6]  1 */
    34015584, /*  3894 (  97) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
     1538472, /*  3895 (  97) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
    17140532, /*  3896 (  97) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
    51139632, /*  3897 (  97) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  6] -1 */
        3198, /*  3898 (  97) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    51152918, /*  3899 (  97) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
     1551758, /*  3900 (  97) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
    18439610, /*  3901 (  97) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    35550858, /*  3902 (  97) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6] -1 */
    18426648, /*  3903 (  97) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
    52451996, /*  3904 (  97) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
    52438710, /*  3905 (  97) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
       16484, /*  3906 (  98) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    51021696, /*  3907 (  98) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  0] -1 */
    17127570, /*  3908 (  98) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6]  1 */
    52556970, /*  3909 (  98) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    34146806, /*  3910 (  98) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    51034658, /*  3911 (  98) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  0] -1 */
     1538472, /*  3912 (  98) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
    17140532, /*  3913 (  98) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
        3198, /*  3914 (  98) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    34133520, /*  3915 (  98) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
    35445884, /*  3916 (  98) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  0] -1 */
    35432598, /*  3917 (  98) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  0] -1 */
     1551758, /*  3918 (  98) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
    18439610, /*  3919 (  98) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    18426648, /*  3920 (  98) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
    52569932, /*  3921 (  98) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
       16484, /*  3922 (  92) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    17009472, /*  3923 (  92) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  0]  1 */
    18544584, /*  3924 (  92) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
    17022434, /*  3925 (  92) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  0]  1 */
        3198, /*  3926 (  92) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    18557870, /*  3927 (  92) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
     1551596, /*  3928 (  92) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
     1538634, /*  3929 (  92) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
       16484, /*  3930 (  93) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    17009472, /*  3931 (  93) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  0]  1 */
    34015422, /*  3932 (  93) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    52556808, /*  3933 (  93) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    51034658, /*  3934 (  93) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  0] -1 */
    35563820, /*  3935 (  93) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
    18544584, /*  3936 (  93) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
    17022434, /*  3937 (  93) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  0]  1 */
    52570094, /*  3938 (  93) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
        3198, /*  3939 (  93) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    35550858, /*  3940 (  93) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6] -1 */
    51021696, /*  3941 (  93) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  0] -1 */
    18557870, /*  3942 (  93) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
     1551596, /*  3943 (  93) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
    34028708, /*  3944 (  93) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
     1538634, /*  3945 (  93) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
       16484, /*  3946 (  94) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34015422, /*  3947 (  94) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    52556808, /*  3948 (  94) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    17022434, /*  3949 (  94) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  0]  1 */
    35550858, /*  3950 (  94) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6] -1 */
    51021696, /*  3951 (  94) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  0] -1 */
    18557870, /*  3952 (  94) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
     1551596, /*  3953 (  94) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
       16484, /*  3954 (  95) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34015422, /*  3955 (  95) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    17009472, /*  3956 (  95) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  0]  1 */
    52556808, /*  3957 (  95) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    51034658, /*  3958 (  95) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  0] -1 */
    35563820, /*  3959 (  95) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
    18557870, /*  3960 (  95) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
     1538634, /*  3961 (  95) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
       16484, /*  3962 (  96) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    51034658, /*  3963 (  96) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  0] -1 */
    35563820, /*  3964 (  96) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
    18544584, /*  3965 (  96) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
        3198, /*  3966 (  96) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    35550858, /*  3967 (  96) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6] -1 */
    51021696, /*  3968 (  96) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  0] -1 */
    18557870, /*  3969 (  96) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
       16484, /*  3970 (  97) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    52569932, /*  3971 (  97) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    34028546, /*  3972 (  97) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    17009472, /*  3973 (  97) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  0]  1 */
    34015584, /*  3974 (  97) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    18544584, /*  3975 (  97) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
    17022434, /*  3976 (  97) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  0]  1 */
    51021534, /*  3977 (  97) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  0] -1 */
        3198, /*  3978 (  97) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    51034820, /*  3979 (  97) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  0] -1 */
    18557870, /*  3980 (  97) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
     1551596, /*  3981 (  97) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
    52556970, /*  3982 (  97) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
     1538634, /*  3983 (  97) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
    35563982, /*  3984 (  97) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
    35550696, /*  3985 (  97) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  6] -1 */
       16484, /*  3986 (  98) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34133682, /*  3987 (  98) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
    17009472, /*  3988 (  98) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  0]  1 */
    52438872, /*  3989 (  98) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
    51152918, /*  3990 (  98) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
    34146644, /*  3991 (  98) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    18544584, /*  3992 (  98) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
    17022434, /*  3993 (  98) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  0]  1 */
        3198, /*  3994 (  98) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    51139632, /*  3995 (  98) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  6] -1 */
    35445884, /*  3996 (  98) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  0] -1 */
    35432598, /*  3997 (  98) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  0] -1 */
    18557870, /*  3998 (  98) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
     1551596, /*  3999 (  98) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
     1538634, /*  4000 (  98) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
    52451834, /*  4001 (  98) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
       16484, /*  4002 (  92) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    17009472, /*  4003 (  92) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  0]  1 */
     1538472, /*  4004 (  92) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
    17022434, /*  4005 (  92) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  0]  1 */
        3198, /*  4006 (  92) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
     1551758, /*  4007 (  92) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
    18557708, /*  4008 (  92) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    18544746, /*  4009 (  92) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
       16484, /*  4010 (  93) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    17009472, /*  4011 (  93) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  0]  1 */
    34015422, /*  4012 (  93) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    35550696, /*  4013 (  93) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  6] -1 */
    51034658, /*  4014 (  93) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  0] -1 */
    52569932, /*  4015 (  93) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
     1538472, /*  4016 (  93) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
    17022434, /*  4017 (  93) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  0]  1 */
    35563982, /*  4018 (  93) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
        3198, /*  4019 (  93) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    52556970, /*  4020 (  93) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    51021696, /*  4021 (  93) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  0] -1 */
     1551758, /*  4022 (  93) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
    18557708, /*  4023 (  93) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    34028708, /*  4024 (  93) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    18544746, /*  4025 (  93) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
       16484, /*  4026 (  94) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34015422, /*  4027 (  94) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    35550696, /*  4028 (  94) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  6] -1 */
    17022434, /*  4029 (  94) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  0]  1 */
    52556970, /*  4030 (  94) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    51021696, /*  4031 (  94) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  0] -1 */
     1551758, /*  4032 (  94) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
    18557708, /*  4033 (  94) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
       16484, /*  4034 (  95) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34015422, /*  4035 (  95) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    17009472, /*  4036 (  95) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  0]  1 */
    35550696, /*  4037 (  95) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  6] -1 */
    51034658, /*  4038 (  95) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  0] -1 */
    52569932, /*  4039 (  95) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
     1551758, /*  4040 (  95) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
    18544746, /*  4041 (  95) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
       16484, /*  4042 (  96) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    51034658, /*  4043 (  96) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  0] -1 */
    52569932, /*  4044 (  96) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
     1538472, /*  4045 (  96) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
        3198, /*  4046 (  96) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    52556970, /*  4047 (  96) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    51021696, /*  4048 (  96) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  0] -1 */
     1551758, /*  4049 (  96) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
       16484, /*  4050 (  97) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    35563820, /*  4051 (  97) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
    34028546, /*  4052 (  97) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    17009472, /*  4053 (  97) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  0]  1 */
    34015584, /*  4054 (  97) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
     1538472, /*  4055 (  97) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
    17022434, /*  4056 (  97) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  0]  1 */
    51021534, /*  4057 (  97) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  0] -1 */
        3198, /*  4058 (  97) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    51034820, /*  4059 (  97) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  0] -1 */
     1551758, /*  4060 (  97) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
    18557708, /*  4061 (  97) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    35550858, /*  4062 (  97) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6] -1 */
    18544746, /*  4063 (  97) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
    52570094, /*  4064 (  97) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    52556808, /*  4065 (  97) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
       16484, /*  4066 (  98) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    51139794, /*  4067 (  98) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6] -1 */
    17009472, /*  4068 (  98) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  0]  1 */
    52438872, /*  4069 (  98) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
    34146806, /*  4070 (  98) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    51152756, /*  4071 (  98) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
     1538472, /*  4072 (  98) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
    17022434, /*  4073 (  98) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  0]  1 */
        3198, /*  4074 (  98) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    34133520, /*  4075 (  98) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
    35445884, /*  4076 (  98) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  0] -1 */
    35432598, /*  4077 (  98) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  0] -1 */
     1551758, /*  4078 (  98) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
    18557708, /*  4079 (  98) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    18544746, /*  4080 (  98) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
    52451834, /*  4081 (  98) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
       16484, /*  4082 (  92) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    17127570, /*  4083 (  92) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6]  1 */
    18426486, /*  4084 (  92) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
    17140532, /*  4085 (  92) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
        3198, /*  4086 (  92) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    18439772, /*  4087 (  92) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
     1551596, /*  4088 (  92) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
     1538634, /*  4089 (  92) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
       16484, /*  4090 (  93) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    17127570, /*  4091 (  93) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6]  1 */
    34015422, /*  4092 (  93) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    52438710, /*  4093 (  93) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
    51152756, /*  4094 (  93) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
    35563820, /*  4095 (  93) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
    18426486, /*  4096 (  93) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
    17140532, /*  4097 (  93) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
    52451996, /*  4098 (  93) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
        3198, /*  4099 (  93) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    35550858, /*  4100 (  93) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6] -1 */
    51139794, /*  4101 (  93) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6] -1 */
    18439772, /*  4102 (  93) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
     1551596, /*  4103 (  93) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
    34028708, /*  4104 (  93) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
     1538634, /*  4105 (  93) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
       16484, /*  4106 (  94) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34015422, /*  4107 (  94) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    52438710, /*  4108 (  94) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
    17140532, /*  4109 (  94) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
    35550858, /*  4110 (  94) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6] -1 */
    51139794, /*  4111 (  94) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6] -1 */
    18439772, /*  4112 (  94) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
     1551596, /*  4113 (  94) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
       16484, /*  4114 (  95) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34015422, /*  4115 (  95) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    17127570, /*  4116 (  95) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6]  1 */
    52438710, /*  4117 (  95) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
    51152756, /*  4118 (  95) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
    35563820, /*  4119 (  95) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
    18439772, /*  4120 (  95) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
     1538634, /*  4121 (  95) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
       16484, /*  4122 (  96) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    51152756, /*  4123 (  96) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
    35563820, /*  4124 (  96) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
    18426486, /*  4125 (  96) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
        3198, /*  4126 (  96) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    35550858, /*  4127 (  96) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6] -1 */
    51139794, /*  4128 (  96) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6] -1 */
    18439772, /*  4129 (  96) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
       16484, /*  4130 (  97) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    52451834, /*  4131 (  97) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
    34028546, /*  4132 (  97) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    17127570, /*  4133 (  97) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6]  1 */
    34015584, /*  4134 (  97) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    18426486, /*  4135 (  97) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
    17140532, /*  4136 (  97) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
    51139632, /*  4137 (  97) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  6] -1 */
        3198, /*  4138 (  97) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    51152918, /*  4139 (  97) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
    18439772, /*  4140 (  97) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
     1551596, /*  4141 (  97) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
    52438872, /*  4142 (  97) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
     1538634, /*  4143 (  97) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
    35563982, /*  4144 (  97) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
    35550696, /*  4145 (  97) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  6] -1 */
       16484, /*  4146 (  98) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34133682, /*  4147 (  98) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
    17127570, /*  4148 (  98) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6]  1 */
    52556970, /*  4149 (  98) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    51034820, /*  4150 (  98) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  0] -1 */
    34146644, /*  4151 (  98) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    18426486, /*  4152 (  98) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
    17140532, /*  4153 (  98) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
        3198, /*  4154 (  98) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    51021534, /*  4155 (  98) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  0] -1 */
    35445884, /*  4156 (  98) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  0] -1 */
    35432598, /*  4157 (  98) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  0] -1 */
    18439772, /*  4158 (  98) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
     1551596, /*  4159 (  98) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
     1538634, /*  4160 (  98) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
    52569932, /*  4161 (  98) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
       16484, /*  4162 (  92) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
      121458, /*  4163 (  92) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  6]  1 */
    18544584, /*  4164 (  92) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
      134420, /*  4165 (  92) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6]  1 */
        3198, /*  4166 (  92) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    18557870, /*  4167 (  92) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    18439610, /*  4168 (  92) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    18426648, /*  4169 (  92) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
       16484, /*  4170 (  93) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
      121458, /*  4171 (  93) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  6]  1 */
    34015422, /*  4172 (  93) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    52556808, /*  4173 (  93) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    34146644, /*  4174 (  93) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    52451834, /*  4175 (  93) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
    18544584, /*  4176 (  93) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
      134420, /*  4177 (  93) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6]  1 */
    52570094, /*  4178 (  93) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
        3198, /*  4179 (  93) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    52438872, /*  4180 (  93) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
    34133682, /*  4181 (  93) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
    18557870, /*  4182 (  93) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    18439610, /*  4183 (  93) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    34028708, /*  4184 (  93) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    18426648, /*  4185 (  93) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
       16484, /*  4186 (  94) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34015422, /*  4187 (  94) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    52556808, /*  4188 (  94) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
      134420, /*  4189 (  94) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6]  1 */
    52438872, /*  4190 (  94) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
    34133682, /*  4191 (  94) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
    18557870, /*  4192 (  94) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    18439610, /*  4193 (  94) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
       16484, /*  4194 (  95) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34015422, /*  4195 (  95) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
      121458, /*  4196 (  95) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  6]  1 */
    52556808, /*  4197 (  95) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    34146644, /*  4198 (  95) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    52451834, /*  4199 (  95) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
    18557870, /*  4200 (  95) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    18426648, /*  4201 (  95) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
       16484, /*  4202 (  96) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34146644, /*  4203 (  96) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    52451834, /*  4204 (  96) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
    18544584, /*  4205 (  96) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
        3198, /*  4206 (  96) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    52438872, /*  4207 (  96) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
    34133682, /*  4208 (  96) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
    18557870, /*  4209 (  96) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
       16484, /*  4210 (  97) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    52569932, /*  4211 (  97) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    34028546, /*  4212 (  97) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
      121458, /*  4213 (  97) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  6]  1 */
    34015584, /*  4214 (  97) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    18544584, /*  4215 (  97) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
      134420, /*  4216 (  97) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6]  1 */
    34133520, /*  4217 (  97) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
        3198, /*  4218 (  97) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    34146806, /*  4219 (  97) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    18557870, /*  4220 (  97) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    18439610, /*  4221 (  97) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    52556970, /*  4222 (  97) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    18426648, /*  4223 (  97) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
    52451996, /*  4224 (  97) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
    52438710, /*  4225 (  97) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
       16484, /*  4226 (  98) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    51021696, /*  4227 (  98) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  0] -1 */
      121458, /*  4228 (  98) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  6]  1 */
    35550858, /*  4229 (  98) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6] -1 */
    51152918, /*  4230 (  98) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
    51034658, /*  4231 (  98) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  0] -1 */
    18544584, /*  4232 (  98) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
      134420, /*  4233 (  98) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6]  1 */
        3198, /*  4234 (  98) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    51139632, /*  4235 (  98) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  6] -1 */
    35445884, /*  4236 (  98) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  0] -1 */
    35432598, /*  4237 (  98) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  0] -1 */
    18557870, /*  4238 (  98) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    18439610, /*  4239 (  98) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    18426648, /*  4240 (  98) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
    35563820, /*  4241 (  98) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
       16484, /*  4242 (  92) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    17009312, /*  4243 (  92) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  0]  1 */
     1538472, /*  4244 (  92) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
    17022594, /*  4245 (  92) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  0]  1 */
        3198, /*  4246 (  92) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
     1551758, /*  4247 (  92) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
    18557868, /*  4248 (  92) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
    18544586, /*  4249 (  92) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
       16484, /*  4250 (  93) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    17009312, /*  4251 (  93) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  0]  1 */
    34015422, /*  4252 (  93) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    35550696, /*  4253 (  93) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  6] -1 */
    51034818, /*  4254 (  93) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  0] -1 */
    52570092, /*  4255 (  93) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
     1538472, /*  4256 (  93) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
    17022594, /*  4257 (  93) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  0]  1 */
    35563982, /*  4258 (  93) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
        3198, /*  4259 (  93) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    52556810, /*  4260 (  93) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    51021536, /*  4261 (  93) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  0] -1 */
     1551758, /*  4262 (  93) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
    18557868, /*  4263 (  93) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
    34028708, /*  4264 (  93) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    18544586, /*  4265 (  93) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
       16484, /*  4266 (  94) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34015422, /*  4267 (  94) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    35550696, /*  4268 (  94) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  6] -1 */
    17022594, /*  4269 (  94) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  0]  1 */
    52556810, /*  4270 (  94) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    51021536, /*  4271 (  94) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  0] -1 */
     1551758, /*  4272 (  94) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
    18557868, /*  4273 (  94) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
       16484, /*  4274 (  95) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34015422, /*  4275 (  95) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    17009312, /*  4276 (  95) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  0]  1 */
    35550696, /*  4277 (  95) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  6] -1 */
    51034818, /*  4278 (  95) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  0] -1 */
    52570092, /*  4279 (  95) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
     1551758, /*  4280 (  95) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
    18544586, /*  4281 (  95) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
       16484, /*  4282 (  96) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    51034818, /*  4283 (  96) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  0] -1 */
    52570092, /*  4284 (  96) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
     1538472, /*  4285 (  96) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
        3198, /*  4286 (  96) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    52556810, /*  4287 (  96) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    51021536, /*  4288 (  96) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  0] -1 */
     1551758, /*  4289 (  96) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
       16484, /*  4290 (  97) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    35563980, /*  4291 (  97) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6] -1 */
    34028706, /*  4292 (  97) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    17009312, /*  4293 (  97) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  0]  1 */
    34015424, /*  4294 (  97) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
     1538472, /*  4295 (  97) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
    17022594, /*  4296 (  97) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  0]  1 */
    51021534, /*  4297 (  97) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  0] -1 */
        3198, /*  4298 (  97) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    51034820, /*  4299 (  97) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  0] -1 */
     1551758, /*  4300 (  97) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
    18557868, /*  4301 (  97) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
    35550698, /*  4302 (  97) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
    18544586, /*  4303 (  97) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    52570094, /*  4304 (  97) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    52556808, /*  4305 (  97) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
       16484, /*  4306 (  98) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    52438712, /*  4307 (  98) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
    17009312, /*  4308 (  98) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  0]  1 */
    51139634, /*  4309 (  98) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
    35445884, /*  4310 (  98) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  0] -1 */
    52451994, /*  4311 (  98) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
     1538472, /*  4312 (  98) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
    17022594, /*  4313 (  98) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  0]  1 */
        3198, /*  4314 (  98) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    35432598, /*  4315 (  98) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  0] -1 */
    34146806, /*  4316 (  98) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    34133520, /*  4317 (  98) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
     1551758, /*  4318 (  98) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
    18557868, /*  4319 (  98) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
    18544586, /*  4320 (  98) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    51152916, /*  4321 (  98) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6] -1 */
       16484, /*  4322 (  92) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    18426488, /*  4323 (  92) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    17127408, /*  4324 (  92) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  6]  1 */
    18439770, /*  4325 (  92) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
        3198, /*  4326 (  92) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    17140694, /*  4327 (  92) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
     1551756, /*  4328 (  92) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
     1538474, /*  4329 (  92) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
       16484, /*  4330 (  93) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    18426488, /*  4331 (  93) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    34015422, /*  4332 (  93) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    51139632, /*  4333 (  93) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  6] -1 */
    52451994, /*  4334 (  93) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
    35563980, /*  4335 (  93) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6] -1 */
    17127408, /*  4336 (  93) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  6]  1 */
    18439770, /*  4337 (  93) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
    51152918, /*  4338 (  93) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
        3198, /*  4339 (  93) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    35550698, /*  4340 (  93) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
    52438712, /*  4341 (  93) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
    17140694, /*  4342 (  93) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
     1551756, /*  4343 (  93) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
    34028708, /*  4344 (  93) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
     1538474, /*  4345 (  93) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
       16484, /*  4346 (  94) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34015422, /*  4347 (  94) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    51139632, /*  4348 (  94) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  6] -1 */
    18439770, /*  4349 (  94) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
    35550698, /*  4350 (  94) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
    52438712, /*  4351 (  94) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
    17140694, /*  4352 (  94) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
     1551756, /*  4353 (  94) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
       16484, /*  4354 (  95) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34015422, /*  4355 (  95) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    18426488, /*  4356 (  95) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    51139632, /*  4357 (  95) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  6] -1 */
    52451994, /*  4358 (  95) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
    35563980, /*  4359 (  95) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6] -1 */
    17140694, /*  4360 (  95) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
     1538474, /*  4361 (  95) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
       16484, /*  4362 (  96) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    52451994, /*  4363 (  96) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
    35563980, /*  4364 (  96) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6] -1 */
    17127408, /*  4365 (  96) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  6]  1 */
        3198, /*  4366 (  96) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    35550698, /*  4367 (  96) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
    52438712, /*  4368 (  96) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
    17140694, /*  4369 (  96) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
       16484, /*  4370 (  97) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    51152916, /*  4371 (  97) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6] -1 */
    34028706, /*  4372 (  97) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    18426488, /*  4373 (  97) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    34015424, /*  4374 (  97) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    17127408, /*  4375 (  97) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  6]  1 */
    18439770, /*  4376 (  97) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
    52438710, /*  4377 (  97) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
        3198, /*  4378 (  97) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    52451996, /*  4379 (  97) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
    17140694, /*  4380 (  97) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
     1551756, /*  4381 (  97) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
    51139634, /*  4382 (  97) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
     1538474, /*  4383 (  97) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
    35563982, /*  4384 (  97) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
    35550696, /*  4385 (  97) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  6] -1 */
       16484, /*  4386 (  98) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    35432600, /*  4387 (  98) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  0] -1 */
    18426488, /*  4388 (  98) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    52556810, /*  4389 (  98) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    51034820, /*  4390 (  98) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  0] -1 */
    35445882, /*  4391 (  98) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  0] -1 */
    17127408, /*  4392 (  98) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  6]  1 */
    18439770, /*  4393 (  98) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
        3198, /*  4394 (  98) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    51021534, /*  4395 (  98) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  0] -1 */
    34146806, /*  4396 (  98) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    34133520, /*  4397 (  98) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
    17140694, /*  4398 (  98) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
     1551756, /*  4399 (  98) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
     1538474, /*  4400 (  98) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
    52570092, /*  4401 (  98) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
       16484, /*  4402 (  92) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
     1420376, /*  4403 (  92) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  0]  1 */
    18544584, /*  4404 (  92) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
     1433658, /*  4405 (  92) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  0]  1 */
        3198, /*  4406 (  92) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    18557870, /*  4407 (  92) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    17140692, /*  4408 (  92) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6]  1 */
    17127410, /*  4409 (  92) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
       16484, /*  4410 (  93) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
     1420376, /*  4411 (  93) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  0]  1 */
    34015422, /*  4412 (  93) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    52556808, /*  4413 (  93) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    35445882, /*  4414 (  93) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  0] -1 */
    51152916, /*  4415 (  93) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6] -1 */
    18544584, /*  4416 (  93) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
     1433658, /*  4417 (  93) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  0]  1 */
    52570094, /*  4418 (  93) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
        3198, /*  4419 (  93) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    51139634, /*  4420 (  93) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
    35432600, /*  4421 (  93) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  0] -1 */
    18557870, /*  4422 (  93) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    17140692, /*  4423 (  93) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6]  1 */
    34028708, /*  4424 (  93) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    17127410, /*  4425 (  93) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
       16484, /*  4426 (  94) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34015422, /*  4427 (  94) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    52556808, /*  4428 (  94) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
     1433658, /*  4429 (  94) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  0]  1 */
    51139634, /*  4430 (  94) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
    35432600, /*  4431 (  94) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  0] -1 */
    18557870, /*  4432 (  94) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    17140692, /*  4433 (  94) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6]  1 */
       16484, /*  4434 (  95) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34015422, /*  4435 (  95) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
     1420376, /*  4436 (  95) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  0]  1 */
    52556808, /*  4437 (  95) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    35445882, /*  4438 (  95) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  0] -1 */
    51152916, /*  4439 (  95) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6] -1 */
    18557870, /*  4440 (  95) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    17127410, /*  4441 (  95) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
       16484, /*  4442 (  96) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    35445882, /*  4443 (  96) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  0] -1 */
    51152916, /*  4444 (  96) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6] -1 */
    18544584, /*  4445 (  96) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
        3198, /*  4446 (  96) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    51139634, /*  4447 (  96) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
    35432600, /*  4448 (  96) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  0] -1 */
    18557870, /*  4449 (  96) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
       16484, /*  4450 (  97) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    52570092, /*  4451 (  97) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    34028706, /*  4452 (  97) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
     1420376, /*  4453 (  97) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  0]  1 */
    34015424, /*  4454 (  97) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    18544584, /*  4455 (  97) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
     1433658, /*  4456 (  97) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  0]  1 */
    35432598, /*  4457 (  97) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  0] -1 */
        3198, /*  4458 (  97) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    35445884, /*  4459 (  97) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  0] -1 */
    18557870, /*  4460 (  97) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    17140692, /*  4461 (  97) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6]  1 */
    52556810, /*  4462 (  97) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    17127410, /*  4463 (  97) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
    51152918, /*  4464 (  97) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
    51139632, /*  4465 (  97) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  6] -1 */
       16484, /*  4466 (  98) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    51021536, /*  4467 (  98) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  0] -1 */
     1420376, /*  4468 (  98) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  0]  1 */
    35550698, /*  4469 (  98) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
    52451996, /*  4470 (  98) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
    51034818, /*  4471 (  98) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  0] -1 */
    18544584, /*  4472 (  98) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
     1433658, /*  4473 (  98) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  0]  1 */
        3198, /*  4474 (  98) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    52438710, /*  4475 (  98) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
    34146806, /*  4476 (  98) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    34133520, /*  4477 (  98) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
    18557870, /*  4478 (  98) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    17140692, /*  4479 (  98) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6]  1 */
    17127410, /*  4480 (  98) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
    35563980, /*  4481 (  98) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6] -1 */
       16484, /*  4482 (  92) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
     1420376, /*  4483 (  92) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  0]  1 */
    17127408, /*  4484 (  92) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  6]  1 */
     1433658, /*  4485 (  92) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  0]  1 */
        3198, /*  4486 (  92) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    17140694, /*  4487 (  92) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
    18557868, /*  4488 (  92) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
    18544586, /*  4489 (  92) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
       16484, /*  4490 (  93) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
     1420376, /*  4491 (  93) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  0]  1 */
    34015422, /*  4492 (  93) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    51139632, /*  4493 (  93) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  6] -1 */
    35445882, /*  4494 (  93) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  0] -1 */
    52570092, /*  4495 (  93) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    17127408, /*  4496 (  93) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  6]  1 */
     1433658, /*  4497 (  93) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  0]  1 */
    51152918, /*  4498 (  93) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
        3198, /*  4499 (  93) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    52556810, /*  4500 (  93) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    35432600, /*  4501 (  93) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  0] -1 */
    17140694, /*  4502 (  93) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
    18557868, /*  4503 (  93) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
    34028708, /*  4504 (  93) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    18544586, /*  4505 (  93) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
       16484, /*  4506 (  94) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34015422, /*  4507 (  94) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    51139632, /*  4508 (  94) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  6] -1 */
     1433658, /*  4509 (  94) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  0]  1 */
    52556810, /*  4510 (  94) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    35432600, /*  4511 (  94) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  0] -1 */
    17140694, /*  4512 (  94) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
    18557868, /*  4513 (  94) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
       16484, /*  4514 (  95) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34015422, /*  4515 (  95) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
     1420376, /*  4516 (  95) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  0]  1 */
    51139632, /*  4517 (  95) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  6] -1 */
    35445882, /*  4518 (  95) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  0] -1 */
    52570092, /*  4519 (  95) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    17140694, /*  4520 (  95) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
    18544586, /*  4521 (  95) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
       16484, /*  4522 (  96) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    35445882, /*  4523 (  96) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  0] -1 */
    52570092, /*  4524 (  96) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    17127408, /*  4525 (  96) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  6]  1 */
        3198, /*  4526 (  96) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    52556810, /*  4527 (  96) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    35432600, /*  4528 (  96) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  0] -1 */
    17140694, /*  4529 (  96) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
       16484, /*  4530 (  97) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    51152916, /*  4531 (  97) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6] -1 */
    34028706, /*  4532 (  97) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
     1420376, /*  4533 (  97) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  0]  1 */
    34015424, /*  4534 (  97) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    17127408, /*  4535 (  97) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  6]  1 */
     1433658, /*  4536 (  97) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  0]  1 */
    35432598, /*  4537 (  97) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  0] -1 */
        3198, /*  4538 (  97) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    35445884, /*  4539 (  97) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  0] -1 */
    17140694, /*  4540 (  97) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
    18557868, /*  4541 (  97) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
    51139634, /*  4542 (  97) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
    18544586, /*  4543 (  97) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    52570094, /*  4544 (  97) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    52556808, /*  4545 (  97) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
       16484, /*  4546 (  98) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    52438712, /*  4547 (  98) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
     1420376, /*  4548 (  98) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  0]  1 */
    35550698, /*  4549 (  98) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
    51034820, /*  4550 (  98) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  0] -1 */
    52451994, /*  4551 (  98) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
    17127408, /*  4552 (  98) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  6]  1 */
     1433658, /*  4553 (  98) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  0]  1 */
        3198, /*  4554 (  98) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    51021534, /*  4555 (  98) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  0] -1 */
    34146806, /*  4556 (  98) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    34133520, /*  4557 (  98) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
    17140694, /*  4558 (  98) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
    18557868, /*  4559 (  98) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
    18544586, /*  4560 (  98) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    35563980, /*  4561 (  98) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6] -1 */
       16484, /*  4562 (  92) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    18426488, /*  4563 (  92) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
     1538472, /*  4564 (  92) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
    18439770, /*  4565 (  92) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
        3198, /*  4566 (  92) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
     1551758, /*  4567 (  92) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
    17140692, /*  4568 (  92) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6]  1 */
    17127410, /*  4569 (  92) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
       16484, /*  4570 (  93) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    18426488, /*  4571 (  93) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    34015422, /*  4572 (  93) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    35550696, /*  4573 (  93) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  6] -1 */
    52451994, /*  4574 (  93) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
    51152916, /*  4575 (  93) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6] -1 */
     1538472, /*  4576 (  93) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
    18439770, /*  4577 (  93) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
    35563982, /*  4578 (  93) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
        3198, /*  4579 (  93) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    51139634, /*  4580 (  93) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
    52438712, /*  4581 (  93) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
     1551758, /*  4582 (  93) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
    17140692, /*  4583 (  93) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6]  1 */
    34028708, /*  4584 (  93) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    17127410, /*  4585 (  93) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
       16484, /*  4586 (  94) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34015422, /*  4587 (  94) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    35550696, /*  4588 (  94) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  6] -1 */
    18439770, /*  4589 (  94) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
    51139634, /*  4590 (  94) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
    52438712, /*  4591 (  94) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
     1551758, /*  4592 (  94) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
    17140692, /*  4593 (  94) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6]  1 */
       16484, /*  4594 (  95) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34015422, /*  4595 (  95) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    18426488, /*  4596 (  95) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    35550696, /*  4597 (  95) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  6] -1 */
    52451994, /*  4598 (  95) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
    51152916, /*  4599 (  95) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6] -1 */
     1551758, /*  4600 (  95) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
    17127410, /*  4601 (  95) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
       16484, /*  4602 (  96) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    52451994, /*  4603 (  96) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
    51152916, /*  4604 (  96) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6] -1 */
     1538472, /*  4605 (  96) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
        3198, /*  4606 (  96) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    51139634, /*  4607 (  96) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
    52438712, /*  4608 (  96) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
     1551758, /*  4609 (  96) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
       16484, /*  4610 (  97) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    35563980, /*  4611 (  97) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6] -1 */
    34028706, /*  4612 (  97) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    18426488, /*  4613 (  97) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    34015424, /*  4614 (  97) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
     1538472, /*  4615 (  97) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
    18439770, /*  4616 (  97) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
    52438710, /*  4617 (  97) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
        3198, /*  4618 (  97) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    52451996, /*  4619 (  97) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
     1551758, /*  4620 (  97) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
    17140692, /*  4621 (  97) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6]  1 */
    35550698, /*  4622 (  97) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
    17127410, /*  4623 (  97) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
    51152918, /*  4624 (  97) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
    51139632, /*  4625 (  97) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  6] -1 */
       16484, /*  4626 (  98) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    51021536, /*  4627 (  98) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  0] -1 */
    18426488, /*  4628 (  98) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    52556810, /*  4629 (  98) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    35445884, /*  4630 (  98) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  0] -1 */
    51034818, /*  4631 (  98) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  0] -1 */
     1538472, /*  4632 (  98) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
    18439770, /*  4633 (  98) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
        3198, /*  4634 (  98) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    35432598, /*  4635 (  98) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  0] -1 */
    34146806, /*  4636 (  98) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    34133520, /*  4637 (  98) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
     1551758, /*  4638 (  98) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
    17140692, /*  4639 (  98) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6]  1 */
    17127410, /*  4640 (  98) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
    52570092, /*  4641 (  98) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
       16484, /*  4642 (  92) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    17009312, /*  4643 (  92) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  0]  1 */
    18544584, /*  4644 (  92) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
    17022594, /*  4645 (  92) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  0]  1 */
        3198, /*  4646 (  92) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    18557870, /*  4647 (  92) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
     1551756, /*  4648 (  92) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
     1538474, /*  4649 (  92) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
       16484, /*  4650 (  93) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    17009312, /*  4651 (  93) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  0]  1 */
    34015422, /*  4652 (  93) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    52556808, /*  4653 (  93) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    51034818, /*  4654 (  93) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  0] -1 */
    35563980, /*  4655 (  93) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6] -1 */
    18544584, /*  4656 (  93) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
    17022594, /*  4657 (  93) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  0]  1 */
    52570094, /*  4658 (  93) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
        3198, /*  4659 (  93) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    35550698, /*  4660 (  93) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
    51021536, /*  4661 (  93) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  0] -1 */
    18557870, /*  4662 (  93) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
     1551756, /*  4663 (  93) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
    34028708, /*  4664 (  93) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
     1538474, /*  4665 (  93) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
       16484, /*  4666 (  94) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34015422, /*  4667 (  94) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    52556808, /*  4668 (  94) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    17022594, /*  4669 (  94) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  0]  1 */
    35550698, /*  4670 (  94) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
    51021536, /*  4671 (  94) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  0] -1 */
    18557870, /*  4672 (  94) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
     1551756, /*  4673 (  94) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
       16484, /*  4674 (  95) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34015422, /*  4675 (  95) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    17009312, /*  4676 (  95) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  0]  1 */
    52556808, /*  4677 (  95) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    51034818, /*  4678 (  95) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  0] -1 */
    35563980, /*  4679 (  95) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6] -1 */
    18557870, /*  4680 (  95) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
     1538474, /*  4681 (  95) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
       16484, /*  4682 (  96) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    51034818, /*  4683 (  96) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  0] -1 */
    35563980, /*  4684 (  96) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6] -1 */
    18544584, /*  4685 (  96) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
        3198, /*  4686 (  96) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    35550698, /*  4687 (  96) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
    51021536, /*  4688 (  96) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  0] -1 */
    18557870, /*  4689 (  96) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
       16484, /*  4690 (  97) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    52570092, /*  4691 (  97) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    34028706, /*  4692 (  97) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    17009312, /*  4693 (  97) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  0]  1 */
    34015424, /*  4694 (  97) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    18544584, /*  4695 (  97) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
    17022594, /*  4696 (  97) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  0]  1 */
    51021534, /*  4697 (  97) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  0] -1 */
        3198, /*  4698 (  97) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    51034820, /*  4699 (  97) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  0] -1 */
    18557870, /*  4700 (  97) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
     1551756, /*  4701 (  97) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
    52556810, /*  4702 (  97) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
     1538474, /*  4703 (  97) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
    35563982, /*  4704 (  97) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
    35550696, /*  4705 (  97) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  6] -1 */
       16484, /*  4706 (  98) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    35432600, /*  4707 (  98) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  0] -1 */
    17009312, /*  4708 (  98) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  0]  1 */
    51139634, /*  4709 (  98) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
    52451996, /*  4710 (  98) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
    35445882, /*  4711 (  98) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  0] -1 */
    18544584, /*  4712 (  98) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
    17022594, /*  4713 (  98) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  0]  1 */
        3198, /*  4714 (  98) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    52438710, /*  4715 (  98) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
    34146806, /*  4716 (  98) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    34133520, /*  4717 (  98) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
    18557870, /*  4718 (  98) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
     1551756, /*  4719 (  98) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
     1538474, /*  4720 (  98) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
    51152916, /*  4721 (  98) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6] -1 */
       16484, /*  4722 (  92) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
     1433496, /*  4723 (  92) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  0]  1 */
    17127408, /*  4724 (  92) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  6]  1 */
     1420538, /*  4725 (  92) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  0]  1 */
        3198, /*  4726 (  92) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    17140694, /*  4727 (  92) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
    18544748, /*  4728 (  92) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    18557706, /*  4729 (  92) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
       16484, /*  4730 (  93) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
     1433496, /*  4731 (  93) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  0]  1 */
    34015422, /*  4732 (  93) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    51139632, /*  4733 (  93) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  6] -1 */
    35432762, /*  4734 (  93) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  0] -1 */
    52556972, /*  4735 (  93) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    17127408, /*  4736 (  93) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  6]  1 */
     1420538, /*  4737 (  93) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  0]  1 */
    51152918, /*  4738 (  93) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
        3198, /*  4739 (  93) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    52569930, /*  4740 (  93) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    35445720, /*  4741 (  93) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  0] -1 */
    17140694, /*  4742 (  93) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
    18544748, /*  4743 (  93) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    34028708, /*  4744 (  93) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    18557706, /*  4745 (  93) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
       16484, /*  4746 (  94) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34015422, /*  4747 (  94) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    51139632, /*  4748 (  94) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  6] -1 */
     1420538, /*  4749 (  94) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  0]  1 */
    52569930, /*  4750 (  94) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    35445720, /*  4751 (  94) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  0] -1 */
    17140694, /*  4752 (  94) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
    18544748, /*  4753 (  94) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
       16484, /*  4754 (  95) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34015422, /*  4755 (  95) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
     1433496, /*  4756 (  95) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  0]  1 */
    51139632, /*  4757 (  95) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  6] -1 */
    35432762, /*  4758 (  95) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  0] -1 */
    52556972, /*  4759 (  95) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    17140694, /*  4760 (  95) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
    18557706, /*  4761 (  95) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
       16484, /*  4762 (  96) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    35432762, /*  4763 (  96) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  0] -1 */
    52556972, /*  4764 (  96) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    17127408, /*  4765 (  96) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  6]  1 */
        3198, /*  4766 (  96) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    52569930, /*  4767 (  96) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    35445720, /*  4768 (  96) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  0] -1 */
    17140694, /*  4769 (  96) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
       16484, /*  4770 (  97) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    51139796, /*  4771 (  97) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
    34015586, /*  4772 (  97) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
     1433496, /*  4773 (  97) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  0]  1 */
    34028544, /*  4774 (  97) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    17127408, /*  4775 (  97) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  6]  1 */
     1420538, /*  4776 (  97) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  0]  1 */
    35432598, /*  4777 (  97) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  0] -1 */
        3198, /*  4778 (  97) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    35445884, /*  4779 (  97) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  0] -1 */
    17140694, /*  4780 (  97) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
    18544748, /*  4781 (  97) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    51152754, /*  4782 (  97) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  6] -1 */
    18557706, /*  4783 (  97) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
    52570094, /*  4784 (  97) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    52556808, /*  4785 (  97) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
       16484, /*  4786 (  98) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    35563818, /*  4787 (  98) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  6] -1 */
     1433496, /*  4788 (  98) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  0]  1 */
    52451832, /*  4789 (  98) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
    34146806, /*  4790 (  98) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    35550860, /*  4791 (  98) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
    17127408, /*  4792 (  98) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  6]  1 */
     1420538, /*  4793 (  98) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  0]  1 */
        3198, /*  4794 (  98) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    34133520, /*  4795 (  98) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
    51034820, /*  4796 (  98) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  0] -1 */
    51021534, /*  4797 (  98) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  0] -1 */
    17140694, /*  4798 (  98) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
    18544748, /*  4799 (  98) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    18557706, /*  4800 (  98) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
    52438874, /*  4801 (  98) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
       16484, /*  4802 (  92) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
     1551594, /*  4803 (  92) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
    18426486, /*  4804 (  92) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
     1538636, /*  4805 (  92) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
        3198, /*  4806 (  92) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    18439772, /*  4807 (  92) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    17127572, /*  4808 (  92) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
    17140530, /*  4809 (  92) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  6]  1 */
       16484, /*  4810 (  93) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
     1551594, /*  4811 (  93) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
    34015422, /*  4812 (  93) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    52438710, /*  4813 (  93) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
    35550860, /*  4814 (  93) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
    51139796, /*  4815 (  93) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
    18426486, /*  4816 (  93) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
     1538636, /*  4817 (  93) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
    52451996, /*  4818 (  93) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
        3198, /*  4819 (  93) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    51152754, /*  4820 (  93) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  6] -1 */
    35563818, /*  4821 (  93) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  6] -1 */
    18439772, /*  4822 (  93) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    17127572, /*  4823 (  93) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
    34028708, /*  4824 (  93) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    17140530, /*  4825 (  93) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  6]  1 */
       16484, /*  4826 (  94) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34015422, /*  4827 (  94) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    52438710, /*  4828 (  94) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
     1538636, /*  4829 (  94) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
    51152754, /*  4830 (  94) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  6] -1 */
    35563818, /*  4831 (  94) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  6] -1 */
    18439772, /*  4832 (  94) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    17127572, /*  4833 (  94) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
       16484, /*  4834 (  95) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34015422, /*  4835 (  95) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
     1551594, /*  4836 (  95) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
    52438710, /*  4837 (  95) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
    35550860, /*  4838 (  95) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
    51139796, /*  4839 (  95) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
    18439772, /*  4840 (  95) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    17140530, /*  4841 (  95) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  6]  1 */
       16484, /*  4842 (  96) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    35550860, /*  4843 (  96) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
    51139796, /*  4844 (  96) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
    18426486, /*  4845 (  96) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
        3198, /*  4846 (  96) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    51152754, /*  4847 (  96) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  6] -1 */
    35563818, /*  4848 (  96) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  6] -1 */
    18439772, /*  4849 (  96) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
       16484, /*  4850 (  97) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    52438874, /*  4851 (  97) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
    34015586, /*  4852 (  97) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
     1551594, /*  4853 (  97) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
    34028544, /*  4854 (  97) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    18426486, /*  4855 (  97) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
     1538636, /*  4856 (  97) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
    35550696, /*  4857 (  97) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  6] -1 */
        3198, /*  4858 (  97) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    35563982, /*  4859 (  97) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
    18439772, /*  4860 (  97) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    17127572, /*  4861 (  97) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
    52451832, /*  4862 (  97) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
    17140530, /*  4863 (  97) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  6]  1 */
    51152918, /*  4864 (  97) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
    51139632, /*  4865 (  97) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  6] -1 */
       16484, /*  4866 (  98) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34146642, /*  4867 (  98) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
     1551594, /*  4868 (  98) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
    52569930, /*  4869 (  98) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    35445884, /*  4870 (  98) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  0] -1 */
    34133684, /*  4871 (  98) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    18426486, /*  4872 (  98) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
     1538636, /*  4873 (  98) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
        3198, /*  4874 (  98) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    35432598, /*  4875 (  98) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  0] -1 */
    51034820, /*  4876 (  98) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  0] -1 */
    51021534, /*  4877 (  98) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  0] -1 */
    18439772, /*  4878 (  98) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    17127572, /*  4879 (  98) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
    17140530, /*  4880 (  98) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  6]  1 */
    52556972, /*  4881 (  98) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
       16484, /*  4882 (  92) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
      134418, /*  4883 (  92) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  6]  1 */
    18544584, /*  4884 (  92) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
      121460, /*  4885 (  92) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6]  1 */
        3198, /*  4886 (  92) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    18557870, /*  4887 (  92) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    18426650, /*  4888 (  92) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    18439608, /*  4889 (  92) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
       16484, /*  4890 (  93) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
      134418, /*  4891 (  93) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  6]  1 */
    34015422, /*  4892 (  93) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    52556808, /*  4893 (  93) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    34133684, /*  4894 (  93) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    52438874, /*  4895 (  93) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
    18544584, /*  4896 (  93) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
      121460, /*  4897 (  93) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6]  1 */
    52570094, /*  4898 (  93) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
        3198, /*  4899 (  93) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    52451832, /*  4900 (  93) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
    34146642, /*  4901 (  93) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
    18557870, /*  4902 (  93) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    18426650, /*  4903 (  93) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    34028708, /*  4904 (  93) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    18439608, /*  4905 (  93) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
       16484, /*  4906 (  94) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34015422, /*  4907 (  94) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    52556808, /*  4908 (  94) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
      121460, /*  4909 (  94) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6]  1 */
    52451832, /*  4910 (  94) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
    34146642, /*  4911 (  94) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
    18557870, /*  4912 (  94) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    18426650, /*  4913 (  94) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
       16484, /*  4914 (  95) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34015422, /*  4915 (  95) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
      134418, /*  4916 (  95) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  6]  1 */
    52556808, /*  4917 (  95) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    34133684, /*  4918 (  95) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    52438874, /*  4919 (  95) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
    18557870, /*  4920 (  95) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    18439608, /*  4921 (  95) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
       16484, /*  4922 (  96) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34133684, /*  4923 (  96) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    52438874, /*  4924 (  96) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
    18544584, /*  4925 (  96) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
        3198, /*  4926 (  96) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    52451832, /*  4927 (  96) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
    34146642, /*  4928 (  96) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
    18557870, /*  4929 (  96) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
       16484, /*  4930 (  97) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    52556972, /*  4931 (  97) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    34015586, /*  4932 (  97) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
      134418, /*  4933 (  97) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  6]  1 */
    34028544, /*  4934 (  97) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    18544584, /*  4935 (  97) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
      121460, /*  4936 (  97) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6]  1 */
    34133520, /*  4937 (  97) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
        3198, /*  4938 (  97) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    34146806, /*  4939 (  97) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    18557870, /*  4940 (  97) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    18426650, /*  4941 (  97) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    52569930, /*  4942 (  97) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    18439608, /*  4943 (  97) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
    52451996, /*  4944 (  97) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
    52438710, /*  4945 (  97) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
       16484, /*  4946 (  98) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    35445720, /*  4947 (  98) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  0] -1 */
      134418, /*  4948 (  98) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  6]  1 */
    51152754, /*  4949 (  98) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  6] -1 */
    35563982, /*  4950 (  98) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
    35432762, /*  4951 (  98) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  0] -1 */
    18544584, /*  4952 (  98) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
      121460, /*  4953 (  98) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6]  1 */
        3198, /*  4954 (  98) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    35550696, /*  4955 (  98) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  6] -1 */
    51034820, /*  4956 (  98) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  0] -1 */
    51021534, /*  4957 (  98) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  0] -1 */
    18557870, /*  4958 (  98) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    18426650, /*  4959 (  98) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    18439608, /*  4960 (  98) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
    51139796, /*  4961 (  98) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
       16484, /*  4962 (  92) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
      134418, /*  4963 (  92) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  6]  1 */
    18426486, /*  4964 (  92) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
      121460, /*  4965 (  92) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6]  1 */
        3198, /*  4966 (  92) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    18439772, /*  4967 (  92) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    18544748, /*  4968 (  92) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    18557706, /*  4969 (  92) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
       16484, /*  4970 (  93) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
      134418, /*  4971 (  93) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  6]  1 */
    34015422, /*  4972 (  93) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    52438710, /*  4973 (  93) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
    34133684, /*  4974 (  93) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    52556972, /*  4975 (  93) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    18426486, /*  4976 (  93) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
      121460, /*  4977 (  93) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6]  1 */
    52451996, /*  4978 (  93) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
        3198, /*  4979 (  93) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    52569930, /*  4980 (  93) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    34146642, /*  4981 (  93) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
    18439772, /*  4982 (  93) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    18544748, /*  4983 (  93) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    34028708, /*  4984 (  93) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    18557706, /*  4985 (  93) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
       16484, /*  4986 (  94) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34015422, /*  4987 (  94) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    52438710, /*  4988 (  94) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
      121460, /*  4989 (  94) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6]  1 */
    52569930, /*  4990 (  94) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    34146642, /*  4991 (  94) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
    18439772, /*  4992 (  94) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    18544748, /*  4993 (  94) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
       16484, /*  4994 (  95) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34015422, /*  4995 (  95) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
      134418, /*  4996 (  95) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  6]  1 */
    52438710, /*  4997 (  95) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
    34133684, /*  4998 (  95) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    52556972, /*  4999 (  95) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    18439772, /*  5000 (  95) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    18557706, /*  5001 (  95) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
       16484, /*  5002 (  96) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34133684, /*  5003 (  96) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    52556972, /*  5004 (  96) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    18426486, /*  5005 (  96) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
        3198, /*  5006 (  96) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    52569930, /*  5007 (  96) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    34146642, /*  5008 (  96) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
    18439772, /*  5009 (  96) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
       16484, /*  5010 (  97) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    52438874, /*  5011 (  97) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
    34015586, /*  5012 (  97) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
      134418, /*  5013 (  97) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  6]  1 */
    34028544, /*  5014 (  97) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    18426486, /*  5015 (  97) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
      121460, /*  5016 (  97) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6]  1 */
    34133520, /*  5017 (  97) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
        3198, /*  5018 (  97) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    34146806, /*  5019 (  97) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    18439772, /*  5020 (  97) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    18544748, /*  5021 (  97) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    52451832, /*  5022 (  97) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
    18557706, /*  5023 (  97) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
    52570094, /*  5024 (  97) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    52556808, /*  5025 (  97) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
       16484, /*  5026 (  98) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    35563818, /*  5027 (  98) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  6] -1 */
      134418, /*  5028 (  98) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  6]  1 */
    51152754, /*  5029 (  98) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  6] -1 */
    35445884, /*  5030 (  98) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  0] -1 */
    35550860, /*  5031 (  98) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
    18426486, /*  5032 (  98) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
      121460, /*  5033 (  98) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6]  1 */
        3198, /*  5034 (  98) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    35432598, /*  5035 (  98) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  0] -1 */
    51034820, /*  5036 (  98) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  0] -1 */
    51021534, /*  5037 (  98) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  0] -1 */
    18439772, /*  5038 (  98) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    18544748, /*  5039 (  98) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    18557706, /*  5040 (  98) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
    51139796, /*  5041 (  98) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
       16484, /*  5042 (  92) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
     1551594, /*  5043 (  92) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
    17127408, /*  5044 (  92) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  6]  1 */
     1538636, /*  5045 (  92) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
        3198, /*  5046 (  92) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    17140694, /*  5047 (  92) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
    18426650, /*  5048 (  92) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    18439608, /*  5049 (  92) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
       16484, /*  5050 (  93) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
     1551594, /*  5051 (  93) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
    34015422, /*  5052 (  93) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    51139632, /*  5053 (  93) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  6] -1 */
    35550860, /*  5054 (  93) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
    52438874, /*  5055 (  93) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
    17127408, /*  5056 (  93) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  6]  1 */
     1538636, /*  5057 (  93) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
    51152918, /*  5058 (  93) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
        3198, /*  5059 (  93) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    52451832, /*  5060 (  93) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
    35563818, /*  5061 (  93) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  6] -1 */
    17140694, /*  5062 (  93) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
    18426650, /*  5063 (  93) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    34028708, /*  5064 (  93) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    18439608, /*  5065 (  93) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
       16484, /*  5066 (  94) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34015422, /*  5067 (  94) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    51139632, /*  5068 (  94) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  6] -1 */
     1538636, /*  5069 (  94) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
    52451832, /*  5070 (  94) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
    35563818, /*  5071 (  94) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  6] -1 */
    17140694, /*  5072 (  94) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
    18426650, /*  5073 (  94) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
       16484, /*  5074 (  95) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34015422, /*  5075 (  95) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
     1551594, /*  5076 (  95) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
    51139632, /*  5077 (  95) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  6] -1 */
    35550860, /*  5078 (  95) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
    52438874, /*  5079 (  95) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
    17140694, /*  5080 (  95) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
    18439608, /*  5081 (  95) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
       16484, /*  5082 (  96) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    35550860, /*  5083 (  96) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
    52438874, /*  5084 (  96) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
    17127408, /*  5085 (  96) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  6]  1 */
        3198, /*  5086 (  96) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    52451832, /*  5087 (  96) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
    35563818, /*  5088 (  96) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  6] -1 */
    17140694, /*  5089 (  96) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
       16484, /*  5090 (  97) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    51139796, /*  5091 (  97) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
    34015586, /*  5092 (  97) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
     1551594, /*  5093 (  97) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
    34028544, /*  5094 (  97) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    17127408, /*  5095 (  97) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  6]  1 */
     1538636, /*  5096 (  97) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
    35550696, /*  5097 (  97) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  6] -1 */
        3198, /*  5098 (  97) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    35563982, /*  5099 (  97) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
    17140694, /*  5100 (  97) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
    18426650, /*  5101 (  97) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    51152754, /*  5102 (  97) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  6] -1 */
    18439608, /*  5103 (  97) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
    52451996, /*  5104 (  97) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
    52438710, /*  5105 (  97) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
       16484, /*  5106 (  98) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    35445720, /*  5107 (  98) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  0] -1 */
     1551594, /*  5108 (  98) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
    52569930, /*  5109 (  98) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    34146806, /*  5110 (  98) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    35432762, /*  5111 (  98) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  0] -1 */
    17127408, /*  5112 (  98) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  6]  1 */
     1538636, /*  5113 (  98) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
        3198, /*  5114 (  98) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    34133520, /*  5115 (  98) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
    51034820, /*  5116 (  98) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  0] -1 */
    51021534, /*  5117 (  98) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  0] -1 */
    17140694, /*  5118 (  98) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
    18426650, /*  5119 (  98) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    18439608, /*  5120 (  98) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
    52556972, /*  5121 (  98) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
       16484, /*  5122 (  92) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
     1433496, /*  5123 (  92) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  0]  1 */
    18544584, /*  5124 (  92) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
     1420538, /*  5125 (  92) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  0]  1 */
        3198, /*  5126 (  92) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    18557870, /*  5127 (  92) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    17127572, /*  5128 (  92) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
    17140530, /*  5129 (  92) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  6]  1 */
       16484, /*  5130 (  93) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
     1433496, /*  5131 (  93) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  0]  1 */
    34015422, /*  5132 (  93) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    52556808, /*  5133 (  93) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    35432762, /*  5134 (  93) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  0] -1 */
    51139796, /*  5135 (  93) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
    18544584, /*  5136 (  93) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
     1420538, /*  5137 (  93) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  0]  1 */
    52570094, /*  5138 (  93) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
        3198, /*  5139 (  93) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    51152754, /*  5140 (  93) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  6] -1 */
    35445720, /*  5141 (  93) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  0] -1 */
    18557870, /*  5142 (  93) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    17127572, /*  5143 (  93) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
    34028708, /*  5144 (  93) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    17140530, /*  5145 (  93) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  6]  1 */
       16484, /*  5146 (  94) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34015422, /*  5147 (  94) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    52556808, /*  5148 (  94) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
     1420538, /*  5149 (  94) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  0]  1 */
    51152754, /*  5150 (  94) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  6] -1 */
    35445720, /*  5151 (  94) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  0] -1 */
    18557870, /*  5152 (  94) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    17127572, /*  5153 (  94) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
       16484, /*  5154 (  95) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34015422, /*  5155 (  95) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
     1433496, /*  5156 (  95) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  0]  1 */
    52556808, /*  5157 (  95) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    35432762, /*  5158 (  95) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  0] -1 */
    51139796, /*  5159 (  95) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
    18557870, /*  5160 (  95) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    17140530, /*  5161 (  95) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  6]  1 */
       16484, /*  5162 (  96) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    35432762, /*  5163 (  96) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  0] -1 */
    51139796, /*  5164 (  96) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
    18544584, /*  5165 (  96) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
        3198, /*  5166 (  96) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    51152754, /*  5167 (  96) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  6] -1 */
    35445720, /*  5168 (  96) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  0] -1 */
    18557870, /*  5169 (  96) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
       16484, /*  5170 (  97) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    52556972, /*  5171 (  97) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    34015586, /*  5172 (  97) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
     1433496, /*  5173 (  97) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  0]  1 */
    34028544, /*  5174 (  97) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    18544584, /*  5175 (  97) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
     1420538, /*  5176 (  97) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  0]  1 */
    35432598, /*  5177 (  97) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  0] -1 */
        3198, /*  5178 (  97) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    35445884, /*  5179 (  97) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  0] -1 */
    18557870, /*  5180 (  97) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    17127572, /*  5181 (  97) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
    52569930, /*  5182 (  97) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    17140530, /*  5183 (  97) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  6]  1 */
    51152918, /*  5184 (  97) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
    51139632, /*  5185 (  97) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  6] -1 */
       16484, /*  5186 (  98) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34146642, /*  5187 (  98) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
     1433496, /*  5188 (  98) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  0]  1 */
    52451832, /*  5189 (  98) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
    35563982, /*  5190 (  98) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
    34133684, /*  5191 (  98) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    18544584, /*  5192 (  98) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
     1420538, /*  5193 (  98) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  0]  1 */
        3198, /*  5194 (  98) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    35550696, /*  5195 (  98) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  6] -1 */
    51034820, /*  5196 (  98) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  0] -1 */
    51021534, /*  5197 (  98) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  0] -1 */
    18557870, /*  5198 (  98) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    17127572, /*  5199 (  98) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
    17140530, /*  5200 (  98) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  6]  1 */
    52438874, /*  5201 (  98) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
       16484, /*  5202 (  99) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
        3360, /*  5203 (  99) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
       16320, /*  5204 (  99) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
        3200, /*  5205 (  99) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
       16484, /*  5206 ( 100) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
        3200, /*  5207 ( 100) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
       16320, /*  5208 ( 100) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    34015584, /*  5209 ( 100) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    34015424, /*  5210 ( 100) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
        3360, /*  5211 ( 100) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    34028708, /*  5212 ( 100) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    34028544, /*  5213 ( 100) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
       16484, /*  5214 ( 101) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34015424, /*  5215 ( 101) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
        3360, /*  5216 ( 101) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    34028544, /*  5217 ( 101) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
       16484, /*  5218 ( 102) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
        3200, /*  5219 ( 102) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    51034820, /*  5220 ( 102) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  0] -1 */
    51021696, /*  5221 ( 102) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  0] -1 */
       16320, /*  5222 ( 102) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    51034656, /*  5223 ( 102) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  0] -1 */
    51021536, /*  5224 ( 102) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  0] -1 */
        3360, /*  5225 ( 102) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
       16484, /*  5226 ( 103) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    52438712, /*  5227 ( 103) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
        3200, /*  5228 ( 103) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
       16320, /*  5229 ( 103) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    52451996, /*  5230 ( 103) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
        3360, /*  5231 ( 103) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    52438872, /*  5232 ( 103) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
    52451832, /*  5233 ( 103) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
       16484, /*  5234 ( 104) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    52556810, /*  5235 ( 104) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
        3200, /*  5236 ( 104) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
       16320, /*  5237 ( 104) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    52556970, /*  5238 ( 104) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    52569930, /*  5239 ( 104) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
        3360, /*  5240 ( 104) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    52570094, /*  5241 ( 104) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
       16484, /*  5242 ( 105) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
       16320, /*  5243 ( 105) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
      121298, /*  5244 ( 105) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6]  1 */
      121458, /*  5245 ( 105) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  6]  1 */
       16484, /*  5246 ( 106) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34133522, /*  5247 ( 106) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
      121458, /*  5248 ( 106) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  6]  1 */
       16320, /*  5249 ( 106) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
      121298, /*  5250 ( 106) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6]  1 */
    34133682, /*  5251 ( 106) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
    34028708, /*  5252 ( 106) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    34028544, /*  5253 ( 106) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
       16484, /*  5254 ( 107) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
      121298, /*  5255 ( 107) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6]  1 */
    34028544, /*  5256 ( 107) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    34133682, /*  5257 ( 107) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
       16484, /*  5258 ( 108) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
       16320, /*  5259 ( 108) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    34133522, /*  5260 ( 108) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    34133682, /*  5261 ( 108) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
       16484, /*  5262 ( 109) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    51139794, /*  5263 ( 109) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6] -1 */
      121458, /*  5264 ( 109) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  6]  1 */
    51034820, /*  5265 ( 109) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  0] -1 */
       16320, /*  5266 ( 109) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    51034656, /*  5267 ( 109) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  0] -1 */
    51139634, /*  5268 ( 109) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
      121298, /*  5269 ( 109) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6]  1 */
       16484, /*  5270 ( 110) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
      121458, /*  5271 ( 110) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  6]  1 */
       16320, /*  5272 ( 110) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    34015584, /*  5273 ( 110) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
      121298, /*  5274 ( 110) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6]  1 */
    34146806, /*  5275 ( 110) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    34146642, /*  5276 ( 110) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
    34015424, /*  5277 ( 110) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
       16484, /*  5278 ( 111) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
      121458, /*  5279 ( 111) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  6]  1 */
       16320, /*  5280 ( 111) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
      121298, /*  5281 ( 111) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6]  1 */
    51152754, /*  5282 ( 111) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  6] -1 */
    51021536, /*  5283 ( 111) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  0] -1 */
    51152918, /*  5284 ( 111) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
    51021696, /*  5285 ( 111) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  0] -1 */
       16484, /*  5286 ( 112) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
      121458, /*  5287 ( 112) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  6]  1 */
    52556810, /*  5288 ( 112) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
       16320, /*  5289 ( 112) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
      121298, /*  5290 ( 112) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6]  1 */
    52451996, /*  5291 ( 112) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
    52556970, /*  5292 ( 112) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    52451832, /*  5293 ( 112) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
       16484, /*  5294 ( 113) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
      121458, /*  5295 ( 113) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  6]  1 */
       16320, /*  5296 ( 113) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
      121298, /*  5297 ( 113) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6]  1 */
    52569930, /*  5298 ( 113) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    52438712, /*  5299 ( 113) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
    52438872, /*  5300 ( 113) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
    52570094, /*  5301 ( 113) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
       16484, /*  5302 ( 105) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
        3360, /*  5303 ( 105) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    17022432, /*  5304 ( 105) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  0]  1 */
    17009312, /*  5305 ( 105) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  0]  1 */
       16484, /*  5306 ( 106) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    51034656, /*  5307 ( 106) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  0] -1 */
    17009312, /*  5308 ( 106) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  0]  1 */
        3360, /*  5309 ( 106) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    17022432, /*  5310 ( 106) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  0]  1 */
    51021536, /*  5311 ( 106) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  0] -1 */
    34028708, /*  5312 ( 106) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    34015584, /*  5313 ( 106) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
       16484, /*  5314 ( 107) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    17022432, /*  5315 ( 107) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  0]  1 */
    34015584, /*  5316 ( 107) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    51021536, /*  5317 ( 107) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  0] -1 */
       16484, /*  5318 ( 108) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
        3360, /*  5319 ( 108) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    51034656, /*  5320 ( 108) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  0] -1 */
    51021536, /*  5321 ( 108) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  0] -1 */
       16484, /*  5322 ( 109) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    52438712, /*  5323 ( 109) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
    17009312, /*  5324 ( 109) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  0]  1 */
    35445884, /*  5325 ( 109) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  0] -1 */
        3360, /*  5326 ( 109) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    35432760, /*  5327 ( 109) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  0] -1 */
    52451832, /*  5328 ( 109) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
    17022432, /*  5329 ( 109) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  0]  1 */
       16484, /*  5330 ( 110) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    17009312, /*  5331 ( 110) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  0]  1 */
        3360, /*  5332 ( 110) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    34015424, /*  5333 ( 110) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    17022432, /*  5334 ( 110) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  0]  1 */
    51034820, /*  5335 ( 110) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  0] -1 */
    51021696, /*  5336 ( 110) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  0] -1 */
    34028544, /*  5337 ( 110) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
       16484, /*  5338 ( 111) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    17009312, /*  5339 ( 111) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  0]  1 */
        3360, /*  5340 ( 111) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    17022432, /*  5341 ( 111) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  0]  1 */
    52438872, /*  5342 ( 111) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
    35445720, /*  5343 ( 111) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  0] -1 */
    52451996, /*  5344 ( 111) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
    35432600, /*  5345 ( 111) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  0] -1 */
       16484, /*  5346 ( 112) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    17009312, /*  5347 ( 112) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  0]  1 */
    52569930, /*  5348 ( 112) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
        3360, /*  5349 ( 112) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    17022432, /*  5350 ( 112) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  0]  1 */
    35563982, /*  5351 ( 112) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
    52556810, /*  5352 ( 112) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    35550858, /*  5353 ( 112) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6] -1 */
       16484, /*  5354 ( 113) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    17009312, /*  5355 ( 113) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  0]  1 */
        3360, /*  5356 ( 113) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    17022432, /*  5357 ( 113) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  0]  1 */
    52556970, /*  5358 ( 113) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    35563818, /*  5359 ( 113) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  6] -1 */
    35550698, /*  5360 ( 113) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
    52570094, /*  5361 ( 113) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
       16484, /*  5362 ( 105) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
        3200, /*  5363 ( 105) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
     1420536, /*  5364 ( 105) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  0]  1 */
     1433496, /*  5365 ( 105) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  0]  1 */
       16484, /*  5366 ( 106) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    35432760, /*  5367 ( 106) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  0] -1 */
     1433496, /*  5368 ( 106) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  0]  1 */
        3200, /*  5369 ( 106) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
     1420536, /*  5370 ( 106) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  0]  1 */
    35445720, /*  5371 ( 106) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  0] -1 */
    34028708, /*  5372 ( 106) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    34015424, /*  5373 ( 106) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
       16484, /*  5374 ( 107) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
     1420536, /*  5375 ( 107) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  0]  1 */
    34015424, /*  5376 ( 107) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    35445720, /*  5377 ( 107) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  0] -1 */
       16484, /*  5378 ( 108) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
        3200, /*  5379 ( 108) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    35432760, /*  5380 ( 108) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  0] -1 */
    35445720, /*  5381 ( 108) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  0] -1 */
       16484, /*  5382 ( 109) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    35563818, /*  5383 ( 109) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  6] -1 */
     1433496, /*  5384 ( 109) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  0]  1 */
    34146806, /*  5385 ( 109) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
        3200, /*  5386 ( 109) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34133522, /*  5387 ( 109) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    35550858, /*  5388 ( 109) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6] -1 */
     1420536, /*  5389 ( 109) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  0]  1 */
       16484, /*  5390 ( 110) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
     1433496, /*  5391 ( 110) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  0]  1 */
        3200, /*  5392 ( 110) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34028544, /*  5393 ( 110) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
     1420536, /*  5394 ( 110) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  0]  1 */
    35445884, /*  5395 ( 110) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  0] -1 */
    35432600, /*  5396 ( 110) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  0] -1 */
    34015584, /*  5397 ( 110) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
       16484, /*  5398 ( 111) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
     1433496, /*  5399 ( 111) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  0]  1 */
        3200, /*  5400 ( 111) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
     1420536, /*  5401 ( 111) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  0]  1 */
    35550698, /*  5402 ( 111) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
    34133682, /*  5403 ( 111) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
    35563982, /*  5404 ( 111) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
    34146642, /*  5405 ( 111) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
       16484, /*  5406 ( 112) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
     1433496, /*  5407 ( 112) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  0]  1 */
    52556970, /*  5408 ( 112) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
        3200, /*  5409 ( 112) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
     1420536, /*  5410 ( 112) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  0]  1 */
    51152918, /*  5411 ( 112) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
    52569930, /*  5412 ( 112) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    51139634, /*  5413 ( 112) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
       16484, /*  5414 ( 113) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
     1433496, /*  5415 ( 113) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  0]  1 */
        3200, /*  5416 ( 113) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
     1420536, /*  5417 ( 113) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  0]  1 */
    52556810, /*  5418 ( 113) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    51139794, /*  5419 ( 113) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6] -1 */
    51152754, /*  5420 ( 113) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  6] -1 */
    52570094, /*  5421 ( 113) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
       16484, /*  5422 ( 114) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    18426648, /*  5423 ( 114) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
    18439608, /*  5424 ( 114) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
        3200, /*  5425 ( 114) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
       16484, /*  5426 ( 115) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    18426648, /*  5427 ( 115) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
    18439608, /*  5428 ( 115) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
        3200, /*  5429 ( 115) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    52438872, /*  5430 ( 115) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
    34015424, /*  5431 ( 115) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    34028708, /*  5432 ( 115) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    52451832, /*  5433 ( 115) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
       16484, /*  5434 ( 116) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    52438872, /*  5435 ( 116) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
    52451832, /*  5436 ( 116) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
        3200, /*  5437 ( 116) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
       16484, /*  5438 ( 117) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34015424, /*  5439 ( 117) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    52438872, /*  5440 ( 117) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
    18439608, /*  5441 ( 117) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
       16484, /*  5442 ( 118) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    18426648, /*  5443 ( 118) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
    18439608, /*  5444 ( 118) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
        3200, /*  5445 ( 118) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    51034656, /*  5446 ( 118) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  0] -1 */
    35432600, /*  5447 ( 118) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  0] -1 */
    35445884, /*  5448 ( 118) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  0] -1 */
    51021696, /*  5449 ( 118) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  0] -1 */
       16484, /*  5450 ( 119) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    18426648, /*  5451 ( 119) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
    34133522, /*  5452 ( 119) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    18439608, /*  5453 ( 119) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
        3200, /*  5454 ( 119) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34146806, /*  5455 ( 119) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    52556970, /*  5456 ( 119) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    52569930, /*  5457 ( 119) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
       16484, /*  5458 ( 120) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    18426648, /*  5459 ( 120) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
    18439608, /*  5460 ( 120) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
        3200, /*  5461 ( 120) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    35550858, /*  5462 ( 120) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6] -1 */
    51139634, /*  5463 ( 120) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
    51152918, /*  5464 ( 120) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
    35563818, /*  5465 ( 120) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  6] -1 */
       16484, /*  5466 ( 121) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    18426648, /*  5467 ( 121) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
    18439608, /*  5468 ( 121) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
        3200, /*  5469 ( 121) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34015584, /*  5470 ( 121) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    52451996, /*  5471 ( 121) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
    52438712, /*  5472 ( 121) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
    34028544, /*  5473 ( 121) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
       16484, /*  5474 ( 122) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    18426648, /*  5475 ( 122) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
    52556810, /*  5476 ( 122) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    18439608, /*  5477 ( 122) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
        3200, /*  5478 ( 122) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34133682, /*  5479 ( 122) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
    34146642, /*  5480 ( 122) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
    52570094, /*  5481 ( 122) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
       16484, /*  5482 ( 114) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
     1538474, /*  5483 ( 114) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
     1538634, /*  5484 ( 114) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
       16320, /*  5485 ( 114) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
       16484, /*  5486 ( 115) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
     1538474, /*  5487 ( 115) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
     1538634, /*  5488 ( 115) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
       16320, /*  5489 ( 115) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    35550698, /*  5490 ( 115) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
    34028544, /*  5491 ( 115) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    34028708, /*  5492 ( 115) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    35550858, /*  5493 ( 115) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6] -1 */
       16484, /*  5494 ( 116) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    35550698, /*  5495 ( 116) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
    35550858, /*  5496 ( 116) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6] -1 */
       16320, /*  5497 ( 116) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
       16484, /*  5498 ( 117) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34028544, /*  5499 ( 117) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    35550698, /*  5500 ( 117) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
     1538634, /*  5501 ( 117) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
       16484, /*  5502 ( 118) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
     1538474, /*  5503 ( 118) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
     1538634, /*  5504 ( 118) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
       16320, /*  5505 ( 118) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    35432760, /*  5506 ( 118) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  0] -1 */
    34146642, /*  5507 ( 118) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
    34146806, /*  5508 ( 118) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    35432600, /*  5509 ( 118) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  0] -1 */
       16484, /*  5510 ( 119) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
     1538474, /*  5511 ( 119) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
    51034656, /*  5512 ( 119) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  0] -1 */
     1538634, /*  5513 ( 119) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
       16320, /*  5514 ( 119) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    51034820, /*  5515 ( 119) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  0] -1 */
    52556810, /*  5516 ( 119) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    52556970, /*  5517 ( 119) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
       16484, /*  5518 ( 120) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
     1538474, /*  5519 ( 120) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
     1538634, /*  5520 ( 120) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
       16320, /*  5521 ( 120) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    51139634, /*  5522 ( 120) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
    52451832, /*  5523 ( 120) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
    52451996, /*  5524 ( 120) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
    51139794, /*  5525 ( 120) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6] -1 */
       16484, /*  5526 ( 121) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
     1538474, /*  5527 ( 121) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
     1538634, /*  5528 ( 121) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
       16320, /*  5529 ( 121) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    34015424, /*  5530 ( 121) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    35563982, /*  5531 ( 121) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
    35563818, /*  5532 ( 121) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  6] -1 */
    34015584, /*  5533 ( 121) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
       16484, /*  5534 ( 122) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
     1538474, /*  5535 ( 122) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
    52569930, /*  5536 ( 122) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
     1538634, /*  5537 ( 122) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
       16320, /*  5538 ( 122) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    51021536, /*  5539 ( 122) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  0] -1 */
    51021696, /*  5540 ( 122) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  0] -1 */
    52570094, /*  5541 ( 122) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
       16484, /*  5542 ( 114) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    17140530, /*  5543 ( 114) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  6]  1 */
    17127410, /*  5544 ( 114) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
        3360, /*  5545 ( 114) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
       16484, /*  5546 ( 115) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    17140530, /*  5547 ( 115) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  6]  1 */
    17127410, /*  5548 ( 115) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
        3360, /*  5549 ( 115) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    51152754, /*  5550 ( 115) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  6] -1 */
    34015584, /*  5551 ( 115) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    34028708, /*  5552 ( 115) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    51139634, /*  5553 ( 115) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
       16484, /*  5554 ( 116) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    51152754, /*  5555 ( 116) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  6] -1 */
    51139634, /*  5556 ( 116) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
        3360, /*  5557 ( 116) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
       16484, /*  5558 ( 117) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34015584, /*  5559 ( 117) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    51152754, /*  5560 ( 117) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  6] -1 */
    17127410, /*  5561 ( 117) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
       16484, /*  5562 ( 118) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    17140530, /*  5563 ( 118) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  6]  1 */
    17127410, /*  5564 ( 118) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
        3360, /*  5565 ( 118) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    34133522, /*  5566 ( 118) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    51021696, /*  5567 ( 118) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  0] -1 */
    51034820, /*  5568 ( 118) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  0] -1 */
    34146642, /*  5569 ( 118) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
       16484, /*  5570 ( 119) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    17140530, /*  5571 ( 119) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  6]  1 */
    35432760, /*  5572 ( 119) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  0] -1 */
    17127410, /*  5573 ( 119) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
        3360, /*  5574 ( 119) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    35445884, /*  5575 ( 119) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  0] -1 */
    52569930, /*  5576 ( 119) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    52556810, /*  5577 ( 119) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
       16484, /*  5578 ( 120) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    17140530, /*  5579 ( 120) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  6]  1 */
    17127410, /*  5580 ( 120) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
        3360, /*  5581 ( 120) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    52451832, /*  5582 ( 120) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
    35550858, /*  5583 ( 120) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6] -1 */
    35563982, /*  5584 ( 120) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
    52438712, /*  5585 ( 120) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
       16484, /*  5586 ( 121) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    17140530, /*  5587 ( 121) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  6]  1 */
    17127410, /*  5588 ( 121) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
        3360, /*  5589 ( 121) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    34028544, /*  5590 ( 121) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    51152918, /*  5591 ( 121) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
    51139794, /*  5592 ( 121) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6] -1 */
    34015424, /*  5593 ( 121) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
       16484, /*  5594 ( 122) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    17140530, /*  5595 ( 122) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  6]  1 */
    52556970, /*  5596 ( 122) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    17127410, /*  5597 ( 122) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
        3360, /*  5598 ( 122) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    35445720, /*  5599 ( 122) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  0] -1 */
    35432600, /*  5600 ( 122) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  0] -1 */
    52570094, /*  5601 ( 122) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
       16484, /*  5602 ( 123) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    17127410, /*  5603 ( 123) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
    18439608, /*  5604 ( 123) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
     1538634, /*  5605 ( 123) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
       16484, /*  5606 ( 124) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    18439608, /*  5607 ( 124) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
    51139634, /*  5608 ( 124) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
    17127410, /*  5609 ( 124) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
    35550858, /*  5610 ( 124) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6] -1 */
    34028708, /*  5611 ( 124) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    52451832, /*  5612 ( 124) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
     1538634, /*  5613 ( 124) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
       16484, /*  5614 ( 125) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    35550858, /*  5615 ( 125) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6] -1 */
    17127410, /*  5616 ( 125) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
    52451832, /*  5617 ( 125) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
       16484, /*  5618 ( 126) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    18439608, /*  5619 ( 126) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
    35432760, /*  5620 ( 126) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  0] -1 */
    34146806, /*  5621 ( 126) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    17127410, /*  5622 ( 126) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
    51021536, /*  5623 ( 126) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  0] -1 */
    52569930, /*  5624 ( 126) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
     1538634, /*  5625 ( 126) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
       16484, /*  5626 ( 127) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    51139794, /*  5627 ( 127) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6] -1 */
    18439608, /*  5628 ( 127) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
    52451996, /*  5629 ( 127) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
    17127410, /*  5630 ( 127) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
    35550698, /*  5631 ( 127) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
    34028544, /*  5632 ( 127) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
     1538634, /*  5633 ( 127) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
       16484, /*  5634 ( 128) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    18439608, /*  5635 ( 128) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
    35432600, /*  5636 ( 128) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  0] -1 */
    17127410, /*  5637 ( 128) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
    34146642, /*  5638 ( 128) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
    51021696, /*  5639 ( 128) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  0] -1 */
    52570094, /*  5640 ( 128) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
     1538634, /*  5641 ( 128) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
       16484, /*  5642 ( 129) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
      121458, /*  5643 ( 129) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  6]  1 */
    18439608, /*  5644 ( 129) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
       16320, /*  5645 ( 129) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
      121298, /*  5646 ( 129) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6]  1 */
    18544586, /*  5647 ( 129) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    18439772, /*  5648 ( 129) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    18544746, /*  5649 ( 129) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
       16484, /*  5650 ( 130) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34133522, /*  5651 ( 130) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
      121458, /*  5652 ( 130) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  6]  1 */
    18439608, /*  5653 ( 130) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
    52556810, /*  5654 ( 130) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
       16320, /*  5655 ( 130) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
      121298, /*  5656 ( 130) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6]  1 */
    18544586, /*  5657 ( 130) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    52451996, /*  5658 ( 130) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
    52556970, /*  5659 ( 130) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    34133682, /*  5660 ( 130) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
    18439772, /*  5661 ( 130) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    34028708, /*  5662 ( 130) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    18544746, /*  5663 ( 130) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
    34028544, /*  5664 ( 130) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    52451832, /*  5665 ( 130) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
       16484, /*  5666 ( 131) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
      121298, /*  5667 ( 131) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6]  1 */
    18544586, /*  5668 ( 131) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    52556970, /*  5669 ( 131) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    34133682, /*  5670 ( 131) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
    18439772, /*  5671 ( 131) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    34028544, /*  5672 ( 131) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    52451832, /*  5673 ( 131) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
       16484, /*  5674 ( 132) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34133522, /*  5675 ( 132) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    52556810, /*  5676 ( 132) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    18439608, /*  5677 ( 132) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
       16320, /*  5678 ( 132) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    52556970, /*  5679 ( 132) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    34133682, /*  5680 ( 132) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
    18439772, /*  5681 ( 132) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
       16484, /*  5682 ( 133) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
      121458, /*  5683 ( 133) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  6]  1 */
    18439608, /*  5684 ( 133) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
       16320, /*  5685 ( 133) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    34015584, /*  5686 ( 133) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
      121298, /*  5687 ( 133) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6]  1 */
    18544586, /*  5688 ( 133) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    34146806, /*  5689 ( 133) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    34146642, /*  5690 ( 133) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
    18439772, /*  5691 ( 133) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    52438712, /*  5692 ( 133) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
    52438872, /*  5693 ( 133) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
    18544746, /*  5694 ( 133) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
    52570094, /*  5695 ( 133) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    34015424, /*  5696 ( 133) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    52569930, /*  5697 ( 133) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
       16484, /*  5698 ( 134) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    51139794, /*  5699 ( 134) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6] -1 */
      121458, /*  5700 ( 134) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  6]  1 */
    18439608, /*  5701 ( 134) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
    35550858, /*  5702 ( 134) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6] -1 */
    51034820, /*  5703 ( 134) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  0] -1 */
       16320, /*  5704 ( 134) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    51034656, /*  5705 ( 134) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  0] -1 */
    51139634, /*  5706 ( 134) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
      121298, /*  5707 ( 134) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6]  1 */
    18544586, /*  5708 ( 134) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    35445720, /*  5709 ( 134) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  0] -1 */
    35445884, /*  5710 ( 134) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  0] -1 */
    35550698, /*  5711 ( 134) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
    18439772, /*  5712 ( 134) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    18544746, /*  5713 ( 134) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
       16484, /*  5714 ( 135) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
      121458, /*  5715 ( 135) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  6]  1 */
    18439608, /*  5716 ( 135) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
       16320, /*  5717 ( 135) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    35432600, /*  5718 ( 135) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  0] -1 */
    35432760, /*  5719 ( 135) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  0] -1 */
    35563982, /*  5720 ( 135) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
      121298, /*  5721 ( 135) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6]  1 */
    18544586, /*  5722 ( 135) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    51152754, /*  5723 ( 135) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  6] -1 */
    51021536, /*  5724 ( 135) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  0] -1 */
    18439772, /*  5725 ( 135) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    51021696, /*  5726 ( 135) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  0] -1 */
    18544746, /*  5727 ( 135) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
    35563818, /*  5728 ( 135) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  6] -1 */
    51152918, /*  5729 ( 135) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
       16484, /*  5730 ( 129) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    17009312, /*  5731 ( 129) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  0]  1 */
     1538634, /*  5732 ( 129) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
        3360, /*  5733 ( 129) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    17022432, /*  5734 ( 129) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  0]  1 */
    18557706, /*  5735 ( 129) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
     1551758, /*  5736 ( 129) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
    18544586, /*  5737 ( 129) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
       16484, /*  5738 ( 130) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    51034656, /*  5739 ( 130) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  0] -1 */
    17009312, /*  5740 ( 130) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  0]  1 */
     1538634, /*  5741 ( 130) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
    52569930, /*  5742 ( 130) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
        3360, /*  5743 ( 130) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    17022432, /*  5744 ( 130) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  0]  1 */
    18557706, /*  5745 ( 130) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
    35563982, /*  5746 ( 130) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
    52556810, /*  5747 ( 130) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    51021536, /*  5748 ( 130) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  0] -1 */
     1551758, /*  5749 ( 130) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
    34028708, /*  5750 ( 130) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    18544586, /*  5751 ( 130) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    34015584, /*  5752 ( 130) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    35550858, /*  5753 ( 130) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6] -1 */
       16484, /*  5754 ( 131) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    17022432, /*  5755 ( 131) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  0]  1 */
    18557706, /*  5756 ( 131) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
    52556810, /*  5757 ( 131) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    51021536, /*  5758 ( 131) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  0] -1 */
     1551758, /*  5759 ( 131) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
    34015584, /*  5760 ( 131) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    35550858, /*  5761 ( 131) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6] -1 */
       16484, /*  5762 ( 132) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    51034656, /*  5763 ( 132) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  0] -1 */
    52569930, /*  5764 ( 132) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
     1538634, /*  5765 ( 132) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
        3360, /*  5766 ( 132) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    52556810, /*  5767 ( 132) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    51021536, /*  5768 ( 132) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  0] -1 */
     1551758, /*  5769 ( 132) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
       16484, /*  5770 ( 133) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    17009312, /*  5771 ( 133) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  0]  1 */
     1538634, /*  5772 ( 133) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
        3360, /*  5773 ( 133) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    34015424, /*  5774 ( 133) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    17022432, /*  5775 ( 133) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  0]  1 */
    18557706, /*  5776 ( 133) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
    51034820, /*  5777 ( 133) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  0] -1 */
    51021696, /*  5778 ( 133) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  0] -1 */
     1551758, /*  5779 ( 133) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
    35563818, /*  5780 ( 133) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  6] -1 */
    35550698, /*  5781 ( 133) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
    18544586, /*  5782 ( 133) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    52570094, /*  5783 ( 133) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    34028544, /*  5784 ( 133) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    52556970, /*  5785 ( 133) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
       16484, /*  5786 ( 134) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    52438712, /*  5787 ( 134) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
    17009312, /*  5788 ( 134) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  0]  1 */
     1538634, /*  5789 ( 134) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
    51139634, /*  5790 ( 134) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
    35445884, /*  5791 ( 134) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  0] -1 */
        3360, /*  5792 ( 134) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    35432760, /*  5793 ( 134) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  0] -1 */
    52451832, /*  5794 ( 134) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
    17022432, /*  5795 ( 134) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  0]  1 */
    18557706, /*  5796 ( 134) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
    34133682, /*  5797 ( 134) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
    34146806, /*  5798 ( 134) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    51152754, /*  5799 ( 134) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  6] -1 */
     1551758, /*  5800 ( 134) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
    18544586, /*  5801 ( 134) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
       16484, /*  5802 ( 135) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    17009312, /*  5803 ( 135) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  0]  1 */
     1538634, /*  5804 ( 135) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
        3360, /*  5805 ( 135) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    34146642, /*  5806 ( 135) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
    34133522, /*  5807 ( 135) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    51152918, /*  5808 ( 135) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
    17022432, /*  5809 ( 135) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  0]  1 */
    18557706, /*  5810 ( 135) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
    52438872, /*  5811 ( 135) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
    35445720, /*  5812 ( 135) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  0] -1 */
     1551758, /*  5813 ( 135) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
    35432600, /*  5814 ( 135) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  0] -1 */
    18544586, /*  5815 ( 135) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    51139794, /*  5816 ( 135) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6] -1 */
    52451996, /*  5817 ( 135) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
       16484, /*  5818 ( 129) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
     1433496, /*  5819 ( 129) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  0]  1 */
    17127410, /*  5820 ( 129) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
        3200, /*  5821 ( 129) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
     1420536, /*  5822 ( 129) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  0]  1 */
    18544746, /*  5823 ( 129) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
    17140694, /*  5824 ( 129) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
    18557706, /*  5825 ( 129) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
       16484, /*  5826 ( 130) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    35432760, /*  5827 ( 130) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  0] -1 */
     1433496, /*  5828 ( 130) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  0]  1 */
    17127410, /*  5829 ( 130) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
    52556970, /*  5830 ( 130) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
        3200, /*  5831 ( 130) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
     1420536, /*  5832 ( 130) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  0]  1 */
    18544746, /*  5833 ( 130) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
    51152918, /*  5834 ( 130) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
    52569930, /*  5835 ( 130) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    35445720, /*  5836 ( 130) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  0] -1 */
    17140694, /*  5837 ( 130) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
    34028708, /*  5838 ( 130) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    18557706, /*  5839 ( 130) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
    34015424, /*  5840 ( 130) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    51139634, /*  5841 ( 130) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
       16484, /*  5842 ( 131) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
     1420536, /*  5843 ( 131) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  0]  1 */
    18544746, /*  5844 ( 131) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
    52569930, /*  5845 ( 131) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    35445720, /*  5846 ( 131) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  0] -1 */
    17140694, /*  5847 ( 131) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
    34015424, /*  5848 ( 131) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    51139634, /*  5849 ( 131) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
       16484, /*  5850 ( 132) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    35432760, /*  5851 ( 132) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  0] -1 */
    52556970, /*  5852 ( 132) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    17127410, /*  5853 ( 132) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
        3200, /*  5854 ( 132) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    52569930, /*  5855 ( 132) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    35445720, /*  5856 ( 132) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  0] -1 */
    17140694, /*  5857 ( 132) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
       16484, /*  5858 ( 133) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
     1433496, /*  5859 ( 133) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  0]  1 */
    17127410, /*  5860 ( 133) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
        3200, /*  5861 ( 133) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34028544, /*  5862 ( 133) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
     1420536, /*  5863 ( 133) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  0]  1 */
    18544746, /*  5864 ( 133) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
    35445884, /*  5865 ( 133) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  0] -1 */
    35432600, /*  5866 ( 133) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  0] -1 */
    17140694, /*  5867 ( 133) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
    51139794, /*  5868 ( 133) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6] -1 */
    51152754, /*  5869 ( 133) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  6] -1 */
    18557706, /*  5870 ( 133) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
    52570094, /*  5871 ( 133) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    34015584, /*  5872 ( 133) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    52556810, /*  5873 ( 133) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
       16484, /*  5874 ( 134) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    35563818, /*  5875 ( 134) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  6] -1 */
     1433496, /*  5876 ( 134) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  0]  1 */
    17127410, /*  5877 ( 134) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
    52451832, /*  5878 ( 134) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
    34146806, /*  5879 ( 134) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
        3200, /*  5880 ( 134) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34133522, /*  5881 ( 134) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    35550858, /*  5882 ( 134) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6] -1 */
     1420536, /*  5883 ( 134) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  0]  1 */
    18544746, /*  5884 ( 134) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
    51021536, /*  5885 ( 134) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  0] -1 */
    51034820, /*  5886 ( 134) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  0] -1 */
    52438872, /*  5887 ( 134) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
    17140694, /*  5888 ( 134) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
    18557706, /*  5889 ( 134) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
       16484, /*  5890 ( 135) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
     1433496, /*  5891 ( 135) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  0]  1 */
    17127410, /*  5892 ( 135) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
        3200, /*  5893 ( 135) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    51021696, /*  5894 ( 135) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  0] -1 */
    51034656, /*  5895 ( 135) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  0] -1 */
    52451996, /*  5896 ( 135) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
     1420536, /*  5897 ( 135) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  0]  1 */
    18544746, /*  5898 ( 135) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
    35550698, /*  5899 ( 135) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
    34133682, /*  5900 ( 135) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
    17140694, /*  5901 ( 135) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
    34146642, /*  5902 ( 135) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
    18557706, /*  5903 ( 135) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
    52438712, /*  5904 ( 135) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
    35563982, /*  5905 ( 135) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
       16484, /*  5906 ( 136) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    18426488, /*  5907 ( 136) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    18426648, /*  5908 ( 136) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
    18439608, /*  5909 ( 136) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
        3200, /*  5910 ( 136) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
       16320, /*  5911 ( 136) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    18439772, /*  5912 ( 136) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
        3360, /*  5913 ( 136) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
       16484, /*  5914 ( 137) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    18426488, /*  5915 ( 137) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    18426648, /*  5916 ( 137) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
    52438712, /*  5917 ( 137) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
    18439608, /*  5918 ( 137) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
        3200, /*  5919 ( 137) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
       16320, /*  5920 ( 137) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    34015584, /*  5921 ( 137) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    52451832, /*  5922 ( 137) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
    52438872, /*  5923 ( 137) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
    52451996, /*  5924 ( 137) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
    18439772, /*  5925 ( 137) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
        3360, /*  5926 ( 137) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    34028708, /*  5927 ( 137) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    34028544, /*  5928 ( 137) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    34015424, /*  5929 ( 137) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
       16484, /*  5930 ( 138) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    18426488, /*  5931 ( 138) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
        3200, /*  5932 ( 138) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34015584, /*  5933 ( 138) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    18439772, /*  5934 ( 138) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    52438872, /*  5935 ( 138) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
    34028544, /*  5936 ( 138) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    52451832, /*  5937 ( 138) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
       16484, /*  5938 ( 139) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    18439608, /*  5939 ( 139) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
       16320, /*  5940 ( 139) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    34015584, /*  5941 ( 139) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    18439772, /*  5942 ( 139) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    52438712, /*  5943 ( 139) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
    52438872, /*  5944 ( 139) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
    34015424, /*  5945 ( 139) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
       16484, /*  5946 ( 140) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    18426488, /*  5947 ( 140) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    18426648, /*  5948 ( 140) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
    34133522, /*  5949 ( 140) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    52556810, /*  5950 ( 140) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    18439608, /*  5951 ( 140) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
        3200, /*  5952 ( 140) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
       16320, /*  5953 ( 140) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    34146806, /*  5954 ( 140) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    52556970, /*  5955 ( 140) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    34133682, /*  5956 ( 140) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
    34146642, /*  5957 ( 140) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
    18439772, /*  5958 ( 140) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
        3360, /*  5959 ( 140) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    52570094, /*  5960 ( 140) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    52569930, /*  5961 ( 140) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
       16484, /*  5962 ( 141) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    18426488, /*  5963 ( 141) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    18426648, /*  5964 ( 141) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
    18439608, /*  5965 ( 141) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
        3200, /*  5966 ( 141) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    51034820, /*  5967 ( 141) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  0] -1 */
    51021696, /*  5968 ( 141) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  0] -1 */
       16320, /*  5969 ( 141) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    51034656, /*  5970 ( 141) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  0] -1 */
    35432600, /*  5971 ( 141) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  0] -1 */
    35432760, /*  5972 ( 141) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  0] -1 */
    35445720, /*  5973 ( 141) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  0] -1 */
    35445884, /*  5974 ( 141) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  0] -1 */
    51021536, /*  5975 ( 141) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  0] -1 */
    18439772, /*  5976 ( 141) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
        3360, /*  5977 ( 141) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
       16484, /*  5978 ( 142) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    18426488, /*  5979 ( 142) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    18426648, /*  5980 ( 142) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
    51139794, /*  5981 ( 142) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6] -1 */
    18439608, /*  5982 ( 142) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
        3200, /*  5983 ( 142) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    35550858, /*  5984 ( 142) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6] -1 */
       16320, /*  5985 ( 142) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    51139634, /*  5986 ( 142) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
    35563982, /*  5987 ( 142) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
    51152754, /*  5988 ( 142) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  6] -1 */
    35550698, /*  5989 ( 142) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
    18439772, /*  5990 ( 142) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
        3360, /*  5991 ( 142) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    35563818, /*  5992 ( 142) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  6] -1 */
    51152918, /*  5993 ( 142) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
       16484, /*  5994 ( 136) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
     1551594, /*  5995 ( 136) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
     1538474, /*  5996 ( 136) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
     1538634, /*  5997 ( 136) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
       16320, /*  5998 ( 136) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
        3360, /*  5999 ( 136) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
     1551758, /*  6000 ( 136) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
        3200, /*  6001 ( 136) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
       16484, /*  6002 ( 137) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
     1551594, /*  6003 ( 137) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
     1538474, /*  6004 ( 137) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
    35563818, /*  6005 ( 137) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  6] -1 */
     1538634, /*  6006 ( 137) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
       16320, /*  6007 ( 137) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
        3360, /*  6008 ( 137) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    34015424, /*  6009 ( 137) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    35550858, /*  6010 ( 137) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6] -1 */
    35550698, /*  6011 ( 137) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
    35563982, /*  6012 ( 137) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
     1551758, /*  6013 ( 137) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
        3200, /*  6014 ( 137) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34028708, /*  6015 ( 137) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    34015584, /*  6016 ( 137) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    34028544, /*  6017 ( 137) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
       16484, /*  6018 ( 138) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
     1551594, /*  6019 ( 138) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
       16320, /*  6020 ( 138) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    34015424, /*  6021 ( 138) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
     1551758, /*  6022 ( 138) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
    35550698, /*  6023 ( 138) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
    34015584, /*  6024 ( 138) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    35550858, /*  6025 ( 138) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6] -1 */
       16484, /*  6026 ( 139) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
     1538634, /*  6027 ( 139) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
        3360, /*  6028 ( 139) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    34015424, /*  6029 ( 139) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
     1551758, /*  6030 ( 139) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
    35563818, /*  6031 ( 139) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  6] -1 */
    35550698, /*  6032 ( 139) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
    34028544, /*  6033 ( 139) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
       16484, /*  6034 ( 140) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
     1551594, /*  6035 ( 140) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
     1538474, /*  6036 ( 140) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
    51034656, /*  6037 ( 140) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  0] -1 */
    52569930, /*  6038 ( 140) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
     1538634, /*  6039 ( 140) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
       16320, /*  6040 ( 140) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
        3360, /*  6041 ( 140) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    51034820, /*  6042 ( 140) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  0] -1 */
    52556810, /*  6043 ( 140) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    51021536, /*  6044 ( 140) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  0] -1 */
    51021696, /*  6045 ( 140) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  0] -1 */
     1551758, /*  6046 ( 140) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
        3200, /*  6047 ( 140) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    52570094, /*  6048 ( 140) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    52556970, /*  6049 ( 140) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
       16484, /*  6050 ( 141) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
     1551594, /*  6051 ( 141) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
     1538474, /*  6052 ( 141) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
     1538634, /*  6053 ( 141) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
       16320, /*  6054 ( 141) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    35445884, /*  6055 ( 141) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  0] -1 */
    35432600, /*  6056 ( 141) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  0] -1 */
        3360, /*  6057 ( 141) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    35432760, /*  6058 ( 141) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  0] -1 */
    34146642, /*  6059 ( 141) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
    34133522, /*  6060 ( 141) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    34133682, /*  6061 ( 141) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
    34146806, /*  6062 ( 141) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    35445720, /*  6063 ( 141) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  0] -1 */
     1551758, /*  6064 ( 141) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
        3200, /*  6065 ( 141) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
       16484, /*  6066 ( 142) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
     1551594, /*  6067 ( 142) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
     1538474, /*  6068 ( 142) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
    52438712, /*  6069 ( 142) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
     1538634, /*  6070 ( 142) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
       16320, /*  6071 ( 142) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    51139634, /*  6072 ( 142) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
        3360, /*  6073 ( 142) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    52451832, /*  6074 ( 142) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
    51152918, /*  6075 ( 142) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
    52438872, /*  6076 ( 142) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
    51152754, /*  6077 ( 142) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  6] -1 */
     1551758, /*  6078 ( 142) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
        3200, /*  6079 ( 142) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    51139794, /*  6080 ( 142) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6] -1 */
    52451996, /*  6081 ( 142) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
       16484, /*  6082 ( 136) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    17127570, /*  6083 ( 136) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6]  1 */
    17140530, /*  6084 ( 136) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  6]  1 */
    17127410, /*  6085 ( 136) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
        3360, /*  6086 ( 136) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
        3200, /*  6087 ( 136) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    17140694, /*  6088 ( 136) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
       16320, /*  6089 ( 136) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
       16484, /*  6090 ( 137) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    17127570, /*  6091 ( 137) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6]  1 */
    17140530, /*  6092 ( 137) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  6]  1 */
    51139794, /*  6093 ( 137) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6] -1 */
    17127410, /*  6094 ( 137) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
        3360, /*  6095 ( 137) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
        3200, /*  6096 ( 137) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34028544, /*  6097 ( 137) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    51139634, /*  6098 ( 137) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
    51152754, /*  6099 ( 137) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  6] -1 */
    51152918, /*  6100 ( 137) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
    17140694, /*  6101 ( 137) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
       16320, /*  6102 ( 137) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    34028708, /*  6103 ( 137) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    34015424, /*  6104 ( 137) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    34015584, /*  6105 ( 137) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
       16484, /*  6106 ( 138) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    17127570, /*  6107 ( 138) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6]  1 */
        3360, /*  6108 ( 138) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    34028544, /*  6109 ( 138) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    17140694, /*  6110 ( 138) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
    51152754, /*  6111 ( 138) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  6] -1 */
    34015424, /*  6112 ( 138) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    51139634, /*  6113 ( 138) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
       16484, /*  6114 ( 139) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    17127410, /*  6115 ( 139) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
        3200, /*  6116 ( 139) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34028544, /*  6117 ( 139) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    17140694, /*  6118 ( 139) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
    51139794, /*  6119 ( 139) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6] -1 */
    51152754, /*  6120 ( 139) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  6] -1 */
    34015584, /*  6121 ( 139) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
       16484, /*  6122 ( 140) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    17127570, /*  6123 ( 140) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6]  1 */
    17140530, /*  6124 ( 140) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  6]  1 */
    35432760, /*  6125 ( 140) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  0] -1 */
    52556970, /*  6126 ( 140) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    17127410, /*  6127 ( 140) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
        3360, /*  6128 ( 140) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
        3200, /*  6129 ( 140) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    35445884, /*  6130 ( 140) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  0] -1 */
    52569930, /*  6131 ( 140) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    35445720, /*  6132 ( 140) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  0] -1 */
    35432600, /*  6133 ( 140) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  0] -1 */
    17140694, /*  6134 ( 140) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
       16320, /*  6135 ( 140) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    52570094, /*  6136 ( 140) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    52556810, /*  6137 ( 140) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
       16484, /*  6138 ( 141) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    17127570, /*  6139 ( 141) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6]  1 */
    17140530, /*  6140 ( 141) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  6]  1 */
    17127410, /*  6141 ( 141) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
        3360, /*  6142 ( 141) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    34146806, /*  6143 ( 141) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    34146642, /*  6144 ( 141) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
        3200, /*  6145 ( 141) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34133522, /*  6146 ( 141) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    51021696, /*  6147 ( 141) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  0] -1 */
    51034656, /*  6148 ( 141) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  0] -1 */
    51021536, /*  6149 ( 141) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  0] -1 */
    51034820, /*  6150 ( 141) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  0] -1 */
    34133682, /*  6151 ( 141) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
    17140694, /*  6152 ( 141) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
       16320, /*  6153 ( 141) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
       16484, /*  6154 ( 142) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    17127570, /*  6155 ( 142) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6]  1 */
    17140530, /*  6156 ( 142) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  6]  1 */
    35563818, /*  6157 ( 142) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  6] -1 */
    17127410, /*  6158 ( 142) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
        3360, /*  6159 ( 142) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    52451832, /*  6160 ( 142) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
        3200, /*  6161 ( 142) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    35550858, /*  6162 ( 142) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6] -1 */
    52451996, /*  6163 ( 142) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
    35550698, /*  6164 ( 142) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
    52438872, /*  6165 ( 142) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
    17140694, /*  6166 ( 142) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
       16320, /*  6167 ( 142) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    52438712, /*  6168 ( 142) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
    35563982, /*  6169 ( 142) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
       16484, /*  6170 ( 143) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    18426488, /*  6171 ( 143) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    18426648, /*  6172 ( 143) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
     1551594, /*  6173 ( 143) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
     1538474, /*  6174 ( 143) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
        3200, /*  6175 ( 143) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    17140694, /*  6176 ( 143) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
    18439608, /*  6177 ( 143) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
    17127570, /*  6178 ( 143) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6]  1 */
       16320, /*  6179 ( 143) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    17127410, /*  6180 ( 143) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
     1551758, /*  6181 ( 143) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
    18439772, /*  6182 ( 143) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
        3360, /*  6183 ( 143) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    17140530, /*  6184 ( 143) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  6]  1 */
     1538634, /*  6185 ( 143) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
       16484, /*  6186 ( 144) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    18439608, /*  6187 ( 144) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
    17140694, /*  6188 ( 144) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
    17127570, /*  6189 ( 144) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6]  1 */
       16320, /*  6190 ( 144) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    52451996, /*  6191 ( 144) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
    51152754, /*  6192 ( 144) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  6] -1 */
    17127410, /*  6193 ( 144) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
    52438872, /*  6194 ( 144) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
    35563818, /*  6195 ( 144) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  6] -1 */
     1538474, /*  6196 ( 144) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
    34015584, /*  6197 ( 144) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    18439772, /*  6198 ( 144) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    34015424, /*  6199 ( 144) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    34028708, /*  6200 ( 144) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    17140530, /*  6201 ( 144) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  6]  1 */
    52438712, /*  6202 ( 144) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
    18426648, /*  6203 ( 144) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
     1551594, /*  6204 ( 144) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
    35563982, /*  6205 ( 144) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
    51152918, /*  6206 ( 144) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
        3360, /*  6207 ( 144) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    35550858, /*  6208 ( 144) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6] -1 */
    34028544, /*  6209 ( 144) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    52451832, /*  6210 ( 144) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
    18426488, /*  6211 ( 144) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    51139794, /*  6212 ( 144) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6] -1 */
        3200, /*  6213 ( 144) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    51139634, /*  6214 ( 144) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
     1551758, /*  6215 ( 144) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
    35550698, /*  6216 ( 144) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
     1538634, /*  6217 ( 144) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
       16484, /*  6218 ( 145) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    18426488, /*  6219 ( 145) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    51139794, /*  6220 ( 145) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6] -1 */
     1538474, /*  6221 ( 145) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
        3200, /*  6222 ( 145) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    17140694, /*  6223 ( 145) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
    35550858, /*  6224 ( 145) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6] -1 */
    34015584, /*  6225 ( 145) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    51152754, /*  6226 ( 145) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  6] -1 */
    17127410, /*  6227 ( 145) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
     1551758, /*  6228 ( 145) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
    18439772, /*  6229 ( 145) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    52438872, /*  6230 ( 145) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
    35563818, /*  6231 ( 145) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  6] -1 */
    34028544, /*  6232 ( 145) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    52451832, /*  6233 ( 145) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
       16484, /*  6234 ( 146) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    18439608, /*  6235 ( 146) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
    17140694, /*  6236 ( 146) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
    17127570, /*  6237 ( 146) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6]  1 */
       16320, /*  6238 ( 146) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    35445720, /*  6239 ( 146) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  0] -1 */
    52556970, /*  6240 ( 146) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    17127410, /*  6241 ( 146) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
    51021696, /*  6242 ( 146) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  0] -1 */
    52570094, /*  6243 ( 146) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
     1538474, /*  6244 ( 146) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
    51034820, /*  6245 ( 146) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  0] -1 */
    34146806, /*  6246 ( 146) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    34133682, /*  6247 ( 146) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
    51021536, /*  6248 ( 146) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  0] -1 */
    18439772, /*  6249 ( 146) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    17140530, /*  6250 ( 146) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  6]  1 */
    18426648, /*  6251 ( 146) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
     1551594, /*  6252 ( 146) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
    52556810, /*  6253 ( 146) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    34133522, /*  6254 ( 146) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    51034656, /*  6255 ( 146) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  0] -1 */
    35432760, /*  6256 ( 146) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  0] -1 */
    35445884, /*  6257 ( 146) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  0] -1 */
    34146642, /*  6258 ( 146) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
    52569930, /*  6259 ( 146) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
        3360, /*  6260 ( 146) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    18426488, /*  6261 ( 146) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
        3200, /*  6262 ( 146) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    35432600, /*  6263 ( 146) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  0] -1 */
     1551758, /*  6264 ( 146) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
     1538634, /*  6265 ( 146) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
       16484, /*  6266 ( 147) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    18557870, /*  6267 ( 147) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
        3200, /*  6268 ( 147) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
       16320, /*  6269 ( 147) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    18544586, /*  6270 ( 147) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
        3360, /*  6271 ( 147) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    18544746, /*  6272 ( 147) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
    18557706, /*  6273 ( 147) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
       16484, /*  6274 ( 148) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    18557870, /*  6275 ( 148) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    52556810, /*  6276 ( 148) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
        3200, /*  6277 ( 148) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
       16320, /*  6278 ( 148) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    34015584, /*  6279 ( 148) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    18544586, /*  6280 ( 148) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    52556970, /*  6281 ( 148) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    52569930, /*  6282 ( 148) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    34015424, /*  6283 ( 148) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
        3360, /*  6284 ( 148) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    34028708, /*  6285 ( 148) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    18544746, /*  6286 ( 148) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
    52570094, /*  6287 ( 148) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    34028544, /*  6288 ( 148) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    18557706, /*  6289 ( 148) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
       16484, /*  6290 ( 149) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    18557870, /*  6291 ( 149) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
        3200, /*  6292 ( 149) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34015584, /*  6293 ( 149) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    18544586, /*  6294 ( 149) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    52556970, /*  6295 ( 149) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    52569930, /*  6296 ( 149) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    34028544, /*  6297 ( 149) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
       16484, /*  6298 ( 150) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    18557870, /*  6299 ( 150) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    34133522, /*  6300 ( 150) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    52438712, /*  6301 ( 150) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
        3200, /*  6302 ( 150) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
       16320, /*  6303 ( 150) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    52451996, /*  6304 ( 150) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
    18544586, /*  6305 ( 150) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    34146806, /*  6306 ( 150) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    34133682, /*  6307 ( 150) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
    34146642, /*  6308 ( 150) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
        3360, /*  6309 ( 150) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    52438872, /*  6310 ( 150) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
    18544746, /*  6311 ( 150) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
    52451832, /*  6312 ( 150) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
    18557706, /*  6313 ( 150) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
       16484, /*  6314 ( 151) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    18557870, /*  6315 ( 151) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
      134418, /*  6316 ( 151) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  6]  1 */
    18439608, /*  6317 ( 151) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
    17009472, /*  6318 ( 151) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  0]  1 */
     1420376, /*  6319 ( 151) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  0]  1 */
    17127410, /*  6320 ( 151) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
     1538634, /*  6321 ( 151) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
       16484, /*  6322 ( 152) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    18557870, /*  6323 ( 152) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
      134418, /*  6324 ( 152) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  6]  1 */
    18439608, /*  6325 ( 152) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
    17009472, /*  6326 ( 152) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  0]  1 */
    35432600, /*  6327 ( 152) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  0] -1 */
    51139634, /*  6328 ( 152) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
     1420376, /*  6329 ( 152) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  0]  1 */
    17127410, /*  6330 ( 152) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
    34146642, /*  6331 ( 152) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
    35550858, /*  6332 ( 152) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6] -1 */
    51021696, /*  6333 ( 152) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  0] -1 */
    34028708, /*  6334 ( 152) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    52570094, /*  6335 ( 152) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    52451832, /*  6336 ( 152) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
     1538634, /*  6337 ( 152) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
       16484, /*  6338 ( 153) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    18557870, /*  6339 ( 153) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
     1420376, /*  6340 ( 153) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  0]  1 */
    17127410, /*  6341 ( 153) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
    34146642, /*  6342 ( 153) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
    35550858, /*  6343 ( 153) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6] -1 */
    51021696, /*  6344 ( 153) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  0] -1 */
    52451832, /*  6345 ( 153) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
       16484, /*  6346 ( 154) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    51139794, /*  6347 ( 154) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6] -1 */
    18557870, /*  6348 ( 154) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
      134418, /*  6349 ( 154) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  6]  1 */
    18439608, /*  6350 ( 154) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
    17009472, /*  6351 ( 154) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  0]  1 */
    35432760, /*  6352 ( 154) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  0] -1 */
    52451996, /*  6353 ( 154) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
    51021536, /*  6354 ( 154) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  0] -1 */
     1420376, /*  6355 ( 154) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  0]  1 */
    34146806, /*  6356 ( 154) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    17127410, /*  6357 ( 154) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
    35550698, /*  6358 ( 154) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
    52569930, /*  6359 ( 154) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    34028544, /*  6360 ( 154) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
     1538634, /*  6361 ( 154) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
       16484, /*  6362 ( 155) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
        3362, /*  6363 ( 155) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
        3200, /*  6364 ( 155) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
       16322, /*  6365 ( 155) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
       16484, /*  6366 ( 156) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34015586, /*  6367 ( 156) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    34028546, /*  6368 ( 156) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
        3200, /*  6369 ( 156) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
        3362, /*  6370 ( 156) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34015424, /*  6371 ( 156) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    34028708, /*  6372 ( 156) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
       16322, /*  6373 ( 156) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
       16484, /*  6374 ( 157) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34015424, /*  6375 ( 157) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    34015586, /*  6376 ( 157) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
       16322, /*  6377 ( 157) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
       16484, /*  6378 ( 158) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34028546, /*  6379 ( 158) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    34015586, /*  6380 ( 158) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
        3200, /*  6381 ( 158) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
       16484, /*  6382 ( 159) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34133522, /*  6383 ( 159) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
        3200, /*  6384 ( 159) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
        3362, /*  6385 ( 159) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34146644, /*  6386 ( 159) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    34146806, /*  6387 ( 159) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    34133684, /*  6388 ( 159) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
       16322, /*  6389 ( 159) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
       16484, /*  6390 ( 160) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
        3200, /*  6391 ( 160) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
        3362, /*  6392 ( 160) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    51034820, /*  6393 ( 160) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  0] -1 */
    51021698, /*  6394 ( 160) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  0] -1 */
    51034658, /*  6395 ( 160) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  0] -1 */
    51021536, /*  6396 ( 160) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  0] -1 */
       16322, /*  6397 ( 160) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
       16484, /*  6398 ( 161) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    52451834, /*  6399 ( 161) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
        3200, /*  6400 ( 161) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
        3362, /*  6401 ( 161) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    52438874, /*  6402 ( 161) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
    52451996, /*  6403 ( 161) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
    52438712, /*  6404 ( 161) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
       16322, /*  6405 ( 161) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
       16484, /*  6406 ( 162) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
        3200, /*  6407 ( 162) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
        3362, /*  6408 ( 162) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    35550860, /*  6409 ( 162) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
    35563982, /*  6410 ( 162) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
    35550698, /*  6411 ( 162) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
    35563820, /*  6412 ( 162) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
       16322, /*  6413 ( 162) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
       16484, /*  6414 ( 163) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    52556810, /*  6415 ( 163) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
        3200, /*  6416 ( 163) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
        3362, /*  6417 ( 163) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    52569932, /*  6418 ( 163) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    52556972, /*  6419 ( 163) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    52570094, /*  6420 ( 163) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
       16322, /*  6421 ( 163) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
       16484, /*  6422 ( 155) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
       16322, /*  6423 ( 155) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
       16320, /*  6424 ( 155) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
       16482, /*  6425 ( 155) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
       16484, /*  6426 ( 156) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34028546, /*  6427 ( 156) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    34028706, /*  6428 ( 156) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
       16320, /*  6429 ( 156) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
       16322, /*  6430 ( 156) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34028544, /*  6431 ( 156) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    34028708, /*  6432 ( 156) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
       16482, /*  6433 ( 156) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
       16484, /*  6434 ( 157) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34028544, /*  6435 ( 157) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    34028546, /*  6436 ( 157) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
       16482, /*  6437 ( 157) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
       16484, /*  6438 ( 158) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34028706, /*  6439 ( 158) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    34028546, /*  6440 ( 158) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
       16320, /*  6441 ( 158) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
       16484, /*  6442 ( 159) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    51034656, /*  6443 ( 159) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  0] -1 */
       16320, /*  6444 ( 159) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
       16322, /*  6445 ( 159) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    51034818, /*  6446 ( 159) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  0] -1 */
    51034820, /*  6447 ( 159) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  0] -1 */
    51034658, /*  6448 ( 159) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  0] -1 */
       16482, /*  6449 ( 159) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
       16484, /*  6450 ( 160) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
       16320, /*  6451 ( 160) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
       16322, /*  6452 ( 160) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    35445884, /*  6453 ( 160) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  0] -1 */
    35445722, /*  6454 ( 160) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  0] -1 */
    35445882, /*  6455 ( 160) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  0] -1 */
    35445720, /*  6456 ( 160) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  0] -1 */
       16482, /*  6457 ( 160) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
       16484, /*  6458 ( 161) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    35563980, /*  6459 ( 161) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6] -1 */
       16320, /*  6460 ( 161) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
       16322, /*  6461 ( 161) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    35563820, /*  6462 ( 161) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
    35563982, /*  6463 ( 161) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
    35563818, /*  6464 ( 161) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  6] -1 */
       16482, /*  6465 ( 161) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
       16484, /*  6466 ( 162) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
       16320, /*  6467 ( 162) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
       16322, /*  6468 ( 162) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    51152756, /*  6469 ( 162) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
    51152918, /*  6470 ( 162) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
    51152754, /*  6471 ( 162) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  6] -1 */
    51152916, /*  6472 ( 162) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6] -1 */
       16482, /*  6473 ( 162) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
       16484, /*  6474 ( 163) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    52569930, /*  6475 ( 163) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
       16320, /*  6476 ( 163) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
       16322, /*  6477 ( 163) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    52570092, /*  6478 ( 163) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    52569932, /*  6479 ( 163) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    52570094, /*  6480 ( 163) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
       16482, /*  6481 ( 163) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
       16484, /*  6482 ( 155) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
       16482, /*  6483 ( 155) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
        3360, /*  6484 ( 155) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
        3362, /*  6485 ( 155) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
       16484, /*  6486 ( 156) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34028706, /*  6487 ( 156) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    34015586, /*  6488 ( 156) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
        3360, /*  6489 ( 156) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
       16482, /*  6490 ( 156) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    34015584, /*  6491 ( 156) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    34028708, /*  6492 ( 156) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
        3362, /*  6493 ( 156) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
       16484, /*  6494 ( 157) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34015584, /*  6495 ( 157) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    34028706, /*  6496 ( 157) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
        3362, /*  6497 ( 157) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
       16484, /*  6498 ( 158) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34015586, /*  6499 ( 158) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    34028706, /*  6500 ( 158) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
        3360, /*  6501 ( 158) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
       16484, /*  6502 ( 159) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    35432760, /*  6503 ( 159) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  0] -1 */
        3360, /*  6504 ( 159) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
       16482, /*  6505 ( 159) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    35432762, /*  6506 ( 159) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  0] -1 */
    35445884, /*  6507 ( 159) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  0] -1 */
    35445882, /*  6508 ( 159) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  0] -1 */
        3362, /*  6509 ( 159) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
       16484, /*  6510 ( 160) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
        3360, /*  6511 ( 160) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
       16482, /*  6512 ( 160) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    34146806, /*  6513 ( 160) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    34146804, /*  6514 ( 160) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
    34133684, /*  6515 ( 160) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    34133682, /*  6516 ( 160) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
        3362, /*  6517 ( 160) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
       16484, /*  6518 ( 161) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    51139796, /*  6519 ( 161) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
        3360, /*  6520 ( 161) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
       16482, /*  6521 ( 161) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    51152916, /*  6522 ( 161) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6] -1 */
    51152918, /*  6523 ( 161) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
    51139794, /*  6524 ( 161) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6] -1 */
        3362, /*  6525 ( 161) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
       16484, /*  6526 ( 162) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
        3360, /*  6527 ( 162) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
       16482, /*  6528 ( 162) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    52451994, /*  6529 ( 162) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
    52451996, /*  6530 ( 162) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
    52438872, /*  6531 ( 162) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
    52438874, /*  6532 ( 162) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
        3362, /*  6533 ( 162) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
       16484, /*  6534 ( 163) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    52556970, /*  6535 ( 163) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
        3360, /*  6536 ( 163) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
       16482, /*  6537 ( 163) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    52556972, /*  6538 ( 163) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    52570092, /*  6539 ( 163) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    52570094, /*  6540 ( 163) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
        3362, /*  6541 ( 163) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
       16484, /*  6542 ( 164) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
        3362, /*  6543 ( 164) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
      121298, /*  6544 ( 164) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6]  1 */
      134420, /*  6545 ( 164) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6]  1 */
       16484, /*  6546 ( 165) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34015586, /*  6547 ( 165) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    34133522, /*  6548 ( 165) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
        3362, /*  6549 ( 165) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34146644, /*  6550 ( 165) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
      121298, /*  6551 ( 165) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6]  1 */
      134420, /*  6552 ( 165) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6]  1 */
    34028708, /*  6553 ( 165) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
       16484, /*  6554 ( 166) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
      134420, /*  6555 ( 166) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6]  1 */
    34133522, /*  6556 ( 166) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    34015586, /*  6557 ( 166) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
       16484, /*  6558 ( 167) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
        3362, /*  6559 ( 167) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34146644, /*  6560 ( 167) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    34133522, /*  6561 ( 167) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
       16484, /*  6562 ( 168) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34146644, /*  6563 ( 168) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
      121298, /*  6564 ( 168) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6]  1 */
    34015586, /*  6565 ( 168) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
       16484, /*  6566 ( 169) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    51152756, /*  6567 ( 169) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
        3362, /*  6568 ( 169) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    51034820, /*  6569 ( 169) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  0] -1 */
    51021698, /*  6570 ( 169) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  0] -1 */
    51139634, /*  6571 ( 169) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
      121298, /*  6572 ( 169) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6]  1 */
      134420, /*  6573 ( 169) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6]  1 */
       16484, /*  6574 ( 170) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
        3362, /*  6575 ( 170) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    35432762, /*  6576 ( 170) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  0] -1 */
      121298, /*  6577 ( 170) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6]  1 */
    35445884, /*  6578 ( 170) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  0] -1 */
    35550698, /*  6579 ( 170) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
      134420, /*  6580 ( 170) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6]  1 */
    35563820, /*  6581 ( 170) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
       16484, /*  6582 ( 171) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34028546, /*  6583 ( 171) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
        3362, /*  6584 ( 171) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
      121298, /*  6585 ( 171) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6]  1 */
    34146806, /*  6586 ( 171) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    34133684, /*  6587 ( 171) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
      134420, /*  6588 ( 171) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6]  1 */
    34015424, /*  6589 ( 171) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
       16484, /*  6590 ( 172) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
        3362, /*  6591 ( 172) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    35550860, /*  6592 ( 172) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
    35432600, /*  6593 ( 172) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  0] -1 */
    35563982, /*  6594 ( 172) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
      121298, /*  6595 ( 172) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6]  1 */
    35445722, /*  6596 ( 172) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  0] -1 */
      134420, /*  6597 ( 172) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6]  1 */
       16484, /*  6598 ( 173) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
        3362, /*  6599 ( 173) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    51034658, /*  6600 ( 173) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  0] -1 */
      121298, /*  6601 ( 173) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6]  1 */
    51139796, /*  6602 ( 173) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
    51021536, /*  6603 ( 173) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  0] -1 */
      134420, /*  6604 ( 173) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6]  1 */
    51152918, /*  6605 ( 173) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
       16484, /*  6606 ( 174) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    52556810, /*  6607 ( 174) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
        3362, /*  6608 ( 174) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    52438874, /*  6609 ( 174) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
    52569932, /*  6610 ( 174) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
      121298, /*  6611 ( 174) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6]  1 */
    52451996, /*  6612 ( 174) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
      134420, /*  6613 ( 174) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6]  1 */
       16484, /*  6614 ( 175) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    52451834, /*  6615 ( 175) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
        3362, /*  6616 ( 175) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
      121298, /*  6617 ( 175) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6]  1 */
    52556972, /*  6618 ( 175) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
      134420, /*  6619 ( 175) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6]  1 */
    52438712, /*  6620 ( 175) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
    52570094, /*  6621 ( 175) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
       16484, /*  6622 ( 164) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
       16322, /*  6623 ( 164) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
      121298, /*  6624 ( 164) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6]  1 */
      121460, /*  6625 ( 164) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6]  1 */
       16484, /*  6626 ( 165) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34028546, /*  6627 ( 165) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    34133522, /*  6628 ( 165) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
       16322, /*  6629 ( 165) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34133684, /*  6630 ( 165) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
      121298, /*  6631 ( 165) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6]  1 */
      121460, /*  6632 ( 165) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6]  1 */
    34028708, /*  6633 ( 165) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
       16484, /*  6634 ( 166) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
      121460, /*  6635 ( 166) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6]  1 */
    34133522, /*  6636 ( 166) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    34028546, /*  6637 ( 166) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
       16484, /*  6638 ( 167) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
       16322, /*  6639 ( 167) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34133684, /*  6640 ( 167) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    34133522, /*  6641 ( 167) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
       16484, /*  6642 ( 168) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34133684, /*  6643 ( 168) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
      121298, /*  6644 ( 168) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6]  1 */
    34028546, /*  6645 ( 168) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
       16484, /*  6646 ( 169) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    35550860, /*  6647 ( 169) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
       16322, /*  6648 ( 169) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    35445884, /*  6649 ( 169) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  0] -1 */
    35445722, /*  6650 ( 169) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  0] -1 */
    35550698, /*  6651 ( 169) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
      121298, /*  6652 ( 169) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6]  1 */
      121460, /*  6653 ( 169) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6]  1 */
       16484, /*  6654 ( 170) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
       16322, /*  6655 ( 170) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    51034658, /*  6656 ( 170) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  0] -1 */
      121298, /*  6657 ( 170) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6]  1 */
    51034820, /*  6658 ( 170) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  0] -1 */
    51139634, /*  6659 ( 170) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
      121460, /*  6660 ( 170) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6]  1 */
    51139796, /*  6661 ( 170) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
       16484, /*  6662 ( 171) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34015586, /*  6663 ( 171) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
       16322, /*  6664 ( 171) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
      121298, /*  6665 ( 171) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6]  1 */
    34146806, /*  6666 ( 171) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    34146644, /*  6667 ( 171) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
      121460, /*  6668 ( 171) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6]  1 */
    34015424, /*  6669 ( 171) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
       16484, /*  6670 ( 172) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
       16322, /*  6671 ( 172) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    51152756, /*  6672 ( 172) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
    51021536, /*  6673 ( 172) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  0] -1 */
    51152918, /*  6674 ( 172) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
      121298, /*  6675 ( 172) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6]  1 */
    51021698, /*  6676 ( 172) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  0] -1 */
      121460, /*  6677 ( 172) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6]  1 */
       16484, /*  6678 ( 173) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
       16322, /*  6679 ( 173) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    35432762, /*  6680 ( 173) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  0] -1 */
      121298, /*  6681 ( 173) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6]  1 */
    35563820, /*  6682 ( 173) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
    35432600, /*  6683 ( 173) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  0] -1 */
      121460, /*  6684 ( 173) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6]  1 */
    35563982, /*  6685 ( 173) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
       16484, /*  6686 ( 174) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    52556810, /*  6687 ( 174) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
       16322, /*  6688 ( 174) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    52451834, /*  6689 ( 174) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
    52556972, /*  6690 ( 174) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
      121298, /*  6691 ( 174) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6]  1 */
    52451996, /*  6692 ( 174) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
      121460, /*  6693 ( 174) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6]  1 */
       16484, /*  6694 ( 175) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    52438874, /*  6695 ( 175) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
       16322, /*  6696 ( 175) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
      121298, /*  6697 ( 175) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6]  1 */
    52569932, /*  6698 ( 175) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
      121460, /*  6699 ( 175) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6]  1 */
    52438712, /*  6700 ( 175) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
    52570094, /*  6701 ( 175) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
       16484, /*  6702 ( 164) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
       16322, /*  6703 ( 164) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    17022432, /*  6704 ( 164) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  0]  1 */
    17022594, /*  6705 ( 164) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  0]  1 */
       16484, /*  6706 ( 165) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34028546, /*  6707 ( 165) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    51034656, /*  6708 ( 165) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  0] -1 */
       16322, /*  6709 ( 165) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    51034818, /*  6710 ( 165) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  0] -1 */
    17022432, /*  6711 ( 165) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  0]  1 */
    17022594, /*  6712 ( 165) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  0]  1 */
    34028708, /*  6713 ( 165) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
       16484, /*  6714 ( 166) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    17022594, /*  6715 ( 166) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  0]  1 */
    51034656, /*  6716 ( 166) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  0] -1 */
    34028546, /*  6717 ( 166) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
       16484, /*  6718 ( 167) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
       16322, /*  6719 ( 167) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    51034818, /*  6720 ( 167) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  0] -1 */
    51034656, /*  6721 ( 167) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  0] -1 */
       16484, /*  6722 ( 168) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    51034818, /*  6723 ( 168) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  0] -1 */
    17022432, /*  6724 ( 168) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  0]  1 */
    34028546, /*  6725 ( 168) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
       16484, /*  6726 ( 169) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    52451994, /*  6727 ( 169) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
       16322, /*  6728 ( 169) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    35445884, /*  6729 ( 169) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  0] -1 */
    35445722, /*  6730 ( 169) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  0] -1 */
    52451832, /*  6731 ( 169) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
    17022432, /*  6732 ( 169) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  0]  1 */
    17022594, /*  6733 ( 169) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  0]  1 */
       16484, /*  6734 ( 170) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
       16322, /*  6735 ( 170) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34146644, /*  6736 ( 170) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    17022432, /*  6737 ( 170) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  0]  1 */
    34146806, /*  6738 ( 170) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    51152754, /*  6739 ( 170) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  6] -1 */
    17022594, /*  6740 ( 170) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  0]  1 */
    51152916, /*  6741 ( 170) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6] -1 */
       16484, /*  6742 ( 171) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34028706, /*  6743 ( 171) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
       16322, /*  6744 ( 171) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    17022432, /*  6745 ( 171) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  0]  1 */
    51034820, /*  6746 ( 171) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  0] -1 */
    51034658, /*  6747 ( 171) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  0] -1 */
    17022594, /*  6748 ( 171) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  0]  1 */
    34028544, /*  6749 ( 171) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
       16484, /*  6750 ( 172) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
       16322, /*  6751 ( 172) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    51152756, /*  6752 ( 172) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
    34146642, /*  6753 ( 172) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
    51152918, /*  6754 ( 172) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
    17022432, /*  6755 ( 172) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  0]  1 */
    34146804, /*  6756 ( 172) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
    17022594, /*  6757 ( 172) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  0]  1 */
       16484, /*  6758 ( 173) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
       16322, /*  6759 ( 173) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    35445882, /*  6760 ( 173) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  0] -1 */
    17022432, /*  6761 ( 173) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  0]  1 */
    52451834, /*  6762 ( 173) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
    35445720, /*  6763 ( 173) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  0] -1 */
    17022594, /*  6764 ( 173) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  0]  1 */
    52451996, /*  6765 ( 173) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
       16484, /*  6766 ( 174) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    52569930, /*  6767 ( 174) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
       16322, /*  6768 ( 174) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    35563820, /*  6769 ( 174) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
    52570092, /*  6770 ( 174) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    17022432, /*  6771 ( 174) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  0]  1 */
    35563982, /*  6772 ( 174) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
    17022594, /*  6773 ( 174) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  0]  1 */
       16484, /*  6774 ( 175) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    35563980, /*  6775 ( 175) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6] -1 */
       16322, /*  6776 ( 175) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    17022432, /*  6777 ( 175) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  0]  1 */
    52569932, /*  6778 ( 175) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    17022594, /*  6779 ( 175) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  0]  1 */
    35563818, /*  6780 ( 175) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  6] -1 */
    52570094, /*  6781 ( 175) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
       16484, /*  6782 ( 164) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
       16482, /*  6783 ( 164) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    17022432, /*  6784 ( 164) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  0]  1 */
    17022434, /*  6785 ( 164) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  0]  1 */
       16484, /*  6786 ( 165) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34028706, /*  6787 ( 165) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    51034656, /*  6788 ( 165) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  0] -1 */
       16482, /*  6789 ( 165) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    51034658, /*  6790 ( 165) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  0] -1 */
    17022432, /*  6791 ( 165) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  0]  1 */
    17022434, /*  6792 ( 165) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  0]  1 */
    34028708, /*  6793 ( 165) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
       16484, /*  6794 ( 166) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    17022434, /*  6795 ( 166) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  0]  1 */
    51034656, /*  6796 ( 166) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  0] -1 */
    34028706, /*  6797 ( 166) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
       16484, /*  6798 ( 167) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
       16482, /*  6799 ( 167) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    51034658, /*  6800 ( 167) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  0] -1 */
    51034656, /*  6801 ( 167) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  0] -1 */
       16484, /*  6802 ( 168) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    51034658, /*  6803 ( 168) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  0] -1 */
    17022432, /*  6804 ( 168) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  0]  1 */
    34028706, /*  6805 ( 168) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
       16484, /*  6806 ( 169) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    51152756, /*  6807 ( 169) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
       16482, /*  6808 ( 169) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    34146806, /*  6809 ( 169) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    34146804, /*  6810 ( 169) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
    51152754, /*  6811 ( 169) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  6] -1 */
    17022432, /*  6812 ( 169) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  0]  1 */
    17022434, /*  6813 ( 169) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  0]  1 */
       16484, /*  6814 ( 170) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
       16482, /*  6815 ( 170) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    35445882, /*  6816 ( 170) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  0] -1 */
    17022432, /*  6817 ( 170) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  0]  1 */
    35445884, /*  6818 ( 170) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  0] -1 */
    52451832, /*  6819 ( 170) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
    17022434, /*  6820 ( 170) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  0]  1 */
    52451834, /*  6821 ( 170) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
       16484, /*  6822 ( 171) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34028546, /*  6823 ( 171) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
       16482, /*  6824 ( 171) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    17022432, /*  6825 ( 171) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  0]  1 */
    51034820, /*  6826 ( 171) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  0] -1 */
    51034818, /*  6827 ( 171) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  0] -1 */
    17022434, /*  6828 ( 171) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  0]  1 */
    34028544, /*  6829 ( 171) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
       16484, /*  6830 ( 172) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
       16482, /*  6831 ( 172) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    52451994, /*  6832 ( 172) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
    35445720, /*  6833 ( 172) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  0] -1 */
    52451996, /*  6834 ( 172) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
    17022432, /*  6835 ( 172) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  0]  1 */
    35445722, /*  6836 ( 172) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  0] -1 */
    17022434, /*  6837 ( 172) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  0]  1 */
       16484, /*  6838 ( 173) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
       16482, /*  6839 ( 173) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    34146644, /*  6840 ( 173) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    17022432, /*  6841 ( 173) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  0]  1 */
    51152916, /*  6842 ( 173) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6] -1 */
    34146642, /*  6843 ( 173) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
    17022434, /*  6844 ( 173) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  0]  1 */
    51152918, /*  6845 ( 173) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
       16484, /*  6846 ( 174) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    52569930, /*  6847 ( 174) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
       16482, /*  6848 ( 174) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    35563980, /*  6849 ( 174) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6] -1 */
    52569932, /*  6850 ( 174) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    17022432, /*  6851 ( 174) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  0]  1 */
    35563982, /*  6852 ( 174) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
    17022434, /*  6853 ( 174) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  0]  1 */
       16484, /*  6854 ( 175) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    35563820, /*  6855 ( 175) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
       16482, /*  6856 ( 175) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    17022432, /*  6857 ( 175) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  0]  1 */
    52570092, /*  6858 ( 175) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    17022434, /*  6859 ( 175) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  0]  1 */
    35563818, /*  6860 ( 175) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  6] -1 */
    52570094, /*  6861 ( 175) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
       16484, /*  6862 ( 164) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
       16482, /*  6863 ( 164) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
     1420536, /*  6864 ( 164) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  0]  1 */
     1420538, /*  6865 ( 164) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  0]  1 */
       16484, /*  6866 ( 165) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34028706, /*  6867 ( 165) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    35432760, /*  6868 ( 165) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  0] -1 */
       16482, /*  6869 ( 165) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    35432762, /*  6870 ( 165) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  0] -1 */
     1420536, /*  6871 ( 165) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  0]  1 */
     1420538, /*  6872 ( 165) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  0]  1 */
    34028708, /*  6873 ( 165) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
       16484, /*  6874 ( 166) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
     1420538, /*  6875 ( 166) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  0]  1 */
    35432760, /*  6876 ( 166) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  0] -1 */
    34028706, /*  6877 ( 166) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
       16484, /*  6878 ( 167) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
       16482, /*  6879 ( 167) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    35432762, /*  6880 ( 167) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  0] -1 */
    35432760, /*  6881 ( 167) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  0] -1 */
       16484, /*  6882 ( 168) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    35432762, /*  6883 ( 168) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  0] -1 */
     1420536, /*  6884 ( 168) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  0]  1 */
    34028706, /*  6885 ( 168) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
       16484, /*  6886 ( 169) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    35550860, /*  6887 ( 169) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
       16482, /*  6888 ( 169) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    34146806, /*  6889 ( 169) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    34146804, /*  6890 ( 169) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
    35550858, /*  6891 ( 169) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6] -1 */
     1420536, /*  6892 ( 169) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  0]  1 */
     1420538, /*  6893 ( 169) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  0]  1 */
       16484, /*  6894 ( 170) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
       16482, /*  6895 ( 170) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    51034818, /*  6896 ( 170) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  0] -1 */
     1420536, /*  6897 ( 170) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  0]  1 */
    51034820, /*  6898 ( 170) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  0] -1 */
    52438872, /*  6899 ( 170) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
     1420538, /*  6900 ( 170) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  0]  1 */
    52438874, /*  6901 ( 170) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
       16484, /*  6902 ( 171) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34015586, /*  6903 ( 171) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
       16482, /*  6904 ( 171) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
     1420536, /*  6905 ( 171) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  0]  1 */
    35445884, /*  6906 ( 171) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  0] -1 */
    35445882, /*  6907 ( 171) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  0] -1 */
     1420538, /*  6908 ( 171) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  0]  1 */
    34015584, /*  6909 ( 171) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
       16484, /*  6910 ( 172) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
       16482, /*  6911 ( 172) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    52451994, /*  6912 ( 172) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
    51021696, /*  6913 ( 172) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  0] -1 */
    52451996, /*  6914 ( 172) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
     1420536, /*  6915 ( 172) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  0]  1 */
    51021698, /*  6916 ( 172) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  0] -1 */
     1420538, /*  6917 ( 172) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  0]  1 */
       16484, /*  6918 ( 173) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
       16482, /*  6919 ( 173) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    34133684, /*  6920 ( 173) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
     1420536, /*  6921 ( 173) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  0]  1 */
    35563980, /*  6922 ( 173) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6] -1 */
    34133682, /*  6923 ( 173) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
     1420538, /*  6924 ( 173) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  0]  1 */
    35563982, /*  6925 ( 173) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
       16484, /*  6926 ( 174) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    52556970, /*  6927 ( 174) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
       16482, /*  6928 ( 174) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    51152916, /*  6929 ( 174) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6] -1 */
    52556972, /*  6930 ( 174) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
     1420536, /*  6931 ( 174) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  0]  1 */
    51152918, /*  6932 ( 174) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
     1420538, /*  6933 ( 174) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  0]  1 */
       16484, /*  6934 ( 175) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    51139796, /*  6935 ( 175) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
       16482, /*  6936 ( 175) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
     1420536, /*  6937 ( 175) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  0]  1 */
    52570092, /*  6938 ( 175) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
     1420538, /*  6939 ( 175) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  0]  1 */
    51139794, /*  6940 ( 175) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6] -1 */
    52570094, /*  6941 ( 175) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
       16484, /*  6942 ( 164) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
        3362, /*  6943 ( 164) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
     1420536, /*  6944 ( 164) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  0]  1 */
     1433658, /*  6945 ( 164) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  0]  1 */
       16484, /*  6946 ( 165) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34015586, /*  6947 ( 165) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    35432760, /*  6948 ( 165) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  0] -1 */
        3362, /*  6949 ( 165) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    35445882, /*  6950 ( 165) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  0] -1 */
     1420536, /*  6951 ( 165) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  0]  1 */
     1433658, /*  6952 ( 165) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  0]  1 */
    34028708, /*  6953 ( 165) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
       16484, /*  6954 ( 166) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
     1433658, /*  6955 ( 166) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  0]  1 */
    35432760, /*  6956 ( 166) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  0] -1 */
    34015586, /*  6957 ( 166) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
       16484, /*  6958 ( 167) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
        3362, /*  6959 ( 167) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    35445882, /*  6960 ( 167) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  0] -1 */
    35432760, /*  6961 ( 167) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  0] -1 */
       16484, /*  6962 ( 168) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    35445882, /*  6963 ( 168) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  0] -1 */
     1420536, /*  6964 ( 168) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  0]  1 */
    34015586, /*  6965 ( 168) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
       16484, /*  6966 ( 169) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    52451994, /*  6967 ( 169) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
        3362, /*  6968 ( 169) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    51034820, /*  6969 ( 169) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  0] -1 */
    51021698, /*  6970 ( 169) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  0] -1 */
    52438872, /*  6971 ( 169) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
     1420536, /*  6972 ( 169) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  0]  1 */
     1433658, /*  6973 ( 169) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  0]  1 */
       16484, /*  6974 ( 170) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
        3362, /*  6975 ( 170) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34133684, /*  6976 ( 170) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
     1420536, /*  6977 ( 170) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  0]  1 */
    34146806, /*  6978 ( 170) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    35550858, /*  6979 ( 170) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6] -1 */
     1433658, /*  6980 ( 170) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  0]  1 */
    35563980, /*  6981 ( 170) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6] -1 */
       16484, /*  6982 ( 171) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34028706, /*  6983 ( 171) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
        3362, /*  6984 ( 171) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
     1420536, /*  6985 ( 171) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  0]  1 */
    35445884, /*  6986 ( 171) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  0] -1 */
    35432762, /*  6987 ( 171) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  0] -1 */
     1433658, /*  6988 ( 171) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  0]  1 */
    34015584, /*  6989 ( 171) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
       16484, /*  6990 ( 172) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
        3362, /*  6991 ( 172) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    35550860, /*  6992 ( 172) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
    34133682, /*  6993 ( 172) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
    35563982, /*  6994 ( 172) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
     1420536, /*  6995 ( 172) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  0]  1 */
    34146804, /*  6996 ( 172) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
     1433658, /*  6997 ( 172) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  0]  1 */
       16484, /*  6998 ( 173) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
        3362, /*  6999 ( 173) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    51034818, /*  7000 ( 173) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  0] -1 */
     1420536, /*  7001 ( 173) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  0]  1 */
    52438874, /*  7002 ( 173) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
    51021696, /*  7003 ( 173) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  0] -1 */
     1433658, /*  7004 ( 173) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  0]  1 */
    52451996, /*  7005 ( 173) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
       16484, /*  7006 ( 174) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    52556970, /*  7007 ( 174) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
        3362, /*  7008 ( 174) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    51139796, /*  7009 ( 174) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
    52570092, /*  7010 ( 174) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
     1420536, /*  7011 ( 174) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  0]  1 */
    51152918, /*  7012 ( 174) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
     1433658, /*  7013 ( 174) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  0]  1 */
       16484, /*  7014 ( 175) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    51152916, /*  7015 ( 175) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6] -1 */
        3362, /*  7016 ( 175) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
     1420536, /*  7017 ( 175) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  0]  1 */
    52556972, /*  7018 ( 175) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
     1433658, /*  7019 ( 175) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  0]  1 */
    51139794, /*  7020 ( 175) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6] -1 */
    52570094, /*  7021 ( 175) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
       16484, /*  7022 ( 176) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
      134420, /*  7023 ( 176) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6]  1 */
      121460, /*  7024 ( 176) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6]  1 */
        3200, /*  7025 ( 176) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
       16484, /*  7026 ( 177) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
      121460, /*  7027 ( 177) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6]  1 */
        3200, /*  7028 ( 177) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34146644, /*  7029 ( 177) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    34133684, /*  7030 ( 177) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
      134420, /*  7031 ( 177) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6]  1 */
    34028708, /*  7032 ( 177) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    34015424, /*  7033 ( 177) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
       16484, /*  7034 ( 178) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34015424, /*  7035 ( 178) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
      121460, /*  7036 ( 178) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6]  1 */
    34146644, /*  7037 ( 178) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
       16484, /*  7038 ( 179) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34146644, /*  7039 ( 179) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    34133684, /*  7040 ( 179) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
        3200, /*  7041 ( 179) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
       16484, /*  7042 ( 180) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
      121460, /*  7043 ( 180) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6]  1 */
    34133522, /*  7044 ( 180) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    34015586, /*  7045 ( 180) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    34028546, /*  7046 ( 180) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
        3200, /*  7047 ( 180) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34146806, /*  7048 ( 180) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
      134420, /*  7049 ( 180) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6]  1 */
       16484, /*  7050 ( 181) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
      121460, /*  7051 ( 181) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6]  1 */
        3200, /*  7052 ( 181) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    51152756, /*  7053 ( 181) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
    51034820, /*  7054 ( 181) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  0] -1 */
    51139796, /*  7055 ( 181) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
    51021536, /*  7056 ( 181) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  0] -1 */
      134420, /*  7057 ( 181) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6]  1 */
       16484, /*  7058 ( 182) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
      121460, /*  7059 ( 182) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6]  1 */
        3200, /*  7060 ( 182) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    52569932, /*  7061 ( 182) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    52451996, /*  7062 ( 182) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
    52556972, /*  7063 ( 182) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
      134420, /*  7064 ( 182) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6]  1 */
    52438712, /*  7065 ( 182) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
       16484, /*  7066 ( 183) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
      121460, /*  7067 ( 183) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6]  1 */
        3200, /*  7068 ( 183) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    35432762, /*  7069 ( 183) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  0] -1 */
    35563982, /*  7070 ( 183) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
    35445722, /*  7071 ( 183) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  0] -1 */
    35550698, /*  7072 ( 183) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
      134420, /*  7073 ( 183) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6]  1 */
       16484, /*  7074 ( 184) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    52451834, /*  7075 ( 184) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
      121460, /*  7076 ( 184) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6]  1 */
    52556810, /*  7077 ( 184) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
        3200, /*  7078 ( 184) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    52438874, /*  7079 ( 184) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
      134420, /*  7080 ( 184) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6]  1 */
    52570094, /*  7081 ( 184) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
       16484, /*  7082 ( 176) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    17022594, /*  7083 ( 176) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  0]  1 */
    17022434, /*  7084 ( 176) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  0]  1 */
       16320, /*  7085 ( 176) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
       16484, /*  7086 ( 177) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    17022434, /*  7087 ( 177) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  0]  1 */
       16320, /*  7088 ( 177) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    51034818, /*  7089 ( 177) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  0] -1 */
    51034658, /*  7090 ( 177) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  0] -1 */
    17022594, /*  7091 ( 177) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  0]  1 */
    34028708, /*  7092 ( 177) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    34028544, /*  7093 ( 177) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
       16484, /*  7094 ( 178) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34028544, /*  7095 ( 178) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    17022434, /*  7096 ( 178) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  0]  1 */
    51034818, /*  7097 ( 178) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  0] -1 */
       16484, /*  7098 ( 179) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    51034818, /*  7099 ( 179) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  0] -1 */
    51034658, /*  7100 ( 179) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  0] -1 */
       16320, /*  7101 ( 179) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
       16484, /*  7102 ( 180) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    17022434, /*  7103 ( 180) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  0]  1 */
    51034656, /*  7104 ( 180) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  0] -1 */
    34028546, /*  7105 ( 180) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    34028706, /*  7106 ( 180) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
       16320, /*  7107 ( 180) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    51034820, /*  7108 ( 180) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  0] -1 */
    17022594, /*  7109 ( 180) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  0]  1 */
       16484, /*  7110 ( 181) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    17022434, /*  7111 ( 181) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  0]  1 */
       16320, /*  7112 ( 181) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    52451994, /*  7113 ( 181) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
    35445884, /*  7114 ( 181) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  0] -1 */
    52451834, /*  7115 ( 181) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
    35445720, /*  7116 ( 181) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  0] -1 */
    17022594, /*  7117 ( 181) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  0]  1 */
       16484, /*  7118 ( 182) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    17022434, /*  7119 ( 182) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  0]  1 */
       16320, /*  7120 ( 182) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    52570092, /*  7121 ( 182) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    35563982, /*  7122 ( 182) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
    52569932, /*  7123 ( 182) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    17022594, /*  7124 ( 182) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  0]  1 */
    35563818, /*  7125 ( 182) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  6] -1 */
       16484, /*  7126 ( 183) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    17022434, /*  7127 ( 183) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  0]  1 */
       16320, /*  7128 ( 183) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    34146644, /*  7129 ( 183) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    51152918, /*  7130 ( 183) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
    34146804, /*  7131 ( 183) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
    51152754, /*  7132 ( 183) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  6] -1 */
    17022594, /*  7133 ( 183) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  0]  1 */
       16484, /*  7134 ( 184) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    35563980, /*  7135 ( 184) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6] -1 */
    17022434, /*  7136 ( 184) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  0]  1 */
    52569930, /*  7137 ( 184) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
       16320, /*  7138 ( 184) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    35563820, /*  7139 ( 184) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
    17022594, /*  7140 ( 184) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  0]  1 */
    52570094, /*  7141 ( 184) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
       16484, /*  7142 ( 176) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
     1420538, /*  7143 ( 176) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  0]  1 */
     1433658, /*  7144 ( 176) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  0]  1 */
        3360, /*  7145 ( 176) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
       16484, /*  7146 ( 177) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
     1433658, /*  7147 ( 177) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  0]  1 */
        3360, /*  7148 ( 177) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    35432762, /*  7149 ( 177) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  0] -1 */
    35445882, /*  7150 ( 177) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  0] -1 */
     1420538, /*  7151 ( 177) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  0]  1 */
    34028708, /*  7152 ( 177) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    34015584, /*  7153 ( 177) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
       16484, /*  7154 ( 178) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34015584, /*  7155 ( 178) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
     1433658, /*  7156 ( 178) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  0]  1 */
    35432762, /*  7157 ( 178) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  0] -1 */
       16484, /*  7158 ( 179) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    35432762, /*  7159 ( 179) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  0] -1 */
    35445882, /*  7160 ( 179) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  0] -1 */
        3360, /*  7161 ( 179) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
       16484, /*  7162 ( 180) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
     1433658, /*  7163 ( 180) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  0]  1 */
    35432760, /*  7164 ( 180) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  0] -1 */
    34028706, /*  7165 ( 180) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    34015586, /*  7166 ( 180) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
        3360, /*  7167 ( 180) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    35445884, /*  7168 ( 180) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  0] -1 */
     1420538, /*  7169 ( 180) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  0]  1 */
       16484, /*  7170 ( 181) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
     1433658, /*  7171 ( 181) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  0]  1 */
        3360, /*  7172 ( 181) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    35550860, /*  7173 ( 181) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
    34146806, /*  7174 ( 181) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    35563980, /*  7175 ( 181) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6] -1 */
    34133682, /*  7176 ( 181) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
     1420538, /*  7177 ( 181) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  0]  1 */
       16484, /*  7178 ( 182) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
     1433658, /*  7179 ( 182) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  0]  1 */
        3360, /*  7180 ( 182) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    52556972, /*  7181 ( 182) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    51152918, /*  7182 ( 182) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
    52570092, /*  7183 ( 182) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
     1420538, /*  7184 ( 182) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  0]  1 */
    51139794, /*  7185 ( 182) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6] -1 */
       16484, /*  7186 ( 183) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
     1433658, /*  7187 ( 183) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  0]  1 */
        3360, /*  7188 ( 183) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    51034818, /*  7189 ( 183) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  0] -1 */
    52451996, /*  7190 ( 183) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
    51021698, /*  7191 ( 183) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  0] -1 */
    52438872, /*  7192 ( 183) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
     1420538, /*  7193 ( 183) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  0]  1 */
       16484, /*  7194 ( 184) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    51139796, /*  7195 ( 184) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
     1433658, /*  7196 ( 184) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  0]  1 */
    52556970, /*  7197 ( 184) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
        3360, /*  7198 ( 184) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    51152916, /*  7199 ( 184) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6] -1 */
     1420538, /*  7200 ( 184) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  0]  1 */
    52570094, /*  7201 ( 184) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
       16484, /*  7202 ( 185) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    17022434, /*  7203 ( 185) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  0]  1 */
    17009474, /*  7204 ( 185) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  0]  1 */
        3200, /*  7205 ( 185) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
       16484, /*  7206 ( 186) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
        3200, /*  7207 ( 186) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    51021698, /*  7208 ( 186) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  0] -1 */
    17022434, /*  7209 ( 186) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  0]  1 */
    17009474, /*  7210 ( 186) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  0]  1 */
    34015424, /*  7211 ( 186) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    34028708, /*  7212 ( 186) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    51034658, /*  7213 ( 186) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  0] -1 */
       16484, /*  7214 ( 187) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34015424, /*  7215 ( 187) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    17022434, /*  7216 ( 187) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  0]  1 */
    51021698, /*  7217 ( 187) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  0] -1 */
       16484, /*  7218 ( 188) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34015424, /*  7219 ( 188) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    17009474, /*  7220 ( 188) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  0]  1 */
    51034658, /*  7221 ( 188) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  0] -1 */
       16484, /*  7222 ( 189) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    51021698, /*  7223 ( 189) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  0] -1 */
        3200, /*  7224 ( 189) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    51034658, /*  7225 ( 189) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  0] -1 */
       16484, /*  7226 ( 190) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34015586, /*  7227 ( 190) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
        3200, /*  7228 ( 190) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    51034820, /*  7229 ( 190) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  0] -1 */
    17022434, /*  7230 ( 190) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  0]  1 */
    17009474, /*  7231 ( 190) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  0]  1 */
    51021536, /*  7232 ( 190) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  0] -1 */
    34028546, /*  7233 ( 190) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
       16484, /*  7234 ( 191) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    52451834, /*  7235 ( 191) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
        3200, /*  7236 ( 191) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    52438874, /*  7237 ( 191) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
    35432600, /*  7238 ( 191) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  0] -1 */
    17022434, /*  7239 ( 191) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  0]  1 */
    35445884, /*  7240 ( 191) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  0] -1 */
    17009474, /*  7241 ( 191) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  0]  1 */
       16484, /*  7242 ( 192) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34133522, /*  7243 ( 192) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
        3200, /*  7244 ( 192) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    51152756, /*  7245 ( 192) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
    17022434, /*  7246 ( 192) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  0]  1 */
    51139796, /*  7247 ( 192) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
    34146806, /*  7248 ( 192) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    17009474, /*  7249 ( 192) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  0]  1 */
       16484, /*  7250 ( 193) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
        3200, /*  7251 ( 193) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    52569932, /*  7252 ( 193) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    17022434, /*  7253 ( 193) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  0]  1 */
    35563982, /*  7254 ( 193) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
    52556972, /*  7255 ( 193) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    17009474, /*  7256 ( 193) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  0]  1 */
    35550698, /*  7257 ( 193) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
       16484, /*  7258 ( 194) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
        3200, /*  7259 ( 194) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34146644, /*  7260 ( 194) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    17022434, /*  7261 ( 194) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  0]  1 */
    51139634, /*  7262 ( 194) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
    34133684, /*  7263 ( 194) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    17009474, /*  7264 ( 194) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  0]  1 */
    51152918, /*  7265 ( 194) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
       16484, /*  7266 ( 195) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
        3200, /*  7267 ( 195) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    17022434, /*  7268 ( 195) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  0]  1 */
    35432762, /*  7269 ( 195) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  0] -1 */
    52451996, /*  7270 ( 195) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
    35445722, /*  7271 ( 195) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  0] -1 */
    17009474, /*  7272 ( 195) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  0]  1 */
    52438712, /*  7273 ( 195) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
       16484, /*  7274 ( 196) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    52556810, /*  7275 ( 196) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
        3200, /*  7276 ( 196) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    35550860, /*  7277 ( 196) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
    17022434, /*  7278 ( 196) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  0]  1 */
    17009474, /*  7279 ( 196) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  0]  1 */
    52570094, /*  7280 ( 196) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    35563820, /*  7281 ( 196) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
       16484, /*  7282 ( 185) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
     1420538, /*  7283 ( 185) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  0]  1 */
     1433498, /*  7284 ( 185) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  0]  1 */
        3200, /*  7285 ( 185) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
       16484, /*  7286 ( 186) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
        3200, /*  7287 ( 186) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    35445722, /*  7288 ( 186) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  0] -1 */
     1420538, /*  7289 ( 186) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  0]  1 */
     1433498, /*  7290 ( 186) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  0]  1 */
    34015424, /*  7291 ( 186) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    34028708, /*  7292 ( 186) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    35432762, /*  7293 ( 186) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  0] -1 */
       16484, /*  7294 ( 187) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34015424, /*  7295 ( 187) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
     1420538, /*  7296 ( 187) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  0]  1 */
    35445722, /*  7297 ( 187) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  0] -1 */
       16484, /*  7298 ( 188) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34015424, /*  7299 ( 188) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
     1433498, /*  7300 ( 188) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  0]  1 */
    35432762, /*  7301 ( 188) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  0] -1 */
       16484, /*  7302 ( 189) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    35445722, /*  7303 ( 189) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  0] -1 */
        3200, /*  7304 ( 189) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    35432762, /*  7305 ( 189) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  0] -1 */
       16484, /*  7306 ( 190) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34028546, /*  7307 ( 190) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
        3200, /*  7308 ( 190) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    35445884, /*  7309 ( 190) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  0] -1 */
     1420538, /*  7310 ( 190) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  0]  1 */
     1433498, /*  7311 ( 190) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  0]  1 */
    35432600, /*  7312 ( 190) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  0] -1 */
    34015586, /*  7313 ( 190) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
       16484, /*  7314 ( 191) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    52438874, /*  7315 ( 191) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
        3200, /*  7316 ( 191) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    52451834, /*  7317 ( 191) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
    51021536, /*  7318 ( 191) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  0] -1 */
     1420538, /*  7319 ( 191) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  0]  1 */
    51034820, /*  7320 ( 191) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  0] -1 */
     1433498, /*  7321 ( 191) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  0]  1 */
       16484, /*  7322 ( 192) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34133522, /*  7323 ( 192) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
        3200, /*  7324 ( 192) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    35550860, /*  7325 ( 192) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
     1420538, /*  7326 ( 192) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  0]  1 */
    35563820, /*  7327 ( 192) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
    34146806, /*  7328 ( 192) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
     1433498, /*  7329 ( 192) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  0]  1 */
       16484, /*  7330 ( 193) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
        3200, /*  7331 ( 193) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    52556972, /*  7332 ( 193) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
     1420538, /*  7333 ( 193) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  0]  1 */
    51152918, /*  7334 ( 193) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
    52569932, /*  7335 ( 193) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
     1433498, /*  7336 ( 193) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  0]  1 */
    51139634, /*  7337 ( 193) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
       16484, /*  7338 ( 194) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
        3200, /*  7339 ( 194) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34133684, /*  7340 ( 194) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
     1420538, /*  7341 ( 194) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  0]  1 */
    35550698, /*  7342 ( 194) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
    34146644, /*  7343 ( 194) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
     1433498, /*  7344 ( 194) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  0]  1 */
    35563982, /*  7345 ( 194) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
       16484, /*  7346 ( 195) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
        3200, /*  7347 ( 195) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
     1420538, /*  7348 ( 195) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  0]  1 */
    51034658, /*  7349 ( 195) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  0] -1 */
    52451996, /*  7350 ( 195) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
    51021698, /*  7351 ( 195) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  0] -1 */
     1433498, /*  7352 ( 195) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  0]  1 */
    52438712, /*  7353 ( 195) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
       16484, /*  7354 ( 196) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    52556810, /*  7355 ( 196) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
        3200, /*  7356 ( 196) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    51152756, /*  7357 ( 196) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
     1420538, /*  7358 ( 196) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  0]  1 */
     1433498, /*  7359 ( 196) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  0]  1 */
    52570094, /*  7360 ( 196) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    51139796, /*  7361 ( 196) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
       16484, /*  7362 ( 185) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
     1433658, /*  7363 ( 185) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  0]  1 */
     1433498, /*  7364 ( 185) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  0]  1 */
       16320, /*  7365 ( 185) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
       16484, /*  7366 ( 186) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
       16320, /*  7367 ( 186) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    35445722, /*  7368 ( 186) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  0] -1 */
     1433658, /*  7369 ( 186) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  0]  1 */
     1433498, /*  7370 ( 186) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  0]  1 */
    34028544, /*  7371 ( 186) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    34028708, /*  7372 ( 186) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    35445882, /*  7373 ( 186) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  0] -1 */
       16484, /*  7374 ( 187) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34028544, /*  7375 ( 187) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
     1433658, /*  7376 ( 187) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  0]  1 */
    35445722, /*  7377 ( 187) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  0] -1 */
       16484, /*  7378 ( 188) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34028544, /*  7379 ( 188) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
     1433498, /*  7380 ( 188) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  0]  1 */
    35445882, /*  7381 ( 188) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  0] -1 */
       16484, /*  7382 ( 189) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    35445722, /*  7383 ( 189) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  0] -1 */
       16320, /*  7384 ( 189) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    35445882, /*  7385 ( 189) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  0] -1 */
       16484, /*  7386 ( 190) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34028546, /*  7387 ( 190) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
       16320, /*  7388 ( 190) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    35445884, /*  7389 ( 190) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  0] -1 */
     1433658, /*  7390 ( 190) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  0]  1 */
     1433498, /*  7391 ( 190) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  0]  1 */
    35445720, /*  7392 ( 190) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  0] -1 */
    34028706, /*  7393 ( 190) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
       16484, /*  7394 ( 191) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    35563980, /*  7395 ( 191) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6] -1 */
       16320, /*  7396 ( 191) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    35563820, /*  7397 ( 191) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
    34146642, /*  7398 ( 191) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
     1433658, /*  7399 ( 191) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  0]  1 */
    34146806, /*  7400 ( 191) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
     1433498, /*  7401 ( 191) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  0]  1 */
       16484, /*  7402 ( 192) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    51034656, /*  7403 ( 192) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  0] -1 */
       16320, /*  7404 ( 192) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    52451994, /*  7405 ( 192) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
     1433658, /*  7406 ( 192) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  0]  1 */
    52451834, /*  7407 ( 192) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
    51034820, /*  7408 ( 192) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  0] -1 */
     1433498, /*  7409 ( 192) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  0]  1 */
       16484, /*  7410 ( 193) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
       16320, /*  7411 ( 193) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    52570092, /*  7412 ( 193) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
     1433658, /*  7413 ( 193) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  0]  1 */
    51152918, /*  7414 ( 193) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
    52569932, /*  7415 ( 193) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
     1433498, /*  7416 ( 193) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  0]  1 */
    51152754, /*  7417 ( 193) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  6] -1 */
       16484, /*  7418 ( 194) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
       16320, /*  7419 ( 194) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    51034818, /*  7420 ( 194) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  0] -1 */
     1433658, /*  7421 ( 194) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  0]  1 */
    52451832, /*  7422 ( 194) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
    51034658, /*  7423 ( 194) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  0] -1 */
     1433498, /*  7424 ( 194) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  0]  1 */
    52451996, /*  7425 ( 194) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
       16484, /*  7426 ( 195) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
       16320, /*  7427 ( 195) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
     1433658, /*  7428 ( 195) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  0]  1 */
    34146644, /*  7429 ( 195) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    35563982, /*  7430 ( 195) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
    34146804, /*  7431 ( 195) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
     1433498, /*  7432 ( 195) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  0]  1 */
    35563818, /*  7433 ( 195) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  6] -1 */
       16484, /*  7434 ( 196) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    52569930, /*  7435 ( 196) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
       16320, /*  7436 ( 196) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    51152756, /*  7437 ( 196) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
     1433658, /*  7438 ( 196) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  0]  1 */
     1433498, /*  7439 ( 196) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  0]  1 */
    52570094, /*  7440 ( 196) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    51152916, /*  7441 ( 196) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6] -1 */
       16484, /*  7442 ( 185) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
      134420, /*  7443 ( 185) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6]  1 */
      134580, /*  7444 ( 185) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  6]  1 */
       16320, /*  7445 ( 185) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
       16484, /*  7446 ( 186) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
       16320, /*  7447 ( 186) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    34146804, /*  7448 ( 186) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
      134420, /*  7449 ( 186) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6]  1 */
      134580, /*  7450 ( 186) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  6]  1 */
    34028544, /*  7451 ( 186) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    34028708, /*  7452 ( 186) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    34146644, /*  7453 ( 186) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
       16484, /*  7454 ( 187) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34028544, /*  7455 ( 187) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
      134420, /*  7456 ( 187) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6]  1 */
    34146804, /*  7457 ( 187) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
       16484, /*  7458 ( 188) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34028544, /*  7459 ( 188) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
      134580, /*  7460 ( 188) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  6]  1 */
    34146644, /*  7461 ( 188) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
       16484, /*  7462 ( 189) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34146804, /*  7463 ( 189) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
       16320, /*  7464 ( 189) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    34146644, /*  7465 ( 189) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
       16484, /*  7466 ( 190) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34028706, /*  7467 ( 190) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
       16320, /*  7468 ( 190) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    34146806, /*  7469 ( 190) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
      134420, /*  7470 ( 190) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6]  1 */
      134580, /*  7471 ( 190) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  6]  1 */
    34146642, /*  7472 ( 190) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
    34028546, /*  7473 ( 190) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
       16484, /*  7474 ( 191) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    35563820, /*  7475 ( 191) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
       16320, /*  7476 ( 191) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    35563980, /*  7477 ( 191) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6] -1 */
    35445720, /*  7478 ( 191) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  0] -1 */
      134420, /*  7479 ( 191) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6]  1 */
    35445884, /*  7480 ( 191) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  0] -1 */
      134580, /*  7481 ( 191) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  6]  1 */
       16484, /*  7482 ( 192) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    51034656, /*  7483 ( 192) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  0] -1 */
       16320, /*  7484 ( 192) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    51152756, /*  7485 ( 192) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
      134420, /*  7486 ( 192) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6]  1 */
    51152916, /*  7487 ( 192) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6] -1 */
    51034820, /*  7488 ( 192) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  0] -1 */
      134580, /*  7489 ( 192) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  6]  1 */
       16484, /*  7490 ( 193) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
       16320, /*  7491 ( 193) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    52569932, /*  7492 ( 193) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
      134420, /*  7493 ( 193) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6]  1 */
    52451996, /*  7494 ( 193) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
    52570092, /*  7495 ( 193) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
      134580, /*  7496 ( 193) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  6]  1 */
    52451832, /*  7497 ( 193) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
       16484, /*  7498 ( 194) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
       16320, /*  7499 ( 194) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    51034658, /*  7500 ( 194) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  0] -1 */
      134420, /*  7501 ( 194) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6]  1 */
    51152754, /*  7502 ( 194) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  6] -1 */
    51034818, /*  7503 ( 194) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  0] -1 */
      134580, /*  7504 ( 194) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  6]  1 */
    51152918, /*  7505 ( 194) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
       16484, /*  7506 ( 195) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
       16320, /*  7507 ( 195) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
      134420, /*  7508 ( 195) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6]  1 */
    35445882, /*  7509 ( 195) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  0] -1 */
    35563982, /*  7510 ( 195) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
    35445722, /*  7511 ( 195) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  0] -1 */
      134580, /*  7512 ( 195) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  6]  1 */
    35563818, /*  7513 ( 195) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  6] -1 */
       16484, /*  7514 ( 196) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    52569930, /*  7515 ( 196) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
       16320, /*  7516 ( 196) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    52451994, /*  7517 ( 196) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
      134420, /*  7518 ( 196) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6]  1 */
      134580, /*  7519 ( 196) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  6]  1 */
    52570094, /*  7520 ( 196) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    52451834, /*  7521 ( 196) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
       16484, /*  7522 ( 185) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
      121460, /*  7523 ( 185) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6]  1 */
      134580, /*  7524 ( 185) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  6]  1 */
        3360, /*  7525 ( 185) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
       16484, /*  7526 ( 186) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
        3360, /*  7527 ( 186) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    34146804, /*  7528 ( 186) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
      121460, /*  7529 ( 186) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6]  1 */
      134580, /*  7530 ( 186) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  6]  1 */
    34015584, /*  7531 ( 186) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    34028708, /*  7532 ( 186) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    34133684, /*  7533 ( 186) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
       16484, /*  7534 ( 187) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34015584, /*  7535 ( 187) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
      121460, /*  7536 ( 187) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6]  1 */
    34146804, /*  7537 ( 187) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
       16484, /*  7538 ( 188) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34015584, /*  7539 ( 188) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
      134580, /*  7540 ( 188) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  6]  1 */
    34133684, /*  7541 ( 188) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
       16484, /*  7542 ( 189) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34146804, /*  7543 ( 189) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
        3360, /*  7544 ( 189) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    34133684, /*  7545 ( 189) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
       16484, /*  7546 ( 190) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34028706, /*  7547 ( 190) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
        3360, /*  7548 ( 190) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    34146806, /*  7549 ( 190) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
      121460, /*  7550 ( 190) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6]  1 */
      134580, /*  7551 ( 190) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  6]  1 */
    34133682, /*  7552 ( 190) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
    34015586, /*  7553 ( 190) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
       16484, /*  7554 ( 191) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    51139796, /*  7555 ( 191) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
        3360, /*  7556 ( 191) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    51152916, /*  7557 ( 191) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6] -1 */
    51021696, /*  7558 ( 191) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  0] -1 */
      121460, /*  7559 ( 191) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6]  1 */
    51034820, /*  7560 ( 191) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  0] -1 */
      134580, /*  7561 ( 191) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  6]  1 */
       16484, /*  7562 ( 192) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    35432760, /*  7563 ( 192) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  0] -1 */
        3360, /*  7564 ( 192) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    35550860, /*  7565 ( 192) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
      121460, /*  7566 ( 192) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6]  1 */
    35563980, /*  7567 ( 192) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6] -1 */
    35445884, /*  7568 ( 192) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  0] -1 */
      134580, /*  7569 ( 192) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  6]  1 */
       16484, /*  7570 ( 193) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
        3360, /*  7571 ( 193) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    52556972, /*  7572 ( 193) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
      121460, /*  7573 ( 193) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6]  1 */
    52451996, /*  7574 ( 193) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
    52570092, /*  7575 ( 193) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
      134580, /*  7576 ( 193) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  6]  1 */
    52438872, /*  7577 ( 193) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
       16484, /*  7578 ( 194) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
        3360, /*  7579 ( 194) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    35432762, /*  7580 ( 194) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  0] -1 */
      121460, /*  7581 ( 194) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6]  1 */
    35550858, /*  7582 ( 194) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6] -1 */
    35445882, /*  7583 ( 194) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  0] -1 */
      134580, /*  7584 ( 194) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  6]  1 */
    35563982, /*  7585 ( 194) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
       16484, /*  7586 ( 195) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
        3360, /*  7587 ( 195) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
      121460, /*  7588 ( 195) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6]  1 */
    51034818, /*  7589 ( 195) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  0] -1 */
    51152918, /*  7590 ( 195) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
    51021698, /*  7591 ( 195) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  0] -1 */
      134580, /*  7592 ( 195) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  6]  1 */
    51139794, /*  7593 ( 195) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6] -1 */
       16484, /*  7594 ( 196) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    52556970, /*  7595 ( 196) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
        3360, /*  7596 ( 196) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    52451994, /*  7597 ( 196) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
      121460, /*  7598 ( 196) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6]  1 */
      134580, /*  7599 ( 196) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  6]  1 */
    52570094, /*  7600 ( 196) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    52438874, /*  7601 ( 196) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
       16484, /*  7602 ( 185) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    17022594, /*  7603 ( 185) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  0]  1 */
    17009474, /*  7604 ( 185) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  0]  1 */
        3360, /*  7605 ( 185) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
       16484, /*  7606 ( 186) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
        3360, /*  7607 ( 186) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    51021698, /*  7608 ( 186) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  0] -1 */
    17022594, /*  7609 ( 186) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  0]  1 */
    17009474, /*  7610 ( 186) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  0]  1 */
    34015584, /*  7611 ( 186) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    34028708, /*  7612 ( 186) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    51034818, /*  7613 ( 186) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  0] -1 */
       16484, /*  7614 ( 187) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34015584, /*  7615 ( 187) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    17022594, /*  7616 ( 187) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  0]  1 */
    51021698, /*  7617 ( 187) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  0] -1 */
       16484, /*  7618 ( 188) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34015584, /*  7619 ( 188) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    17009474, /*  7620 ( 188) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  0]  1 */
    51034818, /*  7621 ( 188) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  0] -1 */
       16484, /*  7622 ( 189) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    51021698, /*  7623 ( 189) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  0] -1 */
        3360, /*  7624 ( 189) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    51034818, /*  7625 ( 189) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  0] -1 */
       16484, /*  7626 ( 190) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34015586, /*  7627 ( 190) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
        3360, /*  7628 ( 190) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    51034820, /*  7629 ( 190) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  0] -1 */
    17022594, /*  7630 ( 190) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  0]  1 */
    17009474, /*  7631 ( 190) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  0]  1 */
    51021696, /*  7632 ( 190) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  0] -1 */
    34028706, /*  7633 ( 190) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
       16484, /*  7634 ( 191) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    51152916, /*  7635 ( 191) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6] -1 */
        3360, /*  7636 ( 191) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    51139796, /*  7637 ( 191) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
    34133682, /*  7638 ( 191) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
    17022594, /*  7639 ( 191) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  0]  1 */
    34146806, /*  7640 ( 191) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    17009474, /*  7641 ( 191) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  0]  1 */
       16484, /*  7642 ( 192) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    35432760, /*  7643 ( 192) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  0] -1 */
        3360, /*  7644 ( 192) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    52451994, /*  7645 ( 192) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
    17022594, /*  7646 ( 192) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  0]  1 */
    52438874, /*  7647 ( 192) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
    35445884, /*  7648 ( 192) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  0] -1 */
    17009474, /*  7649 ( 192) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  0]  1 */
       16484, /*  7650 ( 193) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
        3360, /*  7651 ( 193) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    52570092, /*  7652 ( 193) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    17022594, /*  7653 ( 193) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  0]  1 */
    35563982, /*  7654 ( 193) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
    52556972, /*  7655 ( 193) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    17009474, /*  7656 ( 193) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  0]  1 */
    35550858, /*  7657 ( 193) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6] -1 */
       16484, /*  7658 ( 194) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
        3360, /*  7659 ( 194) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    35445882, /*  7660 ( 194) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  0] -1 */
    17022594, /*  7661 ( 194) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  0]  1 */
    52438872, /*  7662 ( 194) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
    35432762, /*  7663 ( 194) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  0] -1 */
    17009474, /*  7664 ( 194) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  0]  1 */
    52451996, /*  7665 ( 194) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
       16484, /*  7666 ( 195) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
        3360, /*  7667 ( 195) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    17022594, /*  7668 ( 195) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  0]  1 */
    34133684, /*  7669 ( 195) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    51152918, /*  7670 ( 195) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
    34146804, /*  7671 ( 195) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
    17009474, /*  7672 ( 195) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  0]  1 */
    51139794, /*  7673 ( 195) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6] -1 */
       16484, /*  7674 ( 196) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    52556970, /*  7675 ( 196) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
        3360, /*  7676 ( 196) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    35550860, /*  7677 ( 196) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
    17022594, /*  7678 ( 196) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  0]  1 */
    17009474, /*  7679 ( 196) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  0]  1 */
    52570094, /*  7680 ( 196) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    35563980, /*  7681 ( 196) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6] -1 */
       16484, /*  7682 ( 197) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
      121298, /*  7683 ( 197) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6]  1 */
    17022434, /*  7684 ( 197) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  0]  1 */
    17127572, /*  7685 ( 197) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
       16484, /*  7686 ( 198) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34133522, /*  7687 ( 198) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    51034658, /*  7688 ( 198) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  0] -1 */
    17022434, /*  7689 ( 198) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  0]  1 */
      121298, /*  7690 ( 198) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6]  1 */
    51139796, /*  7691 ( 198) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
    34028708, /*  7692 ( 198) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    17127572, /*  7693 ( 198) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
       16484, /*  7694 ( 199) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    51139796, /*  7695 ( 199) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
    34133522, /*  7696 ( 199) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    17022434, /*  7697 ( 199) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  0]  1 */
       16484, /*  7698 ( 200) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34133522, /*  7699 ( 200) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    51034658, /*  7700 ( 200) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  0] -1 */
    17127572, /*  7701 ( 200) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
       16484, /*  7702 ( 201) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    51139796, /*  7703 ( 201) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
      121298, /*  7704 ( 201) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6]  1 */
    51034658, /*  7705 ( 201) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  0] -1 */
       16484, /*  7706 ( 202) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    51034820, /*  7707 ( 202) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  0] -1 */
    17022434, /*  7708 ( 202) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  0]  1 */
    51139634, /*  7709 ( 202) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
      121298, /*  7710 ( 202) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6]  1 */
    34133684, /*  7711 ( 202) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    34028546, /*  7712 ( 202) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    17127572, /*  7713 ( 202) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
       16484, /*  7714 ( 203) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    52451834, /*  7715 ( 203) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
    17022434, /*  7716 ( 203) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  0]  1 */
      121298, /*  7717 ( 203) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6]  1 */
    35445884, /*  7718 ( 203) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  0] -1 */
    52556972, /*  7719 ( 203) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    35550698, /*  7720 ( 203) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
    17127572, /*  7721 ( 203) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
       16484, /*  7722 ( 204) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    51152756, /*  7723 ( 204) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
    51021698, /*  7724 ( 204) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  0] -1 */
    17022434, /*  7725 ( 204) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  0]  1 */
      121298, /*  7726 ( 204) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6]  1 */
    34146806, /*  7727 ( 204) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    34015424, /*  7728 ( 204) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    17127572, /*  7729 ( 204) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
       16484, /*  7730 ( 205) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    52438874, /*  7731 ( 205) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
    52569932, /*  7732 ( 205) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    35432600, /*  7733 ( 205) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  0] -1 */
    17022434, /*  7734 ( 205) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  0]  1 */
    35563982, /*  7735 ( 205) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
      121298, /*  7736 ( 205) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6]  1 */
    17127572, /*  7737 ( 205) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
       16484, /*  7738 ( 206) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34015586, /*  7739 ( 206) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    34146644, /*  7740 ( 206) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    17022434, /*  7741 ( 206) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  0]  1 */
      121298, /*  7742 ( 206) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6]  1 */
    51021536, /*  7743 ( 206) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  0] -1 */
    51152918, /*  7744 ( 206) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
    17127572, /*  7745 ( 206) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
       16484, /*  7746 ( 207) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    52556810, /*  7747 ( 207) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    35550860, /*  7748 ( 207) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
    17022434, /*  7749 ( 207) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  0]  1 */
      121298, /*  7750 ( 207) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6]  1 */
    52451996, /*  7751 ( 207) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
    35445722, /*  7752 ( 207) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  0] -1 */
    17127572, /*  7753 ( 207) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
       16484, /*  7754 ( 208) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    17022434, /*  7755 ( 208) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  0]  1 */
    35432762, /*  7756 ( 208) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  0] -1 */
      121298, /*  7757 ( 208) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6]  1 */
    52438712, /*  7758 ( 208) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
    52570094, /*  7759 ( 208) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    35563820, /*  7760 ( 208) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
    17127572, /*  7761 ( 208) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
       16484, /*  7762 ( 197) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
      121298, /*  7763 ( 197) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6]  1 */
     1420538, /*  7764 ( 197) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  0]  1 */
     1551596, /*  7765 ( 197) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
       16484, /*  7766 ( 198) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34133522, /*  7767 ( 198) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    35432762, /*  7768 ( 198) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  0] -1 */
     1420538, /*  7769 ( 198) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  0]  1 */
      121298, /*  7770 ( 198) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6]  1 */
    35563820, /*  7771 ( 198) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
    34028708, /*  7772 ( 198) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
     1551596, /*  7773 ( 198) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
       16484, /*  7774 ( 199) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    35563820, /*  7775 ( 199) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
    34133522, /*  7776 ( 199) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
     1420538, /*  7777 ( 199) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  0]  1 */
       16484, /*  7778 ( 200) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34133522, /*  7779 ( 200) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    35432762, /*  7780 ( 200) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  0] -1 */
     1551596, /*  7781 ( 200) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
       16484, /*  7782 ( 201) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    35563820, /*  7783 ( 201) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
      121298, /*  7784 ( 201) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6]  1 */
    35432762, /*  7785 ( 201) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  0] -1 */
       16484, /*  7786 ( 202) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    35445884, /*  7787 ( 202) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  0] -1 */
     1420538, /*  7788 ( 202) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  0]  1 */
    35550698, /*  7789 ( 202) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
      121298, /*  7790 ( 202) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6]  1 */
    34146644, /*  7791 ( 202) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    34015586, /*  7792 ( 202) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
     1551596, /*  7793 ( 202) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
       16484, /*  7794 ( 203) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    52438874, /*  7795 ( 203) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
     1420538, /*  7796 ( 203) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  0]  1 */
      121298, /*  7797 ( 203) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6]  1 */
    51034820, /*  7798 ( 203) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  0] -1 */
    52569932, /*  7799 ( 203) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    51139634, /*  7800 ( 203) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
     1551596, /*  7801 ( 203) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
       16484, /*  7802 ( 204) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    35550860, /*  7803 ( 204) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
    35445722, /*  7804 ( 204) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  0] -1 */
     1420538, /*  7805 ( 204) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  0]  1 */
      121298, /*  7806 ( 204) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6]  1 */
    34146806, /*  7807 ( 204) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    34015424, /*  7808 ( 204) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
     1551596, /*  7809 ( 204) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
       16484, /*  7810 ( 205) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    52451834, /*  7811 ( 205) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
    52556972, /*  7812 ( 205) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    51021536, /*  7813 ( 205) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  0] -1 */
     1420538, /*  7814 ( 205) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  0]  1 */
    51152918, /*  7815 ( 205) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
      121298, /*  7816 ( 205) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6]  1 */
     1551596, /*  7817 ( 205) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
       16484, /*  7818 ( 206) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34028546, /*  7819 ( 206) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    34133684, /*  7820 ( 206) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
     1420538, /*  7821 ( 206) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  0]  1 */
      121298, /*  7822 ( 206) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6]  1 */
    35432600, /*  7823 ( 206) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  0] -1 */
    35563982, /*  7824 ( 206) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
     1551596, /*  7825 ( 206) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
       16484, /*  7826 ( 207) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    52556810, /*  7827 ( 207) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    51152756, /*  7828 ( 207) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
     1420538, /*  7829 ( 207) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  0]  1 */
      121298, /*  7830 ( 207) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6]  1 */
    52451996, /*  7831 ( 207) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
    51021698, /*  7832 ( 207) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  0] -1 */
     1551596, /*  7833 ( 207) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
       16484, /*  7834 ( 208) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
     1420538, /*  7835 ( 208) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  0]  1 */
    51034658, /*  7836 ( 208) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  0] -1 */
      121298, /*  7837 ( 208) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6]  1 */
    52438712, /*  7838 ( 208) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
    52570094, /*  7839 ( 208) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    51139796, /*  7840 ( 208) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
     1551596, /*  7841 ( 208) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
       16484, /*  7842 ( 197) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    17022432, /*  7843 ( 197) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  0]  1 */
     1433658, /*  7844 ( 197) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  0]  1 */
    18439610, /*  7845 ( 197) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
       16484, /*  7846 ( 198) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    51034656, /*  7847 ( 198) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  0] -1 */
    35445882, /*  7848 ( 198) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  0] -1 */
     1433658, /*  7849 ( 198) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  0]  1 */
    17022432, /*  7850 ( 198) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  0]  1 */
    52451834, /*  7851 ( 198) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
    34028708, /*  7852 ( 198) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    18439610, /*  7853 ( 198) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
       16484, /*  7854 ( 199) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    52451834, /*  7855 ( 199) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
    51034656, /*  7856 ( 199) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  0] -1 */
     1433658, /*  7857 ( 199) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  0]  1 */
       16484, /*  7858 ( 200) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    51034656, /*  7859 ( 200) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  0] -1 */
    35445882, /*  7860 ( 200) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  0] -1 */
    18439610, /*  7861 ( 200) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
       16484, /*  7862 ( 201) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    52451834, /*  7863 ( 201) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
    17022432, /*  7864 ( 201) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  0]  1 */
    35445882, /*  7865 ( 201) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  0] -1 */
       16484, /*  7866 ( 202) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    35445884, /*  7867 ( 202) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  0] -1 */
     1433658, /*  7868 ( 202) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  0]  1 */
    52451832, /*  7869 ( 202) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
    17022432, /*  7870 ( 202) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  0]  1 */
    51034658, /*  7871 ( 202) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  0] -1 */
    34028706, /*  7872 ( 202) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    18439610, /*  7873 ( 202) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
       16484, /*  7874 ( 203) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    35563980, /*  7875 ( 203) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6] -1 */
     1433658, /*  7876 ( 203) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  0]  1 */
    17022432, /*  7877 ( 203) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  0]  1 */
    34146806, /*  7878 ( 203) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    52569932, /*  7879 ( 203) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    51152754, /*  7880 ( 203) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  6] -1 */
    18439610, /*  7881 ( 203) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
       16484, /*  7882 ( 204) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    52451994, /*  7883 ( 204) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
    35445722, /*  7884 ( 204) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  0] -1 */
     1433658, /*  7885 ( 204) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  0]  1 */
    17022432, /*  7886 ( 204) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  0]  1 */
    51034820, /*  7887 ( 204) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  0] -1 */
    34028544, /*  7888 ( 204) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    18439610, /*  7889 ( 204) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
       16484, /*  7890 ( 205) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    35563820, /*  7891 ( 205) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
    52570092, /*  7892 ( 205) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    34146642, /*  7893 ( 205) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
     1433658, /*  7894 ( 205) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  0]  1 */
    51152918, /*  7895 ( 205) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
    17022432, /*  7896 ( 205) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  0]  1 */
    18439610, /*  7897 ( 205) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
       16484, /*  7898 ( 206) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34028546, /*  7899 ( 206) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    51034818, /*  7900 ( 206) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  0] -1 */
     1433658, /*  7901 ( 206) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  0]  1 */
    17022432, /*  7902 ( 206) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  0]  1 */
    35445720, /*  7903 ( 206) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  0] -1 */
    52451996, /*  7904 ( 206) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
    18439610, /*  7905 ( 206) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
       16484, /*  7906 ( 207) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    52569930, /*  7907 ( 207) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    51152756, /*  7908 ( 207) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
     1433658, /*  7909 ( 207) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  0]  1 */
    17022432, /*  7910 ( 207) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  0]  1 */
    35563982, /*  7911 ( 207) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
    34146804, /*  7912 ( 207) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
    18439610, /*  7913 ( 207) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
       16484, /*  7914 ( 208) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
     1433658, /*  7915 ( 208) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  0]  1 */
    34146644, /*  7916 ( 208) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    17022432, /*  7917 ( 208) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  0]  1 */
    35563818, /*  7918 ( 208) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  6] -1 */
    52570094, /*  7919 ( 208) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    51152916, /*  7920 ( 208) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6] -1 */
    18439610, /*  7921 ( 208) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
       16484, /*  7922 ( 197) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    17022432, /*  7923 ( 197) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  0]  1 */
      134420, /*  7924 ( 197) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6]  1 */
    17140692, /*  7925 ( 197) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6]  1 */
       16484, /*  7926 ( 198) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    51034656, /*  7927 ( 198) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  0] -1 */
    34146644, /*  7928 ( 198) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
      134420, /*  7929 ( 198) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6]  1 */
    17022432, /*  7930 ( 198) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  0]  1 */
    51152916, /*  7931 ( 198) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6] -1 */
    34028708, /*  7932 ( 198) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    17140692, /*  7933 ( 198) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6]  1 */
       16484, /*  7934 ( 199) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    51152916, /*  7935 ( 199) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6] -1 */
    51034656, /*  7936 ( 199) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  0] -1 */
      134420, /*  7937 ( 199) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6]  1 */
       16484, /*  7938 ( 200) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    51034656, /*  7939 ( 200) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  0] -1 */
    34146644, /*  7940 ( 200) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    17140692, /*  7941 ( 200) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6]  1 */
       16484, /*  7942 ( 201) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    51152916, /*  7943 ( 201) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6] -1 */
    17022432, /*  7944 ( 201) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  0]  1 */
    34146644, /*  7945 ( 201) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
       16484, /*  7946 ( 202) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34146806, /*  7947 ( 202) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
      134420, /*  7948 ( 202) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6]  1 */
    51152754, /*  7949 ( 202) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  6] -1 */
    17022432, /*  7950 ( 202) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  0]  1 */
    51034818, /*  7951 ( 202) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  0] -1 */
    34028546, /*  7952 ( 202) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    17140692, /*  7953 ( 202) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6]  1 */
       16484, /*  7954 ( 203) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    35563820, /*  7955 ( 203) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
      134420, /*  7956 ( 203) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6]  1 */
    17022432, /*  7957 ( 203) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  0]  1 */
    35445884, /*  7958 ( 203) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  0] -1 */
    52570092, /*  7959 ( 203) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    52451832, /*  7960 ( 203) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
    17140692, /*  7961 ( 203) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6]  1 */
       16484, /*  7962 ( 204) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    51152756, /*  7963 ( 204) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
    34146804, /*  7964 ( 204) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
      134420, /*  7965 ( 204) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6]  1 */
    17022432, /*  7966 ( 204) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  0]  1 */
    51034820, /*  7967 ( 204) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  0] -1 */
    34028544, /*  7968 ( 204) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    17140692, /*  7969 ( 204) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6]  1 */
       16484, /*  7970 ( 205) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    35563980, /*  7971 ( 205) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6] -1 */
    52569932, /*  7972 ( 205) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    35445720, /*  7973 ( 205) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  0] -1 */
      134420, /*  7974 ( 205) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6]  1 */
    52451996, /*  7975 ( 205) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
    17022432, /*  7976 ( 205) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  0]  1 */
    17140692, /*  7977 ( 205) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6]  1 */
       16484, /*  7978 ( 206) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34028706, /*  7979 ( 206) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    51034658, /*  7980 ( 206) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  0] -1 */
      134420, /*  7981 ( 206) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6]  1 */
    17022432, /*  7982 ( 206) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  0]  1 */
    34146642, /*  7983 ( 206) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
    51152918, /*  7984 ( 206) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
    17140692, /*  7985 ( 206) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6]  1 */
       16484, /*  7986 ( 207) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    52569930, /*  7987 ( 207) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    52451994, /*  7988 ( 207) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
      134420, /*  7989 ( 207) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6]  1 */
    17022432, /*  7990 ( 207) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  0]  1 */
    35563982, /*  7991 ( 207) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
    35445722, /*  7992 ( 207) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  0] -1 */
    17140692, /*  7993 ( 207) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6]  1 */
       16484, /*  7994 ( 208) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
      134420, /*  7995 ( 208) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6]  1 */
    35445882, /*  7996 ( 208) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  0] -1 */
    17022432, /*  7997 ( 208) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  0]  1 */
    35563818, /*  7998 ( 208) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  6] -1 */
    52570094, /*  7999 ( 208) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    52451834, /*  8000 ( 208) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
    17140692, /*  8001 ( 208) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6]  1 */
       16484, /*  8002 ( 197) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
     1420536, /*  8003 ( 197) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  0]  1 */
      121460, /*  8004 ( 197) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6]  1 */
     1551756, /*  8005 ( 197) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
       16484, /*  8006 ( 198) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    35432760, /*  8007 ( 198) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  0] -1 */
    34133684, /*  8008 ( 198) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
      121460, /*  8009 ( 198) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6]  1 */
     1420536, /*  8010 ( 198) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  0]  1 */
    35563980, /*  8011 ( 198) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6] -1 */
    34028708, /*  8012 ( 198) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
     1551756, /*  8013 ( 198) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
       16484, /*  8014 ( 199) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    35563980, /*  8015 ( 199) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6] -1 */
    35432760, /*  8016 ( 199) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  0] -1 */
      121460, /*  8017 ( 199) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6]  1 */
       16484, /*  8018 ( 200) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    35432760, /*  8019 ( 200) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  0] -1 */
    34133684, /*  8020 ( 200) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
     1551756, /*  8021 ( 200) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
       16484, /*  8022 ( 201) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    35563980, /*  8023 ( 201) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6] -1 */
     1420536, /*  8024 ( 201) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  0]  1 */
    34133684, /*  8025 ( 201) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
       16484, /*  8026 ( 202) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34146806, /*  8027 ( 202) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
      121460, /*  8028 ( 202) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6]  1 */
    35550858, /*  8029 ( 202) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6] -1 */
     1420536, /*  8030 ( 202) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  0]  1 */
    35445882, /*  8031 ( 202) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  0] -1 */
    34015586, /*  8032 ( 202) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
     1551756, /*  8033 ( 202) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
       16484, /*  8034 ( 203) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    51139796, /*  8035 ( 203) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
      121460, /*  8036 ( 203) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6]  1 */
     1420536, /*  8037 ( 203) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  0]  1 */
    51034820, /*  8038 ( 203) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  0] -1 */
    52570092, /*  8039 ( 203) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    52438872, /*  8040 ( 203) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
     1551756, /*  8041 ( 203) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
       16484, /*  8042 ( 204) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    35550860, /*  8043 ( 204) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
    34146804, /*  8044 ( 204) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
      121460, /*  8045 ( 204) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6]  1 */
     1420536, /*  8046 ( 204) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  0]  1 */
    35445884, /*  8047 ( 204) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  0] -1 */
    34015584, /*  8048 ( 204) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
     1551756, /*  8049 ( 204) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
       16484, /*  8050 ( 205) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    51152916, /*  8051 ( 205) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6] -1 */
    52556972, /*  8052 ( 205) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    51021696, /*  8053 ( 205) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  0] -1 */
      121460, /*  8054 ( 205) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6]  1 */
    52451996, /*  8055 ( 205) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
     1420536, /*  8056 ( 205) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  0]  1 */
     1551756, /*  8057 ( 205) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
       16484, /*  8058 ( 206) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34028706, /*  8059 ( 206) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    35432762, /*  8060 ( 206) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  0] -1 */
      121460, /*  8061 ( 206) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6]  1 */
     1420536, /*  8062 ( 206) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  0]  1 */
    34133682, /*  8063 ( 206) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
    35563982, /*  8064 ( 206) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
     1551756, /*  8065 ( 206) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
       16484, /*  8066 ( 207) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    52556970, /*  8067 ( 207) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    52451994, /*  8068 ( 207) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
      121460, /*  8069 ( 207) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6]  1 */
     1420536, /*  8070 ( 207) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  0]  1 */
    51152918, /*  8071 ( 207) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
    51021698, /*  8072 ( 207) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  0] -1 */
     1551756, /*  8073 ( 207) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
       16484, /*  8074 ( 208) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
      121460, /*  8075 ( 208) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6]  1 */
    51034818, /*  8076 ( 208) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  0] -1 */
     1420536, /*  8077 ( 208) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  0]  1 */
    51139794, /*  8078 ( 208) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6] -1 */
    52570094, /*  8079 ( 208) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    52438874, /*  8080 ( 208) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
     1551756, /*  8081 ( 208) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
       16484, /*  8082 ( 197) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
     1420536, /*  8083 ( 197) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  0]  1 */
    17022594, /*  8084 ( 197) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  0]  1 */
    18426650, /*  8085 ( 197) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
       16484, /*  8086 ( 198) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    35432760, /*  8087 ( 198) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  0] -1 */
    51034818, /*  8088 ( 198) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  0] -1 */
    17022594, /*  8089 ( 198) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  0]  1 */
     1420536, /*  8090 ( 198) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  0]  1 */
    52438874, /*  8091 ( 198) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
    34028708, /*  8092 ( 198) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    18426650, /*  8093 ( 198) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
       16484, /*  8094 ( 199) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    52438874, /*  8095 ( 199) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
    35432760, /*  8096 ( 199) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  0] -1 */
    17022594, /*  8097 ( 199) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  0]  1 */
       16484, /*  8098 ( 200) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    35432760, /*  8099 ( 200) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  0] -1 */
    51034818, /*  8100 ( 200) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  0] -1 */
    18426650, /*  8101 ( 200) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
       16484, /*  8102 ( 201) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    52438874, /*  8103 ( 201) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
     1420536, /*  8104 ( 201) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  0]  1 */
    51034818, /*  8105 ( 201) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  0] -1 */
       16484, /*  8106 ( 202) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    51034820, /*  8107 ( 202) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  0] -1 */
    17022594, /*  8108 ( 202) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  0]  1 */
    52438872, /*  8109 ( 202) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
     1420536, /*  8110 ( 202) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  0]  1 */
    35432762, /*  8111 ( 202) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  0] -1 */
    34028706, /*  8112 ( 202) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    18426650, /*  8113 ( 202) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
       16484, /*  8114 ( 203) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    51152916, /*  8115 ( 203) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6] -1 */
    17022594, /*  8116 ( 203) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  0]  1 */
     1420536, /*  8117 ( 203) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  0]  1 */
    34146806, /*  8118 ( 203) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    52556972, /*  8119 ( 203) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    35550858, /*  8120 ( 203) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6] -1 */
    18426650, /*  8121 ( 203) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
       16484, /*  8122 ( 204) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    52451994, /*  8123 ( 204) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
    51021698, /*  8124 ( 204) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  0] -1 */
    17022594, /*  8125 ( 204) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  0]  1 */
     1420536, /*  8126 ( 204) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  0]  1 */
    35445884, /*  8127 ( 204) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  0] -1 */
    34015584, /*  8128 ( 204) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    18426650, /*  8129 ( 204) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
       16484, /*  8130 ( 205) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    51139796, /*  8131 ( 205) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
    52570092, /*  8132 ( 205) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    34133682, /*  8133 ( 205) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
    17022594, /*  8134 ( 205) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  0]  1 */
    35563982, /*  8135 ( 205) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
     1420536, /*  8136 ( 205) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  0]  1 */
    18426650, /*  8137 ( 205) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
       16484, /*  8138 ( 206) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34015586, /*  8139 ( 206) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    35445882, /*  8140 ( 206) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  0] -1 */
    17022594, /*  8141 ( 206) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  0]  1 */
     1420536, /*  8142 ( 206) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  0]  1 */
    51021696, /*  8143 ( 206) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  0] -1 */
    52451996, /*  8144 ( 206) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
    18426650, /*  8145 ( 206) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
       16484, /*  8146 ( 207) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    52556970, /*  8147 ( 207) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    35550860, /*  8148 ( 207) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
    17022594, /*  8149 ( 207) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  0]  1 */
     1420536, /*  8150 ( 207) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  0]  1 */
    51152918, /*  8151 ( 207) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
    34146804, /*  8152 ( 207) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
    18426650, /*  8153 ( 207) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
       16484, /*  8154 ( 208) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    17022594, /*  8155 ( 208) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  0]  1 */
    34133684, /*  8156 ( 208) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
     1420536, /*  8157 ( 208) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  0]  1 */
    51139794, /*  8158 ( 208) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6] -1 */
    52570094, /*  8159 ( 208) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    35563980, /*  8160 ( 208) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6] -1 */
    18426650, /*  8161 ( 208) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
       16484, /*  8162 ( 209) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
     1551596, /*  8163 ( 209) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
        3200, /*  8164 ( 209) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
     1538636, /*  8165 ( 209) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
       16484, /*  8166 ( 210) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
        3200, /*  8167 ( 210) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    35550860, /*  8168 ( 210) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
     1551596, /*  8169 ( 210) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
     1538636, /*  8170 ( 210) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
    34015424, /*  8171 ( 210) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    34028708, /*  8172 ( 210) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    35563820, /*  8173 ( 210) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
       16484, /*  8174 ( 211) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34015424, /*  8175 ( 211) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
     1551596, /*  8176 ( 211) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
    35550860, /*  8177 ( 211) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
       16484, /*  8178 ( 212) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34015424, /*  8179 ( 212) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    35563820, /*  8180 ( 212) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
     1538636, /*  8181 ( 212) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
       16484, /*  8182 ( 213) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    35550860, /*  8183 ( 213) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
    35563820, /*  8184 ( 213) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
        3200, /*  8185 ( 213) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
       16484, /*  8186 ( 214) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
        3200, /*  8187 ( 214) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    51034820, /*  8188 ( 214) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  0] -1 */
    52569932, /*  8189 ( 214) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
     1551596, /*  8190 ( 214) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
     1538636, /*  8191 ( 214) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
    52556972, /*  8192 ( 214) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    51021536, /*  8193 ( 214) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  0] -1 */
       16484, /*  8194 ( 215) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
        3200, /*  8195 ( 215) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34146644, /*  8196 ( 215) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
     1551596, /*  8197 ( 215) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
    35432600, /*  8198 ( 215) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  0] -1 */
     1538636, /*  8199 ( 215) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
    34133684, /*  8200 ( 215) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    35445884, /*  8201 ( 215) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  0] -1 */
       16484, /*  8202 ( 216) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34133522, /*  8203 ( 216) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
        3200, /*  8204 ( 216) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
     1551596, /*  8205 ( 216) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
    35432762, /*  8206 ( 216) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  0] -1 */
     1538636, /*  8207 ( 216) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
    35445722, /*  8208 ( 216) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  0] -1 */
    34146806, /*  8209 ( 216) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
       16484, /*  8210 ( 217) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34015586, /*  8211 ( 217) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
        3200, /*  8212 ( 217) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
     1551596, /*  8213 ( 217) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
    35563982, /*  8214 ( 217) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
     1538636, /*  8215 ( 217) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
    35550698, /*  8216 ( 217) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
    34028546, /*  8217 ( 217) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
       16484, /*  8218 ( 218) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    52451834, /*  8219 ( 218) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
        3200, /*  8220 ( 218) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    52438874, /*  8221 ( 218) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
     1551596, /*  8222 ( 218) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
    51139634, /*  8223 ( 218) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
     1538636, /*  8224 ( 218) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
    51152918, /*  8225 ( 218) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
       16484, /*  8226 ( 219) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
        3200, /*  8227 ( 219) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    51152756, /*  8228 ( 219) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
     1551596, /*  8229 ( 219) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
     1538636, /*  8230 ( 219) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
    52451996, /*  8231 ( 219) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
    51139796, /*  8232 ( 219) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
    52438712, /*  8233 ( 219) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
       16484, /*  8234 ( 220) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    52556810, /*  8235 ( 220) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
        3200, /*  8236 ( 220) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    51021698, /*  8237 ( 220) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  0] -1 */
     1551596, /*  8238 ( 220) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
     1538636, /*  8239 ( 220) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
    52570094, /*  8240 ( 220) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    51034658, /*  8241 ( 220) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  0] -1 */
       16484, /*  8242 ( 209) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    17127572, /*  8243 ( 209) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
        3200, /*  8244 ( 209) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    17140532, /*  8245 ( 209) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
       16484, /*  8246 ( 210) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
        3200, /*  8247 ( 210) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    51152756, /*  8248 ( 210) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
    17127572, /*  8249 ( 210) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
    17140532, /*  8250 ( 210) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
    34015424, /*  8251 ( 210) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    34028708, /*  8252 ( 210) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    51139796, /*  8253 ( 210) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
       16484, /*  8254 ( 211) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34015424, /*  8255 ( 211) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    17127572, /*  8256 ( 211) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
    51152756, /*  8257 ( 211) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
       16484, /*  8258 ( 212) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34015424, /*  8259 ( 212) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    51139796, /*  8260 ( 212) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
    17140532, /*  8261 ( 212) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
       16484, /*  8262 ( 213) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    51152756, /*  8263 ( 213) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
    51139796, /*  8264 ( 213) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
        3200, /*  8265 ( 213) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
       16484, /*  8266 ( 214) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
        3200, /*  8267 ( 214) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    35445884, /*  8268 ( 214) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  0] -1 */
    52556972, /*  8269 ( 214) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    17127572, /*  8270 ( 214) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
    17140532, /*  8271 ( 214) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
    52569932, /*  8272 ( 214) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    35432600, /*  8273 ( 214) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  0] -1 */
       16484, /*  8274 ( 215) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
        3200, /*  8275 ( 215) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34133684, /*  8276 ( 215) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    17127572, /*  8277 ( 215) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
    51021536, /*  8278 ( 215) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  0] -1 */
    17140532, /*  8279 ( 215) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
    34146644, /*  8280 ( 215) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    51034820, /*  8281 ( 215) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  0] -1 */
       16484, /*  8282 ( 216) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34133522, /*  8283 ( 216) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
        3200, /*  8284 ( 216) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    17127572, /*  8285 ( 216) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
    51034658, /*  8286 ( 216) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  0] -1 */
    17140532, /*  8287 ( 216) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
    51021698, /*  8288 ( 216) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  0] -1 */
    34146806, /*  8289 ( 216) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
       16484, /*  8290 ( 217) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34028546, /*  8291 ( 217) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
        3200, /*  8292 ( 217) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    17127572, /*  8293 ( 217) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
    51152918, /*  8294 ( 217) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
    17140532, /*  8295 ( 217) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
    51139634, /*  8296 ( 217) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
    34015586, /*  8297 ( 217) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
       16484, /*  8298 ( 218) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    52438874, /*  8299 ( 218) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
        3200, /*  8300 ( 218) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    52451834, /*  8301 ( 218) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
    17127572, /*  8302 ( 218) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
    35550698, /*  8303 ( 218) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
    17140532, /*  8304 ( 218) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
    35563982, /*  8305 ( 218) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
       16484, /*  8306 ( 219) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
        3200, /*  8307 ( 219) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    35550860, /*  8308 ( 219) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
    17127572, /*  8309 ( 219) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
    17140532, /*  8310 ( 219) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
    52451996, /*  8311 ( 219) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
    35563820, /*  8312 ( 219) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
    52438712, /*  8313 ( 219) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
       16484, /*  8314 ( 220) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    52556810, /*  8315 ( 220) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
        3200, /*  8316 ( 220) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    35445722, /*  8317 ( 220) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  0] -1 */
    17127572, /*  8318 ( 220) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
    17140532, /*  8319 ( 220) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
    52570094, /*  8320 ( 220) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    35432762, /*  8321 ( 220) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  0] -1 */
       16484, /*  8322 ( 209) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    17140692, /*  8323 ( 209) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6]  1 */
       16320, /*  8324 ( 209) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    17140532, /*  8325 ( 209) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
       16484, /*  8326 ( 210) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
       16320, /*  8327 ( 210) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    51152756, /*  8328 ( 210) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
    17140692, /*  8329 ( 210) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6]  1 */
    17140532, /*  8330 ( 210) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
    34028544, /*  8331 ( 210) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    34028708, /*  8332 ( 210) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    51152916, /*  8333 ( 210) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6] -1 */
       16484, /*  8334 ( 211) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34028544, /*  8335 ( 211) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    17140692, /*  8336 ( 211) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6]  1 */
    51152756, /*  8337 ( 211) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
       16484, /*  8338 ( 212) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34028544, /*  8339 ( 212) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    51152916, /*  8340 ( 212) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6] -1 */
    17140532, /*  8341 ( 212) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
       16484, /*  8342 ( 213) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    51152756, /*  8343 ( 213) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
    51152916, /*  8344 ( 213) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6] -1 */
       16320, /*  8345 ( 213) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
       16484, /*  8346 ( 214) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
       16320, /*  8347 ( 214) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    35445884, /*  8348 ( 214) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  0] -1 */
    52570092, /*  8349 ( 214) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    17140692, /*  8350 ( 214) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6]  1 */
    17140532, /*  8351 ( 214) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
    52569932, /*  8352 ( 214) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    35445720, /*  8353 ( 214) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  0] -1 */
       16484, /*  8354 ( 215) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
       16320, /*  8355 ( 215) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    51034818, /*  8356 ( 215) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  0] -1 */
    17140692, /*  8357 ( 215) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6]  1 */
    34146642, /*  8358 ( 215) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
    17140532, /*  8359 ( 215) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
    51034658, /*  8360 ( 215) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  0] -1 */
    34146806, /*  8361 ( 215) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
       16484, /*  8362 ( 216) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    51034656, /*  8363 ( 216) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  0] -1 */
       16320, /*  8364 ( 216) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    17140692, /*  8365 ( 216) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6]  1 */
    34146644, /*  8366 ( 216) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    17140532, /*  8367 ( 216) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
    34146804, /*  8368 ( 216) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
    51034820, /*  8369 ( 216) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  0] -1 */
       16484, /*  8370 ( 217) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34028546, /*  8371 ( 217) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
       16320, /*  8372 ( 217) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    17140692, /*  8373 ( 217) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6]  1 */
    51152918, /*  8374 ( 217) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
    17140532, /*  8375 ( 217) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
    51152754, /*  8376 ( 217) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  6] -1 */
    34028706, /*  8377 ( 217) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
       16484, /*  8378 ( 218) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    35563980, /*  8379 ( 218) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6] -1 */
       16320, /*  8380 ( 218) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    35563820, /*  8381 ( 218) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
    17140692, /*  8382 ( 218) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6]  1 */
    52451832, /*  8383 ( 218) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
    17140532, /*  8384 ( 218) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
    52451996, /*  8385 ( 218) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
       16484, /*  8386 ( 219) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
       16320, /*  8387 ( 219) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    52451994, /*  8388 ( 219) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
    17140692, /*  8389 ( 219) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6]  1 */
    17140532, /*  8390 ( 219) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
    35563982, /*  8391 ( 219) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
    52451834, /*  8392 ( 219) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
    35563818, /*  8393 ( 219) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  6] -1 */
       16484, /*  8394 ( 220) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    52569930, /*  8395 ( 220) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
       16320, /*  8396 ( 220) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    35445722, /*  8397 ( 220) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  0] -1 */
    17140692, /*  8398 ( 220) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6]  1 */
    17140532, /*  8399 ( 220) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
    52570094, /*  8400 ( 220) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    35445882, /*  8401 ( 220) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  0] -1 */
       16484, /*  8402 ( 209) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    18439610, /*  8403 ( 209) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
       16320, /*  8404 ( 209) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    18439770, /*  8405 ( 209) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
       16484, /*  8406 ( 210) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
       16320, /*  8407 ( 210) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    52451994, /*  8408 ( 210) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
    18439610, /*  8409 ( 210) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    18439770, /*  8410 ( 210) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
    34028544, /*  8411 ( 210) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    34028708, /*  8412 ( 210) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    52451834, /*  8413 ( 210) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
       16484, /*  8414 ( 211) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34028544, /*  8415 ( 211) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    18439610, /*  8416 ( 211) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    52451994, /*  8417 ( 211) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
       16484, /*  8418 ( 212) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34028544, /*  8419 ( 212) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    52451834, /*  8420 ( 212) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
    18439770, /*  8421 ( 212) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
       16484, /*  8422 ( 213) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    52451994, /*  8423 ( 213) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
    52451834, /*  8424 ( 213) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
       16320, /*  8425 ( 213) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
       16484, /*  8426 ( 214) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
       16320, /*  8427 ( 214) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    34146806, /*  8428 ( 214) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    52569932, /*  8429 ( 214) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    18439610, /*  8430 ( 214) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    18439770, /*  8431 ( 214) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
    52570092, /*  8432 ( 214) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    34146642, /*  8433 ( 214) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
       16484, /*  8434 ( 215) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
       16320, /*  8435 ( 215) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    51034658, /*  8436 ( 215) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  0] -1 */
    18439610, /*  8437 ( 215) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    35445720, /*  8438 ( 215) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  0] -1 */
    18439770, /*  8439 ( 215) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
    51034818, /*  8440 ( 215) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  0] -1 */
    35445884, /*  8441 ( 215) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  0] -1 */
       16484, /*  8442 ( 216) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    51034656, /*  8443 ( 216) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  0] -1 */
       16320, /*  8444 ( 216) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    18439610, /*  8445 ( 216) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    35445882, /*  8446 ( 216) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  0] -1 */
    18439770, /*  8447 ( 216) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
    35445722, /*  8448 ( 216) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  0] -1 */
    51034820, /*  8449 ( 216) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  0] -1 */
       16484, /*  8450 ( 217) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34028706, /*  8451 ( 217) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
       16320, /*  8452 ( 217) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    18439610, /*  8453 ( 217) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    52451996, /*  8454 ( 217) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
    18439770, /*  8455 ( 217) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
    52451832, /*  8456 ( 217) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
    34028546, /*  8457 ( 217) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
       16484, /*  8458 ( 218) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    35563820, /*  8459 ( 218) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
       16320, /*  8460 ( 218) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    35563980, /*  8461 ( 218) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6] -1 */
    18439610, /*  8462 ( 218) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    51152754, /*  8463 ( 218) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  6] -1 */
    18439770, /*  8464 ( 218) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
    51152918, /*  8465 ( 218) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
       16484, /*  8466 ( 219) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
       16320, /*  8467 ( 219) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    51152756, /*  8468 ( 219) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
    18439610, /*  8469 ( 219) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    18439770, /*  8470 ( 219) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
    35563982, /*  8471 ( 219) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
    51152916, /*  8472 ( 219) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6] -1 */
    35563818, /*  8473 ( 219) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  6] -1 */
       16484, /*  8474 ( 220) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    52569930, /*  8475 ( 220) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
       16320, /*  8476 ( 220) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    34146804, /*  8477 ( 220) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
    18439610, /*  8478 ( 220) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    18439770, /*  8479 ( 220) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
    52570094, /*  8480 ( 220) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    34146644, /*  8481 ( 220) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
       16484, /*  8482 ( 209) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    18426650, /*  8483 ( 209) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
        3360, /*  8484 ( 209) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    18439770, /*  8485 ( 209) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
       16484, /*  8486 ( 210) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
        3360, /*  8487 ( 210) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    52451994, /*  8488 ( 210) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
    18426650, /*  8489 ( 210) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    18439770, /*  8490 ( 210) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
    34015584, /*  8491 ( 210) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    34028708, /*  8492 ( 210) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    52438874, /*  8493 ( 210) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
       16484, /*  8494 ( 211) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34015584, /*  8495 ( 211) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    18426650, /*  8496 ( 211) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    52451994, /*  8497 ( 211) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
       16484, /*  8498 ( 212) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34015584, /*  8499 ( 212) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    52438874, /*  8500 ( 212) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
    18439770, /*  8501 ( 212) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
       16484, /*  8502 ( 213) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    52451994, /*  8503 ( 213) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
    52438874, /*  8504 ( 213) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
        3360, /*  8505 ( 213) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
       16484, /*  8506 ( 214) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
        3360, /*  8507 ( 214) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    34146806, /*  8508 ( 214) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    52556972, /*  8509 ( 214) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    18426650, /*  8510 ( 214) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    18439770, /*  8511 ( 214) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
    52570092, /*  8512 ( 214) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    34133682, /*  8513 ( 214) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
       16484, /*  8514 ( 215) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
        3360, /*  8515 ( 215) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    35432762, /*  8516 ( 215) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  0] -1 */
    18426650, /*  8517 ( 215) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    51021696, /*  8518 ( 215) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  0] -1 */
    18439770, /*  8519 ( 215) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
    35445882, /*  8520 ( 215) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  0] -1 */
    51034820, /*  8521 ( 215) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  0] -1 */
       16484, /*  8522 ( 216) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    35432760, /*  8523 ( 216) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  0] -1 */
        3360, /*  8524 ( 216) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    18426650, /*  8525 ( 216) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    51034818, /*  8526 ( 216) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  0] -1 */
    18439770, /*  8527 ( 216) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
    51021698, /*  8528 ( 216) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  0] -1 */
    35445884, /*  8529 ( 216) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  0] -1 */
       16484, /*  8530 ( 217) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34028706, /*  8531 ( 217) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
        3360, /*  8532 ( 217) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    18426650, /*  8533 ( 217) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    52451996, /*  8534 ( 217) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
    18439770, /*  8535 ( 217) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
    52438872, /*  8536 ( 217) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
    34015586, /*  8537 ( 217) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
       16484, /*  8538 ( 218) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    51139796, /*  8539 ( 218) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
        3360, /*  8540 ( 218) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    51152916, /*  8541 ( 218) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6] -1 */
    18426650, /*  8542 ( 218) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    35550858, /*  8543 ( 218) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6] -1 */
    18439770, /*  8544 ( 218) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
    35563982, /*  8545 ( 218) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
       16484, /*  8546 ( 219) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
        3360, /*  8547 ( 219) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    35550860, /*  8548 ( 219) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
    18426650, /*  8549 ( 219) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    18439770, /*  8550 ( 219) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
    51152918, /*  8551 ( 219) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
    35563980, /*  8552 ( 219) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6] -1 */
    51139794, /*  8553 ( 219) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6] -1 */
       16484, /*  8554 ( 220) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    52556970, /*  8555 ( 220) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
        3360, /*  8556 ( 220) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    34146804, /*  8557 ( 220) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
    18426650, /*  8558 ( 220) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    18439770, /*  8559 ( 220) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
    52570094, /*  8560 ( 220) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    34133684, /*  8561 ( 220) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
       16484, /*  8562 ( 209) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
     1551756, /*  8563 ( 209) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
        3360, /*  8564 ( 209) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
     1538636, /*  8565 ( 209) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
       16484, /*  8566 ( 210) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
        3360, /*  8567 ( 210) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    35550860, /*  8568 ( 210) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
     1551756, /*  8569 ( 210) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
     1538636, /*  8570 ( 210) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
    34015584, /*  8571 ( 210) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    34028708, /*  8572 ( 210) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    35563980, /*  8573 ( 210) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6] -1 */
       16484, /*  8574 ( 211) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34015584, /*  8575 ( 211) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
     1551756, /*  8576 ( 211) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
    35550860, /*  8577 ( 211) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
       16484, /*  8578 ( 212) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34015584, /*  8579 ( 212) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    35563980, /*  8580 ( 212) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6] -1 */
     1538636, /*  8581 ( 212) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
       16484, /*  8582 ( 213) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    35550860, /*  8583 ( 213) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
    35563980, /*  8584 ( 213) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6] -1 */
        3360, /*  8585 ( 213) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
       16484, /*  8586 ( 214) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
        3360, /*  8587 ( 214) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    51034820, /*  8588 ( 214) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  0] -1 */
    52570092, /*  8589 ( 214) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
     1551756, /*  8590 ( 214) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
     1538636, /*  8591 ( 214) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
    52556972, /*  8592 ( 214) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    51021696, /*  8593 ( 214) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  0] -1 */
       16484, /*  8594 ( 215) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
        3360, /*  8595 ( 215) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    35445882, /*  8596 ( 215) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  0] -1 */
     1551756, /*  8597 ( 215) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
    34133682, /*  8598 ( 215) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
     1538636, /*  8599 ( 215) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
    35432762, /*  8600 ( 215) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  0] -1 */
    34146806, /*  8601 ( 215) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
       16484, /*  8602 ( 216) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    35432760, /*  8603 ( 216) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  0] -1 */
        3360, /*  8604 ( 216) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
     1551756, /*  8605 ( 216) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
    34133684, /*  8606 ( 216) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
     1538636, /*  8607 ( 216) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
    34146804, /*  8608 ( 216) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
    35445884, /*  8609 ( 216) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  0] -1 */
       16484, /*  8610 ( 217) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34015586, /*  8611 ( 217) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
        3360, /*  8612 ( 217) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
     1551756, /*  8613 ( 217) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
    35563982, /*  8614 ( 217) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
     1538636, /*  8615 ( 217) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
    35550858, /*  8616 ( 217) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6] -1 */
    34028706, /*  8617 ( 217) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
       16484, /*  8618 ( 218) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    51152916, /*  8619 ( 218) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6] -1 */
        3360, /*  8620 ( 218) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    51139796, /*  8621 ( 218) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
     1551756, /*  8622 ( 218) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
    52438872, /*  8623 ( 218) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
     1538636, /*  8624 ( 218) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
    52451996, /*  8625 ( 218) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
       16484, /*  8626 ( 219) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
        3360, /*  8627 ( 219) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    52451994, /*  8628 ( 219) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
     1551756, /*  8629 ( 219) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
     1538636, /*  8630 ( 219) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
    51152918, /*  8631 ( 219) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
    52438874, /*  8632 ( 219) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
    51139794, /*  8633 ( 219) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6] -1 */
       16484, /*  8634 ( 220) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    52556970, /*  8635 ( 220) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
        3360, /*  8636 ( 220) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    51021698, /*  8637 ( 220) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  0] -1 */
     1551756, /*  8638 ( 220) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
     1538636, /*  8639 ( 220) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
    52570094, /*  8640 ( 220) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    51034818, /*  8641 ( 220) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  0] -1 */
       16484, /*  8642 ( 221) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
        3362, /*  8643 ( 221) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    17140532, /*  8644 ( 221) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
    17127410, /*  8645 ( 221) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
       16484, /*  8646 ( 222) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34015586, /*  8647 ( 222) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    51152756, /*  8648 ( 222) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
        3362, /*  8649 ( 222) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    51139634, /*  8650 ( 222) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
    17140532, /*  8651 ( 222) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
    17127410, /*  8652 ( 222) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
    34028708, /*  8653 ( 222) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
       16484, /*  8654 ( 223) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34015586, /*  8655 ( 223) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    17140532, /*  8656 ( 223) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
    51139634, /*  8657 ( 223) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
       16484, /*  8658 ( 224) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
        3362, /*  8659 ( 224) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    51139634, /*  8660 ( 224) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
    51152756, /*  8661 ( 224) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
       16484, /*  8662 ( 225) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34015586, /*  8663 ( 225) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    17127410, /*  8664 ( 225) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
    51152756, /*  8665 ( 225) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
       16484, /*  8666 ( 226) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34133522, /*  8667 ( 226) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
        3362, /*  8668 ( 226) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    51034820, /*  8669 ( 226) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  0] -1 */
    51021698, /*  8670 ( 226) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  0] -1 */
    34146644, /*  8671 ( 226) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    17140532, /*  8672 ( 226) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
    17127410, /*  8673 ( 226) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
       16484, /*  8674 ( 227) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    52556810, /*  8675 ( 227) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
        3362, /*  8676 ( 227) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    52569932, /*  8677 ( 227) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    35432762, /*  8678 ( 227) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  0] -1 */
    17140532, /*  8679 ( 227) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
    35445884, /*  8680 ( 227) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  0] -1 */
    17127410, /*  8681 ( 227) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
       16484, /*  8682 ( 228) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
        3362, /*  8683 ( 228) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34146806, /*  8684 ( 228) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    17140532, /*  8685 ( 228) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
    17127410, /*  8686 ( 228) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
    51021536, /*  8687 ( 228) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  0] -1 */
    34133684, /*  8688 ( 228) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    51034658, /*  8689 ( 228) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  0] -1 */
       16484, /*  8690 ( 229) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    52451834, /*  8691 ( 229) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
        3362, /*  8692 ( 229) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    35550860, /*  8693 ( 229) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
    35563982, /*  8694 ( 229) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
    17140532, /*  8695 ( 229) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
    17127410, /*  8696 ( 229) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
    52438712, /*  8697 ( 229) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
       16484, /*  8698 ( 230) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34028546, /*  8699 ( 230) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
        3362, /*  8700 ( 230) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    51139796, /*  8701 ( 230) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
    17140532, /*  8702 ( 230) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
    17127410, /*  8703 ( 230) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
    51152918, /*  8704 ( 230) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
    34015424, /*  8705 ( 230) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
       16484, /*  8706 ( 231) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
        3362, /*  8707 ( 231) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    52438874, /*  8708 ( 231) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
    52451996, /*  8709 ( 231) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
    17140532, /*  8710 ( 231) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
    17127410, /*  8711 ( 231) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
    35550698, /*  8712 ( 231) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
    35563820, /*  8713 ( 231) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
       16484, /*  8714 ( 232) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
        3362, /*  8715 ( 232) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    35432600, /*  8716 ( 232) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  0] -1 */
    35445722, /*  8717 ( 232) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  0] -1 */
    17140532, /*  8718 ( 232) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
    17127410, /*  8719 ( 232) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
    52556972, /*  8720 ( 232) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    52570094, /*  8721 ( 232) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
       16484, /*  8722 ( 221) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
       16322, /*  8723 ( 221) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
     1538636, /*  8724 ( 221) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
     1538474, /*  8725 ( 221) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
       16484, /*  8726 ( 222) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34028546, /*  8727 ( 222) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    35550860, /*  8728 ( 222) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
       16322, /*  8729 ( 222) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    35550698, /*  8730 ( 222) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
     1538636, /*  8731 ( 222) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
     1538474, /*  8732 ( 222) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
    34028708, /*  8733 ( 222) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
       16484, /*  8734 ( 223) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34028546, /*  8735 ( 223) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
     1538636, /*  8736 ( 223) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
    35550698, /*  8737 ( 223) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
       16484, /*  8738 ( 224) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
       16322, /*  8739 ( 224) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    35550698, /*  8740 ( 224) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
    35550860, /*  8741 ( 224) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
       16484, /*  8742 ( 225) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34028546, /*  8743 ( 225) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
     1538474, /*  8744 ( 225) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
    35550860, /*  8745 ( 225) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
       16484, /*  8746 ( 226) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34133522, /*  8747 ( 226) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
       16322, /*  8748 ( 226) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    35445884, /*  8749 ( 226) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  0] -1 */
    35445722, /*  8750 ( 226) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  0] -1 */
    34133684, /*  8751 ( 226) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
     1538636, /*  8752 ( 226) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
     1538474, /*  8753 ( 226) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
       16484, /*  8754 ( 227) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    52556810, /*  8755 ( 227) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
       16322, /*  8756 ( 227) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    52556972, /*  8757 ( 227) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    51034658, /*  8758 ( 227) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  0] -1 */
     1538636, /*  8759 ( 227) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
    51034820, /*  8760 ( 227) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  0] -1 */
     1538474, /*  8761 ( 227) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
       16484, /*  8762 ( 228) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
       16322, /*  8763 ( 228) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34146806, /*  8764 ( 228) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
     1538636, /*  8765 ( 228) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
     1538474, /*  8766 ( 228) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
    35432600, /*  8767 ( 228) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  0] -1 */
    34146644, /*  8768 ( 228) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    35432762, /*  8769 ( 228) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  0] -1 */
       16484, /*  8770 ( 229) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    52438874, /*  8771 ( 229) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
       16322, /*  8772 ( 229) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    51152756, /*  8773 ( 229) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
    51152918, /*  8774 ( 229) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
     1538636, /*  8775 ( 229) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
     1538474, /*  8776 ( 229) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
    52438712, /*  8777 ( 229) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
       16484, /*  8778 ( 230) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34015586, /*  8779 ( 230) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
       16322, /*  8780 ( 230) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    35563820, /*  8781 ( 230) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
     1538636, /*  8782 ( 230) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
     1538474, /*  8783 ( 230) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
    35563982, /*  8784 ( 230) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
    34015424, /*  8785 ( 230) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
       16484, /*  8786 ( 231) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
       16322, /*  8787 ( 231) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    52451834, /*  8788 ( 231) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
    52451996, /*  8789 ( 231) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
     1538636, /*  8790 ( 231) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
     1538474, /*  8791 ( 231) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
    51139634, /*  8792 ( 231) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
    51139796, /*  8793 ( 231) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
       16484, /*  8794 ( 232) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
       16322, /*  8795 ( 232) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    51021536, /*  8796 ( 232) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  0] -1 */
    51021698, /*  8797 ( 232) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  0] -1 */
     1538636, /*  8798 ( 232) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
     1538474, /*  8799 ( 232) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
    52569932, /*  8800 ( 232) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    52570094, /*  8801 ( 232) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
       16484, /*  8802 ( 221) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
       16322, /*  8803 ( 221) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    18439770, /*  8804 ( 221) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
    18439608, /*  8805 ( 221) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
       16484, /*  8806 ( 222) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34028546, /*  8807 ( 222) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    52451994, /*  8808 ( 222) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
       16322, /*  8809 ( 222) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    52451832, /*  8810 ( 222) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
    18439770, /*  8811 ( 222) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
    18439608, /*  8812 ( 222) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
    34028708, /*  8813 ( 222) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
       16484, /*  8814 ( 223) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34028546, /*  8815 ( 223) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    18439770, /*  8816 ( 223) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
    52451832, /*  8817 ( 223) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
       16484, /*  8818 ( 224) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
       16322, /*  8819 ( 224) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    52451832, /*  8820 ( 224) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
    52451994, /*  8821 ( 224) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
       16484, /*  8822 ( 225) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34028546, /*  8823 ( 225) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    18439608, /*  8824 ( 225) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
    52451994, /*  8825 ( 225) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
       16484, /*  8826 ( 226) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    51034656, /*  8827 ( 226) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  0] -1 */
       16322, /*  8828 ( 226) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    35445884, /*  8829 ( 226) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  0] -1 */
    35445722, /*  8830 ( 226) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  0] -1 */
    51034818, /*  8831 ( 226) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  0] -1 */
    18439770, /*  8832 ( 226) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
    18439608, /*  8833 ( 226) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
       16484, /*  8834 ( 227) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    52569930, /*  8835 ( 227) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
       16322, /*  8836 ( 227) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    52570092, /*  8837 ( 227) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    34146644, /*  8838 ( 227) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    18439770, /*  8839 ( 227) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
    34146806, /*  8840 ( 227) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    18439608, /*  8841 ( 227) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
       16484, /*  8842 ( 228) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
       16322, /*  8843 ( 228) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    51034820, /*  8844 ( 228) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  0] -1 */
    18439770, /*  8845 ( 228) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
    18439608, /*  8846 ( 228) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
    35445720, /*  8847 ( 228) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  0] -1 */
    51034658, /*  8848 ( 228) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  0] -1 */
    35445882, /*  8849 ( 228) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  0] -1 */
       16484, /*  8850 ( 229) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    35563980, /*  8851 ( 229) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6] -1 */
       16322, /*  8852 ( 229) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    51152756, /*  8853 ( 229) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
    51152918, /*  8854 ( 229) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
    18439770, /*  8855 ( 229) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
    18439608, /*  8856 ( 229) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
    35563818, /*  8857 ( 229) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  6] -1 */
       16484, /*  8858 ( 230) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34028706, /*  8859 ( 230) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
       16322, /*  8860 ( 230) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    52451834, /*  8861 ( 230) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
    18439770, /*  8862 ( 230) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
    18439608, /*  8863 ( 230) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
    52451996, /*  8864 ( 230) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
    34028544, /*  8865 ( 230) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
       16484, /*  8866 ( 231) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
       16322, /*  8867 ( 231) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    35563820, /*  8868 ( 231) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
    35563982, /*  8869 ( 231) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
    18439770, /*  8870 ( 231) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
    18439608, /*  8871 ( 231) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
    51152754, /*  8872 ( 231) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  6] -1 */
    51152916, /*  8873 ( 231) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6] -1 */
       16484, /*  8874 ( 232) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
       16322, /*  8875 ( 232) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34146642, /*  8876 ( 232) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
    34146804, /*  8877 ( 232) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
    18439770, /*  8878 ( 232) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
    18439608, /*  8879 ( 232) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
    52569932, /*  8880 ( 232) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    52570094, /*  8881 ( 232) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
       16484, /*  8882 ( 221) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
       16482, /*  8883 ( 221) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    17140532, /*  8884 ( 221) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
    17140530, /*  8885 ( 221) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  6]  1 */
       16484, /*  8886 ( 222) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34028706, /*  8887 ( 222) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    51152756, /*  8888 ( 222) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
       16482, /*  8889 ( 222) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    51152754, /*  8890 ( 222) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  6] -1 */
    17140532, /*  8891 ( 222) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
    17140530, /*  8892 ( 222) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  6]  1 */
    34028708, /*  8893 ( 222) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
       16484, /*  8894 ( 223) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34028706, /*  8895 ( 223) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    17140532, /*  8896 ( 223) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
    51152754, /*  8897 ( 223) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  6] -1 */
       16484, /*  8898 ( 224) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
       16482, /*  8899 ( 224) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    51152754, /*  8900 ( 224) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  6] -1 */
    51152756, /*  8901 ( 224) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
       16484, /*  8902 ( 225) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34028706, /*  8903 ( 225) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    17140530, /*  8904 ( 225) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  6]  1 */
    51152756, /*  8905 ( 225) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
       16484, /*  8906 ( 226) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    51034656, /*  8907 ( 226) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  0] -1 */
       16482, /*  8908 ( 226) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    34146806, /*  8909 ( 226) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    34146804, /*  8910 ( 226) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
    51034658, /*  8911 ( 226) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  0] -1 */
    17140532, /*  8912 ( 226) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
    17140530, /*  8913 ( 226) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  6]  1 */
       16484, /*  8914 ( 227) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    52569930, /*  8915 ( 227) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
       16482, /*  8916 ( 227) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    52569932, /*  8917 ( 227) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    35445882, /*  8918 ( 227) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  0] -1 */
    17140532, /*  8919 ( 227) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
    35445884, /*  8920 ( 227) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  0] -1 */
    17140530, /*  8921 ( 227) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  6]  1 */
       16484, /*  8922 ( 228) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
       16482, /*  8923 ( 228) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    51034820, /*  8924 ( 228) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  0] -1 */
    17140532, /*  8925 ( 228) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
    17140530, /*  8926 ( 228) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  6]  1 */
    34146642, /*  8927 ( 228) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
    51034818, /*  8928 ( 228) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  0] -1 */
    34146644, /*  8929 ( 228) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
       16484, /*  8930 ( 229) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    35563820, /*  8931 ( 229) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
       16482, /*  8932 ( 229) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    52451994, /*  8933 ( 229) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
    52451996, /*  8934 ( 229) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
    17140532, /*  8935 ( 229) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
    17140530, /*  8936 ( 229) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  6]  1 */
    35563818, /*  8937 ( 229) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  6] -1 */
       16484, /*  8938 ( 230) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34028546, /*  8939 ( 230) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
       16482, /*  8940 ( 230) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    51152916, /*  8941 ( 230) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6] -1 */
    17140532, /*  8942 ( 230) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
    17140530, /*  8943 ( 230) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  6]  1 */
    51152918, /*  8944 ( 230) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
    34028544, /*  8945 ( 230) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
       16484, /*  8946 ( 231) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
       16482, /*  8947 ( 231) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    35563980, /*  8948 ( 231) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6] -1 */
    35563982, /*  8949 ( 231) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
    17140532, /*  8950 ( 231) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
    17140530, /*  8951 ( 231) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  6]  1 */
    52451832, /*  8952 ( 231) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
    52451834, /*  8953 ( 231) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
       16484, /*  8954 ( 232) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
       16482, /*  8955 ( 232) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    35445720, /*  8956 ( 232) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  0] -1 */
    35445722, /*  8957 ( 232) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  0] -1 */
    17140532, /*  8958 ( 232) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
    17140530, /*  8959 ( 232) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  6]  1 */
    52570092, /*  8960 ( 232) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    52570094, /*  8961 ( 232) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
       16484, /*  8962 ( 221) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
       16482, /*  8963 ( 221) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
     1538636, /*  8964 ( 221) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
     1538634, /*  8965 ( 221) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
       16484, /*  8966 ( 222) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34028706, /*  8967 ( 222) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    35550860, /*  8968 ( 222) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
       16482, /*  8969 ( 222) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    35550858, /*  8970 ( 222) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6] -1 */
     1538636, /*  8971 ( 222) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
     1538634, /*  8972 ( 222) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
    34028708, /*  8973 ( 222) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
       16484, /*  8974 ( 223) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34028706, /*  8975 ( 223) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
     1538636, /*  8976 ( 223) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
    35550858, /*  8977 ( 223) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6] -1 */
       16484, /*  8978 ( 224) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
       16482, /*  8979 ( 224) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    35550858, /*  8980 ( 224) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6] -1 */
    35550860, /*  8981 ( 224) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
       16484, /*  8982 ( 225) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34028706, /*  8983 ( 225) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
     1538634, /*  8984 ( 225) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
    35550860, /*  8985 ( 225) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
       16484, /*  8986 ( 226) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    35432760, /*  8987 ( 226) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  0] -1 */
       16482, /*  8988 ( 226) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    34146806, /*  8989 ( 226) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    34146804, /*  8990 ( 226) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
    35432762, /*  8991 ( 226) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  0] -1 */
     1538636, /*  8992 ( 226) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
     1538634, /*  8993 ( 226) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
       16484, /*  8994 ( 227) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    52556970, /*  8995 ( 227) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
       16482, /*  8996 ( 227) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    52556972, /*  8997 ( 227) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    51034818, /*  8998 ( 227) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  0] -1 */
     1538636, /*  8999 ( 227) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
    51034820, /*  9000 ( 227) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  0] -1 */
     1538634, /*  9001 ( 227) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
       16484, /*  9002 ( 228) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
       16482, /*  9003 ( 228) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    35445884, /*  9004 ( 228) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  0] -1 */
     1538636, /*  9005 ( 228) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
     1538634, /*  9006 ( 228) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
    34133682, /*  9007 ( 228) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
    35445882, /*  9008 ( 228) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  0] -1 */
    34133684, /*  9009 ( 228) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
       16484, /*  9010 ( 229) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    51139796, /*  9011 ( 229) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
       16482, /*  9012 ( 229) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    52451994, /*  9013 ( 229) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
    52451996, /*  9014 ( 229) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
     1538636, /*  9015 ( 229) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
     1538634, /*  9016 ( 229) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
    51139794, /*  9017 ( 229) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6] -1 */
       16484, /*  9018 ( 230) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34015586, /*  9019 ( 230) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
       16482, /*  9020 ( 230) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    35563980, /*  9021 ( 230) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6] -1 */
     1538636, /*  9022 ( 230) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
     1538634, /*  9023 ( 230) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
    35563982, /*  9024 ( 230) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
    34015584, /*  9025 ( 230) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
       16484, /*  9026 ( 231) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
       16482, /*  9027 ( 231) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    51152916, /*  9028 ( 231) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6] -1 */
    51152918, /*  9029 ( 231) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
     1538636, /*  9030 ( 231) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
     1538634, /*  9031 ( 231) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
    52438872, /*  9032 ( 231) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
    52438874, /*  9033 ( 231) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
       16484, /*  9034 ( 232) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
       16482, /*  9035 ( 232) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    51021696, /*  9036 ( 232) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  0] -1 */
    51021698, /*  9037 ( 232) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  0] -1 */
     1538636, /*  9038 ( 232) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
     1538634, /*  9039 ( 232) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
    52570092, /*  9040 ( 232) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    52570094, /*  9041 ( 232) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
       16484, /*  9042 ( 221) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
        3362, /*  9043 ( 221) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    18439770, /*  9044 ( 221) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
    18426648, /*  9045 ( 221) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
       16484, /*  9046 ( 222) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34015586, /*  9047 ( 222) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    52451994, /*  9048 ( 222) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
        3362, /*  9049 ( 222) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    52438872, /*  9050 ( 222) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
    18439770, /*  9051 ( 222) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
    18426648, /*  9052 ( 222) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
    34028708, /*  9053 ( 222) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
       16484, /*  9054 ( 223) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34015586, /*  9055 ( 223) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    18439770, /*  9056 ( 223) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
    52438872, /*  9057 ( 223) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
       16484, /*  9058 ( 224) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
        3362, /*  9059 ( 224) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    52438872, /*  9060 ( 224) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
    52451994, /*  9061 ( 224) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
       16484, /*  9062 ( 225) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34015586, /*  9063 ( 225) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    18426648, /*  9064 ( 225) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
    52451994, /*  9065 ( 225) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
       16484, /*  9066 ( 226) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    35432760, /*  9067 ( 226) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  0] -1 */
        3362, /*  9068 ( 226) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    51034820, /*  9069 ( 226) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  0] -1 */
    51021698, /*  9070 ( 226) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  0] -1 */
    35445882, /*  9071 ( 226) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  0] -1 */
    18439770, /*  9072 ( 226) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
    18426648, /*  9073 ( 226) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
       16484, /*  9074 ( 227) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    52556970, /*  9075 ( 227) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
        3362, /*  9076 ( 227) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    52570092, /*  9077 ( 227) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    34133684, /*  9078 ( 227) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    18439770, /*  9079 ( 227) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
    34146806, /*  9080 ( 227) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    18426648, /*  9081 ( 227) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
       16484, /*  9082 ( 228) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
        3362, /*  9083 ( 228) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    35445884, /*  9084 ( 228) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  0] -1 */
    18439770, /*  9085 ( 228) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
    18426648, /*  9086 ( 228) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
    51021696, /*  9087 ( 228) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  0] -1 */
    35432762, /*  9088 ( 228) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  0] -1 */
    51034818, /*  9089 ( 228) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  0] -1 */
       16484, /*  9090 ( 229) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    51152916, /*  9091 ( 229) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6] -1 */
        3362, /*  9092 ( 229) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    35550860, /*  9093 ( 229) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
    35563982, /*  9094 ( 229) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
    18439770, /*  9095 ( 229) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
    18426648, /*  9096 ( 229) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
    51139794, /*  9097 ( 229) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6] -1 */
       16484, /*  9098 ( 230) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34028706, /*  9099 ( 230) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
        3362, /*  9100 ( 230) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    52438874, /*  9101 ( 230) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
    18439770, /*  9102 ( 230) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
    18426648, /*  9103 ( 230) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
    52451996, /*  9104 ( 230) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
    34015584, /*  9105 ( 230) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
       16484, /*  9106 ( 231) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
        3362, /*  9107 ( 231) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    51139796, /*  9108 ( 231) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
    51152918, /*  9109 ( 231) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
    18439770, /*  9110 ( 231) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
    18426648, /*  9111 ( 231) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
    35550858, /*  9112 ( 231) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6] -1 */
    35563980, /*  9113 ( 231) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6] -1 */
       16484, /*  9114 ( 232) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
        3362, /*  9115 ( 232) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34133682, /*  9116 ( 232) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
    34146804, /*  9117 ( 232) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
    18439770, /*  9118 ( 232) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
    18426648, /*  9119 ( 232) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
    52556972, /*  9120 ( 232) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    52570094, /*  9121 ( 232) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
       16484, /*  9122 ( 233) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    18426650, /*  9123 ( 233) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
        3200, /*  9124 ( 233) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    18439610, /*  9125 ( 233) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
       16484, /*  9126 ( 234) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    52451834, /*  9127 ( 234) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
        3200, /*  9128 ( 234) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    18439610, /*  9129 ( 234) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    52438874, /*  9130 ( 234) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
    18426650, /*  9131 ( 234) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    34015424, /*  9132 ( 234) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    34028708, /*  9133 ( 234) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
       16484, /*  9134 ( 235) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34015424, /*  9135 ( 235) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    18426650, /*  9136 ( 235) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    52451834, /*  9137 ( 235) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
       16484, /*  9138 ( 236) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    52451834, /*  9139 ( 236) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
    52438874, /*  9140 ( 236) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
        3200, /*  9141 ( 236) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
       16484, /*  9142 ( 237) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34133522, /*  9143 ( 237) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
        3200, /*  9144 ( 237) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    18439610, /*  9145 ( 237) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    52569932, /*  9146 ( 237) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    18426650, /*  9147 ( 237) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    34146806, /*  9148 ( 237) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    52556972, /*  9149 ( 237) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
       16484, /*  9150 ( 238) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
        3200, /*  9151 ( 238) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    18439610, /*  9152 ( 238) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    51021698, /*  9153 ( 238) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  0] -1 */
    35432600, /*  9154 ( 238) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  0] -1 */
    18426650, /*  9155 ( 238) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    35445884, /*  9156 ( 238) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  0] -1 */
    51034658, /*  9157 ( 238) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  0] -1 */
       16484, /*  9158 ( 239) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34015586, /*  9159 ( 239) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
        3200, /*  9160 ( 239) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    18439610, /*  9161 ( 239) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    18426650, /*  9162 ( 239) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    52451996, /*  9163 ( 239) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
    34028546, /*  9164 ( 239) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    52438712, /*  9165 ( 239) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
       16484, /*  9166 ( 240) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
        3200, /*  9167 ( 240) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    18439610, /*  9168 ( 240) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    51152756, /*  9169 ( 240) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
    35563982, /*  9170 ( 240) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
    18426650, /*  9171 ( 240) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    51139796, /*  9172 ( 240) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
    35550698, /*  9173 ( 240) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
       16484, /*  9174 ( 241) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    52556810, /*  9175 ( 241) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
        3200, /*  9176 ( 241) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    18439610, /*  9177 ( 241) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    34146644, /*  9178 ( 241) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    18426650, /*  9179 ( 241) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    34133684, /*  9180 ( 241) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    52570094, /*  9181 ( 241) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
       16484, /*  9182 ( 233) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
     1551596, /*  9183 ( 233) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
       16320, /*  9184 ( 233) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
     1551756, /*  9185 ( 233) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
       16484, /*  9186 ( 234) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    35563980, /*  9187 ( 234) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6] -1 */
       16320, /*  9188 ( 234) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
     1551756, /*  9189 ( 234) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
    35563820, /*  9190 ( 234) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
     1551596, /*  9191 ( 234) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
    34028544, /*  9192 ( 234) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    34028708, /*  9193 ( 234) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
       16484, /*  9194 ( 235) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34028544, /*  9195 ( 235) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
     1551596, /*  9196 ( 235) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
    35563980, /*  9197 ( 235) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6] -1 */
       16484, /*  9198 ( 236) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    35563980, /*  9199 ( 236) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6] -1 */
    35563820, /*  9200 ( 236) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
       16320, /*  9201 ( 236) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
       16484, /*  9202 ( 237) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    51034656, /*  9203 ( 237) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  0] -1 */
       16320, /*  9204 ( 237) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
     1551756, /*  9205 ( 237) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
    52570092, /*  9206 ( 237) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
     1551596, /*  9207 ( 237) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
    51034820, /*  9208 ( 237) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  0] -1 */
    52569932, /*  9209 ( 237) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
       16484, /*  9210 ( 238) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
       16320, /*  9211 ( 238) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
     1551756, /*  9212 ( 238) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
    35445722, /*  9213 ( 238) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  0] -1 */
    34146642, /*  9214 ( 238) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
     1551596, /*  9215 ( 238) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
    34146806, /*  9216 ( 238) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    35445882, /*  9217 ( 238) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  0] -1 */
       16484, /*  9218 ( 239) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34028546, /*  9219 ( 239) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
       16320, /*  9220 ( 239) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
     1551756, /*  9221 ( 239) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
     1551596, /*  9222 ( 239) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
    35563982, /*  9223 ( 239) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
    34028706, /*  9224 ( 239) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    35563818, /*  9225 ( 239) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  6] -1 */
       16484, /*  9226 ( 240) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
       16320, /*  9227 ( 240) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
     1551756, /*  9228 ( 240) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
    52451994, /*  9229 ( 240) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
    51152918, /*  9230 ( 240) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
     1551596, /*  9231 ( 240) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
    52451834, /*  9232 ( 240) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
    51152754, /*  9233 ( 240) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  6] -1 */
       16484, /*  9234 ( 241) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    52569930, /*  9235 ( 241) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
       16320, /*  9236 ( 241) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
     1551756, /*  9237 ( 241) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
    51034818, /*  9238 ( 241) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  0] -1 */
     1551596, /*  9239 ( 241) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
    51034658, /*  9240 ( 241) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  0] -1 */
    52570094, /*  9241 ( 241) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
       16484, /*  9242 ( 233) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    17140692, /*  9243 ( 233) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6]  1 */
        3360, /*  9244 ( 233) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    17127572, /*  9245 ( 233) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
       16484, /*  9246 ( 234) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    51139796, /*  9247 ( 234) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
        3360, /*  9248 ( 234) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    17127572, /*  9249 ( 234) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
    51152916, /*  9250 ( 234) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6] -1 */
    17140692, /*  9251 ( 234) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6]  1 */
    34015584, /*  9252 ( 234) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    34028708, /*  9253 ( 234) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
       16484, /*  9254 ( 235) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34015584, /*  9255 ( 235) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    17140692, /*  9256 ( 235) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6]  1 */
    51139796, /*  9257 ( 235) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
       16484, /*  9258 ( 236) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    51139796, /*  9259 ( 236) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
    51152916, /*  9260 ( 236) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6] -1 */
        3360, /*  9261 ( 236) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
       16484, /*  9262 ( 237) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    35432760, /*  9263 ( 237) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  0] -1 */
        3360, /*  9264 ( 237) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    17127572, /*  9265 ( 237) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
    52556972, /*  9266 ( 237) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    17140692, /*  9267 ( 237) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6]  1 */
    35445884, /*  9268 ( 237) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  0] -1 */
    52570092, /*  9269 ( 237) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
       16484, /*  9270 ( 238) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
        3360, /*  9271 ( 238) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    17127572, /*  9272 ( 238) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
    34146804, /*  9273 ( 238) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
    51021696, /*  9274 ( 238) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  0] -1 */
    17140692, /*  9275 ( 238) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6]  1 */
    51034820, /*  9276 ( 238) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  0] -1 */
    34133684, /*  9277 ( 238) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
       16484, /*  9278 ( 239) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34028706, /*  9279 ( 239) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
        3360, /*  9280 ( 239) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    17127572, /*  9281 ( 239) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
    17140692, /*  9282 ( 239) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6]  1 */
    51152918, /*  9283 ( 239) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
    34015586, /*  9284 ( 239) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    51139794, /*  9285 ( 239) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6] -1 */
       16484, /*  9286 ( 240) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
        3360, /*  9287 ( 240) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    17127572, /*  9288 ( 240) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
    35550860, /*  9289 ( 240) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
    52451996, /*  9290 ( 240) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
    17140692, /*  9291 ( 240) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6]  1 */
    35563980, /*  9292 ( 240) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6] -1 */
    52438872, /*  9293 ( 240) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
       16484, /*  9294 ( 241) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    52556970, /*  9295 ( 241) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
        3360, /*  9296 ( 241) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    17127572, /*  9297 ( 241) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
    35432762, /*  9298 ( 241) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  0] -1 */
    17140692, /*  9299 ( 241) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6]  1 */
    35445882, /*  9300 ( 241) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  0] -1 */
    52570094, /*  9301 ( 241) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
       16484, /*  9302 ( 242) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
      121298, /*  9303 ( 242) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6]  1 */
    18544748, /*  9304 ( 242) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    18439610, /*  9305 ( 242) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
       16484, /*  9306 ( 243) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    52451834, /*  9307 ( 243) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
    34133522, /*  9308 ( 243) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    18439610, /*  9309 ( 243) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
      121298, /*  9310 ( 243) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6]  1 */
    52556972, /*  9311 ( 243) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    34028708, /*  9312 ( 243) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    18544748, /*  9313 ( 243) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
       16484, /*  9314 ( 244) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34133522, /*  9315 ( 244) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    52556972, /*  9316 ( 244) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    18439610, /*  9317 ( 244) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
       16484, /*  9318 ( 245) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    52451834, /*  9319 ( 245) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
    34133522, /*  9320 ( 245) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    18544748, /*  9321 ( 245) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
       16484, /*  9322 ( 246) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    52451834, /*  9323 ( 246) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
      121298, /*  9324 ( 246) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6]  1 */
    52556972, /*  9325 ( 246) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
       16484, /*  9326 ( 247) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    18439610, /*  9327 ( 247) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    51034820, /*  9328 ( 247) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  0] -1 */
    35550860, /*  9329 ( 247) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
    51139634, /*  9330 ( 247) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
      121298, /*  9331 ( 247) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6]  1 */
    35445722, /*  9332 ( 247) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  0] -1 */
    18544748, /*  9333 ( 247) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
       16484, /*  9334 ( 248) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    18439610, /*  9335 ( 248) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
      121298, /*  9336 ( 248) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6]  1 */
    51139796, /*  9337 ( 248) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
    35445884, /*  9338 ( 248) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  0] -1 */
    35550698, /*  9339 ( 248) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
    18544748, /*  9340 ( 248) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    51034658, /*  9341 ( 248) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  0] -1 */
       16484, /*  9342 ( 249) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    18439610, /*  9343 ( 249) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    52438874, /*  9344 ( 249) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
    52569932, /*  9345 ( 249) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
      121298, /*  9346 ( 249) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6]  1 */
    34146806, /*  9347 ( 249) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    34015424, /*  9348 ( 249) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    18544748, /*  9349 ( 249) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
       16484, /*  9350 ( 250) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    18439610, /*  9351 ( 250) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    51021698, /*  9352 ( 250) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  0] -1 */
    51152756, /*  9353 ( 250) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
    35432600, /*  9354 ( 250) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  0] -1 */
    35563982, /*  9355 ( 250) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
      121298, /*  9356 ( 250) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6]  1 */
    18544748, /*  9357 ( 250) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
       16484, /*  9358 ( 251) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    18439610, /*  9359 ( 251) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    35432762, /*  9360 ( 251) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  0] -1 */
      121298, /*  9361 ( 251) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6]  1 */
    51021536, /*  9362 ( 251) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  0] -1 */
    51152918, /*  9363 ( 251) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
    18544748, /*  9364 ( 251) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    35563820, /*  9365 ( 251) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
       16484, /*  9366 ( 252) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    52556810, /*  9367 ( 252) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    18439610, /*  9368 ( 252) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
      121298, /*  9369 ( 252) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6]  1 */
    52451996, /*  9370 ( 252) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
    34133684, /*  9371 ( 252) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    34028546, /*  9372 ( 252) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    18544748, /*  9373 ( 252) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
       16484, /*  9374 ( 253) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34015586, /*  9375 ( 253) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    52438712, /*  9376 ( 253) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
    18439610, /*  9377 ( 253) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    34146644, /*  9378 ( 253) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
      121298, /*  9379 ( 253) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6]  1 */
    52570094, /*  9380 ( 253) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    18544748, /*  9381 ( 253) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
       16484, /*  9382 ( 242) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
      121298, /*  9383 ( 242) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6]  1 */
    18557708, /*  9384 ( 242) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    18426650, /*  9385 ( 242) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
       16484, /*  9386 ( 243) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    52438874, /*  9387 ( 243) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
    34133522, /*  9388 ( 243) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    18426650, /*  9389 ( 243) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
      121298, /*  9390 ( 243) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6]  1 */
    52569932, /*  9391 ( 243) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    34028708, /*  9392 ( 243) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    18557708, /*  9393 ( 243) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
       16484, /*  9394 ( 244) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34133522, /*  9395 ( 244) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    52569932, /*  9396 ( 244) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    18426650, /*  9397 ( 244) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
       16484, /*  9398 ( 245) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    52438874, /*  9399 ( 245) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
    34133522, /*  9400 ( 245) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    18557708, /*  9401 ( 245) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
       16484, /*  9402 ( 246) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    52438874, /*  9403 ( 246) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
      121298, /*  9404 ( 246) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6]  1 */
    52569932, /*  9405 ( 246) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
       16484, /*  9406 ( 247) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    18426650, /*  9407 ( 247) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    35445884, /*  9408 ( 247) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  0] -1 */
    51152756, /*  9409 ( 247) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
    35550698, /*  9410 ( 247) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
      121298, /*  9411 ( 247) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6]  1 */
    51021698, /*  9412 ( 247) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  0] -1 */
    18557708, /*  9413 ( 247) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
       16484, /*  9414 ( 248) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    18426650, /*  9415 ( 248) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
      121298, /*  9416 ( 248) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6]  1 */
    35563820, /*  9417 ( 248) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
    51034820, /*  9418 ( 248) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  0] -1 */
    51139634, /*  9419 ( 248) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
    18557708, /*  9420 ( 248) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    35432762, /*  9421 ( 248) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  0] -1 */
       16484, /*  9422 ( 249) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    18426650, /*  9423 ( 249) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    52451834, /*  9424 ( 249) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
    52556972, /*  9425 ( 249) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
      121298, /*  9426 ( 249) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6]  1 */
    34146806, /*  9427 ( 249) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    34015424, /*  9428 ( 249) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    18557708, /*  9429 ( 249) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
       16484, /*  9430 ( 250) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    18426650, /*  9431 ( 250) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    35445722, /*  9432 ( 250) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  0] -1 */
    35550860, /*  9433 ( 250) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
    51021536, /*  9434 ( 250) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  0] -1 */
    51152918, /*  9435 ( 250) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
      121298, /*  9436 ( 250) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6]  1 */
    18557708, /*  9437 ( 250) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
       16484, /*  9438 ( 251) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    18426650, /*  9439 ( 251) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    51034658, /*  9440 ( 251) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  0] -1 */
      121298, /*  9441 ( 251) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6]  1 */
    35432600, /*  9442 ( 251) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  0] -1 */
    35563982, /*  9443 ( 251) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
    18557708, /*  9444 ( 251) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    51139796, /*  9445 ( 251) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
       16484, /*  9446 ( 252) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    52556810, /*  9447 ( 252) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    18426650, /*  9448 ( 252) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
      121298, /*  9449 ( 252) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6]  1 */
    52451996, /*  9450 ( 252) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
    34146644, /*  9451 ( 252) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    34015586, /*  9452 ( 252) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    18557708, /*  9453 ( 252) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
       16484, /*  9454 ( 253) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34028546, /*  9455 ( 253) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    52438712, /*  9456 ( 253) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
    18426650, /*  9457 ( 253) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    34133684, /*  9458 ( 253) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
      121298, /*  9459 ( 253) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6]  1 */
    52570094, /*  9460 ( 253) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    18557708, /*  9461 ( 253) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
       16484, /*  9462 ( 242) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    17022432, /*  9463 ( 242) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  0]  1 */
    18557708, /*  9464 ( 242) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
     1551756, /*  9465 ( 242) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
       16484, /*  9466 ( 243) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    35563980, /*  9467 ( 243) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6] -1 */
    51034656, /*  9468 ( 243) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  0] -1 */
     1551756, /*  9469 ( 243) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
    17022432, /*  9470 ( 243) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  0]  1 */
    52569932, /*  9471 ( 243) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    34028708, /*  9472 ( 243) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    18557708, /*  9473 ( 243) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
       16484, /*  9474 ( 244) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    51034656, /*  9475 ( 244) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  0] -1 */
    52569932, /*  9476 ( 244) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
     1551756, /*  9477 ( 244) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
       16484, /*  9478 ( 245) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    35563980, /*  9479 ( 245) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6] -1 */
    51034656, /*  9480 ( 245) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  0] -1 */
    18557708, /*  9481 ( 245) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
       16484, /*  9482 ( 246) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    35563980, /*  9483 ( 246) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6] -1 */
    17022432, /*  9484 ( 246) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  0]  1 */
    52569932, /*  9485 ( 246) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
       16484, /*  9486 ( 247) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
     1551756, /*  9487 ( 247) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
    35445884, /*  9488 ( 247) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  0] -1 */
    51152756, /*  9489 ( 247) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
    52451832, /*  9490 ( 247) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
    17022432, /*  9491 ( 247) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  0]  1 */
    34146804, /*  9492 ( 247) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
    18557708, /*  9493 ( 247) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
       16484, /*  9494 ( 248) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
     1551756, /*  9495 ( 248) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
    17022432, /*  9496 ( 248) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  0]  1 */
    52451834, /*  9497 ( 248) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
    34146806, /*  9498 ( 248) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    51152754, /*  9499 ( 248) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  6] -1 */
    18557708, /*  9500 ( 248) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    35445882, /*  9501 ( 248) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  0] -1 */
       16484, /*  9502 ( 249) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
     1551756, /*  9503 ( 249) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
    35563820, /*  9504 ( 249) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
    52570092, /*  9505 ( 249) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    17022432, /*  9506 ( 249) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  0]  1 */
    51034820, /*  9507 ( 249) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  0] -1 */
    34028544, /*  9508 ( 249) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    18557708, /*  9509 ( 249) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
       16484, /*  9510 ( 250) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
     1551756, /*  9511 ( 250) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
    35445722, /*  9512 ( 250) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  0] -1 */
    52451994, /*  9513 ( 250) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
    34146642, /*  9514 ( 250) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
    51152918, /*  9515 ( 250) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
    17022432, /*  9516 ( 250) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  0]  1 */
    18557708, /*  9517 ( 250) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
       16484, /*  9518 ( 251) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
     1551756, /*  9519 ( 251) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
    34146644, /*  9520 ( 251) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    17022432, /*  9521 ( 251) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  0]  1 */
    35445720, /*  9522 ( 251) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  0] -1 */
    52451996, /*  9523 ( 251) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
    18557708, /*  9524 ( 251) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    51152916, /*  9525 ( 251) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6] -1 */
       16484, /*  9526 ( 252) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    52569930, /*  9527 ( 252) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
     1551756, /*  9528 ( 252) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
    17022432, /*  9529 ( 252) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  0]  1 */
    35563982, /*  9530 ( 252) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
    51034658, /*  9531 ( 252) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  0] -1 */
    34028706, /*  9532 ( 252) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    18557708, /*  9533 ( 252) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
       16484, /*  9534 ( 253) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34028546, /*  9535 ( 253) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    35563818, /*  9536 ( 253) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  6] -1 */
     1551756, /*  9537 ( 253) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
    51034818, /*  9538 ( 253) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  0] -1 */
    17022432, /*  9539 ( 253) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  0]  1 */
    52570094, /*  9540 ( 253) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    18557708, /*  9541 ( 253) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
       16484, /*  9542 ( 242) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    17022432, /*  9543 ( 242) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  0]  1 */
    18557868, /*  9544 ( 242) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
     1551596, /*  9545 ( 242) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
       16484, /*  9546 ( 243) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    35563820, /*  9547 ( 243) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
    51034656, /*  9548 ( 243) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  0] -1 */
     1551596, /*  9549 ( 243) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
    17022432, /*  9550 ( 243) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  0]  1 */
    52570092, /*  9551 ( 243) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    34028708, /*  9552 ( 243) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    18557868, /*  9553 ( 243) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
       16484, /*  9554 ( 244) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    51034656, /*  9555 ( 244) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  0] -1 */
    52570092, /*  9556 ( 244) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
     1551596, /*  9557 ( 244) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
       16484, /*  9558 ( 245) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    35563820, /*  9559 ( 245) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
    51034656, /*  9560 ( 245) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  0] -1 */
    18557868, /*  9561 ( 245) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
       16484, /*  9562 ( 246) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    35563820, /*  9563 ( 246) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
    17022432, /*  9564 ( 246) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  0]  1 */
    52570092, /*  9565 ( 246) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
       16484, /*  9566 ( 247) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
     1551596, /*  9567 ( 247) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
    34146806, /*  9568 ( 247) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    52451994, /*  9569 ( 247) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
    51152754, /*  9570 ( 247) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  6] -1 */
    17022432, /*  9571 ( 247) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  0]  1 */
    35445722, /*  9572 ( 247) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  0] -1 */
    18557868, /*  9573 ( 247) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
       16484, /*  9574 ( 248) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
     1551596, /*  9575 ( 248) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
    17022432, /*  9576 ( 248) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  0]  1 */
    51152916, /*  9577 ( 248) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6] -1 */
    35445884, /*  9578 ( 248) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  0] -1 */
    52451832, /*  9579 ( 248) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
    18557868, /*  9580 ( 248) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
    34146644, /*  9581 ( 248) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
       16484, /*  9582 ( 249) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
     1551596, /*  9583 ( 249) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
    35563980, /*  9584 ( 249) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6] -1 */
    52569932, /*  9585 ( 249) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    17022432, /*  9586 ( 249) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  0]  1 */
    51034820, /*  9587 ( 249) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  0] -1 */
    34028544, /*  9588 ( 249) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    18557868, /*  9589 ( 249) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
       16484, /*  9590 ( 250) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
     1551596, /*  9591 ( 250) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
    34146804, /*  9592 ( 250) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
    51152756, /*  9593 ( 250) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
    35445720, /*  9594 ( 250) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  0] -1 */
    52451996, /*  9595 ( 250) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
    17022432, /*  9596 ( 250) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  0]  1 */
    18557868, /*  9597 ( 250) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
       16484, /*  9598 ( 251) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
     1551596, /*  9599 ( 251) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
    35445882, /*  9600 ( 251) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  0] -1 */
    17022432, /*  9601 ( 251) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  0]  1 */
    34146642, /*  9602 ( 251) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
    51152918, /*  9603 ( 251) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
    18557868, /*  9604 ( 251) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
    52451834, /*  9605 ( 251) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
       16484, /*  9606 ( 252) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    52569930, /*  9607 ( 252) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
     1551596, /*  9608 ( 252) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
    17022432, /*  9609 ( 252) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  0]  1 */
    35563982, /*  9610 ( 252) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
    51034818, /*  9611 ( 252) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  0] -1 */
    34028546, /*  9612 ( 252) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    18557868, /*  9613 ( 252) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
       16484, /*  9614 ( 253) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34028706, /*  9615 ( 253) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    35563818, /*  9616 ( 253) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  6] -1 */
     1551596, /*  9617 ( 253) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
    51034658, /*  9618 ( 253) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  0] -1 */
    17022432, /*  9619 ( 253) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  0]  1 */
    52570094, /*  9620 ( 253) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    18557868, /*  9621 ( 253) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
       16484, /*  9622 ( 242) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
     1420536, /*  9623 ( 242) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  0]  1 */
    18557868, /*  9624 ( 242) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
    17127572, /*  9625 ( 242) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
       16484, /*  9626 ( 243) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    51139796, /*  9627 ( 243) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
    35432760, /*  9628 ( 243) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  0] -1 */
    17127572, /*  9629 ( 243) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
     1420536, /*  9630 ( 243) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  0]  1 */
    52570092, /*  9631 ( 243) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    34028708, /*  9632 ( 243) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    18557868, /*  9633 ( 243) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
       16484, /*  9634 ( 244) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    35432760, /*  9635 ( 244) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  0] -1 */
    52570092, /*  9636 ( 244) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    17127572, /*  9637 ( 244) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
       16484, /*  9638 ( 245) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    51139796, /*  9639 ( 245) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
    35432760, /*  9640 ( 245) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  0] -1 */
    18557868, /*  9641 ( 245) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
       16484, /*  9642 ( 246) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    51139796, /*  9643 ( 246) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
     1420536, /*  9644 ( 246) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  0]  1 */
    52570092, /*  9645 ( 246) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
       16484, /*  9646 ( 247) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    17127572, /*  9647 ( 247) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
    34146806, /*  9648 ( 247) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    52451994, /*  9649 ( 247) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
    35550858, /*  9650 ( 247) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6] -1 */
     1420536, /*  9651 ( 247) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  0]  1 */
    51021698, /*  9652 ( 247) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  0] -1 */
    18557868, /*  9653 ( 247) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
       16484, /*  9654 ( 248) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    17127572, /*  9655 ( 248) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
     1420536, /*  9656 ( 248) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  0]  1 */
    35563980, /*  9657 ( 248) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6] -1 */
    51034820, /*  9658 ( 248) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  0] -1 */
    52438872, /*  9659 ( 248) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
    18557868, /*  9660 ( 248) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
    34133684, /*  9661 ( 248) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
       16484, /*  9662 ( 249) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    17127572, /*  9663 ( 249) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
    51152916, /*  9664 ( 249) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6] -1 */
    52556972, /*  9665 ( 249) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
     1420536, /*  9666 ( 249) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  0]  1 */
    35445884, /*  9667 ( 249) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  0] -1 */
    34015584, /*  9668 ( 249) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    18557868, /*  9669 ( 249) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
       16484, /*  9670 ( 250) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    17127572, /*  9671 ( 250) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
    34146804, /*  9672 ( 250) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
    35550860, /*  9673 ( 250) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
    51021696, /*  9674 ( 250) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  0] -1 */
    52451996, /*  9675 ( 250) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
     1420536, /*  9676 ( 250) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  0]  1 */
    18557868, /*  9677 ( 250) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
       16484, /*  9678 ( 251) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    17127572, /*  9679 ( 251) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
    51034818, /*  9680 ( 251) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  0] -1 */
     1420536, /*  9681 ( 251) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  0]  1 */
    34133682, /*  9682 ( 251) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
    35563982, /*  9683 ( 251) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
    18557868, /*  9684 ( 251) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
    52438874, /*  9685 ( 251) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
       16484, /*  9686 ( 252) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    52556970, /*  9687 ( 252) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    17127572, /*  9688 ( 252) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
     1420536, /*  9689 ( 252) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  0]  1 */
    51152918, /*  9690 ( 252) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
    35445882, /*  9691 ( 252) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  0] -1 */
    34015586, /*  9692 ( 252) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    18557868, /*  9693 ( 252) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
       16484, /*  9694 ( 253) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34028706, /*  9695 ( 253) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    51139794, /*  9696 ( 253) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6] -1 */
    17127572, /*  9697 ( 253) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
    35432762, /*  9698 ( 253) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  0] -1 */
     1420536, /*  9699 ( 253) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  0]  1 */
    52570094, /*  9700 ( 253) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    18557868, /*  9701 ( 253) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
       16484, /*  9702 ( 242) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
     1420536, /*  9703 ( 242) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  0]  1 */
    18544748, /*  9704 ( 242) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    17140692, /*  9705 ( 242) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6]  1 */
       16484, /*  9706 ( 243) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    51152916, /*  9707 ( 243) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6] -1 */
    35432760, /*  9708 ( 243) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  0] -1 */
    17140692, /*  9709 ( 243) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6]  1 */
     1420536, /*  9710 ( 243) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  0]  1 */
    52556972, /*  9711 ( 243) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    34028708, /*  9712 ( 243) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    18544748, /*  9713 ( 243) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
       16484, /*  9714 ( 244) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    35432760, /*  9715 ( 244) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  0] -1 */
    52556972, /*  9716 ( 244) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    17140692, /*  9717 ( 244) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6]  1 */
       16484, /*  9718 ( 245) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    51152916, /*  9719 ( 245) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6] -1 */
    35432760, /*  9720 ( 245) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  0] -1 */
    18544748, /*  9721 ( 245) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
       16484, /*  9722 ( 246) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    51152916, /*  9723 ( 246) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6] -1 */
     1420536, /*  9724 ( 246) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  0]  1 */
    52556972, /*  9725 ( 246) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
       16484, /*  9726 ( 247) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    17140692, /*  9727 ( 247) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6]  1 */
    51034820, /*  9728 ( 247) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  0] -1 */
    35550860, /*  9729 ( 247) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
    52438872, /*  9730 ( 247) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
     1420536, /*  9731 ( 247) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  0]  1 */
    34146804, /*  9732 ( 247) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
    18544748, /*  9733 ( 247) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
       16484, /*  9734 ( 248) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    17140692, /*  9735 ( 248) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6]  1 */
     1420536, /*  9736 ( 248) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  0]  1 */
    52438874, /*  9737 ( 248) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
    34146806, /*  9738 ( 248) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    35550858, /*  9739 ( 248) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6] -1 */
    18544748, /*  9740 ( 248) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    51034818, /*  9741 ( 248) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  0] -1 */
       16484, /*  9742 ( 249) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    17140692, /*  9743 ( 249) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6]  1 */
    51139796, /*  9744 ( 249) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
    52570092, /*  9745 ( 249) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
     1420536, /*  9746 ( 249) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  0]  1 */
    35445884, /*  9747 ( 249) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  0] -1 */
    34015584, /*  9748 ( 249) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    18544748, /*  9749 ( 249) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
       16484, /*  9750 ( 250) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    17140692, /*  9751 ( 250) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6]  1 */
    51021698, /*  9752 ( 250) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  0] -1 */
    52451994, /*  9753 ( 250) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
    34133682, /*  9754 ( 250) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
    35563982, /*  9755 ( 250) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
     1420536, /*  9756 ( 250) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  0]  1 */
    18544748, /*  9757 ( 250) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
       16484, /*  9758 ( 251) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    17140692, /*  9759 ( 251) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6]  1 */
    34133684, /*  9760 ( 251) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
     1420536, /*  9761 ( 251) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  0]  1 */
    51021696, /*  9762 ( 251) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  0] -1 */
    52451996, /*  9763 ( 251) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
    18544748, /*  9764 ( 251) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    35563980, /*  9765 ( 251) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6] -1 */
       16484, /*  9766 ( 252) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    52556970, /*  9767 ( 252) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    17140692, /*  9768 ( 252) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6]  1 */
     1420536, /*  9769 ( 252) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  0]  1 */
    51152918, /*  9770 ( 252) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
    35432762, /*  9771 ( 252) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  0] -1 */
    34028706, /*  9772 ( 252) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    18544748, /*  9773 ( 252) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
       16484, /*  9774 ( 253) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34015586, /*  9775 ( 253) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    51139794, /*  9776 ( 253) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6] -1 */
    17140692, /*  9777 ( 253) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6]  1 */
    35445882, /*  9778 ( 253) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  0] -1 */
     1420536, /*  9779 ( 253) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  0]  1 */
    52570094, /*  9780 ( 253) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    18544748, /*  9781 ( 253) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
       16484, /*  9782 ( 254) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    18544748, /*  9783 ( 254) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    18557708, /*  9784 ( 254) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
        3200, /*  9785 ( 254) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
       16484, /*  9786 ( 255) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
        3200, /*  9787 ( 255) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    52569932, /*  9788 ( 255) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    52556972, /*  9789 ( 255) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    34015424, /*  9790 ( 255) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    18557708, /*  9791 ( 255) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    34028708, /*  9792 ( 255) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    18544748, /*  9793 ( 255) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
       16484, /*  9794 ( 256) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34015424, /*  9795 ( 256) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    52569932, /*  9796 ( 256) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    18544748, /*  9797 ( 256) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
       16484, /*  9798 ( 257) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    52569932, /*  9799 ( 257) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    52556972, /*  9800 ( 257) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
        3200, /*  9801 ( 257) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
       16484, /*  9802 ( 258) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
        3200, /*  9803 ( 258) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    51034820, /*  9804 ( 258) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  0] -1 */
    35550860, /*  9805 ( 258) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
    51021536, /*  9806 ( 258) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  0] -1 */
    18557708, /*  9807 ( 258) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    18544748, /*  9808 ( 258) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    35563820, /*  9809 ( 258) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
       16484, /*  9810 ( 259) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    52451834, /*  9811 ( 259) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
    34133522, /*  9812 ( 259) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
        3200, /*  9813 ( 259) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    52438874, /*  9814 ( 259) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
    34146806, /*  9815 ( 259) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    18557708, /*  9816 ( 259) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    18544748, /*  9817 ( 259) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
       16484, /*  9818 ( 260) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
        3200, /*  9819 ( 260) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    51021698, /*  9820 ( 260) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  0] -1 */
    35563982, /*  9821 ( 260) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
    35550698, /*  9822 ( 260) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
    18557708, /*  9823 ( 260) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    18544748, /*  9824 ( 260) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    51034658, /*  9825 ( 260) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  0] -1 */
       16484, /*  9826 ( 261) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    52438712, /*  9827 ( 261) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
        3200, /*  9828 ( 261) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34146644, /*  9829 ( 261) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    52451996, /*  9830 ( 261) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
    34133684, /*  9831 ( 261) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    18557708, /*  9832 ( 261) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    18544748, /*  9833 ( 261) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
       16484, /*  9834 ( 262) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34015586, /*  9835 ( 262) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    52556810, /*  9836 ( 262) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
        3200, /*  9837 ( 262) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    52570094, /*  9838 ( 262) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    34028546, /*  9839 ( 262) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    18557708, /*  9840 ( 262) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    18544748, /*  9841 ( 262) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
       16484, /*  9842 ( 254) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    18557708, /*  9843 ( 254) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    18557868, /*  9844 ( 254) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
       16320, /*  9845 ( 254) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
       16484, /*  9846 ( 255) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
       16320, /*  9847 ( 255) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    52570092, /*  9848 ( 255) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    52569932, /*  9849 ( 255) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    34028544, /*  9850 ( 255) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    18557868, /*  9851 ( 255) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
    34028708, /*  9852 ( 255) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    18557708, /*  9853 ( 255) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
       16484, /*  9854 ( 256) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34028544, /*  9855 ( 256) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    52570092, /*  9856 ( 256) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    18557708, /*  9857 ( 256) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
       16484, /*  9858 ( 257) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    52570092, /*  9859 ( 257) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    52569932, /*  9860 ( 257) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
       16320, /*  9861 ( 257) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
       16484, /*  9862 ( 258) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
       16320, /*  9863 ( 258) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    35445884, /*  9864 ( 258) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  0] -1 */
    51152756, /*  9865 ( 258) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
    35445720, /*  9866 ( 258) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  0] -1 */
    18557868, /*  9867 ( 258) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
    18557708, /*  9868 ( 258) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    51152916, /*  9869 ( 258) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6] -1 */
       16484, /*  9870 ( 259) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    35563980, /*  9871 ( 259) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6] -1 */
    51034656, /*  9872 ( 259) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  0] -1 */
       16320, /*  9873 ( 259) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    35563820, /*  9874 ( 259) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
    51034820, /*  9875 ( 259) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  0] -1 */
    18557868, /*  9876 ( 259) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
    18557708, /*  9877 ( 259) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
       16484, /*  9878 ( 260) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
       16320, /*  9879 ( 260) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    35445722, /*  9880 ( 260) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  0] -1 */
    51152918, /*  9881 ( 260) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
    51152754, /*  9882 ( 260) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  6] -1 */
    18557868, /*  9883 ( 260) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
    18557708, /*  9884 ( 260) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    35445882, /*  9885 ( 260) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  0] -1 */
       16484, /*  9886 ( 261) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    35563818, /*  9887 ( 261) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  6] -1 */
       16320, /*  9888 ( 261) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    51034818, /*  9889 ( 261) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  0] -1 */
    35563982, /*  9890 ( 261) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
    51034658, /*  9891 ( 261) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  0] -1 */
    18557868, /*  9892 ( 261) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
    18557708, /*  9893 ( 261) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
       16484, /*  9894 ( 262) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34028546, /*  9895 ( 262) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    52569930, /*  9896 ( 262) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
       16320, /*  9897 ( 262) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    52570094, /*  9898 ( 262) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    34028706, /*  9899 ( 262) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    18557868, /*  9900 ( 262) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
    18557708, /*  9901 ( 262) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
       16484, /*  9902 ( 254) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    18557868, /*  9903 ( 254) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
    18544748, /*  9904 ( 254) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
        3360, /*  9905 ( 254) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
       16484, /*  9906 ( 255) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
        3360, /*  9907 ( 255) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    52556972, /*  9908 ( 255) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    52570092, /*  9909 ( 255) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    34015584, /*  9910 ( 255) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    18544748, /*  9911 ( 255) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    34028708, /*  9912 ( 255) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    18557868, /*  9913 ( 255) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
       16484, /*  9914 ( 256) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34015584, /*  9915 ( 256) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    52556972, /*  9916 ( 256) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    18557868, /*  9917 ( 256) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
       16484, /*  9918 ( 257) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    52556972, /*  9919 ( 257) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    52570092, /*  9920 ( 257) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
        3360, /*  9921 ( 257) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
       16484, /*  9922 ( 258) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
        3360, /*  9923 ( 258) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    34146806, /*  9924 ( 258) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    52451994, /*  9925 ( 258) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
    34133682, /*  9926 ( 258) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
    18544748, /*  9927 ( 258) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    18557868, /*  9928 ( 258) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
    52438874, /*  9929 ( 258) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
       16484, /*  9930 ( 259) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    51139796, /*  9931 ( 259) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
    35432760, /*  9932 ( 259) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  0] -1 */
        3360, /*  9933 ( 259) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    51152916, /*  9934 ( 259) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6] -1 */
    35445884, /*  9935 ( 259) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  0] -1 */
    18544748, /*  9936 ( 259) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    18557868, /*  9937 ( 259) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
       16484, /*  9938 ( 260) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
        3360, /*  9939 ( 260) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    34146804, /*  9940 ( 260) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
    52451996, /*  9941 ( 260) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
    52438872, /*  9942 ( 260) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
    18544748, /*  9943 ( 260) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    18557868, /*  9944 ( 260) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
    34133684, /*  9945 ( 260) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
       16484, /*  9946 ( 261) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    51139794, /*  9947 ( 261) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6] -1 */
        3360, /*  9948 ( 261) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    35432762, /*  9949 ( 261) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  0] -1 */
    51152918, /*  9950 ( 261) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
    35445882, /*  9951 ( 261) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  0] -1 */
    18544748, /*  9952 ( 261) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    18557868, /*  9953 ( 261) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
       16484, /*  9954 ( 262) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34028706, /*  9955 ( 262) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    52556970, /*  9956 ( 262) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
        3360, /*  9957 ( 262) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    52570094, /*  9958 ( 262) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    34015586, /*  9959 ( 262) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    18544748, /*  9960 ( 262) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    18557868, /*  9961 ( 262) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
       16484, /*  9962 ( 263) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    18426488, /*  9963 ( 263) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
        3200, /*  9964 ( 263) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    18439610, /*  9965 ( 263) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
        3362, /*  9966 ( 263) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    18426650, /*  9967 ( 263) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    18439772, /*  9968 ( 263) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
       16322, /*  9969 ( 263) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
       16484, /*  9970 ( 264) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    18426488, /*  9971 ( 264) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    34015586, /*  9972 ( 264) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    34028546, /*  9973 ( 264) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    52451834, /*  9974 ( 264) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
        3200, /*  9975 ( 264) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    18439610, /*  9976 ( 264) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
        3362, /*  9977 ( 264) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    52438874, /*  9978 ( 264) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
    18426650, /*  9979 ( 264) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    52451996, /*  9980 ( 264) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
    18439772, /*  9981 ( 264) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    52438712, /*  9982 ( 264) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
    34028708, /*  9983 ( 264) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    34015424, /*  9984 ( 264) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
       16322, /*  9985 ( 264) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
       16484, /*  9986 ( 265) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    52451834, /*  9987 ( 265) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
    34028546, /*  9988 ( 265) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
        3362, /*  9989 ( 265) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    18426650, /*  9990 ( 265) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    18439772, /*  9991 ( 265) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    52438712, /*  9992 ( 265) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
    34015424, /*  9993 ( 265) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
       16484, /*  9994 ( 266) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    18426488, /*  9995 ( 266) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    34015586, /*  9996 ( 266) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    34028546, /*  9997 ( 266) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    52451834, /*  9998 ( 266) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
        3200, /*  9999 ( 266) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    52438874, /* 10000 ( 266) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
    18439772, /* 10001 ( 266) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
       16484, /* 10002 ( 267) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    18426488, /* 10003 ( 267) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    34133522, /* 10004 ( 267) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    52556810, /* 10005 ( 267) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
        3200, /* 10006 ( 267) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    18439610, /* 10007 ( 267) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
        3362, /* 10008 ( 267) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34146644, /* 10009 ( 267) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    52569932, /* 10010 ( 267) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    18426650, /* 10011 ( 267) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    34146806, /* 10012 ( 267) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    34133684, /* 10013 ( 267) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    52556972, /* 10014 ( 267) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    18439772, /* 10015 ( 267) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    52570094, /* 10016 ( 267) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
       16322, /* 10017 ( 267) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
       16484, /* 10018 ( 268) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    18426488, /* 10019 ( 268) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
        3200, /* 10020 ( 268) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    18439610, /* 10021 ( 268) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    51034820, /* 10022 ( 268) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  0] -1 */
        3362, /* 10023 ( 268) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    51021698, /* 10024 ( 268) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  0] -1 */
    35432600, /* 10025 ( 268) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  0] -1 */
    51034658, /* 10026 ( 268) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  0] -1 */
    35432762, /* 10027 ( 268) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  0] -1 */
    18426650, /* 10028 ( 268) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    35445722, /* 10029 ( 268) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  0] -1 */
    35445884, /* 10030 ( 268) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  0] -1 */
    51021536, /* 10031 ( 268) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  0] -1 */
    18439772, /* 10032 ( 268) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
       16322, /* 10033 ( 268) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
       16484, /* 10034 ( 269) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    18426488, /* 10035 ( 269) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
        3200, /* 10036 ( 269) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    18439610, /* 10037 ( 269) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
        3362, /* 10038 ( 269) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    35550860, /* 10039 ( 269) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
       16322, /* 10040 ( 269) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    51152756, /* 10041 ( 269) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
    51139634, /* 10042 ( 269) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
    35563982, /* 10043 ( 269) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
    18426650, /* 10044 ( 269) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    51139796, /* 10045 ( 269) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
    35550698, /* 10046 ( 269) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
    18439772, /* 10047 ( 269) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    35563820, /* 10048 ( 269) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
    51152918, /* 10049 ( 269) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
       16484, /* 10050 ( 263) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
     1551594, /* 10051 ( 263) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
       16320, /* 10052 ( 263) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
     1551756, /* 10053 ( 263) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
       16322, /* 10054 ( 263) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
     1551596, /* 10055 ( 263) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
     1551758, /* 10056 ( 263) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
       16482, /* 10057 ( 263) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
       16484, /* 10058 ( 264) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
     1551594, /* 10059 ( 264) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
    34028546, /* 10060 ( 264) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    34028706, /* 10061 ( 264) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    35563980, /* 10062 ( 264) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6] -1 */
       16320, /* 10063 ( 264) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
     1551756, /* 10064 ( 264) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
       16322, /* 10065 ( 264) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    35563820, /* 10066 ( 264) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
     1551596, /* 10067 ( 264) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
    35563982, /* 10068 ( 264) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
     1551758, /* 10069 ( 264) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
    35563818, /* 10070 ( 264) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  6] -1 */
    34028708, /* 10071 ( 264) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    34028544, /* 10072 ( 264) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
       16482, /* 10073 ( 264) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
       16484, /* 10074 ( 265) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    35563980, /* 10075 ( 265) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6] -1 */
    34028706, /* 10076 ( 265) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
       16322, /* 10077 ( 265) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
     1551596, /* 10078 ( 265) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
     1551758, /* 10079 ( 265) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
    35563818, /* 10080 ( 265) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  6] -1 */
    34028544, /* 10081 ( 265) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
       16484, /* 10082 ( 266) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
     1551594, /* 10083 ( 266) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
    34028546, /* 10084 ( 266) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    34028706, /* 10085 ( 266) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    35563980, /* 10086 ( 266) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6] -1 */
       16320, /* 10087 ( 266) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    35563820, /* 10088 ( 266) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
     1551758, /* 10089 ( 266) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
       16484, /* 10090 ( 267) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
     1551594, /* 10091 ( 267) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
    51034656, /* 10092 ( 267) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  0] -1 */
    52569930, /* 10093 ( 267) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
       16320, /* 10094 ( 267) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
     1551756, /* 10095 ( 267) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
       16322, /* 10096 ( 267) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    51034818, /* 10097 ( 267) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  0] -1 */
    52570092, /* 10098 ( 267) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
     1551596, /* 10099 ( 267) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
    51034820, /* 10100 ( 267) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  0] -1 */
    51034658, /* 10101 ( 267) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  0] -1 */
    52569932, /* 10102 ( 267) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
     1551758, /* 10103 ( 267) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
    52570094, /* 10104 ( 267) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
       16482, /* 10105 ( 267) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
       16484, /* 10106 ( 268) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
     1551594, /* 10107 ( 268) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
       16320, /* 10108 ( 268) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
     1551756, /* 10109 ( 268) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
    35445884, /* 10110 ( 268) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  0] -1 */
       16322, /* 10111 ( 268) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    35445722, /* 10112 ( 268) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  0] -1 */
    34146642, /* 10113 ( 268) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
    35445882, /* 10114 ( 268) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  0] -1 */
    34146644, /* 10115 ( 268) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
     1551596, /* 10116 ( 268) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
    34146804, /* 10117 ( 268) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
    34146806, /* 10118 ( 268) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    35445720, /* 10119 ( 268) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  0] -1 */
     1551758, /* 10120 ( 268) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
       16482, /* 10121 ( 268) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
       16484, /* 10122 ( 269) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
     1551594, /* 10123 ( 269) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
       16320, /* 10124 ( 269) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
     1551756, /* 10125 ( 269) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
       16322, /* 10126 ( 269) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    51152756, /* 10127 ( 269) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
       16482, /* 10128 ( 269) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    52451994, /* 10129 ( 269) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
    52451832, /* 10130 ( 269) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
    51152918, /* 10131 ( 269) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
     1551596, /* 10132 ( 269) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
    52451834, /* 10133 ( 269) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
    51152754, /* 10134 ( 269) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  6] -1 */
     1551758, /* 10135 ( 269) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
    51152916, /* 10136 ( 269) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6] -1 */
    52451996, /* 10137 ( 269) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
       16484, /* 10138 ( 263) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    17127570, /* 10139 ( 263) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6]  1 */
        3360, /* 10140 ( 263) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    17127572, /* 10141 ( 263) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
       16482, /* 10142 ( 263) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    17140692, /* 10143 ( 263) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6]  1 */
    17140694, /* 10144 ( 263) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
        3362, /* 10145 ( 263) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
       16484, /* 10146 ( 264) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    17127570, /* 10147 ( 264) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6]  1 */
    34028706, /* 10148 ( 264) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    34015586, /* 10149 ( 264) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    51139796, /* 10150 ( 264) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
        3360, /* 10151 ( 264) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    17127572, /* 10152 ( 264) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
       16482, /* 10153 ( 264) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    51152916, /* 10154 ( 264) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6] -1 */
    17140692, /* 10155 ( 264) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6]  1 */
    51152918, /* 10156 ( 264) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
    17140694, /* 10157 ( 264) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
    51139794, /* 10158 ( 264) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6] -1 */
    34028708, /* 10159 ( 264) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    34015584, /* 10160 ( 264) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
        3362, /* 10161 ( 264) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
       16484, /* 10162 ( 265) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    51139796, /* 10163 ( 265) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
    34015586, /* 10164 ( 265) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
       16482, /* 10165 ( 265) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    17140692, /* 10166 ( 265) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6]  1 */
    17140694, /* 10167 ( 265) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
    51139794, /* 10168 ( 265) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6] -1 */
    34015584, /* 10169 ( 265) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
       16484, /* 10170 ( 266) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    17127570, /* 10171 ( 266) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6]  1 */
    34028706, /* 10172 ( 266) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    34015586, /* 10173 ( 266) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    51139796, /* 10174 ( 266) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
        3360, /* 10175 ( 266) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    51152916, /* 10176 ( 266) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6] -1 */
    17140694, /* 10177 ( 266) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
       16484, /* 10178 ( 267) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    17127570, /* 10179 ( 267) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6]  1 */
    35432760, /* 10180 ( 267) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  0] -1 */
    52556970, /* 10181 ( 267) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
        3360, /* 10182 ( 267) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    17127572, /* 10183 ( 267) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
       16482, /* 10184 ( 267) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    35432762, /* 10185 ( 267) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  0] -1 */
    52556972, /* 10186 ( 267) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    17140692, /* 10187 ( 267) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6]  1 */
    35445884, /* 10188 ( 267) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  0] -1 */
    35445882, /* 10189 ( 267) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  0] -1 */
    52570092, /* 10190 ( 267) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    17140694, /* 10191 ( 267) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
    52570094, /* 10192 ( 267) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
        3362, /* 10193 ( 267) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
       16484, /* 10194 ( 268) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    17127570, /* 10195 ( 268) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6]  1 */
        3360, /* 10196 ( 268) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    17127572, /* 10197 ( 268) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
    34146806, /* 10198 ( 268) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
       16482, /* 10199 ( 268) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    34146804, /* 10200 ( 268) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
    51021696, /* 10201 ( 268) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  0] -1 */
    34133684, /* 10202 ( 268) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    51034818, /* 10203 ( 268) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  0] -1 */
    17140692, /* 10204 ( 268) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6]  1 */
    51021698, /* 10205 ( 268) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  0] -1 */
    51034820, /* 10206 ( 268) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  0] -1 */
    34133682, /* 10207 ( 268) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
    17140694, /* 10208 ( 268) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
        3362, /* 10209 ( 268) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
       16484, /* 10210 ( 269) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    17127570, /* 10211 ( 269) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6]  1 */
        3360, /* 10212 ( 269) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    17127572, /* 10213 ( 269) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
       16482, /* 10214 ( 269) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    52451994, /* 10215 ( 269) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
        3362, /* 10216 ( 269) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    35550860, /* 10217 ( 269) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
    35550858, /* 10218 ( 269) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6] -1 */
    52451996, /* 10219 ( 269) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
    17140692, /* 10220 ( 269) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6]  1 */
    35563980, /* 10221 ( 269) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6] -1 */
    52438872, /* 10222 ( 269) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
    17140694, /* 10223 ( 269) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
    52438874, /* 10224 ( 269) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
    35563982, /* 10225 ( 269) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
       16484, /* 10226 ( 270) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
        3362, /* 10227 ( 270) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
      134420, /* 10228 ( 270) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6]  1 */
      121298, /* 10229 ( 270) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6]  1 */
    18544586, /* 10230 ( 270) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    18426650, /* 10231 ( 270) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    18439772, /* 10232 ( 270) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    18557708, /* 10233 ( 270) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
       16484, /* 10234 ( 271) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34015586, /* 10235 ( 271) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    34133522, /* 10236 ( 271) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    52556810, /* 10237 ( 271) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
        3362, /* 10238 ( 271) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    52438874, /* 10239 ( 271) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
    34146644, /* 10240 ( 271) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    52569932, /* 10241 ( 271) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
      134420, /* 10242 ( 271) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6]  1 */
      121298, /* 10243 ( 271) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6]  1 */
    18544586, /* 10244 ( 271) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    18426650, /* 10245 ( 271) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    52451996, /* 10246 ( 271) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
    18439772, /* 10247 ( 271) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    18557708, /* 10248 ( 271) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    34028708, /* 10249 ( 271) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
       16484, /* 10250 ( 272) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34015586, /* 10251 ( 272) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    34133522, /* 10252 ( 272) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    52556810, /* 10253 ( 272) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    52438874, /* 10254 ( 272) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
      134420, /* 10255 ( 272) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6]  1 */
    18439772, /* 10256 ( 272) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    18557708, /* 10257 ( 272) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
       16484, /* 10258 ( 273) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34133522, /* 10259 ( 273) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    52556810, /* 10260 ( 273) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
        3362, /* 10261 ( 273) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34146644, /* 10262 ( 273) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    52569932, /* 10263 ( 273) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    18426650, /* 10264 ( 273) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    18439772, /* 10265 ( 273) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
       16484, /* 10266 ( 274) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34015586, /* 10267 ( 274) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    52438874, /* 10268 ( 274) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
    34146644, /* 10269 ( 274) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    52569932, /* 10270 ( 274) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
      121298, /* 10271 ( 274) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6]  1 */
    18544586, /* 10272 ( 274) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    18439772, /* 10273 ( 274) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
       16484, /* 10274 ( 275) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    52451834, /* 10275 ( 275) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
    34028546, /* 10276 ( 275) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    52438712, /* 10277 ( 275) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
        3362, /* 10278 ( 275) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
      134420, /* 10279 ( 275) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6]  1 */
      121298, /* 10280 ( 275) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6]  1 */
    18544586, /* 10281 ( 275) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    18426650, /* 10282 ( 275) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    34146806, /* 10283 ( 275) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    34133684, /* 10284 ( 275) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    52556972, /* 10285 ( 275) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    18439772, /* 10286 ( 275) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    18557708, /* 10287 ( 275) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    52570094, /* 10288 ( 275) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    34015424, /* 10289 ( 275) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
       16484, /* 10290 ( 276) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    51152756, /* 10291 ( 276) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
    51034820, /* 10292 ( 276) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  0] -1 */
        3362, /* 10293 ( 276) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    51021698, /* 10294 ( 276) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  0] -1 */
    51139634, /* 10295 ( 276) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
      134420, /* 10296 ( 276) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6]  1 */
    35432762, /* 10297 ( 276) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  0] -1 */
      121298, /* 10298 ( 276) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6]  1 */
    18544586, /* 10299 ( 276) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    18426650, /* 10300 ( 276) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    35445884, /* 10301 ( 276) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  0] -1 */
    35550698, /* 10302 ( 276) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
    18439772, /* 10303 ( 276) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    18557708, /* 10304 ( 276) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    35563820, /* 10305 ( 276) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
       16484, /* 10306 ( 277) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
        3362, /* 10307 ( 277) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    35550860, /* 10308 ( 277) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
    35432600, /* 10309 ( 277) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  0] -1 */
    51034658, /* 10310 ( 277) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  0] -1 */
    35563982, /* 10311 ( 277) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
      134420, /* 10312 ( 277) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6]  1 */
      121298, /* 10313 ( 277) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6]  1 */
    18544586, /* 10314 ( 277) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    18426650, /* 10315 ( 277) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    51139796, /* 10316 ( 277) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
    35445722, /* 10317 ( 277) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  0] -1 */
    51021536, /* 10318 ( 277) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  0] -1 */
    18439772, /* 10319 ( 277) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    18557708, /* 10320 ( 277) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    51152918, /* 10321 ( 277) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
       16484, /* 10322 ( 270) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
       16322, /* 10323 ( 270) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
      121460, /* 10324 ( 270) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6]  1 */
      121298, /* 10325 ( 270) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6]  1 */
    18544586, /* 10326 ( 270) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    18439610, /* 10327 ( 270) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    18439772, /* 10328 ( 270) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    18544748, /* 10329 ( 270) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
       16484, /* 10330 ( 271) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34028546, /* 10331 ( 271) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    34133522, /* 10332 ( 271) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    52556810, /* 10333 ( 271) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
       16322, /* 10334 ( 271) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    52451834, /* 10335 ( 271) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
    34133684, /* 10336 ( 271) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    52556972, /* 10337 ( 271) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
      121460, /* 10338 ( 271) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6]  1 */
      121298, /* 10339 ( 271) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6]  1 */
    18544586, /* 10340 ( 271) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    18439610, /* 10341 ( 271) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    52451996, /* 10342 ( 271) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
    18439772, /* 10343 ( 271) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    18544748, /* 10344 ( 271) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    34028708, /* 10345 ( 271) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
       16484, /* 10346 ( 272) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34028546, /* 10347 ( 272) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    34133522, /* 10348 ( 272) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    52556810, /* 10349 ( 272) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    52451834, /* 10350 ( 272) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
      121460, /* 10351 ( 272) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6]  1 */
    18439772, /* 10352 ( 272) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    18544748, /* 10353 ( 272) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
       16484, /* 10354 ( 273) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34133522, /* 10355 ( 273) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    52556810, /* 10356 ( 273) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
       16322, /* 10357 ( 273) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34133684, /* 10358 ( 273) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    52556972, /* 10359 ( 273) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    18439610, /* 10360 ( 273) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    18439772, /* 10361 ( 273) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
       16484, /* 10362 ( 274) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34028546, /* 10363 ( 274) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    52451834, /* 10364 ( 274) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
    34133684, /* 10365 ( 274) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    52556972, /* 10366 ( 274) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
      121298, /* 10367 ( 274) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6]  1 */
    18544586, /* 10368 ( 274) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    18439772, /* 10369 ( 274) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
       16484, /* 10370 ( 275) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    52438874, /* 10371 ( 275) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
    34015586, /* 10372 ( 275) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    52438712, /* 10373 ( 275) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
       16322, /* 10374 ( 275) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
      121460, /* 10375 ( 275) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6]  1 */
      121298, /* 10376 ( 275) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6]  1 */
    18544586, /* 10377 ( 275) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    18439610, /* 10378 ( 275) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    34146806, /* 10379 ( 275) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    34146644, /* 10380 ( 275) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    52569932, /* 10381 ( 275) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    18439772, /* 10382 ( 275) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    18544748, /* 10383 ( 275) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    52570094, /* 10384 ( 275) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    34015424, /* 10385 ( 275) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
       16484, /* 10386 ( 276) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    35550860, /* 10387 ( 276) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
    35445884, /* 10388 ( 276) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  0] -1 */
       16322, /* 10389 ( 276) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    35445722, /* 10390 ( 276) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  0] -1 */
    35550698, /* 10391 ( 276) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
      121460, /* 10392 ( 276) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6]  1 */
    51034658, /* 10393 ( 276) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  0] -1 */
      121298, /* 10394 ( 276) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6]  1 */
    18544586, /* 10395 ( 276) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    18439610, /* 10396 ( 276) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    51034820, /* 10397 ( 276) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  0] -1 */
    51139634, /* 10398 ( 276) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
    18439772, /* 10399 ( 276) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    18544748, /* 10400 ( 276) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    51139796, /* 10401 ( 276) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
       16484, /* 10402 ( 277) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
       16322, /* 10403 ( 277) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    51152756, /* 10404 ( 277) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
    51021536, /* 10405 ( 277) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  0] -1 */
    35432762, /* 10406 ( 277) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  0] -1 */
    51152918, /* 10407 ( 277) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
      121460, /* 10408 ( 277) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6]  1 */
      121298, /* 10409 ( 277) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6]  1 */
    18544586, /* 10410 ( 277) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    18439610, /* 10411 ( 277) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    35563820, /* 10412 ( 277) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
    51021698, /* 10413 ( 277) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  0] -1 */
    35432600, /* 10414 ( 277) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  0] -1 */
    18439772, /* 10415 ( 277) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    18544748, /* 10416 ( 277) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    35563982, /* 10417 ( 277) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
       16484, /* 10418 ( 270) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
       16322, /* 10419 ( 270) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    17022594, /* 10420 ( 270) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  0]  1 */
    17022432, /* 10421 ( 270) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  0]  1 */
    18557706, /* 10422 ( 270) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
     1551596, /* 10423 ( 270) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
     1551758, /* 10424 ( 270) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
    18557868, /* 10425 ( 270) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
       16484, /* 10426 ( 271) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34028546, /* 10427 ( 271) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    51034656, /* 10428 ( 271) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  0] -1 */
    52569930, /* 10429 ( 271) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
       16322, /* 10430 ( 271) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    35563820, /* 10431 ( 271) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
    51034818, /* 10432 ( 271) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  0] -1 */
    52570092, /* 10433 ( 271) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    17022594, /* 10434 ( 271) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  0]  1 */
    17022432, /* 10435 ( 271) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  0]  1 */
    18557706, /* 10436 ( 271) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
     1551596, /* 10437 ( 271) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
    35563982, /* 10438 ( 271) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
     1551758, /* 10439 ( 271) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
    18557868, /* 10440 ( 271) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
    34028708, /* 10441 ( 271) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
       16484, /* 10442 ( 272) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34028546, /* 10443 ( 272) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    51034656, /* 10444 ( 272) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  0] -1 */
    52569930, /* 10445 ( 272) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    35563820, /* 10446 ( 272) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
    17022594, /* 10447 ( 272) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  0]  1 */
     1551758, /* 10448 ( 272) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
    18557868, /* 10449 ( 272) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
       16484, /* 10450 ( 273) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    51034656, /* 10451 ( 273) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  0] -1 */
    52569930, /* 10452 ( 273) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
       16322, /* 10453 ( 273) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    51034818, /* 10454 ( 273) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  0] -1 */
    52570092, /* 10455 ( 273) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
     1551596, /* 10456 ( 273) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
     1551758, /* 10457 ( 273) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
       16484, /* 10458 ( 274) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34028546, /* 10459 ( 274) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    35563820, /* 10460 ( 274) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
    51034818, /* 10461 ( 274) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  0] -1 */
    52570092, /* 10462 ( 274) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    17022432, /* 10463 ( 274) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  0]  1 */
    18557706, /* 10464 ( 274) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
     1551758, /* 10465 ( 274) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
       16484, /* 10466 ( 275) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    35563980, /* 10467 ( 275) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6] -1 */
    34028706, /* 10468 ( 275) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    35563818, /* 10469 ( 275) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  6] -1 */
       16322, /* 10470 ( 275) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    17022594, /* 10471 ( 275) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  0]  1 */
    17022432, /* 10472 ( 275) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  0]  1 */
    18557706, /* 10473 ( 275) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
     1551596, /* 10474 ( 275) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
    51034820, /* 10475 ( 275) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  0] -1 */
    51034658, /* 10476 ( 275) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  0] -1 */
    52569932, /* 10477 ( 275) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
     1551758, /* 10478 ( 275) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
    18557868, /* 10479 ( 275) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
    52570094, /* 10480 ( 275) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    34028544, /* 10481 ( 275) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
       16484, /* 10482 ( 276) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    52451994, /* 10483 ( 276) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
    35445884, /* 10484 ( 276) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  0] -1 */
       16322, /* 10485 ( 276) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    35445722, /* 10486 ( 276) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  0] -1 */
    52451832, /* 10487 ( 276) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
    17022594, /* 10488 ( 276) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  0]  1 */
    34146644, /* 10489 ( 276) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    17022432, /* 10490 ( 276) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  0]  1 */
    18557706, /* 10491 ( 276) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
     1551596, /* 10492 ( 276) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
    34146806, /* 10493 ( 276) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    51152754, /* 10494 ( 276) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  6] -1 */
     1551758, /* 10495 ( 276) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
    18557868, /* 10496 ( 276) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
    51152916, /* 10497 ( 276) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6] -1 */
       16484, /* 10498 ( 277) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
       16322, /* 10499 ( 277) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    51152756, /* 10500 ( 277) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
    34146642, /* 10501 ( 277) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
    35445882, /* 10502 ( 277) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  0] -1 */
    51152918, /* 10503 ( 277) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
    17022594, /* 10504 ( 277) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  0]  1 */
    17022432, /* 10505 ( 277) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  0]  1 */
    18557706, /* 10506 ( 277) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
     1551596, /* 10507 ( 277) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
    52451834, /* 10508 ( 277) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
    34146804, /* 10509 ( 277) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
    35445720, /* 10510 ( 277) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  0] -1 */
     1551758, /* 10511 ( 277) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
    18557868, /* 10512 ( 277) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
    52451996, /* 10513 ( 277) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
       16484, /* 10514 ( 270) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
       16482, /* 10515 ( 270) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    17022434, /* 10516 ( 270) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  0]  1 */
    17022432, /* 10517 ( 270) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  0]  1 */
    18557706, /* 10518 ( 270) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
     1551756, /* 10519 ( 270) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
     1551758, /* 10520 ( 270) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
    18557708, /* 10521 ( 270) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
       16484, /* 10522 ( 271) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34028706, /* 10523 ( 271) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    51034656, /* 10524 ( 271) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  0] -1 */
    52569930, /* 10525 ( 271) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
       16482, /* 10526 ( 271) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    35563980, /* 10527 ( 271) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6] -1 */
    51034658, /* 10528 ( 271) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  0] -1 */
    52569932, /* 10529 ( 271) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    17022434, /* 10530 ( 271) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  0]  1 */
    17022432, /* 10531 ( 271) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  0]  1 */
    18557706, /* 10532 ( 271) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
     1551756, /* 10533 ( 271) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
    35563982, /* 10534 ( 271) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
     1551758, /* 10535 ( 271) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
    18557708, /* 10536 ( 271) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    34028708, /* 10537 ( 271) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
       16484, /* 10538 ( 272) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34028706, /* 10539 ( 272) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    51034656, /* 10540 ( 272) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  0] -1 */
    52569930, /* 10541 ( 272) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    35563980, /* 10542 ( 272) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6] -1 */
    17022434, /* 10543 ( 272) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  0]  1 */
     1551758, /* 10544 ( 272) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
    18557708, /* 10545 ( 272) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
       16484, /* 10546 ( 273) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    51034656, /* 10547 ( 273) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  0] -1 */
    52569930, /* 10548 ( 273) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
       16482, /* 10549 ( 273) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    51034658, /* 10550 ( 273) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  0] -1 */
    52569932, /* 10551 ( 273) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
     1551756, /* 10552 ( 273) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
     1551758, /* 10553 ( 273) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
       16484, /* 10554 ( 274) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34028706, /* 10555 ( 274) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    35563980, /* 10556 ( 274) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6] -1 */
    51034658, /* 10557 ( 274) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  0] -1 */
    52569932, /* 10558 ( 274) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    17022432, /* 10559 ( 274) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  0]  1 */
    18557706, /* 10560 ( 274) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
     1551758, /* 10561 ( 274) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
       16484, /* 10562 ( 275) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    35563820, /* 10563 ( 275) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
    34028546, /* 10564 ( 275) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    35563818, /* 10565 ( 275) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  6] -1 */
       16482, /* 10566 ( 275) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    17022434, /* 10567 ( 275) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  0]  1 */
    17022432, /* 10568 ( 275) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  0]  1 */
    18557706, /* 10569 ( 275) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
     1551756, /* 10570 ( 275) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
    51034820, /* 10571 ( 275) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  0] -1 */
    51034818, /* 10572 ( 275) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  0] -1 */
    52570092, /* 10573 ( 275) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
     1551758, /* 10574 ( 275) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
    18557708, /* 10575 ( 275) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    52570094, /* 10576 ( 275) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    34028544, /* 10577 ( 275) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
       16484, /* 10578 ( 276) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    51152756, /* 10579 ( 276) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
    34146806, /* 10580 ( 276) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
       16482, /* 10581 ( 276) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    34146804, /* 10582 ( 276) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
    51152754, /* 10583 ( 276) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  6] -1 */
    17022434, /* 10584 ( 276) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  0]  1 */
    35445882, /* 10585 ( 276) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  0] -1 */
    17022432, /* 10586 ( 276) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  0]  1 */
    18557706, /* 10587 ( 276) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
     1551756, /* 10588 ( 276) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
    35445884, /* 10589 ( 276) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  0] -1 */
    52451832, /* 10590 ( 276) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
     1551758, /* 10591 ( 276) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
    18557708, /* 10592 ( 276) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    52451834, /* 10593 ( 276) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
       16484, /* 10594 ( 277) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
       16482, /* 10595 ( 277) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    52451994, /* 10596 ( 277) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
    35445720, /* 10597 ( 277) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  0] -1 */
    34146644, /* 10598 ( 277) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    52451996, /* 10599 ( 277) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
    17022434, /* 10600 ( 277) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  0]  1 */
    17022432, /* 10601 ( 277) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  0]  1 */
    18557706, /* 10602 ( 277) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
     1551756, /* 10603 ( 277) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
    51152916, /* 10604 ( 277) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6] -1 */
    35445722, /* 10605 ( 277) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  0] -1 */
    34146642, /* 10606 ( 277) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
     1551758, /* 10607 ( 277) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
    18557708, /* 10608 ( 277) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    51152918, /* 10609 ( 277) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
       16484, /* 10610 ( 270) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
       16482, /* 10611 ( 270) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
     1420538, /* 10612 ( 270) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  0]  1 */
     1420536, /* 10613 ( 270) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  0]  1 */
    18544746, /* 10614 ( 270) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
    17140692, /* 10615 ( 270) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6]  1 */
    17140694, /* 10616 ( 270) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
    18544748, /* 10617 ( 270) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
       16484, /* 10618 ( 271) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34028706, /* 10619 ( 271) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    35432760, /* 10620 ( 271) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  0] -1 */
    52556970, /* 10621 ( 271) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
       16482, /* 10622 ( 271) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    51152916, /* 10623 ( 271) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6] -1 */
    35432762, /* 10624 ( 271) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  0] -1 */
    52556972, /* 10625 ( 271) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
     1420538, /* 10626 ( 271) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  0]  1 */
     1420536, /* 10627 ( 271) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  0]  1 */
    18544746, /* 10628 ( 271) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
    17140692, /* 10629 ( 271) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6]  1 */
    51152918, /* 10630 ( 271) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
    17140694, /* 10631 ( 271) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
    18544748, /* 10632 ( 271) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    34028708, /* 10633 ( 271) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
       16484, /* 10634 ( 272) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34028706, /* 10635 ( 272) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    35432760, /* 10636 ( 272) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  0] -1 */
    52556970, /* 10637 ( 272) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    51152916, /* 10638 ( 272) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6] -1 */
     1420538, /* 10639 ( 272) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  0]  1 */
    17140694, /* 10640 ( 272) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
    18544748, /* 10641 ( 272) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
       16484, /* 10642 ( 273) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    35432760, /* 10643 ( 273) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  0] -1 */
    52556970, /* 10644 ( 273) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
       16482, /* 10645 ( 273) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    35432762, /* 10646 ( 273) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  0] -1 */
    52556972, /* 10647 ( 273) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    17140692, /* 10648 ( 273) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6]  1 */
    17140694, /* 10649 ( 273) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
       16484, /* 10650 ( 274) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34028706, /* 10651 ( 274) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    51152916, /* 10652 ( 274) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6] -1 */
    35432762, /* 10653 ( 274) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  0] -1 */
    52556972, /* 10654 ( 274) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
     1420536, /* 10655 ( 274) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  0]  1 */
    18544746, /* 10656 ( 274) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
    17140694, /* 10657 ( 274) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
       16484, /* 10658 ( 275) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    51139796, /* 10659 ( 275) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
    34015586, /* 10660 ( 275) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    51139794, /* 10661 ( 275) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6] -1 */
       16482, /* 10662 ( 275) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
     1420538, /* 10663 ( 275) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  0]  1 */
     1420536, /* 10664 ( 275) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  0]  1 */
    18544746, /* 10665 ( 275) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
    17140692, /* 10666 ( 275) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6]  1 */
    35445884, /* 10667 ( 275) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  0] -1 */
    35445882, /* 10668 ( 275) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  0] -1 */
    52570092, /* 10669 ( 275) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    17140694, /* 10670 ( 275) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
    18544748, /* 10671 ( 275) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    52570094, /* 10672 ( 275) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    34015584, /* 10673 ( 275) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
       16484, /* 10674 ( 276) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    35550860, /* 10675 ( 276) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
    34146806, /* 10676 ( 276) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
       16482, /* 10677 ( 276) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    34146804, /* 10678 ( 276) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
    35550858, /* 10679 ( 276) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6] -1 */
     1420538, /* 10680 ( 276) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  0]  1 */
    51034818, /* 10681 ( 276) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  0] -1 */
     1420536, /* 10682 ( 276) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  0]  1 */
    18544746, /* 10683 ( 276) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
    17140692, /* 10684 ( 276) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6]  1 */
    51034820, /* 10685 ( 276) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  0] -1 */
    52438872, /* 10686 ( 276) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
    17140694, /* 10687 ( 276) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
    18544748, /* 10688 ( 276) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    52438874, /* 10689 ( 276) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
       16484, /* 10690 ( 277) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
       16482, /* 10691 ( 277) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    52451994, /* 10692 ( 277) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
    51021696, /* 10693 ( 277) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  0] -1 */
    34133684, /* 10694 ( 277) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    52451996, /* 10695 ( 277) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
     1420538, /* 10696 ( 277) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  0]  1 */
     1420536, /* 10697 ( 277) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  0]  1 */
    18544746, /* 10698 ( 277) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
    17140692, /* 10699 ( 277) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6]  1 */
    35563980, /* 10700 ( 277) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6] -1 */
    51021698, /* 10701 ( 277) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  0] -1 */
    34133682, /* 10702 ( 277) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
    17140694, /* 10703 ( 277) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
    18544748, /* 10704 ( 277) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    35563982, /* 10705 ( 277) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
       16484, /* 10706 ( 270) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
        3362, /* 10707 ( 270) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
     1433658, /* 10708 ( 270) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  0]  1 */
     1420536, /* 10709 ( 270) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  0]  1 */
    18544746, /* 10710 ( 270) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
    17127572, /* 10711 ( 270) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
    17140694, /* 10712 ( 270) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
    18557868, /* 10713 ( 270) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
       16484, /* 10714 ( 271) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34015586, /* 10715 ( 271) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    35432760, /* 10716 ( 271) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  0] -1 */
    52556970, /* 10717 ( 271) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
        3362, /* 10718 ( 271) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    51139796, /* 10719 ( 271) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
    35445882, /* 10720 ( 271) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  0] -1 */
    52570092, /* 10721 ( 271) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
     1433658, /* 10722 ( 271) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  0]  1 */
     1420536, /* 10723 ( 271) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  0]  1 */
    18544746, /* 10724 ( 271) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
    17127572, /* 10725 ( 271) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
    51152918, /* 10726 ( 271) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
    17140694, /* 10727 ( 271) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
    18557868, /* 10728 ( 271) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
    34028708, /* 10729 ( 271) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
       16484, /* 10730 ( 272) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34015586, /* 10731 ( 272) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    35432760, /* 10732 ( 272) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  0] -1 */
    52556970, /* 10733 ( 272) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    51139796, /* 10734 ( 272) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
     1433658, /* 10735 ( 272) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  0]  1 */
    17140694, /* 10736 ( 272) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
    18557868, /* 10737 ( 272) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
       16484, /* 10738 ( 273) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    35432760, /* 10739 ( 273) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  0] -1 */
    52556970, /* 10740 ( 273) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
        3362, /* 10741 ( 273) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    35445882, /* 10742 ( 273) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  0] -1 */
    52570092, /* 10743 ( 273) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    17127572, /* 10744 ( 273) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
    17140694, /* 10745 ( 273) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
       16484, /* 10746 ( 274) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34015586, /* 10747 ( 274) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    51139796, /* 10748 ( 274) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
    35445882, /* 10749 ( 274) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  0] -1 */
    52570092, /* 10750 ( 274) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
     1420536, /* 10751 ( 274) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  0]  1 */
    18544746, /* 10752 ( 274) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
    17140694, /* 10753 ( 274) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
       16484, /* 10754 ( 275) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    51152916, /* 10755 ( 275) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6] -1 */
    34028706, /* 10756 ( 275) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    51139794, /* 10757 ( 275) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6] -1 */
        3362, /* 10758 ( 275) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
     1433658, /* 10759 ( 275) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  0]  1 */
     1420536, /* 10760 ( 275) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  0]  1 */
    18544746, /* 10761 ( 275) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
    17127572, /* 10762 ( 275) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
    35445884, /* 10763 ( 275) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  0] -1 */
    35432762, /* 10764 ( 275) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  0] -1 */
    52556972, /* 10765 ( 275) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    17140694, /* 10766 ( 275) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
    18557868, /* 10767 ( 275) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
    52570094, /* 10768 ( 275) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    34015584, /* 10769 ( 275) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
       16484, /* 10770 ( 276) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    52451994, /* 10771 ( 276) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
    51034820, /* 10772 ( 276) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  0] -1 */
        3362, /* 10773 ( 276) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    51021698, /* 10774 ( 276) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  0] -1 */
    52438872, /* 10775 ( 276) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
     1433658, /* 10776 ( 276) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  0]  1 */
    34133684, /* 10777 ( 276) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
     1420536, /* 10778 ( 276) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  0]  1 */
    18544746, /* 10779 ( 276) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
    17127572, /* 10780 ( 276) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
    34146806, /* 10781 ( 276) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    35550858, /* 10782 ( 276) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6] -1 */
    17140694, /* 10783 ( 276) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
    18557868, /* 10784 ( 276) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
    35563980, /* 10785 ( 276) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6] -1 */
       16484, /* 10786 ( 277) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
        3362, /* 10787 ( 277) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    35550860, /* 10788 ( 277) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
    34133682, /* 10789 ( 277) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
    51034818, /* 10790 ( 277) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  0] -1 */
    35563982, /* 10791 ( 277) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
     1433658, /* 10792 ( 277) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  0]  1 */
     1420536, /* 10793 ( 277) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  0]  1 */
    18544746, /* 10794 ( 277) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
    17127572, /* 10795 ( 277) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
    52438874, /* 10796 ( 277) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
    34146804, /* 10797 ( 277) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
    51021696, /* 10798 ( 277) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  0] -1 */
    17140694, /* 10799 ( 277) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
    18557868, /* 10800 ( 277) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
    52451996, /* 10801 ( 277) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
       16484, /* 10802 ( 278) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    18426488, /* 10803 ( 278) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
      121460, /* 10804 ( 278) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6]  1 */
        3200, /* 10805 ( 278) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
      134420, /* 10806 ( 278) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6]  1 */
    18439772, /* 10807 ( 278) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    18557708, /* 10808 ( 278) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    18544748, /* 10809 ( 278) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
       16484, /* 10810 ( 279) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    18426488, /* 10811 ( 279) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
      121460, /* 10812 ( 279) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6]  1 */
    52438712, /* 10813 ( 279) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
        3200, /* 10814 ( 279) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34146644, /* 10815 ( 279) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    52569932, /* 10816 ( 279) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
      134420, /* 10817 ( 279) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6]  1 */
    52451996, /* 10818 ( 279) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
    34133684, /* 10819 ( 279) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    52556972, /* 10820 ( 279) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    18439772, /* 10821 ( 279) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    18557708, /* 10822 ( 279) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    34028708, /* 10823 ( 279) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    18544748, /* 10824 ( 279) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    34015424, /* 10825 ( 279) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
       16484, /* 10826 ( 280) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
      121460, /* 10827 ( 280) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6]  1 */
    34146644, /* 10828 ( 280) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    52569932, /* 10829 ( 280) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    18439772, /* 10830 ( 280) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    52438712, /* 10831 ( 280) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
    18544748, /* 10832 ( 280) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    34015424, /* 10833 ( 280) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
       16484, /* 10834 ( 281) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    18426488, /* 10835 ( 281) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
        3200, /* 10836 ( 281) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34146644, /* 10837 ( 281) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    52569932, /* 10838 ( 281) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    34133684, /* 10839 ( 281) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    52556972, /* 10840 ( 281) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    18439772, /* 10841 ( 281) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
       16484, /* 10842 ( 282) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
      121460, /* 10843 ( 282) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6]  1 */
    34015586, /* 10844 ( 282) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    18439610, /* 10845 ( 282) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    34146644, /* 10846 ( 282) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    52569932, /* 10847 ( 282) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    52438874, /* 10848 ( 282) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
    52570094, /* 10849 ( 282) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
      121298, /* 10850 ( 282) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6]  1 */
    18544586, /* 10851 ( 282) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    34146806, /* 10852 ( 282) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    18439772, /* 10853 ( 282) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    52438712, /* 10854 ( 282) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
    18544748, /* 10855 ( 282) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    34015424, /* 10856 ( 282) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
       16322, /* 10857 ( 282) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
       16484, /* 10858 ( 283) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
      121460, /* 10859 ( 283) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6]  1 */
    17009312, /* 10860 ( 283) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  0]  1 */
    51034820, /* 10861 ( 283) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  0] -1 */
    35550860, /* 10862 ( 283) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
    34146644, /* 10863 ( 283) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    52569932, /* 10864 ( 283) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
     1551596, /* 10865 ( 283) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
    51139796, /* 10866 ( 283) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
     1420376, /* 10867 ( 283) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  0]  1 */
    35445884, /* 10868 ( 283) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  0] -1 */
    17140532, /* 10869 ( 283) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
    18439772, /* 10870 ( 283) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    52438712, /* 10871 ( 283) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
    18544748, /* 10872 ( 283) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    34015424, /* 10873 ( 283) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
       16484, /* 10874 ( 284) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
      121460, /* 10875 ( 284) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6]  1 */
     1538474, /* 10876 ( 284) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
    51021698, /* 10877 ( 284) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  0] -1 */
    34146644, /* 10878 ( 284) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    52569932, /* 10879 ( 284) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    17022434, /* 10880 ( 284) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  0]  1 */
    35432762, /* 10881 ( 284) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  0] -1 */
    35563982, /* 10882 ( 284) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
    17127410, /* 10883 ( 284) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
    18439772, /* 10884 ( 284) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    52438712, /* 10885 ( 284) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
     1433498, /* 10886 ( 284) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  0]  1 */
    18544748, /* 10887 ( 284) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    34015424, /* 10888 ( 284) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    51152918, /* 10889 ( 284) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
       16484, /* 10890 ( 278) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
     1551594, /* 10891 ( 278) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
    17022434, /* 10892 ( 278) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  0]  1 */
       16320, /* 10893 ( 278) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    17022594, /* 10894 ( 278) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  0]  1 */
     1551758, /* 10895 ( 278) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
    18557868, /* 10896 ( 278) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
    18557708, /* 10897 ( 278) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
       16484, /* 10898 ( 279) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
     1551594, /* 10899 ( 279) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
    17022434, /* 10900 ( 279) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  0]  1 */
    35563818, /* 10901 ( 279) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  6] -1 */
       16320, /* 10902 ( 279) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    51034818, /* 10903 ( 279) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  0] -1 */
    52570092, /* 10904 ( 279) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    17022594, /* 10905 ( 279) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  0]  1 */
    35563982, /* 10906 ( 279) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
    51034658, /* 10907 ( 279) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  0] -1 */
    52569932, /* 10908 ( 279) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
     1551758, /* 10909 ( 279) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
    18557868, /* 10910 ( 279) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
    34028708, /* 10911 ( 279) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    18557708, /* 10912 ( 279) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    34028544, /* 10913 ( 279) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
       16484, /* 10914 ( 280) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    17022434, /* 10915 ( 280) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  0]  1 */
    51034818, /* 10916 ( 280) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  0] -1 */
    52570092, /* 10917 ( 280) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
     1551758, /* 10918 ( 280) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
    35563818, /* 10919 ( 280) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  6] -1 */
    18557708, /* 10920 ( 280) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    34028544, /* 10921 ( 280) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
       16484, /* 10922 ( 281) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
     1551594, /* 10923 ( 281) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
       16320, /* 10924 ( 281) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    51034818, /* 10925 ( 281) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  0] -1 */
    52570092, /* 10926 ( 281) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    51034658, /* 10927 ( 281) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  0] -1 */
    52569932, /* 10928 ( 281) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
     1551758, /* 10929 ( 281) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
       16484, /* 10930 ( 282) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    17022434, /* 10931 ( 282) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  0]  1 */
    34028546, /* 10932 ( 282) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
     1551756, /* 10933 ( 282) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
    51034818, /* 10934 ( 282) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  0] -1 */
    52570092, /* 10935 ( 282) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    35563820, /* 10936 ( 282) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
    52570094, /* 10937 ( 282) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    17022432, /* 10938 ( 282) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  0]  1 */
    18557706, /* 10939 ( 282) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
    51034820, /* 10940 ( 282) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  0] -1 */
     1551758, /* 10941 ( 282) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
    35563818, /* 10942 ( 282) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  6] -1 */
    18557708, /* 10943 ( 282) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    34028544, /* 10944 ( 282) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
       16482, /* 10945 ( 282) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
       16484, /* 10946 ( 283) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    17022434, /* 10947 ( 283) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  0]  1 */
     1433496, /* 10948 ( 283) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  0]  1 */
    35445884, /* 10949 ( 283) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  0] -1 */
    51152756, /* 10950 ( 283) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
    51034818, /* 10951 ( 283) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  0] -1 */
    52570092, /* 10952 ( 283) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    17140692, /* 10953 ( 283) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6]  1 */
    52451834, /* 10954 ( 283) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
      134418, /* 10955 ( 283) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  6]  1 */
    34146806, /* 10956 ( 283) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    18439770, /* 10957 ( 283) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
     1551758, /* 10958 ( 283) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
    35563818, /* 10959 ( 283) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  6] -1 */
    18557708, /* 10960 ( 283) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    34028544, /* 10961 ( 283) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
       16484, /* 10962 ( 284) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    17022434, /* 10963 ( 284) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  0]  1 */
    17140530, /* 10964 ( 284) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  6]  1 */
    35445722, /* 10965 ( 284) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  0] -1 */
    51034818, /* 10966 ( 284) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  0] -1 */
    52570092, /* 10967 ( 284) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
     1433658, /* 10968 ( 284) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  0]  1 */
    34146644, /* 10969 ( 284) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    51152918, /* 10970 ( 284) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
    18439608, /* 10971 ( 284) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
     1551758, /* 10972 ( 284) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
    35563818, /* 10973 ( 284) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  6] -1 */
      134580, /* 10974 ( 284) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  6]  1 */
    18557708, /* 10975 ( 284) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    34028544, /* 10976 ( 284) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    52451996, /* 10977 ( 284) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
       16484, /* 10978 ( 278) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    17127570, /* 10979 ( 278) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6]  1 */
     1433658, /* 10980 ( 278) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  0]  1 */
        3360, /* 10981 ( 278) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
     1420538, /* 10982 ( 278) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  0]  1 */
    17140694, /* 10983 ( 278) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
    18544748, /* 10984 ( 278) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    18557868, /* 10985 ( 278) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
       16484, /* 10986 ( 279) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    17127570, /* 10987 ( 279) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6]  1 */
     1433658, /* 10988 ( 279) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  0]  1 */
    51139794, /* 10989 ( 279) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6] -1 */
        3360, /* 10990 ( 279) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    35432762, /* 10991 ( 279) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  0] -1 */
    52556972, /* 10992 ( 279) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
     1420538, /* 10993 ( 279) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  0]  1 */
    51152918, /* 10994 ( 279) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
    35445882, /* 10995 ( 279) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  0] -1 */
    52570092, /* 10996 ( 279) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    17140694, /* 10997 ( 279) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
    18544748, /* 10998 ( 279) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    34028708, /* 10999 ( 279) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    18557868, /* 11000 ( 279) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
    34015584, /* 11001 ( 279) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
       16484, /* 11002 ( 280) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
     1433658, /* 11003 ( 280) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  0]  1 */
    35432762, /* 11004 ( 280) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  0] -1 */
    52556972, /* 11005 ( 280) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    17140694, /* 11006 ( 280) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
    51139794, /* 11007 ( 280) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6] -1 */
    18557868, /* 11008 ( 280) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
    34015584, /* 11009 ( 280) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
       16484, /* 11010 ( 281) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    17127570, /* 11011 ( 281) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6]  1 */
        3360, /* 11012 ( 281) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    35432762, /* 11013 ( 281) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  0] -1 */
    52556972, /* 11014 ( 281) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    35445882, /* 11015 ( 281) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  0] -1 */
    52570092, /* 11016 ( 281) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    17140694, /* 11017 ( 281) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
       16484, /* 11018 ( 282) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
     1433658, /* 11019 ( 282) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  0]  1 */
    34028706, /* 11020 ( 282) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    17127572, /* 11021 ( 282) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
    35432762, /* 11022 ( 282) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  0] -1 */
    52556972, /* 11023 ( 282) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    51152916, /* 11024 ( 282) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6] -1 */
    52570094, /* 11025 ( 282) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
     1420536, /* 11026 ( 282) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  0]  1 */
    18544746, /* 11027 ( 282) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
    35445884, /* 11028 ( 282) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  0] -1 */
    17140694, /* 11029 ( 282) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
    51139794, /* 11030 ( 282) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6] -1 */
    18557868, /* 11031 ( 282) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
    34015584, /* 11032 ( 282) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
        3362, /* 11033 ( 282) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
       16484, /* 11034 ( 283) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
     1433658, /* 11035 ( 283) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  0]  1 */
      121458, /* 11036 ( 283) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  6]  1 */
    34146806, /* 11037 ( 283) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    52451994, /* 11038 ( 283) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
    35432762, /* 11039 ( 283) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  0] -1 */
    52556972, /* 11040 ( 283) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    18426650, /* 11041 ( 283) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    35563980, /* 11042 ( 283) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6] -1 */
    17009472, /* 11043 ( 283) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  0]  1 */
    51034820, /* 11044 ( 283) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  0] -1 */
     1538636, /* 11045 ( 283) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
    17140694, /* 11046 ( 283) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
    51139794, /* 11047 ( 283) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6] -1 */
    18557868, /* 11048 ( 283) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
    34015584, /* 11049 ( 283) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
       16484, /* 11050 ( 284) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
     1433658, /* 11051 ( 284) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  0]  1 */
    18426648, /* 11052 ( 284) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
    34146804, /* 11053 ( 284) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
    35432762, /* 11054 ( 284) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  0] -1 */
    52556972, /* 11055 ( 284) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
      121460, /* 11056 ( 284) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6]  1 */
    51034818, /* 11057 ( 284) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  0] -1 */
    52451996, /* 11058 ( 284) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
     1538634, /* 11059 ( 284) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
    17140694, /* 11060 ( 284) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
    51139794, /* 11061 ( 284) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6] -1 */
    17009474, /* 11062 ( 284) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  0]  1 */
    18557868, /* 11063 ( 284) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
    34015584, /* 11064 ( 284) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    35563982, /* 11065 ( 284) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
       16484, /* 11066 ( 285) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
     1538474, /* 11067 ( 285) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
        3200, /* 11068 ( 285) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
        3362, /* 11069 ( 285) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
     1551596, /* 11070 ( 285) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
     1538636, /* 11071 ( 285) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
     1551758, /* 11072 ( 285) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
       16322, /* 11073 ( 285) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
       16484, /* 11074 ( 286) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34015586, /* 11075 ( 286) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    34028546, /* 11076 ( 286) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
     1538474, /* 11077 ( 286) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
        3200, /* 11078 ( 286) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
        3362, /* 11079 ( 286) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    35550860, /* 11080 ( 286) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
     1551596, /* 11081 ( 286) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
     1538636, /* 11082 ( 286) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
    35563982, /* 11083 ( 286) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
     1551758, /* 11084 ( 286) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
    35550698, /* 11085 ( 286) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
    34015424, /* 11086 ( 286) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    34028708, /* 11087 ( 286) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    35563820, /* 11088 ( 286) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
       16322, /* 11089 ( 286) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
       16484, /* 11090 ( 287) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34015586, /* 11091 ( 287) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    35550860, /* 11092 ( 287) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
     1551596, /* 11093 ( 287) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
     1551758, /* 11094 ( 287) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
    35550698, /* 11095 ( 287) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
    34015424, /* 11096 ( 287) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
       16322, /* 11097 ( 287) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
       16484, /* 11098 ( 288) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34028546, /* 11099 ( 288) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
        3362, /* 11100 ( 288) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
     1538636, /* 11101 ( 288) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
     1551758, /* 11102 ( 288) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
    35550698, /* 11103 ( 288) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
    34015424, /* 11104 ( 288) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    35563820, /* 11105 ( 288) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
       16484, /* 11106 ( 289) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34015586, /* 11107 ( 289) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
     1538474, /* 11108 ( 289) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
        3200, /* 11109 ( 289) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    35550860, /* 11110 ( 289) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
     1551758, /* 11111 ( 289) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
    34028546, /* 11112 ( 289) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    35563820, /* 11113 ( 289) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
       16484, /* 11114 ( 290) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    52556810, /* 11115 ( 290) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
     1538474, /* 11116 ( 290) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
        3200, /* 11117 ( 290) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
        3362, /* 11118 ( 290) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    51034820, /* 11119 ( 290) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  0] -1 */
    51021698, /* 11120 ( 290) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  0] -1 */
    52569932, /* 11121 ( 290) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
     1551596, /* 11122 ( 290) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
    51034658, /* 11123 ( 290) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  0] -1 */
     1538636, /* 11124 ( 290) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
    52556972, /* 11125 ( 290) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
     1551758, /* 11126 ( 290) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
    51021536, /* 11127 ( 290) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  0] -1 */
    52570094, /* 11128 ( 290) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
       16322, /* 11129 ( 290) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
       16484, /* 11130 ( 291) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34133522, /* 11131 ( 291) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
     1538474, /* 11132 ( 291) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
        3200, /* 11133 ( 291) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
        3362, /* 11134 ( 291) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34146644, /* 11135 ( 291) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    35432600, /* 11136 ( 291) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  0] -1 */
     1551596, /* 11137 ( 291) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
    35432762, /* 11138 ( 291) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  0] -1 */
     1538636, /* 11139 ( 291) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
    35445722, /* 11140 ( 291) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  0] -1 */
    34146806, /* 11141 ( 291) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    35445884, /* 11142 ( 291) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  0] -1 */
     1551758, /* 11143 ( 291) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
    34133684, /* 11144 ( 291) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
       16322, /* 11145 ( 291) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
       16484, /* 11146 ( 292) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    52451834, /* 11147 ( 292) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
     1538474, /* 11148 ( 292) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
        3200, /* 11149 ( 292) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    51152756, /* 11150 ( 292) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
        3362, /* 11151 ( 292) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    52438874, /* 11152 ( 292) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
     1551596, /* 11153 ( 292) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
    51139634, /* 11154 ( 292) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
     1538636, /* 11155 ( 292) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
    52451996, /* 11156 ( 292) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
    51139796, /* 11157 ( 292) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
     1551758, /* 11158 ( 292) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
    51152918, /* 11159 ( 292) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
    52438712, /* 11160 ( 292) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
       16322, /* 11161 ( 292) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
       16484, /* 11162 ( 285) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    17127410, /* 11163 ( 285) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
        3200, /* 11164 ( 285) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
       16322, /* 11165 ( 285) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    17127572, /* 11166 ( 285) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
    17140532, /* 11167 ( 285) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
    17140694, /* 11168 ( 285) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
        3362, /* 11169 ( 285) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
       16484, /* 11170 ( 286) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34028546, /* 11171 ( 286) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    34015586, /* 11172 ( 286) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    17127410, /* 11173 ( 286) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
        3200, /* 11174 ( 286) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
       16322, /* 11175 ( 286) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    51152756, /* 11176 ( 286) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
    17127572, /* 11177 ( 286) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
    17140532, /* 11178 ( 286) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
    51152918, /* 11179 ( 286) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
    17140694, /* 11180 ( 286) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
    51139634, /* 11181 ( 286) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
    34015424, /* 11182 ( 286) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    34028708, /* 11183 ( 286) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    51139796, /* 11184 ( 286) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
        3362, /* 11185 ( 286) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
       16484, /* 11186 ( 287) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34028546, /* 11187 ( 287) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    51152756, /* 11188 ( 287) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
    17127572, /* 11189 ( 287) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
    17140694, /* 11190 ( 287) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
    51139634, /* 11191 ( 287) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
    34015424, /* 11192 ( 287) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
        3362, /* 11193 ( 287) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
       16484, /* 11194 ( 288) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34015586, /* 11195 ( 288) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
       16322, /* 11196 ( 288) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    17140532, /* 11197 ( 288) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
    17140694, /* 11198 ( 288) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
    51139634, /* 11199 ( 288) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
    34015424, /* 11200 ( 288) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    51139796, /* 11201 ( 288) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
       16484, /* 11202 ( 289) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34028546, /* 11203 ( 289) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    17127410, /* 11204 ( 289) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
        3200, /* 11205 ( 289) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    51152756, /* 11206 ( 289) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
    17140694, /* 11207 ( 289) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
    34015586, /* 11208 ( 289) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    51139796, /* 11209 ( 289) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
       16484, /* 11210 ( 290) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    52556810, /* 11211 ( 290) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    17127410, /* 11212 ( 290) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
        3200, /* 11213 ( 290) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
       16322, /* 11214 ( 290) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    35445884, /* 11215 ( 290) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  0] -1 */
    35445722, /* 11216 ( 290) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  0] -1 */
    52556972, /* 11217 ( 290) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    17127572, /* 11218 ( 290) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
    35432762, /* 11219 ( 290) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  0] -1 */
    17140532, /* 11220 ( 290) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
    52569932, /* 11221 ( 290) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    17140694, /* 11222 ( 290) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
    35432600, /* 11223 ( 290) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  0] -1 */
    52570094, /* 11224 ( 290) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
        3362, /* 11225 ( 290) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
       16484, /* 11226 ( 291) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34133522, /* 11227 ( 291) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    17127410, /* 11228 ( 291) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
        3200, /* 11229 ( 291) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
       16322, /* 11230 ( 291) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34133684, /* 11231 ( 291) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    51021536, /* 11232 ( 291) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  0] -1 */
    17127572, /* 11233 ( 291) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
    51034658, /* 11234 ( 291) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  0] -1 */
    17140532, /* 11235 ( 291) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
    51021698, /* 11236 ( 291) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  0] -1 */
    34146806, /* 11237 ( 291) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    51034820, /* 11238 ( 291) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  0] -1 */
    17140694, /* 11239 ( 291) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
    34146644, /* 11240 ( 291) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
        3362, /* 11241 ( 291) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
       16484, /* 11242 ( 292) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    52438874, /* 11243 ( 292) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
    17127410, /* 11244 ( 292) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
        3200, /* 11245 ( 292) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    35550860, /* 11246 ( 292) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
       16322, /* 11247 ( 292) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    52451834, /* 11248 ( 292) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
    17127572, /* 11249 ( 292) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
    35550698, /* 11250 ( 292) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
    17140532, /* 11251 ( 292) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
    52451996, /* 11252 ( 292) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
    35563820, /* 11253 ( 292) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
    17140694, /* 11254 ( 292) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
    35563982, /* 11255 ( 292) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
    52438712, /* 11256 ( 292) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
        3362, /* 11257 ( 292) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
       16484, /* 11258 ( 285) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    17140530, /* 11259 ( 285) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  6]  1 */
       16320, /* 11260 ( 285) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
       16322, /* 11261 ( 285) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    17140692, /* 11262 ( 285) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6]  1 */
    17140532, /* 11263 ( 285) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
    17140694, /* 11264 ( 285) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
       16482, /* 11265 ( 285) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
       16484, /* 11266 ( 286) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34028546, /* 11267 ( 286) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    34028706, /* 11268 ( 286) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    17140530, /* 11269 ( 286) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  6]  1 */
       16320, /* 11270 ( 286) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
       16322, /* 11271 ( 286) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    51152756, /* 11272 ( 286) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
    17140692, /* 11273 ( 286) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6]  1 */
    17140532, /* 11274 ( 286) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
    51152918, /* 11275 ( 286) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
    17140694, /* 11276 ( 286) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
    51152754, /* 11277 ( 286) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  6] -1 */
    34028544, /* 11278 ( 286) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    34028708, /* 11279 ( 286) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    51152916, /* 11280 ( 286) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6] -1 */
       16482, /* 11281 ( 286) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
       16484, /* 11282 ( 287) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34028546, /* 11283 ( 287) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    51152756, /* 11284 ( 287) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
    17140692, /* 11285 ( 287) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6]  1 */
    17140694, /* 11286 ( 287) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
    51152754, /* 11287 ( 287) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  6] -1 */
    34028544, /* 11288 ( 287) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
       16482, /* 11289 ( 287) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
       16484, /* 11290 ( 288) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34028706, /* 11291 ( 288) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
       16322, /* 11292 ( 288) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    17140532, /* 11293 ( 288) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
    17140694, /* 11294 ( 288) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
    51152754, /* 11295 ( 288) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  6] -1 */
    34028544, /* 11296 ( 288) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    51152916, /* 11297 ( 288) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6] -1 */
       16484, /* 11298 ( 289) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34028546, /* 11299 ( 289) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    17140530, /* 11300 ( 289) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  6]  1 */
       16320, /* 11301 ( 289) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    51152756, /* 11302 ( 289) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
    17140694, /* 11303 ( 289) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
    34028706, /* 11304 ( 289) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    51152916, /* 11305 ( 289) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6] -1 */
       16484, /* 11306 ( 290) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    52569930, /* 11307 ( 290) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    17140530, /* 11308 ( 290) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  6]  1 */
       16320, /* 11309 ( 290) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
       16322, /* 11310 ( 290) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    35445884, /* 11311 ( 290) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  0] -1 */
    35445722, /* 11312 ( 290) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  0] -1 */
    52570092, /* 11313 ( 290) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    17140692, /* 11314 ( 290) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6]  1 */
    35445882, /* 11315 ( 290) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  0] -1 */
    17140532, /* 11316 ( 290) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
    52569932, /* 11317 ( 290) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    17140694, /* 11318 ( 290) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
    35445720, /* 11319 ( 290) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  0] -1 */
    52570094, /* 11320 ( 290) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
       16482, /* 11321 ( 290) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
       16484, /* 11322 ( 291) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    51034656, /* 11323 ( 291) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  0] -1 */
    17140530, /* 11324 ( 291) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  6]  1 */
       16320, /* 11325 ( 291) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
       16322, /* 11326 ( 291) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    51034818, /* 11327 ( 291) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  0] -1 */
    34146642, /* 11328 ( 291) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
    17140692, /* 11329 ( 291) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6]  1 */
    34146644, /* 11330 ( 291) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    17140532, /* 11331 ( 291) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
    34146804, /* 11332 ( 291) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
    51034820, /* 11333 ( 291) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  0] -1 */
    34146806, /* 11334 ( 291) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    17140694, /* 11335 ( 291) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
    51034658, /* 11336 ( 291) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  0] -1 */
       16482, /* 11337 ( 291) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
       16484, /* 11338 ( 292) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    35563980, /* 11339 ( 292) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6] -1 */
    17140530, /* 11340 ( 292) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  6]  1 */
       16320, /* 11341 ( 292) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    52451994, /* 11342 ( 292) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
       16322, /* 11343 ( 292) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    35563820, /* 11344 ( 292) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
    17140692, /* 11345 ( 292) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6]  1 */
    52451832, /* 11346 ( 292) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
    17140532, /* 11347 ( 292) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
    35563982, /* 11348 ( 292) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
    52451834, /* 11349 ( 292) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
    17140694, /* 11350 ( 292) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
    52451996, /* 11351 ( 292) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
    35563818, /* 11352 ( 292) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  6] -1 */
       16482, /* 11353 ( 292) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
       16484, /* 11354 ( 285) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    18439608, /* 11355 ( 285) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
       16320, /* 11356 ( 285) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
       16482, /* 11357 ( 285) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    18439610, /* 11358 ( 285) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    18439770, /* 11359 ( 285) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
    18439772, /* 11360 ( 285) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
       16322, /* 11361 ( 285) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
       16484, /* 11362 ( 286) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34028706, /* 11363 ( 286) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    34028546, /* 11364 ( 286) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    18439608, /* 11365 ( 286) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
       16320, /* 11366 ( 286) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
       16482, /* 11367 ( 286) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    52451994, /* 11368 ( 286) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
    18439610, /* 11369 ( 286) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    18439770, /* 11370 ( 286) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
    52451996, /* 11371 ( 286) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
    18439772, /* 11372 ( 286) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    52451832, /* 11373 ( 286) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
    34028544, /* 11374 ( 286) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    34028708, /* 11375 ( 286) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    52451834, /* 11376 ( 286) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
       16322, /* 11377 ( 286) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
       16484, /* 11378 ( 287) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34028706, /* 11379 ( 287) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    52451994, /* 11380 ( 287) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
    18439610, /* 11381 ( 287) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    18439772, /* 11382 ( 287) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    52451832, /* 11383 ( 287) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
    34028544, /* 11384 ( 287) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
       16322, /* 11385 ( 287) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
       16484, /* 11386 ( 288) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34028546, /* 11387 ( 288) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
       16482, /* 11388 ( 288) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    18439770, /* 11389 ( 288) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
    18439772, /* 11390 ( 288) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    52451832, /* 11391 ( 288) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
    34028544, /* 11392 ( 288) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    52451834, /* 11393 ( 288) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
       16484, /* 11394 ( 289) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34028706, /* 11395 ( 289) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    18439608, /* 11396 ( 289) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
       16320, /* 11397 ( 289) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    52451994, /* 11398 ( 289) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
    18439772, /* 11399 ( 289) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    34028546, /* 11400 ( 289) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    52451834, /* 11401 ( 289) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
       16484, /* 11402 ( 290) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    52569930, /* 11403 ( 290) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    18439608, /* 11404 ( 290) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
       16320, /* 11405 ( 290) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
       16482, /* 11406 ( 290) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    34146806, /* 11407 ( 290) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    34146804, /* 11408 ( 290) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
    52569932, /* 11409 ( 290) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    18439610, /* 11410 ( 290) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    34146644, /* 11411 ( 290) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    18439770, /* 11412 ( 290) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
    52570092, /* 11413 ( 290) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    18439772, /* 11414 ( 290) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    34146642, /* 11415 ( 290) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
    52570094, /* 11416 ( 290) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
       16322, /* 11417 ( 290) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
       16484, /* 11418 ( 291) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    51034656, /* 11419 ( 291) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  0] -1 */
    18439608, /* 11420 ( 291) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
       16320, /* 11421 ( 291) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
       16482, /* 11422 ( 291) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    51034658, /* 11423 ( 291) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  0] -1 */
    35445720, /* 11424 ( 291) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  0] -1 */
    18439610, /* 11425 ( 291) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    35445882, /* 11426 ( 291) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  0] -1 */
    18439770, /* 11427 ( 291) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
    35445722, /* 11428 ( 291) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  0] -1 */
    51034820, /* 11429 ( 291) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  0] -1 */
    35445884, /* 11430 ( 291) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  0] -1 */
    18439772, /* 11431 ( 291) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    51034818, /* 11432 ( 291) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  0] -1 */
       16322, /* 11433 ( 291) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
       16484, /* 11434 ( 292) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    35563820, /* 11435 ( 292) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
    18439608, /* 11436 ( 292) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
       16320, /* 11437 ( 292) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    51152756, /* 11438 ( 292) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
       16482, /* 11439 ( 292) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    35563980, /* 11440 ( 292) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6] -1 */
    18439610, /* 11441 ( 292) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    51152754, /* 11442 ( 292) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  6] -1 */
    18439770, /* 11443 ( 292) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
    35563982, /* 11444 ( 292) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
    51152916, /* 11445 ( 292) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6] -1 */
    18439772, /* 11446 ( 292) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    51152918, /* 11447 ( 292) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
    35563818, /* 11448 ( 292) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  6] -1 */
       16322, /* 11449 ( 292) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
       16484, /* 11450 ( 285) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    18426648, /* 11451 ( 285) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
        3360, /* 11452 ( 285) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
       16482, /* 11453 ( 285) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    18426650, /* 11454 ( 285) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    18439770, /* 11455 ( 285) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
    18439772, /* 11456 ( 285) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
        3362, /* 11457 ( 285) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
       16484, /* 11458 ( 286) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34028706, /* 11459 ( 286) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    34015586, /* 11460 ( 286) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    18426648, /* 11461 ( 286) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
        3360, /* 11462 ( 286) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
       16482, /* 11463 ( 286) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    52451994, /* 11464 ( 286) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
    18426650, /* 11465 ( 286) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    18439770, /* 11466 ( 286) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
    52451996, /* 11467 ( 286) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
    18439772, /* 11468 ( 286) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    52438872, /* 11469 ( 286) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
    34015584, /* 11470 ( 286) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    34028708, /* 11471 ( 286) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    52438874, /* 11472 ( 286) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
        3362, /* 11473 ( 286) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
       16484, /* 11474 ( 287) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34028706, /* 11475 ( 287) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    52451994, /* 11476 ( 287) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
    18426650, /* 11477 ( 287) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    18439772, /* 11478 ( 287) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    52438872, /* 11479 ( 287) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
    34015584, /* 11480 ( 287) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
        3362, /* 11481 ( 287) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
       16484, /* 11482 ( 288) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34015586, /* 11483 ( 288) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
       16482, /* 11484 ( 288) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    18439770, /* 11485 ( 288) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
    18439772, /* 11486 ( 288) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    52438872, /* 11487 ( 288) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
    34015584, /* 11488 ( 288) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    52438874, /* 11489 ( 288) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
       16484, /* 11490 ( 289) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34028706, /* 11491 ( 289) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    18426648, /* 11492 ( 289) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
        3360, /* 11493 ( 289) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    52451994, /* 11494 ( 289) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
    18439772, /* 11495 ( 289) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    34015586, /* 11496 ( 289) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    52438874, /* 11497 ( 289) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
       16484, /* 11498 ( 290) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    52556970, /* 11499 ( 290) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    18426648, /* 11500 ( 290) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
        3360, /* 11501 ( 290) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
       16482, /* 11502 ( 290) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    34146806, /* 11503 ( 290) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    34146804, /* 11504 ( 290) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
    52556972, /* 11505 ( 290) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    18426650, /* 11506 ( 290) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    34133684, /* 11507 ( 290) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    18439770, /* 11508 ( 290) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
    52570092, /* 11509 ( 290) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    18439772, /* 11510 ( 290) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    34133682, /* 11511 ( 290) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
    52570094, /* 11512 ( 290) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
        3362, /* 11513 ( 290) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
       16484, /* 11514 ( 291) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    35432760, /* 11515 ( 291) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  0] -1 */
    18426648, /* 11516 ( 291) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
        3360, /* 11517 ( 291) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
       16482, /* 11518 ( 291) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    35432762, /* 11519 ( 291) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  0] -1 */
    51021696, /* 11520 ( 291) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  0] -1 */
    18426650, /* 11521 ( 291) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    51034818, /* 11522 ( 291) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  0] -1 */
    18439770, /* 11523 ( 291) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
    51021698, /* 11524 ( 291) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  0] -1 */
    35445884, /* 11525 ( 291) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  0] -1 */
    51034820, /* 11526 ( 291) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  0] -1 */
    18439772, /* 11527 ( 291) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    35445882, /* 11528 ( 291) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  0] -1 */
        3362, /* 11529 ( 291) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
       16484, /* 11530 ( 292) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    51139796, /* 11531 ( 292) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
    18426648, /* 11532 ( 292) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
        3360, /* 11533 ( 292) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    35550860, /* 11534 ( 292) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
       16482, /* 11535 ( 292) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    51152916, /* 11536 ( 292) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6] -1 */
    18426650, /* 11537 ( 292) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    35550858, /* 11538 ( 292) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6] -1 */
    18439770, /* 11539 ( 292) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
    51152918, /* 11540 ( 292) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
    35563980, /* 11541 ( 292) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6] -1 */
    18439772, /* 11542 ( 292) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    35563982, /* 11543 ( 292) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
    51139794, /* 11544 ( 292) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6] -1 */
        3362, /* 11545 ( 292) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
       16484, /* 11546 ( 285) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
     1538634, /* 11547 ( 285) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
        3360, /* 11548 ( 285) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
        3362, /* 11549 ( 285) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
     1551756, /* 11550 ( 285) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
     1538636, /* 11551 ( 285) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
     1551758, /* 11552 ( 285) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
       16482, /* 11553 ( 285) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
       16484, /* 11554 ( 286) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34015586, /* 11555 ( 286) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    34028706, /* 11556 ( 286) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
     1538634, /* 11557 ( 286) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
        3360, /* 11558 ( 286) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
        3362, /* 11559 ( 286) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    35550860, /* 11560 ( 286) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
     1551756, /* 11561 ( 286) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
     1538636, /* 11562 ( 286) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
    35563982, /* 11563 ( 286) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
     1551758, /* 11564 ( 286) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
    35550858, /* 11565 ( 286) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6] -1 */
    34015584, /* 11566 ( 286) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    34028708, /* 11567 ( 286) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    35563980, /* 11568 ( 286) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6] -1 */
       16482, /* 11569 ( 286) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
       16484, /* 11570 ( 287) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34015586, /* 11571 ( 287) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    35550860, /* 11572 ( 287) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
     1551756, /* 11573 ( 287) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
     1551758, /* 11574 ( 287) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
    35550858, /* 11575 ( 287) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6] -1 */
    34015584, /* 11576 ( 287) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
       16482, /* 11577 ( 287) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
       16484, /* 11578 ( 288) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34028706, /* 11579 ( 288) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
        3362, /* 11580 ( 288) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
     1538636, /* 11581 ( 288) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
     1551758, /* 11582 ( 288) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
    35550858, /* 11583 ( 288) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6] -1 */
    34015584, /* 11584 ( 288) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    35563980, /* 11585 ( 288) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6] -1 */
       16484, /* 11586 ( 289) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34015586, /* 11587 ( 289) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
     1538634, /* 11588 ( 289) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
        3360, /* 11589 ( 289) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    35550860, /* 11590 ( 289) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
     1551758, /* 11591 ( 289) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
    34028706, /* 11592 ( 289) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    35563980, /* 11593 ( 289) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6] -1 */
       16484, /* 11594 ( 290) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    52556970, /* 11595 ( 290) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
     1538634, /* 11596 ( 290) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
        3360, /* 11597 ( 290) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
        3362, /* 11598 ( 290) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    51034820, /* 11599 ( 290) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  0] -1 */
    51021698, /* 11600 ( 290) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  0] -1 */
    52570092, /* 11601 ( 290) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
     1551756, /* 11602 ( 290) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
    51034818, /* 11603 ( 290) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  0] -1 */
     1538636, /* 11604 ( 290) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
    52556972, /* 11605 ( 290) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
     1551758, /* 11606 ( 290) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
    51021696, /* 11607 ( 290) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  0] -1 */
    52570094, /* 11608 ( 290) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
       16482, /* 11609 ( 290) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
       16484, /* 11610 ( 291) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    35432760, /* 11611 ( 291) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  0] -1 */
     1538634, /* 11612 ( 291) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
        3360, /* 11613 ( 291) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
        3362, /* 11614 ( 291) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    35445882, /* 11615 ( 291) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  0] -1 */
    34133682, /* 11616 ( 291) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
     1551756, /* 11617 ( 291) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
    34133684, /* 11618 ( 291) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
     1538636, /* 11619 ( 291) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
    34146804, /* 11620 ( 291) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
    35445884, /* 11621 ( 291) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  0] -1 */
    34146806, /* 11622 ( 291) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
     1551758, /* 11623 ( 291) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
    35432762, /* 11624 ( 291) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  0] -1 */
       16482, /* 11625 ( 291) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
       16484, /* 11626 ( 292) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    51152916, /* 11627 ( 292) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6] -1 */
     1538634, /* 11628 ( 292) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
        3360, /* 11629 ( 292) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    52451994, /* 11630 ( 292) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
        3362, /* 11631 ( 292) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    51139796, /* 11632 ( 292) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
     1551756, /* 11633 ( 292) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
    52438872, /* 11634 ( 292) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
     1538636, /* 11635 ( 292) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
    51152918, /* 11636 ( 292) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
    52438874, /* 11637 ( 292) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
     1551758, /* 11638 ( 292) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
    52451996, /* 11639 ( 292) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
    51139794, /* 11640 ( 292) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6] -1 */
       16482, /* 11641 ( 292) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
       16484, /* 11642 ( 293) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
      121460, /* 11643 ( 293) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6]  1 */
     1538474, /* 11644 ( 293) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
        3200, /* 11645 ( 293) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
     1551758, /* 11646 ( 293) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
      134420, /* 11647 ( 293) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6]  1 */
     1433498, /* 11648 ( 293) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  0]  1 */
     1420538, /* 11649 ( 293) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  0]  1 */
       16484, /* 11650 ( 294) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
      121460, /* 11651 ( 294) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6]  1 */
     1538474, /* 11652 ( 294) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
        3200, /* 11653 ( 294) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34146644, /* 11654 ( 294) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
     1433498, /* 11655 ( 294) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  0]  1 */
    35563982, /* 11656 ( 294) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
    35432762, /* 11657 ( 294) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  0] -1 */
    35445722, /* 11658 ( 294) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  0] -1 */
    34133684, /* 11659 ( 294) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
     1551758, /* 11660 ( 294) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
    35550698, /* 11661 ( 294) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
      134420, /* 11662 ( 294) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6]  1 */
    34028708, /* 11663 ( 294) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
     1420538, /* 11664 ( 294) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  0]  1 */
    34015424, /* 11665 ( 294) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
       16484, /* 11666 ( 295) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    35432762, /* 11667 ( 295) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  0] -1 */
      134420, /* 11668 ( 295) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6]  1 */
    34133684, /* 11669 ( 295) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
     1551758, /* 11670 ( 295) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
    35550698, /* 11671 ( 295) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
    34015424, /* 11672 ( 295) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
     1433498, /* 11673 ( 295) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  0]  1 */
       16484, /* 11674 ( 296) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
      121460, /* 11675 ( 296) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6]  1 */
    34146644, /* 11676 ( 296) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    35445722, /* 11677 ( 296) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  0] -1 */
     1551758, /* 11678 ( 296) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
    35550698, /* 11679 ( 296) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
    34015424, /* 11680 ( 296) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
     1420538, /* 11681 ( 296) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  0]  1 */
       16484, /* 11682 ( 297) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
     1538474, /* 11683 ( 297) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
        3200, /* 11684 ( 297) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34146644, /* 11685 ( 297) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    35432762, /* 11686 ( 297) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  0] -1 */
    35445722, /* 11687 ( 297) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  0] -1 */
    34133684, /* 11688 ( 297) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
     1551758, /* 11689 ( 297) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
       16484, /* 11690 ( 298) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    52451834, /* 11691 ( 298) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
      121460, /* 11692 ( 298) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6]  1 */
    52556810, /* 11693 ( 298) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
     1538474, /* 11694 ( 298) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
        3200, /* 11695 ( 298) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    51152756, /* 11696 ( 298) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
    51034820, /* 11697 ( 298) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  0] -1 */
    52438874, /* 11698 ( 298) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
    51139796, /* 11699 ( 298) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
     1551758, /* 11700 ( 298) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
    51021536, /* 11701 ( 298) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  0] -1 */
      134420, /* 11702 ( 298) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6]  1 */
    52570094, /* 11703 ( 298) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
     1433498, /* 11704 ( 298) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  0]  1 */
     1420538, /* 11705 ( 298) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  0]  1 */
       16484, /* 11706 ( 299) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
      121460, /* 11707 ( 299) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6]  1 */
    34133522, /* 11708 ( 299) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    34015586, /* 11709 ( 299) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
     1538474, /* 11710 ( 299) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
        3200, /* 11711 ( 299) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34028546, /* 11712 ( 299) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    35550860, /* 11713 ( 299) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
    35432600, /* 11714 ( 299) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  0] -1 */
    34146806, /* 11715 ( 299) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    35445884, /* 11716 ( 299) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  0] -1 */
     1551758, /* 11717 ( 299) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
      134420, /* 11718 ( 299) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6]  1 */
     1433498, /* 11719 ( 299) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  0]  1 */
     1420538, /* 11720 ( 299) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  0]  1 */
    35563820, /* 11721 ( 299) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
       16484, /* 11722 ( 300) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
      121460, /* 11723 ( 300) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6]  1 */
     1538474, /* 11724 ( 300) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
        3200, /* 11725 ( 300) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    51021698, /* 11726 ( 300) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  0] -1 */
    52569932, /* 11727 ( 300) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    51139634, /* 11728 ( 300) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
      134420, /* 11729 ( 300) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6]  1 */
    52451996, /* 11730 ( 300) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
    52556972, /* 11731 ( 300) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
     1551758, /* 11732 ( 300) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
    51152918, /* 11733 ( 300) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
    52438712, /* 11734 ( 300) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
     1433498, /* 11735 ( 300) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  0]  1 */
     1420538, /* 11736 ( 300) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  0]  1 */
    51034658, /* 11737 ( 300) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  0] -1 */
       16484, /* 11738 ( 293) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
      134420, /* 11739 ( 293) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6]  1 */
    17127410, /* 11740 ( 293) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
        3200, /* 11741 ( 293) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    17140694, /* 11742 ( 293) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
      121460, /* 11743 ( 293) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6]  1 */
    17009474, /* 11744 ( 293) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  0]  1 */
    17022434, /* 11745 ( 293) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  0]  1 */
       16484, /* 11746 ( 294) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
      134420, /* 11747 ( 294) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6]  1 */
    17127410, /* 11748 ( 294) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
        3200, /* 11749 ( 294) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34133684, /* 11750 ( 294) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    17009474, /* 11751 ( 294) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  0]  1 */
    51152918, /* 11752 ( 294) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
    51034658, /* 11753 ( 294) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  0] -1 */
    51021698, /* 11754 ( 294) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  0] -1 */
    34146644, /* 11755 ( 294) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    17140694, /* 11756 ( 294) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
    51139634, /* 11757 ( 294) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
      121460, /* 11758 ( 294) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6]  1 */
    34028708, /* 11759 ( 294) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    17022434, /* 11760 ( 294) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  0]  1 */
    34015424, /* 11761 ( 294) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
       16484, /* 11762 ( 295) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    51034658, /* 11763 ( 295) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  0] -1 */
      121460, /* 11764 ( 295) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6]  1 */
    34146644, /* 11765 ( 295) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    17140694, /* 11766 ( 295) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
    51139634, /* 11767 ( 295) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
    34015424, /* 11768 ( 295) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    17009474, /* 11769 ( 295) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  0]  1 */
       16484, /* 11770 ( 296) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
      134420, /* 11771 ( 296) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6]  1 */
    34133684, /* 11772 ( 296) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    51021698, /* 11773 ( 296) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  0] -1 */
    17140694, /* 11774 ( 296) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
    51139634, /* 11775 ( 296) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
    34015424, /* 11776 ( 296) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    17022434, /* 11777 ( 296) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  0]  1 */
       16484, /* 11778 ( 297) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    17127410, /* 11779 ( 297) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
        3200, /* 11780 ( 297) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34133684, /* 11781 ( 297) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    51034658, /* 11782 ( 297) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  0] -1 */
    51021698, /* 11783 ( 297) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  0] -1 */
    34146644, /* 11784 ( 297) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    17140694, /* 11785 ( 297) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
       16484, /* 11786 ( 298) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    52438874, /* 11787 ( 298) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
      134420, /* 11788 ( 298) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6]  1 */
    52556810, /* 11789 ( 298) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    17127410, /* 11790 ( 298) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
        3200, /* 11791 ( 298) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    35550860, /* 11792 ( 298) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
    35445884, /* 11793 ( 298) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  0] -1 */
    52451834, /* 11794 ( 298) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
    35563820, /* 11795 ( 298) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
    17140694, /* 11796 ( 298) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
    35432600, /* 11797 ( 298) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  0] -1 */
      121460, /* 11798 ( 298) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6]  1 */
    52570094, /* 11799 ( 298) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    17009474, /* 11800 ( 298) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  0]  1 */
    17022434, /* 11801 ( 298) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  0]  1 */
       16484, /* 11802 ( 299) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
      134420, /* 11803 ( 299) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6]  1 */
    34133522, /* 11804 ( 299) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    34028546, /* 11805 ( 299) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    17127410, /* 11806 ( 299) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
        3200, /* 11807 ( 299) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34015586, /* 11808 ( 299) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    51152756, /* 11809 ( 299) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
    51021536, /* 11810 ( 299) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  0] -1 */
    34146806, /* 11811 ( 299) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    51034820, /* 11812 ( 299) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  0] -1 */
    17140694, /* 11813 ( 299) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
      121460, /* 11814 ( 299) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6]  1 */
    17009474, /* 11815 ( 299) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  0]  1 */
    17022434, /* 11816 ( 299) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  0]  1 */
    51139796, /* 11817 ( 299) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
       16484, /* 11818 ( 300) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
      134420, /* 11819 ( 300) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6]  1 */
    17127410, /* 11820 ( 300) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
        3200, /* 11821 ( 300) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    35445722, /* 11822 ( 300) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  0] -1 */
    52556972, /* 11823 ( 300) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    35550698, /* 11824 ( 300) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
      121460, /* 11825 ( 300) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6]  1 */
    52451996, /* 11826 ( 300) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
    52569932, /* 11827 ( 300) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    17140694, /* 11828 ( 300) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
    35563982, /* 11829 ( 300) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
    52438712, /* 11830 ( 300) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
    17009474, /* 11831 ( 300) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  0]  1 */
    17022434, /* 11832 ( 300) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  0]  1 */
    35432762, /* 11833 ( 300) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  0] -1 */
       16484, /* 11834 ( 293) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    17022434, /* 11835 ( 293) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  0]  1 */
    17140530, /* 11836 ( 293) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  6]  1 */
       16320, /* 11837 ( 293) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    17140694, /* 11838 ( 293) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
    17022594, /* 11839 ( 293) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  0]  1 */
      134580, /* 11840 ( 293) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  6]  1 */
      134420, /* 11841 ( 293) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6]  1 */
       16484, /* 11842 ( 294) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    17022434, /* 11843 ( 294) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  0]  1 */
    17140530, /* 11844 ( 294) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  6]  1 */
       16320, /* 11845 ( 294) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    51034818, /* 11846 ( 294) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  0] -1 */
      134580, /* 11847 ( 294) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  6]  1 */
    51152918, /* 11848 ( 294) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
    34146644, /* 11849 ( 294) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    34146804, /* 11850 ( 294) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
    51034658, /* 11851 ( 294) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  0] -1 */
    17140694, /* 11852 ( 294) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
    51152754, /* 11853 ( 294) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  6] -1 */
    17022594, /* 11854 ( 294) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  0]  1 */
    34028708, /* 11855 ( 294) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
      134420, /* 11856 ( 294) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6]  1 */
    34028544, /* 11857 ( 294) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
       16484, /* 11858 ( 295) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34146644, /* 11859 ( 295) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    17022594, /* 11860 ( 295) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  0]  1 */
    51034658, /* 11861 ( 295) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  0] -1 */
    17140694, /* 11862 ( 295) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
    51152754, /* 11863 ( 295) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  6] -1 */
    34028544, /* 11864 ( 295) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
      134580, /* 11865 ( 295) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  6]  1 */
       16484, /* 11866 ( 296) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    17022434, /* 11867 ( 296) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  0]  1 */
    51034818, /* 11868 ( 296) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  0] -1 */
    34146804, /* 11869 ( 296) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
    17140694, /* 11870 ( 296) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
    51152754, /* 11871 ( 296) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  6] -1 */
    34028544, /* 11872 ( 296) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
      134420, /* 11873 ( 296) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6]  1 */
       16484, /* 11874 ( 297) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    17140530, /* 11875 ( 297) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  6]  1 */
       16320, /* 11876 ( 297) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    51034818, /* 11877 ( 297) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  0] -1 */
    34146644, /* 11878 ( 297) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    34146804, /* 11879 ( 297) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
    51034658, /* 11880 ( 297) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  0] -1 */
    17140694, /* 11881 ( 297) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
       16484, /* 11882 ( 298) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    35563980, /* 11883 ( 298) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6] -1 */
    17022434, /* 11884 ( 298) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  0]  1 */
    52569930, /* 11885 ( 298) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    17140530, /* 11886 ( 298) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  6]  1 */
       16320, /* 11887 ( 298) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    52451994, /* 11888 ( 298) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
    35445884, /* 11889 ( 298) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  0] -1 */
    35563820, /* 11890 ( 298) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
    52451834, /* 11891 ( 298) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
    17140694, /* 11892 ( 298) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
    35445720, /* 11893 ( 298) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  0] -1 */
    17022594, /* 11894 ( 298) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  0]  1 */
    52570094, /* 11895 ( 298) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
      134580, /* 11896 ( 298) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  6]  1 */
      134420, /* 11897 ( 298) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6]  1 */
       16484, /* 11898 ( 299) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    17022434, /* 11899 ( 299) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  0]  1 */
    51034656, /* 11900 ( 299) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  0] -1 */
    34028546, /* 11901 ( 299) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    17140530, /* 11902 ( 299) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  6]  1 */
       16320, /* 11903 ( 299) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    34028706, /* 11904 ( 299) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    51152756, /* 11905 ( 299) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
    34146642, /* 11906 ( 299) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
    51034820, /* 11907 ( 299) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  0] -1 */
    34146806, /* 11908 ( 299) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    17140694, /* 11909 ( 299) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
    17022594, /* 11910 ( 299) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  0]  1 */
      134580, /* 11911 ( 299) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  6]  1 */
      134420, /* 11912 ( 299) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6]  1 */
    51152916, /* 11913 ( 299) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6] -1 */
       16484, /* 11914 ( 300) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    17022434, /* 11915 ( 300) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  0]  1 */
    17140530, /* 11916 ( 300) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  6]  1 */
       16320, /* 11917 ( 300) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    35445722, /* 11918 ( 300) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  0] -1 */
    52570092, /* 11919 ( 300) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    52451832, /* 11920 ( 300) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
    17022594, /* 11921 ( 300) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  0]  1 */
    35563982, /* 11922 ( 300) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
    52569932, /* 11923 ( 300) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    17140694, /* 11924 ( 300) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
    52451996, /* 11925 ( 300) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
    35563818, /* 11926 ( 300) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  6] -1 */
      134580, /* 11927 ( 300) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  6]  1 */
      134420, /* 11928 ( 300) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6]  1 */
    35445882, /* 11929 ( 300) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  0] -1 */
       16484, /* 11930 ( 293) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    17022594, /* 11931 ( 293) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  0]  1 */
    18439608, /* 11932 ( 293) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
       16320, /* 11933 ( 293) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    18439772, /* 11934 ( 293) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    17022434, /* 11935 ( 293) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  0]  1 */
     1433498, /* 11936 ( 293) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  0]  1 */
     1433658, /* 11937 ( 293) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  0]  1 */
       16484, /* 11938 ( 294) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    17022594, /* 11939 ( 294) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  0]  1 */
    18439608, /* 11940 ( 294) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
       16320, /* 11941 ( 294) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    51034658, /* 11942 ( 294) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  0] -1 */
     1433498, /* 11943 ( 294) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  0]  1 */
    52451996, /* 11944 ( 294) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
    35445882, /* 11945 ( 294) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  0] -1 */
    35445722, /* 11946 ( 294) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  0] -1 */
    51034818, /* 11947 ( 294) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  0] -1 */
    18439772, /* 11948 ( 294) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    52451832, /* 11949 ( 294) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
    17022434, /* 11950 ( 294) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  0]  1 */
    34028708, /* 11951 ( 294) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
     1433658, /* 11952 ( 294) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  0]  1 */
    34028544, /* 11953 ( 294) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
       16484, /* 11954 ( 295) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    35445882, /* 11955 ( 295) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  0] -1 */
    17022434, /* 11956 ( 295) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  0]  1 */
    51034818, /* 11957 ( 295) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  0] -1 */
    18439772, /* 11958 ( 295) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    52451832, /* 11959 ( 295) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
    34028544, /* 11960 ( 295) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
     1433498, /* 11961 ( 295) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  0]  1 */
       16484, /* 11962 ( 296) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    17022594, /* 11963 ( 296) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  0]  1 */
    51034658, /* 11964 ( 296) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  0] -1 */
    35445722, /* 11965 ( 296) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  0] -1 */
    18439772, /* 11966 ( 296) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    52451832, /* 11967 ( 296) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
    34028544, /* 11968 ( 296) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
     1433658, /* 11969 ( 296) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  0]  1 */
       16484, /* 11970 ( 297) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    18439608, /* 11971 ( 297) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
       16320, /* 11972 ( 297) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    51034658, /* 11973 ( 297) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  0] -1 */
    35445882, /* 11974 ( 297) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  0] -1 */
    35445722, /* 11975 ( 297) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  0] -1 */
    51034818, /* 11976 ( 297) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  0] -1 */
    18439772, /* 11977 ( 297) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
       16484, /* 11978 ( 298) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    35563820, /* 11979 ( 298) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
    17022594, /* 11980 ( 298) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  0]  1 */
    52569930, /* 11981 ( 298) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    18439608, /* 11982 ( 298) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
       16320, /* 11983 ( 298) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    51152756, /* 11984 ( 298) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
    34146806, /* 11985 ( 298) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    35563980, /* 11986 ( 298) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6] -1 */
    51152916, /* 11987 ( 298) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6] -1 */
    18439772, /* 11988 ( 298) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    34146642, /* 11989 ( 298) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
    17022434, /* 11990 ( 298) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  0]  1 */
    52570094, /* 11991 ( 298) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
     1433498, /* 11992 ( 298) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  0]  1 */
     1433658, /* 11993 ( 298) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  0]  1 */
       16484, /* 11994 ( 299) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    17022594, /* 11995 ( 299) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  0]  1 */
    51034656, /* 11996 ( 299) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  0] -1 */
    34028706, /* 11997 ( 299) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    18439608, /* 11998 ( 299) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
       16320, /* 11999 ( 299) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    34028546, /* 12000 ( 299) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    52451994, /* 12001 ( 299) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
    35445720, /* 12002 ( 299) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  0] -1 */
    51034820, /* 12003 ( 299) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  0] -1 */
    35445884, /* 12004 ( 299) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  0] -1 */
    18439772, /* 12005 ( 299) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    17022434, /* 12006 ( 299) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  0]  1 */
     1433498, /* 12007 ( 299) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  0]  1 */
     1433658, /* 12008 ( 299) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  0]  1 */
    52451834, /* 12009 ( 299) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
       16484, /* 12010 ( 300) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    17022594, /* 12011 ( 300) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  0]  1 */
    18439608, /* 12012 ( 300) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
       16320, /* 12013 ( 300) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    34146804, /* 12014 ( 300) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
    52569932, /* 12015 ( 300) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    51152754, /* 12016 ( 300) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  6] -1 */
    17022434, /* 12017 ( 300) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  0]  1 */
    35563982, /* 12018 ( 300) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
    52570092, /* 12019 ( 300) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    18439772, /* 12020 ( 300) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    51152918, /* 12021 ( 300) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
    35563818, /* 12022 ( 300) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  6] -1 */
     1433498, /* 12023 ( 300) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  0]  1 */
     1433658, /* 12024 ( 300) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  0]  1 */
    34146644, /* 12025 ( 300) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
       16484, /* 12026 ( 293) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
     1433658, /* 12027 ( 293) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  0]  1 */
    18426648, /* 12028 ( 293) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
        3360, /* 12029 ( 293) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    18439772, /* 12030 ( 293) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
     1420538, /* 12031 ( 293) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  0]  1 */
    17009474, /* 12032 ( 293) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  0]  1 */
    17022594, /* 12033 ( 293) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  0]  1 */
       16484, /* 12034 ( 294) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
     1433658, /* 12035 ( 294) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  0]  1 */
    18426648, /* 12036 ( 294) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
        3360, /* 12037 ( 294) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    35432762, /* 12038 ( 294) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  0] -1 */
    17009474, /* 12039 ( 294) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  0]  1 */
    52451996, /* 12040 ( 294) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
    51034818, /* 12041 ( 294) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  0] -1 */
    51021698, /* 12042 ( 294) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  0] -1 */
    35445882, /* 12043 ( 294) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  0] -1 */
    18439772, /* 12044 ( 294) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    52438872, /* 12045 ( 294) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
     1420538, /* 12046 ( 294) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  0]  1 */
    34028708, /* 12047 ( 294) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    17022594, /* 12048 ( 294) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  0]  1 */
    34015584, /* 12049 ( 294) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
       16484, /* 12050 ( 295) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    51034818, /* 12051 ( 295) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  0] -1 */
     1420538, /* 12052 ( 295) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  0]  1 */
    35445882, /* 12053 ( 295) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  0] -1 */
    18439772, /* 12054 ( 295) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    52438872, /* 12055 ( 295) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
    34015584, /* 12056 ( 295) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    17009474, /* 12057 ( 295) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  0]  1 */
       16484, /* 12058 ( 296) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
     1433658, /* 12059 ( 296) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  0]  1 */
    35432762, /* 12060 ( 296) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  0] -1 */
    51021698, /* 12061 ( 296) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  0] -1 */
    18439772, /* 12062 ( 296) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    52438872, /* 12063 ( 296) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
    34015584, /* 12064 ( 296) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    17022594, /* 12065 ( 296) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  0]  1 */
       16484, /* 12066 ( 297) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    18426648, /* 12067 ( 297) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
        3360, /* 12068 ( 297) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    35432762, /* 12069 ( 297) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  0] -1 */
    51034818, /* 12070 ( 297) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  0] -1 */
    51021698, /* 12071 ( 297) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  0] -1 */
    35445882, /* 12072 ( 297) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  0] -1 */
    18439772, /* 12073 ( 297) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
       16484, /* 12074 ( 298) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    51139796, /* 12075 ( 298) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
     1433658, /* 12076 ( 298) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  0]  1 */
    52556970, /* 12077 ( 298) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    18426648, /* 12078 ( 298) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
        3360, /* 12079 ( 298) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    35550860, /* 12080 ( 298) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
    34146806, /* 12081 ( 298) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    51152916, /* 12082 ( 298) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6] -1 */
    35563980, /* 12083 ( 298) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6] -1 */
    18439772, /* 12084 ( 298) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    34133682, /* 12085 ( 298) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
     1420538, /* 12086 ( 298) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  0]  1 */
    52570094, /* 12087 ( 298) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    17009474, /* 12088 ( 298) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  0]  1 */
    17022594, /* 12089 ( 298) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  0]  1 */
       16484, /* 12090 ( 299) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
     1433658, /* 12091 ( 299) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  0]  1 */
    35432760, /* 12092 ( 299) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  0] -1 */
    34028706, /* 12093 ( 299) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    18426648, /* 12094 ( 299) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
        3360, /* 12095 ( 299) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    34015586, /* 12096 ( 299) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    52451994, /* 12097 ( 299) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
    51021696, /* 12098 ( 299) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  0] -1 */
    35445884, /* 12099 ( 299) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  0] -1 */
    51034820, /* 12100 ( 299) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  0] -1 */
    18439772, /* 12101 ( 299) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
     1420538, /* 12102 ( 299) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  0]  1 */
    17009474, /* 12103 ( 299) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  0]  1 */
    17022594, /* 12104 ( 299) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  0]  1 */
    52438874, /* 12105 ( 299) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
       16484, /* 12106 ( 300) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
     1433658, /* 12107 ( 300) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  0]  1 */
    18426648, /* 12108 ( 300) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
        3360, /* 12109 ( 300) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    34146804, /* 12110 ( 300) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
    52556972, /* 12111 ( 300) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    35550858, /* 12112 ( 300) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6] -1 */
     1420538, /* 12113 ( 300) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  0]  1 */
    51152918, /* 12114 ( 300) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
    52570092, /* 12115 ( 300) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    18439772, /* 12116 ( 300) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    35563982, /* 12117 ( 300) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
    51139794, /* 12118 ( 300) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6] -1 */
    17009474, /* 12119 ( 300) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  0]  1 */
    17022594, /* 12120 ( 300) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  0]  1 */
    34133684, /* 12121 ( 300) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
       16484, /* 12122 ( 293) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
     1420538, /* 12123 ( 293) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  0]  1 */
     1538634, /* 12124 ( 293) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
        3360, /* 12125 ( 293) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
     1551758, /* 12126 ( 293) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
     1433658, /* 12127 ( 293) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  0]  1 */
      134580, /* 12128 ( 293) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  6]  1 */
      121460, /* 12129 ( 293) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6]  1 */
       16484, /* 12130 ( 294) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
     1420538, /* 12131 ( 294) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  0]  1 */
     1538634, /* 12132 ( 294) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
        3360, /* 12133 ( 294) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    35445882, /* 12134 ( 294) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  0] -1 */
      134580, /* 12135 ( 294) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  6]  1 */
    35563982, /* 12136 ( 294) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
    34133684, /* 12137 ( 294) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    34146804, /* 12138 ( 294) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
    35432762, /* 12139 ( 294) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  0] -1 */
     1551758, /* 12140 ( 294) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
    35550858, /* 12141 ( 294) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6] -1 */
     1433658, /* 12142 ( 294) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  0]  1 */
    34028708, /* 12143 ( 294) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
      121460, /* 12144 ( 294) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6]  1 */
    34015584, /* 12145 ( 294) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
       16484, /* 12146 ( 295) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34133684, /* 12147 ( 295) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
     1433658, /* 12148 ( 295) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  0]  1 */
    35432762, /* 12149 ( 295) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  0] -1 */
     1551758, /* 12150 ( 295) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
    35550858, /* 12151 ( 295) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6] -1 */
    34015584, /* 12152 ( 295) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
      134580, /* 12153 ( 295) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  6]  1 */
       16484, /* 12154 ( 296) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
     1420538, /* 12155 ( 296) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  0]  1 */
    35445882, /* 12156 ( 296) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  0] -1 */
    34146804, /* 12157 ( 296) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
     1551758, /* 12158 ( 296) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
    35550858, /* 12159 ( 296) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6] -1 */
    34015584, /* 12160 ( 296) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
      121460, /* 12161 ( 296) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6]  1 */
       16484, /* 12162 ( 297) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
     1538634, /* 12163 ( 297) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
        3360, /* 12164 ( 297) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    35445882, /* 12165 ( 297) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  0] -1 */
    34133684, /* 12166 ( 297) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    34146804, /* 12167 ( 297) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
    35432762, /* 12168 ( 297) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  0] -1 */
     1551758, /* 12169 ( 297) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
       16484, /* 12170 ( 298) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    51152916, /* 12171 ( 298) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6] -1 */
     1420538, /* 12172 ( 298) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  0]  1 */
    52556970, /* 12173 ( 298) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
     1538634, /* 12174 ( 298) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
        3360, /* 12175 ( 298) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    52451994, /* 12176 ( 298) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
    51034820, /* 12177 ( 298) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  0] -1 */
    51139796, /* 12178 ( 298) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
    52438874, /* 12179 ( 298) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
     1551758, /* 12180 ( 298) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
    51021696, /* 12181 ( 298) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  0] -1 */
     1433658, /* 12182 ( 298) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  0]  1 */
    52570094, /* 12183 ( 298) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
      134580, /* 12184 ( 298) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  6]  1 */
      121460, /* 12185 ( 298) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6]  1 */
       16484, /* 12186 ( 299) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
     1420538, /* 12187 ( 299) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  0]  1 */
    35432760, /* 12188 ( 299) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  0] -1 */
    34015586, /* 12189 ( 299) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
     1538634, /* 12190 ( 299) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
        3360, /* 12191 ( 299) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    34028706, /* 12192 ( 299) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    35550860, /* 12193 ( 299) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
    34133682, /* 12194 ( 299) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
    35445884, /* 12195 ( 299) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  0] -1 */
    34146806, /* 12196 ( 299) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
     1551758, /* 12197 ( 299) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
     1433658, /* 12198 ( 299) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  0]  1 */
      134580, /* 12199 ( 299) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  6]  1 */
      121460, /* 12200 ( 299) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6]  1 */
    35563980, /* 12201 ( 299) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6] -1 */
       16484, /* 12202 ( 300) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
     1420538, /* 12203 ( 300) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  0]  1 */
     1538634, /* 12204 ( 300) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
        3360, /* 12205 ( 300) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    51021698, /* 12206 ( 300) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  0] -1 */
    52570092, /* 12207 ( 300) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    52438872, /* 12208 ( 300) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
     1433658, /* 12209 ( 300) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  0]  1 */
    51152918, /* 12210 ( 300) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
    52556972, /* 12211 ( 300) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
     1551758, /* 12212 ( 300) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
    52451996, /* 12213 ( 300) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
    51139794, /* 12214 ( 300) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6] -1 */
      134580, /* 12215 ( 300) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  6]  1 */
      121460, /* 12216 ( 300) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6]  1 */
    51034818, /* 12217 ( 300) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  0] -1 */
       16484, /* 12218 ( 301) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
     1538474, /* 12219 ( 301) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
        3200, /* 12220 ( 301) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    17022434, /* 12221 ( 301) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  0]  1 */
    17009474, /* 12222 ( 301) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  0]  1 */
     1551758, /* 12223 ( 301) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
    18557708, /* 12224 ( 301) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    18544748, /* 12225 ( 301) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
       16484, /* 12226 ( 302) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
     1538474, /* 12227 ( 302) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
        3200, /* 12228 ( 302) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    51021698, /* 12229 ( 302) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  0] -1 */
    52569932, /* 12230 ( 302) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    17022434, /* 12231 ( 302) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  0]  1 */
    35563982, /* 12232 ( 302) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
    52556972, /* 12233 ( 302) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    17009474, /* 12234 ( 302) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  0]  1 */
     1551758, /* 12235 ( 302) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
    34015424, /* 12236 ( 302) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    18557708, /* 12237 ( 302) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    34028708, /* 12238 ( 302) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    35550698, /* 12239 ( 302) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
    18544748, /* 12240 ( 302) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    51034658, /* 12241 ( 302) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  0] -1 */
       16484, /* 12242 ( 303) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    51021698, /* 12243 ( 303) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  0] -1 */
    17022434, /* 12244 ( 303) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  0]  1 */
    52556972, /* 12245 ( 303) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
     1551758, /* 12246 ( 303) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
    35550698, /* 12247 ( 303) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
    34015424, /* 12248 ( 303) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    18557708, /* 12249 ( 303) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
       16484, /* 12250 ( 304) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    52569932, /* 12251 ( 304) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    17009474, /* 12252 ( 304) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  0]  1 */
     1551758, /* 12253 ( 304) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
    34015424, /* 12254 ( 304) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    35550698, /* 12255 ( 304) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
    18544748, /* 12256 ( 304) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    51034658, /* 12257 ( 304) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  0] -1 */
       16484, /* 12258 ( 305) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
     1538474, /* 12259 ( 305) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
        3200, /* 12260 ( 305) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    51021698, /* 12261 ( 305) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  0] -1 */
    52569932, /* 12262 ( 305) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    52556972, /* 12263 ( 305) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
     1551758, /* 12264 ( 305) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
    51034658, /* 12265 ( 305) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  0] -1 */
       16484, /* 12266 ( 306) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34015586, /* 12267 ( 306) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    52556810, /* 12268 ( 306) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
     1538474, /* 12269 ( 306) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
        3200, /* 12270 ( 306) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    51034820, /* 12271 ( 306) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  0] -1 */
    35550860, /* 12272 ( 306) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
    17022434, /* 12273 ( 306) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  0]  1 */
    51021536, /* 12274 ( 306) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  0] -1 */
    18557708, /* 12275 ( 306) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    17009474, /* 12276 ( 306) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  0]  1 */
     1551758, /* 12277 ( 306) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
    34028546, /* 12278 ( 306) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    52570094, /* 12279 ( 306) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    18544748, /* 12280 ( 306) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    35563820, /* 12281 ( 306) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
       16484, /* 12282 ( 307) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    52451834, /* 12283 ( 307) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
    34133522, /* 12284 ( 307) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
     1538474, /* 12285 ( 307) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
        3200, /* 12286 ( 307) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    51152756, /* 12287 ( 307) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
    52438874, /* 12288 ( 307) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
    35432600, /* 12289 ( 307) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  0] -1 */
    17022434, /* 12290 ( 307) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  0]  1 */
    51139796, /* 12291 ( 307) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
    34146806, /* 12292 ( 307) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    35445884, /* 12293 ( 307) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  0] -1 */
    17009474, /* 12294 ( 307) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  0]  1 */
     1551758, /* 12295 ( 307) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
    18557708, /* 12296 ( 307) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    18544748, /* 12297 ( 307) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
       16484, /* 12298 ( 308) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    52438712, /* 12299 ( 308) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
     1538474, /* 12300 ( 308) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
        3200, /* 12301 ( 308) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34146644, /* 12302 ( 308) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    17022434, /* 12303 ( 308) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  0]  1 */
    51139634, /* 12304 ( 308) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
    35432762, /* 12305 ( 308) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  0] -1 */
    52451996, /* 12306 ( 308) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
    35445722, /* 12307 ( 308) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  0] -1 */
    34133684, /* 12308 ( 308) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    17009474, /* 12309 ( 308) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  0]  1 */
     1551758, /* 12310 ( 308) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
    51152918, /* 12311 ( 308) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
    18557708, /* 12312 ( 308) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    18544748, /* 12313 ( 308) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
       16484, /* 12314 ( 301) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    17127410, /* 12315 ( 301) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
        3200, /* 12316 ( 301) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
     1420538, /* 12317 ( 301) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  0]  1 */
     1433498, /* 12318 ( 301) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  0]  1 */
    17140694, /* 12319 ( 301) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
    18544748, /* 12320 ( 301) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    18557708, /* 12321 ( 301) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
       16484, /* 12322 ( 302) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    17127410, /* 12323 ( 302) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
        3200, /* 12324 ( 302) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    35445722, /* 12325 ( 302) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  0] -1 */
    52556972, /* 12326 ( 302) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
     1420538, /* 12327 ( 302) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  0]  1 */
    51152918, /* 12328 ( 302) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
    52569932, /* 12329 ( 302) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
     1433498, /* 12330 ( 302) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  0]  1 */
    17140694, /* 12331 ( 302) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
    34015424, /* 12332 ( 302) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    18544748, /* 12333 ( 302) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    34028708, /* 12334 ( 302) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    51139634, /* 12335 ( 302) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
    18557708, /* 12336 ( 302) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    35432762, /* 12337 ( 302) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  0] -1 */
       16484, /* 12338 ( 303) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    35445722, /* 12339 ( 303) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  0] -1 */
     1420538, /* 12340 ( 303) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  0]  1 */
    52569932, /* 12341 ( 303) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    17140694, /* 12342 ( 303) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
    51139634, /* 12343 ( 303) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
    34015424, /* 12344 ( 303) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    18544748, /* 12345 ( 303) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
       16484, /* 12346 ( 304) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    52556972, /* 12347 ( 304) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
     1433498, /* 12348 ( 304) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  0]  1 */
    17140694, /* 12349 ( 304) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
    34015424, /* 12350 ( 304) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    51139634, /* 12351 ( 304) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
    18557708, /* 12352 ( 304) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    35432762, /* 12353 ( 304) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  0] -1 */
       16484, /* 12354 ( 305) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    17127410, /* 12355 ( 305) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
        3200, /* 12356 ( 305) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    35445722, /* 12357 ( 305) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  0] -1 */
    52556972, /* 12358 ( 305) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    52569932, /* 12359 ( 305) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    17140694, /* 12360 ( 305) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
    35432762, /* 12361 ( 305) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  0] -1 */
       16484, /* 12362 ( 306) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34028546, /* 12363 ( 306) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    52556810, /* 12364 ( 306) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    17127410, /* 12365 ( 306) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
        3200, /* 12366 ( 306) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    35445884, /* 12367 ( 306) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  0] -1 */
    51152756, /* 12368 ( 306) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
     1420538, /* 12369 ( 306) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  0]  1 */
    35432600, /* 12370 ( 306) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  0] -1 */
    18544748, /* 12371 ( 306) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
     1433498, /* 12372 ( 306) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  0]  1 */
    17140694, /* 12373 ( 306) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
    34015586, /* 12374 ( 306) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    52570094, /* 12375 ( 306) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    18557708, /* 12376 ( 306) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    51139796, /* 12377 ( 306) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
       16484, /* 12378 ( 307) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    52438874, /* 12379 ( 307) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
    34133522, /* 12380 ( 307) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    17127410, /* 12381 ( 307) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
        3200, /* 12382 ( 307) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    35550860, /* 12383 ( 307) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
    52451834, /* 12384 ( 307) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
    51021536, /* 12385 ( 307) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  0] -1 */
     1420538, /* 12386 ( 307) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  0]  1 */
    35563820, /* 12387 ( 307) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
    34146806, /* 12388 ( 307) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    51034820, /* 12389 ( 307) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  0] -1 */
     1433498, /* 12390 ( 307) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  0]  1 */
    17140694, /* 12391 ( 307) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
    18544748, /* 12392 ( 307) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    18557708, /* 12393 ( 307) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
       16484, /* 12394 ( 308) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    52438712, /* 12395 ( 308) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
    17127410, /* 12396 ( 308) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
        3200, /* 12397 ( 308) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34133684, /* 12398 ( 308) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
     1420538, /* 12399 ( 308) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  0]  1 */
    35550698, /* 12400 ( 308) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
    51034658, /* 12401 ( 308) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  0] -1 */
    52451996, /* 12402 ( 308) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
    51021698, /* 12403 ( 308) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  0] -1 */
    34146644, /* 12404 ( 308) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
     1433498, /* 12405 ( 308) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  0]  1 */
    17140694, /* 12406 ( 308) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
    35563982, /* 12407 ( 308) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
    18544748, /* 12408 ( 308) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    18557708, /* 12409 ( 308) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
       16484, /* 12410 ( 301) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    17140530, /* 12411 ( 301) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  6]  1 */
       16320, /* 12412 ( 301) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
     1433658, /* 12413 ( 301) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  0]  1 */
     1433498, /* 12414 ( 301) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  0]  1 */
    17140694, /* 12415 ( 301) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
    18557868, /* 12416 ( 301) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
    18557708, /* 12417 ( 301) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
       16484, /* 12418 ( 302) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    17140530, /* 12419 ( 302) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  6]  1 */
       16320, /* 12420 ( 302) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    35445722, /* 12421 ( 302) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  0] -1 */
    52570092, /* 12422 ( 302) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
     1433658, /* 12423 ( 302) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  0]  1 */
    51152918, /* 12424 ( 302) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
    52569932, /* 12425 ( 302) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
     1433498, /* 12426 ( 302) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  0]  1 */
    17140694, /* 12427 ( 302) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
    34028544, /* 12428 ( 302) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    18557868, /* 12429 ( 302) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
    34028708, /* 12430 ( 302) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    51152754, /* 12431 ( 302) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  6] -1 */
    18557708, /* 12432 ( 302) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    35445882, /* 12433 ( 302) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  0] -1 */
       16484, /* 12434 ( 303) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    35445722, /* 12435 ( 303) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  0] -1 */
     1433658, /* 12436 ( 303) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  0]  1 */
    52569932, /* 12437 ( 303) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    17140694, /* 12438 ( 303) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
    51152754, /* 12439 ( 303) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  6] -1 */
    34028544, /* 12440 ( 303) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    18557868, /* 12441 ( 303) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
       16484, /* 12442 ( 304) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    52570092, /* 12443 ( 304) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
     1433498, /* 12444 ( 304) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  0]  1 */
    17140694, /* 12445 ( 304) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
    34028544, /* 12446 ( 304) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    51152754, /* 12447 ( 304) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  6] -1 */
    18557708, /* 12448 ( 304) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    35445882, /* 12449 ( 304) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  0] -1 */
       16484, /* 12450 ( 305) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    17140530, /* 12451 ( 305) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  6]  1 */
       16320, /* 12452 ( 305) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    35445722, /* 12453 ( 305) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  0] -1 */
    52570092, /* 12454 ( 305) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    52569932, /* 12455 ( 305) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    17140694, /* 12456 ( 305) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
    35445882, /* 12457 ( 305) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  0] -1 */
       16484, /* 12458 ( 306) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34028546, /* 12459 ( 306) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    52569930, /* 12460 ( 306) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    17140530, /* 12461 ( 306) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  6]  1 */
       16320, /* 12462 ( 306) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    35445884, /* 12463 ( 306) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  0] -1 */
    51152756, /* 12464 ( 306) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
     1433658, /* 12465 ( 306) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  0]  1 */
    35445720, /* 12466 ( 306) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  0] -1 */
    18557868, /* 12467 ( 306) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
     1433498, /* 12468 ( 306) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  0]  1 */
    17140694, /* 12469 ( 306) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
    34028706, /* 12470 ( 306) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    52570094, /* 12471 ( 306) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    18557708, /* 12472 ( 306) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    51152916, /* 12473 ( 306) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6] -1 */
       16484, /* 12474 ( 307) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    35563980, /* 12475 ( 307) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6] -1 */
    51034656, /* 12476 ( 307) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  0] -1 */
    17140530, /* 12477 ( 307) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  6]  1 */
       16320, /* 12478 ( 307) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    52451994, /* 12479 ( 307) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
    35563820, /* 12480 ( 307) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
    34146642, /* 12481 ( 307) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
     1433658, /* 12482 ( 307) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  0]  1 */
    52451834, /* 12483 ( 307) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
    51034820, /* 12484 ( 307) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  0] -1 */
    34146806, /* 12485 ( 307) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
     1433498, /* 12486 ( 307) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  0]  1 */
    17140694, /* 12487 ( 307) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
    18557868, /* 12488 ( 307) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
    18557708, /* 12489 ( 307) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
       16484, /* 12490 ( 308) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    35563818, /* 12491 ( 308) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  6] -1 */
    17140530, /* 12492 ( 308) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  6]  1 */
       16320, /* 12493 ( 308) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    51034818, /* 12494 ( 308) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  0] -1 */
     1433658, /* 12495 ( 308) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  0]  1 */
    52451832, /* 12496 ( 308) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
    34146644, /* 12497 ( 308) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    35563982, /* 12498 ( 308) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
    34146804, /* 12499 ( 308) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
    51034658, /* 12500 ( 308) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  0] -1 */
     1433498, /* 12501 ( 308) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  0]  1 */
    17140694, /* 12502 ( 308) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
    52451996, /* 12503 ( 308) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
    18557868, /* 12504 ( 308) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
    18557708, /* 12505 ( 308) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
       16484, /* 12506 ( 301) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    18439608, /* 12507 ( 301) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
       16320, /* 12508 ( 301) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
      134420, /* 12509 ( 301) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6]  1 */
      134580, /* 12510 ( 301) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  6]  1 */
    18439772, /* 12511 ( 301) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    18557708, /* 12512 ( 301) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    18557868, /* 12513 ( 301) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
       16484, /* 12514 ( 302) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    18439608, /* 12515 ( 302) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
       16320, /* 12516 ( 302) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    34146804, /* 12517 ( 302) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
    52569932, /* 12518 ( 302) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
      134420, /* 12519 ( 302) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6]  1 */
    52451996, /* 12520 ( 302) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
    52570092, /* 12521 ( 302) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
      134580, /* 12522 ( 302) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  6]  1 */
    18439772, /* 12523 ( 302) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    34028544, /* 12524 ( 302) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    18557708, /* 12525 ( 302) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    34028708, /* 12526 ( 302) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    52451832, /* 12527 ( 302) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
    18557868, /* 12528 ( 302) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
    34146644, /* 12529 ( 302) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
       16484, /* 12530 ( 303) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34146804, /* 12531 ( 303) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
      134420, /* 12532 ( 303) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6]  1 */
    52570092, /* 12533 ( 303) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    18439772, /* 12534 ( 303) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    52451832, /* 12535 ( 303) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
    34028544, /* 12536 ( 303) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    18557708, /* 12537 ( 303) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
       16484, /* 12538 ( 304) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    52569932, /* 12539 ( 304) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
      134580, /* 12540 ( 304) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  6]  1 */
    18439772, /* 12541 ( 304) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    34028544, /* 12542 ( 304) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    52451832, /* 12543 ( 304) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
    18557868, /* 12544 ( 304) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
    34146644, /* 12545 ( 304) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
       16484, /* 12546 ( 305) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    18439608, /* 12547 ( 305) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
       16320, /* 12548 ( 305) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    34146804, /* 12549 ( 305) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
    52569932, /* 12550 ( 305) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    52570092, /* 12551 ( 305) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    18439772, /* 12552 ( 305) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    34146644, /* 12553 ( 305) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
       16484, /* 12554 ( 306) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34028706, /* 12555 ( 306) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    52569930, /* 12556 ( 306) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    18439608, /* 12557 ( 306) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
       16320, /* 12558 ( 306) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    34146806, /* 12559 ( 306) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    52451994, /* 12560 ( 306) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
      134420, /* 12561 ( 306) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6]  1 */
    34146642, /* 12562 ( 306) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
    18557708, /* 12563 ( 306) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
      134580, /* 12564 ( 306) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  6]  1 */
    18439772, /* 12565 ( 306) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    34028546, /* 12566 ( 306) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    52570094, /* 12567 ( 306) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    18557868, /* 12568 ( 306) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
    52451834, /* 12569 ( 306) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
       16484, /* 12570 ( 307) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    35563820, /* 12571 ( 307) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
    51034656, /* 12572 ( 307) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  0] -1 */
    18439608, /* 12573 ( 307) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
       16320, /* 12574 ( 307) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    51152756, /* 12575 ( 307) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
    35563980, /* 12576 ( 307) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6] -1 */
    35445720, /* 12577 ( 307) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  0] -1 */
      134420, /* 12578 ( 307) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6]  1 */
    51152916, /* 12579 ( 307) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6] -1 */
    51034820, /* 12580 ( 307) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  0] -1 */
    35445884, /* 12581 ( 307) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  0] -1 */
      134580, /* 12582 ( 307) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  6]  1 */
    18439772, /* 12583 ( 307) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    18557708, /* 12584 ( 307) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    18557868, /* 12585 ( 307) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
       16484, /* 12586 ( 308) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    35563818, /* 12587 ( 308) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  6] -1 */
    18439608, /* 12588 ( 308) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
       16320, /* 12589 ( 308) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    51034658, /* 12590 ( 308) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  0] -1 */
      134420, /* 12591 ( 308) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6]  1 */
    51152754, /* 12592 ( 308) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  6] -1 */
    35445882, /* 12593 ( 308) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  0] -1 */
    35563982, /* 12594 ( 308) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
    35445722, /* 12595 ( 308) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  0] -1 */
    51034818, /* 12596 ( 308) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  0] -1 */
      134580, /* 12597 ( 308) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  6]  1 */
    18439772, /* 12598 ( 308) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    51152918, /* 12599 ( 308) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
    18557708, /* 12600 ( 308) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    18557868, /* 12601 ( 308) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
       16484, /* 12602 ( 301) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    18426648, /* 12603 ( 301) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
        3360, /* 12604 ( 301) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
      121460, /* 12605 ( 301) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6]  1 */
      134580, /* 12606 ( 301) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  6]  1 */
    18439772, /* 12607 ( 301) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    18544748, /* 12608 ( 301) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    18557868, /* 12609 ( 301) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
       16484, /* 12610 ( 302) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    18426648, /* 12611 ( 302) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
        3360, /* 12612 ( 302) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    34146804, /* 12613 ( 302) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
    52556972, /* 12614 ( 302) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
      121460, /* 12615 ( 302) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6]  1 */
    52451996, /* 12616 ( 302) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
    52570092, /* 12617 ( 302) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
      134580, /* 12618 ( 302) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  6]  1 */
    18439772, /* 12619 ( 302) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    34015584, /* 12620 ( 302) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    18544748, /* 12621 ( 302) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    34028708, /* 12622 ( 302) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    52438872, /* 12623 ( 302) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
    18557868, /* 12624 ( 302) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
    34133684, /* 12625 ( 302) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
       16484, /* 12626 ( 303) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34146804, /* 12627 ( 303) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
      121460, /* 12628 ( 303) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6]  1 */
    52570092, /* 12629 ( 303) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    18439772, /* 12630 ( 303) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    52438872, /* 12631 ( 303) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
    34015584, /* 12632 ( 303) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    18544748, /* 12633 ( 303) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
       16484, /* 12634 ( 304) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    52556972, /* 12635 ( 304) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
      134580, /* 12636 ( 304) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  6]  1 */
    18439772, /* 12637 ( 304) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    34015584, /* 12638 ( 304) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    52438872, /* 12639 ( 304) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
    18557868, /* 12640 ( 304) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
    34133684, /* 12641 ( 304) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
       16484, /* 12642 ( 305) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    18426648, /* 12643 ( 305) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
        3360, /* 12644 ( 305) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    34146804, /* 12645 ( 305) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
    52556972, /* 12646 ( 305) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    52570092, /* 12647 ( 305) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    18439772, /* 12648 ( 305) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    34133684, /* 12649 ( 305) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
       16484, /* 12650 ( 306) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34028706, /* 12651 ( 306) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    52556970, /* 12652 ( 306) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    18426648, /* 12653 ( 306) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
        3360, /* 12654 ( 306) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    34146806, /* 12655 ( 306) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    52451994, /* 12656 ( 306) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
      121460, /* 12657 ( 306) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6]  1 */
    34133682, /* 12658 ( 306) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
    18544748, /* 12659 ( 306) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
      134580, /* 12660 ( 306) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  6]  1 */
    18439772, /* 12661 ( 306) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    34015586, /* 12662 ( 306) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    52570094, /* 12663 ( 306) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    18557868, /* 12664 ( 306) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
    52438874, /* 12665 ( 306) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
       16484, /* 12666 ( 307) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    51139796, /* 12667 ( 307) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
    35432760, /* 12668 ( 307) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  0] -1 */
    18426648, /* 12669 ( 307) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
        3360, /* 12670 ( 307) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    35550860, /* 12671 ( 307) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
    51152916, /* 12672 ( 307) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6] -1 */
    51021696, /* 12673 ( 307) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  0] -1 */
      121460, /* 12674 ( 307) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6]  1 */
    35563980, /* 12675 ( 307) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6] -1 */
    35445884, /* 12676 ( 307) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  0] -1 */
    51034820, /* 12677 ( 307) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  0] -1 */
      134580, /* 12678 ( 307) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  6]  1 */
    18439772, /* 12679 ( 307) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    18544748, /* 12680 ( 307) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    18557868, /* 12681 ( 307) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
       16484, /* 12682 ( 308) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    51139794, /* 12683 ( 308) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6] -1 */
    18426648, /* 12684 ( 308) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
        3360, /* 12685 ( 308) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    35432762, /* 12686 ( 308) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  0] -1 */
      121460, /* 12687 ( 308) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6]  1 */
    35550858, /* 12688 ( 308) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6] -1 */
    51034818, /* 12689 ( 308) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  0] -1 */
    51152918, /* 12690 ( 308) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
    51021698, /* 12691 ( 308) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  0] -1 */
    35445882, /* 12692 ( 308) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  0] -1 */
      134580, /* 12693 ( 308) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  6]  1 */
    18439772, /* 12694 ( 308) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    35563982, /* 12695 ( 308) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
    18544748, /* 12696 ( 308) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    18557868, /* 12697 ( 308) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
       16484, /* 12698 ( 301) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
     1538634, /* 12699 ( 301) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
        3360, /* 12700 ( 301) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    17022594, /* 12701 ( 301) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  0]  1 */
    17009474, /* 12702 ( 301) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  0]  1 */
     1551758, /* 12703 ( 301) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
    18557868, /* 12704 ( 301) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
    18544748, /* 12705 ( 301) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
       16484, /* 12706 ( 302) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
     1538634, /* 12707 ( 302) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
        3360, /* 12708 ( 302) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    51021698, /* 12709 ( 302) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  0] -1 */
    52570092, /* 12710 ( 302) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    17022594, /* 12711 ( 302) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  0]  1 */
    35563982, /* 12712 ( 302) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
    52556972, /* 12713 ( 302) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    17009474, /* 12714 ( 302) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  0]  1 */
     1551758, /* 12715 ( 302) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
    34015584, /* 12716 ( 302) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    18557868, /* 12717 ( 302) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
    34028708, /* 12718 ( 302) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    35550858, /* 12719 ( 302) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6] -1 */
    18544748, /* 12720 ( 302) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    51034818, /* 12721 ( 302) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  0] -1 */
       16484, /* 12722 ( 303) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    51021698, /* 12723 ( 303) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  0] -1 */
    17022594, /* 12724 ( 303) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  0]  1 */
    52556972, /* 12725 ( 303) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
     1551758, /* 12726 ( 303) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
    35550858, /* 12727 ( 303) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6] -1 */
    34015584, /* 12728 ( 303) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    18557868, /* 12729 ( 303) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
       16484, /* 12730 ( 304) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    52570092, /* 12731 ( 304) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    17009474, /* 12732 ( 304) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  0]  1 */
     1551758, /* 12733 ( 304) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
    34015584, /* 12734 ( 304) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    35550858, /* 12735 ( 304) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6] -1 */
    18544748, /* 12736 ( 304) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    51034818, /* 12737 ( 304) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  0] -1 */
       16484, /* 12738 ( 305) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
     1538634, /* 12739 ( 305) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
        3360, /* 12740 ( 305) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    51021698, /* 12741 ( 305) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  0] -1 */
    52570092, /* 12742 ( 305) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    52556972, /* 12743 ( 305) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
     1551758, /* 12744 ( 305) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
    51034818, /* 12745 ( 305) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  0] -1 */
       16484, /* 12746 ( 306) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34015586, /* 12747 ( 306) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    52556970, /* 12748 ( 306) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
     1538634, /* 12749 ( 306) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
        3360, /* 12750 ( 306) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    51034820, /* 12751 ( 306) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  0] -1 */
    35550860, /* 12752 ( 306) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
    17022594, /* 12753 ( 306) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  0]  1 */
    51021696, /* 12754 ( 306) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  0] -1 */
    18557868, /* 12755 ( 306) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
    17009474, /* 12756 ( 306) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  0]  1 */
     1551758, /* 12757 ( 306) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
    34028706, /* 12758 ( 306) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    52570094, /* 12759 ( 306) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    18544748, /* 12760 ( 306) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    35563980, /* 12761 ( 306) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6] -1 */
       16484, /* 12762 ( 307) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    51152916, /* 12763 ( 307) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6] -1 */
    35432760, /* 12764 ( 307) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  0] -1 */
     1538634, /* 12765 ( 307) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
        3360, /* 12766 ( 307) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    52451994, /* 12767 ( 307) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
    51139796, /* 12768 ( 307) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
    34133682, /* 12769 ( 307) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
    17022594, /* 12770 ( 307) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  0]  1 */
    52438874, /* 12771 ( 307) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
    35445884, /* 12772 ( 307) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  0] -1 */
    34146806, /* 12773 ( 307) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    17009474, /* 12774 ( 307) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  0]  1 */
     1551758, /* 12775 ( 307) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
    18557868, /* 12776 ( 307) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
    18544748, /* 12777 ( 307) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
       16484, /* 12778 ( 308) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    51139794, /* 12779 ( 308) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6] -1 */
     1538634, /* 12780 ( 308) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
        3360, /* 12781 ( 308) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    35445882, /* 12782 ( 308) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  0] -1 */
    17022594, /* 12783 ( 308) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  0]  1 */
    52438872, /* 12784 ( 308) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
    34133684, /* 12785 ( 308) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    51152918, /* 12786 ( 308) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
    34146804, /* 12787 ( 308) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
    35432762, /* 12788 ( 308) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  0] -1 */
    17009474, /* 12789 ( 308) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  0]  1 */
     1551758, /* 12790 ( 308) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
    52451996, /* 12791 ( 308) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
    18557868, /* 12792 ( 308) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
    18544748, /* 12793 ( 308) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
       16484, /* 12794 ( 309) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
     1538474, /* 12795 ( 309) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
        3200, /* 12796 ( 309) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    18439610, /* 12797 ( 309) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    18426650, /* 12798 ( 309) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    17140532, /* 12799 ( 309) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
     1551758, /* 12800 ( 309) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
    17127572, /* 12801 ( 309) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
       16484, /* 12802 ( 310) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    52451834, /* 12803 ( 310) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
     1538474, /* 12804 ( 310) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
        3200, /* 12805 ( 310) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    18439610, /* 12806 ( 310) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    51152756, /* 12807 ( 310) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
    52438874, /* 12808 ( 310) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
    35563982, /* 12809 ( 310) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
    18426650, /* 12810 ( 310) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    51139796, /* 12811 ( 310) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
    17140532, /* 12812 ( 310) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
     1551758, /* 12813 ( 310) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
    35550698, /* 12814 ( 310) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
    34015424, /* 12815 ( 310) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    34028708, /* 12816 ( 310) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    17127572, /* 12817 ( 310) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
       16484, /* 12818 ( 311) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    18439610, /* 12819 ( 311) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    52438874, /* 12820 ( 311) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
    51139796, /* 12821 ( 311) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
    17140532, /* 12822 ( 311) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
     1551758, /* 12823 ( 311) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
    35550698, /* 12824 ( 311) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
    34015424, /* 12825 ( 311) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
       16484, /* 12826 ( 312) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    52451834, /* 12827 ( 312) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
    51152756, /* 12828 ( 312) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
    18426650, /* 12829 ( 312) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
     1551758, /* 12830 ( 312) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
    35550698, /* 12831 ( 312) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
    34015424, /* 12832 ( 312) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    17127572, /* 12833 ( 312) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
       16484, /* 12834 ( 313) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    52451834, /* 12835 ( 313) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
     1538474, /* 12836 ( 313) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
        3200, /* 12837 ( 313) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    51152756, /* 12838 ( 313) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
    52438874, /* 12839 ( 313) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
    51139796, /* 12840 ( 313) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
     1551758, /* 12841 ( 313) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
       16484, /* 12842 ( 314) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    52556810, /* 12843 ( 314) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
     1538474, /* 12844 ( 314) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
        3200, /* 12845 ( 314) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    18439610, /* 12846 ( 314) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    51034820, /* 12847 ( 314) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  0] -1 */
    34146644, /* 12848 ( 314) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    35432762, /* 12849 ( 314) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  0] -1 */
    18426650, /* 12850 ( 314) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    35445722, /* 12851 ( 314) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  0] -1 */
    34133684, /* 12852 ( 314) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    17140532, /* 12853 ( 314) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
     1551758, /* 12854 ( 314) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
    51021536, /* 12855 ( 314) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  0] -1 */
    52570094, /* 12856 ( 314) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    17127572, /* 12857 ( 314) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
       16484, /* 12858 ( 315) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34133522, /* 12859 ( 315) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
     1538474, /* 12860 ( 315) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
        3200, /* 12861 ( 315) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    18439610, /* 12862 ( 315) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    51021698, /* 12863 ( 315) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  0] -1 */
    52569932, /* 12864 ( 315) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    35432600, /* 12865 ( 315) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  0] -1 */
    51034658, /* 12866 ( 315) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  0] -1 */
    18426650, /* 12867 ( 315) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    34146806, /* 12868 ( 315) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    35445884, /* 12869 ( 315) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  0] -1 */
     1551758, /* 12870 ( 315) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
    17140532, /* 12871 ( 315) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
    52556972, /* 12872 ( 315) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    17127572, /* 12873 ( 315) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
       16484, /* 12874 ( 316) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34015586, /* 12875 ( 316) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    34028546, /* 12876 ( 316) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
     1538474, /* 12877 ( 316) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
        3200, /* 12878 ( 316) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    18439610, /* 12879 ( 316) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    35550860, /* 12880 ( 316) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
    51139634, /* 12881 ( 316) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
    18426650, /* 12882 ( 316) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    52451996, /* 12883 ( 316) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
    17140532, /* 12884 ( 316) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
     1551758, /* 12885 ( 316) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
    51152918, /* 12886 ( 316) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
    52438712, /* 12887 ( 316) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
    35563820, /* 12888 ( 316) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
    17127572, /* 12889 ( 316) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
       16484, /* 12890 ( 309) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    17127410, /* 12891 ( 309) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
        3200, /* 12892 ( 309) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    18426650, /* 12893 ( 309) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    18439610, /* 12894 ( 309) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
     1538636, /* 12895 ( 309) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
    17140694, /* 12896 ( 309) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
     1551596, /* 12897 ( 309) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
       16484, /* 12898 ( 310) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    52438874, /* 12899 ( 310) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
    17127410, /* 12900 ( 310) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
        3200, /* 12901 ( 310) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    18426650, /* 12902 ( 310) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    35550860, /* 12903 ( 310) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
    52451834, /* 12904 ( 310) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
    51152918, /* 12905 ( 310) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
    18439610, /* 12906 ( 310) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    35563820, /* 12907 ( 310) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
     1538636, /* 12908 ( 310) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
    17140694, /* 12909 ( 310) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
    51139634, /* 12910 ( 310) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
    34015424, /* 12911 ( 310) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    34028708, /* 12912 ( 310) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
     1551596, /* 12913 ( 310) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
       16484, /* 12914 ( 311) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    18426650, /* 12915 ( 311) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    52451834, /* 12916 ( 311) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
    35563820, /* 12917 ( 311) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
     1538636, /* 12918 ( 311) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
    17140694, /* 12919 ( 311) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
    51139634, /* 12920 ( 311) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
    34015424, /* 12921 ( 311) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
       16484, /* 12922 ( 312) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    52438874, /* 12923 ( 312) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
    35550860, /* 12924 ( 312) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
    18439610, /* 12925 ( 312) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    17140694, /* 12926 ( 312) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
    51139634, /* 12927 ( 312) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
    34015424, /* 12928 ( 312) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
     1551596, /* 12929 ( 312) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
       16484, /* 12930 ( 313) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    52438874, /* 12931 ( 313) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
    17127410, /* 12932 ( 313) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
        3200, /* 12933 ( 313) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    35550860, /* 12934 ( 313) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
    52451834, /* 12935 ( 313) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
    35563820, /* 12936 ( 313) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
    17140694, /* 12937 ( 313) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
       16484, /* 12938 ( 314) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    52556810, /* 12939 ( 314) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    17127410, /* 12940 ( 314) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
        3200, /* 12941 ( 314) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    18426650, /* 12942 ( 314) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    35445884, /* 12943 ( 314) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  0] -1 */
    34133684, /* 12944 ( 314) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    51034658, /* 12945 ( 314) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  0] -1 */
    18439610, /* 12946 ( 314) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    51021698, /* 12947 ( 314) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  0] -1 */
    34146644, /* 12948 ( 314) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
     1538636, /* 12949 ( 314) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
    17140694, /* 12950 ( 314) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
    35432600, /* 12951 ( 314) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  0] -1 */
    52570094, /* 12952 ( 314) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
     1551596, /* 12953 ( 314) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
       16484, /* 12954 ( 315) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34133522, /* 12955 ( 315) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    17127410, /* 12956 ( 315) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
        3200, /* 12957 ( 315) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    18426650, /* 12958 ( 315) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    35445722, /* 12959 ( 315) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  0] -1 */
    52556972, /* 12960 ( 315) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    51021536, /* 12961 ( 315) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  0] -1 */
    35432762, /* 12962 ( 315) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  0] -1 */
    18439610, /* 12963 ( 315) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    34146806, /* 12964 ( 315) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    51034820, /* 12965 ( 315) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  0] -1 */
    17140694, /* 12966 ( 315) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
     1538636, /* 12967 ( 315) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
    52569932, /* 12968 ( 315) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
     1551596, /* 12969 ( 315) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
       16484, /* 12970 ( 316) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34028546, /* 12971 ( 316) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    34015586, /* 12972 ( 316) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    17127410, /* 12973 ( 316) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
        3200, /* 12974 ( 316) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    18426650, /* 12975 ( 316) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    51152756, /* 12976 ( 316) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
    35550698, /* 12977 ( 316) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
    18439610, /* 12978 ( 316) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    52451996, /* 12979 ( 316) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
     1538636, /* 12980 ( 316) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
    17140694, /* 12981 ( 316) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
    35563982, /* 12982 ( 316) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
    52438712, /* 12983 ( 316) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
    51139796, /* 12984 ( 316) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
     1551596, /* 12985 ( 316) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
       16484, /* 12986 ( 309) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    17140530, /* 12987 ( 309) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  6]  1 */
       16320, /* 12988 ( 309) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
     1551756, /* 12989 ( 309) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
     1551596, /* 12990 ( 309) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
    18439770, /* 12991 ( 309) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
    17140694, /* 12992 ( 309) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
    18439610, /* 12993 ( 309) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
       16484, /* 12994 ( 310) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    35563980, /* 12995 ( 310) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6] -1 */
    17140530, /* 12996 ( 310) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  6]  1 */
       16320, /* 12997 ( 310) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
     1551756, /* 12998 ( 310) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
    52451994, /* 12999 ( 310) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
    35563820, /* 13000 ( 310) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
    51152918, /* 13001 ( 310) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
     1551596, /* 13002 ( 310) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
    52451834, /* 13003 ( 310) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
    18439770, /* 13004 ( 310) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
    17140694, /* 13005 ( 310) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
    51152754, /* 13006 ( 310) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  6] -1 */
    34028544, /* 13007 ( 310) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    34028708, /* 13008 ( 310) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    18439610, /* 13009 ( 310) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
       16484, /* 13010 ( 311) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
     1551756, /* 13011 ( 311) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
    35563820, /* 13012 ( 311) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
    52451834, /* 13013 ( 311) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
    18439770, /* 13014 ( 311) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
    17140694, /* 13015 ( 311) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
    51152754, /* 13016 ( 311) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  6] -1 */
    34028544, /* 13017 ( 311) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
       16484, /* 13018 ( 312) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    35563980, /* 13019 ( 312) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6] -1 */
    52451994, /* 13020 ( 312) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
     1551596, /* 13021 ( 312) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
    17140694, /* 13022 ( 312) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
    51152754, /* 13023 ( 312) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  6] -1 */
    34028544, /* 13024 ( 312) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    18439610, /* 13025 ( 312) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
       16484, /* 13026 ( 313) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    35563980, /* 13027 ( 313) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6] -1 */
    17140530, /* 13028 ( 313) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  6]  1 */
       16320, /* 13029 ( 313) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    52451994, /* 13030 ( 313) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
    35563820, /* 13031 ( 313) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
    52451834, /* 13032 ( 313) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
    17140694, /* 13033 ( 313) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
       16484, /* 13034 ( 314) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    52569930, /* 13035 ( 314) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    17140530, /* 13036 ( 314) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  6]  1 */
       16320, /* 13037 ( 314) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
     1551756, /* 13038 ( 314) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
    35445884, /* 13039 ( 314) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  0] -1 */
    51034818, /* 13040 ( 314) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  0] -1 */
    34146644, /* 13041 ( 314) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
     1551596, /* 13042 ( 314) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
    34146804, /* 13043 ( 314) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
    51034658, /* 13044 ( 314) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  0] -1 */
    18439770, /* 13045 ( 314) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
    17140694, /* 13046 ( 314) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
    35445720, /* 13047 ( 314) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  0] -1 */
    52570094, /* 13048 ( 314) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    18439610, /* 13049 ( 314) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
       16484, /* 13050 ( 315) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    51034656, /* 13051 ( 315) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  0] -1 */
    17140530, /* 13052 ( 315) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  6]  1 */
       16320, /* 13053 ( 315) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
     1551756, /* 13054 ( 315) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
    35445722, /* 13055 ( 315) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  0] -1 */
    52570092, /* 13056 ( 315) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    34146642, /* 13057 ( 315) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
    35445882, /* 13058 ( 315) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  0] -1 */
     1551596, /* 13059 ( 315) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
    51034820, /* 13060 ( 315) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  0] -1 */
    34146806, /* 13061 ( 315) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    17140694, /* 13062 ( 315) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
    18439770, /* 13063 ( 315) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
    52569932, /* 13064 ( 315) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    18439610, /* 13065 ( 315) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
       16484, /* 13066 ( 316) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34028546, /* 13067 ( 316) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    34028706, /* 13068 ( 316) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    17140530, /* 13069 ( 316) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  6]  1 */
       16320, /* 13070 ( 316) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
     1551756, /* 13071 ( 316) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
    51152756, /* 13072 ( 316) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
    52451832, /* 13073 ( 316) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
     1551596, /* 13074 ( 316) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
    35563982, /* 13075 ( 316) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
    18439770, /* 13076 ( 316) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
    17140694, /* 13077 ( 316) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
    52451996, /* 13078 ( 316) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
    35563818, /* 13079 ( 316) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  6] -1 */
    51152916, /* 13080 ( 316) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6] -1 */
    18439610, /* 13081 ( 316) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
       16484, /* 13082 ( 309) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    18439608, /* 13083 ( 309) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
       16320, /* 13084 ( 309) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
     1551596, /* 13085 ( 309) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
     1551756, /* 13086 ( 309) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
    17140532, /* 13087 ( 309) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
    18439772, /* 13088 ( 309) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    17140692, /* 13089 ( 309) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6]  1 */
       16484, /* 13090 ( 310) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    35563820, /* 13091 ( 310) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
    18439608, /* 13092 ( 310) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
       16320, /* 13093 ( 310) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
     1551596, /* 13094 ( 310) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
    51152756, /* 13095 ( 310) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
    35563980, /* 13096 ( 310) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6] -1 */
    52451996, /* 13097 ( 310) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
     1551756, /* 13098 ( 310) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
    51152916, /* 13099 ( 310) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6] -1 */
    17140532, /* 13100 ( 310) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
    18439772, /* 13101 ( 310) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    52451832, /* 13102 ( 310) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
    34028544, /* 13103 ( 310) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    34028708, /* 13104 ( 310) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    17140692, /* 13105 ( 310) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6]  1 */
       16484, /* 13106 ( 311) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
     1551596, /* 13107 ( 311) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
    35563980, /* 13108 ( 311) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6] -1 */
    51152916, /* 13109 ( 311) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6] -1 */
    17140532, /* 13110 ( 311) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
    18439772, /* 13111 ( 311) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    52451832, /* 13112 ( 311) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
    34028544, /* 13113 ( 311) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
       16484, /* 13114 ( 312) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    35563820, /* 13115 ( 312) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
    51152756, /* 13116 ( 312) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
     1551756, /* 13117 ( 312) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
    18439772, /* 13118 ( 312) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    52451832, /* 13119 ( 312) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
    34028544, /* 13120 ( 312) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    17140692, /* 13121 ( 312) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6]  1 */
       16484, /* 13122 ( 313) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    35563820, /* 13123 ( 313) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
    18439608, /* 13124 ( 313) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
       16320, /* 13125 ( 313) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    51152756, /* 13126 ( 313) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
    35563980, /* 13127 ( 313) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6] -1 */
    51152916, /* 13128 ( 313) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6] -1 */
    18439772, /* 13129 ( 313) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
       16484, /* 13130 ( 314) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    52569930, /* 13131 ( 314) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    18439608, /* 13132 ( 314) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
       16320, /* 13133 ( 314) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
     1551596, /* 13134 ( 314) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
    34146806, /* 13135 ( 314) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    51034658, /* 13136 ( 314) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  0] -1 */
    35445882, /* 13137 ( 314) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  0] -1 */
     1551756, /* 13138 ( 314) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
    35445722, /* 13139 ( 314) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  0] -1 */
    51034818, /* 13140 ( 314) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  0] -1 */
    17140532, /* 13141 ( 314) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
    18439772, /* 13142 ( 314) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    34146642, /* 13143 ( 314) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
    52570094, /* 13144 ( 314) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    17140692, /* 13145 ( 314) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6]  1 */
       16484, /* 13146 ( 315) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    51034656, /* 13147 ( 315) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  0] -1 */
    18439608, /* 13148 ( 315) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
       16320, /* 13149 ( 315) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
     1551596, /* 13150 ( 315) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
    34146804, /* 13151 ( 315) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
    52569932, /* 13152 ( 315) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    35445720, /* 13153 ( 315) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  0] -1 */
    34146644, /* 13154 ( 315) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
     1551756, /* 13155 ( 315) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
    51034820, /* 13156 ( 315) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  0] -1 */
    35445884, /* 13157 ( 315) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  0] -1 */
    18439772, /* 13158 ( 315) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    17140532, /* 13159 ( 315) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
    52570092, /* 13160 ( 315) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    17140692, /* 13161 ( 315) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6]  1 */
       16484, /* 13162 ( 316) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34028706, /* 13163 ( 316) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    34028546, /* 13164 ( 316) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    18439608, /* 13165 ( 316) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
       16320, /* 13166 ( 316) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
     1551596, /* 13167 ( 316) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
    52451994, /* 13168 ( 316) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
    51152754, /* 13169 ( 316) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  6] -1 */
     1551756, /* 13170 ( 316) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
    35563982, /* 13171 ( 316) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
    17140532, /* 13172 ( 316) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
    18439772, /* 13173 ( 316) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    51152918, /* 13174 ( 316) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
    35563818, /* 13175 ( 316) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  6] -1 */
    52451834, /* 13176 ( 316) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
    17140692, /* 13177 ( 316) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6]  1 */
       16484, /* 13178 ( 309) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    18426648, /* 13179 ( 309) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
        3360, /* 13180 ( 309) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    17127572, /* 13181 ( 309) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
    17140692, /* 13182 ( 309) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6]  1 */
     1538636, /* 13183 ( 309) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
    18439772, /* 13184 ( 309) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
     1551756, /* 13185 ( 309) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
       16484, /* 13186 ( 310) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    51139796, /* 13187 ( 310) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
    18426648, /* 13188 ( 310) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
        3360, /* 13189 ( 310) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    17127572, /* 13190 ( 310) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
    35550860, /* 13191 ( 310) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
    51152916, /* 13192 ( 310) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6] -1 */
    52451996, /* 13193 ( 310) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
    17140692, /* 13194 ( 310) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6]  1 */
    35563980, /* 13195 ( 310) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6] -1 */
     1538636, /* 13196 ( 310) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
    18439772, /* 13197 ( 310) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    52438872, /* 13198 ( 310) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
    34015584, /* 13199 ( 310) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    34028708, /* 13200 ( 310) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
     1551756, /* 13201 ( 310) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
       16484, /* 13202 ( 311) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    17127572, /* 13203 ( 311) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
    51152916, /* 13204 ( 311) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6] -1 */
    35563980, /* 13205 ( 311) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6] -1 */
     1538636, /* 13206 ( 311) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
    18439772, /* 13207 ( 311) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    52438872, /* 13208 ( 311) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
    34015584, /* 13209 ( 311) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
       16484, /* 13210 ( 312) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    51139796, /* 13211 ( 312) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
    35550860, /* 13212 ( 312) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
    17140692, /* 13213 ( 312) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6]  1 */
    18439772, /* 13214 ( 312) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    52438872, /* 13215 ( 312) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
    34015584, /* 13216 ( 312) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
     1551756, /* 13217 ( 312) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
       16484, /* 13218 ( 313) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    51139796, /* 13219 ( 313) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
    18426648, /* 13220 ( 313) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
        3360, /* 13221 ( 313) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    35550860, /* 13222 ( 313) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
    51152916, /* 13223 ( 313) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6] -1 */
    35563980, /* 13224 ( 313) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6] -1 */
    18439772, /* 13225 ( 313) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
       16484, /* 13226 ( 314) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    52556970, /* 13227 ( 314) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    18426648, /* 13228 ( 314) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
        3360, /* 13229 ( 314) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    17127572, /* 13230 ( 314) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
    34146806, /* 13231 ( 314) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    35432762, /* 13232 ( 314) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  0] -1 */
    51034818, /* 13233 ( 314) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  0] -1 */
    17140692, /* 13234 ( 314) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6]  1 */
    51021698, /* 13235 ( 314) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  0] -1 */
    35445882, /* 13236 ( 314) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  0] -1 */
     1538636, /* 13237 ( 314) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
    18439772, /* 13238 ( 314) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    34133682, /* 13239 ( 314) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
    52570094, /* 13240 ( 314) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
     1551756, /* 13241 ( 314) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
       16484, /* 13242 ( 315) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    35432760, /* 13243 ( 315) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  0] -1 */
    18426648, /* 13244 ( 315) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
        3360, /* 13245 ( 315) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    17127572, /* 13246 ( 315) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
    34146804, /* 13247 ( 315) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
    52556972, /* 13248 ( 315) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    51021696, /* 13249 ( 315) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  0] -1 */
    34133684, /* 13250 ( 315) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    17140692, /* 13251 ( 315) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6]  1 */
    35445884, /* 13252 ( 315) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  0] -1 */
    51034820, /* 13253 ( 315) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  0] -1 */
    18439772, /* 13254 ( 315) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
     1538636, /* 13255 ( 315) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
    52570092, /* 13256 ( 315) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
     1551756, /* 13257 ( 315) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
       16484, /* 13258 ( 316) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34028706, /* 13259 ( 316) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    34015586, /* 13260 ( 316) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    18426648, /* 13261 ( 316) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
        3360, /* 13262 ( 316) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    17127572, /* 13263 ( 316) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
    52451994, /* 13264 ( 316) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
    35550858, /* 13265 ( 316) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6] -1 */
    17140692, /* 13266 ( 316) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6]  1 */
    51152918, /* 13267 ( 316) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
     1538636, /* 13268 ( 316) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
    18439772, /* 13269 ( 316) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    35563982, /* 13270 ( 316) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
    51139794, /* 13271 ( 316) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6] -1 */
    52438874, /* 13272 ( 316) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
     1551756, /* 13273 ( 316) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
       16484, /* 13274 ( 309) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
     1538634, /* 13275 ( 309) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
        3360, /* 13276 ( 309) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    17140692, /* 13277 ( 309) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6]  1 */
    17127572, /* 13278 ( 309) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
    18439770, /* 13279 ( 309) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
     1551758, /* 13280 ( 309) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
    18426650, /* 13281 ( 309) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
       16484, /* 13282 ( 310) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    51152916, /* 13283 ( 310) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6] -1 */
     1538634, /* 13284 ( 310) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
        3360, /* 13285 ( 310) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    17140692, /* 13286 ( 310) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6]  1 */
    52451994, /* 13287 ( 310) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
    51139796, /* 13288 ( 310) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
    35563982, /* 13289 ( 310) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
    17127572, /* 13290 ( 310) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
    52438874, /* 13291 ( 310) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
    18439770, /* 13292 ( 310) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
     1551758, /* 13293 ( 310) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
    35550858, /* 13294 ( 310) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6] -1 */
    34015584, /* 13295 ( 310) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    34028708, /* 13296 ( 310) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    18426650, /* 13297 ( 310) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
       16484, /* 13298 ( 311) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    17140692, /* 13299 ( 311) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6]  1 */
    51139796, /* 13300 ( 311) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
    52438874, /* 13301 ( 311) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
    18439770, /* 13302 ( 311) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
     1551758, /* 13303 ( 311) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
    35550858, /* 13304 ( 311) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6] -1 */
    34015584, /* 13305 ( 311) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
       16484, /* 13306 ( 312) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    51152916, /* 13307 ( 312) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6] -1 */
    52451994, /* 13308 ( 312) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
    17127572, /* 13309 ( 312) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
     1551758, /* 13310 ( 312) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
    35550858, /* 13311 ( 312) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6] -1 */
    34015584, /* 13312 ( 312) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    18426650, /* 13313 ( 312) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
       16484, /* 13314 ( 313) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    51152916, /* 13315 ( 313) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6] -1 */
     1538634, /* 13316 ( 313) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
        3360, /* 13317 ( 313) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    52451994, /* 13318 ( 313) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
    51139796, /* 13319 ( 313) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
    52438874, /* 13320 ( 313) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
     1551758, /* 13321 ( 313) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
       16484, /* 13322 ( 314) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    52556970, /* 13323 ( 314) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
     1538634, /* 13324 ( 314) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
        3360, /* 13325 ( 314) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    17140692, /* 13326 ( 314) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6]  1 */
    51034820, /* 13327 ( 314) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  0] -1 */
    35445882, /* 13328 ( 314) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  0] -1 */
    34133684, /* 13329 ( 314) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    17127572, /* 13330 ( 314) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
    34146804, /* 13331 ( 314) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
    35432762, /* 13332 ( 314) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  0] -1 */
    18439770, /* 13333 ( 314) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
     1551758, /* 13334 ( 314) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
    51021696, /* 13335 ( 314) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  0] -1 */
    52570094, /* 13336 ( 314) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    18426650, /* 13337 ( 314) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
       16484, /* 13338 ( 315) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    35432760, /* 13339 ( 315) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  0] -1 */
     1538634, /* 13340 ( 315) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
        3360, /* 13341 ( 315) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    17140692, /* 13342 ( 315) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6]  1 */
    51021698, /* 13343 ( 315) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  0] -1 */
    52570092, /* 13344 ( 315) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    34133682, /* 13345 ( 315) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
    51034818, /* 13346 ( 315) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  0] -1 */
    17127572, /* 13347 ( 315) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
    35445884, /* 13348 ( 315) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  0] -1 */
    34146806, /* 13349 ( 315) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
     1551758, /* 13350 ( 315) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
    18439770, /* 13351 ( 315) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
    52556972, /* 13352 ( 315) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    18426650, /* 13353 ( 315) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
       16484, /* 13354 ( 316) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34015586, /* 13355 ( 316) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    34028706, /* 13356 ( 316) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
     1538634, /* 13357 ( 316) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
        3360, /* 13358 ( 316) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    17140692, /* 13359 ( 316) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6]  1 */
    35550860, /* 13360 ( 316) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
    52438872, /* 13361 ( 316) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
    17127572, /* 13362 ( 316) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
    51152918, /* 13363 ( 316) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
    18439770, /* 13364 ( 316) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
     1551758, /* 13365 ( 316) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
    52451996, /* 13366 ( 316) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
    51139794, /* 13367 ( 316) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6] -1 */
    35563980, /* 13368 ( 316) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6] -1 */
    18426650, /* 13369 ( 316) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
       16484, /* 13370 ( 317) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    18426488, /* 13371 ( 317) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
     1538474, /* 13372 ( 317) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
        3200, /* 13373 ( 317) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    17140694, /* 13374 ( 317) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
        3362, /* 13375 ( 317) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    18439610, /* 13376 ( 317) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
       16322, /* 13377 ( 317) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
     1551596, /* 13378 ( 317) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
     1538636, /* 13379 ( 317) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
    18426650, /* 13380 ( 317) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    17127410, /* 13381 ( 317) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
     1551758, /* 13382 ( 317) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
    17140532, /* 13383 ( 317) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
    18439772, /* 13384 ( 317) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    17127572, /* 13385 ( 317) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
       16484, /* 13386 ( 318) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    17140694, /* 13387 ( 318) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
     1551596, /* 13388 ( 318) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
     1538636, /* 13389 ( 318) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
    52451996, /* 13390 ( 318) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
    17127410, /* 13391 ( 318) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
    17140532, /* 13392 ( 318) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
    17127572, /* 13393 ( 318) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
    52451834, /* 13394 ( 318) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
     1538474, /* 13395 ( 318) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
    52438874, /* 13396 ( 318) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
    18439772, /* 13397 ( 318) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    34015424, /* 13398 ( 318) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    34028708, /* 13399 ( 318) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    52438712, /* 13400 ( 318) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
    34028546, /* 13401 ( 318) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    34015586, /* 13402 ( 318) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    18439610, /* 13403 ( 318) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    35563982, /* 13404 ( 318) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
    18426650, /* 13405 ( 318) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    51152918, /* 13406 ( 318) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
    35563820, /* 13407 ( 318) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
       16322, /* 13408 ( 318) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    18426488, /* 13409 ( 318) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
        3200, /* 13410 ( 318) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    51152756, /* 13411 ( 318) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
        3362, /* 13412 ( 318) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    35550860, /* 13413 ( 318) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
    51139634, /* 13414 ( 318) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
    51139796, /* 13415 ( 318) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
     1551758, /* 13416 ( 318) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
    35550698, /* 13417 ( 318) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
       16484, /* 13418 ( 319) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    52451834, /* 13419 ( 319) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
    34028546, /* 13420 ( 319) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    17140694, /* 13421 ( 319) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
    51152756, /* 13422 ( 319) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
        3362, /* 13423 ( 319) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    35563820, /* 13424 ( 319) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
    51139634, /* 13425 ( 319) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
     1538636, /* 13426 ( 319) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
    18426650, /* 13427 ( 319) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
     1551758, /* 13428 ( 319) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
    35550698, /* 13429 ( 319) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
    18439772, /* 13430 ( 319) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    52438712, /* 13431 ( 319) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
    34015424, /* 13432 ( 319) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    17127572, /* 13433 ( 319) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
       16484, /* 13434 ( 320) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    18426488, /* 13435 ( 320) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    34015586, /* 13436 ( 320) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    34028546, /* 13437 ( 320) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    52451834, /* 13438 ( 320) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
     1538474, /* 13439 ( 320) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
        3200, /* 13440 ( 320) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    17140694, /* 13441 ( 320) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
    35550860, /* 13442 ( 320) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
    51152756, /* 13443 ( 320) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
    52438874, /* 13444 ( 320) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
    51139796, /* 13445 ( 320) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
    17127410, /* 13446 ( 320) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
     1551758, /* 13447 ( 320) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
    18439772, /* 13448 ( 320) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    35563820, /* 13449 ( 320) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
       16484, /* 13450 ( 321) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    17140694, /* 13451 ( 321) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
     1551596, /* 13452 ( 321) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
     1538636, /* 13453 ( 321) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
    17127410, /* 13454 ( 321) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
    17140532, /* 13455 ( 321) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
    52570094, /* 13456 ( 321) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    17127572, /* 13457 ( 321) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
    51034658, /* 13458 ( 321) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  0] -1 */
     1538474, /* 13459 ( 321) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
    51034820, /* 13460 ( 321) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  0] -1 */
    51021698, /* 13461 ( 321) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  0] -1 */
    34146644, /* 13462 ( 321) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    52569932, /* 13463 ( 321) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    34146806, /* 13464 ( 321) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    52556972, /* 13465 ( 321) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    34133684, /* 13466 ( 321) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    51021536, /* 13467 ( 321) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  0] -1 */
    18439772, /* 13468 ( 321) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    34133522, /* 13469 ( 321) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    52556810, /* 13470 ( 321) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    18439610, /* 13471 ( 321) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    18426650, /* 13472 ( 321) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    35445722, /* 13473 ( 321) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  0] -1 */
    35445884, /* 13474 ( 321) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  0] -1 */
       16322, /* 13475 ( 321) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    18426488, /* 13476 ( 321) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
        3200, /* 13477 ( 321) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
        3362, /* 13478 ( 321) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    35432600, /* 13479 ( 321) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  0] -1 */
    35432762, /* 13480 ( 321) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  0] -1 */
     1551758, /* 13481 ( 321) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
       16484, /* 13482 ( 317) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
     1551594, /* 13483 ( 317) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
    17140530, /* 13484 ( 317) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  6]  1 */
       16320, /* 13485 ( 317) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    18439772, /* 13486 ( 317) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
       16322, /* 13487 ( 317) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
     1551756, /* 13488 ( 317) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
       16482, /* 13489 ( 317) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    17140692, /* 13490 ( 317) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6]  1 */
    17140532, /* 13491 ( 317) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
     1551596, /* 13492 ( 317) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
    18439608, /* 13493 ( 317) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
    17140694, /* 13494 ( 317) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
    18439770, /* 13495 ( 317) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
     1551758, /* 13496 ( 317) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
    18439610, /* 13497 ( 317) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
       16484, /* 13498 ( 318) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    18439772, /* 13499 ( 318) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    17140692, /* 13500 ( 318) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6]  1 */
    17140532, /* 13501 ( 318) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
    35563982, /* 13502 ( 318) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
    18439608, /* 13503 ( 318) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
    18439770, /* 13504 ( 318) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
    18439610, /* 13505 ( 318) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    35563980, /* 13506 ( 318) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6] -1 */
    17140530, /* 13507 ( 318) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  6]  1 */
    35563820, /* 13508 ( 318) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
     1551758, /* 13509 ( 318) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
    34028544, /* 13510 ( 318) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    34028708, /* 13511 ( 318) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    35563818, /* 13512 ( 318) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  6] -1 */
    34028706, /* 13513 ( 318) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    34028546, /* 13514 ( 318) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
     1551756, /* 13515 ( 318) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
    51152918, /* 13516 ( 318) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
     1551596, /* 13517 ( 318) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
    52451996, /* 13518 ( 318) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
    51152916, /* 13519 ( 318) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6] -1 */
       16482, /* 13520 ( 318) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
     1551594, /* 13521 ( 318) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
       16320, /* 13522 ( 318) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    52451994, /* 13523 ( 318) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
       16322, /* 13524 ( 318) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    51152756, /* 13525 ( 318) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
    52451832, /* 13526 ( 318) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
    52451834, /* 13527 ( 318) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
    17140694, /* 13528 ( 318) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
    51152754, /* 13529 ( 318) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  6] -1 */
       16484, /* 13530 ( 319) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    35563980, /* 13531 ( 319) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6] -1 */
    34028706, /* 13532 ( 319) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    18439772, /* 13533 ( 319) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    52451994, /* 13534 ( 319) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
       16322, /* 13535 ( 319) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    51152916, /* 13536 ( 319) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6] -1 */
    52451832, /* 13537 ( 319) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
    17140532, /* 13538 ( 319) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
     1551596, /* 13539 ( 319) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
    17140694, /* 13540 ( 319) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
    51152754, /* 13541 ( 319) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  6] -1 */
     1551758, /* 13542 ( 319) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
    35563818, /* 13543 ( 319) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  6] -1 */
    34028544, /* 13544 ( 319) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    18439610, /* 13545 ( 319) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
       16484, /* 13546 ( 320) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
     1551594, /* 13547 ( 320) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
    34028546, /* 13548 ( 320) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    34028706, /* 13549 ( 320) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    35563980, /* 13550 ( 320) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6] -1 */
    17140530, /* 13551 ( 320) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  6]  1 */
       16320, /* 13552 ( 320) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    18439772, /* 13553 ( 320) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    51152756, /* 13554 ( 320) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
    52451994, /* 13555 ( 320) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
    35563820, /* 13556 ( 320) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
    52451834, /* 13557 ( 320) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
    18439608, /* 13558 ( 320) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
    17140694, /* 13559 ( 320) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
     1551758, /* 13560 ( 320) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
    51152916, /* 13561 ( 320) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6] -1 */
       16484, /* 13562 ( 321) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    18439772, /* 13563 ( 321) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    17140692, /* 13564 ( 321) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6]  1 */
    17140532, /* 13565 ( 321) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
    18439608, /* 13566 ( 321) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
    18439770, /* 13567 ( 321) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
    52570094, /* 13568 ( 321) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    18439610, /* 13569 ( 321) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    35445882, /* 13570 ( 321) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  0] -1 */
    17140530, /* 13571 ( 321) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  6]  1 */
    35445884, /* 13572 ( 321) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  0] -1 */
    35445722, /* 13573 ( 321) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  0] -1 */
    51034818, /* 13574 ( 321) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  0] -1 */
    52570092, /* 13575 ( 321) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    51034820, /* 13576 ( 321) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  0] -1 */
    52569932, /* 13577 ( 321) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    51034658, /* 13578 ( 321) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  0] -1 */
    35445720, /* 13579 ( 321) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  0] -1 */
     1551758, /* 13580 ( 321) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
    51034656, /* 13581 ( 321) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  0] -1 */
    52569930, /* 13582 ( 321) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
     1551756, /* 13583 ( 321) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
     1551596, /* 13584 ( 321) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
    34146804, /* 13585 ( 321) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
    34146806, /* 13586 ( 321) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
       16482, /* 13587 ( 321) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
     1551594, /* 13588 ( 321) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
       16320, /* 13589 ( 321) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
       16322, /* 13590 ( 321) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34146642, /* 13591 ( 321) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
    34146644, /* 13592 ( 321) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    17140694, /* 13593 ( 321) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
       16484, /* 13594 ( 317) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    17127570, /* 13595 ( 317) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6]  1 */
    18426648, /* 13596 ( 317) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
        3360, /* 13597 ( 317) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
     1551758, /* 13598 ( 317) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
       16482, /* 13599 ( 317) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    17127572, /* 13600 ( 317) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
        3362, /* 13601 ( 317) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    18426650, /* 13602 ( 317) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    18439770, /* 13603 ( 317) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
    17140692, /* 13604 ( 317) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6]  1 */
     1538634, /* 13605 ( 317) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
    18439772, /* 13606 ( 317) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
     1538636, /* 13607 ( 317) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
    17140694, /* 13608 ( 317) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
     1551756, /* 13609 ( 317) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
       16484, /* 13610 ( 318) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
     1551758, /* 13611 ( 318) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
    18426650, /* 13612 ( 318) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    18439770, /* 13613 ( 318) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
    51152918, /* 13614 ( 318) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
     1538634, /* 13615 ( 318) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
     1538636, /* 13616 ( 318) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
     1551756, /* 13617 ( 318) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
    51139796, /* 13618 ( 318) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
    18426648, /* 13619 ( 318) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
    51152916, /* 13620 ( 318) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6] -1 */
    17140694, /* 13621 ( 318) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
    34015584, /* 13622 ( 318) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    34028708, /* 13623 ( 318) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    51139794, /* 13624 ( 318) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6] -1 */
    34015586, /* 13625 ( 318) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    34028706, /* 13626 ( 318) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    17127572, /* 13627 ( 318) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
    52451996, /* 13628 ( 318) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
    17140692, /* 13629 ( 318) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6]  1 */
    35563982, /* 13630 ( 318) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
    52438874, /* 13631 ( 318) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
        3362, /* 13632 ( 318) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    17127570, /* 13633 ( 318) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6]  1 */
        3360, /* 13634 ( 318) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    35550860, /* 13635 ( 318) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
       16482, /* 13636 ( 318) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    52451994, /* 13637 ( 318) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
    35550858, /* 13638 ( 318) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6] -1 */
    35563980, /* 13639 ( 318) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6] -1 */
    18439772, /* 13640 ( 318) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    52438872, /* 13641 ( 318) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
       16484, /* 13642 ( 319) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    51139796, /* 13643 ( 319) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
    34015586, /* 13644 ( 319) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
     1551758, /* 13645 ( 319) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
    35550860, /* 13646 ( 319) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
       16482, /* 13647 ( 319) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    52438874, /* 13648 ( 319) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
    35550858, /* 13649 ( 319) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6] -1 */
    18439770, /* 13650 ( 319) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
    17140692, /* 13651 ( 319) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6]  1 */
    18439772, /* 13652 ( 319) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    52438872, /* 13653 ( 319) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
    17140694, /* 13654 ( 319) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
    51139794, /* 13655 ( 319) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6] -1 */
    34015584, /* 13656 ( 319) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
     1551756, /* 13657 ( 319) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
       16484, /* 13658 ( 320) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    17127570, /* 13659 ( 320) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6]  1 */
    34028706, /* 13660 ( 320) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    34015586, /* 13661 ( 320) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    51139796, /* 13662 ( 320) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
    18426648, /* 13663 ( 320) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
        3360, /* 13664 ( 320) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
     1551758, /* 13665 ( 320) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
    52451994, /* 13666 ( 320) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
    35550860, /* 13667 ( 320) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
    51152916, /* 13668 ( 320) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6] -1 */
    35563980, /* 13669 ( 320) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6] -1 */
     1538634, /* 13670 ( 320) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
    18439772, /* 13671 ( 320) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    17140694, /* 13672 ( 320) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
    52438874, /* 13673 ( 320) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
       16484, /* 13674 ( 321) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
     1551758, /* 13675 ( 321) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
    18426650, /* 13676 ( 321) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    18439770, /* 13677 ( 321) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
     1538634, /* 13678 ( 321) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
     1538636, /* 13679 ( 321) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
    52570094, /* 13680 ( 321) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
     1551756, /* 13681 ( 321) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
    34133684, /* 13682 ( 321) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    18426648, /* 13683 ( 321) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
    34146806, /* 13684 ( 321) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    34146804, /* 13685 ( 321) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
    35432762, /* 13686 ( 321) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  0] -1 */
    52556972, /* 13687 ( 321) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    35445884, /* 13688 ( 321) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  0] -1 */
    52570092, /* 13689 ( 321) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    35445882, /* 13690 ( 321) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  0] -1 */
    34133682, /* 13691 ( 321) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
    17140694, /* 13692 ( 321) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
    35432760, /* 13693 ( 321) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  0] -1 */
    52556970, /* 13694 ( 321) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    17127572, /* 13695 ( 321) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
    17140692, /* 13696 ( 321) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6]  1 */
    51021698, /* 13697 ( 321) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  0] -1 */
    51034820, /* 13698 ( 321) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  0] -1 */
        3362, /* 13699 ( 321) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    17127570, /* 13700 ( 321) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6]  1 */
        3360, /* 13701 ( 321) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
       16482, /* 13702 ( 321) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    51021696, /* 13703 ( 321) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  0] -1 */
    51034818, /* 13704 ( 321) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  0] -1 */
    18439772, /* 13705 ( 321) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
       16484, /* 13706 ( 322) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    18426488, /* 13707 ( 322) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    10809329, /* 13708 ( 322) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 3,  9,  9]  1 */
    27697343, /* 13709 ( 322) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 9,  9,  3]  1 */
     1538474, /* 13710 ( 322) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
        3200, /* 13711 ( 322) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    17140694, /* 13712 ( 322) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
    26411225, /* 13713 ( 322) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 9,  3,  9]  1 */
    26398265, /* 13714 ( 322) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 9,  3,  9]  1 */
     9287015, /* 13715 ( 322) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 3,  3,  3]  1 */
    17127410, /* 13716 ( 322) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
     1551758, /* 13717 ( 322) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
    18439772, /* 13718 ( 322) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    27710303, /* 13719 ( 322) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 9,  9,  3]  1 */
     9274055, /* 13720 ( 322) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 3,  3,  3]  1 */
    10822289, /* 13721 ( 322) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 3,  9,  9]  1 */
       16484, /* 13722 ( 323) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    17140694, /* 13723 ( 323) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
    52451996, /* 13724 ( 323) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
    17127410, /* 13725 ( 323) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
    27710303, /* 13726 ( 323) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 9,  9,  3]  1 */
    27697343, /* 13727 ( 323) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 9,  9,  3]  1 */
    43299239, /* 13728 ( 323) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 3,  3,  3] -1 */
     1538474, /* 13729 ( 323) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
    43286279, /* 13730 ( 323) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 3,  3,  3] -1 */
    44834513, /* 13731 ( 323) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 3,  9,  9] -1 */
    18439772, /* 13732 ( 323) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    34015424, /* 13733 ( 323) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    34028708, /* 13734 ( 323) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    44821553, /* 13735 ( 323) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 3,  9,  9] -1 */
    52438712, /* 13736 ( 323) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
    60423449, /* 13737 ( 323) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 9,  3,  9] -1 */
    60410489, /* 13738 ( 323) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 9,  3,  9] -1 */
    35563982, /* 13739 ( 323) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
     9287015, /* 13740 ( 323) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 3,  3,  3]  1 */
    51152918, /* 13741 ( 323) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
     9274055, /* 13742 ( 323) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 3,  3,  3]  1 */
    10822289, /* 13743 ( 323) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 3,  9,  9]  1 */
    18426488, /* 13744 ( 323) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    10809329, /* 13745 ( 323) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 3,  9,  9]  1 */
        3200, /* 13746 ( 323) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    26411225, /* 13747 ( 323) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 9,  3,  9]  1 */
    51139634, /* 13748 ( 323) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
    26398265, /* 13749 ( 323) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 9,  3,  9]  1 */
    61722527, /* 13750 ( 323) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 9,  9,  3] -1 */
     1551758, /* 13751 ( 323) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
    35550698, /* 13752 ( 323) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
    61709567, /* 13753 ( 323) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 9,  9,  3] -1 */
       16484, /* 13754 ( 324) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    10809329, /* 13755 ( 324) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 3,  9,  9]  1 */
    27697343, /* 13756 ( 324) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 9,  9,  3]  1 */
    43299239, /* 13757 ( 324) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 3,  3,  3] -1 */
    17140694, /* 13758 ( 324) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
    51139634, /* 13759 ( 324) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
    26398265, /* 13760 ( 324) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 9,  3,  9]  1 */
    44834513, /* 13761 ( 324) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 3,  9,  9] -1 */
    61722527, /* 13762 ( 324) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 9,  9,  3] -1 */
     1551758, /* 13763 ( 324) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
    35550698, /* 13764 ( 324) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
    18439772, /* 13765 ( 324) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    52438712, /* 13766 ( 324) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
    60423449, /* 13767 ( 324) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 9,  3,  9] -1 */
     9274055, /* 13768 ( 324) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 3,  3,  3]  1 */
    34015424, /* 13769 ( 324) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
       16484, /* 13770 ( 325) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    18426488, /* 13771 ( 325) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    60410489, /* 13772 ( 325) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 9,  3,  9] -1 */
    43299239, /* 13773 ( 325) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 3,  3,  3] -1 */
     1538474, /* 13774 ( 325) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
        3200, /* 13775 ( 325) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    17140694, /* 13776 ( 325) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
    60423449, /* 13777 ( 325) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 9,  3,  9] -1 */
    43286279, /* 13778 ( 325) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 3,  3,  3] -1 */
    44834513, /* 13779 ( 325) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 3,  9,  9] -1 */
    61722527, /* 13780 ( 325) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 9,  9,  3] -1 */
    17127410, /* 13781 ( 325) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
     1551758, /* 13782 ( 325) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
    18439772, /* 13783 ( 325) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    44821553, /* 13784 ( 325) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 3,  9,  9] -1 */
    61709567, /* 13785 ( 325) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 9,  9,  3] -1 */
       16484, /* 13786 ( 326) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    17140694, /* 13787 ( 326) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
    17127410, /* 13788 ( 326) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
    27710303, /* 13789 ( 326) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 9,  9,  3]  1 */
    52570094, /* 13790 ( 326) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    27697343, /* 13791 ( 326) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 9,  9,  3]  1 */
     1538474, /* 13792 ( 326) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
    51034820, /* 13793 ( 326) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  0] -1 */
    44703455, /* 13794 ( 326) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 3,  9,  3] -1 */
    60305351, /* 13795 ( 326) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 9,  3,  3] -1 */
    34146806, /* 13796 ( 326) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    51021536, /* 13797 ( 326) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  0] -1 */
    18439772, /* 13798 ( 326) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    60292391, /* 13799 ( 326) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 9,  3,  3] -1 */
    44716415, /* 13800 ( 326) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 3,  9,  3] -1 */
    34133522, /* 13801 ( 326) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    52556810, /* 13802 ( 326) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
     9287015, /* 13803 ( 326) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 3,  3,  3]  1 */
    35445884, /* 13804 ( 326) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  0] -1 */
     9274055, /* 13805 ( 326) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 3,  3,  3]  1 */
    10822289, /* 13806 ( 326) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 3,  9,  9]  1 */
    18426488, /* 13807 ( 326) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    10809329, /* 13808 ( 326) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 3,  9,  9]  1 */
        3200, /* 13809 ( 326) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    26411225, /* 13810 ( 326) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 9,  3,  9]  1 */
    35432600, /* 13811 ( 326) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  0] -1 */
    43417337, /* 13812 ( 326) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 3,  3,  9] -1 */
    26398265, /* 13813 ( 326) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 9,  3,  9]  1 */
     1551758, /* 13814 ( 326) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
    61827665, /* 13815 ( 326) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 9,  9,  9] -1 */
    43404377, /* 13816 ( 326) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 3,  3,  9] -1 */
    61840625, /* 13817 ( 326) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 9,  9,  9] -1 */
       16484, /* 13818 ( 322) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
     1551594, /* 13819 ( 322) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
    26411225, /* 13820 ( 322) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 9,  3,  9]  1 */
    10822289, /* 13821 ( 322) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 3,  9,  9]  1 */
    17140530, /* 13822 ( 322) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  6]  1 */
       16320, /* 13823 ( 322) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    18439772, /* 13824 ( 322) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    27710463, /* 13825 ( 322) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 9,  9,  3]  1 */
    27710303, /* 13826 ( 322) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 9,  9,  3]  1 */
     9287175, /* 13827 ( 322) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 3,  3,  3]  1 */
    18439608, /* 13828 ( 322) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
    17140694, /* 13829 ( 322) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
     1551758, /* 13830 ( 322) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
    10822449, /* 13831 ( 322) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 3,  9,  9]  1 */
     9287015, /* 13832 ( 322) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 3,  3,  3]  1 */
    26411385, /* 13833 ( 322) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 9,  3,  9]  1 */
       16484, /* 13834 ( 323) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    18439772, /* 13835 ( 323) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    35563982, /* 13836 ( 323) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
    18439608, /* 13837 ( 323) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
    10822449, /* 13838 ( 323) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 3,  9,  9]  1 */
    10822289, /* 13839 ( 323) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 3,  9,  9]  1 */
    43299399, /* 13840 ( 323) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 3,  3,  3] -1 */
    17140530, /* 13841 ( 323) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  6]  1 */
    43299239, /* 13842 ( 323) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 3,  3,  3] -1 */
    60423609, /* 13843 ( 323) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 9,  3,  9] -1 */
     1551758, /* 13844 ( 323) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
    34028544, /* 13845 ( 323) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    34028708, /* 13846 ( 323) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    60423449, /* 13847 ( 323) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 9,  3,  9] -1 */
    35563818, /* 13848 ( 323) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  6] -1 */
    61722687, /* 13849 ( 323) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 9,  9,  3] -1 */
    61722527, /* 13850 ( 323) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 9,  9,  3] -1 */
    51152918, /* 13851 ( 323) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
     9287175, /* 13852 ( 323) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 3,  3,  3]  1 */
    52451996, /* 13853 ( 323) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
     9287015, /* 13854 ( 323) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 3,  3,  3]  1 */
    26411385, /* 13855 ( 323) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 9,  3,  9]  1 */
     1551594, /* 13856 ( 323) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
    26411225, /* 13857 ( 323) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 9,  3,  9]  1 */
       16320, /* 13858 ( 323) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    27710463, /* 13859 ( 323) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 9,  9,  3]  1 */
    52451832, /* 13860 ( 323) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
    27710303, /* 13861 ( 323) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 9,  9,  3]  1 */
    44834673, /* 13862 ( 323) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 3,  9,  9] -1 */
    17140694, /* 13863 ( 323) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
    51152754, /* 13864 ( 323) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  6] -1 */
    44834513, /* 13865 ( 323) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 3,  9,  9] -1 */
       16484, /* 13866 ( 324) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    26411225, /* 13867 ( 324) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 9,  3,  9]  1 */
    10822289, /* 13868 ( 324) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 3,  9,  9]  1 */
    43299399, /* 13869 ( 324) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 3,  3,  3] -1 */
    18439772, /* 13870 ( 324) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    52451832, /* 13871 ( 324) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
    27710303, /* 13872 ( 324) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 9,  9,  3]  1 */
    60423609, /* 13873 ( 324) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 9,  3,  9] -1 */
    44834673, /* 13874 ( 324) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 3,  9,  9] -1 */
    17140694, /* 13875 ( 324) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
    51152754, /* 13876 ( 324) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  6] -1 */
     1551758, /* 13877 ( 324) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
    35563818, /* 13878 ( 324) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  6] -1 */
    61722687, /* 13879 ( 324) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 9,  9,  3] -1 */
     9287015, /* 13880 ( 324) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 3,  3,  3]  1 */
    34028544, /* 13881 ( 324) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
       16484, /* 13882 ( 325) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
     1551594, /* 13883 ( 325) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
    61722527, /* 13884 ( 325) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 9,  9,  3] -1 */
    43299399, /* 13885 ( 325) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 3,  3,  3] -1 */
    17140530, /* 13886 ( 325) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  6]  1 */
       16320, /* 13887 ( 325) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    18439772, /* 13888 ( 325) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    61722687, /* 13889 ( 325) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 9,  9,  3] -1 */
    43299239, /* 13890 ( 325) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 3,  3,  3] -1 */
    60423609, /* 13891 ( 325) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 9,  3,  9] -1 */
    44834673, /* 13892 ( 325) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 3,  9,  9] -1 */
    18439608, /* 13893 ( 325) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
    17140694, /* 13894 ( 325) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
     1551758, /* 13895 ( 325) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
    60423449, /* 13896 ( 325) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 9,  3,  9] -1 */
    44834513, /* 13897 ( 325) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 3,  9,  9] -1 */
       16484, /* 13898 ( 326) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    18439772, /* 13899 ( 326) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    18439608, /* 13900 ( 326) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
    10822449, /* 13901 ( 326) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 3,  9,  9]  1 */
    52570094, /* 13902 ( 326) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    10822289, /* 13903 ( 326) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 3,  9,  9]  1 */
    17140530, /* 13904 ( 326) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  6]  1 */
    35445884, /* 13905 ( 326) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  0] -1 */
    43417337, /* 13906 ( 326) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 3,  3,  9] -1 */
    44716575, /* 13907 ( 326) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 3,  9,  3] -1 */
    51034820, /* 13908 ( 326) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  0] -1 */
    35445720, /* 13909 ( 326) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  0] -1 */
     1551758, /* 13910 ( 326) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
    44716415, /* 13911 ( 326) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 3,  9,  3] -1 */
    43417497, /* 13912 ( 326) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 3,  3,  9] -1 */
    51034656, /* 13913 ( 326) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  0] -1 */
    52569930, /* 13914 ( 326) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
     9287175, /* 13915 ( 326) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 3,  3,  3]  1 */
    34146806, /* 13916 ( 326) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
     9287015, /* 13917 ( 326) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 3,  3,  3]  1 */
    26411385, /* 13918 ( 326) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 9,  3,  9]  1 */
     1551594, /* 13919 ( 326) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
    26411225, /* 13920 ( 326) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 9,  3,  9]  1 */
       16320, /* 13921 ( 326) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    27710463, /* 13922 ( 326) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 9,  9,  3]  1 */
    34146642, /* 13923 ( 326) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
    60305511, /* 13924 ( 326) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 9,  3,  3] -1 */
    27710303, /* 13925 ( 326) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 9,  9,  3]  1 */
    17140694, /* 13926 ( 326) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
    61840625, /* 13927 ( 326) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 9,  9,  9] -1 */
    60305351, /* 13928 ( 326) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 9,  3,  3] -1 */
    61840785, /* 13929 ( 326) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 9,  9,  9] -1 */
       16484, /* 13930 ( 322) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    17127570, /* 13931 ( 322) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6]  1 */
    27710463, /* 13932 ( 322) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 9,  9,  3]  1 */
    26411385, /* 13933 ( 322) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 9,  3,  9]  1 */
    18426648, /* 13934 ( 322) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
        3360, /* 13935 ( 322) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
     1551758, /* 13936 ( 322) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
    10809329, /* 13937 ( 322) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 3,  9,  9]  1 */
    10822449, /* 13938 ( 322) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 3,  9,  9]  1 */
     9274055, /* 13939 ( 322) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 3,  3,  3]  1 */
     1538634, /* 13940 ( 322) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
    18439772, /* 13941 ( 322) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    17140694, /* 13942 ( 322) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
    26398265, /* 13943 ( 322) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 9,  3,  9]  1 */
     9287175, /* 13944 ( 322) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 3,  3,  3]  1 */
    27697343, /* 13945 ( 322) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 9,  9,  3]  1 */
       16484, /* 13946 ( 323) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
     1551758, /* 13947 ( 323) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
    51152918, /* 13948 ( 323) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
     1538634, /* 13949 ( 323) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
    26398265, /* 13950 ( 323) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 9,  3,  9]  1 */
    26411385, /* 13951 ( 323) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 9,  3,  9]  1 */
    43286279, /* 13952 ( 323) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 3,  3,  3] -1 */
    18426648, /* 13953 ( 323) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
    43299399, /* 13954 ( 323) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 3,  3,  3] -1 */
    61709567, /* 13955 ( 323) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 9,  9,  3] -1 */
    17140694, /* 13956 ( 323) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
    34015584, /* 13957 ( 323) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    34028708, /* 13958 ( 323) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    61722687, /* 13959 ( 323) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 9,  9,  3] -1 */
    51139794, /* 13960 ( 323) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6] -1 */
    44821553, /* 13961 ( 323) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 3,  9,  9] -1 */
    44834673, /* 13962 ( 323) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 3,  9,  9] -1 */
    52451996, /* 13963 ( 323) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
     9274055, /* 13964 ( 323) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 3,  3,  3]  1 */
    35563982, /* 13965 ( 323) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
     9287175, /* 13966 ( 323) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 3,  3,  3]  1 */
    27697343, /* 13967 ( 323) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 9,  9,  3]  1 */
    17127570, /* 13968 ( 323) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6]  1 */
    27710463, /* 13969 ( 323) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 9,  9,  3]  1 */
        3360, /* 13970 ( 323) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    10809329, /* 13971 ( 323) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 3,  9,  9]  1 */
    35550858, /* 13972 ( 323) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6] -1 */
    10822449, /* 13973 ( 323) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 3,  9,  9]  1 */
    60410489, /* 13974 ( 323) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 9,  3,  9] -1 */
    18439772, /* 13975 ( 323) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    52438872, /* 13976 ( 323) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
    60423609, /* 13977 ( 323) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 9,  3,  9] -1 */
       16484, /* 13978 ( 324) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    27710463, /* 13979 ( 324) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 9,  9,  3]  1 */
    26411385, /* 13980 ( 324) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 9,  3,  9]  1 */
    43286279, /* 13981 ( 324) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 3,  3,  3] -1 */
     1551758, /* 13982 ( 324) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
    35550858, /* 13983 ( 324) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6] -1 */
    10822449, /* 13984 ( 324) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 3,  9,  9]  1 */
    61709567, /* 13985 ( 324) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 9,  9,  3] -1 */
    60410489, /* 13986 ( 324) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 9,  3,  9] -1 */
    18439772, /* 13987 ( 324) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    52438872, /* 13988 ( 324) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
    17140694, /* 13989 ( 324) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
    51139794, /* 13990 ( 324) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6] -1 */
    44821553, /* 13991 ( 324) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 3,  9,  9] -1 */
     9287175, /* 13992 ( 324) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 3,  3,  3]  1 */
    34015584, /* 13993 ( 324) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
       16484, /* 13994 ( 325) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    17127570, /* 13995 ( 325) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6]  1 */
    44834673, /* 13996 ( 325) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 3,  9,  9] -1 */
    43286279, /* 13997 ( 325) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 3,  3,  3] -1 */
    18426648, /* 13998 ( 325) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
        3360, /* 13999 ( 325) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
     1551758, /* 14000 ( 325) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
    44821553, /* 14001 ( 325) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 3,  9,  9] -1 */
    43299399, /* 14002 ( 325) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 3,  3,  3] -1 */
    61709567, /* 14003 ( 325) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 9,  9,  3] -1 */
    60410489, /* 14004 ( 325) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 9,  3,  9] -1 */
     1538634, /* 14005 ( 325) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
    18439772, /* 14006 ( 325) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    17140694, /* 14007 ( 325) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
    61722687, /* 14008 ( 325) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 9,  9,  3] -1 */
    60423609, /* 14009 ( 325) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 9,  3,  9] -1 */
       16484, /* 14010 ( 326) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
     1551758, /* 14011 ( 326) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
     1538634, /* 14012 ( 326) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
    26398265, /* 14013 ( 326) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 9,  3,  9]  1 */
    52570094, /* 14014 ( 326) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    26411385, /* 14015 ( 326) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 9,  3,  9]  1 */
    18426648, /* 14016 ( 326) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
    34146806, /* 14017 ( 326) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    60305511, /* 14018 ( 326) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 9,  3,  3] -1 */
    43404377, /* 14019 ( 326) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 3,  3,  9] -1 */
    35445884, /* 14020 ( 326) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  0] -1 */
    34133682, /* 14021 ( 326) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
    17140694, /* 14022 ( 326) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
    43417497, /* 14023 ( 326) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 3,  3,  9] -1 */
    60292391, /* 14024 ( 326) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 9,  3,  3] -1 */
    35432760, /* 14025 ( 326) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  0] -1 */
    52556970, /* 14026 ( 326) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
     9274055, /* 14027 ( 326) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 3,  3,  3]  1 */
    51034820, /* 14028 ( 326) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  0] -1 */
     9287175, /* 14029 ( 326) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 3,  3,  3]  1 */
    27697343, /* 14030 ( 326) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 9,  9,  3]  1 */
    17127570, /* 14031 ( 326) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6]  1 */
    27710463, /* 14032 ( 326) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 9,  9,  3]  1 */
        3360, /* 14033 ( 326) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    10809329, /* 14034 ( 326) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 3,  9,  9]  1 */
    51021696, /* 14035 ( 326) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  0] -1 */
    44703455, /* 14036 ( 326) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 3,  9,  3] -1 */
    10822449, /* 14037 ( 326) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 3,  9,  9]  1 */
    18439772, /* 14038 ( 326) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    61840785, /* 14039 ( 326) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 9,  9,  9] -1 */
    44716575, /* 14040 ( 326) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 3,  9,  3] -1 */
    61827665, /* 14041 ( 326) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 9,  9,  9] -1 */
       16484, /* 14042 ( 327) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    18557870, /* 14043 ( 327) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
        3200, /* 14044 ( 327) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
        3362, /* 14045 ( 327) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    18544586, /* 14046 ( 327) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    18557708, /* 14047 ( 327) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    18544748, /* 14048 ( 327) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
       16322, /* 14049 ( 327) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
       16484, /* 14050 ( 328) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34015586, /* 14051 ( 328) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    18557870, /* 14052 ( 328) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    52556810, /* 14053 ( 328) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    34028546, /* 14054 ( 328) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
        3200, /* 14055 ( 328) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
        3362, /* 14056 ( 328) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    52569932, /* 14057 ( 328) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    18544586, /* 14058 ( 328) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    18557708, /* 14059 ( 328) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    52556972, /* 14060 ( 328) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    34015424, /* 14061 ( 328) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    52570094, /* 14062 ( 328) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    34028708, /* 14063 ( 328) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    18544748, /* 14064 ( 328) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
       16322, /* 14065 ( 328) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
       16484, /* 14066 ( 329) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34028546, /* 14067 ( 329) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    18557870, /* 14068 ( 329) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    52556810, /* 14069 ( 329) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
        3362, /* 14070 ( 329) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    52569932, /* 14071 ( 329) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    34015424, /* 14072 ( 329) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    18544748, /* 14073 ( 329) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
       16484, /* 14074 ( 330) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34015586, /* 14075 ( 330) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    18557870, /* 14076 ( 330) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
        3200, /* 14077 ( 330) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    52569932, /* 14078 ( 330) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    18544586, /* 14079 ( 330) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    52556972, /* 14080 ( 330) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    34028546, /* 14081 ( 330) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
       16484, /* 14082 ( 331) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    52451834, /* 14083 ( 331) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
    18557870, /* 14084 ( 331) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    34133522, /* 14085 ( 331) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    52438712, /* 14086 ( 331) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
        3200, /* 14087 ( 331) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
        3362, /* 14088 ( 331) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    52438874, /* 14089 ( 331) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
    34146644, /* 14090 ( 331) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    52451996, /* 14091 ( 331) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
    18544586, /* 14092 ( 331) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    34146806, /* 14093 ( 331) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    34133684, /* 14094 ( 331) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    18557708, /* 14095 ( 331) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    18544748, /* 14096 ( 331) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
       16322, /* 14097 ( 331) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
       16484, /* 14098 ( 332) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    18557870, /* 14099 ( 332) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
        3200, /* 14100 ( 332) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
        3362, /* 14101 ( 332) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    51034820, /* 14102 ( 332) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  0] -1 */
    51021698, /* 14103 ( 332) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  0] -1 */
    35550860, /* 14104 ( 332) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
    51034658, /* 14105 ( 332) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  0] -1 */
    35563982, /* 14106 ( 332) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
    18544586, /* 14107 ( 332) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    51021536, /* 14108 ( 332) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  0] -1 */
    18557708, /* 14109 ( 332) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    35550698, /* 14110 ( 332) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
    18544748, /* 14111 ( 332) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    35563820, /* 14112 ( 332) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
       16322, /* 14113 ( 332) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
       16484, /* 14114 ( 327) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    18557870, /* 14115 ( 327) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
       16320, /* 14116 ( 327) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
       16322, /* 14117 ( 327) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    18557706, /* 14118 ( 327) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
    18557868, /* 14119 ( 327) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
    18557708, /* 14120 ( 327) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
       16482, /* 14121 ( 327) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
       16484, /* 14122 ( 328) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34028546, /* 14123 ( 328) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    18557870, /* 14124 ( 328) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    52569930, /* 14125 ( 328) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    34028706, /* 14126 ( 328) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
       16320, /* 14127 ( 328) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
       16322, /* 14128 ( 328) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    52570092, /* 14129 ( 328) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    18557706, /* 14130 ( 328) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
    18557868, /* 14131 ( 328) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
    52569932, /* 14132 ( 328) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    34028544, /* 14133 ( 328) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    52570094, /* 14134 ( 328) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    34028708, /* 14135 ( 328) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    18557708, /* 14136 ( 328) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
       16482, /* 14137 ( 328) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
       16484, /* 14138 ( 329) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34028706, /* 14139 ( 329) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    18557870, /* 14140 ( 329) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    52569930, /* 14141 ( 329) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
       16322, /* 14142 ( 329) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    52570092, /* 14143 ( 329) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    34028544, /* 14144 ( 329) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    18557708, /* 14145 ( 329) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
       16484, /* 14146 ( 330) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34028546, /* 14147 ( 330) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    18557870, /* 14148 ( 330) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
       16320, /* 14149 ( 330) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    52570092, /* 14150 ( 330) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    18557706, /* 14151 ( 330) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
    52569932, /* 14152 ( 330) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    34028706, /* 14153 ( 330) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
       16484, /* 14154 ( 331) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    35563980, /* 14155 ( 331) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6] -1 */
    18557870, /* 14156 ( 331) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    51034656, /* 14157 ( 331) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  0] -1 */
    35563818, /* 14158 ( 331) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  6] -1 */
       16320, /* 14159 ( 331) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
       16322, /* 14160 ( 331) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    35563820, /* 14161 ( 331) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
    51034818, /* 14162 ( 331) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  0] -1 */
    35563982, /* 14163 ( 331) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
    18557706, /* 14164 ( 331) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
    51034820, /* 14165 ( 331) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  0] -1 */
    51034658, /* 14166 ( 331) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  0] -1 */
    18557868, /* 14167 ( 331) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
    18557708, /* 14168 ( 331) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
       16482, /* 14169 ( 331) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
       16484, /* 14170 ( 332) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    18557870, /* 14171 ( 332) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
       16320, /* 14172 ( 332) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
       16322, /* 14173 ( 332) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    35445884, /* 14174 ( 332) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  0] -1 */
    35445722, /* 14175 ( 332) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  0] -1 */
    51152756, /* 14176 ( 332) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
    35445882, /* 14177 ( 332) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  0] -1 */
    51152918, /* 14178 ( 332) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
    18557706, /* 14179 ( 332) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
    35445720, /* 14180 ( 332) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  0] -1 */
    18557868, /* 14181 ( 332) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
    51152754, /* 14182 ( 332) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  6] -1 */
    18557708, /* 14183 ( 332) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    51152916, /* 14184 ( 332) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6] -1 */
       16482, /* 14185 ( 332) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
       16484, /* 14186 ( 327) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    18557870, /* 14187 ( 327) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
        3360, /* 14188 ( 327) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
       16482, /* 14189 ( 327) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    18544746, /* 14190 ( 327) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
    18544748, /* 14191 ( 327) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    18557868, /* 14192 ( 327) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
        3362, /* 14193 ( 327) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
       16484, /* 14194 ( 328) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34028706, /* 14195 ( 328) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    18557870, /* 14196 ( 328) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    52556970, /* 14197 ( 328) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    34015586, /* 14198 ( 328) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
        3360, /* 14199 ( 328) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
       16482, /* 14200 ( 328) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    52556972, /* 14201 ( 328) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    18544746, /* 14202 ( 328) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
    18544748, /* 14203 ( 328) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    52570092, /* 14204 ( 328) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    34015584, /* 14205 ( 328) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    52570094, /* 14206 ( 328) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    34028708, /* 14207 ( 328) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    18557868, /* 14208 ( 328) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
        3362, /* 14209 ( 328) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
       16484, /* 14210 ( 329) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34015586, /* 14211 ( 329) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    18557870, /* 14212 ( 329) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    52556970, /* 14213 ( 329) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
       16482, /* 14214 ( 329) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    52556972, /* 14215 ( 329) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    34015584, /* 14216 ( 329) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    18557868, /* 14217 ( 329) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
       16484, /* 14218 ( 330) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34028706, /* 14219 ( 330) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    18557870, /* 14220 ( 330) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
        3360, /* 14221 ( 330) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    52556972, /* 14222 ( 330) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    18544746, /* 14223 ( 330) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
    52570092, /* 14224 ( 330) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    34015586, /* 14225 ( 330) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
       16484, /* 14226 ( 331) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    51139796, /* 14227 ( 331) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
    18557870, /* 14228 ( 331) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    35432760, /* 14229 ( 331) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  0] -1 */
    51139794, /* 14230 ( 331) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6] -1 */
        3360, /* 14231 ( 331) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
       16482, /* 14232 ( 331) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    51152916, /* 14233 ( 331) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6] -1 */
    35432762, /* 14234 ( 331) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  0] -1 */
    51152918, /* 14235 ( 331) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
    18544746, /* 14236 ( 331) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
    35445884, /* 14237 ( 331) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  0] -1 */
    35445882, /* 14238 ( 331) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  0] -1 */
    18544748, /* 14239 ( 331) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    18557868, /* 14240 ( 331) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
        3362, /* 14241 ( 331) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
       16484, /* 14242 ( 332) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    18557870, /* 14243 ( 332) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
        3360, /* 14244 ( 332) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
       16482, /* 14245 ( 332) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    34146806, /* 14246 ( 332) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    34146804, /* 14247 ( 332) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
    52451994, /* 14248 ( 332) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
    34133684, /* 14249 ( 332) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    52451996, /* 14250 ( 332) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
    18544746, /* 14251 ( 332) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
    34133682, /* 14252 ( 332) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
    18544748, /* 14253 ( 332) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    52438872, /* 14254 ( 332) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
    18557868, /* 14255 ( 332) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
    52438874, /* 14256 ( 332) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
        3362, /* 14257 ( 332) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
       16484, /* 14258 ( 333) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
      121460, /* 14259 ( 333) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6]  1 */
    18557870, /* 14260 ( 333) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
        3200, /* 14261 ( 333) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    18439610, /* 14262 ( 333) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    18426650, /* 14263 ( 333) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    18544586, /* 14264 ( 333) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
      134420, /* 14265 ( 333) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6]  1 */
       16484, /* 14266 ( 334) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    52451834, /* 14267 ( 334) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
      121460, /* 14268 ( 334) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6]  1 */
    18557870, /* 14269 ( 334) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    52556810, /* 14270 ( 334) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
        3200, /* 14271 ( 334) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    18439610, /* 14272 ( 334) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    52438874, /* 14273 ( 334) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
    34146644, /* 14274 ( 334) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    18426650, /* 14275 ( 334) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    18544586, /* 14276 ( 334) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    34133684, /* 14277 ( 334) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
      134420, /* 14278 ( 334) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6]  1 */
    34028708, /* 14279 ( 334) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    52570094, /* 14280 ( 334) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    34015424, /* 14281 ( 334) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
       16484, /* 14282 ( 335) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    18557870, /* 14283 ( 335) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    52556810, /* 14284 ( 335) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    18439610, /* 14285 ( 335) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    52438874, /* 14286 ( 335) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
      134420, /* 14287 ( 335) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6]  1 */
    34133684, /* 14288 ( 335) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    34015424, /* 14289 ( 335) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
       16484, /* 14290 ( 336) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    52451834, /* 14291 ( 336) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
    18557870, /* 14292 ( 336) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
        3200, /* 14293 ( 336) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    52438874, /* 14294 ( 336) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
    34146644, /* 14295 ( 336) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    18544586, /* 14296 ( 336) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    34133684, /* 14297 ( 336) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
       16484, /* 14298 ( 337) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
      121460, /* 14299 ( 337) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6]  1 */
    18557870, /* 14300 ( 337) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    34133522, /* 14301 ( 337) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    34015586, /* 14302 ( 337) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
        3200, /* 14303 ( 337) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    18439610, /* 14304 ( 337) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    34028546, /* 14305 ( 337) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    52569932, /* 14306 ( 337) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    18426650, /* 14307 ( 337) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    18544586, /* 14308 ( 337) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    52451996, /* 14309 ( 337) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
    34146806, /* 14310 ( 337) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    52556972, /* 14311 ( 337) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
      134420, /* 14312 ( 337) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6]  1 */
    52438712, /* 14313 ( 337) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
       16484, /* 14314 ( 338) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
      121460, /* 14315 ( 338) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6]  1 */
    18557870, /* 14316 ( 338) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
        3200, /* 14317 ( 338) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    18439610, /* 14318 ( 338) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    51034820, /* 14319 ( 338) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  0] -1 */
    51152756, /* 14320 ( 338) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
    35432762, /* 14321 ( 338) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  0] -1 */
    35563982, /* 14322 ( 338) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
    18426650, /* 14323 ( 338) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    18544586, /* 14324 ( 338) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    51139796, /* 14325 ( 338) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
    35445722, /* 14326 ( 338) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  0] -1 */
    51021536, /* 14327 ( 338) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  0] -1 */
      134420, /* 14328 ( 338) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6]  1 */
    35550698, /* 14329 ( 338) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
       16484, /* 14330 ( 333) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    17022434, /* 14331 ( 333) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  0]  1 */
    18557870, /* 14332 ( 333) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
       16320, /* 14333 ( 333) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
     1551756, /* 14334 ( 333) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
     1551596, /* 14335 ( 333) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
    18557706, /* 14336 ( 333) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
    17022594, /* 14337 ( 333) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  0]  1 */
       16484, /* 14338 ( 334) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    35563980, /* 14339 ( 334) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6] -1 */
    17022434, /* 14340 ( 334) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  0]  1 */
    18557870, /* 14341 ( 334) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    52569930, /* 14342 ( 334) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
       16320, /* 14343 ( 334) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
     1551756, /* 14344 ( 334) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
    35563820, /* 14345 ( 334) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
    51034818, /* 14346 ( 334) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  0] -1 */
     1551596, /* 14347 ( 334) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
    18557706, /* 14348 ( 334) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
    51034658, /* 14349 ( 334) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  0] -1 */
    17022594, /* 14350 ( 334) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  0]  1 */
    34028708, /* 14351 ( 334) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    52570094, /* 14352 ( 334) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    34028544, /* 14353 ( 334) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
       16484, /* 14354 ( 335) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    18557870, /* 14355 ( 335) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    52569930, /* 14356 ( 335) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
     1551756, /* 14357 ( 335) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
    35563820, /* 14358 ( 335) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
    17022594, /* 14359 ( 335) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  0]  1 */
    51034658, /* 14360 ( 335) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  0] -1 */
    34028544, /* 14361 ( 335) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
       16484, /* 14362 ( 336) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    35563980, /* 14363 ( 336) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6] -1 */
    18557870, /* 14364 ( 336) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
       16320, /* 14365 ( 336) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    35563820, /* 14366 ( 336) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
    51034818, /* 14367 ( 336) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  0] -1 */
    18557706, /* 14368 ( 336) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
    51034658, /* 14369 ( 336) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  0] -1 */
       16484, /* 14370 ( 337) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    17022434, /* 14371 ( 337) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  0]  1 */
    18557870, /* 14372 ( 337) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    51034656, /* 14373 ( 337) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  0] -1 */
    34028546, /* 14374 ( 337) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
       16320, /* 14375 ( 337) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
     1551756, /* 14376 ( 337) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
    34028706, /* 14377 ( 337) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    52570092, /* 14378 ( 337) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
     1551596, /* 14379 ( 337) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
    18557706, /* 14380 ( 337) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
    35563982, /* 14381 ( 337) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
    51034820, /* 14382 ( 337) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  0] -1 */
    52569932, /* 14383 ( 337) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    17022594, /* 14384 ( 337) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  0]  1 */
    35563818, /* 14385 ( 337) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  6] -1 */
       16484, /* 14386 ( 338) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    17022434, /* 14387 ( 338) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  0]  1 */
    18557870, /* 14388 ( 338) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
       16320, /* 14389 ( 338) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
     1551756, /* 14390 ( 338) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
    35445884, /* 14391 ( 338) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  0] -1 */
    52451994, /* 14392 ( 338) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
    34146644, /* 14393 ( 338) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    51152918, /* 14394 ( 338) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
     1551596, /* 14395 ( 338) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
    18557706, /* 14396 ( 338) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
    52451834, /* 14397 ( 338) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
    34146804, /* 14398 ( 338) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
    35445720, /* 14399 ( 338) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  0] -1 */
    17022594, /* 14400 ( 338) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  0]  1 */
    51152754, /* 14401 ( 338) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  6] -1 */
       16484, /* 14402 ( 333) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
     1433658, /* 14403 ( 333) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  0]  1 */
    18557870, /* 14404 ( 333) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
        3360, /* 14405 ( 333) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    17127572, /* 14406 ( 333) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
    17140692, /* 14407 ( 333) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6]  1 */
    18544746, /* 14408 ( 333) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
     1420538, /* 14409 ( 333) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  0]  1 */
       16484, /* 14410 ( 334) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    51139796, /* 14411 ( 334) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
     1433658, /* 14412 ( 334) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  0]  1 */
    18557870, /* 14413 ( 334) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    52556970, /* 14414 ( 334) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
        3360, /* 14415 ( 334) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    17127572, /* 14416 ( 334) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
    51152916, /* 14417 ( 334) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6] -1 */
    35432762, /* 14418 ( 334) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  0] -1 */
    17140692, /* 14419 ( 334) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6]  1 */
    18544746, /* 14420 ( 334) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
    35445882, /* 14421 ( 334) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  0] -1 */
     1420538, /* 14422 ( 334) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  0]  1 */
    34028708, /* 14423 ( 334) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    52570094, /* 14424 ( 334) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    34015584, /* 14425 ( 334) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
       16484, /* 14426 ( 335) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    18557870, /* 14427 ( 335) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    52556970, /* 14428 ( 335) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    17127572, /* 14429 ( 335) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
    51152916, /* 14430 ( 335) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6] -1 */
     1420538, /* 14431 ( 335) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  0]  1 */
    35445882, /* 14432 ( 335) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  0] -1 */
    34015584, /* 14433 ( 335) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
       16484, /* 14434 ( 336) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    51139796, /* 14435 ( 336) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
    18557870, /* 14436 ( 336) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
        3360, /* 14437 ( 336) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    51152916, /* 14438 ( 336) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6] -1 */
    35432762, /* 14439 ( 336) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  0] -1 */
    18544746, /* 14440 ( 336) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
    35445882, /* 14441 ( 336) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  0] -1 */
       16484, /* 14442 ( 337) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
     1433658, /* 14443 ( 337) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  0]  1 */
    18557870, /* 14444 ( 337) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    35432760, /* 14445 ( 337) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  0] -1 */
    34028706, /* 14446 ( 337) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
        3360, /* 14447 ( 337) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    17127572, /* 14448 ( 337) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
    34015586, /* 14449 ( 337) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    52556972, /* 14450 ( 337) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    17140692, /* 14451 ( 337) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6]  1 */
    18544746, /* 14452 ( 337) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
    51152918, /* 14453 ( 337) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
    35445884, /* 14454 ( 337) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  0] -1 */
    52570092, /* 14455 ( 337) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
     1420538, /* 14456 ( 337) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  0]  1 */
    51139794, /* 14457 ( 337) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6] -1 */
       16484, /* 14458 ( 338) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
     1433658, /* 14459 ( 338) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  0]  1 */
    18557870, /* 14460 ( 338) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
        3360, /* 14461 ( 338) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    17127572, /* 14462 ( 338) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
    34146806, /* 14463 ( 338) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    35550860, /* 14464 ( 338) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
    51034818, /* 14465 ( 338) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  0] -1 */
    52451996, /* 14466 ( 338) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
    17140692, /* 14467 ( 338) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6]  1 */
    18544746, /* 14468 ( 338) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
    35563980, /* 14469 ( 338) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6] -1 */
    51021698, /* 14470 ( 338) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  0] -1 */
    34133682, /* 14471 ( 338) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
     1420538, /* 14472 ( 338) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  0]  1 */
    52438872, /* 14473 ( 338) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
       16484, /* 14474 ( 339) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    18557870, /* 14475 ( 339) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
        3200, /* 14476 ( 339) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
     1551596, /* 14477 ( 339) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
    17022434, /* 14478 ( 339) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  0]  1 */
     1538636, /* 14479 ( 339) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
    18544586, /* 14480 ( 339) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    17009474, /* 14481 ( 339) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  0]  1 */
       16484, /* 14482 ( 340) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    18557870, /* 14483 ( 340) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    52556810, /* 14484 ( 340) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
        3200, /* 14485 ( 340) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    51021698, /* 14486 ( 340) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  0] -1 */
    35550860, /* 14487 ( 340) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
     1551596, /* 14488 ( 340) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
    17022434, /* 14489 ( 340) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  0]  1 */
     1538636, /* 14490 ( 340) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
    18544586, /* 14491 ( 340) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    17009474, /* 14492 ( 340) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  0]  1 */
    34015424, /* 14493 ( 340) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    34028708, /* 14494 ( 340) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    52570094, /* 14495 ( 340) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    35563820, /* 14496 ( 340) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
    51034658, /* 14497 ( 340) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  0] -1 */
       16484, /* 14498 ( 341) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    18557870, /* 14499 ( 341) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    52556810, /* 14500 ( 341) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    51021698, /* 14501 ( 341) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  0] -1 */
    35550860, /* 14502 ( 341) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
     1551596, /* 14503 ( 341) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
    17022434, /* 14504 ( 341) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  0]  1 */
    34015424, /* 14505 ( 341) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
       16484, /* 14506 ( 342) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    18557870, /* 14507 ( 342) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    52556810, /* 14508 ( 342) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
     1538636, /* 14509 ( 342) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
    17009474, /* 14510 ( 342) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  0]  1 */
    34015424, /* 14511 ( 342) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    35563820, /* 14512 ( 342) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
    51034658, /* 14513 ( 342) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  0] -1 */
       16484, /* 14514 ( 343) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    18557870, /* 14515 ( 343) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
        3200, /* 14516 ( 343) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    51021698, /* 14517 ( 343) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  0] -1 */
    35550860, /* 14518 ( 343) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
    18544586, /* 14519 ( 343) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    35563820, /* 14520 ( 343) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
    51034658, /* 14521 ( 343) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  0] -1 */
       16484, /* 14522 ( 344) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    18557870, /* 14523 ( 344) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    34133522, /* 14524 ( 344) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
        3200, /* 14525 ( 344) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    51152756, /* 14526 ( 344) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
     1551596, /* 14527 ( 344) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
    17022434, /* 14528 ( 344) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  0]  1 */
    35432762, /* 14529 ( 344) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  0] -1 */
     1538636, /* 14530 ( 344) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
    52451996, /* 14531 ( 344) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
    18544586, /* 14532 ( 344) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    51139796, /* 14533 ( 344) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
    34146806, /* 14534 ( 344) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    35445722, /* 14535 ( 344) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  0] -1 */
    17009474, /* 14536 ( 344) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  0]  1 */
    52438712, /* 14537 ( 344) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
       16484, /* 14538 ( 345) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34015586, /* 14539 ( 345) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    18557870, /* 14540 ( 345) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
        3200, /* 14541 ( 345) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    51034820, /* 14542 ( 345) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  0] -1 */
    52569932, /* 14543 ( 345) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
     1551596, /* 14544 ( 345) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
    17022434, /* 14545 ( 345) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  0]  1 */
     1538636, /* 14546 ( 345) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
    35563982, /* 14547 ( 345) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
    18544586, /* 14548 ( 345) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    52556972, /* 14549 ( 345) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    17009474, /* 14550 ( 345) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  0]  1 */
    51021536, /* 14551 ( 345) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  0] -1 */
    34028546, /* 14552 ( 345) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    35550698, /* 14553 ( 345) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
       16484, /* 14554 ( 346) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    52451834, /* 14555 ( 346) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
    18557870, /* 14556 ( 346) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
        3200, /* 14557 ( 346) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    52438874, /* 14558 ( 346) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
    34146644, /* 14559 ( 346) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    35432600, /* 14560 ( 346) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  0] -1 */
    17022434, /* 14561 ( 346) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  0]  1 */
     1551596, /* 14562 ( 346) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
     1538636, /* 14563 ( 346) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
    51139634, /* 14564 ( 346) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
    18544586, /* 14565 ( 346) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    34133684, /* 14566 ( 346) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    35445884, /* 14567 ( 346) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  0] -1 */
    17009474, /* 14568 ( 346) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  0]  1 */
    51152918, /* 14569 ( 346) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
       16484, /* 14570 ( 339) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    18557870, /* 14571 ( 339) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
        3200, /* 14572 ( 339) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    17127572, /* 14573 ( 339) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
     1420538, /* 14574 ( 339) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  0]  1 */
    17140532, /* 14575 ( 339) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
    18544586, /* 14576 ( 339) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
     1433498, /* 14577 ( 339) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  0]  1 */
       16484, /* 14578 ( 340) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    18557870, /* 14579 ( 340) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    52556810, /* 14580 ( 340) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
        3200, /* 14581 ( 340) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    35445722, /* 14582 ( 340) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  0] -1 */
    51152756, /* 14583 ( 340) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
    17127572, /* 14584 ( 340) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
     1420538, /* 14585 ( 340) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  0]  1 */
    17140532, /* 14586 ( 340) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
    18544586, /* 14587 ( 340) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
     1433498, /* 14588 ( 340) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  0]  1 */
    34015424, /* 14589 ( 340) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    34028708, /* 14590 ( 340) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    52570094, /* 14591 ( 340) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    51139796, /* 14592 ( 340) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
    35432762, /* 14593 ( 340) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  0] -1 */
       16484, /* 14594 ( 341) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    18557870, /* 14595 ( 341) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    52556810, /* 14596 ( 341) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    35445722, /* 14597 ( 341) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  0] -1 */
    51152756, /* 14598 ( 341) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
    17127572, /* 14599 ( 341) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
     1420538, /* 14600 ( 341) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  0]  1 */
    34015424, /* 14601 ( 341) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
       16484, /* 14602 ( 342) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    18557870, /* 14603 ( 342) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    52556810, /* 14604 ( 342) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    17140532, /* 14605 ( 342) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
     1433498, /* 14606 ( 342) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  0]  1 */
    34015424, /* 14607 ( 342) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    51139796, /* 14608 ( 342) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
    35432762, /* 14609 ( 342) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  0] -1 */
       16484, /* 14610 ( 343) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    18557870, /* 14611 ( 343) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
        3200, /* 14612 ( 343) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    35445722, /* 14613 ( 343) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  0] -1 */
    51152756, /* 14614 ( 343) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
    18544586, /* 14615 ( 343) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    51139796, /* 14616 ( 343) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
    35432762, /* 14617 ( 343) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  0] -1 */
       16484, /* 14618 ( 344) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    18557870, /* 14619 ( 344) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    34133522, /* 14620 ( 344) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
        3200, /* 14621 ( 344) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    35550860, /* 14622 ( 344) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
    17127572, /* 14623 ( 344) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
     1420538, /* 14624 ( 344) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  0]  1 */
    51034658, /* 14625 ( 344) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  0] -1 */
    17140532, /* 14626 ( 344) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
    52451996, /* 14627 ( 344) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
    18544586, /* 14628 ( 344) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    35563820, /* 14629 ( 344) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
    34146806, /* 14630 ( 344) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    51021698, /* 14631 ( 344) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  0] -1 */
     1433498, /* 14632 ( 344) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  0]  1 */
    52438712, /* 14633 ( 344) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
       16484, /* 14634 ( 345) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34028546, /* 14635 ( 345) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    18557870, /* 14636 ( 345) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
        3200, /* 14637 ( 345) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    35445884, /* 14638 ( 345) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  0] -1 */
    52556972, /* 14639 ( 345) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    17127572, /* 14640 ( 345) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
     1420538, /* 14641 ( 345) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  0]  1 */
    17140532, /* 14642 ( 345) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
    51152918, /* 14643 ( 345) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
    18544586, /* 14644 ( 345) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    52569932, /* 14645 ( 345) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
     1433498, /* 14646 ( 345) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  0]  1 */
    35432600, /* 14647 ( 345) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  0] -1 */
    34015586, /* 14648 ( 345) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    51139634, /* 14649 ( 345) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
       16484, /* 14650 ( 346) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    52438874, /* 14651 ( 346) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
    18557870, /* 14652 ( 346) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
        3200, /* 14653 ( 346) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    52451834, /* 14654 ( 346) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
    34133684, /* 14655 ( 346) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    51021536, /* 14656 ( 346) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  0] -1 */
     1420538, /* 14657 ( 346) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  0]  1 */
    17127572, /* 14658 ( 346) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
    17140532, /* 14659 ( 346) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
    35550698, /* 14660 ( 346) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
    18544586, /* 14661 ( 346) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    34146644, /* 14662 ( 346) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    51034820, /* 14663 ( 346) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  0] -1 */
     1433498, /* 14664 ( 346) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  0]  1 */
    35563982, /* 14665 ( 346) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
       16484, /* 14666 ( 339) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    18557870, /* 14667 ( 339) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
       16320, /* 14668 ( 339) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    17140692, /* 14669 ( 339) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6]  1 */
     1433658, /* 14670 ( 339) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  0]  1 */
    17140532, /* 14671 ( 339) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
    18557706, /* 14672 ( 339) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
     1433498, /* 14673 ( 339) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  0]  1 */
       16484, /* 14674 ( 340) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    18557870, /* 14675 ( 340) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    52569930, /* 14676 ( 340) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
       16320, /* 14677 ( 340) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    35445722, /* 14678 ( 340) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  0] -1 */
    51152756, /* 14679 ( 340) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
    17140692, /* 14680 ( 340) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6]  1 */
     1433658, /* 14681 ( 340) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  0]  1 */
    17140532, /* 14682 ( 340) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
    18557706, /* 14683 ( 340) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
     1433498, /* 14684 ( 340) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  0]  1 */
    34028544, /* 14685 ( 340) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    34028708, /* 14686 ( 340) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    52570094, /* 14687 ( 340) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    51152916, /* 14688 ( 340) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6] -1 */
    35445882, /* 14689 ( 340) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  0] -1 */
       16484, /* 14690 ( 341) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    18557870, /* 14691 ( 341) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    52569930, /* 14692 ( 341) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    35445722, /* 14693 ( 341) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  0] -1 */
    51152756, /* 14694 ( 341) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
    17140692, /* 14695 ( 341) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6]  1 */
     1433658, /* 14696 ( 341) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  0]  1 */
    34028544, /* 14697 ( 341) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
       16484, /* 14698 ( 342) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    18557870, /* 14699 ( 342) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    52569930, /* 14700 ( 342) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    17140532, /* 14701 ( 342) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
     1433498, /* 14702 ( 342) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  0]  1 */
    34028544, /* 14703 ( 342) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    51152916, /* 14704 ( 342) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6] -1 */
    35445882, /* 14705 ( 342) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  0] -1 */
       16484, /* 14706 ( 343) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    18557870, /* 14707 ( 343) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
       16320, /* 14708 ( 343) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    35445722, /* 14709 ( 343) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  0] -1 */
    51152756, /* 14710 ( 343) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
    18557706, /* 14711 ( 343) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
    51152916, /* 14712 ( 343) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6] -1 */
    35445882, /* 14713 ( 343) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  0] -1 */
       16484, /* 14714 ( 344) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    18557870, /* 14715 ( 344) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    51034656, /* 14716 ( 344) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  0] -1 */
       16320, /* 14717 ( 344) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    52451994, /* 14718 ( 344) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
    17140692, /* 14719 ( 344) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6]  1 */
     1433658, /* 14720 ( 344) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  0]  1 */
    34146644, /* 14721 ( 344) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    17140532, /* 14722 ( 344) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
    35563982, /* 14723 ( 344) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
    18557706, /* 14724 ( 344) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
    52451834, /* 14725 ( 344) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
    51034820, /* 14726 ( 344) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  0] -1 */
    34146804, /* 14727 ( 344) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
     1433498, /* 14728 ( 344) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  0]  1 */
    35563818, /* 14729 ( 344) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  6] -1 */
       16484, /* 14730 ( 345) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34028546, /* 14731 ( 345) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    18557870, /* 14732 ( 345) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
       16320, /* 14733 ( 345) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    35445884, /* 14734 ( 345) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  0] -1 */
    52570092, /* 14735 ( 345) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    17140692, /* 14736 ( 345) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6]  1 */
     1433658, /* 14737 ( 345) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  0]  1 */
    17140532, /* 14738 ( 345) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
    51152918, /* 14739 ( 345) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
    18557706, /* 14740 ( 345) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
    52569932, /* 14741 ( 345) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
     1433498, /* 14742 ( 345) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  0]  1 */
    35445720, /* 14743 ( 345) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  0] -1 */
    34028706, /* 14744 ( 345) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    51152754, /* 14745 ( 345) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  6] -1 */
       16484, /* 14746 ( 346) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    35563980, /* 14747 ( 346) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6] -1 */
    18557870, /* 14748 ( 346) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
       16320, /* 14749 ( 346) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    35563820, /* 14750 ( 346) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
    51034818, /* 14751 ( 346) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  0] -1 */
    34146642, /* 14752 ( 346) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
     1433658, /* 14753 ( 346) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  0]  1 */
    17140692, /* 14754 ( 346) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6]  1 */
    17140532, /* 14755 ( 346) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
    52451832, /* 14756 ( 346) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
    18557706, /* 14757 ( 346) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
    51034658, /* 14758 ( 346) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  0] -1 */
    34146806, /* 14759 ( 346) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
     1433498, /* 14760 ( 346) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  0]  1 */
    52451996, /* 14761 ( 346) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
       16484, /* 14762 ( 339) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    18557870, /* 14763 ( 339) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
       16320, /* 14764 ( 339) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    18439610, /* 14765 ( 339) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
      134420, /* 14766 ( 339) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6]  1 */
    18439770, /* 14767 ( 339) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
    18557706, /* 14768 ( 339) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
      134580, /* 14769 ( 339) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  6]  1 */
       16484, /* 14770 ( 340) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    18557870, /* 14771 ( 340) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    52569930, /* 14772 ( 340) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
       16320, /* 14773 ( 340) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    34146804, /* 14774 ( 340) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
    52451994, /* 14775 ( 340) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
    18439610, /* 14776 ( 340) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
      134420, /* 14777 ( 340) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6]  1 */
    18439770, /* 14778 ( 340) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
    18557706, /* 14779 ( 340) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
      134580, /* 14780 ( 340) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  6]  1 */
    34028544, /* 14781 ( 340) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    34028708, /* 14782 ( 340) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    52570094, /* 14783 ( 340) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    52451834, /* 14784 ( 340) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
    34146644, /* 14785 ( 340) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
       16484, /* 14786 ( 341) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    18557870, /* 14787 ( 341) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    52569930, /* 14788 ( 341) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    34146804, /* 14789 ( 341) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
    52451994, /* 14790 ( 341) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
    18439610, /* 14791 ( 341) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
      134420, /* 14792 ( 341) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6]  1 */
    34028544, /* 14793 ( 341) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
       16484, /* 14794 ( 342) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    18557870, /* 14795 ( 342) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    52569930, /* 14796 ( 342) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    18439770, /* 14797 ( 342) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
      134580, /* 14798 ( 342) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  6]  1 */
    34028544, /* 14799 ( 342) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    52451834, /* 14800 ( 342) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
    34146644, /* 14801 ( 342) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
       16484, /* 14802 ( 343) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    18557870, /* 14803 ( 343) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
       16320, /* 14804 ( 343) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    34146804, /* 14805 ( 343) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
    52451994, /* 14806 ( 343) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
    18557706, /* 14807 ( 343) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
    52451834, /* 14808 ( 343) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
    34146644, /* 14809 ( 343) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
       16484, /* 14810 ( 344) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    18557870, /* 14811 ( 344) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    51034656, /* 14812 ( 344) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  0] -1 */
       16320, /* 14813 ( 344) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    51152756, /* 14814 ( 344) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
    18439610, /* 14815 ( 344) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
      134420, /* 14816 ( 344) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6]  1 */
    35445882, /* 14817 ( 344) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  0] -1 */
    18439770, /* 14818 ( 344) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
    35563982, /* 14819 ( 344) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
    18557706, /* 14820 ( 344) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
    51152916, /* 14821 ( 344) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6] -1 */
    51034820, /* 14822 ( 344) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  0] -1 */
    35445722, /* 14823 ( 344) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  0] -1 */
      134580, /* 14824 ( 344) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  6]  1 */
    35563818, /* 14825 ( 344) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  6] -1 */
       16484, /* 14826 ( 345) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34028706, /* 14827 ( 345) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    18557870, /* 14828 ( 345) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
       16320, /* 14829 ( 345) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    34146806, /* 14830 ( 345) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    52569932, /* 14831 ( 345) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    18439610, /* 14832 ( 345) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
      134420, /* 14833 ( 345) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6]  1 */
    18439770, /* 14834 ( 345) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
    52451996, /* 14835 ( 345) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
    18557706, /* 14836 ( 345) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
    52570092, /* 14837 ( 345) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
      134580, /* 14838 ( 345) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  6]  1 */
    34146642, /* 14839 ( 345) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
    34028546, /* 14840 ( 345) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    52451832, /* 14841 ( 345) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
       16484, /* 14842 ( 346) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    35563820, /* 14843 ( 346) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
    18557870, /* 14844 ( 346) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
       16320, /* 14845 ( 346) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    35563980, /* 14846 ( 346) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6] -1 */
    51034658, /* 14847 ( 346) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  0] -1 */
    35445720, /* 14848 ( 346) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  0] -1 */
      134420, /* 14849 ( 346) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6]  1 */
    18439610, /* 14850 ( 346) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    18439770, /* 14851 ( 346) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
    51152754, /* 14852 ( 346) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  6] -1 */
    18557706, /* 14853 ( 346) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
    51034818, /* 14854 ( 346) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  0] -1 */
    35445884, /* 14855 ( 346) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  0] -1 */
      134580, /* 14856 ( 346) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  6]  1 */
    51152918, /* 14857 ( 346) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
       16484, /* 14858 ( 339) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    18557870, /* 14859 ( 339) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
        3360, /* 14860 ( 339) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    18426650, /* 14861 ( 339) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
      121460, /* 14862 ( 339) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6]  1 */
    18439770, /* 14863 ( 339) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
    18544746, /* 14864 ( 339) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
      134580, /* 14865 ( 339) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  6]  1 */
       16484, /* 14866 ( 340) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    18557870, /* 14867 ( 340) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    52556970, /* 14868 ( 340) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
        3360, /* 14869 ( 340) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    34146804, /* 14870 ( 340) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
    52451994, /* 14871 ( 340) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
    18426650, /* 14872 ( 340) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
      121460, /* 14873 ( 340) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6]  1 */
    18439770, /* 14874 ( 340) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
    18544746, /* 14875 ( 340) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
      134580, /* 14876 ( 340) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  6]  1 */
    34015584, /* 14877 ( 340) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    34028708, /* 14878 ( 340) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    52570094, /* 14879 ( 340) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    52438874, /* 14880 ( 340) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
    34133684, /* 14881 ( 340) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
       16484, /* 14882 ( 341) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    18557870, /* 14883 ( 341) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    52556970, /* 14884 ( 341) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    34146804, /* 14885 ( 341) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
    52451994, /* 14886 ( 341) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
    18426650, /* 14887 ( 341) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
      121460, /* 14888 ( 341) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6]  1 */
    34015584, /* 14889 ( 341) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
       16484, /* 14890 ( 342) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    18557870, /* 14891 ( 342) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    52556970, /* 14892 ( 342) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    18439770, /* 14893 ( 342) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
      134580, /* 14894 ( 342) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  6]  1 */
    34015584, /* 14895 ( 342) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    52438874, /* 14896 ( 342) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
    34133684, /* 14897 ( 342) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
       16484, /* 14898 ( 343) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    18557870, /* 14899 ( 343) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
        3360, /* 14900 ( 343) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    34146804, /* 14901 ( 343) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
    52451994, /* 14902 ( 343) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
    18544746, /* 14903 ( 343) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
    52438874, /* 14904 ( 343) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
    34133684, /* 14905 ( 343) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
       16484, /* 14906 ( 344) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    18557870, /* 14907 ( 344) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    35432760, /* 14908 ( 344) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  0] -1 */
        3360, /* 14909 ( 344) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    35550860, /* 14910 ( 344) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
    18426650, /* 14911 ( 344) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
      121460, /* 14912 ( 344) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6]  1 */
    51034818, /* 14913 ( 344) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  0] -1 */
    18439770, /* 14914 ( 344) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
    51152918, /* 14915 ( 344) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
    18544746, /* 14916 ( 344) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
    35563980, /* 14917 ( 344) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6] -1 */
    35445884, /* 14918 ( 344) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  0] -1 */
    51021698, /* 14919 ( 344) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  0] -1 */
      134580, /* 14920 ( 344) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  6]  1 */
    51139794, /* 14921 ( 344) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6] -1 */
       16484, /* 14922 ( 345) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34028706, /* 14923 ( 345) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    18557870, /* 14924 ( 345) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
        3360, /* 14925 ( 345) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    34146806, /* 14926 ( 345) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    52556972, /* 14927 ( 345) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    18426650, /* 14928 ( 345) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
      121460, /* 14929 ( 345) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6]  1 */
    18439770, /* 14930 ( 345) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
    52451996, /* 14931 ( 345) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
    18544746, /* 14932 ( 345) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
    52570092, /* 14933 ( 345) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
      134580, /* 14934 ( 345) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  6]  1 */
    34133682, /* 14935 ( 345) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
    34015586, /* 14936 ( 345) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    52438872, /* 14937 ( 345) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
       16484, /* 14938 ( 346) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    51139796, /* 14939 ( 346) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
    18557870, /* 14940 ( 346) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
        3360, /* 14941 ( 346) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    51152916, /* 14942 ( 346) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6] -1 */
    35432762, /* 14943 ( 346) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  0] -1 */
    51021696, /* 14944 ( 346) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  0] -1 */
      121460, /* 14945 ( 346) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6]  1 */
    18426650, /* 14946 ( 346) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    18439770, /* 14947 ( 346) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
    35550858, /* 14948 ( 346) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6] -1 */
    18544746, /* 14949 ( 346) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
    35445882, /* 14950 ( 346) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  0] -1 */
    51034820, /* 14951 ( 346) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  0] -1 */
      134580, /* 14952 ( 346) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  6]  1 */
    35563982, /* 14953 ( 346) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
       16484, /* 14954 ( 339) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    18557870, /* 14955 ( 339) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
        3360, /* 14956 ( 339) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
     1551756, /* 14957 ( 339) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
    17022594, /* 14958 ( 339) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  0]  1 */
     1538636, /* 14959 ( 339) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
    18544746, /* 14960 ( 339) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
    17009474, /* 14961 ( 339) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  0]  1 */
       16484, /* 14962 ( 340) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    18557870, /* 14963 ( 340) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    52556970, /* 14964 ( 340) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
        3360, /* 14965 ( 340) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    51021698, /* 14966 ( 340) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  0] -1 */
    35550860, /* 14967 ( 340) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
     1551756, /* 14968 ( 340) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
    17022594, /* 14969 ( 340) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  0]  1 */
     1538636, /* 14970 ( 340) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
    18544746, /* 14971 ( 340) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
    17009474, /* 14972 ( 340) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  0]  1 */
    34015584, /* 14973 ( 340) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    34028708, /* 14974 ( 340) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    52570094, /* 14975 ( 340) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    35563980, /* 14976 ( 340) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6] -1 */
    51034818, /* 14977 ( 340) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  0] -1 */
       16484, /* 14978 ( 341) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    18557870, /* 14979 ( 341) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    52556970, /* 14980 ( 341) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    51021698, /* 14981 ( 341) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  0] -1 */
    35550860, /* 14982 ( 341) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
     1551756, /* 14983 ( 341) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
    17022594, /* 14984 ( 341) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  0]  1 */
    34015584, /* 14985 ( 341) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
       16484, /* 14986 ( 342) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    18557870, /* 14987 ( 342) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    52556970, /* 14988 ( 342) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
     1538636, /* 14989 ( 342) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
    17009474, /* 14990 ( 342) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  0]  1 */
    34015584, /* 14991 ( 342) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    35563980, /* 14992 ( 342) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6] -1 */
    51034818, /* 14993 ( 342) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  0] -1 */
       16484, /* 14994 ( 343) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    18557870, /* 14995 ( 343) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
        3360, /* 14996 ( 343) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    51021698, /* 14997 ( 343) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  0] -1 */
    35550860, /* 14998 ( 343) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
    18544746, /* 14999 ( 343) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
    35563980, /* 15000 ( 343) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6] -1 */
    51034818, /* 15001 ( 343) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  0] -1 */
       16484, /* 15002 ( 344) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    18557870, /* 15003 ( 344) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    35432760, /* 15004 ( 344) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  0] -1 */
        3360, /* 15005 ( 344) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    52451994, /* 15006 ( 344) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
     1551756, /* 15007 ( 344) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
    17022594, /* 15008 ( 344) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  0]  1 */
    34133684, /* 15009 ( 344) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
     1538636, /* 15010 ( 344) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
    51152918, /* 15011 ( 344) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
    18544746, /* 15012 ( 344) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
    52438874, /* 15013 ( 344) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
    35445884, /* 15014 ( 344) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  0] -1 */
    34146804, /* 15015 ( 344) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
    17009474, /* 15016 ( 344) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  0]  1 */
    51139794, /* 15017 ( 344) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6] -1 */
       16484, /* 15018 ( 345) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34015586, /* 15019 ( 345) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    18557870, /* 15020 ( 345) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
        3360, /* 15021 ( 345) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    51034820, /* 15022 ( 345) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  0] -1 */
    52570092, /* 15023 ( 345) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
     1551756, /* 15024 ( 345) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
    17022594, /* 15025 ( 345) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  0]  1 */
     1538636, /* 15026 ( 345) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
    35563982, /* 15027 ( 345) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
    18544746, /* 15028 ( 345) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
    52556972, /* 15029 ( 345) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    17009474, /* 15030 ( 345) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  0]  1 */
    51021696, /* 15031 ( 345) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  0] -1 */
    34028706, /* 15032 ( 345) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    35550858, /* 15033 ( 345) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6] -1 */
       16484, /* 15034 ( 346) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    51152916, /* 15035 ( 346) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6] -1 */
    18557870, /* 15036 ( 346) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
        3360, /* 15037 ( 346) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    51139796, /* 15038 ( 346) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
    35445882, /* 15039 ( 346) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  0] -1 */
    34133682, /* 15040 ( 346) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
    17022594, /* 15041 ( 346) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  0]  1 */
     1551756, /* 15042 ( 346) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
     1538636, /* 15043 ( 346) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
    52438872, /* 15044 ( 346) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
    18544746, /* 15045 ( 346) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
    35432762, /* 15046 ( 346) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  0] -1 */
    34146806, /* 15047 ( 346) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    17009474, /* 15048 ( 346) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  0]  1 */
    52451996, /* 15049 ( 346) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
       16484, /* 15050 ( 347) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
        3200, /* 15051 ( 347) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
        3362, /* 15052 ( 347) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
       16320, /* 15053 ( 347) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
        3198, /* 15054 ( 347) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
        3360, /* 15055 ( 347) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
       16482, /* 15056 ( 347) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
       16322, /* 15057 ( 347) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
       16484, /* 15058 ( 348) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34015586, /* 15059 ( 348) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    34028546, /* 15060 ( 348) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    34015422, /* 15061 ( 348) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
        3200, /* 15062 ( 348) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
        3362, /* 15063 ( 348) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
       16320, /* 15064 ( 348) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    34015584, /* 15065 ( 348) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    34028706, /* 15066 ( 348) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
        3198, /* 15067 ( 348) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    34015424, /* 15068 ( 348) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
        3360, /* 15069 ( 348) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    34028708, /* 15070 ( 348) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
       16482, /* 15071 ( 348) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    34028544, /* 15072 ( 348) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
       16322, /* 15073 ( 348) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
       16484, /* 15074 ( 349) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34015586, /* 15075 ( 349) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    34015422, /* 15076 ( 349) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
       16320, /* 15077 ( 349) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    34015584, /* 15078 ( 349) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    34015424, /* 15079 ( 349) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
       16482, /* 15080 ( 349) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
       16322, /* 15081 ( 349) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
       16484, /* 15082 ( 350) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34015586, /* 15083 ( 350) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
        3200, /* 15084 ( 350) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34015584, /* 15085 ( 350) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
        3198, /* 15086 ( 350) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    34028546, /* 15087 ( 350) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
       16482, /* 15088 ( 350) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    34028544, /* 15089 ( 350) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
       16484, /* 15090 ( 351) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34015586, /* 15091 ( 351) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    34015422, /* 15092 ( 351) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
        3200, /* 15093 ( 351) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
       16320, /* 15094 ( 351) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    34028706, /* 15095 ( 351) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    34028546, /* 15096 ( 351) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
        3360, /* 15097 ( 351) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
       16484, /* 15098 ( 352) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
        3200, /* 15099 ( 352) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    51034820, /* 15100 ( 352) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  0] -1 */
        3362, /* 15101 ( 352) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    51021698, /* 15102 ( 352) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  0] -1 */
       16320, /* 15103 ( 352) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    51034656, /* 15104 ( 352) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  0] -1 */
    51034818, /* 15105 ( 352) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  0] -1 */
    51021696, /* 15106 ( 352) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  0] -1 */
    51034658, /* 15107 ( 352) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  0] -1 */
        3198, /* 15108 ( 352) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    51021534, /* 15109 ( 352) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  0] -1 */
    51021536, /* 15110 ( 352) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  0] -1 */
        3360, /* 15111 ( 352) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
       16482, /* 15112 ( 352) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
       16322, /* 15113 ( 352) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
       16484, /* 15114 ( 353) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    52451834, /* 15115 ( 353) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
    52438712, /* 15116 ( 353) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
    52438710, /* 15117 ( 353) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
        3200, /* 15118 ( 353) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
        3362, /* 15119 ( 353) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    52438874, /* 15120 ( 353) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
       16320, /* 15121 ( 353) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    52451994, /* 15122 ( 353) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
    52451996, /* 15123 ( 353) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
        3198, /* 15124 ( 353) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
        3360, /* 15125 ( 353) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    52438872, /* 15126 ( 353) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
       16482, /* 15127 ( 353) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    52451832, /* 15128 ( 353) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
       16322, /* 15129 ( 353) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
       16484, /* 15130 ( 354) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    52556810, /* 15131 ( 354) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
        3200, /* 15132 ( 354) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
        3362, /* 15133 ( 354) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
       16322, /* 15134 ( 354) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
       16320, /* 15135 ( 354) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
       16482, /* 15136 ( 354) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    52569932, /* 15137 ( 354) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
        3198, /* 15138 ( 354) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    52556970, /* 15139 ( 354) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    52556972, /* 15140 ( 354) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    52569930, /* 15141 ( 354) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
        3360, /* 15142 ( 354) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    52570092, /* 15143 ( 354) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    52570094, /* 15144 ( 354) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    52556808, /* 15145 ( 354) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
       16484, /* 15146 ( 355) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
        3200, /* 15147 ( 355) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
       16320, /* 15148 ( 355) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
        3360, /* 15149 ( 355) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    18544748, /* 15150 ( 355) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    18544584, /* 15151 ( 355) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
    18557708, /* 15152 ( 355) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    18557868, /* 15153 ( 355) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
       16484, /* 15154 ( 356) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
        3200, /* 15155 ( 356) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34015584, /* 15156 ( 356) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
       16320, /* 15157 ( 356) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    52556808, /* 15158 ( 356) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    52569932, /* 15159 ( 356) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
        3360, /* 15160 ( 356) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    52556972, /* 15161 ( 356) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    18544748, /* 15162 ( 356) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    52570092, /* 15163 ( 356) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    18544584, /* 15164 ( 356) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
    18557708, /* 15165 ( 356) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    18557868, /* 15166 ( 356) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
    34015424, /* 15167 ( 356) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    34028708, /* 15168 ( 356) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    34028544, /* 15169 ( 356) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
       16484, /* 15170 ( 357) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34015584, /* 15171 ( 357) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
       16320, /* 15172 ( 357) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    52556808, /* 15173 ( 357) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    52556972, /* 15174 ( 357) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    18557708, /* 15175 ( 357) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    18557868, /* 15176 ( 357) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
    34015424, /* 15177 ( 357) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
       16484, /* 15178 ( 358) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
        3200, /* 15179 ( 358) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34015584, /* 15180 ( 358) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    52569932, /* 15181 ( 358) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    52556972, /* 15182 ( 358) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    18544584, /* 15183 ( 358) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
    18557868, /* 15184 ( 358) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
    34028544, /* 15185 ( 358) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
       16484, /* 15186 ( 359) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
        3200, /* 15187 ( 359) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
       16320, /* 15188 ( 359) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    52556808, /* 15189 ( 359) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    52569932, /* 15190 ( 359) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
        3360, /* 15191 ( 359) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    52556972, /* 15192 ( 359) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    52570092, /* 15193 ( 359) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
       16484, /* 15194 ( 360) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
        3200, /* 15195 ( 360) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
       16320, /* 15196 ( 360) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    34133522, /* 15197 ( 360) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
        3360, /* 15198 ( 360) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    52438874, /* 15199 ( 360) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
    18544748, /* 15200 ( 360) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    52438710, /* 15201 ( 360) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
    34146642, /* 15202 ( 360) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
    18544584, /* 15203 ( 360) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
    34146806, /* 15204 ( 360) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    18557708, /* 15205 ( 360) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    18557868, /* 15206 ( 360) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
    34133682, /* 15207 ( 360) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
    52451994, /* 15208 ( 360) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
    52451834, /* 15209 ( 360) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
       16484, /* 15210 ( 361) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
        3200, /* 15211 ( 361) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
       16320, /* 15212 ( 361) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    34133520, /* 15213 ( 361) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
    52438872, /* 15214 ( 361) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
        3360, /* 15215 ( 361) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    34146804, /* 15216 ( 361) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
    18544748, /* 15217 ( 361) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    52451996, /* 15218 ( 361) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
    18544584, /* 15219 ( 361) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
    34133684, /* 15220 ( 361) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    52451832, /* 15221 ( 361) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
    18557708, /* 15222 ( 361) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    18557868, /* 15223 ( 361) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
    52438712, /* 15224 ( 361) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
    34146644, /* 15225 ( 361) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
       16484, /* 15226 ( 362) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
        3200, /* 15227 ( 362) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
       16320, /* 15228 ( 362) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    52556810, /* 15229 ( 362) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
        3360, /* 15230 ( 362) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    34015586, /* 15231 ( 362) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    52569930, /* 15232 ( 362) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    52556970, /* 15233 ( 362) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    18544748, /* 15234 ( 362) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    18544584, /* 15235 ( 362) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
    34028546, /* 15236 ( 362) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    18557708, /* 15237 ( 362) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    18557868, /* 15238 ( 362) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
    34028706, /* 15239 ( 362) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    52570094, /* 15240 ( 362) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    34015422, /* 15241 ( 362) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
       16484, /* 15242 ( 355) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    18426488, /* 15243 ( 355) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
     1551594, /* 15244 ( 355) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
    17127570, /* 15245 ( 355) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6]  1 */
     1538636, /* 15246 ( 355) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
        3198, /* 15247 ( 355) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    17140532, /* 15248 ( 355) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
    18439770, /* 15249 ( 355) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
       16484, /* 15250 ( 356) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    18426488, /* 15251 ( 356) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    51139794, /* 15252 ( 356) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6] -1 */
     1551594, /* 15253 ( 356) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
    34015422, /* 15254 ( 356) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    51152756, /* 15255 ( 356) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
    17127570, /* 15256 ( 356) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6]  1 */
    35550860, /* 15257 ( 356) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
     1538636, /* 15258 ( 356) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
    52451994, /* 15259 ( 356) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
        3198, /* 15260 ( 356) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    17140532, /* 15261 ( 356) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
    18439770, /* 15262 ( 356) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
    52438712, /* 15263 ( 356) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
    34028708, /* 15264 ( 356) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    35563818, /* 15265 ( 356) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  6] -1 */
       16484, /* 15266 ( 357) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    51139794, /* 15267 ( 357) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6] -1 */
     1551594, /* 15268 ( 357) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
    34015422, /* 15269 ( 357) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    35550860, /* 15270 ( 357) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
    17140532, /* 15271 ( 357) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
    18439770, /* 15272 ( 357) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
    52438712, /* 15273 ( 357) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
       16484, /* 15274 ( 358) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    18426488, /* 15275 ( 358) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    51139794, /* 15276 ( 358) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6] -1 */
    51152756, /* 15277 ( 358) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
    35550860, /* 15278 ( 358) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
        3198, /* 15279 ( 358) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    18439770, /* 15280 ( 358) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
    35563818, /* 15281 ( 358) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  6] -1 */
       16484, /* 15282 ( 359) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    18426488, /* 15283 ( 359) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
     1551594, /* 15284 ( 359) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
    34015422, /* 15285 ( 359) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    51152756, /* 15286 ( 359) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
    17127570, /* 15287 ( 359) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6]  1 */
    35550860, /* 15288 ( 359) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
    52451994, /* 15289 ( 359) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
       16484, /* 15290 ( 360) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    18426488, /* 15291 ( 360) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
     1551594, /* 15292 ( 360) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
    52556810, /* 15293 ( 360) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    17127570, /* 15294 ( 360) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6]  1 */
    35432762, /* 15295 ( 360) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  0] -1 */
     1538636, /* 15296 ( 360) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
    34133520, /* 15297 ( 360) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
    35445720, /* 15298 ( 360) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  0] -1 */
        3198, /* 15299 ( 360) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    34146806, /* 15300 ( 360) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    17140532, /* 15301 ( 360) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
    18439770, /* 15302 ( 360) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
    51021696, /* 15303 ( 360) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  0] -1 */
    52570092, /* 15304 ( 360) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    51034658, /* 15305 ( 360) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  0] -1 */
       16484, /* 15306 ( 361) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    18426488, /* 15307 ( 361) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
     1551594, /* 15308 ( 361) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
    52438710, /* 15309 ( 361) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
    35550858, /* 15310 ( 361) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6] -1 */
    17127570, /* 15311 ( 361) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6]  1 */
    34028706, /* 15312 ( 361) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
     1538636, /* 15313 ( 361) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
    52451996, /* 15314 ( 361) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
        3198, /* 15315 ( 361) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    51139796, /* 15316 ( 361) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
    51152754, /* 15317 ( 361) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  6] -1 */
    17140532, /* 15318 ( 361) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
    18439770, /* 15319 ( 361) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
    34015424, /* 15320 ( 361) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    35563820, /* 15321 ( 361) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
       16484, /* 15322 ( 362) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    18426488, /* 15323 ( 362) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
     1551594, /* 15324 ( 362) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
    34133522, /* 15325 ( 362) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    17127570, /* 15326 ( 362) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6]  1 */
    51021698, /* 15327 ( 362) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  0] -1 */
    51034656, /* 15328 ( 362) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  0] -1 */
    35432760, /* 15329 ( 362) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  0] -1 */
     1538636, /* 15330 ( 362) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
        3198, /* 15331 ( 362) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    35445722, /* 15332 ( 362) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  0] -1 */
    17140532, /* 15333 ( 362) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
    18439770, /* 15334 ( 362) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
    34146804, /* 15335 ( 362) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
    52570094, /* 15336 ( 362) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    52556808, /* 15337 ( 362) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
       16484, /* 15338 ( 363) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
      121460, /* 15339 ( 363) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6]  1 */
      121458, /* 15340 ( 363) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  6]  1 */
      134418, /* 15341 ( 363) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  6]  1 */
        3200, /* 15342 ( 363) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
        3198, /* 15343 ( 363) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
      134420, /* 15344 ( 363) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6]  1 */
       16482, /* 15345 ( 363) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
       16484, /* 15346 ( 364) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
      121460, /* 15347 ( 364) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6]  1 */
    34015422, /* 15348 ( 364) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
      134418, /* 15349 ( 364) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  6]  1 */
        3200, /* 15350 ( 364) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
      121458, /* 15351 ( 364) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  6]  1 */
    34146644, /* 15352 ( 364) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    34028706, /* 15353 ( 364) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
      134420, /* 15354 ( 364) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6]  1 */
        3198, /* 15355 ( 364) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    34133684, /* 15356 ( 364) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    34133682, /* 15357 ( 364) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
    34146642, /* 15358 ( 364) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
    34015424, /* 15359 ( 364) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    34028708, /* 15360 ( 364) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
       16482, /* 15361 ( 364) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
       16484, /* 15362 ( 365) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34015422, /* 15363 ( 365) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
      134418, /* 15364 ( 365) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  6]  1 */
      134420, /* 15365 ( 365) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6]  1 */
    34133684, /* 15366 ( 365) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    34133682, /* 15367 ( 365) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
    34015424, /* 15368 ( 365) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
       16482, /* 15369 ( 365) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
       16484, /* 15370 ( 366) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
      121460, /* 15371 ( 366) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6]  1 */
    34015422, /* 15372 ( 366) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
        3200, /* 15373 ( 366) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34028706, /* 15374 ( 366) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    34133682, /* 15375 ( 366) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
    34146642, /* 15376 ( 366) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
      134420, /* 15377 ( 366) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6]  1 */
       16484, /* 15378 ( 367) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
        3200, /* 15379 ( 367) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34146644, /* 15380 ( 367) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
        3198, /* 15381 ( 367) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    34133684, /* 15382 ( 367) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    34133682, /* 15383 ( 367) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
    34146642, /* 15384 ( 367) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
       16482, /* 15385 ( 367) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
       16484, /* 15386 ( 368) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
      121458, /* 15387 ( 368) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  6]  1 */
    34028706, /* 15388 ( 368) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
      134420, /* 15389 ( 368) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6]  1 */
        3198, /* 15390 ( 368) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    34133684, /* 15391 ( 368) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    34146642, /* 15392 ( 368) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
    34015424, /* 15393 ( 368) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
       16484, /* 15394 ( 369) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34015422, /* 15395 ( 369) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
      134418, /* 15396 ( 369) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  6]  1 */
        3200, /* 15397 ( 369) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
      121458, /* 15398 ( 369) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  6]  1 */
    34146644, /* 15399 ( 369) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    34028706, /* 15400 ( 369) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    34133684, /* 15401 ( 369) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
       16484, /* 15402 ( 370) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
      121460, /* 15403 ( 370) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6]  1 */
    51139794, /* 15404 ( 370) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6] -1 */
      121458, /* 15405 ( 370) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  6]  1 */
      134418, /* 15406 ( 370) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  6]  1 */
        3200, /* 15407 ( 370) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    51152756, /* 15408 ( 370) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
    51034820, /* 15409 ( 370) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  0] -1 */
    51034818, /* 15410 ( 370) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  0] -1 */
    51139796, /* 15411 ( 370) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
        3198, /* 15412 ( 370) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    51021534, /* 15413 ( 370) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  0] -1 */
    51152754, /* 15414 ( 370) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  6] -1 */
    51021536, /* 15415 ( 370) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  0] -1 */
      134420, /* 15416 ( 370) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6]  1 */
       16482, /* 15417 ( 370) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
       16484, /* 15418 ( 371) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
      121460, /* 15419 ( 371) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6]  1 */
    34133522, /* 15420 ( 371) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
      121458, /* 15421 ( 371) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  6]  1 */
      134418, /* 15422 ( 371) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  6]  1 */
        3200, /* 15423 ( 371) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34015586, /* 15424 ( 371) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    34028546, /* 15425 ( 371) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    34015584, /* 15426 ( 371) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    34133520, /* 15427 ( 371) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
        3198, /* 15428 ( 371) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    34146806, /* 15429 ( 371) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
      134420, /* 15430 ( 371) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6]  1 */
    34146804, /* 15431 ( 371) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
       16482, /* 15432 ( 371) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    34028544, /* 15433 ( 371) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
       16484, /* 15434 ( 372) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
      121460, /* 15435 ( 372) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6]  1 */
      121458, /* 15436 ( 372) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  6]  1 */
      134418, /* 15437 ( 372) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  6]  1 */
        3200, /* 15438 ( 372) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    51021698, /* 15439 ( 372) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  0] -1 */
    51034656, /* 15440 ( 372) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  0] -1 */
    51139634, /* 15441 ( 372) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
      134420, /* 15442 ( 372) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6]  1 */
        3198, /* 15443 ( 372) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    51152916, /* 15444 ( 372) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6] -1 */
    51152918, /* 15445 ( 372) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
    51021696, /* 15446 ( 372) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  0] -1 */
    51139632, /* 15447 ( 372) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  6] -1 */
       16482, /* 15448 ( 372) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    51034658, /* 15449 ( 372) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  0] -1 */
       16484, /* 15450 ( 373) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
      121460, /* 15451 ( 373) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6]  1 */
      121458, /* 15452 ( 373) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  6]  1 */
      134418, /* 15453 ( 373) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  6]  1 */
        3200, /* 15454 ( 373) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    52438710, /* 15455 ( 373) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
    52569932, /* 15456 ( 373) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
      134420, /* 15457 ( 373) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6]  1 */
    52451994, /* 15458 ( 373) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
    52451996, /* 15459 ( 373) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
        3198, /* 15460 ( 373) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    52556970, /* 15461 ( 373) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    52556972, /* 15462 ( 373) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    52569930, /* 15463 ( 373) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    52438712, /* 15464 ( 373) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
       16482, /* 15465 ( 373) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
       16484, /* 15466 ( 374) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    52451834, /* 15467 ( 374) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
      121460, /* 15468 ( 374) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6]  1 */
      121458, /* 15469 ( 374) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  6]  1 */
      134418, /* 15470 ( 374) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  6]  1 */
        3200, /* 15471 ( 374) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    52556810, /* 15472 ( 374) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    52438874, /* 15473 ( 374) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
       16482, /* 15474 ( 374) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    52438872, /* 15475 ( 374) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
        3198, /* 15476 ( 374) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
      134420, /* 15477 ( 374) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6]  1 */
    52570092, /* 15478 ( 374) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    52570094, /* 15479 ( 374) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    52451832, /* 15480 ( 374) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
    52556808, /* 15481 ( 374) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
       16484, /* 15482 ( 363) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    17022434, /* 15483 ( 363) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  0]  1 */
    17009312, /* 15484 ( 363) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  0]  1 */
    17009472, /* 15485 ( 363) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  0]  1 */
       16320, /* 15486 ( 363) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
        3198, /* 15487 ( 363) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    17022594, /* 15488 ( 363) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  0]  1 */
        3362, /* 15489 ( 363) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
       16484, /* 15490 ( 364) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    17022434, /* 15491 ( 364) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  0]  1 */
    34015422, /* 15492 ( 364) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    17009472, /* 15493 ( 364) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  0]  1 */
       16320, /* 15494 ( 364) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    17009312, /* 15495 ( 364) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  0]  1 */
    51034818, /* 15496 ( 364) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  0] -1 */
    34015586, /* 15497 ( 364) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    17022594, /* 15498 ( 364) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  0]  1 */
        3198, /* 15499 ( 364) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    51034658, /* 15500 ( 364) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  0] -1 */
    51021536, /* 15501 ( 364) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  0] -1 */
    51021696, /* 15502 ( 364) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  0] -1 */
    34028544, /* 15503 ( 364) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    34028708, /* 15504 ( 364) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
        3362, /* 15505 ( 364) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
       16484, /* 15506 ( 365) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34015422, /* 15507 ( 365) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    17009472, /* 15508 ( 365) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  0]  1 */
    17022594, /* 15509 ( 365) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  0]  1 */
    51034658, /* 15510 ( 365) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  0] -1 */
    51021536, /* 15511 ( 365) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  0] -1 */
    34028544, /* 15512 ( 365) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
        3362, /* 15513 ( 365) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
       16484, /* 15514 ( 366) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    17022434, /* 15515 ( 366) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  0]  1 */
    34015422, /* 15516 ( 366) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
       16320, /* 15517 ( 366) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    34015586, /* 15518 ( 366) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    51021536, /* 15519 ( 366) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  0] -1 */
    51021696, /* 15520 ( 366) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  0] -1 */
    17022594, /* 15521 ( 366) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  0]  1 */
       16484, /* 15522 ( 367) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
       16320, /* 15523 ( 367) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    51034818, /* 15524 ( 367) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  0] -1 */
        3198, /* 15525 ( 367) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    51034658, /* 15526 ( 367) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  0] -1 */
    51021536, /* 15527 ( 367) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  0] -1 */
    51021696, /* 15528 ( 367) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  0] -1 */
        3362, /* 15529 ( 367) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
       16484, /* 15530 ( 368) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    17009312, /* 15531 ( 368) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  0]  1 */
    34015586, /* 15532 ( 368) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    17022594, /* 15533 ( 368) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  0]  1 */
        3198, /* 15534 ( 368) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    51034658, /* 15535 ( 368) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  0] -1 */
    51021696, /* 15536 ( 368) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  0] -1 */
    34028544, /* 15537 ( 368) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
       16484, /* 15538 ( 369) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34015422, /* 15539 ( 369) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    17009472, /* 15540 ( 369) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  0]  1 */
       16320, /* 15541 ( 369) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    17009312, /* 15542 ( 369) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  0]  1 */
    51034818, /* 15543 ( 369) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  0] -1 */
    34015586, /* 15544 ( 369) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    51034658, /* 15545 ( 369) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  0] -1 */
       16484, /* 15546 ( 370) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    17022434, /* 15547 ( 370) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  0]  1 */
    52438712, /* 15548 ( 370) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
    17009312, /* 15549 ( 370) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  0]  1 */
    17009472, /* 15550 ( 370) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  0]  1 */
       16320, /* 15551 ( 370) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    52451994, /* 15552 ( 370) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
    35445884, /* 15553 ( 370) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  0] -1 */
    35432762, /* 15554 ( 370) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  0] -1 */
    52451834, /* 15555 ( 370) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
        3198, /* 15556 ( 370) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    35432598, /* 15557 ( 370) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  0] -1 */
    52438872, /* 15558 ( 370) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
    35445720, /* 15559 ( 370) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  0] -1 */
    17022594, /* 15560 ( 370) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  0]  1 */
        3362, /* 15561 ( 370) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
       16484, /* 15562 ( 371) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    17022434, /* 15563 ( 371) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  0]  1 */
    51034656, /* 15564 ( 371) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  0] -1 */
    17009312, /* 15565 ( 371) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  0]  1 */
    17009472, /* 15566 ( 371) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  0]  1 */
       16320, /* 15567 ( 371) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    34028546, /* 15568 ( 371) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    34028706, /* 15569 ( 371) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    34015424, /* 15570 ( 371) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    51021534, /* 15571 ( 371) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  0] -1 */
        3198, /* 15572 ( 371) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    51034820, /* 15573 ( 371) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  0] -1 */
    17022594, /* 15574 ( 371) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  0]  1 */
    51021698, /* 15575 ( 371) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  0] -1 */
        3362, /* 15576 ( 371) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34015584, /* 15577 ( 371) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
       16484, /* 15578 ( 372) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    17022434, /* 15579 ( 372) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  0]  1 */
    17009312, /* 15580 ( 372) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  0]  1 */
    17009472, /* 15581 ( 372) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  0]  1 */
       16320, /* 15582 ( 372) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    35445722, /* 15583 ( 372) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  0] -1 */
    35432760, /* 15584 ( 372) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  0] -1 */
    52451832, /* 15585 ( 372) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
    17022594, /* 15586 ( 372) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  0]  1 */
        3198, /* 15587 ( 372) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    52438874, /* 15588 ( 372) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
    52451996, /* 15589 ( 372) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
    35432600, /* 15590 ( 372) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  0] -1 */
    52438710, /* 15591 ( 372) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
        3362, /* 15592 ( 372) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    35445882, /* 15593 ( 372) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  0] -1 */
       16484, /* 15594 ( 373) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    17022434, /* 15595 ( 373) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  0]  1 */
    17009312, /* 15596 ( 373) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  0]  1 */
    17009472, /* 15597 ( 373) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  0]  1 */
       16320, /* 15598 ( 373) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    35550696, /* 15599 ( 373) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  6] -1 */
    52570092, /* 15600 ( 373) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    17022594, /* 15601 ( 373) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  0]  1 */
    35550860, /* 15602 ( 373) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
    35563982, /* 15603 ( 373) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
        3198, /* 15604 ( 373) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    52556810, /* 15605 ( 373) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    52569932, /* 15606 ( 373) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    52556970, /* 15607 ( 373) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    35563818, /* 15608 ( 373) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  6] -1 */
        3362, /* 15609 ( 373) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
       16484, /* 15610 ( 374) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    35563980, /* 15611 ( 374) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6] -1 */
    17022434, /* 15612 ( 374) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  0]  1 */
    17009312, /* 15613 ( 374) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  0]  1 */
    17009472, /* 15614 ( 374) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  0]  1 */
       16320, /* 15615 ( 374) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    52569930, /* 15616 ( 374) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    35563820, /* 15617 ( 374) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
        3362, /* 15618 ( 374) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    35550698, /* 15619 ( 374) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
        3198, /* 15620 ( 374) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    17022594, /* 15621 ( 374) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  0]  1 */
    52556972, /* 15622 ( 374) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    52570094, /* 15623 ( 374) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    35550858, /* 15624 ( 374) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6] -1 */
    52556808, /* 15625 ( 374) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
       16484, /* 15626 ( 363) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
     1433658, /* 15627 ( 363) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  0]  1 */
     1433496, /* 15628 ( 363) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  0]  1 */
     1420376, /* 15629 ( 363) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  0]  1 */
        3360, /* 15630 ( 363) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
        3198, /* 15631 ( 363) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
     1420538, /* 15632 ( 363) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  0]  1 */
       16322, /* 15633 ( 363) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
       16484, /* 15634 ( 364) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
     1433658, /* 15635 ( 364) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  0]  1 */
    34015422, /* 15636 ( 364) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
     1420376, /* 15637 ( 364) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  0]  1 */
        3360, /* 15638 ( 364) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
     1433496, /* 15639 ( 364) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  0]  1 */
    35432762, /* 15640 ( 364) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  0] -1 */
    34028546, /* 15641 ( 364) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
     1420538, /* 15642 ( 364) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  0]  1 */
        3198, /* 15643 ( 364) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    35445882, /* 15644 ( 364) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  0] -1 */
    35445720, /* 15645 ( 364) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  0] -1 */
    35432600, /* 15646 ( 364) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  0] -1 */
    34015584, /* 15647 ( 364) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    34028708, /* 15648 ( 364) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
       16322, /* 15649 ( 364) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
       16484, /* 15650 ( 365) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34015422, /* 15651 ( 365) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
     1420376, /* 15652 ( 365) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  0]  1 */
     1420538, /* 15653 ( 365) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  0]  1 */
    35445882, /* 15654 ( 365) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  0] -1 */
    35445720, /* 15655 ( 365) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  0] -1 */
    34015584, /* 15656 ( 365) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
       16322, /* 15657 ( 365) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
       16484, /* 15658 ( 366) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
     1433658, /* 15659 ( 366) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  0]  1 */
    34015422, /* 15660 ( 366) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
        3360, /* 15661 ( 366) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    34028546, /* 15662 ( 366) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    35445720, /* 15663 ( 366) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  0] -1 */
    35432600, /* 15664 ( 366) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  0] -1 */
     1420538, /* 15665 ( 366) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  0]  1 */
       16484, /* 15666 ( 367) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
        3360, /* 15667 ( 367) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    35432762, /* 15668 ( 367) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  0] -1 */
        3198, /* 15669 ( 367) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    35445882, /* 15670 ( 367) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  0] -1 */
    35445720, /* 15671 ( 367) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  0] -1 */
    35432600, /* 15672 ( 367) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  0] -1 */
       16322, /* 15673 ( 367) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
       16484, /* 15674 ( 368) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
     1433496, /* 15675 ( 368) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  0]  1 */
    34028546, /* 15676 ( 368) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
     1420538, /* 15677 ( 368) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  0]  1 */
        3198, /* 15678 ( 368) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    35445882, /* 15679 ( 368) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  0] -1 */
    35432600, /* 15680 ( 368) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  0] -1 */
    34015584, /* 15681 ( 368) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
       16484, /* 15682 ( 369) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34015422, /* 15683 ( 369) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
     1420376, /* 15684 ( 369) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  0]  1 */
        3360, /* 15685 ( 369) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
     1433496, /* 15686 ( 369) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  0]  1 */
    35432762, /* 15687 ( 369) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  0] -1 */
    34028546, /* 15688 ( 369) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    35445882, /* 15689 ( 369) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  0] -1 */
       16484, /* 15690 ( 370) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
     1433658, /* 15691 ( 370) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  0]  1 */
    35563818, /* 15692 ( 370) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  6] -1 */
     1433496, /* 15693 ( 370) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  0]  1 */
     1420376, /* 15694 ( 370) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  0]  1 */
        3360, /* 15695 ( 370) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    35550860, /* 15696 ( 370) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
    34146806, /* 15697 ( 370) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    34146644, /* 15698 ( 370) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    35563980, /* 15699 ( 370) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6] -1 */
        3198, /* 15700 ( 370) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    34133520, /* 15701 ( 370) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
    35550698, /* 15702 ( 370) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
    34133682, /* 15703 ( 370) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
     1420538, /* 15704 ( 370) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  0]  1 */
       16322, /* 15705 ( 370) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
       16484, /* 15706 ( 371) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
     1433658, /* 15707 ( 371) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  0]  1 */
    35432760, /* 15708 ( 371) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  0] -1 */
     1433496, /* 15709 ( 371) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  0]  1 */
     1420376, /* 15710 ( 371) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  0]  1 */
        3360, /* 15711 ( 371) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    34028706, /* 15712 ( 371) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    34015586, /* 15713 ( 371) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    34028544, /* 15714 ( 371) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    35432598, /* 15715 ( 371) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  0] -1 */
        3198, /* 15716 ( 371) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    35445884, /* 15717 ( 371) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  0] -1 */
     1420538, /* 15718 ( 371) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  0]  1 */
    35445722, /* 15719 ( 371) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  0] -1 */
       16322, /* 15720 ( 371) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34015424, /* 15721 ( 371) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
       16484, /* 15722 ( 372) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
     1433658, /* 15723 ( 372) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  0]  1 */
     1433496, /* 15724 ( 372) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  0]  1 */
     1420376, /* 15725 ( 372) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  0]  1 */
        3360, /* 15726 ( 372) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    34146804, /* 15727 ( 372) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
    34133522, /* 15728 ( 372) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    35550858, /* 15729 ( 372) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6] -1 */
     1420538, /* 15730 ( 372) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  0]  1 */
        3198, /* 15731 ( 372) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    35563820, /* 15732 ( 372) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
    35563982, /* 15733 ( 372) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
    34146642, /* 15734 ( 372) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
    35550696, /* 15735 ( 372) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  6] -1 */
       16322, /* 15736 ( 372) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34133684, /* 15737 ( 372) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
       16484, /* 15738 ( 373) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
     1433658, /* 15739 ( 373) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  0]  1 */
     1433496, /* 15740 ( 373) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  0]  1 */
     1420376, /* 15741 ( 373) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  0]  1 */
        3360, /* 15742 ( 373) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    51139632, /* 15743 ( 373) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  6] -1 */
    52556972, /* 15744 ( 373) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
     1420538, /* 15745 ( 373) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  0]  1 */
    51152756, /* 15746 ( 373) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
    51152918, /* 15747 ( 373) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
        3198, /* 15748 ( 373) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    52569930, /* 15749 ( 373) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    52570092, /* 15750 ( 373) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    52556810, /* 15751 ( 373) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    51139794, /* 15752 ( 373) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6] -1 */
       16322, /* 15753 ( 373) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
       16484, /* 15754 ( 374) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    51139796, /* 15755 ( 374) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
     1433658, /* 15756 ( 374) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  0]  1 */
     1433496, /* 15757 ( 374) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  0]  1 */
     1420376, /* 15758 ( 374) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  0]  1 */
        3360, /* 15759 ( 374) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    52556970, /* 15760 ( 374) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    51152916, /* 15761 ( 374) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6] -1 */
       16322, /* 15762 ( 374) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    51152754, /* 15763 ( 374) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  6] -1 */
        3198, /* 15764 ( 374) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
     1420538, /* 15765 ( 374) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  0]  1 */
    52569932, /* 15766 ( 374) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    52570094, /* 15767 ( 374) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    51139634, /* 15768 ( 374) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
    52556808, /* 15769 ( 374) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
       16484, /* 15770 ( 375) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
        3200, /* 15771 ( 375) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
        3360, /* 15772 ( 375) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    18439610, /* 15773 ( 375) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    18426486, /* 15774 ( 375) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
    18439770, /* 15775 ( 375) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
       16320, /* 15776 ( 375) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    18426650, /* 15777 ( 375) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
       16484, /* 15778 ( 376) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
        3200, /* 15779 ( 376) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    52438710, /* 15780 ( 376) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
        3360, /* 15781 ( 376) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    34015584, /* 15782 ( 376) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    18439610, /* 15783 ( 376) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    52438874, /* 15784 ( 376) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
    52451994, /* 15785 ( 376) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
    34028544, /* 15786 ( 376) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    18426486, /* 15787 ( 376) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
    18439770, /* 15788 ( 376) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
       16320, /* 15789 ( 376) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    34015424, /* 15790 ( 376) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    34028708, /* 15791 ( 376) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    18426650, /* 15792 ( 376) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    52451834, /* 15793 ( 376) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
       16484, /* 15794 ( 377) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34015424, /* 15795 ( 377) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    52438710, /* 15796 ( 377) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
    18439610, /* 15797 ( 377) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    52438874, /* 15798 ( 377) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
    18439770, /* 15799 ( 377) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
       16320, /* 15800 ( 377) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    34015584, /* 15801 ( 377) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
       16484, /* 15802 ( 378) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
        3200, /* 15803 ( 378) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    52438710, /* 15804 ( 378) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
    18439610, /* 15805 ( 378) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    52451994, /* 15806 ( 378) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
    34028544, /* 15807 ( 378) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    34015584, /* 15808 ( 378) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    18426650, /* 15809 ( 378) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
       16484, /* 15810 ( 379) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
        3200, /* 15811 ( 379) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    52438874, /* 15812 ( 379) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
    34028544, /* 15813 ( 379) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    18426486, /* 15814 ( 379) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
    18439770, /* 15815 ( 379) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
    34015584, /* 15816 ( 379) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    52451834, /* 15817 ( 379) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
       16484, /* 15818 ( 380) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
        3360, /* 15819 ( 380) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    18439610, /* 15820 ( 380) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    52438874, /* 15821 ( 380) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
    52451994, /* 15822 ( 380) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
    34028544, /* 15823 ( 380) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    18426486, /* 15824 ( 380) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
    34015424, /* 15825 ( 380) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
       16484, /* 15826 ( 381) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
        3200, /* 15827 ( 381) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    52438710, /* 15828 ( 381) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
        3360, /* 15829 ( 381) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    52438874, /* 15830 ( 381) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
    52451994, /* 15831 ( 381) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
       16320, /* 15832 ( 381) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    52451834, /* 15833 ( 381) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
       16484, /* 15834 ( 382) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
        3200, /* 15835 ( 382) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    35445882, /* 15836 ( 382) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  0] -1 */
    35445722, /* 15837 ( 382) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  0] -1 */
        3360, /* 15838 ( 382) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    51034820, /* 15839 ( 382) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  0] -1 */
    35432762, /* 15840 ( 382) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  0] -1 */
    51021696, /* 15841 ( 382) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  0] -1 */
    51021536, /* 15842 ( 382) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  0] -1 */
    18439610, /* 15843 ( 382) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    18426486, /* 15844 ( 382) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
    35432598, /* 15845 ( 382) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  0] -1 */
    18439770, /* 15846 ( 382) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
       16320, /* 15847 ( 382) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    18426650, /* 15848 ( 382) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    51034656, /* 15849 ( 382) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  0] -1 */
       16484, /* 15850 ( 383) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
        3200, /* 15851 ( 383) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34133682, /* 15852 ( 383) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
    34133522, /* 15853 ( 383) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    34146642, /* 15854 ( 383) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
        3360, /* 15855 ( 383) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    52556972, /* 15856 ( 383) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    52569932, /* 15857 ( 383) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    18439610, /* 15858 ( 383) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    52556808, /* 15859 ( 383) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    18426486, /* 15860 ( 383) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
    34146806, /* 15861 ( 383) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    18439770, /* 15862 ( 383) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
       16320, /* 15863 ( 383) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    52570092, /* 15864 ( 383) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    18426650, /* 15865 ( 383) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
       16484, /* 15866 ( 384) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
        3200, /* 15867 ( 384) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    51139632, /* 15868 ( 384) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  6] -1 */
        3360, /* 15869 ( 384) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    51152756, /* 15870 ( 384) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
    18439610, /* 15871 ( 384) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    35550698, /* 15872 ( 384) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
    35563982, /* 15873 ( 384) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
    18426486, /* 15874 ( 384) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
    51139796, /* 15875 ( 384) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
    35550858, /* 15876 ( 384) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6] -1 */
    18439770, /* 15877 ( 384) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
    35563818, /* 15878 ( 384) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  6] -1 */
       16320, /* 15879 ( 384) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    51152916, /* 15880 ( 384) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6] -1 */
    18426650, /* 15881 ( 384) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
       16484, /* 15882 ( 385) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
        3200, /* 15883 ( 385) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34015422, /* 15884 ( 385) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
        3360, /* 15885 ( 385) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    34015586, /* 15886 ( 385) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    52451832, /* 15887 ( 385) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
    18439610, /* 15888 ( 385) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    34028706, /* 15889 ( 385) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    52438872, /* 15890 ( 385) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
    52451996, /* 15891 ( 385) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
    18426486, /* 15892 ( 385) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
    34028546, /* 15893 ( 385) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    18439770, /* 15894 ( 385) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
       16320, /* 15895 ( 385) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    18426650, /* 15896 ( 385) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    52438712, /* 15897 ( 385) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
       16484, /* 15898 ( 386) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
        3200, /* 15899 ( 386) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    52556810, /* 15900 ( 386) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
        3360, /* 15901 ( 386) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    52556970, /* 15902 ( 386) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    18426650, /* 15903 ( 386) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    18439610, /* 15904 ( 386) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    34133684, /* 15905 ( 386) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    18426486, /* 15906 ( 386) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
    52569930, /* 15907 ( 386) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    18439770, /* 15908 ( 386) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
       16320, /* 15909 ( 386) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    34146804, /* 15910 ( 386) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
    52570094, /* 15911 ( 386) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    34146644, /* 15912 ( 386) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    34133520, /* 15913 ( 386) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
       16484, /* 15914 ( 375) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    18426488, /* 15915 ( 375) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    17009472, /* 15916 ( 375) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  0]  1 */
    17022434, /* 15917 ( 375) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  0]  1 */
        3198, /* 15918 ( 375) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    18439770, /* 15919 ( 375) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
     1433496, /* 15920 ( 375) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  0]  1 */
     1420538, /* 15921 ( 375) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  0]  1 */
       16484, /* 15922 ( 376) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    18426488, /* 15923 ( 376) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    34015422, /* 15924 ( 376) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    17009472, /* 15925 ( 376) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  0]  1 */
    51021696, /* 15926 ( 376) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  0] -1 */
    17022434, /* 15927 ( 376) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  0]  1 */
    35432762, /* 15928 ( 376) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  0] -1 */
    52451994, /* 15929 ( 376) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
    35445720, /* 15930 ( 376) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  0] -1 */
        3198, /* 15931 ( 376) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    18439770, /* 15932 ( 376) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
     1433496, /* 15933 ( 376) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  0]  1 */
    52438712, /* 15934 ( 376) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
    34028708, /* 15935 ( 376) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
     1420538, /* 15936 ( 376) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  0]  1 */
    51034658, /* 15937 ( 376) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  0] -1 */
       16484, /* 15938 ( 377) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    52438712, /* 15939 ( 377) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
    34015422, /* 15940 ( 377) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    17022434, /* 15941 ( 377) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  0]  1 */
    35432762, /* 15942 ( 377) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  0] -1 */
    18439770, /* 15943 ( 377) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
     1433496, /* 15944 ( 377) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  0]  1 */
    51021696, /* 15945 ( 377) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  0] -1 */
       16484, /* 15946 ( 378) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    18426488, /* 15947 ( 378) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    34015422, /* 15948 ( 378) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    17022434, /* 15949 ( 378) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  0]  1 */
    52451994, /* 15950 ( 378) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
    35445720, /* 15951 ( 378) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  0] -1 */
    51021696, /* 15952 ( 378) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  0] -1 */
     1420538, /* 15953 ( 378) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  0]  1 */
       16484, /* 15954 ( 379) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    18426488, /* 15955 ( 379) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    35432762, /* 15956 ( 379) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  0] -1 */
    35445720, /* 15957 ( 379) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  0] -1 */
        3198, /* 15958 ( 379) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    18439770, /* 15959 ( 379) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
    51021696, /* 15960 ( 379) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  0] -1 */
    51034658, /* 15961 ( 379) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  0] -1 */
       16484, /* 15962 ( 380) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    17009472, /* 15963 ( 380) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  0]  1 */
    17022434, /* 15964 ( 380) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  0]  1 */
    35432762, /* 15965 ( 380) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  0] -1 */
    52451994, /* 15966 ( 380) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
    35445720, /* 15967 ( 380) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  0] -1 */
        3198, /* 15968 ( 380) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    52438712, /* 15969 ( 380) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
       16484, /* 15970 ( 381) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    18426488, /* 15971 ( 381) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    34015422, /* 15972 ( 381) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    17009472, /* 15973 ( 381) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  0]  1 */
    35432762, /* 15974 ( 381) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  0] -1 */
    52451994, /* 15975 ( 381) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
     1433496, /* 15976 ( 381) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  0]  1 */
    51034658, /* 15977 ( 381) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  0] -1 */
       16484, /* 15978 ( 382) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    18426488, /* 15979 ( 382) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    35445882, /* 15980 ( 382) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  0] -1 */
    34028546, /* 15981 ( 382) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    17009472, /* 15982 ( 382) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  0]  1 */
    51034820, /* 15983 ( 382) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  0] -1 */
    52438874, /* 15984 ( 382) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
    34015584, /* 15985 ( 382) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    35432600, /* 15986 ( 382) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  0] -1 */
    17022434, /* 15987 ( 382) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  0]  1 */
        3198, /* 15988 ( 382) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    51021534, /* 15989 ( 382) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  0] -1 */
    18439770, /* 15990 ( 382) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
     1433496, /* 15991 ( 382) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  0]  1 */
     1420538, /* 15992 ( 382) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  0]  1 */
    52451832, /* 15993 ( 382) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
       16484, /* 15994 ( 383) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    18426488, /* 15995 ( 383) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    51139794, /* 15996 ( 383) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6] -1 */
    52556810, /* 15997 ( 383) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    35563818, /* 15998 ( 383) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  6] -1 */
    17009472, /* 15999 ( 383) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  0]  1 */
    35550860, /* 16000 ( 383) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
    51152756, /* 16001 ( 383) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
    17022434, /* 16002 ( 383) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  0]  1 */
    34133520, /* 16003 ( 383) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
        3198, /* 16004 ( 383) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    34146806, /* 16005 ( 383) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    18439770, /* 16006 ( 383) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
     1433496, /* 16007 ( 383) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  0]  1 */
    52570092, /* 16008 ( 383) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
     1420538, /* 16009 ( 383) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  0]  1 */
       16484, /* 16010 ( 384) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    18426488, /* 16011 ( 384) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    35550696, /* 16012 ( 384) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  6] -1 */
    17009472, /* 16013 ( 384) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  0]  1 */
    52569932, /* 16014 ( 384) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    17022434, /* 16015 ( 384) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  0]  1 */
    51139634, /* 16016 ( 384) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
    35563982, /* 16017 ( 384) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
        3198, /* 16018 ( 384) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    34133684, /* 16019 ( 384) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    52556970, /* 16020 ( 384) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    18439770, /* 16021 ( 384) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
    34146642, /* 16022 ( 384) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
     1433496, /* 16023 ( 384) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  0]  1 */
    51152916, /* 16024 ( 384) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6] -1 */
     1420538, /* 16025 ( 384) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  0]  1 */
       16484, /* 16026 ( 385) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    18426488, /* 16027 ( 385) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    52438710, /* 16028 ( 385) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
    17009472, /* 16029 ( 385) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  0]  1 */
    51021698, /* 16030 ( 385) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  0] -1 */
    51034656, /* 16031 ( 385) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  0] -1 */
    17022434, /* 16032 ( 385) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  0]  1 */
    34028706, /* 16033 ( 385) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    35432760, /* 16034 ( 385) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  0] -1 */
    52451996, /* 16035 ( 385) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
        3198, /* 16036 ( 385) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    35445722, /* 16037 ( 385) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  0] -1 */
    18439770, /* 16038 ( 385) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
     1433496, /* 16039 ( 385) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  0]  1 */
     1420538, /* 16040 ( 385) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  0]  1 */
    34015424, /* 16041 ( 385) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
       16484, /* 16042 ( 386) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    18426488, /* 16043 ( 386) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    34133522, /* 16044 ( 386) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    17009472, /* 16045 ( 386) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  0]  1 */
    35550858, /* 16046 ( 386) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6] -1 */
     1420538, /* 16047 ( 386) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  0]  1 */
    17022434, /* 16048 ( 386) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  0]  1 */
    51139796, /* 16049 ( 386) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
        3198, /* 16050 ( 386) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    51152754, /* 16051 ( 386) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  6] -1 */
    18439770, /* 16052 ( 386) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
     1433496, /* 16053 ( 386) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  0]  1 */
    34146804, /* 16054 ( 386) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
    52570094, /* 16055 ( 386) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    35563820, /* 16056 ( 386) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
    52556808, /* 16057 ( 386) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
       16484, /* 16058 ( 375) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
       16320, /* 16059 ( 375) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
        3200, /* 16060 ( 375) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
     1551756, /* 16061 ( 375) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
     1538472, /* 16062 ( 375) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
     1538636, /* 16063 ( 375) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
        3360, /* 16064 ( 375) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
     1551596, /* 16065 ( 375) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
       16484, /* 16066 ( 376) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
       16320, /* 16067 ( 376) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    35550696, /* 16068 ( 376) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  6] -1 */
        3200, /* 16069 ( 376) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34015424, /* 16070 ( 376) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
     1551756, /* 16071 ( 376) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
    35563820, /* 16072 ( 376) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
    35550860, /* 16073 ( 376) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
    34015584, /* 16074 ( 376) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
     1538472, /* 16075 ( 376) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
     1538636, /* 16076 ( 376) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
        3360, /* 16077 ( 376) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    34028544, /* 16078 ( 376) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    34028708, /* 16079 ( 376) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
     1551596, /* 16080 ( 376) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
    35563980, /* 16081 ( 376) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6] -1 */
       16484, /* 16082 ( 377) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34028544, /* 16083 ( 377) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    35550696, /* 16084 ( 377) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  6] -1 */
     1551756, /* 16085 ( 377) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
    35563820, /* 16086 ( 377) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
     1538636, /* 16087 ( 377) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
        3360, /* 16088 ( 377) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    34015424, /* 16089 ( 377) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
       16484, /* 16090 ( 378) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
       16320, /* 16091 ( 378) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    35550696, /* 16092 ( 378) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  6] -1 */
     1551756, /* 16093 ( 378) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
    35550860, /* 16094 ( 378) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
    34015584, /* 16095 ( 378) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    34015424, /* 16096 ( 378) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
     1551596, /* 16097 ( 378) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
       16484, /* 16098 ( 379) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
       16320, /* 16099 ( 379) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    35563820, /* 16100 ( 379) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
    34015584, /* 16101 ( 379) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
     1538472, /* 16102 ( 379) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
     1538636, /* 16103 ( 379) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
    34015424, /* 16104 ( 379) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    35563980, /* 16105 ( 379) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6] -1 */
       16484, /* 16106 ( 380) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
        3200, /* 16107 ( 380) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
     1551756, /* 16108 ( 380) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
    35563820, /* 16109 ( 380) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
    35550860, /* 16110 ( 380) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
    34015584, /* 16111 ( 380) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
     1538472, /* 16112 ( 380) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
    34028544, /* 16113 ( 380) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
       16484, /* 16114 ( 381) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
       16320, /* 16115 ( 381) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    35550696, /* 16116 ( 381) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  6] -1 */
        3200, /* 16117 ( 381) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    35563820, /* 16118 ( 381) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
    35550860, /* 16119 ( 381) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
        3360, /* 16120 ( 381) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    35563980, /* 16121 ( 381) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6] -1 */
       16484, /* 16122 ( 382) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
       16320, /* 16123 ( 382) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    34133684, /* 16124 ( 382) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    34146804, /* 16125 ( 382) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
        3200, /* 16126 ( 382) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    35445884, /* 16127 ( 382) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  0] -1 */
    34146644, /* 16128 ( 382) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    35432600, /* 16129 ( 382) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  0] -1 */
    35445720, /* 16130 ( 382) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  0] -1 */
     1551756, /* 16131 ( 382) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
     1538472, /* 16132 ( 382) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
    34133520, /* 16133 ( 382) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
     1538636, /* 16134 ( 382) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
        3360, /* 16135 ( 382) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
     1551596, /* 16136 ( 382) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
    35432760, /* 16137 ( 382) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  0] -1 */
       16484, /* 16138 ( 383) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
       16320, /* 16139 ( 383) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    51021536, /* 16140 ( 383) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  0] -1 */
    51034656, /* 16141 ( 383) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  0] -1 */
    51021696, /* 16142 ( 383) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  0] -1 */
        3200, /* 16143 ( 383) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    52569932, /* 16144 ( 383) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    52570092, /* 16145 ( 383) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
     1551756, /* 16146 ( 383) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
    52556808, /* 16147 ( 383) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
     1538472, /* 16148 ( 383) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
    51034820, /* 16149 ( 383) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  0] -1 */
     1538636, /* 16150 ( 383) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
        3360, /* 16151 ( 383) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    52556972, /* 16152 ( 383) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
     1551596, /* 16153 ( 383) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
       16484, /* 16154 ( 384) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
       16320, /* 16155 ( 384) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    52438710, /* 16156 ( 384) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
        3200, /* 16157 ( 384) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    52451994, /* 16158 ( 384) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
     1551756, /* 16159 ( 384) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
    51152754, /* 16160 ( 384) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  6] -1 */
    51152918, /* 16161 ( 384) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
     1538472, /* 16162 ( 384) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
    52451834, /* 16163 ( 384) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
    51139634, /* 16164 ( 384) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
     1538636, /* 16165 ( 384) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
    51139794, /* 16166 ( 384) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6] -1 */
        3360, /* 16167 ( 384) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    52438874, /* 16168 ( 384) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
     1551596, /* 16169 ( 384) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
       16484, /* 16170 ( 385) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
       16320, /* 16171 ( 385) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    34015422, /* 16172 ( 385) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
        3200, /* 16173 ( 385) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34028546, /* 16174 ( 385) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    35550858, /* 16175 ( 385) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6] -1 */
     1551756, /* 16176 ( 385) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
    34015586, /* 16177 ( 385) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    35550698, /* 16178 ( 385) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
    35563982, /* 16179 ( 385) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
     1538472, /* 16180 ( 385) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
    34028706, /* 16181 ( 385) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
     1538636, /* 16182 ( 385) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
        3360, /* 16183 ( 385) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
     1551596, /* 16184 ( 385) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
    35563818, /* 16185 ( 385) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  6] -1 */
       16484, /* 16186 ( 386) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
       16320, /* 16187 ( 386) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    52569930, /* 16188 ( 386) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
        3200, /* 16189 ( 386) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    52556810, /* 16190 ( 386) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
     1551596, /* 16191 ( 386) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
     1551756, /* 16192 ( 386) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
    51034658, /* 16193 ( 386) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  0] -1 */
     1538472, /* 16194 ( 386) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
    52556970, /* 16195 ( 386) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
     1538636, /* 16196 ( 386) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
        3360, /* 16197 ( 386) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    51021698, /* 16198 ( 386) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  0] -1 */
    52570094, /* 16199 ( 386) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    51034818, /* 16200 ( 386) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  0] -1 */
    51021534, /* 16201 ( 386) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  0] -1 */
       16484, /* 16202 ( 375) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
     1551594, /* 16203 ( 375) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
     1420376, /* 16204 ( 375) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  0]  1 */
     1433658, /* 16205 ( 375) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  0]  1 */
        3198, /* 16206 ( 375) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
     1538636, /* 16207 ( 375) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
      121458, /* 16208 ( 375) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  6]  1 */
      134420, /* 16209 ( 375) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6]  1 */
       16484, /* 16210 ( 376) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
     1551594, /* 16211 ( 376) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
    34015422, /* 16212 ( 376) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
     1420376, /* 16213 ( 376) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  0]  1 */
    35432600, /* 16214 ( 376) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  0] -1 */
     1433658, /* 16215 ( 376) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  0]  1 */
    34146644, /* 16216 ( 376) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    35550860, /* 16217 ( 376) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
    34133682, /* 16218 ( 376) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
        3198, /* 16219 ( 376) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
     1538636, /* 16220 ( 376) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
      121458, /* 16221 ( 376) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  6]  1 */
    35563818, /* 16222 ( 376) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  6] -1 */
    34028708, /* 16223 ( 376) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
      134420, /* 16224 ( 376) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6]  1 */
    35445882, /* 16225 ( 376) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  0] -1 */
       16484, /* 16226 ( 377) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    35563818, /* 16227 ( 377) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  6] -1 */
    34015422, /* 16228 ( 377) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
     1433658, /* 16229 ( 377) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  0]  1 */
    34146644, /* 16230 ( 377) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
     1538636, /* 16231 ( 377) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
      121458, /* 16232 ( 377) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  6]  1 */
    35432600, /* 16233 ( 377) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  0] -1 */
       16484, /* 16234 ( 378) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
     1551594, /* 16235 ( 378) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
    34015422, /* 16236 ( 378) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
     1433658, /* 16237 ( 378) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  0]  1 */
    35550860, /* 16238 ( 378) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
    34133682, /* 16239 ( 378) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
    35432600, /* 16240 ( 378) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  0] -1 */
      134420, /* 16241 ( 378) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6]  1 */
       16484, /* 16242 ( 379) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
     1551594, /* 16243 ( 379) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
    34146644, /* 16244 ( 379) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    34133682, /* 16245 ( 379) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
        3198, /* 16246 ( 379) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
     1538636, /* 16247 ( 379) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
    35432600, /* 16248 ( 379) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  0] -1 */
    35445882, /* 16249 ( 379) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  0] -1 */
       16484, /* 16250 ( 380) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
     1420376, /* 16251 ( 380) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  0]  1 */
     1433658, /* 16252 ( 380) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  0]  1 */
    34146644, /* 16253 ( 380) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    35550860, /* 16254 ( 380) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
    34133682, /* 16255 ( 380) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
        3198, /* 16256 ( 380) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    35563818, /* 16257 ( 380) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  6] -1 */
       16484, /* 16258 ( 381) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
     1551594, /* 16259 ( 381) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
    34015422, /* 16260 ( 381) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
     1420376, /* 16261 ( 381) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  0]  1 */
    34146644, /* 16262 ( 381) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    35550860, /* 16263 ( 381) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
      121458, /* 16264 ( 381) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  6]  1 */
    35445882, /* 16265 ( 381) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  0] -1 */
       16484, /* 16266 ( 382) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
     1551594, /* 16267 ( 382) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
    34133684, /* 16268 ( 382) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    34028706, /* 16269 ( 382) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
     1420376, /* 16270 ( 382) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  0]  1 */
    35445884, /* 16271 ( 382) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  0] -1 */
    35563820, /* 16272 ( 382) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
    34015424, /* 16273 ( 382) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    34146642, /* 16274 ( 382) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
     1433658, /* 16275 ( 382) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  0]  1 */
        3198, /* 16276 ( 382) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    35432598, /* 16277 ( 382) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  0] -1 */
     1538636, /* 16278 ( 382) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
      121458, /* 16279 ( 382) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  6]  1 */
      134420, /* 16280 ( 382) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6]  1 */
    35550858, /* 16281 ( 382) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6] -1 */
       16484, /* 16282 ( 383) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
     1551594, /* 16283 ( 383) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
    52438712, /* 16284 ( 383) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
    52569930, /* 16285 ( 383) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    51139794, /* 16286 ( 383) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6] -1 */
     1420376, /* 16287 ( 383) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  0]  1 */
    51152756, /* 16288 ( 383) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
    52451994, /* 16289 ( 383) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
     1433658, /* 16290 ( 383) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  0]  1 */
    51021534, /* 16291 ( 383) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  0] -1 */
        3198, /* 16292 ( 383) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    51034820, /* 16293 ( 383) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  0] -1 */
     1538636, /* 16294 ( 383) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
      121458, /* 16295 ( 383) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  6]  1 */
    52556972, /* 16296 ( 383) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
      134420, /* 16297 ( 383) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6]  1 */
       16484, /* 16298 ( 384) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
     1551594, /* 16299 ( 384) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
    51139632, /* 16300 ( 384) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  6] -1 */
     1420376, /* 16301 ( 384) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  0]  1 */
    52570092, /* 16302 ( 384) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
     1433658, /* 16303 ( 384) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  0]  1 */
    52451832, /* 16304 ( 384) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
    51152918, /* 16305 ( 384) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
        3198, /* 16306 ( 384) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    51034658, /* 16307 ( 384) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  0] -1 */
    52556810, /* 16308 ( 384) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
     1538636, /* 16309 ( 384) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
    51021696, /* 16310 ( 384) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  0] -1 */
      121458, /* 16311 ( 384) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  6]  1 */
    52438874, /* 16312 ( 384) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
      134420, /* 16313 ( 384) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6]  1 */
       16484, /* 16314 ( 385) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
     1551594, /* 16315 ( 385) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
    35550696, /* 16316 ( 385) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  6] -1 */
     1420376, /* 16317 ( 385) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  0]  1 */
    35445722, /* 16318 ( 385) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  0] -1 */
    35432760, /* 16319 ( 385) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  0] -1 */
     1433658, /* 16320 ( 385) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  0]  1 */
    34015586, /* 16321 ( 385) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    34133522, /* 16322 ( 385) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    35563982, /* 16323 ( 385) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
        3198, /* 16324 ( 385) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    34146804, /* 16325 ( 385) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
     1538636, /* 16326 ( 385) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
      121458, /* 16327 ( 385) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  6]  1 */
      134420, /* 16328 ( 385) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6]  1 */
    34028544, /* 16329 ( 385) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
       16484, /* 16330 ( 386) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
     1551594, /* 16331 ( 386) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
    51034656, /* 16332 ( 386) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  0] -1 */
     1420376, /* 16333 ( 386) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  0]  1 */
    51139634, /* 16334 ( 386) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
      134420, /* 16335 ( 386) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6]  1 */
     1433658, /* 16336 ( 386) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  0]  1 */
    52451834, /* 16337 ( 386) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
        3198, /* 16338 ( 386) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    52438872, /* 16339 ( 386) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
     1538636, /* 16340 ( 386) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
      121458, /* 16341 ( 386) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  6]  1 */
    51021698, /* 16342 ( 386) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  0] -1 */
    52570094, /* 16343 ( 386) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    51152916, /* 16344 ( 386) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6] -1 */
    52556808, /* 16345 ( 386) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
       16484, /* 16346 ( 375) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
        3360, /* 16347 ( 375) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
       16320, /* 16348 ( 375) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    17127572, /* 16349 ( 375) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
    17127408, /* 16350 ( 375) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  6]  1 */
    17140532, /* 16351 ( 375) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
        3200, /* 16352 ( 375) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    17140692, /* 16353 ( 375) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6]  1 */
       16484, /* 16354 ( 376) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
        3360, /* 16355 ( 376) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    51139632, /* 16356 ( 376) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  6] -1 */
       16320, /* 16357 ( 376) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    34028544, /* 16358 ( 376) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    17127572, /* 16359 ( 376) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
    51152916, /* 16360 ( 376) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6] -1 */
    51152756, /* 16361 ( 376) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
    34015424, /* 16362 ( 376) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    17127408, /* 16363 ( 376) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  6]  1 */
    17140532, /* 16364 ( 376) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
        3200, /* 16365 ( 376) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34015584, /* 16366 ( 376) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    34028708, /* 16367 ( 376) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    17140692, /* 16368 ( 376) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6]  1 */
    51139796, /* 16369 ( 376) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
       16484, /* 16370 ( 377) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34015584, /* 16371 ( 377) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    51139632, /* 16372 ( 377) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  6] -1 */
    17127572, /* 16373 ( 377) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
    51152916, /* 16374 ( 377) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6] -1 */
    17140532, /* 16375 ( 377) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
        3200, /* 16376 ( 377) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34028544, /* 16377 ( 377) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
       16484, /* 16378 ( 378) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
        3360, /* 16379 ( 378) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    51139632, /* 16380 ( 378) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  6] -1 */
    17127572, /* 16381 ( 378) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
    51152756, /* 16382 ( 378) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
    34015424, /* 16383 ( 378) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    34028544, /* 16384 ( 378) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    17140692, /* 16385 ( 378) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6]  1 */
       16484, /* 16386 ( 379) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
        3360, /* 16387 ( 379) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    51152916, /* 16388 ( 379) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6] -1 */
    34015424, /* 16389 ( 379) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    17127408, /* 16390 ( 379) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  6]  1 */
    17140532, /* 16391 ( 379) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
    34028544, /* 16392 ( 379) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    51139796, /* 16393 ( 379) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
       16484, /* 16394 ( 380) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
       16320, /* 16395 ( 380) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    17127572, /* 16396 ( 380) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
    51152916, /* 16397 ( 380) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6] -1 */
    51152756, /* 16398 ( 380) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
    34015424, /* 16399 ( 380) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    17127408, /* 16400 ( 380) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  6]  1 */
    34015584, /* 16401 ( 380) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
       16484, /* 16402 ( 381) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
        3360, /* 16403 ( 381) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    51139632, /* 16404 ( 381) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  6] -1 */
       16320, /* 16405 ( 381) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    51152916, /* 16406 ( 381) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6] -1 */
    51152756, /* 16407 ( 381) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
        3200, /* 16408 ( 381) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    51139796, /* 16409 ( 381) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
       16484, /* 16410 ( 382) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
        3360, /* 16411 ( 382) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    51034658, /* 16412 ( 382) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  0] -1 */
    51021698, /* 16413 ( 382) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  0] -1 */
       16320, /* 16414 ( 382) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    34146806, /* 16415 ( 382) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    51034818, /* 16416 ( 382) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  0] -1 */
    34146642, /* 16417 ( 382) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
    34133682, /* 16418 ( 382) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
    17127572, /* 16419 ( 382) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
    17127408, /* 16420 ( 382) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  6]  1 */
    51021534, /* 16421 ( 382) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  0] -1 */
    17140532, /* 16422 ( 382) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
        3200, /* 16423 ( 382) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    17140692, /* 16424 ( 382) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6]  1 */
    34133522, /* 16425 ( 382) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
       16484, /* 16426 ( 383) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
        3360, /* 16427 ( 383) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    35445720, /* 16428 ( 383) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  0] -1 */
    35432760, /* 16429 ( 383) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  0] -1 */
    35432600, /* 16430 ( 383) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  0] -1 */
       16320, /* 16431 ( 383) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    52570092, /* 16432 ( 383) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    52556972, /* 16433 ( 383) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    17127572, /* 16434 ( 383) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
    52556808, /* 16435 ( 383) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    17127408, /* 16436 ( 383) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  6]  1 */
    35445884, /* 16437 ( 383) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  0] -1 */
    17140532, /* 16438 ( 383) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
        3200, /* 16439 ( 383) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    52569932, /* 16440 ( 383) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    17140692, /* 16441 ( 383) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6]  1 */
       16484, /* 16442 ( 384) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
        3360, /* 16443 ( 384) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    35550696, /* 16444 ( 384) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  6] -1 */
       16320, /* 16445 ( 384) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    35550860, /* 16446 ( 384) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
    17127572, /* 16447 ( 384) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
    52438872, /* 16448 ( 384) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
    52451996, /* 16449 ( 384) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
    17127408, /* 16450 ( 384) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  6]  1 */
    35563980, /* 16451 ( 384) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6] -1 */
    52451832, /* 16452 ( 384) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
    17140532, /* 16453 ( 384) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
    52438712, /* 16454 ( 384) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
        3200, /* 16455 ( 384) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    35563820, /* 16456 ( 384) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
    17140692, /* 16457 ( 384) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6]  1 */
       16484, /* 16458 ( 385) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
        3360, /* 16459 ( 385) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    34015422, /* 16460 ( 385) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
       16320, /* 16461 ( 385) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    34028706, /* 16462 ( 385) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    51139634, /* 16463 ( 385) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
    17127572, /* 16464 ( 385) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
    34028546, /* 16465 ( 385) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    51152754, /* 16466 ( 385) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  6] -1 */
    51152918, /* 16467 ( 385) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
    17127408, /* 16468 ( 385) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  6]  1 */
    34015586, /* 16469 ( 385) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    17140532, /* 16470 ( 385) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
        3200, /* 16471 ( 385) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    17140692, /* 16472 ( 385) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6]  1 */
    51139794, /* 16473 ( 385) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6] -1 */
       16484, /* 16474 ( 386) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
        3360, /* 16475 ( 386) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    52556970, /* 16476 ( 386) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
       16320, /* 16477 ( 386) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    52569930, /* 16478 ( 386) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    17140692, /* 16479 ( 386) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6]  1 */
    17127572, /* 16480 ( 386) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
    35445882, /* 16481 ( 386) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  0] -1 */
    17127408, /* 16482 ( 386) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  6]  1 */
    52556810, /* 16483 ( 386) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    17140532, /* 16484 ( 386) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
        3200, /* 16485 ( 386) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    35445722, /* 16486 ( 386) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  0] -1 */
    52570094, /* 16487 ( 386) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    35432762, /* 16488 ( 386) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  0] -1 */
    35432598, /* 16489 ( 386) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  0] -1 */
       16484, /* 16490 ( 375) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    17127570, /* 16491 ( 375) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6]  1 */
      134418, /* 16492 ( 375) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  6]  1 */
      121460, /* 16493 ( 375) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6]  1 */
        3198, /* 16494 ( 375) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    17140532, /* 16495 ( 375) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
    17009312, /* 16496 ( 375) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  0]  1 */
    17022594, /* 16497 ( 375) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  0]  1 */
       16484, /* 16498 ( 376) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    17127570, /* 16499 ( 376) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6]  1 */
    34015422, /* 16500 ( 376) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
      134418, /* 16501 ( 376) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  6]  1 */
    34146642, /* 16502 ( 376) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
      121460, /* 16503 ( 376) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6]  1 */
    51034818, /* 16504 ( 376) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  0] -1 */
    51152756, /* 16505 ( 376) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
    51021536, /* 16506 ( 376) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  0] -1 */
        3198, /* 16507 ( 376) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    17140532, /* 16508 ( 376) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
    17009312, /* 16509 ( 376) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  0]  1 */
    51139794, /* 16510 ( 376) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6] -1 */
    34028708, /* 16511 ( 376) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    17022594, /* 16512 ( 376) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  0]  1 */
    34133684, /* 16513 ( 376) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
       16484, /* 16514 ( 377) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    51139794, /* 16515 ( 377) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6] -1 */
    34015422, /* 16516 ( 377) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
      121460, /* 16517 ( 377) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6]  1 */
    51034818, /* 16518 ( 377) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  0] -1 */
    17140532, /* 16519 ( 377) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
    17009312, /* 16520 ( 377) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  0]  1 */
    34146642, /* 16521 ( 377) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
       16484, /* 16522 ( 378) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    17127570, /* 16523 ( 378) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6]  1 */
    34015422, /* 16524 ( 378) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
      121460, /* 16525 ( 378) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6]  1 */
    51152756, /* 16526 ( 378) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
    51021536, /* 16527 ( 378) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  0] -1 */
    34146642, /* 16528 ( 378) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
    17022594, /* 16529 ( 378) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  0]  1 */
       16484, /* 16530 ( 379) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    17127570, /* 16531 ( 379) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6]  1 */
    51034818, /* 16532 ( 379) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  0] -1 */
    51021536, /* 16533 ( 379) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  0] -1 */
        3198, /* 16534 ( 379) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    17140532, /* 16535 ( 379) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
    34146642, /* 16536 ( 379) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
    34133684, /* 16537 ( 379) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
       16484, /* 16538 ( 380) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
      134418, /* 16539 ( 380) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  6]  1 */
      121460, /* 16540 ( 380) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6]  1 */
    51034818, /* 16541 ( 380) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  0] -1 */
    51152756, /* 16542 ( 380) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
    51021536, /* 16543 ( 380) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  0] -1 */
        3198, /* 16544 ( 380) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    51139794, /* 16545 ( 380) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6] -1 */
       16484, /* 16546 ( 381) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    17127570, /* 16547 ( 381) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6]  1 */
    34015422, /* 16548 ( 381) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
      134418, /* 16549 ( 381) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  6]  1 */
    51034818, /* 16550 ( 381) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  0] -1 */
    51152756, /* 16551 ( 381) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
    17009312, /* 16552 ( 381) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  0]  1 */
    34133684, /* 16553 ( 381) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
       16484, /* 16554 ( 382) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    17127570, /* 16555 ( 382) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6]  1 */
    51034658, /* 16556 ( 382) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  0] -1 */
    34015586, /* 16557 ( 382) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
      134418, /* 16558 ( 382) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  6]  1 */
    34146806, /* 16559 ( 382) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    51152916, /* 16560 ( 382) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6] -1 */
    34028544, /* 16561 ( 382) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    51021696, /* 16562 ( 382) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  0] -1 */
      121460, /* 16563 ( 382) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6]  1 */
        3198, /* 16564 ( 382) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    34133520, /* 16565 ( 382) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
    17140532, /* 16566 ( 382) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
    17009312, /* 16567 ( 382) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  0]  1 */
    17022594, /* 16568 ( 382) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  0]  1 */
    51139634, /* 16569 ( 382) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
       16484, /* 16570 ( 383) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    17127570, /* 16571 ( 383) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6]  1 */
    35563818, /* 16572 ( 383) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  6] -1 */
    52556970, /* 16573 ( 383) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    52438712, /* 16574 ( 383) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
      134418, /* 16575 ( 383) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  6]  1 */
    52451994, /* 16576 ( 383) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
    35550860, /* 16577 ( 383) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
      121460, /* 16578 ( 383) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6]  1 */
    35432598, /* 16579 ( 383) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  0] -1 */
        3198, /* 16580 ( 383) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    35445884, /* 16581 ( 383) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  0] -1 */
    17140532, /* 16582 ( 383) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
    17009312, /* 16583 ( 383) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  0]  1 */
    52569932, /* 16584 ( 383) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    17022594, /* 16585 ( 383) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  0]  1 */
       16484, /* 16586 ( 384) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    17127570, /* 16587 ( 384) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6]  1 */
    52438710, /* 16588 ( 384) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
      134418, /* 16589 ( 384) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  6]  1 */
    52556972, /* 16590 ( 384) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
      121460, /* 16591 ( 384) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6]  1 */
    35550858, /* 16592 ( 384) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6] -1 */
    52451996, /* 16593 ( 384) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
        3198, /* 16594 ( 384) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    35445882, /* 16595 ( 384) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  0] -1 */
    52569930, /* 16596 ( 384) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    17140532, /* 16597 ( 384) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
    35432600, /* 16598 ( 384) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  0] -1 */
    17009312, /* 16599 ( 384) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  0]  1 */
    35563820, /* 16600 ( 384) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
    17022594, /* 16601 ( 384) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  0]  1 */
       16484, /* 16602 ( 385) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    17127570, /* 16603 ( 385) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6]  1 */
    51139632, /* 16604 ( 385) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  6] -1 */
      134418, /* 16605 ( 385) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  6]  1 */
    34146804, /* 16606 ( 385) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
    34133522, /* 16607 ( 385) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
      121460, /* 16608 ( 385) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6]  1 */
    34028546, /* 16609 ( 385) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    51034656, /* 16610 ( 385) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  0] -1 */
    51152918, /* 16611 ( 385) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
        3198, /* 16612 ( 385) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    51021698, /* 16613 ( 385) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  0] -1 */
    17140532, /* 16614 ( 385) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
    17009312, /* 16615 ( 385) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  0]  1 */
    17022594, /* 16616 ( 385) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  0]  1 */
    34015584, /* 16617 ( 385) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
       16484, /* 16618 ( 386) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    17127570, /* 16619 ( 386) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6]  1 */
    35432760, /* 16620 ( 386) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  0] -1 */
      134418, /* 16621 ( 386) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  6]  1 */
    52451832, /* 16622 ( 386) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
    17022594, /* 16623 ( 386) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  0]  1 */
      121460, /* 16624 ( 386) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6]  1 */
    35563980, /* 16625 ( 386) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6] -1 */
        3198, /* 16626 ( 386) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    35550698, /* 16627 ( 386) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
    17140532, /* 16628 ( 386) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
    17009312, /* 16629 ( 386) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  0]  1 */
    35445722, /* 16630 ( 386) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  0] -1 */
    52570094, /* 16631 ( 386) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    52438874, /* 16632 ( 386) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
    52556808, /* 16633 ( 386) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
       16484, /* 16634 ( 387) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    17009312, /* 16635 ( 387) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  0]  1 */
        3198, /* 16636 ( 387) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    17022432, /* 16637 ( 387) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  0]  1 */
    17009474, /* 16638 ( 387) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  0]  1 */
        3360, /* 16639 ( 387) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    17022594, /* 16640 ( 387) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  0]  1 */
       16322, /* 16641 ( 387) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
       16484, /* 16642 ( 388) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34015422, /* 16643 ( 388) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    17009312, /* 16644 ( 388) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  0]  1 */
    51021698, /* 16645 ( 388) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  0] -1 */
    51034656, /* 16646 ( 388) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  0] -1 */
    34015584, /* 16647 ( 388) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    51034818, /* 16648 ( 388) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  0] -1 */
        3198, /* 16649 ( 388) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    17022432, /* 16650 ( 388) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  0]  1 */
    17009474, /* 16651 ( 388) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  0]  1 */
    51021536, /* 16652 ( 388) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  0] -1 */
    34028546, /* 16653 ( 388) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
        3360, /* 16654 ( 388) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    34028708, /* 16655 ( 388) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    17022594, /* 16656 ( 388) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  0]  1 */
       16322, /* 16657 ( 388) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
       16484, /* 16658 ( 389) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34015422, /* 16659 ( 389) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    51021698, /* 16660 ( 389) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  0] -1 */
    34015584, /* 16661 ( 389) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    17022432, /* 16662 ( 389) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  0]  1 */
    51021536, /* 16663 ( 389) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  0] -1 */
    17022594, /* 16664 ( 389) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  0]  1 */
       16322, /* 16665 ( 389) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
       16484, /* 16666 ( 390) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34015422, /* 16667 ( 390) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    51034656, /* 16668 ( 390) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  0] -1 */
    17009474, /* 16669 ( 390) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  0]  1 */
    51021536, /* 16670 ( 390) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  0] -1 */
    34028546, /* 16671 ( 390) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
        3360, /* 16672 ( 390) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    17022594, /* 16673 ( 390) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  0]  1 */
       16484, /* 16674 ( 391) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34015422, /* 16675 ( 391) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    17009312, /* 16676 ( 391) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  0]  1 */
    34015584, /* 16677 ( 391) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    51034656, /* 16678 ( 391) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  0] -1 */
    51034818, /* 16679 ( 391) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  0] -1 */
    17009474, /* 16680 ( 391) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  0]  1 */
       16322, /* 16681 ( 391) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
       16484, /* 16682 ( 392) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    17009312, /* 16683 ( 392) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  0]  1 */
    51021698, /* 16684 ( 392) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  0] -1 */
    51034656, /* 16685 ( 392) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  0] -1 */
    34015584, /* 16686 ( 392) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
        3198, /* 16687 ( 392) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    34028546, /* 16688 ( 392) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    17022594, /* 16689 ( 392) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  0]  1 */
       16484, /* 16690 ( 393) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34015584, /* 16691 ( 393) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    51034818, /* 16692 ( 393) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  0] -1 */
        3198, /* 16693 ( 393) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    17022432, /* 16694 ( 393) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  0]  1 */
    17009474, /* 16695 ( 393) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  0]  1 */
    51021536, /* 16696 ( 393) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  0] -1 */
    34028546, /* 16697 ( 393) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
       16484, /* 16698 ( 394) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    51021698, /* 16699 ( 394) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  0] -1 */
    51034656, /* 16700 ( 394) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  0] -1 */
    51034818, /* 16701 ( 394) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  0] -1 */
        3198, /* 16702 ( 394) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    51021536, /* 16703 ( 394) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  0] -1 */
        3360, /* 16704 ( 394) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
       16322, /* 16705 ( 394) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
       16484, /* 16706 ( 395) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34015422, /* 16707 ( 395) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    17009312, /* 16708 ( 395) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  0]  1 */
    51021698, /* 16709 ( 395) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  0] -1 */
    51034818, /* 16710 ( 395) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  0] -1 */
    17022432, /* 16711 ( 395) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  0]  1 */
    34028546, /* 16712 ( 395) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
        3360, /* 16713 ( 395) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
       16484, /* 16714 ( 396) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34015586, /* 16715 ( 396) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    17009312, /* 16716 ( 396) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  0]  1 */
    51034820, /* 16717 ( 396) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  0] -1 */
    51021696, /* 16718 ( 396) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  0] -1 */
    51034658, /* 16719 ( 396) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  0] -1 */
    34028706, /* 16720 ( 396) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
        3198, /* 16721 ( 396) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    17022432, /* 16722 ( 396) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  0]  1 */
    51021534, /* 16723 ( 396) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  0] -1 */
    17009474, /* 16724 ( 396) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  0]  1 */
    34015424, /* 16725 ( 396) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
        3360, /* 16726 ( 396) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    17022594, /* 16727 ( 396) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  0]  1 */
    34028544, /* 16728 ( 396) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
       16322, /* 16729 ( 396) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
       16484, /* 16730 ( 397) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    52438712, /* 16731 ( 397) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
    17009312, /* 16732 ( 397) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  0]  1 */
    52438874, /* 16733 ( 397) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
    35432760, /* 16734 ( 397) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  0] -1 */
    52451994, /* 16735 ( 397) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
        3198, /* 16736 ( 397) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    17022432, /* 16737 ( 397) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  0]  1 */
    35445722, /* 16738 ( 397) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  0] -1 */
    35445884, /* 16739 ( 397) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  0] -1 */
    17009474, /* 16740 ( 397) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  0]  1 */
    35432598, /* 16741 ( 397) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  0] -1 */
        3360, /* 16742 ( 397) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    17022594, /* 16743 ( 397) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  0]  1 */
    52451832, /* 16744 ( 397) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
       16322, /* 16745 ( 397) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
       16484, /* 16746 ( 398) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    17009312, /* 16747 ( 398) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  0]  1 */
    34146644, /* 16748 ( 398) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    51139634, /* 16749 ( 398) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
    34133520, /* 16750 ( 398) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
    51139796, /* 16751 ( 398) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
        3198, /* 16752 ( 398) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    17022432, /* 16753 ( 398) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  0]  1 */
    34146806, /* 16754 ( 398) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    51152754, /* 16755 ( 398) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  6] -1 */
    17009474, /* 16756 ( 398) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  0]  1 */
    51152916, /* 16757 ( 398) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6] -1 */
    34133682, /* 16758 ( 398) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
        3360, /* 16759 ( 398) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    17022594, /* 16760 ( 398) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  0]  1 */
       16322, /* 16761 ( 398) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
       16484, /* 16762 ( 399) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    35550696, /* 16763 ( 399) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  6] -1 */
    52556810, /* 16764 ( 399) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    17009312, /* 16765 ( 399) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  0]  1 */
    35550858, /* 16766 ( 399) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6] -1 */
    35563982, /* 16767 ( 399) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
        3198, /* 16768 ( 399) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    17022432, /* 16769 ( 399) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  0]  1 */
    52556972, /* 16770 ( 399) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    17009474, /* 16771 ( 399) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  0]  1 */
    52569930, /* 16772 ( 399) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
        3360, /* 16773 ( 399) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    52570092, /* 16774 ( 399) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    17022594, /* 16775 ( 399) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  0]  1 */
    35563820, /* 16776 ( 399) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
       16322, /* 16777 ( 399) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
       16484, /* 16778 ( 400) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    51139794, /* 16779 ( 400) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6] -1 */
    34133522, /* 16780 ( 400) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    17009312, /* 16781 ( 400) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  0]  1 */
    51152756, /* 16782 ( 400) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
    51139632, /* 16783 ( 400) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  6] -1 */
    34146804, /* 16784 ( 400) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
        3198, /* 16785 ( 400) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    17022432, /* 16786 ( 400) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  0]  1 */
    34133684, /* 16787 ( 400) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    17009474, /* 16788 ( 400) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  0]  1 */
    34146642, /* 16789 ( 400) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
    51152918, /* 16790 ( 400) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
        3360, /* 16791 ( 400) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    17022594, /* 16792 ( 400) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  0]  1 */
       16322, /* 16793 ( 400) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
       16484, /* 16794 ( 401) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    52451834, /* 16795 ( 401) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
    35445882, /* 16796 ( 401) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  0] -1 */
    17009312, /* 16797 ( 401) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  0]  1 */
    52438710, /* 16798 ( 401) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
    35432600, /* 16799 ( 401) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  0] -1 */
    35432762, /* 16800 ( 401) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  0] -1 */
    52451996, /* 16801 ( 401) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
        3198, /* 16802 ( 401) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    17022432, /* 16803 ( 401) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  0]  1 */
    35445720, /* 16804 ( 401) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  0] -1 */
    17009474, /* 16805 ( 401) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  0]  1 */
        3360, /* 16806 ( 401) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    52438872, /* 16807 ( 401) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
    17022594, /* 16808 ( 401) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  0]  1 */
       16322, /* 16809 ( 401) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
       16484, /* 16810 ( 402) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    17009312, /* 16811 ( 402) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  0]  1 */
    35563818, /* 16812 ( 402) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  6] -1 */
    35550860, /* 16813 ( 402) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
       16322, /* 16814 ( 402) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    52569932, /* 16815 ( 402) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    35563980, /* 16816 ( 402) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6] -1 */
        3198, /* 16817 ( 402) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    17022432, /* 16818 ( 402) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  0]  1 */
    52556970, /* 16819 ( 402) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    17009474, /* 16820 ( 402) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  0]  1 */
    35550698, /* 16821 ( 402) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
        3360, /* 16822 ( 402) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    17022594, /* 16823 ( 402) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  0]  1 */
    52570094, /* 16824 ( 402) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    52556808, /* 16825 ( 402) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
       16484, /* 16826 ( 387) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
     1420376, /* 16827 ( 387) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  0]  1 */
        3198, /* 16828 ( 387) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
     1420536, /* 16829 ( 387) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  0]  1 */
     1433498, /* 16830 ( 387) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  0]  1 */
       16320, /* 16831 ( 387) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
     1433658, /* 16832 ( 387) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  0]  1 */
        3362, /* 16833 ( 387) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
       16484, /* 16834 ( 388) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34015422, /* 16835 ( 388) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
     1420376, /* 16836 ( 388) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  0]  1 */
    35445722, /* 16837 ( 388) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  0] -1 */
    35432760, /* 16838 ( 388) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  0] -1 */
    34028544, /* 16839 ( 388) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    35445882, /* 16840 ( 388) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  0] -1 */
        3198, /* 16841 ( 388) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
     1420536, /* 16842 ( 388) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  0]  1 */
     1433498, /* 16843 ( 388) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  0]  1 */
    35432600, /* 16844 ( 388) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  0] -1 */
    34015586, /* 16845 ( 388) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
       16320, /* 16846 ( 388) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    34028708, /* 16847 ( 388) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
     1433658, /* 16848 ( 388) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  0]  1 */
        3362, /* 16849 ( 388) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
       16484, /* 16850 ( 389) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34015422, /* 16851 ( 389) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    35445722, /* 16852 ( 389) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  0] -1 */
    34028544, /* 16853 ( 389) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
     1420536, /* 16854 ( 389) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  0]  1 */
    35432600, /* 16855 ( 389) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  0] -1 */
     1433658, /* 16856 ( 389) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  0]  1 */
        3362, /* 16857 ( 389) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
       16484, /* 16858 ( 390) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34015422, /* 16859 ( 390) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    35432760, /* 16860 ( 390) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  0] -1 */
     1433498, /* 16861 ( 390) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  0]  1 */
    35432600, /* 16862 ( 390) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  0] -1 */
    34015586, /* 16863 ( 390) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
       16320, /* 16864 ( 390) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
     1433658, /* 16865 ( 390) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  0]  1 */
       16484, /* 16866 ( 391) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34015422, /* 16867 ( 391) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
     1420376, /* 16868 ( 391) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  0]  1 */
    34028544, /* 16869 ( 391) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    35432760, /* 16870 ( 391) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  0] -1 */
    35445882, /* 16871 ( 391) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  0] -1 */
     1433498, /* 16872 ( 391) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  0]  1 */
        3362, /* 16873 ( 391) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
       16484, /* 16874 ( 392) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
     1420376, /* 16875 ( 392) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  0]  1 */
    35445722, /* 16876 ( 392) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  0] -1 */
    35432760, /* 16877 ( 392) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  0] -1 */
    34028544, /* 16878 ( 392) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
        3198, /* 16879 ( 392) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    34015586, /* 16880 ( 392) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
     1433658, /* 16881 ( 392) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  0]  1 */
       16484, /* 16882 ( 393) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34028544, /* 16883 ( 393) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    35445882, /* 16884 ( 393) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  0] -1 */
        3198, /* 16885 ( 393) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
     1420536, /* 16886 ( 393) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  0]  1 */
     1433498, /* 16887 ( 393) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  0]  1 */
    35432600, /* 16888 ( 393) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  0] -1 */
    34015586, /* 16889 ( 393) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
       16484, /* 16890 ( 394) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    35445722, /* 16891 ( 394) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  0] -1 */
    35432760, /* 16892 ( 394) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  0] -1 */
    35445882, /* 16893 ( 394) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  0] -1 */
        3198, /* 16894 ( 394) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    35432600, /* 16895 ( 394) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  0] -1 */
       16320, /* 16896 ( 394) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
        3362, /* 16897 ( 394) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
       16484, /* 16898 ( 395) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34015422, /* 16899 ( 395) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
     1420376, /* 16900 ( 395) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  0]  1 */
    35445722, /* 16901 ( 395) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  0] -1 */
    35445882, /* 16902 ( 395) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  0] -1 */
     1420536, /* 16903 ( 395) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  0]  1 */
    34015586, /* 16904 ( 395) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
       16320, /* 16905 ( 395) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
       16484, /* 16906 ( 396) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34028546, /* 16907 ( 396) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
     1420376, /* 16908 ( 396) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  0]  1 */
    35445884, /* 16909 ( 396) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  0] -1 */
    35445720, /* 16910 ( 396) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  0] -1 */
    35432762, /* 16911 ( 396) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  0] -1 */
    34028706, /* 16912 ( 396) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
        3198, /* 16913 ( 396) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
     1420536, /* 16914 ( 396) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  0]  1 */
    35432598, /* 16915 ( 396) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  0] -1 */
     1433498, /* 16916 ( 396) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  0]  1 */
    34015424, /* 16917 ( 396) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
       16320, /* 16918 ( 396) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
     1433658, /* 16919 ( 396) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  0]  1 */
    34015584, /* 16920 ( 396) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
        3362, /* 16921 ( 396) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
       16484, /* 16922 ( 397) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    52438712, /* 16923 ( 397) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
     1420376, /* 16924 ( 397) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  0]  1 */
    52451834, /* 16925 ( 397) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
    51034656, /* 16926 ( 397) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  0] -1 */
    52451994, /* 16927 ( 397) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
        3198, /* 16928 ( 397) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
     1420536, /* 16929 ( 397) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  0]  1 */
    51021698, /* 16930 ( 397) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  0] -1 */
    51034820, /* 16931 ( 397) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  0] -1 */
     1433498, /* 16932 ( 397) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  0]  1 */
    51021534, /* 16933 ( 397) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  0] -1 */
       16320, /* 16934 ( 397) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
     1433658, /* 16935 ( 397) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  0]  1 */
    52438872, /* 16936 ( 397) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
        3362, /* 16937 ( 397) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
       16484, /* 16938 ( 398) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
     1420376, /* 16939 ( 398) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  0]  1 */
    34133684, /* 16940 ( 398) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    35550698, /* 16941 ( 398) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
    34133520, /* 16942 ( 398) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
    35563820, /* 16943 ( 398) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
        3198, /* 16944 ( 398) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
     1420536, /* 16945 ( 398) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  0]  1 */
    34146806, /* 16946 ( 398) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    35550858, /* 16947 ( 398) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6] -1 */
     1433498, /* 16948 ( 398) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  0]  1 */
    35563980, /* 16949 ( 398) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6] -1 */
    34146642, /* 16950 ( 398) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
       16320, /* 16951 ( 398) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
     1433658, /* 16952 ( 398) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  0]  1 */
        3362, /* 16953 ( 398) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
       16484, /* 16954 ( 399) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    51139632, /* 16955 ( 399) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  6] -1 */
    52556810, /* 16956 ( 399) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
     1420376, /* 16957 ( 399) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  0]  1 */
    51152754, /* 16958 ( 399) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  6] -1 */
    51152918, /* 16959 ( 399) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
        3198, /* 16960 ( 399) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
     1420536, /* 16961 ( 399) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  0]  1 */
    52569932, /* 16962 ( 399) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
     1433498, /* 16963 ( 399) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  0]  1 */
    52556970, /* 16964 ( 399) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
       16320, /* 16965 ( 399) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    52570092, /* 16966 ( 399) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
     1433658, /* 16967 ( 399) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  0]  1 */
    51139796, /* 16968 ( 399) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
        3362, /* 16969 ( 399) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
       16484, /* 16970 ( 400) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    35563818, /* 16971 ( 400) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  6] -1 */
    34133522, /* 16972 ( 400) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
     1420376, /* 16973 ( 400) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  0]  1 */
    35550860, /* 16974 ( 400) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
    35550696, /* 16975 ( 400) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  6] -1 */
    34146804, /* 16976 ( 400) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
        3198, /* 16977 ( 400) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
     1420536, /* 16978 ( 400) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  0]  1 */
    34146644, /* 16979 ( 400) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
     1433498, /* 16980 ( 400) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  0]  1 */
    34133682, /* 16981 ( 400) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
    35563982, /* 16982 ( 400) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
       16320, /* 16983 ( 400) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
     1433658, /* 16984 ( 400) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  0]  1 */
        3362, /* 16985 ( 400) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
       16484, /* 16986 ( 401) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    52438874, /* 16987 ( 401) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
    51034818, /* 16988 ( 401) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  0] -1 */
     1420376, /* 16989 ( 401) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  0]  1 */
    52438710, /* 16990 ( 401) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
    51021536, /* 16991 ( 401) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  0] -1 */
    51034658, /* 16992 ( 401) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  0] -1 */
    52451996, /* 16993 ( 401) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
        3198, /* 16994 ( 401) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
     1420536, /* 16995 ( 401) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  0]  1 */
    51021696, /* 16996 ( 401) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  0] -1 */
     1433498, /* 16997 ( 401) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  0]  1 */
       16320, /* 16998 ( 401) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    52451832, /* 16999 ( 401) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
     1433658, /* 17000 ( 401) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  0]  1 */
        3362, /* 17001 ( 401) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
       16484, /* 17002 ( 402) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
     1420376, /* 17003 ( 402) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  0]  1 */
    51139794, /* 17004 ( 402) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6] -1 */
    51152756, /* 17005 ( 402) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
        3362, /* 17006 ( 402) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    52556972, /* 17007 ( 402) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    51152916, /* 17008 ( 402) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6] -1 */
        3198, /* 17009 ( 402) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
     1420536, /* 17010 ( 402) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  0]  1 */
    52569930, /* 17011 ( 402) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
     1433498, /* 17012 ( 402) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  0]  1 */
    51139634, /* 17013 ( 402) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
       16320, /* 17014 ( 402) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
     1433658, /* 17015 ( 402) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  0]  1 */
    52570094, /* 17016 ( 402) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    52556808, /* 17017 ( 402) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
       16484, /* 17018 ( 387) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
     1433496, /* 17019 ( 387) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  0]  1 */
        3198, /* 17020 ( 387) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
     1420536, /* 17021 ( 387) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  0]  1 */
     1433498, /* 17022 ( 387) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  0]  1 */
        3200, /* 17023 ( 387) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
     1420538, /* 17024 ( 387) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  0]  1 */
       16482, /* 17025 ( 387) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
       16484, /* 17026 ( 388) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34015422, /* 17027 ( 388) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
     1433496, /* 17028 ( 388) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  0]  1 */
    35445722, /* 17029 ( 388) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  0] -1 */
    35432760, /* 17030 ( 388) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  0] -1 */
    34015424, /* 17031 ( 388) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    35432762, /* 17032 ( 388) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  0] -1 */
        3198, /* 17033 ( 388) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
     1420536, /* 17034 ( 388) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  0]  1 */
     1433498, /* 17035 ( 388) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  0]  1 */
    35445720, /* 17036 ( 388) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  0] -1 */
    34028706, /* 17037 ( 388) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
        3200, /* 17038 ( 388) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34028708, /* 17039 ( 388) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
     1420538, /* 17040 ( 388) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  0]  1 */
       16482, /* 17041 ( 388) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
       16484, /* 17042 ( 389) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34015422, /* 17043 ( 389) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    35445722, /* 17044 ( 389) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  0] -1 */
    34015424, /* 17045 ( 389) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
     1420536, /* 17046 ( 389) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  0]  1 */
    35445720, /* 17047 ( 389) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  0] -1 */
     1420538, /* 17048 ( 389) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  0]  1 */
       16482, /* 17049 ( 389) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
       16484, /* 17050 ( 390) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34015422, /* 17051 ( 390) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    35432760, /* 17052 ( 390) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  0] -1 */
     1433498, /* 17053 ( 390) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  0]  1 */
    35445720, /* 17054 ( 390) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  0] -1 */
    34028706, /* 17055 ( 390) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
        3200, /* 17056 ( 390) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
     1420538, /* 17057 ( 390) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  0]  1 */
       16484, /* 17058 ( 391) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34015422, /* 17059 ( 391) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
     1433496, /* 17060 ( 391) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  0]  1 */
    34015424, /* 17061 ( 391) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    35432760, /* 17062 ( 391) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  0] -1 */
    35432762, /* 17063 ( 391) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  0] -1 */
     1433498, /* 17064 ( 391) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  0]  1 */
       16482, /* 17065 ( 391) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
       16484, /* 17066 ( 392) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
     1433496, /* 17067 ( 392) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  0]  1 */
    35445722, /* 17068 ( 392) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  0] -1 */
    35432760, /* 17069 ( 392) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  0] -1 */
    34015424, /* 17070 ( 392) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
        3198, /* 17071 ( 392) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    34028706, /* 17072 ( 392) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
     1420538, /* 17073 ( 392) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  0]  1 */
       16484, /* 17074 ( 393) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34015424, /* 17075 ( 393) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    35432762, /* 17076 ( 393) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  0] -1 */
        3198, /* 17077 ( 393) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
     1420536, /* 17078 ( 393) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  0]  1 */
     1433498, /* 17079 ( 393) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  0]  1 */
    35445720, /* 17080 ( 393) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  0] -1 */
    34028706, /* 17081 ( 393) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
       16484, /* 17082 ( 394) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    35445722, /* 17083 ( 394) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  0] -1 */
    35432760, /* 17084 ( 394) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  0] -1 */
    35432762, /* 17085 ( 394) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  0] -1 */
        3198, /* 17086 ( 394) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    35445720, /* 17087 ( 394) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  0] -1 */
        3200, /* 17088 ( 394) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
       16482, /* 17089 ( 394) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
       16484, /* 17090 ( 395) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34015422, /* 17091 ( 395) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
     1433496, /* 17092 ( 395) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  0]  1 */
    35445722, /* 17093 ( 395) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  0] -1 */
    35432762, /* 17094 ( 395) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  0] -1 */
     1420536, /* 17095 ( 395) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  0]  1 */
    34028706, /* 17096 ( 395) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
        3200, /* 17097 ( 395) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
       16484, /* 17098 ( 396) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34028546, /* 17099 ( 396) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
     1433496, /* 17100 ( 396) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  0]  1 */
    35445884, /* 17101 ( 396) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  0] -1 */
    35432600, /* 17102 ( 396) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  0] -1 */
    35445882, /* 17103 ( 396) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  0] -1 */
    34015586, /* 17104 ( 396) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
        3198, /* 17105 ( 396) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
     1420536, /* 17106 ( 396) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  0]  1 */
    35432598, /* 17107 ( 396) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  0] -1 */
     1433498, /* 17108 ( 396) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  0]  1 */
    34028544, /* 17109 ( 396) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
        3200, /* 17110 ( 396) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
     1420538, /* 17111 ( 396) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  0]  1 */
    34015584, /* 17112 ( 396) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
       16482, /* 17113 ( 396) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
       16484, /* 17114 ( 397) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    35563818, /* 17115 ( 397) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  6] -1 */
     1433496, /* 17116 ( 397) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  0]  1 */
    35563820, /* 17117 ( 397) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
    34133522, /* 17118 ( 397) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    35550860, /* 17119 ( 397) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
        3198, /* 17120 ( 397) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
     1420536, /* 17121 ( 397) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  0]  1 */
    34146804, /* 17122 ( 397) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
    34146806, /* 17123 ( 397) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
     1433498, /* 17124 ( 397) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  0]  1 */
    34133520, /* 17125 ( 397) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
        3200, /* 17126 ( 397) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
     1420538, /* 17127 ( 397) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  0]  1 */
    35550858, /* 17128 ( 397) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6] -1 */
       16482, /* 17129 ( 397) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
       16484, /* 17130 ( 398) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
     1433496, /* 17131 ( 398) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  0]  1 */
    51034818, /* 17132 ( 398) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  0] -1 */
    52451832, /* 17133 ( 398) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
    51021534, /* 17134 ( 398) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  0] -1 */
    52451834, /* 17135 ( 398) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
        3198, /* 17136 ( 398) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
     1420536, /* 17137 ( 398) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  0]  1 */
    51034820, /* 17138 ( 398) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  0] -1 */
    52438872, /* 17139 ( 398) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
     1433498, /* 17140 ( 398) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  0]  1 */
    52438874, /* 17141 ( 398) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
    51021536, /* 17142 ( 398) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  0] -1 */
        3200, /* 17143 ( 398) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
     1420538, /* 17144 ( 398) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  0]  1 */
       16482, /* 17145 ( 398) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
       16484, /* 17146 ( 399) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    51139632, /* 17147 ( 399) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  6] -1 */
    52569930, /* 17148 ( 399) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
     1433496, /* 17149 ( 399) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  0]  1 */
    51139634, /* 17150 ( 399) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
    51152918, /* 17151 ( 399) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
        3198, /* 17152 ( 399) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
     1420536, /* 17153 ( 399) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  0]  1 */
    52569932, /* 17154 ( 399) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
     1433498, /* 17155 ( 399) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  0]  1 */
    52556970, /* 17156 ( 399) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
        3200, /* 17157 ( 399) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    52556972, /* 17158 ( 399) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
     1420538, /* 17159 ( 399) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  0]  1 */
    51152916, /* 17160 ( 399) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6] -1 */
       16482, /* 17161 ( 399) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
       16484, /* 17162 ( 400) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    52438712, /* 17163 ( 400) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
    51034656, /* 17164 ( 400) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  0] -1 */
     1433496, /* 17165 ( 400) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  0]  1 */
    52451994, /* 17166 ( 400) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
    52438710, /* 17167 ( 400) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
    51021698, /* 17168 ( 400) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  0] -1 */
        3198, /* 17169 ( 400) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
     1420536, /* 17170 ( 400) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  0]  1 */
    51034658, /* 17171 ( 400) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  0] -1 */
     1433498, /* 17172 ( 400) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  0]  1 */
    51021696, /* 17173 ( 400) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  0] -1 */
    52451996, /* 17174 ( 400) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
        3200, /* 17175 ( 400) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
     1420538, /* 17176 ( 400) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  0]  1 */
       16482, /* 17177 ( 400) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
       16484, /* 17178 ( 401) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    35563980, /* 17179 ( 401) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6] -1 */
    34133684, /* 17180 ( 401) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
     1433496, /* 17181 ( 401) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  0]  1 */
    35550696, /* 17182 ( 401) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  6] -1 */
    34146642, /* 17183 ( 401) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
    34146644, /* 17184 ( 401) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    35563982, /* 17185 ( 401) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
        3198, /* 17186 ( 401) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
     1420536, /* 17187 ( 401) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  0]  1 */
    34133682, /* 17188 ( 401) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
     1433498, /* 17189 ( 401) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  0]  1 */
        3200, /* 17190 ( 401) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    35550698, /* 17191 ( 401) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
     1420538, /* 17192 ( 401) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  0]  1 */
       16482, /* 17193 ( 401) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
       16484, /* 17194 ( 402) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
     1433496, /* 17195 ( 402) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  0]  1 */
    51139794, /* 17196 ( 402) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6] -1 */
    51152756, /* 17197 ( 402) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
       16482, /* 17198 ( 402) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    52570092, /* 17199 ( 402) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    51139796, /* 17200 ( 402) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
        3198, /* 17201 ( 402) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
     1420536, /* 17202 ( 402) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  0]  1 */
    52556810, /* 17203 ( 402) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
     1433498, /* 17204 ( 402) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  0]  1 */
    51152754, /* 17205 ( 402) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  6] -1 */
        3200, /* 17206 ( 402) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
     1420538, /* 17207 ( 402) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  0]  1 */
    52570094, /* 17208 ( 402) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    52556808, /* 17209 ( 402) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
       16484, /* 17210 ( 387) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
      134418, /* 17211 ( 387) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  6]  1 */
        3198, /* 17212 ( 387) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
      121298, /* 17213 ( 387) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6]  1 */
      134580, /* 17214 ( 387) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  6]  1 */
        3360, /* 17215 ( 387) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
      121460, /* 17216 ( 387) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6]  1 */
       16322, /* 17217 ( 387) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
       16484, /* 17218 ( 388) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34015422, /* 17219 ( 388) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
      134418, /* 17220 ( 388) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  6]  1 */
    34146804, /* 17221 ( 388) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
    34133522, /* 17222 ( 388) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    34015584, /* 17223 ( 388) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    34133684, /* 17224 ( 388) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
        3198, /* 17225 ( 388) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
      121298, /* 17226 ( 388) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6]  1 */
      134580, /* 17227 ( 388) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  6]  1 */
    34146642, /* 17228 ( 388) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
    34028546, /* 17229 ( 388) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
        3360, /* 17230 ( 388) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    34028708, /* 17231 ( 388) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
      121460, /* 17232 ( 388) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6]  1 */
       16322, /* 17233 ( 388) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
       16484, /* 17234 ( 389) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34015422, /* 17235 ( 389) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    34146804, /* 17236 ( 389) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
    34015584, /* 17237 ( 389) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
      121298, /* 17238 ( 389) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6]  1 */
    34146642, /* 17239 ( 389) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
      121460, /* 17240 ( 389) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6]  1 */
       16322, /* 17241 ( 389) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
       16484, /* 17242 ( 390) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34015422, /* 17243 ( 390) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    34133522, /* 17244 ( 390) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
      134580, /* 17245 ( 390) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  6]  1 */
    34146642, /* 17246 ( 390) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
    34028546, /* 17247 ( 390) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
        3360, /* 17248 ( 390) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
      121460, /* 17249 ( 390) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6]  1 */
       16484, /* 17250 ( 391) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34015422, /* 17251 ( 391) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
      134418, /* 17252 ( 391) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  6]  1 */
    34015584, /* 17253 ( 391) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    34133522, /* 17254 ( 391) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    34133684, /* 17255 ( 391) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
      134580, /* 17256 ( 391) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  6]  1 */
       16322, /* 17257 ( 391) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
       16484, /* 17258 ( 392) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
      134418, /* 17259 ( 392) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  6]  1 */
    34146804, /* 17260 ( 392) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
    34133522, /* 17261 ( 392) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    34015584, /* 17262 ( 392) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
        3198, /* 17263 ( 392) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    34028546, /* 17264 ( 392) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
      121460, /* 17265 ( 392) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6]  1 */
       16484, /* 17266 ( 393) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34015584, /* 17267 ( 393) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    34133684, /* 17268 ( 393) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
        3198, /* 17269 ( 393) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
      121298, /* 17270 ( 393) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6]  1 */
      134580, /* 17271 ( 393) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  6]  1 */
    34146642, /* 17272 ( 393) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
    34028546, /* 17273 ( 393) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
       16484, /* 17274 ( 394) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34146804, /* 17275 ( 394) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
    34133522, /* 17276 ( 394) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    34133684, /* 17277 ( 394) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
        3198, /* 17278 ( 394) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    34146642, /* 17279 ( 394) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
        3360, /* 17280 ( 394) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
       16322, /* 17281 ( 394) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
       16484, /* 17282 ( 395) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34015422, /* 17283 ( 395) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
      134418, /* 17284 ( 395) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  6]  1 */
    34146804, /* 17285 ( 395) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
    34133684, /* 17286 ( 395) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
      121298, /* 17287 ( 395) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6]  1 */
    34028546, /* 17288 ( 395) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
        3360, /* 17289 ( 395) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
       16484, /* 17290 ( 396) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34028706, /* 17291 ( 396) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
      134418, /* 17292 ( 396) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  6]  1 */
    34146806, /* 17293 ( 396) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    34133682, /* 17294 ( 396) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
    34146644, /* 17295 ( 396) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    34015586, /* 17296 ( 396) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
        3198, /* 17297 ( 396) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
      121298, /* 17298 ( 396) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6]  1 */
    34133520, /* 17299 ( 396) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
      134580, /* 17300 ( 396) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  6]  1 */
    34028544, /* 17301 ( 396) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
        3360, /* 17302 ( 396) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
      121460, /* 17303 ( 396) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6]  1 */
    34015424, /* 17304 ( 396) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
       16322, /* 17305 ( 396) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
       16484, /* 17306 ( 397) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    35563818, /* 17307 ( 397) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  6] -1 */
      134418, /* 17308 ( 397) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  6]  1 */
    35563980, /* 17309 ( 397) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6] -1 */
    35432760, /* 17310 ( 397) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  0] -1 */
    35550860, /* 17311 ( 397) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
        3198, /* 17312 ( 397) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
      121298, /* 17313 ( 397) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6]  1 */
    35445722, /* 17314 ( 397) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  0] -1 */
    35445884, /* 17315 ( 397) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  0] -1 */
      134580, /* 17316 ( 397) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  6]  1 */
    35432598, /* 17317 ( 397) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  0] -1 */
        3360, /* 17318 ( 397) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
      121460, /* 17319 ( 397) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6]  1 */
    35550698, /* 17320 ( 397) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
       16322, /* 17321 ( 397) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
       16484, /* 17322 ( 398) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
      134418, /* 17323 ( 398) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  6]  1 */
    51034658, /* 17324 ( 398) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  0] -1 */
    51152754, /* 17325 ( 398) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  6] -1 */
    51021534, /* 17326 ( 398) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  0] -1 */
    51152916, /* 17327 ( 398) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6] -1 */
        3198, /* 17328 ( 398) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
      121298, /* 17329 ( 398) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6]  1 */
    51034820, /* 17330 ( 398) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  0] -1 */
    51139634, /* 17331 ( 398) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
      134580, /* 17332 ( 398) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  6]  1 */
    51139796, /* 17333 ( 398) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
    51021696, /* 17334 ( 398) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  0] -1 */
        3360, /* 17335 ( 398) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
      121460, /* 17336 ( 398) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6]  1 */
       16322, /* 17337 ( 398) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
       16484, /* 17338 ( 399) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    52438710, /* 17339 ( 399) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
    52569930, /* 17340 ( 399) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
      134418, /* 17341 ( 399) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  6]  1 */
    52438872, /* 17342 ( 399) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
    52451996, /* 17343 ( 399) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
        3198, /* 17344 ( 399) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
      121298, /* 17345 ( 399) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6]  1 */
    52570092, /* 17346 ( 399) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
      134580, /* 17347 ( 399) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  6]  1 */
    52556810, /* 17348 ( 399) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
        3360, /* 17349 ( 399) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    52556972, /* 17350 ( 399) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
      121460, /* 17351 ( 399) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6]  1 */
    52451834, /* 17352 ( 399) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
       16322, /* 17353 ( 399) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
       16484, /* 17354 ( 400) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    51139794, /* 17355 ( 400) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6] -1 */
    51034656, /* 17356 ( 400) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  0] -1 */
      134418, /* 17357 ( 400) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  6]  1 */
    51152756, /* 17358 ( 400) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
    51139632, /* 17359 ( 400) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  6] -1 */
    51021698, /* 17360 ( 400) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  0] -1 */
        3198, /* 17361 ( 400) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
      121298, /* 17362 ( 400) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6]  1 */
    51034818, /* 17363 ( 400) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  0] -1 */
      134580, /* 17364 ( 400) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  6]  1 */
    51021536, /* 17365 ( 400) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  0] -1 */
    51152918, /* 17366 ( 400) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
        3360, /* 17367 ( 400) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
      121460, /* 17368 ( 400) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6]  1 */
       16322, /* 17369 ( 400) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
       16484, /* 17370 ( 401) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    35563820, /* 17371 ( 401) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
    35432762, /* 17372 ( 401) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  0] -1 */
      134418, /* 17373 ( 401) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  6]  1 */
    35550696, /* 17374 ( 401) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  6] -1 */
    35445720, /* 17375 ( 401) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  0] -1 */
    35445882, /* 17376 ( 401) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  0] -1 */
    35563982, /* 17377 ( 401) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
        3198, /* 17378 ( 401) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
      121298, /* 17379 ( 401) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6]  1 */
    35432600, /* 17380 ( 401) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  0] -1 */
      134580, /* 17381 ( 401) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  6]  1 */
        3360, /* 17382 ( 401) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    35550858, /* 17383 ( 401) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6] -1 */
      121460, /* 17384 ( 401) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6]  1 */
       16322, /* 17385 ( 401) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
       16484, /* 17386 ( 402) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
      134418, /* 17387 ( 402) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  6]  1 */
    52438712, /* 17388 ( 402) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
    52451994, /* 17389 ( 402) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
       16322, /* 17390 ( 402) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    52569932, /* 17391 ( 402) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    52438874, /* 17392 ( 402) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
        3198, /* 17393 ( 402) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
      121298, /* 17394 ( 402) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6]  1 */
    52556970, /* 17395 ( 402) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
      134580, /* 17396 ( 402) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  6]  1 */
    52451832, /* 17397 ( 402) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
        3360, /* 17398 ( 402) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
      121460, /* 17399 ( 402) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6]  1 */
    52570094, /* 17400 ( 402) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    52556808, /* 17401 ( 402) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
       16484, /* 17402 ( 387) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
      121458, /* 17403 ( 387) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  6]  1 */
        3198, /* 17404 ( 387) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
      121298, /* 17405 ( 387) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6]  1 */
      134580, /* 17406 ( 387) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  6]  1 */
       16320, /* 17407 ( 387) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
      134420, /* 17408 ( 387) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6]  1 */
        3362, /* 17409 ( 387) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
       16484, /* 17410 ( 388) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34015422, /* 17411 ( 388) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
      121458, /* 17412 ( 388) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  6]  1 */
    34146804, /* 17413 ( 388) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
    34133522, /* 17414 ( 388) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    34028544, /* 17415 ( 388) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    34146644, /* 17416 ( 388) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
        3198, /* 17417 ( 388) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
      121298, /* 17418 ( 388) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6]  1 */
      134580, /* 17419 ( 388) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  6]  1 */
    34133682, /* 17420 ( 388) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
    34015586, /* 17421 ( 388) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
       16320, /* 17422 ( 388) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    34028708, /* 17423 ( 388) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
      134420, /* 17424 ( 388) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6]  1 */
        3362, /* 17425 ( 388) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
       16484, /* 17426 ( 389) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34015422, /* 17427 ( 389) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    34146804, /* 17428 ( 389) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
    34028544, /* 17429 ( 389) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
      121298, /* 17430 ( 389) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6]  1 */
    34133682, /* 17431 ( 389) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
      134420, /* 17432 ( 389) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6]  1 */
        3362, /* 17433 ( 389) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
       16484, /* 17434 ( 390) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34015422, /* 17435 ( 390) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    34133522, /* 17436 ( 390) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
      134580, /* 17437 ( 390) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  6]  1 */
    34133682, /* 17438 ( 390) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
    34015586, /* 17439 ( 390) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
       16320, /* 17440 ( 390) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
      134420, /* 17441 ( 390) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6]  1 */
       16484, /* 17442 ( 391) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34015422, /* 17443 ( 391) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
      121458, /* 17444 ( 391) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  6]  1 */
    34028544, /* 17445 ( 391) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    34133522, /* 17446 ( 391) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    34146644, /* 17447 ( 391) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
      134580, /* 17448 ( 391) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  6]  1 */
        3362, /* 17449 ( 391) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
       16484, /* 17450 ( 392) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
      121458, /* 17451 ( 392) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  6]  1 */
    34146804, /* 17452 ( 392) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
    34133522, /* 17453 ( 392) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    34028544, /* 17454 ( 392) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
        3198, /* 17455 ( 392) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    34015586, /* 17456 ( 392) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
      134420, /* 17457 ( 392) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6]  1 */
       16484, /* 17458 ( 393) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34028544, /* 17459 ( 393) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    34146644, /* 17460 ( 393) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
        3198, /* 17461 ( 393) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
      121298, /* 17462 ( 393) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6]  1 */
      134580, /* 17463 ( 393) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  6]  1 */
    34133682, /* 17464 ( 393) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
    34015586, /* 17465 ( 393) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
       16484, /* 17466 ( 394) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34146804, /* 17467 ( 394) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
    34133522, /* 17468 ( 394) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    34146644, /* 17469 ( 394) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
        3198, /* 17470 ( 394) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    34133682, /* 17471 ( 394) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
       16320, /* 17472 ( 394) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
        3362, /* 17473 ( 394) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
       16484, /* 17474 ( 395) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34015422, /* 17475 ( 395) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
      121458, /* 17476 ( 395) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  6]  1 */
    34146804, /* 17477 ( 395) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
    34146644, /* 17478 ( 395) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
      121298, /* 17479 ( 395) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6]  1 */
    34015586, /* 17480 ( 395) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
       16320, /* 17481 ( 395) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
       16484, /* 17482 ( 396) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34028706, /* 17483 ( 396) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
      121458, /* 17484 ( 396) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  6]  1 */
    34146806, /* 17485 ( 396) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    34146642, /* 17486 ( 396) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
    34133684, /* 17487 ( 396) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    34028546, /* 17488 ( 396) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
        3198, /* 17489 ( 396) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
      121298, /* 17490 ( 396) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6]  1 */
    34133520, /* 17491 ( 396) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
      134580, /* 17492 ( 396) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  6]  1 */
    34015584, /* 17493 ( 396) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
       16320, /* 17494 ( 396) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
      134420, /* 17495 ( 396) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6]  1 */
    34015424, /* 17496 ( 396) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
        3362, /* 17497 ( 396) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
       16484, /* 17498 ( 397) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    51139794, /* 17499 ( 397) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6] -1 */
      121458, /* 17500 ( 397) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  6]  1 */
    51152916, /* 17501 ( 397) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6] -1 */
    51034656, /* 17502 ( 397) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  0] -1 */
    51152756, /* 17503 ( 397) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
        3198, /* 17504 ( 397) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
      121298, /* 17505 ( 397) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6]  1 */
    51021698, /* 17506 ( 397) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  0] -1 */
    51034820, /* 17507 ( 397) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  0] -1 */
      134580, /* 17508 ( 397) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  6]  1 */
    51021534, /* 17509 ( 397) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  0] -1 */
       16320, /* 17510 ( 397) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
      134420, /* 17511 ( 397) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6]  1 */
    51139634, /* 17512 ( 397) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
        3362, /* 17513 ( 397) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
       16484, /* 17514 ( 398) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
      121458, /* 17515 ( 398) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  6]  1 */
    35432762, /* 17516 ( 398) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  0] -1 */
    35550858, /* 17517 ( 398) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6] -1 */
    35432598, /* 17518 ( 398) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  0] -1 */
    35563980, /* 17519 ( 398) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6] -1 */
        3198, /* 17520 ( 398) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
      121298, /* 17521 ( 398) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6]  1 */
    35445884, /* 17522 ( 398) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  0] -1 */
    35550698, /* 17523 ( 398) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
      134580, /* 17524 ( 398) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  6]  1 */
    35563820, /* 17525 ( 398) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
    35445720, /* 17526 ( 398) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  0] -1 */
       16320, /* 17527 ( 398) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
      134420, /* 17528 ( 398) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6]  1 */
        3362, /* 17529 ( 398) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
       16484, /* 17530 ( 399) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    52438710, /* 17531 ( 399) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
    52556970, /* 17532 ( 399) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
      121458, /* 17533 ( 399) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  6]  1 */
    52451832, /* 17534 ( 399) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
    52451996, /* 17535 ( 399) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
        3198, /* 17536 ( 399) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
      121298, /* 17537 ( 399) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6]  1 */
    52570092, /* 17538 ( 399) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
      134580, /* 17539 ( 399) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  6]  1 */
    52556810, /* 17540 ( 399) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
       16320, /* 17541 ( 399) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    52569932, /* 17542 ( 399) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
      134420, /* 17543 ( 399) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6]  1 */
    52438874, /* 17544 ( 399) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
        3362, /* 17545 ( 399) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
       16484, /* 17546 ( 400) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    35563818, /* 17547 ( 400) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  6] -1 */
    35432760, /* 17548 ( 400) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  0] -1 */
      121458, /* 17549 ( 400) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  6]  1 */
    35550860, /* 17550 ( 400) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
    35550696, /* 17551 ( 400) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  6] -1 */
    35445722, /* 17552 ( 400) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  0] -1 */
        3198, /* 17553 ( 400) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
      121298, /* 17554 ( 400) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6]  1 */
    35445882, /* 17555 ( 400) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  0] -1 */
      134580, /* 17556 ( 400) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  6]  1 */
    35432600, /* 17557 ( 400) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  0] -1 */
    35563982, /* 17558 ( 400) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
       16320, /* 17559 ( 400) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
      134420, /* 17560 ( 400) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6]  1 */
        3362, /* 17561 ( 400) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
       16484, /* 17562 ( 401) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    51139796, /* 17563 ( 401) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
    51034658, /* 17564 ( 401) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  0] -1 */
      121458, /* 17565 ( 401) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  6]  1 */
    51139632, /* 17566 ( 401) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  6] -1 */
    51021696, /* 17567 ( 401) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  0] -1 */
    51034818, /* 17568 ( 401) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  0] -1 */
    51152918, /* 17569 ( 401) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
        3198, /* 17570 ( 401) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
      121298, /* 17571 ( 401) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6]  1 */
    51021536, /* 17572 ( 401) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  0] -1 */
      134580, /* 17573 ( 401) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  6]  1 */
       16320, /* 17574 ( 401) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    51152754, /* 17575 ( 401) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  6] -1 */
      134420, /* 17576 ( 401) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6]  1 */
        3362, /* 17577 ( 401) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
       16484, /* 17578 ( 402) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
      121458, /* 17579 ( 402) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  6]  1 */
    52438712, /* 17580 ( 402) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
    52451994, /* 17581 ( 402) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
        3362, /* 17582 ( 402) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    52556972, /* 17583 ( 402) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    52451834, /* 17584 ( 402) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
        3198, /* 17585 ( 402) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
      121298, /* 17586 ( 402) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6]  1 */
    52569930, /* 17587 ( 402) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
      134580, /* 17588 ( 402) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  6]  1 */
    52438872, /* 17589 ( 402) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
       16320, /* 17590 ( 402) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
      134420, /* 17591 ( 402) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6]  1 */
    52570094, /* 17592 ( 402) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    52556808, /* 17593 ( 402) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
       16484, /* 17594 ( 387) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    17009472, /* 17595 ( 387) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  0]  1 */
        3198, /* 17596 ( 387) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    17022432, /* 17597 ( 387) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  0]  1 */
    17009474, /* 17598 ( 387) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  0]  1 */
        3200, /* 17599 ( 387) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    17022434, /* 17600 ( 387) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  0]  1 */
       16482, /* 17601 ( 387) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
       16484, /* 17602 ( 388) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34015422, /* 17603 ( 388) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    17009472, /* 17604 ( 388) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  0]  1 */
    51021698, /* 17605 ( 388) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  0] -1 */
    51034656, /* 17606 ( 388) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  0] -1 */
    34015424, /* 17607 ( 388) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    51034658, /* 17608 ( 388) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  0] -1 */
        3198, /* 17609 ( 388) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    17022432, /* 17610 ( 388) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  0]  1 */
    17009474, /* 17611 ( 388) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  0]  1 */
    51021696, /* 17612 ( 388) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  0] -1 */
    34028706, /* 17613 ( 388) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
        3200, /* 17614 ( 388) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34028708, /* 17615 ( 388) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    17022434, /* 17616 ( 388) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  0]  1 */
       16482, /* 17617 ( 388) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
       16484, /* 17618 ( 389) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34015422, /* 17619 ( 389) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    51021698, /* 17620 ( 389) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  0] -1 */
    34015424, /* 17621 ( 389) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    17022432, /* 17622 ( 389) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  0]  1 */
    51021696, /* 17623 ( 389) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  0] -1 */
    17022434, /* 17624 ( 389) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  0]  1 */
       16482, /* 17625 ( 389) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
       16484, /* 17626 ( 390) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34015422, /* 17627 ( 390) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    51034656, /* 17628 ( 390) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  0] -1 */
    17009474, /* 17629 ( 390) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  0]  1 */
    51021696, /* 17630 ( 390) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  0] -1 */
    34028706, /* 17631 ( 390) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
        3200, /* 17632 ( 390) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    17022434, /* 17633 ( 390) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  0]  1 */
       16484, /* 17634 ( 391) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34015422, /* 17635 ( 391) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    17009472, /* 17636 ( 391) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  0]  1 */
    34015424, /* 17637 ( 391) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    51034656, /* 17638 ( 391) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  0] -1 */
    51034658, /* 17639 ( 391) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  0] -1 */
    17009474, /* 17640 ( 391) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  0]  1 */
       16482, /* 17641 ( 391) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
       16484, /* 17642 ( 392) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    17009472, /* 17643 ( 392) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  0]  1 */
    51021698, /* 17644 ( 392) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  0] -1 */
    51034656, /* 17645 ( 392) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  0] -1 */
    34015424, /* 17646 ( 392) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
        3198, /* 17647 ( 392) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    34028706, /* 17648 ( 392) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    17022434, /* 17649 ( 392) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  0]  1 */
       16484, /* 17650 ( 393) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34015424, /* 17651 ( 393) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    51034658, /* 17652 ( 393) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  0] -1 */
        3198, /* 17653 ( 393) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    17022432, /* 17654 ( 393) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  0]  1 */
    17009474, /* 17655 ( 393) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  0]  1 */
    51021696, /* 17656 ( 393) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  0] -1 */
    34028706, /* 17657 ( 393) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
       16484, /* 17658 ( 394) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    51021698, /* 17659 ( 394) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  0] -1 */
    51034656, /* 17660 ( 394) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  0] -1 */
    51034658, /* 17661 ( 394) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  0] -1 */
        3198, /* 17662 ( 394) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    51021696, /* 17663 ( 394) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  0] -1 */
        3200, /* 17664 ( 394) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
       16482, /* 17665 ( 394) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
       16484, /* 17666 ( 395) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34015422, /* 17667 ( 395) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    17009472, /* 17668 ( 395) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  0]  1 */
    51021698, /* 17669 ( 395) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  0] -1 */
    51034658, /* 17670 ( 395) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  0] -1 */
    17022432, /* 17671 ( 395) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  0]  1 */
    34028706, /* 17672 ( 395) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
        3200, /* 17673 ( 395) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
       16484, /* 17674 ( 396) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34015586, /* 17675 ( 396) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    17009472, /* 17676 ( 396) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  0]  1 */
    51034820, /* 17677 ( 396) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  0] -1 */
    51021536, /* 17678 ( 396) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  0] -1 */
    51034818, /* 17679 ( 396) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  0] -1 */
    34028546, /* 17680 ( 396) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
        3198, /* 17681 ( 396) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    17022432, /* 17682 ( 396) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  0]  1 */
    51021534, /* 17683 ( 396) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  0] -1 */
    17009474, /* 17684 ( 396) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  0]  1 */
    34015584, /* 17685 ( 396) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
        3200, /* 17686 ( 396) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    17022434, /* 17687 ( 396) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  0]  1 */
    34028544, /* 17688 ( 396) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
       16482, /* 17689 ( 396) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
       16484, /* 17690 ( 397) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    51139794, /* 17691 ( 397) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6] -1 */
    17009472, /* 17692 ( 397) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  0]  1 */
    51139796, /* 17693 ( 397) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
    34133522, /* 17694 ( 397) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    51152756, /* 17695 ( 397) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
        3198, /* 17696 ( 397) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    17022432, /* 17697 ( 397) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  0]  1 */
    34146804, /* 17698 ( 397) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
    34146806, /* 17699 ( 397) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    17009474, /* 17700 ( 397) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  0]  1 */
    34133520, /* 17701 ( 397) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
        3200, /* 17702 ( 397) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    17022434, /* 17703 ( 397) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  0]  1 */
    51152754, /* 17704 ( 397) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  6] -1 */
       16482, /* 17705 ( 397) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
       16484, /* 17706 ( 398) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    17009472, /* 17707 ( 398) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  0]  1 */
    35445882, /* 17708 ( 398) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  0] -1 */
    52438872, /* 17709 ( 398) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
    35432598, /* 17710 ( 398) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  0] -1 */
    52438874, /* 17711 ( 398) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
        3198, /* 17712 ( 398) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    17022432, /* 17713 ( 398) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  0]  1 */
    35445884, /* 17714 ( 398) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  0] -1 */
    52451832, /* 17715 ( 398) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
    17009474, /* 17716 ( 398) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  0]  1 */
    52451834, /* 17717 ( 398) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
    35432600, /* 17718 ( 398) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  0] -1 */
        3200, /* 17719 ( 398) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    17022434, /* 17720 ( 398) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  0]  1 */
       16482, /* 17721 ( 398) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
       16484, /* 17722 ( 399) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    35550696, /* 17723 ( 399) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  6] -1 */
    52556970, /* 17724 ( 399) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    17009472, /* 17725 ( 399) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  0]  1 */
    35550698, /* 17726 ( 399) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
    35563982, /* 17727 ( 399) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
        3198, /* 17728 ( 399) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    17022432, /* 17729 ( 399) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  0]  1 */
    52556972, /* 17730 ( 399) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    17009474, /* 17731 ( 399) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  0]  1 */
    52569930, /* 17732 ( 399) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
        3200, /* 17733 ( 399) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    52569932, /* 17734 ( 399) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    17022434, /* 17735 ( 399) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  0]  1 */
    35563980, /* 17736 ( 399) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6] -1 */
       16482, /* 17737 ( 399) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
       16484, /* 17738 ( 400) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    52438712, /* 17739 ( 400) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
    35432760, /* 17740 ( 400) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  0] -1 */
    17009472, /* 17741 ( 400) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  0]  1 */
    52451994, /* 17742 ( 400) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
    52438710, /* 17743 ( 400) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
    35445722, /* 17744 ( 400) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  0] -1 */
        3198, /* 17745 ( 400) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    17022432, /* 17746 ( 400) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  0]  1 */
    35432762, /* 17747 ( 400) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  0] -1 */
    17009474, /* 17748 ( 400) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  0]  1 */
    35445720, /* 17749 ( 400) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  0] -1 */
    52451996, /* 17750 ( 400) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
        3200, /* 17751 ( 400) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    17022434, /* 17752 ( 400) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  0]  1 */
       16482, /* 17753 ( 400) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
       16484, /* 17754 ( 401) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    51152916, /* 17755 ( 401) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6] -1 */
    34146644, /* 17756 ( 401) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    17009472, /* 17757 ( 401) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  0]  1 */
    51139632, /* 17758 ( 401) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  6] -1 */
    34133682, /* 17759 ( 401) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
    34133684, /* 17760 ( 401) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    51152918, /* 17761 ( 401) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
        3198, /* 17762 ( 401) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    17022432, /* 17763 ( 401) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  0]  1 */
    34146642, /* 17764 ( 401) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
    17009474, /* 17765 ( 401) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  0]  1 */
        3200, /* 17766 ( 401) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    51139634, /* 17767 ( 401) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
    17022434, /* 17768 ( 401) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  0]  1 */
       16482, /* 17769 ( 401) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
       16484, /* 17770 ( 402) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    17009472, /* 17771 ( 402) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  0]  1 */
    35563818, /* 17772 ( 402) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  6] -1 */
    35550860, /* 17773 ( 402) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
       16482, /* 17774 ( 402) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    52570092, /* 17775 ( 402) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    35563820, /* 17776 ( 402) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
        3198, /* 17777 ( 402) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    17022432, /* 17778 ( 402) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  0]  1 */
    52556810, /* 17779 ( 402) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    17009474, /* 17780 ( 402) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  0]  1 */
    35550858, /* 17781 ( 402) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6] -1 */
        3200, /* 17782 ( 402) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    17022434, /* 17783 ( 402) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  0]  1 */
    52570094, /* 17784 ( 402) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    52556808, /* 17785 ( 402) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
       16484, /* 17786 ( 403) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
     1551594, /* 17787 ( 403) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
    17009312, /* 17788 ( 403) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  0]  1 */
    18544746, /* 17789 ( 403) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
     1538636, /* 17790 ( 403) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
        3198, /* 17791 ( 403) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    18557708, /* 17792 ( 403) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    17022594, /* 17793 ( 403) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  0]  1 */
       16484, /* 17794 ( 404) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
     1551594, /* 17795 ( 404) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
    34015422, /* 17796 ( 404) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    17009312, /* 17797 ( 404) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  0]  1 */
    35550860, /* 17798 ( 404) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
    18544746, /* 17799 ( 404) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
    52569932, /* 17800 ( 404) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    51034818, /* 17801 ( 404) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  0] -1 */
     1538636, /* 17802 ( 404) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
        3198, /* 17803 ( 404) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    52556970, /* 17804 ( 404) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    51021536, /* 17805 ( 404) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  0] -1 */
    18557708, /* 17806 ( 404) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    34028708, /* 17807 ( 404) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    17022594, /* 17808 ( 404) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  0]  1 */
    35563818, /* 17809 ( 404) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  6] -1 */
       16484, /* 17810 ( 405) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
     1551594, /* 17811 ( 405) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
    34015422, /* 17812 ( 405) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    35550860, /* 17813 ( 405) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
    52556970, /* 17814 ( 405) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    51021536, /* 17815 ( 405) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  0] -1 */
    18557708, /* 17816 ( 405) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    17022594, /* 17817 ( 405) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  0]  1 */
       16484, /* 17818 ( 406) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34015422, /* 17819 ( 406) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    52569932, /* 17820 ( 406) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
     1538636, /* 17821 ( 406) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
    51021536, /* 17822 ( 406) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  0] -1 */
    18544746, /* 17823 ( 406) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
    35563818, /* 17824 ( 406) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  6] -1 */
    17022594, /* 17825 ( 406) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  0]  1 */
       16484, /* 17826 ( 407) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34015422, /* 17827 ( 407) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    17009312, /* 17828 ( 407) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  0]  1 */
    51034818, /* 17829 ( 407) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  0] -1 */
     1538636, /* 17830 ( 407) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
    52556970, /* 17831 ( 407) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    18557708, /* 17832 ( 407) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    35563818, /* 17833 ( 407) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  6] -1 */
       16484, /* 17834 ( 408) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    17009312, /* 17835 ( 408) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  0]  1 */
    35550860, /* 17836 ( 408) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
    52569932, /* 17837 ( 408) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
        3198, /* 17838 ( 408) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    52556970, /* 17839 ( 408) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    17022594, /* 17840 ( 408) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  0]  1 */
    35563818, /* 17841 ( 408) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  6] -1 */
       16484, /* 17842 ( 409) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
     1551594, /* 17843 ( 409) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
    52569932, /* 17844 ( 409) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    51034818, /* 17845 ( 409) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  0] -1 */
     1538636, /* 17846 ( 409) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
        3198, /* 17847 ( 409) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    52556970, /* 17848 ( 409) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    51021536, /* 17849 ( 409) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  0] -1 */
       16484, /* 17850 ( 410) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    35550860, /* 17851 ( 410) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
    51034818, /* 17852 ( 410) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  0] -1 */
        3198, /* 17853 ( 410) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    51021536, /* 17854 ( 410) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  0] -1 */
    18557708, /* 17855 ( 410) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    18544746, /* 17856 ( 410) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
    35563818, /* 17857 ( 410) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  6] -1 */
       16484, /* 17858 ( 411) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
     1551594, /* 17859 ( 411) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
    34015422, /* 17860 ( 411) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    17009312, /* 17861 ( 411) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  0]  1 */
    35550860, /* 17862 ( 411) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
    52569932, /* 17863 ( 411) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    51034818, /* 17864 ( 411) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  0] -1 */
    18544746, /* 17865 ( 411) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
       16484, /* 17866 ( 412) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
     1551594, /* 17867 ( 412) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
    17009312, /* 17868 ( 412) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  0]  1 */
    35550858, /* 17869 ( 412) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6] -1 */
    51034820, /* 17870 ( 412) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  0] -1 */
    18544746, /* 17871 ( 412) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
    34028706, /* 17872 ( 412) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
     1538636, /* 17873 ( 412) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
        3198, /* 17874 ( 412) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    51021534, /* 17875 ( 412) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  0] -1 */
    52556972, /* 17876 ( 412) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    34015424, /* 17877 ( 412) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    18557708, /* 17878 ( 412) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    17022594, /* 17879 ( 412) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  0]  1 */
    35563820, /* 17880 ( 412) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
    52569930, /* 17881 ( 412) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
       16484, /* 17882 ( 413) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    51139794, /* 17883 ( 413) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6] -1 */
     1551594, /* 17884 ( 413) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
    17009312, /* 17885 ( 413) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  0]  1 */
    51152756, /* 17886 ( 413) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
    18544746, /* 17887 ( 413) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
     1538636, /* 17888 ( 413) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
    52451994, /* 17889 ( 413) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
        3198, /* 17890 ( 413) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    18557708, /* 17891 ( 413) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    35445884, /* 17892 ( 413) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  0] -1 */
    34133684, /* 17893 ( 413) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    34146642, /* 17894 ( 413) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
    35432598, /* 17895 ( 413) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  0] -1 */
    52438712, /* 17896 ( 413) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
    17022594, /* 17897 ( 413) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  0]  1 */
       16484, /* 17898 ( 414) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    52451834, /* 17899 ( 414) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
     1551594, /* 17900 ( 414) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
    17009312, /* 17901 ( 414) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  0]  1 */
    18544746, /* 17902 ( 414) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
    51139634, /* 17903 ( 414) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
     1538636, /* 17904 ( 414) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
    34133520, /* 17905 ( 414) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
    35445720, /* 17906 ( 414) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  0] -1 */
        3198, /* 17907 ( 414) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    35432762, /* 17908 ( 414) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  0] -1 */
    34146806, /* 17909 ( 414) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    51152916, /* 17910 ( 414) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6] -1 */
    18557708, /* 17911 ( 414) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    52438872, /* 17912 ( 414) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
    17022594, /* 17913 ( 414) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  0]  1 */
       16484, /* 17914 ( 415) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34015586, /* 17915 ( 415) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
     1551594, /* 17916 ( 415) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
    35550696, /* 17917 ( 415) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  6] -1 */
    17009312, /* 17918 ( 415) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  0]  1 */
    52556810, /* 17919 ( 415) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    18544746, /* 17920 ( 415) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
    51021696, /* 17921 ( 415) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  0] -1 */
    35563982, /* 17922 ( 415) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
     1538636, /* 17923 ( 415) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
        3198, /* 17924 ( 415) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    18557708, /* 17925 ( 415) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    52570092, /* 17926 ( 415) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    17022594, /* 17927 ( 415) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  0]  1 */
    34028544, /* 17928 ( 415) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    51034658, /* 17929 ( 415) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  0] -1 */
       16484, /* 17930 ( 416) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
     1551594, /* 17931 ( 416) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
    34133522, /* 17932 ( 416) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    17009312, /* 17933 ( 416) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  0]  1 */
    18544746, /* 17934 ( 416) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
    52438874, /* 17935 ( 416) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
    35432760, /* 17936 ( 416) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  0] -1 */
     1538636, /* 17937 ( 416) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
    51139632, /* 17938 ( 416) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  6] -1 */
    34146804, /* 17939 ( 416) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
        3198, /* 17940 ( 416) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    35445722, /* 17941 ( 416) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  0] -1 */
    51152918, /* 17942 ( 416) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
    18557708, /* 17943 ( 416) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    17022594, /* 17944 ( 416) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  0]  1 */
    52451832, /* 17945 ( 416) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
       16484, /* 17946 ( 417) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    35445882, /* 17947 ( 417) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  0] -1 */
     1551594, /* 17948 ( 417) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
    17009312, /* 17949 ( 417) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  0]  1 */
    52438710, /* 17950 ( 417) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
    18544746, /* 17951 ( 417) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
    34146644, /* 17952 ( 417) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    35432600, /* 17953 ( 417) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  0] -1 */
     1538636, /* 17954 ( 417) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
    52451996, /* 17955 ( 417) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
        3198, /* 17956 ( 417) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    51139796, /* 17957 ( 417) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
    51152754, /* 17958 ( 417) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  6] -1 */
    34133682, /* 17959 ( 417) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
    18557708, /* 17960 ( 417) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    17022594, /* 17961 ( 417) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  0]  1 */
       16484, /* 17962 ( 418) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
     1551594, /* 17963 ( 418) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
    17009312, /* 17964 ( 418) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  0]  1 */
    51021698, /* 17965 ( 418) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  0] -1 */
    18544746, /* 17966 ( 418) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
    51034656, /* 17967 ( 418) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  0] -1 */
    34015584, /* 17968 ( 418) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    35563980, /* 17969 ( 418) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6] -1 */
     1538636, /* 17970 ( 418) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
        3198, /* 17971 ( 418) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    35550698, /* 17972 ( 418) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
    34028546, /* 17973 ( 418) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    18557708, /* 17974 ( 418) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    17022594, /* 17975 ( 418) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  0]  1 */
    52570094, /* 17976 ( 418) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    52556808, /* 17977 ( 418) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
       16484, /* 17978 ( 403) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    17127570, /* 17979 ( 403) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6]  1 */
     1420376, /* 17980 ( 403) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  0]  1 */
    18557706, /* 17981 ( 403) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
    17140532, /* 17982 ( 403) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
        3198, /* 17983 ( 403) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    18544748, /* 17984 ( 403) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
     1433658, /* 17985 ( 403) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  0]  1 */
       16484, /* 17986 ( 404) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    17127570, /* 17987 ( 404) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6]  1 */
    34015422, /* 17988 ( 404) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
     1420376, /* 17989 ( 404) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  0]  1 */
    51152756, /* 17990 ( 404) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
    18557706, /* 17991 ( 404) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
    52556972, /* 17992 ( 404) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    35445882, /* 17993 ( 404) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  0] -1 */
    17140532, /* 17994 ( 404) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
        3198, /* 17995 ( 404) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    52569930, /* 17996 ( 404) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    35432600, /* 17997 ( 404) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  0] -1 */
    18544748, /* 17998 ( 404) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    34028708, /* 17999 ( 404) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
     1433658, /* 18000 ( 404) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  0]  1 */
    51139794, /* 18001 ( 404) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6] -1 */
       16484, /* 18002 ( 405) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    17127570, /* 18003 ( 405) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6]  1 */
    34015422, /* 18004 ( 405) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    51152756, /* 18005 ( 405) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
    52569930, /* 18006 ( 405) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    35432600, /* 18007 ( 405) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  0] -1 */
    18544748, /* 18008 ( 405) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
     1433658, /* 18009 ( 405) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  0]  1 */
       16484, /* 18010 ( 406) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34015422, /* 18011 ( 406) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    52556972, /* 18012 ( 406) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    17140532, /* 18013 ( 406) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
    35432600, /* 18014 ( 406) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  0] -1 */
    18557706, /* 18015 ( 406) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
    51139794, /* 18016 ( 406) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6] -1 */
     1433658, /* 18017 ( 406) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  0]  1 */
       16484, /* 18018 ( 407) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34015422, /* 18019 ( 407) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
     1420376, /* 18020 ( 407) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  0]  1 */
    35445882, /* 18021 ( 407) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  0] -1 */
    17140532, /* 18022 ( 407) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
    52569930, /* 18023 ( 407) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    18544748, /* 18024 ( 407) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    51139794, /* 18025 ( 407) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6] -1 */
       16484, /* 18026 ( 408) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
     1420376, /* 18027 ( 408) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  0]  1 */
    51152756, /* 18028 ( 408) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
    52556972, /* 18029 ( 408) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
        3198, /* 18030 ( 408) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    52569930, /* 18031 ( 408) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
     1433658, /* 18032 ( 408) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  0]  1 */
    51139794, /* 18033 ( 408) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6] -1 */
       16484, /* 18034 ( 409) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    17127570, /* 18035 ( 409) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6]  1 */
    52556972, /* 18036 ( 409) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    35445882, /* 18037 ( 409) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  0] -1 */
    17140532, /* 18038 ( 409) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
        3198, /* 18039 ( 409) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    52569930, /* 18040 ( 409) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    35432600, /* 18041 ( 409) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  0] -1 */
       16484, /* 18042 ( 410) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    51152756, /* 18043 ( 410) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
    35445882, /* 18044 ( 410) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  0] -1 */
        3198, /* 18045 ( 410) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    35432600, /* 18046 ( 410) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  0] -1 */
    18544748, /* 18047 ( 410) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    18557706, /* 18048 ( 410) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
    51139794, /* 18049 ( 410) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6] -1 */
       16484, /* 18050 ( 411) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    17127570, /* 18051 ( 411) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6]  1 */
    34015422, /* 18052 ( 411) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
     1420376, /* 18053 ( 411) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  0]  1 */
    51152756, /* 18054 ( 411) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
    52556972, /* 18055 ( 411) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    35445882, /* 18056 ( 411) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  0] -1 */
    18557706, /* 18057 ( 411) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
       16484, /* 18058 ( 412) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    17127570, /* 18059 ( 412) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6]  1 */
     1420376, /* 18060 ( 412) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  0]  1 */
    51152754, /* 18061 ( 412) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  6] -1 */
    35445884, /* 18062 ( 412) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  0] -1 */
    18557706, /* 18063 ( 412) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
    34028706, /* 18064 ( 412) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    17140532, /* 18065 ( 412) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
        3198, /* 18066 ( 412) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    35432598, /* 18067 ( 412) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  0] -1 */
    52569932, /* 18068 ( 412) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    34015424, /* 18069 ( 412) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    18544748, /* 18070 ( 412) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
     1433658, /* 18071 ( 412) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  0]  1 */
    51139796, /* 18072 ( 412) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
    52556970, /* 18073 ( 412) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
       16484, /* 18074 ( 413) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    35563818, /* 18075 ( 413) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  6] -1 */
    17127570, /* 18076 ( 413) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6]  1 */
     1420376, /* 18077 ( 413) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  0]  1 */
    35550860, /* 18078 ( 413) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
    18557706, /* 18079 ( 413) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
    17140532, /* 18080 ( 413) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
    52451994, /* 18081 ( 413) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
        3198, /* 18082 ( 413) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    18544748, /* 18083 ( 413) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    51034820, /* 18084 ( 413) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  0] -1 */
    34146644, /* 18085 ( 413) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    34133682, /* 18086 ( 413) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
    51021534, /* 18087 ( 413) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  0] -1 */
    52438712, /* 18088 ( 413) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
     1433658, /* 18089 ( 413) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  0]  1 */
       16484, /* 18090 ( 414) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    52438874, /* 18091 ( 414) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
    17127570, /* 18092 ( 414) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6]  1 */
     1420376, /* 18093 ( 414) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  0]  1 */
    18557706, /* 18094 ( 414) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
    35550698, /* 18095 ( 414) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
    17140532, /* 18096 ( 414) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
    34133520, /* 18097 ( 414) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
    51021696, /* 18098 ( 414) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  0] -1 */
        3198, /* 18099 ( 414) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    51034658, /* 18100 ( 414) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  0] -1 */
    34146806, /* 18101 ( 414) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    35563980, /* 18102 ( 414) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6] -1 */
    18544748, /* 18103 ( 414) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    52451832, /* 18104 ( 414) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
     1433658, /* 18105 ( 414) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  0]  1 */
       16484, /* 18106 ( 415) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34028546, /* 18107 ( 415) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    17127570, /* 18108 ( 415) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6]  1 */
    51139632, /* 18109 ( 415) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  6] -1 */
     1420376, /* 18110 ( 415) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  0]  1 */
    52556810, /* 18111 ( 415) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    18557706, /* 18112 ( 415) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
    35445720, /* 18113 ( 415) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  0] -1 */
    51152918, /* 18114 ( 415) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
    17140532, /* 18115 ( 415) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
        3198, /* 18116 ( 415) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    18544748, /* 18117 ( 415) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    52570092, /* 18118 ( 415) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
     1433658, /* 18119 ( 415) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  0]  1 */
    34015584, /* 18120 ( 415) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    35432762, /* 18121 ( 415) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  0] -1 */
       16484, /* 18122 ( 416) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    17127570, /* 18123 ( 416) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6]  1 */
    34133522, /* 18124 ( 416) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
     1420376, /* 18125 ( 416) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  0]  1 */
    18557706, /* 18126 ( 416) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
    52451834, /* 18127 ( 416) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
    51034656, /* 18128 ( 416) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  0] -1 */
    17140532, /* 18129 ( 416) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
    35550696, /* 18130 ( 416) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  6] -1 */
    34146804, /* 18131 ( 416) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
        3198, /* 18132 ( 416) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    51021698, /* 18133 ( 416) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  0] -1 */
    35563982, /* 18134 ( 416) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
    18544748, /* 18135 ( 416) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
     1433658, /* 18136 ( 416) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  0]  1 */
    52438872, /* 18137 ( 416) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
       16484, /* 18138 ( 417) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    51034818, /* 18139 ( 417) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  0] -1 */
    17127570, /* 18140 ( 417) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6]  1 */
     1420376, /* 18141 ( 417) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  0]  1 */
    52438710, /* 18142 ( 417) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
    18557706, /* 18143 ( 417) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
    34133684, /* 18144 ( 417) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    51021536, /* 18145 ( 417) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  0] -1 */
    17140532, /* 18146 ( 417) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
    52451996, /* 18147 ( 417) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
        3198, /* 18148 ( 417) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    35563820, /* 18149 ( 417) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
    35550858, /* 18150 ( 417) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6] -1 */
    34146642, /* 18151 ( 417) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
    18544748, /* 18152 ( 417) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
     1433658, /* 18153 ( 417) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  0]  1 */
       16484, /* 18154 ( 418) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    17127570, /* 18155 ( 418) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6]  1 */
     1420376, /* 18156 ( 418) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  0]  1 */
    35445722, /* 18157 ( 418) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  0] -1 */
    18557706, /* 18158 ( 418) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
    35432760, /* 18159 ( 418) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  0] -1 */
    34028544, /* 18160 ( 418) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    51152916, /* 18161 ( 418) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6] -1 */
    17140532, /* 18162 ( 418) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
        3198, /* 18163 ( 418) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    51139634, /* 18164 ( 418) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
    34015586, /* 18165 ( 418) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    18544748, /* 18166 ( 418) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
     1433658, /* 18167 ( 418) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  0]  1 */
    52570094, /* 18168 ( 418) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    52556808, /* 18169 ( 418) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
       16484, /* 18170 ( 403) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    17127570, /* 18171 ( 403) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6]  1 */
     1433496, /* 18172 ( 403) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  0]  1 */
    18544586, /* 18173 ( 403) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    17140532, /* 18174 ( 403) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
        3198, /* 18175 ( 403) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    18557868, /* 18176 ( 403) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
     1420538, /* 18177 ( 403) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  0]  1 */
       16484, /* 18178 ( 404) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    17127570, /* 18179 ( 404) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6]  1 */
    34015422, /* 18180 ( 404) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
     1433496, /* 18181 ( 404) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  0]  1 */
    51152756, /* 18182 ( 404) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
    18544586, /* 18183 ( 404) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    52570092, /* 18184 ( 404) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    35432762, /* 18185 ( 404) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  0] -1 */
    17140532, /* 18186 ( 404) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
        3198, /* 18187 ( 404) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    52556810, /* 18188 ( 404) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    35445720, /* 18189 ( 404) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  0] -1 */
    18557868, /* 18190 ( 404) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
    34028708, /* 18191 ( 404) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
     1420538, /* 18192 ( 404) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  0]  1 */
    51139794, /* 18193 ( 404) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6] -1 */
       16484, /* 18194 ( 405) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    17127570, /* 18195 ( 405) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6]  1 */
    34015422, /* 18196 ( 405) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    51152756, /* 18197 ( 405) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
    52556810, /* 18198 ( 405) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    35445720, /* 18199 ( 405) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  0] -1 */
    18557868, /* 18200 ( 405) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
     1420538, /* 18201 ( 405) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  0]  1 */
       16484, /* 18202 ( 406) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34015422, /* 18203 ( 406) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    52570092, /* 18204 ( 406) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    17140532, /* 18205 ( 406) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
    35445720, /* 18206 ( 406) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  0] -1 */
    18544586, /* 18207 ( 406) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    51139794, /* 18208 ( 406) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6] -1 */
     1420538, /* 18209 ( 406) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  0]  1 */
       16484, /* 18210 ( 407) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34015422, /* 18211 ( 407) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
     1433496, /* 18212 ( 407) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  0]  1 */
    35432762, /* 18213 ( 407) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  0] -1 */
    17140532, /* 18214 ( 407) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
    52556810, /* 18215 ( 407) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    18557868, /* 18216 ( 407) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
    51139794, /* 18217 ( 407) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6] -1 */
       16484, /* 18218 ( 408) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
     1433496, /* 18219 ( 408) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  0]  1 */
    51152756, /* 18220 ( 408) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
    52570092, /* 18221 ( 408) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
        3198, /* 18222 ( 408) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    52556810, /* 18223 ( 408) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
     1420538, /* 18224 ( 408) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  0]  1 */
    51139794, /* 18225 ( 408) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6] -1 */
       16484, /* 18226 ( 409) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    17127570, /* 18227 ( 409) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6]  1 */
    52570092, /* 18228 ( 409) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    35432762, /* 18229 ( 409) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  0] -1 */
    17140532, /* 18230 ( 409) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
        3198, /* 18231 ( 409) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    52556810, /* 18232 ( 409) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    35445720, /* 18233 ( 409) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  0] -1 */
       16484, /* 18234 ( 410) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    51152756, /* 18235 ( 410) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
    35432762, /* 18236 ( 410) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  0] -1 */
        3198, /* 18237 ( 410) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    35445720, /* 18238 ( 410) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  0] -1 */
    18557868, /* 18239 ( 410) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
    18544586, /* 18240 ( 410) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    51139794, /* 18241 ( 410) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6] -1 */
       16484, /* 18242 ( 411) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    17127570, /* 18243 ( 411) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6]  1 */
    34015422, /* 18244 ( 411) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
     1433496, /* 18245 ( 411) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  0]  1 */
    51152756, /* 18246 ( 411) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
    52570092, /* 18247 ( 411) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    35432762, /* 18248 ( 411) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  0] -1 */
    18544586, /* 18249 ( 411) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
       16484, /* 18250 ( 412) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    17127570, /* 18251 ( 412) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6]  1 */
     1433496, /* 18252 ( 412) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  0]  1 */
    51139634, /* 18253 ( 412) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
    35445884, /* 18254 ( 412) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  0] -1 */
    18544586, /* 18255 ( 412) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    34015586, /* 18256 ( 412) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    17140532, /* 18257 ( 412) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
        3198, /* 18258 ( 412) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    35432598, /* 18259 ( 412) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  0] -1 */
    52569932, /* 18260 ( 412) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    34028544, /* 18261 ( 412) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    18557868, /* 18262 ( 412) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
     1420538, /* 18263 ( 412) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  0]  1 */
    51152916, /* 18264 ( 412) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6] -1 */
    52556970, /* 18265 ( 412) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
       16484, /* 18266 ( 413) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    52438712, /* 18267 ( 413) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
    17127570, /* 18268 ( 413) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6]  1 */
     1433496, /* 18269 ( 413) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  0]  1 */
    52451994, /* 18270 ( 413) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
    18544586, /* 18271 ( 413) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    17140532, /* 18272 ( 413) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
    35550860, /* 18273 ( 413) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
        3198, /* 18274 ( 413) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    18557868, /* 18275 ( 413) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
    34146806, /* 18276 ( 413) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    51034658, /* 18277 ( 413) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  0] -1 */
    51021696, /* 18278 ( 413) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  0] -1 */
    34133520, /* 18279 ( 413) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
    35563818, /* 18280 ( 413) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  6] -1 */
     1420538, /* 18281 ( 413) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  0]  1 */
       16484, /* 18282 ( 414) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    35563980, /* 18283 ( 414) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6] -1 */
    17127570, /* 18284 ( 414) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6]  1 */
     1433496, /* 18285 ( 414) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  0]  1 */
    18544586, /* 18286 ( 414) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    52451832, /* 18287 ( 414) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
    17140532, /* 18288 ( 414) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
    51021534, /* 18289 ( 414) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  0] -1 */
    34133682, /* 18290 ( 414) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
        3198, /* 18291 ( 414) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    34146644, /* 18292 ( 414) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    51034820, /* 18293 ( 414) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  0] -1 */
    52438874, /* 18294 ( 414) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
    18557868, /* 18295 ( 414) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
    35550698, /* 18296 ( 414) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
     1420538, /* 18297 ( 414) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  0]  1 */
       16484, /* 18298 ( 415) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34028546, /* 18299 ( 415) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    17127570, /* 18300 ( 415) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6]  1 */
    51139632, /* 18301 ( 415) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  6] -1 */
     1433496, /* 18302 ( 415) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  0]  1 */
    52569930, /* 18303 ( 415) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    18544586, /* 18304 ( 415) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    35432600, /* 18305 ( 415) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  0] -1 */
    51152918, /* 18306 ( 415) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
    17140532, /* 18307 ( 415) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
        3198, /* 18308 ( 415) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    18557868, /* 18309 ( 415) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
    52556972, /* 18310 ( 415) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
     1420538, /* 18311 ( 415) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  0]  1 */
    34015584, /* 18312 ( 415) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    35445882, /* 18313 ( 415) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  0] -1 */
       16484, /* 18314 ( 416) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    17127570, /* 18315 ( 416) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6]  1 */
    51034656, /* 18316 ( 416) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  0] -1 */
     1433496, /* 18317 ( 416) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  0]  1 */
    18544586, /* 18318 ( 416) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    35563820, /* 18319 ( 416) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
    34133522, /* 18320 ( 416) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    17140532, /* 18321 ( 416) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
    52438710, /* 18322 ( 416) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
    51021698, /* 18323 ( 416) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  0] -1 */
        3198, /* 18324 ( 416) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    34146804, /* 18325 ( 416) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
    52451996, /* 18326 ( 416) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
    18557868, /* 18327 ( 416) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
     1420538, /* 18328 ( 416) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  0]  1 */
    35550858, /* 18329 ( 416) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6] -1 */
       16484, /* 18330 ( 417) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34133684, /* 18331 ( 417) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    17127570, /* 18332 ( 417) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6]  1 */
     1433496, /* 18333 ( 417) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  0]  1 */
    35550696, /* 18334 ( 417) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  6] -1 */
    18544586, /* 18335 ( 417) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    51034818, /* 18336 ( 417) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  0] -1 */
    34146642, /* 18337 ( 417) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
    17140532, /* 18338 ( 417) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
    35563982, /* 18339 ( 417) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
        3198, /* 18340 ( 417) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    52451834, /* 18341 ( 417) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
    52438872, /* 18342 ( 417) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
    51021536, /* 18343 ( 417) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  0] -1 */
    18557868, /* 18344 ( 417) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
     1420538, /* 18345 ( 417) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  0]  1 */
       16484, /* 18346 ( 418) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    17127570, /* 18347 ( 418) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6]  1 */
     1433496, /* 18348 ( 418) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  0]  1 */
    35445722, /* 18349 ( 418) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  0] -1 */
    18544586, /* 18350 ( 418) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    35432760, /* 18351 ( 418) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  0] -1 */
    34015424, /* 18352 ( 418) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    51139796, /* 18353 ( 418) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
    17140532, /* 18354 ( 418) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
        3198, /* 18355 ( 418) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    51152754, /* 18356 ( 418) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  6] -1 */
    34028706, /* 18357 ( 418) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    18557868, /* 18358 ( 418) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
     1420538, /* 18359 ( 418) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  0]  1 */
    52570094, /* 18360 ( 418) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    52556808, /* 18361 ( 418) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
       16484, /* 18362 ( 403) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    18426488, /* 18363 ( 403) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
      134418, /* 18364 ( 403) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  6]  1 */
    18544746, /* 18365 ( 403) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
    18439770, /* 18366 ( 403) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
        3198, /* 18367 ( 403) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    18557708, /* 18368 ( 403) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
      121460, /* 18369 ( 403) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6]  1 */
       16484, /* 18370 ( 404) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    18426488, /* 18371 ( 404) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    34015422, /* 18372 ( 404) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
      134418, /* 18373 ( 404) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  6]  1 */
    52451994, /* 18374 ( 404) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
    18544746, /* 18375 ( 404) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
    52569932, /* 18376 ( 404) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    34133684, /* 18377 ( 404) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    18439770, /* 18378 ( 404) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
        3198, /* 18379 ( 404) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    52556970, /* 18380 ( 404) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    34146642, /* 18381 ( 404) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
    18557708, /* 18382 ( 404) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    34028708, /* 18383 ( 404) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
      121460, /* 18384 ( 404) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6]  1 */
    52438712, /* 18385 ( 404) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
       16484, /* 18386 ( 405) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    18426488, /* 18387 ( 405) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    34015422, /* 18388 ( 405) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    52451994, /* 18389 ( 405) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
    52556970, /* 18390 ( 405) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    34146642, /* 18391 ( 405) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
    18557708, /* 18392 ( 405) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
      121460, /* 18393 ( 405) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6]  1 */
       16484, /* 18394 ( 406) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34015422, /* 18395 ( 406) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    52569932, /* 18396 ( 406) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    18439770, /* 18397 ( 406) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
    34146642, /* 18398 ( 406) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
    18544746, /* 18399 ( 406) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
    52438712, /* 18400 ( 406) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
      121460, /* 18401 ( 406) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6]  1 */
       16484, /* 18402 ( 407) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34015422, /* 18403 ( 407) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
      134418, /* 18404 ( 407) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  6]  1 */
    34133684, /* 18405 ( 407) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    18439770, /* 18406 ( 407) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
    52556970, /* 18407 ( 407) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    18557708, /* 18408 ( 407) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    52438712, /* 18409 ( 407) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
       16484, /* 18410 ( 408) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
      134418, /* 18411 ( 408) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  6]  1 */
    52451994, /* 18412 ( 408) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
    52569932, /* 18413 ( 408) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
        3198, /* 18414 ( 408) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    52556970, /* 18415 ( 408) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
      121460, /* 18416 ( 408) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6]  1 */
    52438712, /* 18417 ( 408) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
       16484, /* 18418 ( 409) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    18426488, /* 18419 ( 409) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    52569932, /* 18420 ( 409) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    34133684, /* 18421 ( 409) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    18439770, /* 18422 ( 409) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
        3198, /* 18423 ( 409) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    52556970, /* 18424 ( 409) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    34146642, /* 18425 ( 409) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
       16484, /* 18426 ( 410) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    52451994, /* 18427 ( 410) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
    34133684, /* 18428 ( 410) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
        3198, /* 18429 ( 410) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    34146642, /* 18430 ( 410) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
    18557708, /* 18431 ( 410) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    18544746, /* 18432 ( 410) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
    52438712, /* 18433 ( 410) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
       16484, /* 18434 ( 411) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    18426488, /* 18435 ( 411) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    34015422, /* 18436 ( 411) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
      134418, /* 18437 ( 411) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  6]  1 */
    52451994, /* 18438 ( 411) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
    52569932, /* 18439 ( 411) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    34133684, /* 18440 ( 411) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    18544746, /* 18441 ( 411) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
       16484, /* 18442 ( 412) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    18426488, /* 18443 ( 412) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
      134418, /* 18444 ( 412) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  6]  1 */
    52438872, /* 18445 ( 412) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
    34146806, /* 18446 ( 412) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    18544746, /* 18447 ( 412) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
    34015586, /* 18448 ( 412) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    18439770, /* 18449 ( 412) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
        3198, /* 18450 ( 412) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    34133520, /* 18451 ( 412) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
    52570092, /* 18452 ( 412) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    34028544, /* 18453 ( 412) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    18557708, /* 18454 ( 412) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
      121460, /* 18455 ( 412) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6]  1 */
    52451834, /* 18456 ( 412) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
    52556810, /* 18457 ( 412) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
       16484, /* 18458 ( 413) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    51139794, /* 18459 ( 413) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6] -1 */
    18426488, /* 18460 ( 413) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
      134418, /* 18461 ( 413) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  6]  1 */
    51152756, /* 18462 ( 413) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
    18544746, /* 18463 ( 413) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
    18439770, /* 18464 ( 413) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
    35550860, /* 18465 ( 413) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
        3198, /* 18466 ( 413) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    18557708, /* 18467 ( 413) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    35445884, /* 18468 ( 413) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  0] -1 */
    51034818, /* 18469 ( 413) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  0] -1 */
    51021536, /* 18470 ( 413) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  0] -1 */
    35432598, /* 18471 ( 413) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  0] -1 */
    35563818, /* 18472 ( 413) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  6] -1 */
      121460, /* 18473 ( 413) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6]  1 */
       16484, /* 18474 ( 414) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    35563820, /* 18475 ( 414) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
    18426488, /* 18476 ( 414) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
      134418, /* 18477 ( 414) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  6]  1 */
    18544746, /* 18478 ( 414) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
    51152754, /* 18479 ( 414) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  6] -1 */
    18439770, /* 18480 ( 414) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
    51021534, /* 18481 ( 414) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  0] -1 */
    35432600, /* 18482 ( 414) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  0] -1 */
        3198, /* 18483 ( 414) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    35445882, /* 18484 ( 414) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  0] -1 */
    51034820, /* 18485 ( 414) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  0] -1 */
    51139796, /* 18486 ( 414) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
    18557708, /* 18487 ( 414) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    35550858, /* 18488 ( 414) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6] -1 */
      121460, /* 18489 ( 414) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6]  1 */
       16484, /* 18490 ( 415) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34028706, /* 18491 ( 415) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    18426488, /* 18492 ( 415) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    52438710, /* 18493 ( 415) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
      134418, /* 18494 ( 415) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  6]  1 */
    52569930, /* 18495 ( 415) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    18544746, /* 18496 ( 415) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
    34133682, /* 18497 ( 415) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
    52451996, /* 18498 ( 415) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
    18439770, /* 18499 ( 415) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
        3198, /* 18500 ( 415) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    18557708, /* 18501 ( 415) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    52556972, /* 18502 ( 415) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
      121460, /* 18503 ( 415) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6]  1 */
    34015424, /* 18504 ( 415) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    34146644, /* 18505 ( 415) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
       16484, /* 18506 ( 416) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    18426488, /* 18507 ( 416) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    51034656, /* 18508 ( 416) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  0] -1 */
      134418, /* 18509 ( 416) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  6]  1 */
    18544746, /* 18510 ( 416) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
    35563980, /* 18511 ( 416) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6] -1 */
    35432760, /* 18512 ( 416) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  0] -1 */
    18439770, /* 18513 ( 416) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
    51139632, /* 18514 ( 416) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  6] -1 */
    51021698, /* 18515 ( 416) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  0] -1 */
        3198, /* 18516 ( 416) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    35445722, /* 18517 ( 416) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  0] -1 */
    51152918, /* 18518 ( 416) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
    18557708, /* 18519 ( 416) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
      121460, /* 18520 ( 416) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6]  1 */
    35550698, /* 18521 ( 416) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
       16484, /* 18522 ( 417) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    35432762, /* 18523 ( 417) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  0] -1 */
    18426488, /* 18524 ( 417) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
      134418, /* 18525 ( 417) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  6]  1 */
    35550696, /* 18526 ( 417) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  6] -1 */
    18544746, /* 18527 ( 417) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
    51034658, /* 18528 ( 417) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  0] -1 */
    35445720, /* 18529 ( 417) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  0] -1 */
    18439770, /* 18530 ( 417) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
    35563982, /* 18531 ( 417) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
        3198, /* 18532 ( 417) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    51152916, /* 18533 ( 417) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6] -1 */
    51139634, /* 18534 ( 417) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
    51021696, /* 18535 ( 417) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  0] -1 */
    18557708, /* 18536 ( 417) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
      121460, /* 18537 ( 417) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6]  1 */
       16484, /* 18538 ( 418) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    18426488, /* 18539 ( 418) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
      134418, /* 18540 ( 418) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  6]  1 */
    34146804, /* 18541 ( 418) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
    18544746, /* 18542 ( 418) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
    34133522, /* 18543 ( 418) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    34015584, /* 18544 ( 418) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    52438874, /* 18545 ( 418) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
    18439770, /* 18546 ( 418) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
        3198, /* 18547 ( 418) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    52451832, /* 18548 ( 418) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
    34028546, /* 18549 ( 418) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    18557708, /* 18550 ( 418) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
      121460, /* 18551 ( 418) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6]  1 */
    52570094, /* 18552 ( 418) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    52556808, /* 18553 ( 418) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
       16484, /* 18554 ( 403) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    18426488, /* 18555 ( 403) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
      121458, /* 18556 ( 403) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  6]  1 */
    18557706, /* 18557 ( 403) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
    18439770, /* 18558 ( 403) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
        3198, /* 18559 ( 403) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    18544748, /* 18560 ( 403) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
      134420, /* 18561 ( 403) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6]  1 */
       16484, /* 18562 ( 404) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    18426488, /* 18563 ( 404) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    34015422, /* 18564 ( 404) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
      121458, /* 18565 ( 404) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  6]  1 */
    52451994, /* 18566 ( 404) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
    18557706, /* 18567 ( 404) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
    52556972, /* 18568 ( 404) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    34146644, /* 18569 ( 404) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    18439770, /* 18570 ( 404) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
        3198, /* 18571 ( 404) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    52569930, /* 18572 ( 404) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    34133682, /* 18573 ( 404) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
    18544748, /* 18574 ( 404) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    34028708, /* 18575 ( 404) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
      134420, /* 18576 ( 404) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6]  1 */
    52438712, /* 18577 ( 404) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
       16484, /* 18578 ( 405) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    18426488, /* 18579 ( 405) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    34015422, /* 18580 ( 405) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    52451994, /* 18581 ( 405) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
    52569930, /* 18582 ( 405) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    34133682, /* 18583 ( 405) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
    18544748, /* 18584 ( 405) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
      134420, /* 18585 ( 405) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6]  1 */
       16484, /* 18586 ( 406) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34015422, /* 18587 ( 406) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    52556972, /* 18588 ( 406) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    18439770, /* 18589 ( 406) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
    34133682, /* 18590 ( 406) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
    18557706, /* 18591 ( 406) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
    52438712, /* 18592 ( 406) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
      134420, /* 18593 ( 406) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6]  1 */
       16484, /* 18594 ( 407) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34015422, /* 18595 ( 407) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
      121458, /* 18596 ( 407) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  6]  1 */
    34146644, /* 18597 ( 407) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    18439770, /* 18598 ( 407) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
    52569930, /* 18599 ( 407) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    18544748, /* 18600 ( 407) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    52438712, /* 18601 ( 407) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
       16484, /* 18602 ( 408) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
      121458, /* 18603 ( 408) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  6]  1 */
    52451994, /* 18604 ( 408) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
    52556972, /* 18605 ( 408) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
        3198, /* 18606 ( 408) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    52569930, /* 18607 ( 408) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
      134420, /* 18608 ( 408) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6]  1 */
    52438712, /* 18609 ( 408) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
       16484, /* 18610 ( 409) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    18426488, /* 18611 ( 409) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    52556972, /* 18612 ( 409) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    34146644, /* 18613 ( 409) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    18439770, /* 18614 ( 409) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
        3198, /* 18615 ( 409) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    52569930, /* 18616 ( 409) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    34133682, /* 18617 ( 409) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
       16484, /* 18618 ( 410) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    52451994, /* 18619 ( 410) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
    34146644, /* 18620 ( 410) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
        3198, /* 18621 ( 410) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    34133682, /* 18622 ( 410) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
    18544748, /* 18623 ( 410) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    18557706, /* 18624 ( 410) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
    52438712, /* 18625 ( 410) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
       16484, /* 18626 ( 411) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    18426488, /* 18627 ( 411) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    34015422, /* 18628 ( 411) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
      121458, /* 18629 ( 411) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  6]  1 */
    52451994, /* 18630 ( 411) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
    52556972, /* 18631 ( 411) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    34146644, /* 18632 ( 411) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    18557706, /* 18633 ( 411) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
       16484, /* 18634 ( 412) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    18426488, /* 18635 ( 412) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
      121458, /* 18636 ( 412) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  6]  1 */
    52451832, /* 18637 ( 412) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
    34146806, /* 18638 ( 412) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    18557706, /* 18639 ( 412) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
    34028546, /* 18640 ( 412) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    18439770, /* 18641 ( 412) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
        3198, /* 18642 ( 412) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    34133520, /* 18643 ( 412) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
    52570092, /* 18644 ( 412) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    34015584, /* 18645 ( 412) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    18544748, /* 18646 ( 412) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
      134420, /* 18647 ( 412) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6]  1 */
    52438874, /* 18648 ( 412) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
    52556810, /* 18649 ( 412) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
       16484, /* 18650 ( 413) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    35563818, /* 18651 ( 413) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  6] -1 */
    18426488, /* 18652 ( 413) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
      121458, /* 18653 ( 413) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  6]  1 */
    35550860, /* 18654 ( 413) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
    18557706, /* 18655 ( 413) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
    18439770, /* 18656 ( 413) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
    51152756, /* 18657 ( 413) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
        3198, /* 18658 ( 413) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    18544748, /* 18659 ( 413) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    51034820, /* 18660 ( 413) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  0] -1 */
    35445882, /* 18661 ( 413) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  0] -1 */
    35432600, /* 18662 ( 413) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  0] -1 */
    51021534, /* 18663 ( 413) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  0] -1 */
    51139794, /* 18664 ( 413) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6] -1 */
      134420, /* 18665 ( 413) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6]  1 */
       16484, /* 18666 ( 414) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    51139796, /* 18667 ( 414) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
    18426488, /* 18668 ( 414) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
      121458, /* 18669 ( 414) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  6]  1 */
    18557706, /* 18670 ( 414) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
    35550858, /* 18671 ( 414) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6] -1 */
    18439770, /* 18672 ( 414) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
    35432598, /* 18673 ( 414) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  0] -1 */
    51021536, /* 18674 ( 414) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  0] -1 */
        3198, /* 18675 ( 414) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    51034818, /* 18676 ( 414) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  0] -1 */
    35445884, /* 18677 ( 414) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  0] -1 */
    35563820, /* 18678 ( 414) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
    18544748, /* 18679 ( 414) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    51152754, /* 18680 ( 414) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  6] -1 */
      134420, /* 18681 ( 414) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6]  1 */
       16484, /* 18682 ( 415) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34028706, /* 18683 ( 415) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    18426488, /* 18684 ( 415) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    52438710, /* 18685 ( 415) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
      121458, /* 18686 ( 415) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  6]  1 */
    52556970, /* 18687 ( 415) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    18557706, /* 18688 ( 415) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
    34146642, /* 18689 ( 415) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
    52451996, /* 18690 ( 415) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
    18439770, /* 18691 ( 415) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
        3198, /* 18692 ( 415) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    18544748, /* 18693 ( 415) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    52569932, /* 18694 ( 415) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
      134420, /* 18695 ( 415) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6]  1 */
    34015424, /* 18696 ( 415) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    34133684, /* 18697 ( 415) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
       16484, /* 18698 ( 416) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    18426488, /* 18699 ( 416) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    35432760, /* 18700 ( 416) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  0] -1 */
      121458, /* 18701 ( 416) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  6]  1 */
    18557706, /* 18702 ( 416) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
    51152916, /* 18703 ( 416) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6] -1 */
    51034656, /* 18704 ( 416) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  0] -1 */
    18439770, /* 18705 ( 416) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
    35550696, /* 18706 ( 416) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  6] -1 */
    35445722, /* 18707 ( 416) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  0] -1 */
        3198, /* 18708 ( 416) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    51021698, /* 18709 ( 416) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  0] -1 */
    35563982, /* 18710 ( 416) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
    18544748, /* 18711 ( 416) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
      134420, /* 18712 ( 416) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6]  1 */
    51139634, /* 18713 ( 416) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
       16484, /* 18714 ( 417) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    51034658, /* 18715 ( 417) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  0] -1 */
    18426488, /* 18716 ( 417) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
      121458, /* 18717 ( 417) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  6]  1 */
    51139632, /* 18718 ( 417) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  6] -1 */
    18557706, /* 18719 ( 417) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
    35432762, /* 18720 ( 417) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  0] -1 */
    51021696, /* 18721 ( 417) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  0] -1 */
    18439770, /* 18722 ( 417) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
    51152918, /* 18723 ( 417) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
        3198, /* 18724 ( 417) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    35563980, /* 18725 ( 417) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6] -1 */
    35550698, /* 18726 ( 417) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
    35445720, /* 18727 ( 417) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  0] -1 */
    18544748, /* 18728 ( 417) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
      134420, /* 18729 ( 417) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6]  1 */
       16484, /* 18730 ( 418) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    18426488, /* 18731 ( 418) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
      121458, /* 18732 ( 418) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  6]  1 */
    34146804, /* 18733 ( 418) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
    18557706, /* 18734 ( 418) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
    34133522, /* 18735 ( 418) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    34028544, /* 18736 ( 418) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    52451834, /* 18737 ( 418) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
    18439770, /* 18738 ( 418) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
        3198, /* 18739 ( 418) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    52438872, /* 18740 ( 418) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
    34015586, /* 18741 ( 418) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    18544748, /* 18742 ( 418) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
      134420, /* 18743 ( 418) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6]  1 */
    52570094, /* 18744 ( 418) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    52556808, /* 18745 ( 418) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
       16484, /* 18746 ( 403) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
     1551594, /* 18747 ( 403) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
    17009472, /* 18748 ( 403) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  0]  1 */
    18544586, /* 18749 ( 403) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
     1538636, /* 18750 ( 403) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
        3198, /* 18751 ( 403) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    18557868, /* 18752 ( 403) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
    17022434, /* 18753 ( 403) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  0]  1 */
       16484, /* 18754 ( 404) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
     1551594, /* 18755 ( 404) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
    34015422, /* 18756 ( 404) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    17009472, /* 18757 ( 404) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  0]  1 */
    35550860, /* 18758 ( 404) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
    18544586, /* 18759 ( 404) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    52570092, /* 18760 ( 404) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    51034658, /* 18761 ( 404) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  0] -1 */
     1538636, /* 18762 ( 404) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
        3198, /* 18763 ( 404) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    52556810, /* 18764 ( 404) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    51021696, /* 18765 ( 404) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  0] -1 */
    18557868, /* 18766 ( 404) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
    34028708, /* 18767 ( 404) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    17022434, /* 18768 ( 404) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  0]  1 */
    35563818, /* 18769 ( 404) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  6] -1 */
       16484, /* 18770 ( 405) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
     1551594, /* 18771 ( 405) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
    34015422, /* 18772 ( 405) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    35550860, /* 18773 ( 405) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
    52556810, /* 18774 ( 405) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    51021696, /* 18775 ( 405) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  0] -1 */
    18557868, /* 18776 ( 405) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
    17022434, /* 18777 ( 405) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  0]  1 */
       16484, /* 18778 ( 406) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34015422, /* 18779 ( 406) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    52570092, /* 18780 ( 406) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
     1538636, /* 18781 ( 406) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
    51021696, /* 18782 ( 406) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  0] -1 */
    18544586, /* 18783 ( 406) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    35563818, /* 18784 ( 406) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  6] -1 */
    17022434, /* 18785 ( 406) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  0]  1 */
       16484, /* 18786 ( 407) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34015422, /* 18787 ( 407) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    17009472, /* 18788 ( 407) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  0]  1 */
    51034658, /* 18789 ( 407) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  0] -1 */
     1538636, /* 18790 ( 407) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
    52556810, /* 18791 ( 407) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    18557868, /* 18792 ( 407) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
    35563818, /* 18793 ( 407) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  6] -1 */
       16484, /* 18794 ( 408) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    17009472, /* 18795 ( 408) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  0]  1 */
    35550860, /* 18796 ( 408) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
    52570092, /* 18797 ( 408) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
        3198, /* 18798 ( 408) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    52556810, /* 18799 ( 408) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    17022434, /* 18800 ( 408) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  0]  1 */
    35563818, /* 18801 ( 408) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  6] -1 */
       16484, /* 18802 ( 409) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
     1551594, /* 18803 ( 409) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
    52570092, /* 18804 ( 409) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    51034658, /* 18805 ( 409) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  0] -1 */
     1538636, /* 18806 ( 409) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
        3198, /* 18807 ( 409) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    52556810, /* 18808 ( 409) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    51021696, /* 18809 ( 409) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  0] -1 */
       16484, /* 18810 ( 410) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    35550860, /* 18811 ( 410) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
    51034658, /* 18812 ( 410) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  0] -1 */
        3198, /* 18813 ( 410) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    51021696, /* 18814 ( 410) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  0] -1 */
    18557868, /* 18815 ( 410) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
    18544586, /* 18816 ( 410) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    35563818, /* 18817 ( 410) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  6] -1 */
       16484, /* 18818 ( 411) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
     1551594, /* 18819 ( 411) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
    34015422, /* 18820 ( 411) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    17009472, /* 18821 ( 411) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  0]  1 */
    35550860, /* 18822 ( 411) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
    52570092, /* 18823 ( 411) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    51034658, /* 18824 ( 411) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  0] -1 */
    18544586, /* 18825 ( 411) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
       16484, /* 18826 ( 412) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
     1551594, /* 18827 ( 412) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
    17009472, /* 18828 ( 412) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  0]  1 */
    35550698, /* 18829 ( 412) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
    51034820, /* 18830 ( 412) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  0] -1 */
    18544586, /* 18831 ( 412) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    34028546, /* 18832 ( 412) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
     1538636, /* 18833 ( 412) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
        3198, /* 18834 ( 412) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    51021534, /* 18835 ( 412) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  0] -1 */
    52556972, /* 18836 ( 412) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    34015584, /* 18837 ( 412) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    18557868, /* 18838 ( 412) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
    17022434, /* 18839 ( 412) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  0]  1 */
    35563980, /* 18840 ( 412) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6] -1 */
    52569930, /* 18841 ( 412) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
       16484, /* 18842 ( 413) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    52438712, /* 18843 ( 413) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
     1551594, /* 18844 ( 413) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
    17009472, /* 18845 ( 413) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  0]  1 */
    52451994, /* 18846 ( 413) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
    18544586, /* 18847 ( 413) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
     1538636, /* 18848 ( 413) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
    51152756, /* 18849 ( 413) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
        3198, /* 18850 ( 413) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    18557868, /* 18851 ( 413) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
    34146806, /* 18852 ( 413) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    35432762, /* 18853 ( 413) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  0] -1 */
    35445720, /* 18854 ( 413) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  0] -1 */
    34133520, /* 18855 ( 413) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
    51139794, /* 18856 ( 413) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6] -1 */
    17022434, /* 18857 ( 413) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  0]  1 */
       16484, /* 18858 ( 414) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    51152916, /* 18859 ( 414) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6] -1 */
     1551594, /* 18860 ( 414) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
    17009472, /* 18861 ( 414) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  0]  1 */
    18544586, /* 18862 ( 414) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    52438872, /* 18863 ( 414) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
     1538636, /* 18864 ( 414) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
    35432598, /* 18865 ( 414) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  0] -1 */
    34146642, /* 18866 ( 414) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
        3198, /* 18867 ( 414) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    34133684, /* 18868 ( 414) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    35445884, /* 18869 ( 414) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  0] -1 */
    52451834, /* 18870 ( 414) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
    18557868, /* 18871 ( 414) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
    51139634, /* 18872 ( 414) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
    17022434, /* 18873 ( 414) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  0]  1 */
       16484, /* 18874 ( 415) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34015586, /* 18875 ( 415) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
     1551594, /* 18876 ( 415) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
    35550696, /* 18877 ( 415) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  6] -1 */
    17009472, /* 18878 ( 415) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  0]  1 */
    52556970, /* 18879 ( 415) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    18544586, /* 18880 ( 415) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    51021536, /* 18881 ( 415) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  0] -1 */
    35563982, /* 18882 ( 415) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
     1538636, /* 18883 ( 415) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
        3198, /* 18884 ( 415) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    18557868, /* 18885 ( 415) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
    52569932, /* 18886 ( 415) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    17022434, /* 18887 ( 415) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  0]  1 */
    34028544, /* 18888 ( 415) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    51034818, /* 18889 ( 415) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  0] -1 */
       16484, /* 18890 ( 416) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
     1551594, /* 18891 ( 416) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
    35432760, /* 18892 ( 416) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  0] -1 */
    17009472, /* 18893 ( 416) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  0]  1 */
    18544586, /* 18894 ( 416) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    51139796, /* 18895 ( 416) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
    34133522, /* 18896 ( 416) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
     1538636, /* 18897 ( 416) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
    52438710, /* 18898 ( 416) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
    35445722, /* 18899 ( 416) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  0] -1 */
        3198, /* 18900 ( 416) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    34146804, /* 18901 ( 416) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
    52451996, /* 18902 ( 416) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
    18557868, /* 18903 ( 416) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
    17022434, /* 18904 ( 416) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  0]  1 */
    51152754, /* 18905 ( 416) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  6] -1 */
       16484, /* 18906 ( 417) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34146644, /* 18907 ( 417) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
     1551594, /* 18908 ( 417) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
    17009472, /* 18909 ( 417) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  0]  1 */
    51139632, /* 18910 ( 417) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  6] -1 */
    18544586, /* 18911 ( 417) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    35445882, /* 18912 ( 417) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  0] -1 */
    34133682, /* 18913 ( 417) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
     1538636, /* 18914 ( 417) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
    51152918, /* 18915 ( 417) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
        3198, /* 18916 ( 417) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    52438874, /* 18917 ( 417) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
    52451832, /* 18918 ( 417) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
    35432600, /* 18919 ( 417) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  0] -1 */
    18557868, /* 18920 ( 417) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
    17022434, /* 18921 ( 417) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  0]  1 */
       16484, /* 18922 ( 418) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
     1551594, /* 18923 ( 418) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
    17009472, /* 18924 ( 418) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  0]  1 */
    51021698, /* 18925 ( 418) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  0] -1 */
    18544586, /* 18926 ( 418) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    51034656, /* 18927 ( 418) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  0] -1 */
    34015424, /* 18928 ( 418) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    35563820, /* 18929 ( 418) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
     1538636, /* 18930 ( 418) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
        3198, /* 18931 ( 418) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    35550858, /* 18932 ( 418) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6] -1 */
    34028706, /* 18933 ( 418) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    18557868, /* 18934 ( 418) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
    17022434, /* 18935 ( 418) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  0]  1 */
    52570094, /* 18936 ( 418) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    52556808, /* 18937 ( 418) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
       16484, /* 18938 ( 419) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    17140692, /* 18939 ( 419) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6]  1 */
        3362, /* 18940 ( 419) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    17127570, /* 18941 ( 419) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6]  1 */
       16320, /* 18942 ( 419) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
        3198, /* 18943 ( 419) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    17127410, /* 18944 ( 419) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
    17140532, /* 18945 ( 419) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
       16484, /* 18946 ( 420) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34015586, /* 18947 ( 420) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    51139794, /* 18948 ( 420) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6] -1 */
    17140692, /* 18949 ( 420) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6]  1 */
    34015422, /* 18950 ( 420) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    51152756, /* 18951 ( 420) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
        3362, /* 18952 ( 420) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    17127570, /* 18953 ( 420) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6]  1 */
       16320, /* 18954 ( 420) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    51139634, /* 18955 ( 420) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
        3198, /* 18956 ( 420) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    17127410, /* 18957 ( 420) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
    17140532, /* 18958 ( 420) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
    51152916, /* 18959 ( 420) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6] -1 */
    34028708, /* 18960 ( 420) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    34028544, /* 18961 ( 420) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
       16484, /* 18962 ( 421) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    51139794, /* 18963 ( 421) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6] -1 */
    34015586, /* 18964 ( 421) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    34015422, /* 18965 ( 421) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    17140692, /* 18966 ( 421) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6]  1 */
       16320, /* 18967 ( 421) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    51139634, /* 18968 ( 421) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
    17140532, /* 18969 ( 421) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
       16484, /* 18970 ( 422) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34015422, /* 18971 ( 422) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    17140692, /* 18972 ( 422) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6]  1 */
    51152756, /* 18973 ( 422) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
    17127570, /* 18974 ( 422) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6]  1 */
        3362, /* 18975 ( 422) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    51139634, /* 18976 ( 422) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
    34028544, /* 18977 ( 422) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
       16484, /* 18978 ( 423) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    51139794, /* 18979 ( 423) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6] -1 */
    34015422, /* 18980 ( 423) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
        3362, /* 18981 ( 423) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    17127410, /* 18982 ( 423) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
    51152916, /* 18983 ( 423) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6] -1 */
    17140532, /* 18984 ( 423) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
    34028544, /* 18985 ( 423) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
       16484, /* 18986 ( 424) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34015586, /* 18987 ( 424) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    51139794, /* 18988 ( 424) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6] -1 */
    17140692, /* 18989 ( 424) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6]  1 */
    51152756, /* 18990 ( 424) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
        3198, /* 18991 ( 424) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    17127410, /* 18992 ( 424) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
    34028544, /* 18993 ( 424) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
       16484, /* 18994 ( 425) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    51139794, /* 18995 ( 425) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6] -1 */
    51152756, /* 18996 ( 425) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
        3362, /* 18997 ( 425) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
       16320, /* 18998 ( 425) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    51139634, /* 18999 ( 425) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
        3198, /* 19000 ( 425) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    51152916, /* 19001 ( 425) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6] -1 */
       16484, /* 19002 ( 426) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34015586, /* 19003 ( 426) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    17127570, /* 19004 ( 426) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6]  1 */
    51139634, /* 19005 ( 426) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
        3198, /* 19006 ( 426) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    17140532, /* 19007 ( 426) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
    51152916, /* 19008 ( 426) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6] -1 */
    34028544, /* 19009 ( 426) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
       16484, /* 19010 ( 427) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34015586, /* 19011 ( 427) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    34015422, /* 19012 ( 427) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    51152756, /* 19013 ( 427) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
    17127570, /* 19014 ( 427) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6]  1 */
       16320, /* 19015 ( 427) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    17127410, /* 19016 ( 427) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
    51152916, /* 19017 ( 427) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6] -1 */
       16484, /* 19018 ( 428) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34133522, /* 19019 ( 428) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    17140692, /* 19020 ( 428) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6]  1 */
    51034820, /* 19021 ( 428) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  0] -1 */
        3362, /* 19022 ( 428) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    17127570, /* 19023 ( 428) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6]  1 */
       16320, /* 19024 ( 428) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    51034656, /* 19025 ( 428) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  0] -1 */
    51021698, /* 19026 ( 428) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  0] -1 */
    34146644, /* 19027 ( 428) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
        3198, /* 19028 ( 428) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    51021534, /* 19029 ( 428) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  0] -1 */
    17127410, /* 19030 ( 428) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
    17140532, /* 19031 ( 428) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
    34133682, /* 19032 ( 428) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
    34146804, /* 19033 ( 428) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
       16484, /* 19034 ( 429) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    17140692, /* 19035 ( 429) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6]  1 */
    52556810, /* 19036 ( 429) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
        3362, /* 19037 ( 429) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    17127570, /* 19038 ( 429) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6]  1 */
       16320, /* 19039 ( 429) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    52569932, /* 19040 ( 429) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    35432762, /* 19041 ( 429) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  0] -1 */
    35445720, /* 19042 ( 429) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  0] -1 */
        3198, /* 19043 ( 429) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    52556970, /* 19044 ( 429) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    35445884, /* 19045 ( 429) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  0] -1 */
    17127410, /* 19046 ( 429) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
    17140532, /* 19047 ( 429) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
    35432598, /* 19048 ( 429) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  0] -1 */
    52570092, /* 19049 ( 429) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
       16484, /* 19050 ( 430) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    17140692, /* 19051 ( 430) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6]  1 */
        3362, /* 19052 ( 430) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    17127570, /* 19053 ( 430) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6]  1 */
       16320, /* 19054 ( 430) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    51034818, /* 19055 ( 430) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  0] -1 */
    34133520, /* 19056 ( 430) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
        3198, /* 19057 ( 430) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    34146806, /* 19058 ( 430) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    17127410, /* 19059 ( 430) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
    17140532, /* 19060 ( 430) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
    51021536, /* 19061 ( 430) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  0] -1 */
    34133684, /* 19062 ( 430) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    51021696, /* 19063 ( 430) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  0] -1 */
    34146642, /* 19064 ( 430) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
    51034658, /* 19065 ( 430) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  0] -1 */
       16484, /* 19066 ( 431) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    52451834, /* 19067 ( 431) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
    35550696, /* 19068 ( 431) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  6] -1 */
    17140692, /* 19069 ( 431) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6]  1 */
        3362, /* 19070 ( 431) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    17127570, /* 19071 ( 431) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6]  1 */
    35550860, /* 19072 ( 431) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
       16320, /* 19073 ( 431) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    35563982, /* 19074 ( 431) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
    52451994, /* 19075 ( 431) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
        3198, /* 19076 ( 431) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    17127410, /* 19077 ( 431) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
    17140532, /* 19078 ( 431) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
    52438712, /* 19079 ( 431) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
    52438872, /* 19080 ( 431) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
    35563818, /* 19081 ( 431) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  6] -1 */
       16484, /* 19082 ( 432) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34028546, /* 19083 ( 432) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    17140692, /* 19084 ( 432) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6]  1 */
        3362, /* 19085 ( 432) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    17127570, /* 19086 ( 432) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6]  1 */
       16320, /* 19087 ( 432) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    34015584, /* 19088 ( 432) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    34028706, /* 19089 ( 432) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    51139796, /* 19090 ( 432) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
        3198, /* 19091 ( 432) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    51152754, /* 19092 ( 432) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  6] -1 */
    17127410, /* 19093 ( 432) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
    17140532, /* 19094 ( 432) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
    51152918, /* 19095 ( 432) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
    51139632, /* 19096 ( 432) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  6] -1 */
    34015424, /* 19097 ( 432) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
       16484, /* 19098 ( 433) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    17140692, /* 19099 ( 433) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6]  1 */
    52438710, /* 19100 ( 433) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
        3362, /* 19101 ( 433) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    17127570, /* 19102 ( 433) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6]  1 */
    52438874, /* 19103 ( 433) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
       16320, /* 19104 ( 433) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    35563820, /* 19105 ( 433) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
    35563980, /* 19106 ( 433) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6] -1 */
    52451996, /* 19107 ( 433) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
        3198, /* 19108 ( 433) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    17127410, /* 19109 ( 433) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
    17140532, /* 19110 ( 433) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
    35550698, /* 19111 ( 433) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
    35550858, /* 19112 ( 433) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6] -1 */
    52451832, /* 19113 ( 433) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
       16484, /* 19114 ( 434) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    35445882, /* 19115 ( 434) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  0] -1 */
    17140692, /* 19116 ( 434) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6]  1 */
        3362, /* 19117 ( 434) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    17127570, /* 19118 ( 434) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6]  1 */
       16320, /* 19119 ( 434) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    35432600, /* 19120 ( 434) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  0] -1 */
    35432760, /* 19121 ( 434) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  0] -1 */
        3198, /* 19122 ( 434) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    35445722, /* 19123 ( 434) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  0] -1 */
    17127410, /* 19124 ( 434) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
    17140532, /* 19125 ( 434) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
    52556972, /* 19126 ( 434) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    52569930, /* 19127 ( 434) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    52570094, /* 19128 ( 434) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    52556808, /* 19129 ( 434) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
       16484, /* 19130 ( 419) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
     1551756, /* 19131 ( 419) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
       16322, /* 19132 ( 419) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
     1551594, /* 19133 ( 419) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
        3360, /* 19134 ( 419) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
        3198, /* 19135 ( 419) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
     1538474, /* 19136 ( 419) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
     1538636, /* 19137 ( 419) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
       16484, /* 19138 ( 420) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34028546, /* 19139 ( 420) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    35563818, /* 19140 ( 420) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  6] -1 */
     1551756, /* 19141 ( 420) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
    34015422, /* 19142 ( 420) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    35550860, /* 19143 ( 420) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
       16322, /* 19144 ( 420) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
     1551594, /* 19145 ( 420) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
        3360, /* 19146 ( 420) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    35550698, /* 19147 ( 420) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
        3198, /* 19148 ( 420) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
     1538474, /* 19149 ( 420) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
     1538636, /* 19150 ( 420) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
    35563980, /* 19151 ( 420) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6] -1 */
    34028708, /* 19152 ( 420) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    34015584, /* 19153 ( 420) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
       16484, /* 19154 ( 421) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    35563818, /* 19155 ( 421) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  6] -1 */
    34028546, /* 19156 ( 421) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    34015422, /* 19157 ( 421) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
     1551756, /* 19158 ( 421) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
        3360, /* 19159 ( 421) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    35550698, /* 19160 ( 421) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
     1538636, /* 19161 ( 421) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
       16484, /* 19162 ( 422) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34015422, /* 19163 ( 422) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
     1551756, /* 19164 ( 422) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
    35550860, /* 19165 ( 422) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
     1551594, /* 19166 ( 422) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
       16322, /* 19167 ( 422) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    35550698, /* 19168 ( 422) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
    34015584, /* 19169 ( 422) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
       16484, /* 19170 ( 423) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    35563818, /* 19171 ( 423) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  6] -1 */
    34015422, /* 19172 ( 423) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
       16322, /* 19173 ( 423) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
     1538474, /* 19174 ( 423) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
    35563980, /* 19175 ( 423) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6] -1 */
     1538636, /* 19176 ( 423) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
    34015584, /* 19177 ( 423) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
       16484, /* 19178 ( 424) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34028546, /* 19179 ( 424) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    35563818, /* 19180 ( 424) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  6] -1 */
     1551756, /* 19181 ( 424) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
    35550860, /* 19182 ( 424) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
        3198, /* 19183 ( 424) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
     1538474, /* 19184 ( 424) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
    34015584, /* 19185 ( 424) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
       16484, /* 19186 ( 425) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    35563818, /* 19187 ( 425) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  6] -1 */
    35550860, /* 19188 ( 425) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
       16322, /* 19189 ( 425) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
        3360, /* 19190 ( 425) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    35550698, /* 19191 ( 425) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
        3198, /* 19192 ( 425) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    35563980, /* 19193 ( 425) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6] -1 */
       16484, /* 19194 ( 426) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34028546, /* 19195 ( 426) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
     1551594, /* 19196 ( 426) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
    35550698, /* 19197 ( 426) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
        3198, /* 19198 ( 426) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
     1538636, /* 19199 ( 426) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
    35563980, /* 19200 ( 426) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6] -1 */
    34015584, /* 19201 ( 426) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
       16484, /* 19202 ( 427) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34028546, /* 19203 ( 427) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    34015422, /* 19204 ( 427) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    35550860, /* 19205 ( 427) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
     1551594, /* 19206 ( 427) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
        3360, /* 19207 ( 427) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
     1538474, /* 19208 ( 427) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
    35563980, /* 19209 ( 427) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6] -1 */
       16484, /* 19210 ( 428) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34133522, /* 19211 ( 428) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
     1551756, /* 19212 ( 428) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
    35445884, /* 19213 ( 428) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  0] -1 */
       16322, /* 19214 ( 428) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
     1551594, /* 19215 ( 428) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
        3360, /* 19216 ( 428) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    35432760, /* 19217 ( 428) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  0] -1 */
    35445722, /* 19218 ( 428) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  0] -1 */
    34133684, /* 19219 ( 428) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
        3198, /* 19220 ( 428) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    35432598, /* 19221 ( 428) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  0] -1 */
     1538474, /* 19222 ( 428) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
     1538636, /* 19223 ( 428) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
    34146642, /* 19224 ( 428) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
    34146804, /* 19225 ( 428) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
       16484, /* 19226 ( 429) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
     1551756, /* 19227 ( 429) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
    52556810, /* 19228 ( 429) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
       16322, /* 19229 ( 429) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
     1551594, /* 19230 ( 429) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
        3360, /* 19231 ( 429) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    52556972, /* 19232 ( 429) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    51034658, /* 19233 ( 429) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  0] -1 */
    51021696, /* 19234 ( 429) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  0] -1 */
        3198, /* 19235 ( 429) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    52569930, /* 19236 ( 429) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    51034820, /* 19237 ( 429) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  0] -1 */
     1538474, /* 19238 ( 429) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
     1538636, /* 19239 ( 429) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
    51021534, /* 19240 ( 429) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  0] -1 */
    52570092, /* 19241 ( 429) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
       16484, /* 19242 ( 430) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
     1551756, /* 19243 ( 430) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
       16322, /* 19244 ( 430) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
     1551594, /* 19245 ( 430) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
        3360, /* 19246 ( 430) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    35445882, /* 19247 ( 430) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  0] -1 */
    34133520, /* 19248 ( 430) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
        3198, /* 19249 ( 430) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    34146806, /* 19250 ( 430) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
     1538474, /* 19251 ( 430) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
     1538636, /* 19252 ( 430) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
    35432600, /* 19253 ( 430) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  0] -1 */
    34146644, /* 19254 ( 430) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    35445720, /* 19255 ( 430) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  0] -1 */
    34133682, /* 19256 ( 430) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
    35432762, /* 19257 ( 430) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  0] -1 */
       16484, /* 19258 ( 431) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    52438874, /* 19259 ( 431) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
    51139632, /* 19260 ( 431) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  6] -1 */
     1551756, /* 19261 ( 431) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
       16322, /* 19262 ( 431) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
     1551594, /* 19263 ( 431) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
    51152756, /* 19264 ( 431) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
        3360, /* 19265 ( 431) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    51152918, /* 19266 ( 431) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
    52451994, /* 19267 ( 431) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
        3198, /* 19268 ( 431) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
     1538474, /* 19269 ( 431) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
     1538636, /* 19270 ( 431) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
    52438712, /* 19271 ( 431) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
    52451832, /* 19272 ( 431) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
    51139794, /* 19273 ( 431) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6] -1 */
       16484, /* 19274 ( 432) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34015586, /* 19275 ( 432) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
     1551756, /* 19276 ( 432) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
       16322, /* 19277 ( 432) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
     1551594, /* 19278 ( 432) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
        3360, /* 19279 ( 432) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    34028544, /* 19280 ( 432) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    34028706, /* 19281 ( 432) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    35563820, /* 19282 ( 432) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
        3198, /* 19283 ( 432) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    35550858, /* 19284 ( 432) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6] -1 */
     1538474, /* 19285 ( 432) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
     1538636, /* 19286 ( 432) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
    35563982, /* 19287 ( 432) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
    35550696, /* 19288 ( 432) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  6] -1 */
    34015424, /* 19289 ( 432) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
       16484, /* 19290 ( 433) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
     1551756, /* 19291 ( 433) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
    52438710, /* 19292 ( 433) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
       16322, /* 19293 ( 433) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
     1551594, /* 19294 ( 433) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
    52451834, /* 19295 ( 433) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
        3360, /* 19296 ( 433) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    51139796, /* 19297 ( 433) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
    51152916, /* 19298 ( 433) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6] -1 */
    52451996, /* 19299 ( 433) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
        3198, /* 19300 ( 433) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
     1538474, /* 19301 ( 433) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
     1538636, /* 19302 ( 433) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
    51139634, /* 19303 ( 433) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
    51152754, /* 19304 ( 433) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  6] -1 */
    52438872, /* 19305 ( 433) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
       16484, /* 19306 ( 434) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    51034818, /* 19307 ( 434) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  0] -1 */
     1551756, /* 19308 ( 434) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
       16322, /* 19309 ( 434) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
     1551594, /* 19310 ( 434) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
        3360, /* 19311 ( 434) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    51021536, /* 19312 ( 434) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  0] -1 */
    51034656, /* 19313 ( 434) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  0] -1 */
        3198, /* 19314 ( 434) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    51021698, /* 19315 ( 434) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  0] -1 */
     1538474, /* 19316 ( 434) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
     1538636, /* 19317 ( 434) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
    52569932, /* 19318 ( 434) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    52556970, /* 19319 ( 434) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    52570094, /* 19320 ( 434) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    52556808, /* 19321 ( 434) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
       16484, /* 19322 ( 419) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    18426650, /* 19323 ( 419) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
       16322, /* 19324 ( 419) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    18426488, /* 19325 ( 419) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
        3360, /* 19326 ( 419) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
        3198, /* 19327 ( 419) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    18439608, /* 19328 ( 419) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
    18439770, /* 19329 ( 419) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
       16484, /* 19330 ( 420) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34028546, /* 19331 ( 420) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    52438712, /* 19332 ( 420) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
    18426650, /* 19333 ( 420) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    34015422, /* 19334 ( 420) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    52451994, /* 19335 ( 420) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
       16322, /* 19336 ( 420) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    18426488, /* 19337 ( 420) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
        3360, /* 19338 ( 420) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    52451832, /* 19339 ( 420) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
        3198, /* 19340 ( 420) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    18439608, /* 19341 ( 420) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
    18439770, /* 19342 ( 420) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
    52438874, /* 19343 ( 420) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
    34028708, /* 19344 ( 420) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    34015584, /* 19345 ( 420) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
       16484, /* 19346 ( 421) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    52438712, /* 19347 ( 421) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
    34028546, /* 19348 ( 421) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    34015422, /* 19349 ( 421) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    18426650, /* 19350 ( 421) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
        3360, /* 19351 ( 421) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    52451832, /* 19352 ( 421) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
    18439770, /* 19353 ( 421) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
       16484, /* 19354 ( 422) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34015422, /* 19355 ( 422) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    18426650, /* 19356 ( 422) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    52451994, /* 19357 ( 422) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
    18426488, /* 19358 ( 422) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
       16322, /* 19359 ( 422) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    52451832, /* 19360 ( 422) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
    34015584, /* 19361 ( 422) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
       16484, /* 19362 ( 423) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    52438712, /* 19363 ( 423) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
    34015422, /* 19364 ( 423) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
       16322, /* 19365 ( 423) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    18439608, /* 19366 ( 423) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
    52438874, /* 19367 ( 423) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
    18439770, /* 19368 ( 423) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
    34015584, /* 19369 ( 423) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
       16484, /* 19370 ( 424) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34028546, /* 19371 ( 424) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    52438712, /* 19372 ( 424) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
    18426650, /* 19373 ( 424) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    52451994, /* 19374 ( 424) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
        3198, /* 19375 ( 424) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    18439608, /* 19376 ( 424) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
    34015584, /* 19377 ( 424) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
       16484, /* 19378 ( 425) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    52438712, /* 19379 ( 425) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
    52451994, /* 19380 ( 425) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
       16322, /* 19381 ( 425) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
        3360, /* 19382 ( 425) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    52451832, /* 19383 ( 425) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
        3198, /* 19384 ( 425) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    52438874, /* 19385 ( 425) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
       16484, /* 19386 ( 426) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34028546, /* 19387 ( 426) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    18426488, /* 19388 ( 426) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    52451832, /* 19389 ( 426) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
        3198, /* 19390 ( 426) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    18439770, /* 19391 ( 426) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
    52438874, /* 19392 ( 426) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
    34015584, /* 19393 ( 426) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
       16484, /* 19394 ( 427) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34028546, /* 19395 ( 427) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    34015422, /* 19396 ( 427) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    52451994, /* 19397 ( 427) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
    18426488, /* 19398 ( 427) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
        3360, /* 19399 ( 427) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    18439608, /* 19400 ( 427) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
    52438874, /* 19401 ( 427) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
       16484, /* 19402 ( 428) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    51034656, /* 19403 ( 428) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  0] -1 */
    18426650, /* 19404 ( 428) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    35445884, /* 19405 ( 428) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  0] -1 */
       16322, /* 19406 ( 428) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    18426488, /* 19407 ( 428) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
        3360, /* 19408 ( 428) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    35432760, /* 19409 ( 428) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  0] -1 */
    35445722, /* 19410 ( 428) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  0] -1 */
    51034818, /* 19411 ( 428) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  0] -1 */
        3198, /* 19412 ( 428) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    35432598, /* 19413 ( 428) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  0] -1 */
    18439608, /* 19414 ( 428) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
    18439770, /* 19415 ( 428) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
    51021536, /* 19416 ( 428) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  0] -1 */
    51021698, /* 19417 ( 428) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  0] -1 */
       16484, /* 19418 ( 429) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    18426650, /* 19419 ( 429) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    52569930, /* 19420 ( 429) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
       16322, /* 19421 ( 429) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    18426488, /* 19422 ( 429) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
        3360, /* 19423 ( 429) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    52570092, /* 19424 ( 429) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    34146644, /* 19425 ( 429) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    34133682, /* 19426 ( 429) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
        3198, /* 19427 ( 429) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    52556810, /* 19428 ( 429) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    34146806, /* 19429 ( 429) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    18439608, /* 19430 ( 429) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
    18439770, /* 19431 ( 429) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
    34133520, /* 19432 ( 429) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
    52556972, /* 19433 ( 429) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
       16484, /* 19434 ( 430) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    18426650, /* 19435 ( 430) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
       16322, /* 19436 ( 430) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    18426488, /* 19437 ( 430) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
        3360, /* 19438 ( 430) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    35432762, /* 19439 ( 430) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  0] -1 */
    51021534, /* 19440 ( 430) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  0] -1 */
        3198, /* 19441 ( 430) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    51034820, /* 19442 ( 430) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  0] -1 */
    18439608, /* 19443 ( 430) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
    18439770, /* 19444 ( 430) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
    35445720, /* 19445 ( 430) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  0] -1 */
    51034658, /* 19446 ( 430) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  0] -1 */
    35432600, /* 19447 ( 430) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  0] -1 */
    51021696, /* 19448 ( 430) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  0] -1 */
    35445882, /* 19449 ( 430) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  0] -1 */
       16484, /* 19450 ( 431) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    35563980, /* 19451 ( 431) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6] -1 */
    51139632, /* 19452 ( 431) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  6] -1 */
    18426650, /* 19453 ( 431) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
       16322, /* 19454 ( 431) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    18426488, /* 19455 ( 431) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    51152756, /* 19456 ( 431) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
        3360, /* 19457 ( 431) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    51152918, /* 19458 ( 431) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
    35550860, /* 19459 ( 431) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
        3198, /* 19460 ( 431) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    18439608, /* 19461 ( 431) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
    18439770, /* 19462 ( 431) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
    35563818, /* 19463 ( 431) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  6] -1 */
    35550698, /* 19464 ( 431) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
    51139794, /* 19465 ( 431) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6] -1 */
       16484, /* 19466 ( 432) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34028706, /* 19467 ( 432) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    18426650, /* 19468 ( 432) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
       16322, /* 19469 ( 432) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    18426488, /* 19470 ( 432) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
        3360, /* 19471 ( 432) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    34015424, /* 19472 ( 432) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    34015586, /* 19473 ( 432) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    52451834, /* 19474 ( 432) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
        3198, /* 19475 ( 432) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    52438872, /* 19476 ( 432) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
    18439608, /* 19477 ( 432) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
    18439770, /* 19478 ( 432) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
    52451996, /* 19479 ( 432) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
    52438710, /* 19480 ( 432) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
    34028544, /* 19481 ( 432) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
       16484, /* 19482 ( 433) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    18426650, /* 19483 ( 433) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    35550696, /* 19484 ( 433) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  6] -1 */
       16322, /* 19485 ( 433) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    18426488, /* 19486 ( 433) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    35563820, /* 19487 ( 433) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
        3360, /* 19488 ( 433) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    51152916, /* 19489 ( 433) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6] -1 */
    51139796, /* 19490 ( 433) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
    35563982, /* 19491 ( 433) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
        3198, /* 19492 ( 433) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    18439608, /* 19493 ( 433) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
    18439770, /* 19494 ( 433) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
    51152754, /* 19495 ( 433) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  6] -1 */
    51139634, /* 19496 ( 433) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
    35550858, /* 19497 ( 433) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6] -1 */
       16484, /* 19498 ( 434) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34133684, /* 19499 ( 434) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    18426650, /* 19500 ( 434) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
       16322, /* 19501 ( 434) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    18426488, /* 19502 ( 434) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
        3360, /* 19503 ( 434) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    34146642, /* 19504 ( 434) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
    34133522, /* 19505 ( 434) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
        3198, /* 19506 ( 434) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    34146804, /* 19507 ( 434) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
    18439608, /* 19508 ( 434) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
    18439770, /* 19509 ( 434) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
    52569932, /* 19510 ( 434) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    52556970, /* 19511 ( 434) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    52570094, /* 19512 ( 434) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    52556808, /* 19513 ( 434) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
       16484, /* 19514 ( 419) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    17127572, /* 19515 ( 419) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
       16482, /* 19516 ( 419) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    17127570, /* 19517 ( 419) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6]  1 */
        3200, /* 19518 ( 419) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
        3198, /* 19519 ( 419) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    17140530, /* 19520 ( 419) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  6]  1 */
    17140532, /* 19521 ( 419) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
       16484, /* 19522 ( 420) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34028706, /* 19523 ( 420) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    51139794, /* 19524 ( 420) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6] -1 */
    17127572, /* 19525 ( 420) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
    34015422, /* 19526 ( 420) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    51152756, /* 19527 ( 420) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
       16482, /* 19528 ( 420) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    17127570, /* 19529 ( 420) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6]  1 */
        3200, /* 19530 ( 420) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    51152754, /* 19531 ( 420) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  6] -1 */
        3198, /* 19532 ( 420) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    17140530, /* 19533 ( 420) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  6]  1 */
    17140532, /* 19534 ( 420) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
    51139796, /* 19535 ( 420) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
    34028708, /* 19536 ( 420) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    34015424, /* 19537 ( 420) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
       16484, /* 19538 ( 421) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    51139794, /* 19539 ( 421) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6] -1 */
    34028706, /* 19540 ( 421) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    34015422, /* 19541 ( 421) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    17127572, /* 19542 ( 421) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
        3200, /* 19543 ( 421) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    51152754, /* 19544 ( 421) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  6] -1 */
    17140532, /* 19545 ( 421) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
       16484, /* 19546 ( 422) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34015422, /* 19547 ( 422) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    17127572, /* 19548 ( 422) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
    51152756, /* 19549 ( 422) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
    17127570, /* 19550 ( 422) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6]  1 */
       16482, /* 19551 ( 422) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    51152754, /* 19552 ( 422) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  6] -1 */
    34015424, /* 19553 ( 422) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
       16484, /* 19554 ( 423) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    51139794, /* 19555 ( 423) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6] -1 */
    34015422, /* 19556 ( 423) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
       16482, /* 19557 ( 423) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    17140530, /* 19558 ( 423) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  6]  1 */
    51139796, /* 19559 ( 423) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
    17140532, /* 19560 ( 423) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
    34015424, /* 19561 ( 423) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
       16484, /* 19562 ( 424) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34028706, /* 19563 ( 424) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    51139794, /* 19564 ( 424) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6] -1 */
    17127572, /* 19565 ( 424) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
    51152756, /* 19566 ( 424) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
        3198, /* 19567 ( 424) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    17140530, /* 19568 ( 424) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  6]  1 */
    34015424, /* 19569 ( 424) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
       16484, /* 19570 ( 425) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    51139794, /* 19571 ( 425) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6] -1 */
    51152756, /* 19572 ( 425) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
       16482, /* 19573 ( 425) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
        3200, /* 19574 ( 425) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    51152754, /* 19575 ( 425) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  6] -1 */
        3198, /* 19576 ( 425) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    51139796, /* 19577 ( 425) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
       16484, /* 19578 ( 426) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34028706, /* 19579 ( 426) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    17127570, /* 19580 ( 426) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6]  1 */
    51152754, /* 19581 ( 426) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  6] -1 */
        3198, /* 19582 ( 426) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    17140532, /* 19583 ( 426) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
    51139796, /* 19584 ( 426) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
    34015424, /* 19585 ( 426) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
       16484, /* 19586 ( 427) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34028706, /* 19587 ( 427) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    34015422, /* 19588 ( 427) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    51152756, /* 19589 ( 427) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
    17127570, /* 19590 ( 427) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6]  1 */
        3200, /* 19591 ( 427) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    17140530, /* 19592 ( 427) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  6]  1 */
    51139796, /* 19593 ( 427) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
       16484, /* 19594 ( 428) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    51034656, /* 19595 ( 428) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  0] -1 */
    17127572, /* 19596 ( 428) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
    34146806, /* 19597 ( 428) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
       16482, /* 19598 ( 428) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    17127570, /* 19599 ( 428) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6]  1 */
        3200, /* 19600 ( 428) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34133522, /* 19601 ( 428) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    34146804, /* 19602 ( 428) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
    51034658, /* 19603 ( 428) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  0] -1 */
        3198, /* 19604 ( 428) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    34133520, /* 19605 ( 428) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
    17140530, /* 19606 ( 428) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  6]  1 */
    17140532, /* 19607 ( 428) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
    51021696, /* 19608 ( 428) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  0] -1 */
    51021698, /* 19609 ( 428) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  0] -1 */
       16484, /* 19610 ( 429) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    17127572, /* 19611 ( 429) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
    52569930, /* 19612 ( 429) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
       16482, /* 19613 ( 429) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    17127570, /* 19614 ( 429) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6]  1 */
        3200, /* 19615 ( 429) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    52569932, /* 19616 ( 429) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    35445882, /* 19617 ( 429) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  0] -1 */
    35432600, /* 19618 ( 429) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  0] -1 */
        3198, /* 19619 ( 429) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    52556970, /* 19620 ( 429) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    35445884, /* 19621 ( 429) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  0] -1 */
    17140530, /* 19622 ( 429) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  6]  1 */
    17140532, /* 19623 ( 429) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
    35432598, /* 19624 ( 429) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  0] -1 */
    52556972, /* 19625 ( 429) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
       16484, /* 19626 ( 430) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    17127572, /* 19627 ( 430) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
       16482, /* 19628 ( 430) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    17127570, /* 19629 ( 430) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6]  1 */
        3200, /* 19630 ( 430) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34133684, /* 19631 ( 430) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    51021534, /* 19632 ( 430) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  0] -1 */
        3198, /* 19633 ( 430) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    51034820, /* 19634 ( 430) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  0] -1 */
    17140530, /* 19635 ( 430) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  6]  1 */
    17140532, /* 19636 ( 430) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
    34146642, /* 19637 ( 430) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
    51034818, /* 19638 ( 430) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  0] -1 */
    34133682, /* 19639 ( 430) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
    51021536, /* 19640 ( 430) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  0] -1 */
    34146644, /* 19641 ( 430) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
       16484, /* 19642 ( 431) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    35563820, /* 19643 ( 431) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
    52438710, /* 19644 ( 431) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
    17127572, /* 19645 ( 431) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
       16482, /* 19646 ( 431) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    17127570, /* 19647 ( 431) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6]  1 */
    52451994, /* 19648 ( 431) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
        3200, /* 19649 ( 431) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    52451996, /* 19650 ( 431) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
    35550860, /* 19651 ( 431) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
        3198, /* 19652 ( 431) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    17140530, /* 19653 ( 431) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  6]  1 */
    17140532, /* 19654 ( 431) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
    35563818, /* 19655 ( 431) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  6] -1 */
    35550858, /* 19656 ( 431) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6] -1 */
    52438712, /* 19657 ( 431) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
       16484, /* 19658 ( 432) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34028546, /* 19659 ( 432) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    17127572, /* 19660 ( 432) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
       16482, /* 19661 ( 432) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    17127570, /* 19662 ( 432) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6]  1 */
        3200, /* 19663 ( 432) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34015584, /* 19664 ( 432) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    34015586, /* 19665 ( 432) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    51152916, /* 19666 ( 432) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6] -1 */
        3198, /* 19667 ( 432) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    51139634, /* 19668 ( 432) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
    17140530, /* 19669 ( 432) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  6]  1 */
    17140532, /* 19670 ( 432) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
    51152918, /* 19671 ( 432) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
    51139632, /* 19672 ( 432) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  6] -1 */
    34028544, /* 19673 ( 432) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
       16484, /* 19674 ( 433) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    17127572, /* 19675 ( 433) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
    35550696, /* 19676 ( 433) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  6] -1 */
       16482, /* 19677 ( 433) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    17127570, /* 19678 ( 433) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6]  1 */
    35563980, /* 19679 ( 433) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6] -1 */
        3200, /* 19680 ( 433) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    52451834, /* 19681 ( 433) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
    52438874, /* 19682 ( 433) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
    35563982, /* 19683 ( 433) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
        3198, /* 19684 ( 433) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    17140530, /* 19685 ( 433) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  6]  1 */
    17140532, /* 19686 ( 433) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
    52451832, /* 19687 ( 433) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
    52438872, /* 19688 ( 433) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
    35550698, /* 19689 ( 433) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
       16484, /* 19690 ( 434) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    35432762, /* 19691 ( 434) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  0] -1 */
    17127572, /* 19692 ( 434) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
       16482, /* 19693 ( 434) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    17127570, /* 19694 ( 434) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6]  1 */
        3200, /* 19695 ( 434) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    35445720, /* 19696 ( 434) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  0] -1 */
    35432760, /* 19697 ( 434) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  0] -1 */
        3198, /* 19698 ( 434) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    35445722, /* 19699 ( 434) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  0] -1 */
    17140530, /* 19700 ( 434) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  6]  1 */
    17140532, /* 19701 ( 434) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
    52570092, /* 19702 ( 434) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    52556810, /* 19703 ( 434) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    52570094, /* 19704 ( 434) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    52556808, /* 19705 ( 434) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
       16484, /* 19706 ( 419) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
     1551596, /* 19707 ( 419) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
       16482, /* 19708 ( 419) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
     1551594, /* 19709 ( 419) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
        3200, /* 19710 ( 419) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
        3198, /* 19711 ( 419) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
     1538634, /* 19712 ( 419) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
     1538636, /* 19713 ( 419) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
       16484, /* 19714 ( 420) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34028706, /* 19715 ( 420) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    35563818, /* 19716 ( 420) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  6] -1 */
     1551596, /* 19717 ( 420) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
    34015422, /* 19718 ( 420) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    35550860, /* 19719 ( 420) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
       16482, /* 19720 ( 420) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
     1551594, /* 19721 ( 420) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
        3200, /* 19722 ( 420) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    35550858, /* 19723 ( 420) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6] -1 */
        3198, /* 19724 ( 420) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
     1538634, /* 19725 ( 420) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
     1538636, /* 19726 ( 420) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
    35563820, /* 19727 ( 420) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
    34028708, /* 19728 ( 420) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    34015424, /* 19729 ( 420) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
       16484, /* 19730 ( 421) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    35563818, /* 19731 ( 421) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  6] -1 */
    34028706, /* 19732 ( 421) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    34015422, /* 19733 ( 421) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
     1551596, /* 19734 ( 421) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
        3200, /* 19735 ( 421) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    35550858, /* 19736 ( 421) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6] -1 */
     1538636, /* 19737 ( 421) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
       16484, /* 19738 ( 422) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34015422, /* 19739 ( 422) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
     1551596, /* 19740 ( 422) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
    35550860, /* 19741 ( 422) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
     1551594, /* 19742 ( 422) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
       16482, /* 19743 ( 422) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    35550858, /* 19744 ( 422) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6] -1 */
    34015424, /* 19745 ( 422) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
       16484, /* 19746 ( 423) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    35563818, /* 19747 ( 423) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  6] -1 */
    34015422, /* 19748 ( 423) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
       16482, /* 19749 ( 423) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
     1538634, /* 19750 ( 423) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
    35563820, /* 19751 ( 423) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
     1538636, /* 19752 ( 423) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
    34015424, /* 19753 ( 423) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
       16484, /* 19754 ( 424) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34028706, /* 19755 ( 424) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    35563818, /* 19756 ( 424) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  6] -1 */
     1551596, /* 19757 ( 424) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
    35550860, /* 19758 ( 424) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
        3198, /* 19759 ( 424) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
     1538634, /* 19760 ( 424) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
    34015424, /* 19761 ( 424) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
       16484, /* 19762 ( 425) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    35563818, /* 19763 ( 425) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  6] -1 */
    35550860, /* 19764 ( 425) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
       16482, /* 19765 ( 425) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
        3200, /* 19766 ( 425) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    35550858, /* 19767 ( 425) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6] -1 */
        3198, /* 19768 ( 425) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    35563820, /* 19769 ( 425) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
       16484, /* 19770 ( 426) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34028706, /* 19771 ( 426) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
     1551594, /* 19772 ( 426) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
    35550858, /* 19773 ( 426) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6] -1 */
        3198, /* 19774 ( 426) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
     1538636, /* 19775 ( 426) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
    35563820, /* 19776 ( 426) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
    34015424, /* 19777 ( 426) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
       16484, /* 19778 ( 427) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34028706, /* 19779 ( 427) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    34015422, /* 19780 ( 427) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    35550860, /* 19781 ( 427) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
     1551594, /* 19782 ( 427) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
        3200, /* 19783 ( 427) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
     1538634, /* 19784 ( 427) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
    35563820, /* 19785 ( 427) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
       16484, /* 19786 ( 428) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    35432760, /* 19787 ( 428) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  0] -1 */
     1551596, /* 19788 ( 428) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
    34146806, /* 19789 ( 428) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
       16482, /* 19790 ( 428) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
     1551594, /* 19791 ( 428) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
        3200, /* 19792 ( 428) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34133522, /* 19793 ( 428) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    34146804, /* 19794 ( 428) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
    35432762, /* 19795 ( 428) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  0] -1 */
        3198, /* 19796 ( 428) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    34133520, /* 19797 ( 428) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
     1538634, /* 19798 ( 428) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
     1538636, /* 19799 ( 428) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
    35445720, /* 19800 ( 428) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  0] -1 */
    35445722, /* 19801 ( 428) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  0] -1 */
       16484, /* 19802 ( 429) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
     1551596, /* 19803 ( 429) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
    52556970, /* 19804 ( 429) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
       16482, /* 19805 ( 429) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
     1551594, /* 19806 ( 429) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
        3200, /* 19807 ( 429) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    52556972, /* 19808 ( 429) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    51034818, /* 19809 ( 429) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  0] -1 */
    51021536, /* 19810 ( 429) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  0] -1 */
        3198, /* 19811 ( 429) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    52569930, /* 19812 ( 429) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    51034820, /* 19813 ( 429) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  0] -1 */
     1538634, /* 19814 ( 429) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
     1538636, /* 19815 ( 429) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
    51021534, /* 19816 ( 429) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  0] -1 */
    52569932, /* 19817 ( 429) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
       16484, /* 19818 ( 430) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
     1551596, /* 19819 ( 430) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
       16482, /* 19820 ( 430) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
     1551594, /* 19821 ( 430) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
        3200, /* 19822 ( 430) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34146644, /* 19823 ( 430) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    35432598, /* 19824 ( 430) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  0] -1 */
        3198, /* 19825 ( 430) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    35445884, /* 19826 ( 430) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  0] -1 */
     1538634, /* 19827 ( 430) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
     1538636, /* 19828 ( 430) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
    34133682, /* 19829 ( 430) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
    35445882, /* 19830 ( 430) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  0] -1 */
    34146642, /* 19831 ( 430) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
    35432600, /* 19832 ( 430) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  0] -1 */
    34133684, /* 19833 ( 430) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
       16484, /* 19834 ( 431) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    51139796, /* 19835 ( 431) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
    52438710, /* 19836 ( 431) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
     1551596, /* 19837 ( 431) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
       16482, /* 19838 ( 431) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
     1551594, /* 19839 ( 431) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
    52451994, /* 19840 ( 431) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
        3200, /* 19841 ( 431) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    52451996, /* 19842 ( 431) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
    51152756, /* 19843 ( 431) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
        3198, /* 19844 ( 431) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
     1538634, /* 19845 ( 431) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
     1538636, /* 19846 ( 431) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
    51139794, /* 19847 ( 431) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6] -1 */
    51152754, /* 19848 ( 431) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  6] -1 */
    52438712, /* 19849 ( 431) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
       16484, /* 19850 ( 432) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34015586, /* 19851 ( 432) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
     1551596, /* 19852 ( 432) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
       16482, /* 19853 ( 432) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
     1551594, /* 19854 ( 432) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
        3200, /* 19855 ( 432) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34028544, /* 19856 ( 432) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    34028546, /* 19857 ( 432) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    35563980, /* 19858 ( 432) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6] -1 */
        3198, /* 19859 ( 432) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    35550698, /* 19860 ( 432) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
     1538634, /* 19861 ( 432) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
     1538636, /* 19862 ( 432) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
    35563982, /* 19863 ( 432) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
    35550696, /* 19864 ( 432) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  6] -1 */
    34015584, /* 19865 ( 432) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
       16484, /* 19866 ( 433) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
     1551596, /* 19867 ( 433) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
    51139632, /* 19868 ( 433) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  6] -1 */
       16482, /* 19869 ( 433) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
     1551594, /* 19870 ( 433) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
    51152916, /* 19871 ( 433) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6] -1 */
        3200, /* 19872 ( 433) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    52438874, /* 19873 ( 433) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
    52451834, /* 19874 ( 433) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
    51152918, /* 19875 ( 433) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
        3198, /* 19876 ( 433) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
     1538634, /* 19877 ( 433) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
     1538636, /* 19878 ( 433) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
    52438872, /* 19879 ( 433) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
    52451832, /* 19880 ( 433) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
    51139634, /* 19881 ( 433) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
       16484, /* 19882 ( 434) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    51034658, /* 19883 ( 434) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  0] -1 */
     1551596, /* 19884 ( 434) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
       16482, /* 19885 ( 434) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
     1551594, /* 19886 ( 434) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
        3200, /* 19887 ( 434) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    51021696, /* 19888 ( 434) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  0] -1 */
    51034656, /* 19889 ( 434) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  0] -1 */
        3198, /* 19890 ( 434) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    51021698, /* 19891 ( 434) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  0] -1 */
     1538634, /* 19892 ( 434) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
     1538636, /* 19893 ( 434) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
    52570092, /* 19894 ( 434) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    52556810, /* 19895 ( 434) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    52570094, /* 19896 ( 434) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    52556808, /* 19897 ( 434) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
       16484, /* 19898 ( 419) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    18439610, /* 19899 ( 419) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
        3362, /* 19900 ( 419) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    18426488, /* 19901 ( 419) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
       16320, /* 19902 ( 419) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
        3198, /* 19903 ( 419) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    18426648, /* 19904 ( 419) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
    18439770, /* 19905 ( 419) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
       16484, /* 19906 ( 420) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34015586, /* 19907 ( 420) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    52438712, /* 19908 ( 420) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
    18439610, /* 19909 ( 420) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    34015422, /* 19910 ( 420) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    52451994, /* 19911 ( 420) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
        3362, /* 19912 ( 420) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    18426488, /* 19913 ( 420) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
       16320, /* 19914 ( 420) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    52438872, /* 19915 ( 420) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
        3198, /* 19916 ( 420) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    18426648, /* 19917 ( 420) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
    18439770, /* 19918 ( 420) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
    52451834, /* 19919 ( 420) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
    34028708, /* 19920 ( 420) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    34028544, /* 19921 ( 420) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
       16484, /* 19922 ( 421) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    52438712, /* 19923 ( 421) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
    34015586, /* 19924 ( 421) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    34015422, /* 19925 ( 421) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    18439610, /* 19926 ( 421) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
       16320, /* 19927 ( 421) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    52438872, /* 19928 ( 421) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
    18439770, /* 19929 ( 421) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
       16484, /* 19930 ( 422) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34015422, /* 19931 ( 422) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    18439610, /* 19932 ( 422) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    52451994, /* 19933 ( 422) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
    18426488, /* 19934 ( 422) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
        3362, /* 19935 ( 422) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    52438872, /* 19936 ( 422) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
    34028544, /* 19937 ( 422) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
       16484, /* 19938 ( 423) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    52438712, /* 19939 ( 423) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
    34015422, /* 19940 ( 423) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
        3362, /* 19941 ( 423) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    18426648, /* 19942 ( 423) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
    52451834, /* 19943 ( 423) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
    18439770, /* 19944 ( 423) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
    34028544, /* 19945 ( 423) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
       16484, /* 19946 ( 424) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34015586, /* 19947 ( 424) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    52438712, /* 19948 ( 424) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
    18439610, /* 19949 ( 424) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    52451994, /* 19950 ( 424) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
        3198, /* 19951 ( 424) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    18426648, /* 19952 ( 424) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
    34028544, /* 19953 ( 424) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
       16484, /* 19954 ( 425) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    52438712, /* 19955 ( 425) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
    52451994, /* 19956 ( 425) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
        3362, /* 19957 ( 425) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
       16320, /* 19958 ( 425) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    52438872, /* 19959 ( 425) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
        3198, /* 19960 ( 425) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    52451834, /* 19961 ( 425) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
       16484, /* 19962 ( 426) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34015586, /* 19963 ( 426) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    18426488, /* 19964 ( 426) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    52438872, /* 19965 ( 426) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
        3198, /* 19966 ( 426) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    18439770, /* 19967 ( 426) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
    52451834, /* 19968 ( 426) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
    34028544, /* 19969 ( 426) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
       16484, /* 19970 ( 427) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34015586, /* 19971 ( 427) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    34015422, /* 19972 ( 427) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    52451994, /* 19973 ( 427) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
    18426488, /* 19974 ( 427) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
       16320, /* 19975 ( 427) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    18426648, /* 19976 ( 427) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
    52451834, /* 19977 ( 427) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
       16484, /* 19978 ( 428) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    35432760, /* 19979 ( 428) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  0] -1 */
    18439610, /* 19980 ( 428) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    51034820, /* 19981 ( 428) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  0] -1 */
        3362, /* 19982 ( 428) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    18426488, /* 19983 ( 428) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
       16320, /* 19984 ( 428) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    51034656, /* 19985 ( 428) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  0] -1 */
    51021698, /* 19986 ( 428) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  0] -1 */
    35445882, /* 19987 ( 428) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  0] -1 */
        3198, /* 19988 ( 428) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    51021534, /* 19989 ( 428) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  0] -1 */
    18426648, /* 19990 ( 428) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
    18439770, /* 19991 ( 428) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
    35432600, /* 19992 ( 428) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  0] -1 */
    35445722, /* 19993 ( 428) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  0] -1 */
       16484, /* 19994 ( 429) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    18439610, /* 19995 ( 429) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    52556970, /* 19996 ( 429) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
        3362, /* 19997 ( 429) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    18426488, /* 19998 ( 429) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
       16320, /* 19999 ( 429) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    52570092, /* 20000 ( 429) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    34133684, /* 20001 ( 429) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    34146642, /* 20002 ( 429) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
        3198, /* 20003 ( 429) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    52556810, /* 20004 ( 429) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    34146806, /* 20005 ( 429) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    18426648, /* 20006 ( 429) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
    18439770, /* 20007 ( 429) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
    34133520, /* 20008 ( 429) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
    52569932, /* 20009 ( 429) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
       16484, /* 20010 ( 430) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    18439610, /* 20011 ( 430) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
        3362, /* 20012 ( 430) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    18426488, /* 20013 ( 430) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
       16320, /* 20014 ( 430) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    51034658, /* 20015 ( 430) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  0] -1 */
    35432598, /* 20016 ( 430) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  0] -1 */
        3198, /* 20017 ( 430) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    35445884, /* 20018 ( 430) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  0] -1 */
    18426648, /* 20019 ( 430) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
    18439770, /* 20020 ( 430) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
    51021696, /* 20021 ( 430) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  0] -1 */
    35432762, /* 20022 ( 430) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  0] -1 */
    51021536, /* 20023 ( 430) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  0] -1 */
    35445720, /* 20024 ( 430) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  0] -1 */
    51034818, /* 20025 ( 430) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  0] -1 */
       16484, /* 20026 ( 431) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    51152916, /* 20027 ( 431) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6] -1 */
    35550696, /* 20028 ( 431) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  6] -1 */
    18439610, /* 20029 ( 431) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
        3362, /* 20030 ( 431) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    18426488, /* 20031 ( 431) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    35550860, /* 20032 ( 431) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
       16320, /* 20033 ( 431) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    35563982, /* 20034 ( 431) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
    51152756, /* 20035 ( 431) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
        3198, /* 20036 ( 431) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    18426648, /* 20037 ( 431) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
    18439770, /* 20038 ( 431) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
    51139794, /* 20039 ( 431) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6] -1 */
    51139634, /* 20040 ( 431) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
    35563818, /* 20041 ( 431) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  6] -1 */
       16484, /* 20042 ( 432) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34028706, /* 20043 ( 432) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    18439610, /* 20044 ( 432) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
        3362, /* 20045 ( 432) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    18426488, /* 20046 ( 432) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
       16320, /* 20047 ( 432) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    34015424, /* 20048 ( 432) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    34028546, /* 20049 ( 432) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    52438874, /* 20050 ( 432) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
        3198, /* 20051 ( 432) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    52451832, /* 20052 ( 432) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
    18426648, /* 20053 ( 432) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
    18439770, /* 20054 ( 432) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
    52451996, /* 20055 ( 432) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
    52438710, /* 20056 ( 432) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
    34015584, /* 20057 ( 432) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
       16484, /* 20058 ( 433) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    18439610, /* 20059 ( 433) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    51139632, /* 20060 ( 433) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  6] -1 */
        3362, /* 20061 ( 433) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    18426488, /* 20062 ( 433) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    51139796, /* 20063 ( 433) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
       16320, /* 20064 ( 433) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    35563980, /* 20065 ( 433) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6] -1 */
    35563820, /* 20066 ( 433) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
    51152918, /* 20067 ( 433) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
        3198, /* 20068 ( 433) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    18426648, /* 20069 ( 433) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
    18439770, /* 20070 ( 433) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
    35550858, /* 20071 ( 433) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6] -1 */
    35550698, /* 20072 ( 433) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
    51152754, /* 20073 ( 433) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  6] -1 */
       16484, /* 20074 ( 434) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34146644, /* 20075 ( 434) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    18439610, /* 20076 ( 434) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
        3362, /* 20077 ( 434) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    18426488, /* 20078 ( 434) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
       16320, /* 20079 ( 434) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    34133682, /* 20080 ( 434) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
    34133522, /* 20081 ( 434) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
        3198, /* 20082 ( 434) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    34146804, /* 20083 ( 434) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
    18426648, /* 20084 ( 434) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
    18439770, /* 20085 ( 434) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
    52556972, /* 20086 ( 434) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    52569930, /* 20087 ( 434) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    52570094, /* 20088 ( 434) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    52556808, /* 20089 ( 434) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
       16484, /* 20090 ( 435) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
      121458, /* 20091 ( 435) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  6]  1 */
    17009312, /* 20092 ( 435) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  0]  1 */
    17127572, /* 20093 ( 435) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
        3198, /* 20094 ( 435) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
      134420, /* 20095 ( 435) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6]  1 */
    17140530, /* 20096 ( 435) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  6]  1 */
    17022594, /* 20097 ( 435) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  0]  1 */
       16484, /* 20098 ( 436) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34015422, /* 20099 ( 436) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    17009312, /* 20100 ( 436) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  0]  1 */
      121458, /* 20101 ( 436) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  6]  1 */
    34146644, /* 20102 ( 436) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    51034818, /* 20103 ( 436) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  0] -1 */
    17127572, /* 20104 ( 436) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
    51139796, /* 20105 ( 436) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
        3198, /* 20106 ( 436) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    51152754, /* 20107 ( 436) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  6] -1 */
    34133682, /* 20108 ( 436) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
    51021536, /* 20109 ( 436) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  0] -1 */
      134420, /* 20110 ( 436) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6]  1 */
    34028708, /* 20111 ( 436) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    17140530, /* 20112 ( 436) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  6]  1 */
    17022594, /* 20113 ( 436) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  0]  1 */
       16484, /* 20114 ( 437) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34015422, /* 20115 ( 437) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    51139796, /* 20116 ( 437) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
    34133682, /* 20117 ( 437) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
    51021536, /* 20118 ( 437) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  0] -1 */
      134420, /* 20119 ( 437) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6]  1 */
    17140530, /* 20120 ( 437) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  6]  1 */
    17022594, /* 20121 ( 437) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  0]  1 */
       16484, /* 20122 ( 438) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34015422, /* 20123 ( 438) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
      121458, /* 20124 ( 438) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  6]  1 */
    34146644, /* 20125 ( 438) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    51152754, /* 20126 ( 438) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  6] -1 */
    51021536, /* 20127 ( 438) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  0] -1 */
    17022594, /* 20128 ( 438) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  0]  1 */
    17127572, /* 20129 ( 438) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
       16484, /* 20130 ( 439) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34015422, /* 20131 ( 439) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    17009312, /* 20132 ( 439) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  0]  1 */
    51034818, /* 20133 ( 439) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  0] -1 */
    51152754, /* 20134 ( 439) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  6] -1 */
    34133682, /* 20135 ( 439) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
      134420, /* 20136 ( 439) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6]  1 */
    17127572, /* 20137 ( 439) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
       16484, /* 20138 ( 440) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    17009312, /* 20139 ( 440) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  0]  1 */
    34146644, /* 20140 ( 440) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    51139796, /* 20141 ( 440) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
        3198, /* 20142 ( 440) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    51152754, /* 20143 ( 440) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  6] -1 */
    34133682, /* 20144 ( 440) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
    17022594, /* 20145 ( 440) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  0]  1 */
       16484, /* 20146 ( 441) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34146644, /* 20147 ( 441) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    51034818, /* 20148 ( 441) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  0] -1 */
        3198, /* 20149 ( 441) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    34133682, /* 20150 ( 441) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
    51021536, /* 20151 ( 441) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  0] -1 */
    17140530, /* 20152 ( 441) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  6]  1 */
    17127572, /* 20153 ( 441) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
       16484, /* 20154 ( 442) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
      121458, /* 20155 ( 442) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  6]  1 */
    51034818, /* 20156 ( 442) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  0] -1 */
    51139796, /* 20157 ( 442) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
        3198, /* 20158 ( 442) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    51152754, /* 20159 ( 442) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  6] -1 */
    51021536, /* 20160 ( 442) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  0] -1 */
      134420, /* 20161 ( 442) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6]  1 */
       16484, /* 20162 ( 443) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34015422, /* 20163 ( 443) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    17009312, /* 20164 ( 443) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  0]  1 */
      121458, /* 20165 ( 443) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  6]  1 */
    34146644, /* 20166 ( 443) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    51034818, /* 20167 ( 443) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  0] -1 */
    51139796, /* 20168 ( 443) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
    17140530, /* 20169 ( 443) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  6]  1 */
       16484, /* 20170 ( 444) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    51139794, /* 20171 ( 444) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6] -1 */
      121458, /* 20172 ( 444) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  6]  1 */
    17009312, /* 20173 ( 444) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  0]  1 */
    51152756, /* 20174 ( 444) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
    51034820, /* 20175 ( 444) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  0] -1 */
    34028706, /* 20176 ( 444) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
      134420, /* 20177 ( 444) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6]  1 */
    17127572, /* 20178 ( 444) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
        3198, /* 20179 ( 444) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    51021534, /* 20180 ( 444) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  0] -1 */
    34133684, /* 20181 ( 444) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    34146642, /* 20182 ( 444) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
    34015424, /* 20183 ( 444) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    17140530, /* 20184 ( 444) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  6]  1 */
    17022594, /* 20185 ( 444) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  0]  1 */
       16484, /* 20186 ( 445) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
      121458, /* 20187 ( 445) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  6]  1 */
    17009312, /* 20188 ( 445) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  0]  1 */
    35550858, /* 20189 ( 445) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6] -1 */
      134420, /* 20190 ( 445) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6]  1 */
    17127572, /* 20191 ( 445) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
    52451994, /* 20192 ( 445) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
        3198, /* 20193 ( 445) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    35445884, /* 20194 ( 445) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  0] -1 */
    52569930, /* 20195 ( 445) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    52556972, /* 20196 ( 445) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    35432598, /* 20197 ( 445) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  0] -1 */
    52438712, /* 20198 ( 445) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
    17140530, /* 20199 ( 445) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  6]  1 */
    35563820, /* 20200 ( 445) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
    17022594, /* 20201 ( 445) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  0]  1 */
       16484, /* 20202 ( 446) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34028546, /* 20203 ( 446) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
      121458, /* 20204 ( 446) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  6]  1 */
    17009312, /* 20205 ( 446) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  0]  1 */
    51021698, /* 20206 ( 446) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  0] -1 */
    51034656, /* 20207 ( 446) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  0] -1 */
    34015584, /* 20208 ( 446) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    51139634, /* 20209 ( 446) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
    34133520, /* 20210 ( 446) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
    17127572, /* 20211 ( 446) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
        3198, /* 20212 ( 446) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    34146806, /* 20213 ( 446) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    51152916, /* 20214 ( 446) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6] -1 */
      134420, /* 20215 ( 446) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6]  1 */
    17140530, /* 20216 ( 446) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  6]  1 */
    17022594, /* 20217 ( 446) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  0]  1 */
       16484, /* 20218 ( 447) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    35550696, /* 20219 ( 447) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  6] -1 */
      121458, /* 20220 ( 447) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  6]  1 */
    17009312, /* 20221 ( 447) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  0]  1 */
    52556810, /* 20222 ( 447) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    52438874, /* 20223 ( 447) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
    35432760, /* 20224 ( 447) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  0] -1 */
    35563982, /* 20225 ( 447) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
    17127572, /* 20226 ( 447) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
        3198, /* 20227 ( 447) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    35445722, /* 20228 ( 447) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  0] -1 */
      134420, /* 20229 ( 447) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6]  1 */
    52570092, /* 20230 ( 447) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    17140530, /* 20231 ( 447) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  6]  1 */
    52451832, /* 20232 ( 447) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
    17022594, /* 20233 ( 447) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  0]  1 */
       16484, /* 20234 ( 448) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34015586, /* 20235 ( 448) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    34133522, /* 20236 ( 448) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
      121458, /* 20237 ( 448) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  6]  1 */
    17009312, /* 20238 ( 448) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  0]  1 */
    51021696, /* 20239 ( 448) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  0] -1 */
    51034658, /* 20240 ( 448) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  0] -1 */
    51139632, /* 20241 ( 448) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  6] -1 */
    17127572, /* 20242 ( 448) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
      134420, /* 20243 ( 448) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6]  1 */
        3198, /* 20244 ( 448) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    51152918, /* 20245 ( 448) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
    34146804, /* 20246 ( 448) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
    17140530, /* 20247 ( 448) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  6]  1 */
    34028544, /* 20248 ( 448) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    17022594, /* 20249 ( 448) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  0]  1 */
       16484, /* 20250 ( 449) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    35445882, /* 20251 ( 449) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  0] -1 */
      121458, /* 20252 ( 449) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  6]  1 */
    17009312, /* 20253 ( 449) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  0]  1 */
    52438710, /* 20254 ( 449) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
    35550860, /* 20255 ( 449) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
    52569932, /* 20256 ( 449) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    35432600, /* 20257 ( 449) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  0] -1 */
    17127572, /* 20258 ( 449) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
    52451996, /* 20259 ( 449) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
        3198, /* 20260 ( 449) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    52556970, /* 20261 ( 449) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
      134420, /* 20262 ( 449) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6]  1 */
    17140530, /* 20263 ( 449) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  6]  1 */
    35563818, /* 20264 ( 449) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  6] -1 */
    17022594, /* 20265 ( 449) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  0]  1 */
       16484, /* 20266 ( 450) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    52451834, /* 20267 ( 450) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
      121458, /* 20268 ( 450) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  6]  1 */
    17009312, /* 20269 ( 450) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  0]  1 */
    35563980, /* 20270 ( 450) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6] -1 */
    35432762, /* 20271 ( 450) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  0] -1 */
    17127572, /* 20272 ( 450) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
    35445720, /* 20273 ( 450) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  0] -1 */
        3198, /* 20274 ( 450) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    52556808, /* 20275 ( 450) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    35550698, /* 20276 ( 450) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
      134420, /* 20277 ( 450) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6]  1 */
    52438872, /* 20278 ( 450) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
    17140530, /* 20279 ( 450) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  6]  1 */
    52570094, /* 20280 ( 450) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    17022594, /* 20281 ( 450) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  0]  1 */
       16484, /* 20282 ( 435) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
      134418, /* 20283 ( 435) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  6]  1 */
     1420376, /* 20284 ( 435) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  0]  1 */
     1551596, /* 20285 ( 435) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
        3198, /* 20286 ( 435) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
      121460, /* 20287 ( 435) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6]  1 */
     1538634, /* 20288 ( 435) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
     1433658, /* 20289 ( 435) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  0]  1 */
       16484, /* 20290 ( 436) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34015422, /* 20291 ( 436) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
     1420376, /* 20292 ( 436) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  0]  1 */
      134418, /* 20293 ( 436) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  6]  1 */
    34133684, /* 20294 ( 436) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    35445882, /* 20295 ( 436) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  0] -1 */
     1551596, /* 20296 ( 436) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
    35563820, /* 20297 ( 436) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
        3198, /* 20298 ( 436) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    35550858, /* 20299 ( 436) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6] -1 */
    34146642, /* 20300 ( 436) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
    35432600, /* 20301 ( 436) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  0] -1 */
      121460, /* 20302 ( 436) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6]  1 */
    34028708, /* 20303 ( 436) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
     1538634, /* 20304 ( 436) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
     1433658, /* 20305 ( 436) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  0]  1 */
       16484, /* 20306 ( 437) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34015422, /* 20307 ( 437) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    35563820, /* 20308 ( 437) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
    34146642, /* 20309 ( 437) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
    35432600, /* 20310 ( 437) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  0] -1 */
      121460, /* 20311 ( 437) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6]  1 */
     1538634, /* 20312 ( 437) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
     1433658, /* 20313 ( 437) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  0]  1 */
       16484, /* 20314 ( 438) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34015422, /* 20315 ( 438) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
      134418, /* 20316 ( 438) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  6]  1 */
    34133684, /* 20317 ( 438) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    35550858, /* 20318 ( 438) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6] -1 */
    35432600, /* 20319 ( 438) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  0] -1 */
     1433658, /* 20320 ( 438) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  0]  1 */
     1551596, /* 20321 ( 438) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
       16484, /* 20322 ( 439) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34015422, /* 20323 ( 439) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
     1420376, /* 20324 ( 439) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  0]  1 */
    35445882, /* 20325 ( 439) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  0] -1 */
    35550858, /* 20326 ( 439) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6] -1 */
    34146642, /* 20327 ( 439) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
      121460, /* 20328 ( 439) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6]  1 */
     1551596, /* 20329 ( 439) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
       16484, /* 20330 ( 440) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
     1420376, /* 20331 ( 440) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  0]  1 */
    34133684, /* 20332 ( 440) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    35563820, /* 20333 ( 440) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
        3198, /* 20334 ( 440) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    35550858, /* 20335 ( 440) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6] -1 */
    34146642, /* 20336 ( 440) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
     1433658, /* 20337 ( 440) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  0]  1 */
       16484, /* 20338 ( 441) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34133684, /* 20339 ( 441) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    35445882, /* 20340 ( 441) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  0] -1 */
        3198, /* 20341 ( 441) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    34146642, /* 20342 ( 441) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
    35432600, /* 20343 ( 441) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  0] -1 */
     1538634, /* 20344 ( 441) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
     1551596, /* 20345 ( 441) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
       16484, /* 20346 ( 442) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
      134418, /* 20347 ( 442) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  6]  1 */
    35445882, /* 20348 ( 442) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  0] -1 */
    35563820, /* 20349 ( 442) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
        3198, /* 20350 ( 442) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    35550858, /* 20351 ( 442) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6] -1 */
    35432600, /* 20352 ( 442) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  0] -1 */
      121460, /* 20353 ( 442) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6]  1 */
       16484, /* 20354 ( 443) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34015422, /* 20355 ( 443) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
     1420376, /* 20356 ( 443) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  0]  1 */
      134418, /* 20357 ( 443) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  6]  1 */
    34133684, /* 20358 ( 443) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    35445882, /* 20359 ( 443) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  0] -1 */
    35563820, /* 20360 ( 443) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
     1538634, /* 20361 ( 443) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
       16484, /* 20362 ( 444) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    35563818, /* 20363 ( 444) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  6] -1 */
      134418, /* 20364 ( 444) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  6]  1 */
     1420376, /* 20365 ( 444) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  0]  1 */
    35550860, /* 20366 ( 444) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
    35445884, /* 20367 ( 444) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  0] -1 */
    34028706, /* 20368 ( 444) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
      121460, /* 20369 ( 444) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6]  1 */
     1551596, /* 20370 ( 444) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
        3198, /* 20371 ( 444) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    35432598, /* 20372 ( 444) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  0] -1 */
    34146644, /* 20373 ( 444) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    34133682, /* 20374 ( 444) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
    34015424, /* 20375 ( 444) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
     1538634, /* 20376 ( 444) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
     1433658, /* 20377 ( 444) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  0]  1 */
       16484, /* 20378 ( 445) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
      134418, /* 20379 ( 445) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  6]  1 */
     1420376, /* 20380 ( 445) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  0]  1 */
    51152754, /* 20381 ( 445) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  6] -1 */
      121460, /* 20382 ( 445) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6]  1 */
     1551596, /* 20383 ( 445) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
    52451994, /* 20384 ( 445) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
        3198, /* 20385 ( 445) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    51034820, /* 20386 ( 445) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  0] -1 */
    52556970, /* 20387 ( 445) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    52569932, /* 20388 ( 445) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    51021534, /* 20389 ( 445) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  0] -1 */
    52438712, /* 20390 ( 445) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
     1538634, /* 20391 ( 445) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
    51139796, /* 20392 ( 445) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
     1433658, /* 20393 ( 445) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  0]  1 */
       16484, /* 20394 ( 446) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34015586, /* 20395 ( 446) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
      134418, /* 20396 ( 446) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  6]  1 */
     1420376, /* 20397 ( 446) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  0]  1 */
    35445722, /* 20398 ( 446) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  0] -1 */
    35432760, /* 20399 ( 446) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  0] -1 */
    34028544, /* 20400 ( 446) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    35550698, /* 20401 ( 446) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
    34133520, /* 20402 ( 446) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
     1551596, /* 20403 ( 446) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
        3198, /* 20404 ( 446) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    34146806, /* 20405 ( 446) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    35563980, /* 20406 ( 446) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6] -1 */
      121460, /* 20407 ( 446) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6]  1 */
     1538634, /* 20408 ( 446) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
     1433658, /* 20409 ( 446) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  0]  1 */
       16484, /* 20410 ( 447) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    51139632, /* 20411 ( 447) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  6] -1 */
      134418, /* 20412 ( 447) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  6]  1 */
     1420376, /* 20413 ( 447) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  0]  1 */
    52556810, /* 20414 ( 447) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    52451834, /* 20415 ( 447) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
    51034656, /* 20416 ( 447) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  0] -1 */
    51152918, /* 20417 ( 447) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
     1551596, /* 20418 ( 447) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
        3198, /* 20419 ( 447) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    51021698, /* 20420 ( 447) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  0] -1 */
      121460, /* 20421 ( 447) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6]  1 */
    52570092, /* 20422 ( 447) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
     1538634, /* 20423 ( 447) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
    52438872, /* 20424 ( 447) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
     1433658, /* 20425 ( 447) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  0]  1 */
       16484, /* 20426 ( 448) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34028546, /* 20427 ( 448) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    34133522, /* 20428 ( 448) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
      134418, /* 20429 ( 448) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  6]  1 */
     1420376, /* 20430 ( 448) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  0]  1 */
    35445720, /* 20431 ( 448) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  0] -1 */
    35432762, /* 20432 ( 448) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  0] -1 */
    35550696, /* 20433 ( 448) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  6] -1 */
     1551596, /* 20434 ( 448) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
      121460, /* 20435 ( 448) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6]  1 */
        3198, /* 20436 ( 448) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    35563982, /* 20437 ( 448) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
    34146804, /* 20438 ( 448) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
     1538634, /* 20439 ( 448) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
    34015584, /* 20440 ( 448) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
     1433658, /* 20441 ( 448) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  0]  1 */
       16484, /* 20442 ( 449) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    51034818, /* 20443 ( 449) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  0] -1 */
      134418, /* 20444 ( 449) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  6]  1 */
     1420376, /* 20445 ( 449) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  0]  1 */
    52438710, /* 20446 ( 449) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
    51152756, /* 20447 ( 449) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
    52556972, /* 20448 ( 449) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    51021536, /* 20449 ( 449) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  0] -1 */
     1551596, /* 20450 ( 449) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
    52451996, /* 20451 ( 449) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
        3198, /* 20452 ( 449) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    52569930, /* 20453 ( 449) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
      121460, /* 20454 ( 449) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6]  1 */
     1538634, /* 20455 ( 449) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
    51139794, /* 20456 ( 449) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6] -1 */
     1433658, /* 20457 ( 449) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  0]  1 */
       16484, /* 20458 ( 450) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    52438874, /* 20459 ( 450) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
      134418, /* 20460 ( 450) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  6]  1 */
     1420376, /* 20461 ( 450) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  0]  1 */
    51152916, /* 20462 ( 450) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6] -1 */
    51034658, /* 20463 ( 450) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  0] -1 */
     1551596, /* 20464 ( 450) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
    51021696, /* 20465 ( 450) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  0] -1 */
        3198, /* 20466 ( 450) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    52556808, /* 20467 ( 450) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    51139634, /* 20468 ( 450) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
      121460, /* 20469 ( 450) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6]  1 */
    52451832, /* 20470 ( 450) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
     1538634, /* 20471 ( 450) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
    52570094, /* 20472 ( 450) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
     1433658, /* 20473 ( 450) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  0]  1 */
       16484, /* 20474 ( 435) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    17009312, /* 20475 ( 435) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  0]  1 */
     1433496, /* 20476 ( 435) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  0]  1 */
    18439610, /* 20477 ( 435) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
        3198, /* 20478 ( 435) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    17022594, /* 20479 ( 435) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  0]  1 */
    18426648, /* 20480 ( 435) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
     1420538, /* 20481 ( 435) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  0]  1 */
       16484, /* 20482 ( 436) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34015422, /* 20483 ( 436) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
     1433496, /* 20484 ( 436) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  0]  1 */
    17009312, /* 20485 ( 436) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  0]  1 */
    51034818, /* 20486 ( 436) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  0] -1 */
    35432762, /* 20487 ( 436) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  0] -1 */
    18439610, /* 20488 ( 436) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    52451834, /* 20489 ( 436) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
        3198, /* 20490 ( 436) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    52438872, /* 20491 ( 436) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
    51021536, /* 20492 ( 436) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  0] -1 */
    35445720, /* 20493 ( 436) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  0] -1 */
    17022594, /* 20494 ( 436) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  0]  1 */
    34028708, /* 20495 ( 436) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    18426648, /* 20496 ( 436) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
     1420538, /* 20497 ( 436) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  0]  1 */
       16484, /* 20498 ( 437) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34015422, /* 20499 ( 437) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    52451834, /* 20500 ( 437) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
    51021536, /* 20501 ( 437) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  0] -1 */
    35445720, /* 20502 ( 437) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  0] -1 */
    17022594, /* 20503 ( 437) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  0]  1 */
    18426648, /* 20504 ( 437) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
     1420538, /* 20505 ( 437) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  0]  1 */
       16484, /* 20506 ( 438) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34015422, /* 20507 ( 438) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    17009312, /* 20508 ( 438) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  0]  1 */
    51034818, /* 20509 ( 438) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  0] -1 */
    52438872, /* 20510 ( 438) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
    35445720, /* 20511 ( 438) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  0] -1 */
     1420538, /* 20512 ( 438) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  0]  1 */
    18439610, /* 20513 ( 438) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
       16484, /* 20514 ( 439) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34015422, /* 20515 ( 439) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
     1433496, /* 20516 ( 439) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  0]  1 */
    35432762, /* 20517 ( 439) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  0] -1 */
    52438872, /* 20518 ( 439) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
    51021536, /* 20519 ( 439) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  0] -1 */
    17022594, /* 20520 ( 439) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  0]  1 */
    18439610, /* 20521 ( 439) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
       16484, /* 20522 ( 440) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
     1433496, /* 20523 ( 440) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  0]  1 */
    51034818, /* 20524 ( 440) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  0] -1 */
    52451834, /* 20525 ( 440) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
        3198, /* 20526 ( 440) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    52438872, /* 20527 ( 440) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
    51021536, /* 20528 ( 440) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  0] -1 */
     1420538, /* 20529 ( 440) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  0]  1 */
       16484, /* 20530 ( 441) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    51034818, /* 20531 ( 441) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  0] -1 */
    35432762, /* 20532 ( 441) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  0] -1 */
        3198, /* 20533 ( 441) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    51021536, /* 20534 ( 441) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  0] -1 */
    35445720, /* 20535 ( 441) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  0] -1 */
    18426648, /* 20536 ( 441) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
    18439610, /* 20537 ( 441) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
       16484, /* 20538 ( 442) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    17009312, /* 20539 ( 442) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  0]  1 */
    35432762, /* 20540 ( 442) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  0] -1 */
    52451834, /* 20541 ( 442) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
        3198, /* 20542 ( 442) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    52438872, /* 20543 ( 442) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
    35445720, /* 20544 ( 442) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  0] -1 */
    17022594, /* 20545 ( 442) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  0]  1 */
       16484, /* 20546 ( 443) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34015422, /* 20547 ( 443) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
     1433496, /* 20548 ( 443) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  0]  1 */
    17009312, /* 20549 ( 443) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  0]  1 */
    51034818, /* 20550 ( 443) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  0] -1 */
    35432762, /* 20551 ( 443) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  0] -1 */
    52451834, /* 20552 ( 443) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
    18426648, /* 20553 ( 443) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
       16484, /* 20554 ( 444) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    52438712, /* 20555 ( 444) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
    17009312, /* 20556 ( 444) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  0]  1 */
     1433496, /* 20557 ( 444) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  0]  1 */
    52451994, /* 20558 ( 444) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
    35445884, /* 20559 ( 444) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  0] -1 */
    34015586, /* 20560 ( 444) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    17022594, /* 20561 ( 444) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  0]  1 */
    18439610, /* 20562 ( 444) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
        3198, /* 20563 ( 444) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    35432598, /* 20564 ( 444) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  0] -1 */
    51034658, /* 20565 ( 444) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  0] -1 */
    51021696, /* 20566 ( 444) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  0] -1 */
    34028544, /* 20567 ( 444) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    18426648, /* 20568 ( 444) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
     1420538, /* 20569 ( 444) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  0]  1 */
       16484, /* 20570 ( 445) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    17009312, /* 20571 ( 445) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  0]  1 */
     1433496, /* 20572 ( 445) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  0]  1 */
    51139634, /* 20573 ( 445) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
    17022594, /* 20574 ( 445) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  0]  1 */
    18439610, /* 20575 ( 445) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    35550860, /* 20576 ( 445) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
        3198, /* 20577 ( 445) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    34146806, /* 20578 ( 445) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    52556970, /* 20579 ( 445) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    52569932, /* 20580 ( 445) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    34133520, /* 20581 ( 445) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
    35563818, /* 20582 ( 445) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  6] -1 */
    18426648, /* 20583 ( 445) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
    51152916, /* 20584 ( 445) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6] -1 */
     1420538, /* 20585 ( 445) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  0]  1 */
       16484, /* 20586 ( 446) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34028706, /* 20587 ( 446) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    17009312, /* 20588 ( 446) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  0]  1 */
     1433496, /* 20589 ( 446) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  0]  1 */
    35445722, /* 20590 ( 446) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  0] -1 */
    35432760, /* 20591 ( 446) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  0] -1 */
    34015424, /* 20592 ( 446) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    52451832, /* 20593 ( 446) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
    51021534, /* 20594 ( 446) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  0] -1 */
    18439610, /* 20595 ( 446) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
        3198, /* 20596 ( 446) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    51034820, /* 20597 ( 446) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  0] -1 */
    52438874, /* 20598 ( 446) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
    17022594, /* 20599 ( 446) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  0]  1 */
    18426648, /* 20600 ( 446) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
     1420538, /* 20601 ( 446) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  0]  1 */
       16484, /* 20602 ( 447) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    51139632, /* 20603 ( 447) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  6] -1 */
    17009312, /* 20604 ( 447) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  0]  1 */
     1433496, /* 20605 ( 447) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  0]  1 */
    52569930, /* 20606 ( 447) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    35563820, /* 20607 ( 447) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
    34133522, /* 20608 ( 447) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    51152918, /* 20609 ( 447) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
    18439610, /* 20610 ( 447) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
        3198, /* 20611 ( 447) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    34146804, /* 20612 ( 447) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
    17022594, /* 20613 ( 447) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  0]  1 */
    52556972, /* 20614 ( 447) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    18426648, /* 20615 ( 447) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
    35550858, /* 20616 ( 447) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6] -1 */
     1420538, /* 20617 ( 447) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  0]  1 */
       16484, /* 20618 ( 448) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34028546, /* 20619 ( 448) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    51034656, /* 20620 ( 448) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  0] -1 */
    17009312, /* 20621 ( 448) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  0]  1 */
     1433496, /* 20622 ( 448) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  0]  1 */
    35432600, /* 20623 ( 448) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  0] -1 */
    35445882, /* 20624 ( 448) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  0] -1 */
    52438710, /* 20625 ( 448) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
    18439610, /* 20626 ( 448) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    17022594, /* 20627 ( 448) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  0]  1 */
        3198, /* 20628 ( 448) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    52451996, /* 20629 ( 448) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
    51021698, /* 20630 ( 448) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  0] -1 */
    18426648, /* 20631 ( 448) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
    34015584, /* 20632 ( 448) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
     1420538, /* 20633 ( 448) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  0]  1 */
       16484, /* 20634 ( 449) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34133684, /* 20635 ( 449) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    17009312, /* 20636 ( 449) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  0]  1 */
     1433496, /* 20637 ( 449) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  0]  1 */
    35550696, /* 20638 ( 449) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  6] -1 */
    51152756, /* 20639 ( 449) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
    52570092, /* 20640 ( 449) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    34146642, /* 20641 ( 449) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
    18439610, /* 20642 ( 449) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    35563982, /* 20643 ( 449) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
        3198, /* 20644 ( 449) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    52556810, /* 20645 ( 449) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    17022594, /* 20646 ( 449) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  0]  1 */
    18426648, /* 20647 ( 449) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
    51139794, /* 20648 ( 449) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6] -1 */
     1420538, /* 20649 ( 449) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  0]  1 */
       16484, /* 20650 ( 450) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    35563980, /* 20651 ( 450) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6] -1 */
    17009312, /* 20652 ( 450) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  0]  1 */
     1433496, /* 20653 ( 450) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  0]  1 */
    51139796, /* 20654 ( 450) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
    34146644, /* 20655 ( 450) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    18439610, /* 20656 ( 450) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    34133682, /* 20657 ( 450) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
        3198, /* 20658 ( 450) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    52556808, /* 20659 ( 450) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    51152754, /* 20660 ( 450) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  6] -1 */
    17022594, /* 20661 ( 450) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  0]  1 */
    35550698, /* 20662 ( 450) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
    18426648, /* 20663 ( 450) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
    52570094, /* 20664 ( 450) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
     1420538, /* 20665 ( 450) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  0]  1 */
       16484, /* 20666 ( 435) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    17009472, /* 20667 ( 435) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  0]  1 */
      134418, /* 20668 ( 435) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  6]  1 */
    17140692, /* 20669 ( 435) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6]  1 */
        3198, /* 20670 ( 435) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    17022434, /* 20671 ( 435) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  0]  1 */
    17127410, /* 20672 ( 435) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
      121460, /* 20673 ( 435) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6]  1 */
       16484, /* 20674 ( 436) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34015422, /* 20675 ( 436) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
      134418, /* 20676 ( 436) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  6]  1 */
    17009472, /* 20677 ( 436) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  0]  1 */
    51034658, /* 20678 ( 436) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  0] -1 */
    34133684, /* 20679 ( 436) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    17140692, /* 20680 ( 436) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6]  1 */
    51152916, /* 20681 ( 436) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6] -1 */
        3198, /* 20682 ( 436) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    51139634, /* 20683 ( 436) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
    51021696, /* 20684 ( 436) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  0] -1 */
    34146642, /* 20685 ( 436) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
    17022434, /* 20686 ( 436) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  0]  1 */
    34028708, /* 20687 ( 436) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    17127410, /* 20688 ( 436) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
      121460, /* 20689 ( 436) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6]  1 */
       16484, /* 20690 ( 437) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34015422, /* 20691 ( 437) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    51152916, /* 20692 ( 437) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6] -1 */
    51021696, /* 20693 ( 437) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  0] -1 */
    34146642, /* 20694 ( 437) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
    17022434, /* 20695 ( 437) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  0]  1 */
    17127410, /* 20696 ( 437) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
      121460, /* 20697 ( 437) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6]  1 */
       16484, /* 20698 ( 438) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34015422, /* 20699 ( 438) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    17009472, /* 20700 ( 438) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  0]  1 */
    51034658, /* 20701 ( 438) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  0] -1 */
    51139634, /* 20702 ( 438) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
    34146642, /* 20703 ( 438) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
      121460, /* 20704 ( 438) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6]  1 */
    17140692, /* 20705 ( 438) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6]  1 */
       16484, /* 20706 ( 439) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34015422, /* 20707 ( 439) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
      134418, /* 20708 ( 439) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  6]  1 */
    34133684, /* 20709 ( 439) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    51139634, /* 20710 ( 439) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
    51021696, /* 20711 ( 439) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  0] -1 */
    17022434, /* 20712 ( 439) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  0]  1 */
    17140692, /* 20713 ( 439) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6]  1 */
       16484, /* 20714 ( 440) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
      134418, /* 20715 ( 440) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  6]  1 */
    51034658, /* 20716 ( 440) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  0] -1 */
    51152916, /* 20717 ( 440) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6] -1 */
        3198, /* 20718 ( 440) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    51139634, /* 20719 ( 440) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
    51021696, /* 20720 ( 440) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  0] -1 */
      121460, /* 20721 ( 440) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6]  1 */
       16484, /* 20722 ( 441) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    51034658, /* 20723 ( 441) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  0] -1 */
    34133684, /* 20724 ( 441) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
        3198, /* 20725 ( 441) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    51021696, /* 20726 ( 441) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  0] -1 */
    34146642, /* 20727 ( 441) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
    17127410, /* 20728 ( 441) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
    17140692, /* 20729 ( 441) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6]  1 */
       16484, /* 20730 ( 442) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    17009472, /* 20731 ( 442) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  0]  1 */
    34133684, /* 20732 ( 442) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    51152916, /* 20733 ( 442) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6] -1 */
        3198, /* 20734 ( 442) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    51139634, /* 20735 ( 442) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
    34146642, /* 20736 ( 442) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
    17022434, /* 20737 ( 442) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  0]  1 */
       16484, /* 20738 ( 443) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34015422, /* 20739 ( 443) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
      134418, /* 20740 ( 443) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  6]  1 */
    17009472, /* 20741 ( 443) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  0]  1 */
    51034658, /* 20742 ( 443) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  0] -1 */
    34133684, /* 20743 ( 443) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    51152916, /* 20744 ( 443) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6] -1 */
    17127410, /* 20745 ( 443) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
       16484, /* 20746 ( 444) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    51139794, /* 20747 ( 444) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6] -1 */
    17009472, /* 20748 ( 444) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  0]  1 */
      134418, /* 20749 ( 444) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  6]  1 */
    51152756, /* 20750 ( 444) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
    34146806, /* 20751 ( 444) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    34015586, /* 20752 ( 444) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    17022434, /* 20753 ( 444) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  0]  1 */
    17140692, /* 20754 ( 444) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6]  1 */
        3198, /* 20755 ( 444) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    34133520, /* 20756 ( 444) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
    51034818, /* 20757 ( 444) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  0] -1 */
    51021536, /* 20758 ( 444) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  0] -1 */
    34028544, /* 20759 ( 444) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    17127410, /* 20760 ( 444) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
      121460, /* 20761 ( 444) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6]  1 */
       16484, /* 20762 ( 445) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    17009472, /* 20763 ( 445) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  0]  1 */
      134418, /* 20764 ( 445) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  6]  1 */
    52438872, /* 20765 ( 445) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
    17022434, /* 20766 ( 445) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  0]  1 */
    17140692, /* 20767 ( 445) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6]  1 */
    35550860, /* 20768 ( 445) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
        3198, /* 20769 ( 445) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    35445884, /* 20770 ( 445) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  0] -1 */
    52556810, /* 20771 ( 445) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    52570092, /* 20772 ( 445) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    35432598, /* 20773 ( 445) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  0] -1 */
    35563818, /* 20774 ( 445) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  6] -1 */
    17127410, /* 20775 ( 445) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
    52451834, /* 20776 ( 445) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
      121460, /* 20777 ( 445) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6]  1 */
       16484, /* 20778 ( 446) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34028546, /* 20779 ( 446) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    17009472, /* 20780 ( 446) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  0]  1 */
      134418, /* 20781 ( 446) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  6]  1 */
    34146804, /* 20782 ( 446) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
    34133522, /* 20783 ( 446) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    34015584, /* 20784 ( 446) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    51152754, /* 20785 ( 446) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  6] -1 */
    51021534, /* 20786 ( 446) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  0] -1 */
    17140692, /* 20787 ( 446) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6]  1 */
        3198, /* 20788 ( 446) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    51034820, /* 20789 ( 446) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  0] -1 */
    51139796, /* 20790 ( 446) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
    17022434, /* 20791 ( 446) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  0]  1 */
    17127410, /* 20792 ( 446) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
      121460, /* 20793 ( 446) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6]  1 */
       16484, /* 20794 ( 447) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    52438710, /* 20795 ( 447) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
    17009472, /* 20796 ( 447) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  0]  1 */
      134418, /* 20797 ( 447) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  6]  1 */
    52569930, /* 20798 ( 447) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    35563980, /* 20799 ( 447) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6] -1 */
    35432760, /* 20800 ( 447) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  0] -1 */
    52451996, /* 20801 ( 447) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
    17140692, /* 20802 ( 447) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6]  1 */
        3198, /* 20803 ( 447) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    35445722, /* 20804 ( 447) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  0] -1 */
    17022434, /* 20805 ( 447) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  0]  1 */
    52556972, /* 20806 ( 447) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    17127410, /* 20807 ( 447) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
    35550698, /* 20808 ( 447) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
      121460, /* 20809 ( 447) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6]  1 */
       16484, /* 20810 ( 448) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34028706, /* 20811 ( 448) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    51034656, /* 20812 ( 448) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  0] -1 */
    17009472, /* 20813 ( 448) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  0]  1 */
      134418, /* 20814 ( 448) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  6]  1 */
    34133682, /* 20815 ( 448) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
    34146644, /* 20816 ( 448) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    51139632, /* 20817 ( 448) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  6] -1 */
    17140692, /* 20818 ( 448) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6]  1 */
    17022434, /* 20819 ( 448) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  0]  1 */
        3198, /* 20820 ( 448) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    51152918, /* 20821 ( 448) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
    51021698, /* 20822 ( 448) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  0] -1 */
    17127410, /* 20823 ( 448) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
    34015424, /* 20824 ( 448) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
      121460, /* 20825 ( 448) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6]  1 */
       16484, /* 20826 ( 449) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    35432762, /* 20827 ( 449) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  0] -1 */
    17009472, /* 20828 ( 449) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  0]  1 */
      134418, /* 20829 ( 449) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  6]  1 */
    35550696, /* 20830 ( 449) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  6] -1 */
    52451994, /* 20831 ( 449) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
    52569932, /* 20832 ( 449) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    35445720, /* 20833 ( 449) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  0] -1 */
    17140692, /* 20834 ( 449) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6]  1 */
    35563982, /* 20835 ( 449) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
        3198, /* 20836 ( 449) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    52556970, /* 20837 ( 449) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    17022434, /* 20838 ( 449) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  0]  1 */
    17127410, /* 20839 ( 449) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
    52438712, /* 20840 ( 449) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
      121460, /* 20841 ( 449) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6]  1 */
       16484, /* 20842 ( 450) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    35563820, /* 20843 ( 450) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
    17009472, /* 20844 ( 450) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  0]  1 */
      134418, /* 20845 ( 450) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  6]  1 */
    52438874, /* 20846 ( 450) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
    35445882, /* 20847 ( 450) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  0] -1 */
    17140692, /* 20848 ( 450) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6]  1 */
    35432600, /* 20849 ( 450) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  0] -1 */
        3198, /* 20850 ( 450) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    52556808, /* 20851 ( 450) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    52451832, /* 20852 ( 450) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
    17022434, /* 20853 ( 450) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  0]  1 */
    35550858, /* 20854 ( 450) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6] -1 */
    17127410, /* 20855 ( 450) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
    52570094, /* 20856 ( 450) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
      121460, /* 20857 ( 450) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6]  1 */
       16484, /* 20858 ( 435) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
     1433496, /* 20859 ( 435) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  0]  1 */
      121458, /* 20860 ( 435) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  6]  1 */
     1551756, /* 20861 ( 435) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
        3198, /* 20862 ( 435) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
     1420538, /* 20863 ( 435) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  0]  1 */
     1538474, /* 20864 ( 435) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
      134420, /* 20865 ( 435) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6]  1 */
       16484, /* 20866 ( 436) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34015422, /* 20867 ( 436) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
      121458, /* 20868 ( 436) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  6]  1 */
     1433496, /* 20869 ( 436) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  0]  1 */
    35432762, /* 20870 ( 436) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  0] -1 */
    34146644, /* 20871 ( 436) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
     1551756, /* 20872 ( 436) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
    35563980, /* 20873 ( 436) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6] -1 */
        3198, /* 20874 ( 436) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    35550698, /* 20875 ( 436) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
    35445720, /* 20876 ( 436) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  0] -1 */
    34133682, /* 20877 ( 436) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
     1420538, /* 20878 ( 436) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  0]  1 */
    34028708, /* 20879 ( 436) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
     1538474, /* 20880 ( 436) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
      134420, /* 20881 ( 436) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6]  1 */
       16484, /* 20882 ( 437) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34015422, /* 20883 ( 437) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    35563980, /* 20884 ( 437) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6] -1 */
    35445720, /* 20885 ( 437) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  0] -1 */
    34133682, /* 20886 ( 437) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
     1420538, /* 20887 ( 437) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  0]  1 */
     1538474, /* 20888 ( 437) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
      134420, /* 20889 ( 437) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6]  1 */
       16484, /* 20890 ( 438) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34015422, /* 20891 ( 438) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
     1433496, /* 20892 ( 438) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  0]  1 */
    35432762, /* 20893 ( 438) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  0] -1 */
    35550698, /* 20894 ( 438) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
    34133682, /* 20895 ( 438) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
      134420, /* 20896 ( 438) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6]  1 */
     1551756, /* 20897 ( 438) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
       16484, /* 20898 ( 439) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34015422, /* 20899 ( 439) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
      121458, /* 20900 ( 439) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  6]  1 */
    34146644, /* 20901 ( 439) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    35550698, /* 20902 ( 439) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
    35445720, /* 20903 ( 439) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  0] -1 */
     1420538, /* 20904 ( 439) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  0]  1 */
     1551756, /* 20905 ( 439) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
       16484, /* 20906 ( 440) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
      121458, /* 20907 ( 440) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  6]  1 */
    35432762, /* 20908 ( 440) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  0] -1 */
    35563980, /* 20909 ( 440) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6] -1 */
        3198, /* 20910 ( 440) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    35550698, /* 20911 ( 440) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
    35445720, /* 20912 ( 440) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  0] -1 */
      134420, /* 20913 ( 440) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6]  1 */
       16484, /* 20914 ( 441) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    35432762, /* 20915 ( 441) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  0] -1 */
    34146644, /* 20916 ( 441) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
        3198, /* 20917 ( 441) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    35445720, /* 20918 ( 441) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  0] -1 */
    34133682, /* 20919 ( 441) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
     1538474, /* 20920 ( 441) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
     1551756, /* 20921 ( 441) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
       16484, /* 20922 ( 442) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
     1433496, /* 20923 ( 442) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  0]  1 */
    34146644, /* 20924 ( 442) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    35563980, /* 20925 ( 442) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6] -1 */
        3198, /* 20926 ( 442) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    35550698, /* 20927 ( 442) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
    34133682, /* 20928 ( 442) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
     1420538, /* 20929 ( 442) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  0]  1 */
       16484, /* 20930 ( 443) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34015422, /* 20931 ( 443) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
      121458, /* 20932 ( 443) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  6]  1 */
     1433496, /* 20933 ( 443) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  0]  1 */
    35432762, /* 20934 ( 443) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  0] -1 */
    34146644, /* 20935 ( 443) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    35563980, /* 20936 ( 443) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6] -1 */
     1538474, /* 20937 ( 443) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
       16484, /* 20938 ( 444) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    35563818, /* 20939 ( 444) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  6] -1 */
     1433496, /* 20940 ( 444) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  0]  1 */
      121458, /* 20941 ( 444) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  6]  1 */
    35550860, /* 20942 ( 444) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
    34146806, /* 20943 ( 444) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    34028546, /* 20944 ( 444) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
     1420538, /* 20945 ( 444) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  0]  1 */
     1551756, /* 20946 ( 444) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
        3198, /* 20947 ( 444) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    34133520, /* 20948 ( 444) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
    35445882, /* 20949 ( 444) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  0] -1 */
    35432600, /* 20950 ( 444) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  0] -1 */
    34015584, /* 20951 ( 444) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
     1538474, /* 20952 ( 444) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
      134420, /* 20953 ( 444) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6]  1 */
       16484, /* 20954 ( 445) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
     1433496, /* 20955 ( 445) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  0]  1 */
      121458, /* 20956 ( 445) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  6]  1 */
    52451832, /* 20957 ( 445) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
     1420538, /* 20958 ( 445) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  0]  1 */
     1551756, /* 20959 ( 445) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
    51152756, /* 20960 ( 445) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
        3198, /* 20961 ( 445) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    51034820, /* 20962 ( 445) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  0] -1 */
    52556810, /* 20963 ( 445) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    52570092, /* 20964 ( 445) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    51021534, /* 20965 ( 445) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  0] -1 */
    51139794, /* 20966 ( 445) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6] -1 */
     1538474, /* 20967 ( 445) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
    52438874, /* 20968 ( 445) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
      134420, /* 20969 ( 445) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6]  1 */
       16484, /* 20970 ( 446) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34015586, /* 20971 ( 446) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
     1433496, /* 20972 ( 446) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  0]  1 */
      121458, /* 20973 ( 446) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  6]  1 */
    34146804, /* 20974 ( 446) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
    34133522, /* 20975 ( 446) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    34028544, /* 20976 ( 446) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    35550858, /* 20977 ( 446) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6] -1 */
    35432598, /* 20978 ( 446) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  0] -1 */
     1551756, /* 20979 ( 446) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
        3198, /* 20980 ( 446) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    35445884, /* 20981 ( 446) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  0] -1 */
    35563820, /* 20982 ( 446) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
     1420538, /* 20983 ( 446) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  0]  1 */
     1538474, /* 20984 ( 446) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
      134420, /* 20985 ( 446) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6]  1 */
       16484, /* 20986 ( 447) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    52438710, /* 20987 ( 447) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
     1433496, /* 20988 ( 447) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  0]  1 */
      121458, /* 20989 ( 447) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  6]  1 */
    52556970, /* 20990 ( 447) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    51152916, /* 20991 ( 447) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6] -1 */
    51034656, /* 20992 ( 447) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  0] -1 */
    52451996, /* 20993 ( 447) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
     1551756, /* 20994 ( 447) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
        3198, /* 20995 ( 447) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    51021698, /* 20996 ( 447) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  0] -1 */
     1420538, /* 20997 ( 447) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  0]  1 */
    52569932, /* 20998 ( 447) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
     1538474, /* 20999 ( 447) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
    51139634, /* 21000 ( 447) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
      134420, /* 21001 ( 447) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6]  1 */
       16484, /* 21002 ( 448) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34028706, /* 21003 ( 448) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    35432760, /* 21004 ( 448) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  0] -1 */
     1433496, /* 21005 ( 448) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  0]  1 */
      121458, /* 21006 ( 448) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  6]  1 */
    34146642, /* 21007 ( 448) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
    34133684, /* 21008 ( 448) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    35550696, /* 21009 ( 448) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  6] -1 */
     1551756, /* 21010 ( 448) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
     1420538, /* 21011 ( 448) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  0]  1 */
        3198, /* 21012 ( 448) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    35563982, /* 21013 ( 448) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
    35445722, /* 21014 ( 448) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  0] -1 */
     1538474, /* 21015 ( 448) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
    34015424, /* 21016 ( 448) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
      134420, /* 21017 ( 448) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6]  1 */
       16484, /* 21018 ( 449) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    51034658, /* 21019 ( 449) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  0] -1 */
     1433496, /* 21020 ( 449) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  0]  1 */
      121458, /* 21021 ( 449) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  6]  1 */
    51139632, /* 21022 ( 449) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  6] -1 */
    52451994, /* 21023 ( 449) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
    52556972, /* 21024 ( 449) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    51021696, /* 21025 ( 449) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  0] -1 */
     1551756, /* 21026 ( 449) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
    51152918, /* 21027 ( 449) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
        3198, /* 21028 ( 449) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    52569930, /* 21029 ( 449) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
     1420538, /* 21030 ( 449) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  0]  1 */
     1538474, /* 21031 ( 449) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
    52438712, /* 21032 ( 449) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
      134420, /* 21033 ( 449) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6]  1 */
       16484, /* 21034 ( 450) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    51139796, /* 21035 ( 450) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
     1433496, /* 21036 ( 450) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  0]  1 */
      121458, /* 21037 ( 450) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  6]  1 */
    52451834, /* 21038 ( 450) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
    51034818, /* 21039 ( 450) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  0] -1 */
     1551756, /* 21040 ( 450) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
    51021536, /* 21041 ( 450) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  0] -1 */
        3198, /* 21042 ( 450) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    52556808, /* 21043 ( 450) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    52438872, /* 21044 ( 450) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
     1420538, /* 21045 ( 450) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  0]  1 */
    51152754, /* 21046 ( 450) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  6] -1 */
     1538474, /* 21047 ( 450) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
    52570094, /* 21048 ( 450) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
      134420, /* 21049 ( 450) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6]  1 */
       16484, /* 21050 ( 435) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
     1420376, /* 21051 ( 435) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  0]  1 */
    17009472, /* 21052 ( 435) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  0]  1 */
    18426650, /* 21053 ( 435) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
        3198, /* 21054 ( 435) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
     1433658, /* 21055 ( 435) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  0]  1 */
    18439608, /* 21056 ( 435) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
    17022434, /* 21057 ( 435) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  0]  1 */
       16484, /* 21058 ( 436) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34015422, /* 21059 ( 436) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    17009472, /* 21060 ( 436) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  0]  1 */
     1420376, /* 21061 ( 436) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  0]  1 */
    35445882, /* 21062 ( 436) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  0] -1 */
    51034658, /* 21063 ( 436) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  0] -1 */
    18426650, /* 21064 ( 436) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    52438874, /* 21065 ( 436) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
        3198, /* 21066 ( 436) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    52451832, /* 21067 ( 436) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
    35432600, /* 21068 ( 436) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  0] -1 */
    51021696, /* 21069 ( 436) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  0] -1 */
     1433658, /* 21070 ( 436) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  0]  1 */
    34028708, /* 21071 ( 436) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    18439608, /* 21072 ( 436) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
    17022434, /* 21073 ( 436) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  0]  1 */
       16484, /* 21074 ( 437) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34015422, /* 21075 ( 437) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    52438874, /* 21076 ( 437) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
    35432600, /* 21077 ( 437) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  0] -1 */
    51021696, /* 21078 ( 437) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  0] -1 */
     1433658, /* 21079 ( 437) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  0]  1 */
    18439608, /* 21080 ( 437) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
    17022434, /* 21081 ( 437) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  0]  1 */
       16484, /* 21082 ( 438) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34015422, /* 21083 ( 438) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
     1420376, /* 21084 ( 438) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  0]  1 */
    35445882, /* 21085 ( 438) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  0] -1 */
    52451832, /* 21086 ( 438) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
    51021696, /* 21087 ( 438) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  0] -1 */
    17022434, /* 21088 ( 438) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  0]  1 */
    18426650, /* 21089 ( 438) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
       16484, /* 21090 ( 439) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34015422, /* 21091 ( 439) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    17009472, /* 21092 ( 439) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  0]  1 */
    51034658, /* 21093 ( 439) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  0] -1 */
    52451832, /* 21094 ( 439) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
    35432600, /* 21095 ( 439) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  0] -1 */
     1433658, /* 21096 ( 439) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  0]  1 */
    18426650, /* 21097 ( 439) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
       16484, /* 21098 ( 440) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    17009472, /* 21099 ( 440) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  0]  1 */
    35445882, /* 21100 ( 440) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  0] -1 */
    52438874, /* 21101 ( 440) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
        3198, /* 21102 ( 440) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    52451832, /* 21103 ( 440) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
    35432600, /* 21104 ( 440) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  0] -1 */
    17022434, /* 21105 ( 440) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  0]  1 */
       16484, /* 21106 ( 441) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    35445882, /* 21107 ( 441) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  0] -1 */
    51034658, /* 21108 ( 441) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  0] -1 */
        3198, /* 21109 ( 441) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    35432600, /* 21110 ( 441) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  0] -1 */
    51021696, /* 21111 ( 441) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  0] -1 */
    18439608, /* 21112 ( 441) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
    18426650, /* 21113 ( 441) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
       16484, /* 21114 ( 442) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
     1420376, /* 21115 ( 442) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  0]  1 */
    51034658, /* 21116 ( 442) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  0] -1 */
    52438874, /* 21117 ( 442) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
        3198, /* 21118 ( 442) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    52451832, /* 21119 ( 442) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
    51021696, /* 21120 ( 442) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  0] -1 */
     1433658, /* 21121 ( 442) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  0]  1 */
       16484, /* 21122 ( 443) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34015422, /* 21123 ( 443) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    17009472, /* 21124 ( 443) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  0]  1 */
     1420376, /* 21125 ( 443) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  0]  1 */
    35445882, /* 21126 ( 443) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  0] -1 */
    51034658, /* 21127 ( 443) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  0] -1 */
    52438874, /* 21128 ( 443) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
    18439608, /* 21129 ( 443) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
       16484, /* 21130 ( 444) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    52438712, /* 21131 ( 444) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
     1420376, /* 21132 ( 444) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  0]  1 */
    17009472, /* 21133 ( 444) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  0]  1 */
    52451994, /* 21134 ( 444) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
    51034820, /* 21135 ( 444) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  0] -1 */
    34028546, /* 21136 ( 444) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
     1433658, /* 21137 ( 444) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  0]  1 */
    18426650, /* 21138 ( 444) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
        3198, /* 21139 ( 444) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    51021534, /* 21140 ( 444) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  0] -1 */
    35432762, /* 21141 ( 444) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  0] -1 */
    35445720, /* 21142 ( 444) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  0] -1 */
    34015584, /* 21143 ( 444) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    18439608, /* 21144 ( 444) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
    17022434, /* 21145 ( 444) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  0]  1 */
       16484, /* 21146 ( 445) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
     1420376, /* 21147 ( 445) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  0]  1 */
    17009472, /* 21148 ( 445) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  0]  1 */
    35550698, /* 21149 ( 445) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
     1433658, /* 21150 ( 445) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  0]  1 */
    18426650, /* 21151 ( 445) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    51152756, /* 21152 ( 445) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
        3198, /* 21153 ( 445) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    34146806, /* 21154 ( 445) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    52569930, /* 21155 ( 445) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    52556972, /* 21156 ( 445) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    34133520, /* 21157 ( 445) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
    51139794, /* 21158 ( 445) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6] -1 */
    18439608, /* 21159 ( 445) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
    35563980, /* 21160 ( 445) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6] -1 */
    17022434, /* 21161 ( 445) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  0]  1 */
       16484, /* 21162 ( 446) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34028706, /* 21163 ( 446) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
     1420376, /* 21164 ( 446) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  0]  1 */
    17009472, /* 21165 ( 446) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  0]  1 */
    51021698, /* 21166 ( 446) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  0] -1 */
    51034656, /* 21167 ( 446) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  0] -1 */
    34015424, /* 21168 ( 446) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    52438872, /* 21169 ( 446) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
    35432598, /* 21170 ( 446) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  0] -1 */
    18426650, /* 21171 ( 446) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
        3198, /* 21172 ( 446) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    35445884, /* 21173 ( 446) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  0] -1 */
    52451834, /* 21174 ( 446) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
     1433658, /* 21175 ( 446) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  0]  1 */
    18439608, /* 21176 ( 446) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
    17022434, /* 21177 ( 446) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  0]  1 */
       16484, /* 21178 ( 447) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    35550696, /* 21179 ( 447) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  6] -1 */
     1420376, /* 21180 ( 447) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  0]  1 */
    17009472, /* 21181 ( 447) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  0]  1 */
    52556970, /* 21182 ( 447) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    51139796, /* 21183 ( 447) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
    34133522, /* 21184 ( 447) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    35563982, /* 21185 ( 447) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
    18426650, /* 21186 ( 447) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
        3198, /* 21187 ( 447) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    34146804, /* 21188 ( 447) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
     1433658, /* 21189 ( 447) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  0]  1 */
    52569932, /* 21190 ( 447) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    18439608, /* 21191 ( 447) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
    51152754, /* 21192 ( 447) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  6] -1 */
    17022434, /* 21193 ( 447) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  0]  1 */
       16484, /* 21194 ( 448) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34015586, /* 21195 ( 448) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    35432760, /* 21196 ( 448) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  0] -1 */
     1420376, /* 21197 ( 448) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  0]  1 */
    17009472, /* 21198 ( 448) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  0]  1 */
    51021536, /* 21199 ( 448) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  0] -1 */
    51034818, /* 21200 ( 448) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  0] -1 */
    52438710, /* 21201 ( 448) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
    18426650, /* 21202 ( 448) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
     1433658, /* 21203 ( 448) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  0]  1 */
        3198, /* 21204 ( 448) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    52451996, /* 21205 ( 448) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
    35445722, /* 21206 ( 448) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  0] -1 */
    18439608, /* 21207 ( 448) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
    34028544, /* 21208 ( 448) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    17022434, /* 21209 ( 448) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  0]  1 */
       16484, /* 21210 ( 449) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34146644, /* 21211 ( 449) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
     1420376, /* 21212 ( 449) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  0]  1 */
    17009472, /* 21213 ( 449) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  0]  1 */
    51139632, /* 21214 ( 449) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  6] -1 */
    35550860, /* 21215 ( 449) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
    52570092, /* 21216 ( 449) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    34133682, /* 21217 ( 449) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
    18426650, /* 21218 ( 449) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    51152918, /* 21219 ( 449) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
        3198, /* 21220 ( 449) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    52556810, /* 21221 ( 449) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
     1433658, /* 21222 ( 449) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  0]  1 */
    18439608, /* 21223 ( 449) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
    35563818, /* 21224 ( 449) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  6] -1 */
    17022434, /* 21225 ( 449) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  0]  1 */
       16484, /* 21226 ( 450) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    51152916, /* 21227 ( 450) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6] -1 */
     1420376, /* 21228 ( 450) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  0]  1 */
    17009472, /* 21229 ( 450) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  0]  1 */
    35563820, /* 21230 ( 450) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
    34133684, /* 21231 ( 450) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    18426650, /* 21232 ( 450) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    34146642, /* 21233 ( 450) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
        3198, /* 21234 ( 450) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    52556808, /* 21235 ( 450) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    35550858, /* 21236 ( 450) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6] -1 */
     1433658, /* 21237 ( 450) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  0]  1 */
    51139634, /* 21238 ( 450) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
    18439608, /* 21239 ( 450) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
    52570094, /* 21240 ( 450) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    17022434, /* 21241 ( 450) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  0]  1 */
       16484, /* 21242 ( 451) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    18426648, /* 21243 ( 451) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
    18439608, /* 21244 ( 451) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
        3200, /* 21245 ( 451) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    18439610, /* 21246 ( 451) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    18426650, /* 21247 ( 451) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
        3198, /* 21248 ( 451) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
       16482, /* 21249 ( 451) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
       16484, /* 21250 ( 452) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    52451834, /* 21251 ( 452) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
    18426648, /* 21252 ( 452) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
    34015422, /* 21253 ( 452) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    18439608, /* 21254 ( 452) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
        3200, /* 21255 ( 452) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    18439610, /* 21256 ( 452) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    52438874, /* 21257 ( 452) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
    34028706, /* 21258 ( 452) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    52438872, /* 21259 ( 452) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
    18426650, /* 21260 ( 452) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
        3198, /* 21261 ( 452) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    34015424, /* 21262 ( 452) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    34028708, /* 21263 ( 452) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
       16482, /* 21264 ( 452) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    52451832, /* 21265 ( 452) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
       16484, /* 21266 ( 453) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34015422, /* 21267 ( 453) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    18439608, /* 21268 ( 453) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
    18439610, /* 21269 ( 453) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    52438874, /* 21270 ( 453) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
    34015424, /* 21271 ( 453) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    52438872, /* 21272 ( 453) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
       16482, /* 21273 ( 453) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
       16484, /* 21274 ( 454) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34015422, /* 21275 ( 454) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
        3200, /* 21276 ( 454) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    18439610, /* 21277 ( 454) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    34028706, /* 21278 ( 454) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    18426650, /* 21279 ( 454) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    52438872, /* 21280 ( 454) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
    52451832, /* 21281 ( 454) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
       16484, /* 21282 ( 455) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    52451834, /* 21283 ( 455) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
        3200, /* 21284 ( 455) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    52438874, /* 21285 ( 455) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
        3198, /* 21286 ( 455) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    52438872, /* 21287 ( 455) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
       16482, /* 21288 ( 455) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    52451832, /* 21289 ( 455) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
       16484, /* 21290 ( 456) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    18426648, /* 21291 ( 456) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
    18439610, /* 21292 ( 456) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    52438874, /* 21293 ( 456) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
    34028706, /* 21294 ( 456) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
        3198, /* 21295 ( 456) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    34015424, /* 21296 ( 456) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    52451832, /* 21297 ( 456) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
       16484, /* 21298 ( 457) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    52451834, /* 21299 ( 457) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
    18426648, /* 21300 ( 457) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
    34015422, /* 21301 ( 457) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    18439608, /* 21302 ( 457) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
        3200, /* 21303 ( 457) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    52438874, /* 21304 ( 457) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
    34028706, /* 21305 ( 457) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
       16484, /* 21306 ( 458) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    18426648, /* 21307 ( 458) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
    18439608, /* 21308 ( 458) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
        3200, /* 21309 ( 458) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    18439610, /* 21310 ( 458) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    51034820, /* 21311 ( 458) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  0] -1 */
    51034818, /* 21312 ( 458) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  0] -1 */
    35432762, /* 21313 ( 458) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  0] -1 */
    35432760, /* 21314 ( 458) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  0] -1 */
    18426650, /* 21315 ( 458) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
        3198, /* 21316 ( 458) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    51021534, /* 21317 ( 458) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  0] -1 */
    35445720, /* 21318 ( 458) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  0] -1 */
    35445722, /* 21319 ( 458) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  0] -1 */
    51021536, /* 21320 ( 458) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  0] -1 */
       16482, /* 21321 ( 458) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
       16484, /* 21322 ( 459) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    18426648, /* 21323 ( 459) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
    34133522, /* 21324 ( 459) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    18439608, /* 21325 ( 459) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
        3200, /* 21326 ( 459) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    18439610, /* 21327 ( 459) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    52569932, /* 21328 ( 459) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    34133520, /* 21329 ( 459) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
    18426650, /* 21330 ( 459) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
        3198, /* 21331 ( 459) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    34146806, /* 21332 ( 459) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    52556972, /* 21333 ( 459) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    52556970, /* 21334 ( 459) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    52569930, /* 21335 ( 459) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    34146804, /* 21336 ( 459) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
       16482, /* 21337 ( 459) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
       16484, /* 21338 ( 460) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    18426648, /* 21339 ( 460) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
    35550696, /* 21340 ( 460) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  6] -1 */
    51139794, /* 21341 ( 460) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6] -1 */
    18439608, /* 21342 ( 460) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
        3200, /* 21343 ( 460) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    18439610, /* 21344 ( 460) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    51152756, /* 21345 ( 460) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
    35563980, /* 21346 ( 460) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6] -1 */
    35563982, /* 21347 ( 460) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
    18426650, /* 21348 ( 460) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
        3198, /* 21349 ( 460) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    51139796, /* 21350 ( 460) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
    51152754, /* 21351 ( 460) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  6] -1 */
    35550698, /* 21352 ( 460) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
       16482, /* 21353 ( 460) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
       16484, /* 21354 ( 461) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    18426648, /* 21355 ( 461) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
    34015586, /* 21356 ( 461) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    18439608, /* 21357 ( 461) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
        3200, /* 21358 ( 461) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    52438710, /* 21359 ( 461) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
    18439610, /* 21360 ( 461) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    34015584, /* 21361 ( 461) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    52451994, /* 21362 ( 461) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
    52451996, /* 21363 ( 461) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
        3198, /* 21364 ( 461) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    18426650, /* 21365 ( 461) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    34028546, /* 21366 ( 461) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    52438712, /* 21367 ( 461) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
       16482, /* 21368 ( 461) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    34028544, /* 21369 ( 461) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
       16484, /* 21370 ( 462) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    18426648, /* 21371 ( 462) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
    52556810, /* 21372 ( 462) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    18439608, /* 21373 ( 462) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
        3200, /* 21374 ( 462) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    18439610, /* 21375 ( 462) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    34146644, /* 21376 ( 462) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
       16482, /* 21377 ( 462) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    18426650, /* 21378 ( 462) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
        3198, /* 21379 ( 462) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    34133684, /* 21380 ( 462) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    34133682, /* 21381 ( 462) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
    34146642, /* 21382 ( 462) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
    52570092, /* 21383 ( 462) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    52570094, /* 21384 ( 462) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    52556808, /* 21385 ( 462) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
       16484, /* 21386 ( 451) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
     1538474, /* 21387 ( 451) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
     1538634, /* 21388 ( 451) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
       16320, /* 21389 ( 451) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
     1551756, /* 21390 ( 451) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
     1551596, /* 21391 ( 451) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
        3198, /* 21392 ( 451) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
        3362, /* 21393 ( 451) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
       16484, /* 21394 ( 452) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    35563980, /* 21395 ( 452) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6] -1 */
     1538474, /* 21396 ( 452) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
    34015422, /* 21397 ( 452) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
     1538634, /* 21398 ( 452) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
       16320, /* 21399 ( 452) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
     1551756, /* 21400 ( 452) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
    35563820, /* 21401 ( 452) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
    34015586, /* 21402 ( 452) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    35550698, /* 21403 ( 452) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
     1551596, /* 21404 ( 452) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
        3198, /* 21405 ( 452) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    34028544, /* 21406 ( 452) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    34028708, /* 21407 ( 452) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
        3362, /* 21408 ( 452) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    35550858, /* 21409 ( 452) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6] -1 */
       16484, /* 21410 ( 453) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34015422, /* 21411 ( 453) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
     1538634, /* 21412 ( 453) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
     1551756, /* 21413 ( 453) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
    35563820, /* 21414 ( 453) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
    34028544, /* 21415 ( 453) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    35550698, /* 21416 ( 453) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
        3362, /* 21417 ( 453) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
       16484, /* 21418 ( 454) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34015422, /* 21419 ( 454) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
       16320, /* 21420 ( 454) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
     1551756, /* 21421 ( 454) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
    34015586, /* 21422 ( 454) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
     1551596, /* 21423 ( 454) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
    35550698, /* 21424 ( 454) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
    35550858, /* 21425 ( 454) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6] -1 */
       16484, /* 21426 ( 455) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    35563980, /* 21427 ( 455) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6] -1 */
       16320, /* 21428 ( 455) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    35563820, /* 21429 ( 455) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
        3198, /* 21430 ( 455) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    35550698, /* 21431 ( 455) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
        3362, /* 21432 ( 455) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    35550858, /* 21433 ( 455) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6] -1 */
       16484, /* 21434 ( 456) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
     1538474, /* 21435 ( 456) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
     1551756, /* 21436 ( 456) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
    35563820, /* 21437 ( 456) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
    34015586, /* 21438 ( 456) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
        3198, /* 21439 ( 456) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    34028544, /* 21440 ( 456) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    35550858, /* 21441 ( 456) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6] -1 */
       16484, /* 21442 ( 457) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    35563980, /* 21443 ( 457) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6] -1 */
     1538474, /* 21444 ( 457) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
    34015422, /* 21445 ( 457) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
     1538634, /* 21446 ( 457) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
       16320, /* 21447 ( 457) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    35563820, /* 21448 ( 457) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
    34015586, /* 21449 ( 457) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
       16484, /* 21450 ( 458) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
     1538474, /* 21451 ( 458) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
     1538634, /* 21452 ( 458) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
       16320, /* 21453 ( 458) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
     1551756, /* 21454 ( 458) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
    35445884, /* 21455 ( 458) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  0] -1 */
    35432762, /* 21456 ( 458) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  0] -1 */
    34146644, /* 21457 ( 458) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    34133522, /* 21458 ( 458) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
     1551596, /* 21459 ( 458) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
        3198, /* 21460 ( 458) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    35432598, /* 21461 ( 458) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  0] -1 */
    34133682, /* 21462 ( 458) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
    34146804, /* 21463 ( 458) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
    35445720, /* 21464 ( 458) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  0] -1 */
        3362, /* 21465 ( 458) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
       16484, /* 21466 ( 459) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
     1538474, /* 21467 ( 459) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
    51034656, /* 21468 ( 459) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  0] -1 */
     1538634, /* 21469 ( 459) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
       16320, /* 21470 ( 459) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
     1551756, /* 21471 ( 459) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
    52570092, /* 21472 ( 459) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    51021534, /* 21473 ( 459) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  0] -1 */
     1551596, /* 21474 ( 459) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
        3198, /* 21475 ( 459) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    51034820, /* 21476 ( 459) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  0] -1 */
    52569932, /* 21477 ( 459) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    52556810, /* 21478 ( 459) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    52556970, /* 21479 ( 459) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    51021698, /* 21480 ( 459) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  0] -1 */
        3362, /* 21481 ( 459) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
       16484, /* 21482 ( 460) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
     1538474, /* 21483 ( 460) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
    51139632, /* 21484 ( 460) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  6] -1 */
    52438712, /* 21485 ( 460) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
     1538634, /* 21486 ( 460) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
       16320, /* 21487 ( 460) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
     1551756, /* 21488 ( 460) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
    52451994, /* 21489 ( 460) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
    51139796, /* 21490 ( 460) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
    51152918, /* 21491 ( 460) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
     1551596, /* 21492 ( 460) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
        3198, /* 21493 ( 460) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    52451834, /* 21494 ( 460) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
    52438872, /* 21495 ( 460) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
    51152754, /* 21496 ( 460) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  6] -1 */
        3362, /* 21497 ( 460) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
       16484, /* 21498 ( 461) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
     1538474, /* 21499 ( 461) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
    34028546, /* 21500 ( 461) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
     1538634, /* 21501 ( 461) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
       16320, /* 21502 ( 461) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    35550696, /* 21503 ( 461) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  6] -1 */
     1551756, /* 21504 ( 461) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
    34015424, /* 21505 ( 461) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    35550860, /* 21506 ( 461) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
    35563982, /* 21507 ( 461) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
        3198, /* 21508 ( 461) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
     1551596, /* 21509 ( 461) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
    34028706, /* 21510 ( 461) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    35563818, /* 21511 ( 461) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  6] -1 */
        3362, /* 21512 ( 461) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34015584, /* 21513 ( 461) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
       16484, /* 21514 ( 462) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
     1538474, /* 21515 ( 462) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
    52569930, /* 21516 ( 462) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
     1538634, /* 21517 ( 462) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
       16320, /* 21518 ( 462) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
     1551756, /* 21519 ( 462) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
    51034818, /* 21520 ( 462) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  0] -1 */
        3362, /* 21521 ( 462) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
     1551596, /* 21522 ( 462) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
        3198, /* 21523 ( 462) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    51034658, /* 21524 ( 462) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  0] -1 */
    51021536, /* 21525 ( 462) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  0] -1 */
    51021696, /* 21526 ( 462) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  0] -1 */
    52556972, /* 21527 ( 462) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    52570094, /* 21528 ( 462) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    52556808, /* 21529 ( 462) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
       16484, /* 21530 ( 451) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    17140530, /* 21531 ( 451) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  6]  1 */
    17127410, /* 21532 ( 451) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
        3360, /* 21533 ( 451) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    17127572, /* 21534 ( 451) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
    17140692, /* 21535 ( 451) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6]  1 */
        3198, /* 21536 ( 451) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
       16322, /* 21537 ( 451) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
       16484, /* 21538 ( 452) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    51139796, /* 21539 ( 452) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
    17140530, /* 21540 ( 452) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  6]  1 */
    34015422, /* 21541 ( 452) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    17127410, /* 21542 ( 452) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
        3360, /* 21543 ( 452) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    17127572, /* 21544 ( 452) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
    51152916, /* 21545 ( 452) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6] -1 */
    34028546, /* 21546 ( 452) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    51152754, /* 21547 ( 452) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  6] -1 */
    17140692, /* 21548 ( 452) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6]  1 */
        3198, /* 21549 ( 452) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    34015584, /* 21550 ( 452) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    34028708, /* 21551 ( 452) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
       16322, /* 21552 ( 452) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    51139634, /* 21553 ( 452) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
       16484, /* 21554 ( 453) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34015422, /* 21555 ( 453) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    17127410, /* 21556 ( 453) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
    17127572, /* 21557 ( 453) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
    51152916, /* 21558 ( 453) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6] -1 */
    34015584, /* 21559 ( 453) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    51152754, /* 21560 ( 453) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  6] -1 */
       16322, /* 21561 ( 453) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
       16484, /* 21562 ( 454) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34015422, /* 21563 ( 454) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
        3360, /* 21564 ( 454) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    17127572, /* 21565 ( 454) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
    34028546, /* 21566 ( 454) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    17140692, /* 21567 ( 454) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6]  1 */
    51152754, /* 21568 ( 454) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  6] -1 */
    51139634, /* 21569 ( 454) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
       16484, /* 21570 ( 455) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    51139796, /* 21571 ( 455) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
        3360, /* 21572 ( 455) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    51152916, /* 21573 ( 455) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6] -1 */
        3198, /* 21574 ( 455) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    51152754, /* 21575 ( 455) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  6] -1 */
       16322, /* 21576 ( 455) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    51139634, /* 21577 ( 455) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
       16484, /* 21578 ( 456) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    17140530, /* 21579 ( 456) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  6]  1 */
    17127572, /* 21580 ( 456) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
    51152916, /* 21581 ( 456) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6] -1 */
    34028546, /* 21582 ( 456) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
        3198, /* 21583 ( 456) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    34015584, /* 21584 ( 456) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    51139634, /* 21585 ( 456) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
       16484, /* 21586 ( 457) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    51139796, /* 21587 ( 457) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
    17140530, /* 21588 ( 457) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  6]  1 */
    34015422, /* 21589 ( 457) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    17127410, /* 21590 ( 457) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
        3360, /* 21591 ( 457) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    51152916, /* 21592 ( 457) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6] -1 */
    34028546, /* 21593 ( 457) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
       16484, /* 21594 ( 458) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    17140530, /* 21595 ( 458) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  6]  1 */
    17127410, /* 21596 ( 458) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
        3360, /* 21597 ( 458) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    17127572, /* 21598 ( 458) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
    34146806, /* 21599 ( 458) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    34146644, /* 21600 ( 458) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    51034818, /* 21601 ( 458) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  0] -1 */
    51034656, /* 21602 ( 458) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  0] -1 */
    17140692, /* 21603 ( 458) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6]  1 */
        3198, /* 21604 ( 458) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    34133520, /* 21605 ( 458) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
    51021536, /* 21606 ( 458) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  0] -1 */
    51021698, /* 21607 ( 458) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  0] -1 */
    34133682, /* 21608 ( 458) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
       16322, /* 21609 ( 458) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
       16484, /* 21610 ( 459) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    17140530, /* 21611 ( 459) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  6]  1 */
    35432760, /* 21612 ( 459) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  0] -1 */
    17127410, /* 21613 ( 459) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
        3360, /* 21614 ( 459) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    17127572, /* 21615 ( 459) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
    52556972, /* 21616 ( 459) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    35432598, /* 21617 ( 459) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  0] -1 */
    17140692, /* 21618 ( 459) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6]  1 */
        3198, /* 21619 ( 459) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    35445884, /* 21620 ( 459) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  0] -1 */
    52570092, /* 21621 ( 459) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    52569930, /* 21622 ( 459) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    52556810, /* 21623 ( 459) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    35445722, /* 21624 ( 459) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  0] -1 */
       16322, /* 21625 ( 459) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
       16484, /* 21626 ( 460) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    17140530, /* 21627 ( 460) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  6]  1 */
    52438710, /* 21628 ( 460) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
    35563818, /* 21629 ( 460) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  6] -1 */
    17127410, /* 21630 ( 460) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
        3360, /* 21631 ( 460) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    17127572, /* 21632 ( 460) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
    35550860, /* 21633 ( 460) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
    52451834, /* 21634 ( 460) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
    52451996, /* 21635 ( 460) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
    17140692, /* 21636 ( 460) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6]  1 */
        3198, /* 21637 ( 460) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    35563980, /* 21638 ( 460) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6] -1 */
    35550698, /* 21639 ( 460) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
    52438872, /* 21640 ( 460) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
       16322, /* 21641 ( 460) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
       16484, /* 21642 ( 461) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    17140530, /* 21643 ( 461) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  6]  1 */
    34028706, /* 21644 ( 461) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    17127410, /* 21645 ( 461) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
        3360, /* 21646 ( 461) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    51139632, /* 21647 ( 461) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  6] -1 */
    17127572, /* 21648 ( 461) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
    34028544, /* 21649 ( 461) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    51152756, /* 21650 ( 461) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
    51152918, /* 21651 ( 461) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
        3198, /* 21652 ( 461) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    17140692, /* 21653 ( 461) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6]  1 */
    34015586, /* 21654 ( 461) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    51139794, /* 21655 ( 461) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6] -1 */
       16322, /* 21656 ( 461) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34015424, /* 21657 ( 461) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
       16484, /* 21658 ( 462) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    17140530, /* 21659 ( 462) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  6]  1 */
    52556970, /* 21660 ( 462) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    17127410, /* 21661 ( 462) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
        3360, /* 21662 ( 462) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    17127572, /* 21663 ( 462) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
    35432762, /* 21664 ( 462) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  0] -1 */
       16322, /* 21665 ( 462) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    17140692, /* 21666 ( 462) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6]  1 */
        3198, /* 21667 ( 462) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    35445882, /* 21668 ( 462) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  0] -1 */
    35445720, /* 21669 ( 462) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  0] -1 */
    35432600, /* 21670 ( 462) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  0] -1 */
    52569932, /* 21671 ( 462) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    52570094, /* 21672 ( 462) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    52556808, /* 21673 ( 462) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
       16484, /* 21674 ( 463) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    18426488, /* 21675 ( 463) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
     1551596, /* 21676 ( 463) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
     1538634, /* 21677 ( 463) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
        3198, /* 21678 ( 463) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    18439770, /* 21679 ( 463) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
    17140530, /* 21680 ( 463) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  6]  1 */
    17127572, /* 21681 ( 463) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
       16484, /* 21682 ( 464) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    18426488, /* 21683 ( 464) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    34015422, /* 21684 ( 464) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
     1551596, /* 21685 ( 464) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
     1538634, /* 21686 ( 464) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
    52451994, /* 21687 ( 464) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
    51139796, /* 21688 ( 464) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
        3198, /* 21689 ( 464) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    51152754, /* 21690 ( 464) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  6] -1 */
    18439770, /* 21691 ( 464) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
    35550858, /* 21692 ( 464) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6] -1 */
    52438712, /* 21693 ( 464) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
    34028708, /* 21694 ( 464) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    17140530, /* 21695 ( 464) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  6]  1 */
    35563820, /* 21696 ( 464) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
    17127572, /* 21697 ( 464) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
       16484, /* 21698 ( 465) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34015422, /* 21699 ( 465) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
     1551596, /* 21700 ( 465) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
    51139796, /* 21701 ( 465) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
    18439770, /* 21702 ( 465) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
    35550858, /* 21703 ( 465) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6] -1 */
    52438712, /* 21704 ( 465) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
    17140530, /* 21705 ( 465) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  6]  1 */
       16484, /* 21706 ( 466) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    18426488, /* 21707 ( 466) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    34015422, /* 21708 ( 466) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
     1551596, /* 21709 ( 466) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
    52451994, /* 21710 ( 466) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
    51152754, /* 21711 ( 466) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  6] -1 */
    35550858, /* 21712 ( 466) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6] -1 */
    17127572, /* 21713 ( 466) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
       16484, /* 21714 ( 467) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    18426488, /* 21715 ( 467) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    51139796, /* 21716 ( 467) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
        3198, /* 21717 ( 467) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    51152754, /* 21718 ( 467) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  6] -1 */
    18439770, /* 21719 ( 467) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
    35550858, /* 21720 ( 467) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6] -1 */
    35563820, /* 21721 ( 467) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
       16484, /* 21722 ( 468) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
     1551596, /* 21723 ( 468) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
    52451994, /* 21724 ( 468) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
    51139796, /* 21725 ( 468) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
        3198, /* 21726 ( 468) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    51152754, /* 21727 ( 468) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  6] -1 */
    52438712, /* 21728 ( 468) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
     1538634, /* 21729 ( 468) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
       16484, /* 21730 ( 469) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    18426488, /* 21731 ( 469) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    34015422, /* 21732 ( 469) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    52451994, /* 21733 ( 469) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
    51139796, /* 21734 ( 469) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
    17140530, /* 21735 ( 469) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  6]  1 */
    35563820, /* 21736 ( 469) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
     1538634, /* 21737 ( 469) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
       16484, /* 21738 ( 470) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    18426488, /* 21739 ( 470) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    34146644, /* 21740 ( 470) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
     1551596, /* 21741 ( 470) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
    51034818, /* 21742 ( 470) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  0] -1 */
     1538634, /* 21743 ( 470) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
        3198, /* 21744 ( 470) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    35445884, /* 21745 ( 470) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  0] -1 */
    18439770, /* 21746 ( 470) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
    51021536, /* 21747 ( 470) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  0] -1 */
    35432598, /* 21748 ( 470) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  0] -1 */
    52569930, /* 21749 ( 470) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    52556972, /* 21750 ( 470) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    17140530, /* 21751 ( 470) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  6]  1 */
    34133682, /* 21752 ( 470) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
    17127572, /* 21753 ( 470) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
       16484, /* 21754 ( 471) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    18426488, /* 21755 ( 471) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    52556810, /* 21756 ( 471) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    51021698, /* 21757 ( 471) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  0] -1 */
    51034656, /* 21758 ( 471) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  0] -1 */
     1551596, /* 21759 ( 471) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
    35432760, /* 21760 ( 471) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  0] -1 */
    34133520, /* 21761 ( 471) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
     1538634, /* 21762 ( 471) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
        3198, /* 21763 ( 471) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    35445722, /* 21764 ( 471) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  0] -1 */
    34146806, /* 21765 ( 471) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    18439770, /* 21766 ( 471) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
    52570092, /* 21767 ( 471) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    17140530, /* 21768 ( 471) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  6]  1 */
    17127572, /* 21769 ( 471) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
       16484, /* 21770 ( 472) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    18426488, /* 21771 ( 472) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    35550696, /* 21772 ( 472) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  6] -1 */
    52438874, /* 21773 ( 472) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
    34015584, /* 21774 ( 472) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
     1551596, /* 21775 ( 472) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
    51139634, /* 21776 ( 472) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
    35563982, /* 21777 ( 472) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
     1538634, /* 21778 ( 472) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
        3198, /* 21779 ( 472) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    18439770, /* 21780 ( 472) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
    51152916, /* 21781 ( 472) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6] -1 */
    34028546, /* 21782 ( 472) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    17140530, /* 21783 ( 472) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  6]  1 */
    52451832, /* 21784 ( 472) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
    17127572, /* 21785 ( 472) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
       16484, /* 21786 ( 473) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    18426488, /* 21787 ( 473) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    51139794, /* 21788 ( 473) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6] -1 */
    52438710, /* 21789 ( 473) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
    51152756, /* 21790 ( 473) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
    35550860, /* 21791 ( 473) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
     1551596, /* 21792 ( 473) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
    34028706, /* 21793 ( 473) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
     1538634, /* 21794 ( 473) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
    52451996, /* 21795 ( 473) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
        3198, /* 21796 ( 473) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    18439770, /* 21797 ( 473) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
    34015424, /* 21798 ( 473) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    17140530, /* 21799 ( 473) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  6]  1 */
    35563818, /* 21800 ( 473) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  6] -1 */
    17127572, /* 21801 ( 473) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
       16484, /* 21802 ( 474) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    18426488, /* 21803 ( 474) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    34133522, /* 21804 ( 474) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    51021696, /* 21805 ( 474) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  0] -1 */
     1551596, /* 21806 ( 474) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
    51034658, /* 21807 ( 474) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  0] -1 */
    35432762, /* 21808 ( 474) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  0] -1 */
     1538634, /* 21809 ( 474) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
    35445720, /* 21810 ( 474) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  0] -1 */
        3198, /* 21811 ( 474) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    52556808, /* 21812 ( 474) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    18439770, /* 21813 ( 474) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
    34146804, /* 21814 ( 474) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
    17140530, /* 21815 ( 474) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  6]  1 */
    52570094, /* 21816 ( 474) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    17127572, /* 21817 ( 474) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
       16484, /* 21818 ( 463) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
     1551594, /* 21819 ( 463) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
    17140692, /* 21820 ( 463) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6]  1 */
    17127410, /* 21821 ( 463) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
        3198, /* 21822 ( 463) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
     1538636, /* 21823 ( 463) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
    18426648, /* 21824 ( 463) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
    18439610, /* 21825 ( 463) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
       16484, /* 21826 ( 464) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
     1551594, /* 21827 ( 464) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
    34015422, /* 21828 ( 464) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    17140692, /* 21829 ( 464) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6]  1 */
    17127410, /* 21830 ( 464) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
    35550860, /* 21831 ( 464) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
    52451834, /* 21832 ( 464) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
        3198, /* 21833 ( 464) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    52438872, /* 21834 ( 464) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
     1538636, /* 21835 ( 464) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
    51139634, /* 21836 ( 464) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
    35563818, /* 21837 ( 464) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  6] -1 */
    34028708, /* 21838 ( 464) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    18426648, /* 21839 ( 464) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
    51152916, /* 21840 ( 464) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6] -1 */
    18439610, /* 21841 ( 464) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
       16484, /* 21842 ( 465) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34015422, /* 21843 ( 465) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    17140692, /* 21844 ( 465) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6]  1 */
    52451834, /* 21845 ( 465) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
     1538636, /* 21846 ( 465) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
    51139634, /* 21847 ( 465) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
    35563818, /* 21848 ( 465) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  6] -1 */
    18426648, /* 21849 ( 465) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
       16484, /* 21850 ( 466) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
     1551594, /* 21851 ( 466) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
    34015422, /* 21852 ( 466) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    17140692, /* 21853 ( 466) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6]  1 */
    35550860, /* 21854 ( 466) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
    52438872, /* 21855 ( 466) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
    51139634, /* 21856 ( 466) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
    18439610, /* 21857 ( 466) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
       16484, /* 21858 ( 467) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
     1551594, /* 21859 ( 467) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
    52451834, /* 21860 ( 467) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
        3198, /* 21861 ( 467) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    52438872, /* 21862 ( 467) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
     1538636, /* 21863 ( 467) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
    51139634, /* 21864 ( 467) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
    51152916, /* 21865 ( 467) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6] -1 */
       16484, /* 21866 ( 468) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    17140692, /* 21867 ( 468) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6]  1 */
    35550860, /* 21868 ( 468) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
    52451834, /* 21869 ( 468) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
        3198, /* 21870 ( 468) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    52438872, /* 21871 ( 468) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
    35563818, /* 21872 ( 468) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  6] -1 */
    17127410, /* 21873 ( 468) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
       16484, /* 21874 ( 469) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
     1551594, /* 21875 ( 469) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
    34015422, /* 21876 ( 469) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    35550860, /* 21877 ( 469) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
    52451834, /* 21878 ( 469) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
    18426648, /* 21879 ( 469) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
    51152916, /* 21880 ( 469) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6] -1 */
    17127410, /* 21881 ( 469) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
       16484, /* 21882 ( 470) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
     1551594, /* 21883 ( 470) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
    51034818, /* 21884 ( 470) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  0] -1 */
    17140692, /* 21885 ( 470) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6]  1 */
    35432762, /* 21886 ( 470) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  0] -1 */
    17127410, /* 21887 ( 470) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
        3198, /* 21888 ( 470) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    34146806, /* 21889 ( 470) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
     1538636, /* 21890 ( 470) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
    35445720, /* 21891 ( 470) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  0] -1 */
    34133520, /* 21892 ( 470) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
    52556970, /* 21893 ( 470) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    52569932, /* 21894 ( 470) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    18426648, /* 21895 ( 470) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
    51021536, /* 21896 ( 470) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  0] -1 */
    18439610, /* 21897 ( 470) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
       16484, /* 21898 ( 471) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
     1551594, /* 21899 ( 471) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
    52569930, /* 21900 ( 471) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    35445722, /* 21901 ( 471) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  0] -1 */
    35432760, /* 21902 ( 471) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  0] -1 */
    17140692, /* 21903 ( 471) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6]  1 */
    34133522, /* 21904 ( 471) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    51021534, /* 21905 ( 471) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  0] -1 */
    17127410, /* 21906 ( 471) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
        3198, /* 21907 ( 471) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    34146804, /* 21908 ( 471) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
    51034820, /* 21909 ( 471) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  0] -1 */
     1538636, /* 21910 ( 471) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
    52556972, /* 21911 ( 471) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    18426648, /* 21912 ( 471) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
    18439610, /* 21913 ( 471) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
       16484, /* 21914 ( 472) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
     1551594, /* 21915 ( 472) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
    51139632, /* 21916 ( 472) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  6] -1 */
    35563820, /* 21917 ( 472) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
    34015424, /* 21918 ( 472) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    17140692, /* 21919 ( 472) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6]  1 */
    52451832, /* 21920 ( 472) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
    51152918, /* 21921 ( 472) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
    17127410, /* 21922 ( 472) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
        3198, /* 21923 ( 472) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
     1538636, /* 21924 ( 472) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
    52438874, /* 21925 ( 472) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
    34028706, /* 21926 ( 472) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    18426648, /* 21927 ( 472) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
    35550858, /* 21928 ( 472) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6] -1 */
    18439610, /* 21929 ( 472) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
       16484, /* 21930 ( 473) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
     1551594, /* 21931 ( 473) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
    52438712, /* 21932 ( 473) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
    35550696, /* 21933 ( 473) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  6] -1 */
    52451994, /* 21934 ( 473) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
    51152756, /* 21935 ( 473) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
    17140692, /* 21936 ( 473) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6]  1 */
    34015586, /* 21937 ( 473) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    17127410, /* 21938 ( 473) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
    35563982, /* 21939 ( 473) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
        3198, /* 21940 ( 473) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
     1538636, /* 21941 ( 473) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
    34028544, /* 21942 ( 473) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    18426648, /* 21943 ( 473) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
    51139794, /* 21944 ( 473) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6] -1 */
    18439610, /* 21945 ( 473) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
       16484, /* 21946 ( 474) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
     1551594, /* 21947 ( 474) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
    51034656, /* 21948 ( 474) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  0] -1 */
    35432600, /* 21949 ( 474) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  0] -1 */
    17140692, /* 21950 ( 474) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6]  1 */
    35445882, /* 21951 ( 474) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  0] -1 */
    34146644, /* 21952 ( 474) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    17127410, /* 21953 ( 474) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
    34133682, /* 21954 ( 474) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
        3198, /* 21955 ( 474) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    52556808, /* 21956 ( 474) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
     1538636, /* 21957 ( 474) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
    51021698, /* 21958 ( 474) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  0] -1 */
    18426648, /* 21959 ( 474) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
    52570094, /* 21960 ( 474) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    18439610, /* 21961 ( 474) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
       16484, /* 21962 ( 463) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    17127570, /* 21963 ( 463) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6]  1 */
    18426650, /* 21964 ( 463) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    18439608, /* 21965 ( 463) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
        3198, /* 21966 ( 463) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    17140532, /* 21967 ( 463) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
     1538474, /* 21968 ( 463) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
     1551756, /* 21969 ( 463) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
       16484, /* 21970 ( 464) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    17127570, /* 21971 ( 464) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6]  1 */
    34015422, /* 21972 ( 464) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    18426650, /* 21973 ( 464) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    18439608, /* 21974 ( 464) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
    51152756, /* 21975 ( 464) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
    35563980, /* 21976 ( 464) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6] -1 */
        3198, /* 21977 ( 464) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    35550698, /* 21978 ( 464) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
    17140532, /* 21979 ( 464) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
    52451832, /* 21980 ( 464) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
    51139794, /* 21981 ( 464) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6] -1 */
    34028708, /* 21982 ( 464) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
     1538474, /* 21983 ( 464) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
    52438874, /* 21984 ( 464) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
     1551756, /* 21985 ( 464) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
       16484, /* 21986 ( 465) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34015422, /* 21987 ( 465) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    18426650, /* 21988 ( 465) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    35563980, /* 21989 ( 465) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6] -1 */
    17140532, /* 21990 ( 465) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
    52451832, /* 21991 ( 465) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
    51139794, /* 21992 ( 465) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6] -1 */
     1538474, /* 21993 ( 465) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
       16484, /* 21994 ( 466) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    17127570, /* 21995 ( 466) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6]  1 */
    34015422, /* 21996 ( 466) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    18426650, /* 21997 ( 466) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    51152756, /* 21998 ( 466) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
    35550698, /* 21999 ( 466) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
    52451832, /* 22000 ( 466) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
     1551756, /* 22001 ( 466) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
       16484, /* 22002 ( 467) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    17127570, /* 22003 ( 467) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6]  1 */
    35563980, /* 22004 ( 467) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6] -1 */
        3198, /* 22005 ( 467) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    35550698, /* 22006 ( 467) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
    17140532, /* 22007 ( 467) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
    52451832, /* 22008 ( 467) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
    52438874, /* 22009 ( 467) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
       16484, /* 22010 ( 468) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    18426650, /* 22011 ( 468) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    51152756, /* 22012 ( 468) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
    35563980, /* 22013 ( 468) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6] -1 */
        3198, /* 22014 ( 468) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    35550698, /* 22015 ( 468) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
    51139794, /* 22016 ( 468) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6] -1 */
    18439608, /* 22017 ( 468) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
       16484, /* 22018 ( 469) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    17127570, /* 22019 ( 469) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6]  1 */
    34015422, /* 22020 ( 469) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    51152756, /* 22021 ( 469) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
    35563980, /* 22022 ( 469) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6] -1 */
     1538474, /* 22023 ( 469) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
    52438874, /* 22024 ( 469) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
    18439608, /* 22025 ( 469) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
       16484, /* 22026 ( 470) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    17127570, /* 22027 ( 470) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6]  1 */
    35432762, /* 22028 ( 470) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  0] -1 */
    18426650, /* 22029 ( 470) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    34146644, /* 22030 ( 470) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    18439608, /* 22031 ( 470) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
        3198, /* 22032 ( 470) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    51034820, /* 22033 ( 470) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  0] -1 */
    17140532, /* 22034 ( 470) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
    34133682, /* 22035 ( 470) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
    51021534, /* 22036 ( 470) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  0] -1 */
    52556810, /* 22037 ( 470) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    52570092, /* 22038 ( 470) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
     1538474, /* 22039 ( 470) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
    35445720, /* 22040 ( 470) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  0] -1 */
     1551756, /* 22041 ( 470) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
       16484, /* 22042 ( 471) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    17127570, /* 22043 ( 471) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6]  1 */
    52556970, /* 22044 ( 471) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    34146804, /* 22045 ( 471) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
    34133522, /* 22046 ( 471) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    18426650, /* 22047 ( 471) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    51034656, /* 22048 ( 471) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  0] -1 */
    35432598, /* 22049 ( 471) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  0] -1 */
    18439608, /* 22050 ( 471) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
        3198, /* 22051 ( 471) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    51021698, /* 22052 ( 471) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  0] -1 */
    35445884, /* 22053 ( 471) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  0] -1 */
    17140532, /* 22054 ( 471) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
    52569932, /* 22055 ( 471) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
     1538474, /* 22056 ( 471) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
     1551756, /* 22057 ( 471) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
       16484, /* 22058 ( 472) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    17127570, /* 22059 ( 472) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6]  1 */
    52438710, /* 22060 ( 472) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
    51152916, /* 22061 ( 472) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6] -1 */
    34028544, /* 22062 ( 472) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    18426650, /* 22063 ( 472) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    35550858, /* 22064 ( 472) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6] -1 */
    52451996, /* 22065 ( 472) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
    18439608, /* 22066 ( 472) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
        3198, /* 22067 ( 472) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    17140532, /* 22068 ( 472) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
    35563820, /* 22069 ( 472) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
    34015586, /* 22070 ( 472) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
     1538474, /* 22071 ( 472) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
    51139634, /* 22072 ( 472) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
     1551756, /* 22073 ( 472) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
       16484, /* 22074 ( 473) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    17127570, /* 22075 ( 473) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6]  1 */
    35563818, /* 22076 ( 473) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  6] -1 */
    51139632, /* 22077 ( 473) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  6] -1 */
    35550860, /* 22078 ( 473) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
    52451994, /* 22079 ( 473) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
    18426650, /* 22080 ( 473) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    34028546, /* 22081 ( 473) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    18439608, /* 22082 ( 473) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
    51152918, /* 22083 ( 473) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
        3198, /* 22084 ( 473) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    17140532, /* 22085 ( 473) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
    34015584, /* 22086 ( 473) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
     1538474, /* 22087 ( 473) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
    52438712, /* 22088 ( 473) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
     1551756, /* 22089 ( 473) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
       16484, /* 22090 ( 474) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    17127570, /* 22091 ( 474) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6]  1 */
    35432760, /* 22092 ( 474) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  0] -1 */
    34146642, /* 22093 ( 474) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
    18426650, /* 22094 ( 474) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    34133684, /* 22095 ( 474) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    51034818, /* 22096 ( 474) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  0] -1 */
    18439608, /* 22097 ( 474) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
    51021536, /* 22098 ( 474) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  0] -1 */
        3198, /* 22099 ( 474) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    52556808, /* 22100 ( 474) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    17140532, /* 22101 ( 474) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
    35445722, /* 22102 ( 474) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  0] -1 */
     1538474, /* 22103 ( 474) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
    52570094, /* 22104 ( 474) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
     1551756, /* 22105 ( 474) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
       16484, /* 22106 ( 475) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
      134580, /* 22107 ( 475) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  6]  1 */
     1551596, /* 22108 ( 475) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
      121298, /* 22109 ( 475) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6]  1 */
        3198, /* 22110 ( 475) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
     1433496, /* 22111 ( 475) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  0]  1 */
     1420538, /* 22112 ( 475) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  0]  1 */
     1538634, /* 22113 ( 475) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
       16484, /* 22114 ( 476) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34133522, /* 22115 ( 476) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    34015422, /* 22116 ( 476) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
      134580, /* 22117 ( 476) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  6]  1 */
    35550858, /* 22118 ( 476) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6] -1 */
     1551596, /* 22119 ( 476) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
    35432762, /* 22120 ( 476) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  0] -1 */
      121298, /* 22121 ( 476) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6]  1 */
        3198, /* 22122 ( 476) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    35445720, /* 22123 ( 476) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  0] -1 */
     1433496, /* 22124 ( 476) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  0]  1 */
    34146804, /* 22125 ( 476) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
    34028708, /* 22126 ( 476) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
     1420538, /* 22127 ( 476) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  0]  1 */
    35563820, /* 22128 ( 476) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
     1538634, /* 22129 ( 476) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
       16484, /* 22130 ( 477) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34133522, /* 22131 ( 477) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    34015422, /* 22132 ( 477) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    35550858, /* 22133 ( 477) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6] -1 */
      134580, /* 22134 ( 477) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  6]  1 */
     1551596, /* 22135 ( 477) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
    35432762, /* 22136 ( 477) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  0] -1 */
     1433496, /* 22137 ( 477) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  0]  1 */
       16484, /* 22138 ( 478) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34133522, /* 22139 ( 478) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    34015422, /* 22140 ( 478) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
      134580, /* 22141 ( 478) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  6]  1 */
    35445720, /* 22142 ( 478) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  0] -1 */
     1420538, /* 22143 ( 478) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  0]  1 */
    35563820, /* 22144 ( 478) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
     1538634, /* 22145 ( 478) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
       16484, /* 22146 ( 479) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34015422, /* 22147 ( 479) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
     1551596, /* 22148 ( 479) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
    35445720, /* 22149 ( 479) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  0] -1 */
      121298, /* 22150 ( 479) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6]  1 */
    35550858, /* 22151 ( 479) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6] -1 */
    34146804, /* 22152 ( 479) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
     1420538, /* 22153 ( 479) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  0]  1 */
       16484, /* 22154 ( 480) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
      134580, /* 22155 ( 480) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  6]  1 */
    35432762, /* 22156 ( 480) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  0] -1 */
    35445720, /* 22157 ( 480) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  0] -1 */
        3198, /* 22158 ( 480) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
      121298, /* 22159 ( 480) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6]  1 */
    35550858, /* 22160 ( 480) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6] -1 */
    35563820, /* 22161 ( 480) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
       16484, /* 22162 ( 481) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34133522, /* 22163 ( 481) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    35550858, /* 22164 ( 481) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6] -1 */
        3198, /* 22165 ( 481) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
     1433496, /* 22166 ( 481) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  0]  1 */
    34146804, /* 22167 ( 481) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
     1420538, /* 22168 ( 481) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  0]  1 */
    35563820, /* 22169 ( 481) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
       16484, /* 22170 ( 482) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34133522, /* 22171 ( 482) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
     1551596, /* 22172 ( 482) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
    35432762, /* 22173 ( 482) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  0] -1 */
    35445720, /* 22174 ( 482) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  0] -1 */
        3198, /* 22175 ( 482) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    34146804, /* 22176 ( 482) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
     1538634, /* 22177 ( 482) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
       16484, /* 22178 ( 483) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34015422, /* 22179 ( 483) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    35432762, /* 22180 ( 483) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  0] -1 */
      121298, /* 22181 ( 483) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6]  1 */
     1433496, /* 22182 ( 483) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  0]  1 */
    34146804, /* 22183 ( 483) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
    35563820, /* 22184 ( 483) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
     1538634, /* 22185 ( 483) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
       16484, /* 22186 ( 484) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
      134580, /* 22187 ( 484) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  6]  1 */
    51034820, /* 22188 ( 484) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  0] -1 */
    52438874, /* 22189 ( 484) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
    52569932, /* 22190 ( 484) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
     1551596, /* 22191 ( 484) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
    51139634, /* 22192 ( 484) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
      121298, /* 22193 ( 484) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6]  1 */
        3198, /* 22194 ( 484) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    51021534, /* 22195 ( 484) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  0] -1 */
    52556970, /* 22196 ( 484) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    51152916, /* 22197 ( 484) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6] -1 */
     1433496, /* 22198 ( 484) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  0]  1 */
     1420538, /* 22199 ( 484) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  0]  1 */
    52451832, /* 22200 ( 484) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
     1538634, /* 22201 ( 484) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
       16484, /* 22202 ( 485) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34015586, /* 22203 ( 485) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
      134580, /* 22204 ( 485) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  6]  1 */
    34146644, /* 22205 ( 485) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
     1551596, /* 22206 ( 485) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
    35563980, /* 22207 ( 485) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6] -1 */
      121298, /* 22208 ( 485) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6]  1 */
        3198, /* 22209 ( 485) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    35445884, /* 22210 ( 485) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  0] -1 */
    35432598, /* 22211 ( 485) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  0] -1 */
    35550698, /* 22212 ( 485) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
     1433496, /* 22213 ( 485) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  0]  1 */
    34133682, /* 22214 ( 485) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
     1420538, /* 22215 ( 485) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  0]  1 */
    34028544, /* 22216 ( 485) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
     1538634, /* 22217 ( 485) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
       16484, /* 22218 ( 486) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    35563818, /* 22219 ( 486) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  6] -1 */
      134580, /* 22220 ( 486) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  6]  1 */
    35550860, /* 22221 ( 486) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
     1551596, /* 22222 ( 486) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
    35432760, /* 22223 ( 486) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  0] -1 */
    34028706, /* 22224 ( 486) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    34133520, /* 22225 ( 486) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
      121298, /* 22226 ( 486) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6]  1 */
        3198, /* 22227 ( 486) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    35445722, /* 22228 ( 486) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  0] -1 */
    34146806, /* 22229 ( 486) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
     1433496, /* 22230 ( 486) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  0]  1 */
     1420538, /* 22231 ( 486) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  0]  1 */
    34015424, /* 22232 ( 486) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
     1538634, /* 22233 ( 486) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
       16484, /* 22234 ( 487) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    35445882, /* 22235 ( 487) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  0] -1 */
    35550696, /* 22236 ( 487) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  6] -1 */
    34028546, /* 22237 ( 487) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
      134580, /* 22238 ( 487) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  6]  1 */
    34015584, /* 22239 ( 487) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    35432600, /* 22240 ( 487) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  0] -1 */
     1551596, /* 22241 ( 487) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
    35563982, /* 22242 ( 487) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
      121298, /* 22243 ( 487) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6]  1 */
        3198, /* 22244 ( 487) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    34133684, /* 22245 ( 487) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    34146642, /* 22246 ( 487) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
     1433496, /* 22247 ( 487) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  0]  1 */
     1420538, /* 22248 ( 487) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  0]  1 */
     1538634, /* 22249 ( 487) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
       16484, /* 22250 ( 488) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    52451834, /* 22251 ( 488) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
      134580, /* 22252 ( 488) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  6]  1 */
     1551596, /* 22253 ( 488) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
    51034818, /* 22254 ( 488) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  0] -1 */
     1538634, /* 22255 ( 488) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
      121298, /* 22256 ( 488) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6]  1 */
        3198, /* 22257 ( 488) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    52569930, /* 22258 ( 488) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    52556972, /* 22259 ( 488) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    51021536, /* 22260 ( 488) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  0] -1 */
     1433496, /* 22261 ( 488) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  0]  1 */
    52438872, /* 22262 ( 488) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
    51139632, /* 22263 ( 488) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  6] -1 */
     1420538, /* 22264 ( 488) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  0]  1 */
    51152918, /* 22265 ( 488) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
       16484, /* 22266 ( 489) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    51139794, /* 22267 ( 489) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6] -1 */
    52556810, /* 22268 ( 489) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    52438710, /* 22269 ( 489) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
      134580, /* 22270 ( 489) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  6]  1 */
    51021698, /* 22271 ( 489) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  0] -1 */
    51152756, /* 22272 ( 489) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
    51034656, /* 22273 ( 489) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  0] -1 */
     1551596, /* 22274 ( 489) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
      121298, /* 22275 ( 489) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6]  1 */
        3198, /* 22276 ( 489) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    52451996, /* 22277 ( 489) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
     1433496, /* 22278 ( 489) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  0]  1 */
    52570092, /* 22279 ( 489) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
     1420538, /* 22280 ( 489) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  0]  1 */
     1538634, /* 22281 ( 489) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
       16484, /* 22282 ( 490) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
      134580, /* 22283 ( 490) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  6]  1 */
    51021696, /* 22284 ( 490) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  0] -1 */
     1551596, /* 22285 ( 490) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
     1420538, /* 22286 ( 490) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  0]  1 */
    51034658, /* 22287 ( 490) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  0] -1 */
     1538634, /* 22288 ( 490) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
    52451994, /* 22289 ( 490) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
      121298, /* 22290 ( 490) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6]  1 */
        3198, /* 22291 ( 490) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    51139796, /* 22292 ( 490) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
    51152754, /* 22293 ( 490) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  6] -1 */
     1433496, /* 22294 ( 490) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  0]  1 */
    52438712, /* 22295 ( 490) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
    52570094, /* 22296 ( 490) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    52556808, /* 22297 ( 490) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
       16484, /* 22298 ( 475) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
      134580, /* 22299 ( 475) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  6]  1 */
    17127572, /* 22300 ( 475) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
      121298, /* 22301 ( 475) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6]  1 */
        3198, /* 22302 ( 475) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    17009472, /* 22303 ( 475) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  0]  1 */
    17022434, /* 22304 ( 475) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  0]  1 */
    17140530, /* 22305 ( 475) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  6]  1 */
       16484, /* 22306 ( 476) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34133522, /* 22307 ( 476) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    34015422, /* 22308 ( 476) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
      134580, /* 22309 ( 476) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  6]  1 */
    51152754, /* 22310 ( 476) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  6] -1 */
    17127572, /* 22311 ( 476) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
    51034658, /* 22312 ( 476) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  0] -1 */
      121298, /* 22313 ( 476) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6]  1 */
        3198, /* 22314 ( 476) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    51021696, /* 22315 ( 476) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  0] -1 */
    17009472, /* 22316 ( 476) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  0]  1 */
    34146804, /* 22317 ( 476) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
    34028708, /* 22318 ( 476) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    17022434, /* 22319 ( 476) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  0]  1 */
    51139796, /* 22320 ( 476) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
    17140530, /* 22321 ( 476) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  6]  1 */
       16484, /* 22322 ( 477) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34133522, /* 22323 ( 477) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    34015422, /* 22324 ( 477) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    51152754, /* 22325 ( 477) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  6] -1 */
      134580, /* 22326 ( 477) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  6]  1 */
    17127572, /* 22327 ( 477) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
    51034658, /* 22328 ( 477) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  0] -1 */
    17009472, /* 22329 ( 477) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  0]  1 */
       16484, /* 22330 ( 478) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34133522, /* 22331 ( 478) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    34015422, /* 22332 ( 478) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
      134580, /* 22333 ( 478) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  6]  1 */
    51021696, /* 22334 ( 478) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  0] -1 */
    17022434, /* 22335 ( 478) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  0]  1 */
    51139796, /* 22336 ( 478) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
    17140530, /* 22337 ( 478) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  6]  1 */
       16484, /* 22338 ( 479) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34015422, /* 22339 ( 479) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    17127572, /* 22340 ( 479) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
    51021696, /* 22341 ( 479) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  0] -1 */
      121298, /* 22342 ( 479) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6]  1 */
    51152754, /* 22343 ( 479) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  6] -1 */
    34146804, /* 22344 ( 479) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
    17022434, /* 22345 ( 479) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  0]  1 */
       16484, /* 22346 ( 480) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
      134580, /* 22347 ( 480) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  6]  1 */
    51034658, /* 22348 ( 480) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  0] -1 */
    51021696, /* 22349 ( 480) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  0] -1 */
        3198, /* 22350 ( 480) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
      121298, /* 22351 ( 480) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6]  1 */
    51152754, /* 22352 ( 480) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  6] -1 */
    51139796, /* 22353 ( 480) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
       16484, /* 22354 ( 481) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34133522, /* 22355 ( 481) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    51152754, /* 22356 ( 481) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  6] -1 */
        3198, /* 22357 ( 481) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    17009472, /* 22358 ( 481) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  0]  1 */
    34146804, /* 22359 ( 481) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
    17022434, /* 22360 ( 481) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  0]  1 */
    51139796, /* 22361 ( 481) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
       16484, /* 22362 ( 482) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34133522, /* 22363 ( 482) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    17127572, /* 22364 ( 482) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
    51034658, /* 22365 ( 482) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  0] -1 */
    51021696, /* 22366 ( 482) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  0] -1 */
        3198, /* 22367 ( 482) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    34146804, /* 22368 ( 482) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
    17140530, /* 22369 ( 482) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  6]  1 */
       16484, /* 22370 ( 483) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34015422, /* 22371 ( 483) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    51034658, /* 22372 ( 483) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  0] -1 */
      121298, /* 22373 ( 483) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6]  1 */
    17009472, /* 22374 ( 483) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  0]  1 */
    34146804, /* 22375 ( 483) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
    51139796, /* 22376 ( 483) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
    17140530, /* 22377 ( 483) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  6]  1 */
       16484, /* 22378 ( 484) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
      134580, /* 22379 ( 484) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  6]  1 */
    35445884, /* 22380 ( 484) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  0] -1 */
    52451834, /* 22381 ( 484) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
    52556972, /* 22382 ( 484) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    17127572, /* 22383 ( 484) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
    35550698, /* 22384 ( 484) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
      121298, /* 22385 ( 484) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6]  1 */
        3198, /* 22386 ( 484) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    35432598, /* 22387 ( 484) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  0] -1 */
    52569930, /* 22388 ( 484) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    35563980, /* 22389 ( 484) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6] -1 */
    17009472, /* 22390 ( 484) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  0]  1 */
    17022434, /* 22391 ( 484) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  0]  1 */
    52438872, /* 22392 ( 484) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
    17140530, /* 22393 ( 484) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  6]  1 */
       16484, /* 22394 ( 485) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34028546, /* 22395 ( 485) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
      134580, /* 22396 ( 485) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  6]  1 */
    34133684, /* 22397 ( 485) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    17127572, /* 22398 ( 485) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
    51152916, /* 22399 ( 485) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6] -1 */
      121298, /* 22400 ( 485) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6]  1 */
        3198, /* 22401 ( 485) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    51034820, /* 22402 ( 485) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  0] -1 */
    51021534, /* 22403 ( 485) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  0] -1 */
    51139634, /* 22404 ( 485) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
    17009472, /* 22405 ( 485) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  0]  1 */
    34146642, /* 22406 ( 485) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
    17022434, /* 22407 ( 485) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  0]  1 */
    34015584, /* 22408 ( 485) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    17140530, /* 22409 ( 485) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  6]  1 */
       16484, /* 22410 ( 486) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    51139794, /* 22411 ( 486) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6] -1 */
      134580, /* 22412 ( 486) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  6]  1 */
    51152756, /* 22413 ( 486) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
    17127572, /* 22414 ( 486) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
    51034656, /* 22415 ( 486) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  0] -1 */
    34028706, /* 22416 ( 486) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    34133520, /* 22417 ( 486) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
      121298, /* 22418 ( 486) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6]  1 */
        3198, /* 22419 ( 486) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    51021698, /* 22420 ( 486) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  0] -1 */
    34146806, /* 22421 ( 486) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    17009472, /* 22422 ( 486) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  0]  1 */
    17022434, /* 22423 ( 486) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  0]  1 */
    34015424, /* 22424 ( 486) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    17140530, /* 22425 ( 486) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  6]  1 */
       16484, /* 22426 ( 487) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    51034818, /* 22427 ( 487) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  0] -1 */
    51139632, /* 22428 ( 487) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  6] -1 */
    34015586, /* 22429 ( 487) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
      134580, /* 22430 ( 487) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  6]  1 */
    34028544, /* 22431 ( 487) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    51021536, /* 22432 ( 487) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  0] -1 */
    17127572, /* 22433 ( 487) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
    51152918, /* 22434 ( 487) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
      121298, /* 22435 ( 487) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6]  1 */
        3198, /* 22436 ( 487) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    34146644, /* 22437 ( 487) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    34133682, /* 22438 ( 487) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
    17009472, /* 22439 ( 487) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  0]  1 */
    17022434, /* 22440 ( 487) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  0]  1 */
    17140530, /* 22441 ( 487) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  6]  1 */
       16484, /* 22442 ( 488) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    52438874, /* 22443 ( 488) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
      134580, /* 22444 ( 488) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  6]  1 */
    17127572, /* 22445 ( 488) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
    35445882, /* 22446 ( 488) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  0] -1 */
    17140530, /* 22447 ( 488) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  6]  1 */
      121298, /* 22448 ( 488) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6]  1 */
        3198, /* 22449 ( 488) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    52556970, /* 22450 ( 488) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    52569932, /* 22451 ( 488) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    35432600, /* 22452 ( 488) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  0] -1 */
    17009472, /* 22453 ( 488) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  0]  1 */
    52451832, /* 22454 ( 488) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
    35550696, /* 22455 ( 488) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  6] -1 */
    17022434, /* 22456 ( 488) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  0]  1 */
    35563982, /* 22457 ( 488) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
       16484, /* 22458 ( 489) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    35563818, /* 22459 ( 489) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  6] -1 */
    52556810, /* 22460 ( 489) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    52438710, /* 22461 ( 489) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
      134580, /* 22462 ( 489) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  6]  1 */
    35445722, /* 22463 ( 489) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  0] -1 */
    35550860, /* 22464 ( 489) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
    35432760, /* 22465 ( 489) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  0] -1 */
    17127572, /* 22466 ( 489) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
      121298, /* 22467 ( 489) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6]  1 */
        3198, /* 22468 ( 489) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    52451996, /* 22469 ( 489) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
    17009472, /* 22470 ( 489) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  0]  1 */
    52570092, /* 22471 ( 489) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    17022434, /* 22472 ( 489) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  0]  1 */
    17140530, /* 22473 ( 489) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  6]  1 */
       16484, /* 22474 ( 490) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
      134580, /* 22475 ( 490) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  6]  1 */
    35445720, /* 22476 ( 490) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  0] -1 */
    17127572, /* 22477 ( 490) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
    17022434, /* 22478 ( 490) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  0]  1 */
    35432762, /* 22479 ( 490) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  0] -1 */
    17140530, /* 22480 ( 490) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  6]  1 */
    52451994, /* 22481 ( 490) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
      121298, /* 22482 ( 490) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6]  1 */
        3198, /* 22483 ( 490) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    35563820, /* 22484 ( 490) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
    35550858, /* 22485 ( 490) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6] -1 */
    17009472, /* 22486 ( 490) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  0]  1 */
    52438712, /* 22487 ( 490) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
    52570094, /* 22488 ( 490) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    52556808, /* 22489 ( 490) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
       16484, /* 22490 ( 475) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    17009474, /* 22491 ( 475) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  0]  1 */
    17140692, /* 22492 ( 475) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6]  1 */
    17022432, /* 22493 ( 475) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  0]  1 */
        3198, /* 22494 ( 475) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
      121458, /* 22495 ( 475) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  6]  1 */
      134420, /* 22496 ( 475) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6]  1 */
    17127410, /* 22497 ( 475) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
       16484, /* 22498 ( 476) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    51034656, /* 22499 ( 476) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  0] -1 */
    34015422, /* 22500 ( 476) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    17009474, /* 22501 ( 476) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  0]  1 */
    51139634, /* 22502 ( 476) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
    17140692, /* 22503 ( 476) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6]  1 */
    34146644, /* 22504 ( 476) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    17022432, /* 22505 ( 476) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  0]  1 */
        3198, /* 22506 ( 476) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    34133682, /* 22507 ( 476) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
      121458, /* 22508 ( 476) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  6]  1 */
    51021698, /* 22509 ( 476) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  0] -1 */
    34028708, /* 22510 ( 476) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
      134420, /* 22511 ( 476) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6]  1 */
    51152916, /* 22512 ( 476) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6] -1 */
    17127410, /* 22513 ( 476) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
       16484, /* 22514 ( 477) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    51034656, /* 22515 ( 477) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  0] -1 */
    34015422, /* 22516 ( 477) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    51139634, /* 22517 ( 477) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
    17009474, /* 22518 ( 477) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  0]  1 */
    17140692, /* 22519 ( 477) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6]  1 */
    34146644, /* 22520 ( 477) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
      121458, /* 22521 ( 477) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  6]  1 */
       16484, /* 22522 ( 478) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    51034656, /* 22523 ( 478) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  0] -1 */
    34015422, /* 22524 ( 478) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    17009474, /* 22525 ( 478) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  0]  1 */
    34133682, /* 22526 ( 478) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
      134420, /* 22527 ( 478) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6]  1 */
    51152916, /* 22528 ( 478) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6] -1 */
    17127410, /* 22529 ( 478) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
       16484, /* 22530 ( 479) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34015422, /* 22531 ( 479) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    17140692, /* 22532 ( 479) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6]  1 */
    34133682, /* 22533 ( 479) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
    17022432, /* 22534 ( 479) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  0]  1 */
    51139634, /* 22535 ( 479) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
    51021698, /* 22536 ( 479) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  0] -1 */
      134420, /* 22537 ( 479) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6]  1 */
       16484, /* 22538 ( 480) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    17009474, /* 22539 ( 480) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  0]  1 */
    34146644, /* 22540 ( 480) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    34133682, /* 22541 ( 480) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
        3198, /* 22542 ( 480) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    17022432, /* 22543 ( 480) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  0]  1 */
    51139634, /* 22544 ( 480) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
    51152916, /* 22545 ( 480) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6] -1 */
       16484, /* 22546 ( 481) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    51034656, /* 22547 ( 481) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  0] -1 */
    51139634, /* 22548 ( 481) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
        3198, /* 22549 ( 481) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
      121458, /* 22550 ( 481) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  6]  1 */
    51021698, /* 22551 ( 481) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  0] -1 */
      134420, /* 22552 ( 481) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6]  1 */
    51152916, /* 22553 ( 481) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6] -1 */
       16484, /* 22554 ( 482) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    51034656, /* 22555 ( 482) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  0] -1 */
    17140692, /* 22556 ( 482) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6]  1 */
    34146644, /* 22557 ( 482) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    34133682, /* 22558 ( 482) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
        3198, /* 22559 ( 482) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    51021698, /* 22560 ( 482) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  0] -1 */
    17127410, /* 22561 ( 482) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
       16484, /* 22562 ( 483) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34015422, /* 22563 ( 483) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    34146644, /* 22564 ( 483) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    17022432, /* 22565 ( 483) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  0]  1 */
      121458, /* 22566 ( 483) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  6]  1 */
    51021698, /* 22567 ( 483) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  0] -1 */
    51152916, /* 22568 ( 483) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6] -1 */
    17127410, /* 22569 ( 483) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
       16484, /* 22570 ( 484) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    17009474, /* 22571 ( 484) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  0]  1 */
    35445884, /* 22572 ( 484) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  0] -1 */
    35563820, /* 22573 ( 484) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
    52570092, /* 22574 ( 484) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    17140692, /* 22575 ( 484) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6]  1 */
    52451832, /* 22576 ( 484) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
    17022432, /* 22577 ( 484) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  0]  1 */
        3198, /* 22578 ( 484) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    35432598, /* 22579 ( 484) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  0] -1 */
    52556810, /* 22580 ( 484) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    52438874, /* 22581 ( 484) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
      121458, /* 22582 ( 484) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  6]  1 */
      134420, /* 22583 ( 484) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6]  1 */
    35550858, /* 22584 ( 484) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6] -1 */
    17127410, /* 22585 ( 484) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
       16484, /* 22586 ( 485) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34028546, /* 22587 ( 485) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    17009474, /* 22588 ( 485) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  0]  1 */
    51034818, /* 22589 ( 485) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  0] -1 */
    17140692, /* 22590 ( 485) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6]  1 */
    51139796, /* 22591 ( 485) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
    17022432, /* 22592 ( 485) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  0]  1 */
        3198, /* 22593 ( 485) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    34146806, /* 22594 ( 485) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    34133520, /* 22595 ( 485) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
    51152754, /* 22596 ( 485) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  6] -1 */
      121458, /* 22597 ( 485) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  6]  1 */
    51021536, /* 22598 ( 485) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  0] -1 */
      134420, /* 22599 ( 485) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6]  1 */
    34015584, /* 22600 ( 485) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    17127410, /* 22601 ( 485) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
       16484, /* 22602 ( 486) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    51139794, /* 22603 ( 486) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6] -1 */
    17009474, /* 22604 ( 486) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  0]  1 */
    51152756, /* 22605 ( 486) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
    17140692, /* 22606 ( 486) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6]  1 */
    34133522, /* 22607 ( 486) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    34015586, /* 22608 ( 486) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    51021534, /* 22609 ( 486) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  0] -1 */
    17022432, /* 22610 ( 486) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  0]  1 */
        3198, /* 22611 ( 486) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    34146804, /* 22612 ( 486) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
    51034820, /* 22613 ( 486) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  0] -1 */
      121458, /* 22614 ( 486) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  6]  1 */
      134420, /* 22615 ( 486) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6]  1 */
    34028544, /* 22616 ( 486) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    17127410, /* 22617 ( 486) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
       16484, /* 22618 ( 487) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34133684, /* 22619 ( 487) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    51139632, /* 22620 ( 487) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  6] -1 */
    34028706, /* 22621 ( 487) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    17009474, /* 22622 ( 487) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  0]  1 */
    34015424, /* 22623 ( 487) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    34146642, /* 22624 ( 487) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
    17140692, /* 22625 ( 487) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6]  1 */
    51152918, /* 22626 ( 487) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
    17022432, /* 22627 ( 487) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  0]  1 */
        3198, /* 22628 ( 487) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    51034658, /* 22629 ( 487) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  0] -1 */
    51021696, /* 22630 ( 487) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  0] -1 */
      121458, /* 22631 ( 487) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  6]  1 */
      134420, /* 22632 ( 487) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6]  1 */
    17127410, /* 22633 ( 487) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
       16484, /* 22634 ( 488) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    35563980, /* 22635 ( 488) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6] -1 */
    17009474, /* 22636 ( 488) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  0]  1 */
    17140692, /* 22637 ( 488) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6]  1 */
    35432762, /* 22638 ( 488) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  0] -1 */
    17127410, /* 22639 ( 488) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
    17022432, /* 22640 ( 488) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  0]  1 */
        3198, /* 22641 ( 488) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    52556970, /* 22642 ( 488) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    52569932, /* 22643 ( 488) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    35445720, /* 22644 ( 488) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  0] -1 */
      121458, /* 22645 ( 488) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  6]  1 */
    35550698, /* 22646 ( 488) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
    52438710, /* 22647 ( 488) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
      134420, /* 22648 ( 488) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6]  1 */
    52451996, /* 22649 ( 488) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
       16484, /* 22650 ( 489) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    52438712, /* 22651 ( 489) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
    52569930, /* 22652 ( 489) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    35550696, /* 22653 ( 489) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  6] -1 */
    17009474, /* 22654 ( 489) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  0]  1 */
    35445722, /* 22655 ( 489) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  0] -1 */
    52451994, /* 22656 ( 489) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
    35432760, /* 22657 ( 489) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  0] -1 */
    17140692, /* 22658 ( 489) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6]  1 */
    17022432, /* 22659 ( 489) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  0]  1 */
        3198, /* 22660 ( 489) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    35563982, /* 22661 ( 489) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
      121458, /* 22662 ( 489) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  6]  1 */
    52556972, /* 22663 ( 489) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
      134420, /* 22664 ( 489) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6]  1 */
    17127410, /* 22665 ( 489) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
       16484, /* 22666 ( 490) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    17009474, /* 22667 ( 490) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  0]  1 */
    35432600, /* 22668 ( 490) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  0] -1 */
    17140692, /* 22669 ( 490) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6]  1 */
      134420, /* 22670 ( 490) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6]  1 */
    35445882, /* 22671 ( 490) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  0] -1 */
    17127410, /* 22672 ( 490) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
    35550860, /* 22673 ( 490) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
    17022432, /* 22674 ( 490) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  0]  1 */
        3198, /* 22675 ( 490) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    52451834, /* 22676 ( 490) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
    52438872, /* 22677 ( 490) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
      121458, /* 22678 ( 490) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  6]  1 */
    35563818, /* 22679 ( 490) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  6] -1 */
    52570094, /* 22680 ( 490) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    52556808, /* 22681 ( 490) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
       16484, /* 22682 ( 475) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    17009474, /* 22683 ( 475) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  0]  1 */
    18439610, /* 22684 ( 475) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    17022432, /* 22685 ( 475) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  0]  1 */
        3198, /* 22686 ( 475) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
     1420376, /* 22687 ( 475) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  0]  1 */
     1433658, /* 22688 ( 475) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  0]  1 */
    18426648, /* 22689 ( 475) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
       16484, /* 22690 ( 476) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    51034656, /* 22691 ( 476) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  0] -1 */
    34015422, /* 22692 ( 476) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    17009474, /* 22693 ( 476) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  0]  1 */
    52438872, /* 22694 ( 476) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
    18439610, /* 22695 ( 476) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    35445882, /* 22696 ( 476) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  0] -1 */
    17022432, /* 22697 ( 476) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  0]  1 */
        3198, /* 22698 ( 476) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    35432600, /* 22699 ( 476) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  0] -1 */
     1420376, /* 22700 ( 476) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  0]  1 */
    51021698, /* 22701 ( 476) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  0] -1 */
    34028708, /* 22702 ( 476) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
     1433658, /* 22703 ( 476) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  0]  1 */
    52451834, /* 22704 ( 476) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
    18426648, /* 22705 ( 476) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
       16484, /* 22706 ( 477) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    51034656, /* 22707 ( 477) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  0] -1 */
    34015422, /* 22708 ( 477) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    52438872, /* 22709 ( 477) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
    17009474, /* 22710 ( 477) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  0]  1 */
    18439610, /* 22711 ( 477) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    35445882, /* 22712 ( 477) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  0] -1 */
     1420376, /* 22713 ( 477) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  0]  1 */
       16484, /* 22714 ( 478) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    51034656, /* 22715 ( 478) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  0] -1 */
    34015422, /* 22716 ( 478) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    17009474, /* 22717 ( 478) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  0]  1 */
    35432600, /* 22718 ( 478) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  0] -1 */
     1433658, /* 22719 ( 478) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  0]  1 */
    52451834, /* 22720 ( 478) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
    18426648, /* 22721 ( 478) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
       16484, /* 22722 ( 479) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34015422, /* 22723 ( 479) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    18439610, /* 22724 ( 479) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    35432600, /* 22725 ( 479) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  0] -1 */
    17022432, /* 22726 ( 479) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  0]  1 */
    52438872, /* 22727 ( 479) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
    51021698, /* 22728 ( 479) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  0] -1 */
     1433658, /* 22729 ( 479) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  0]  1 */
       16484, /* 22730 ( 480) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    17009474, /* 22731 ( 480) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  0]  1 */
    35445882, /* 22732 ( 480) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  0] -1 */
    35432600, /* 22733 ( 480) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  0] -1 */
        3198, /* 22734 ( 480) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    17022432, /* 22735 ( 480) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  0]  1 */
    52438872, /* 22736 ( 480) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
    52451834, /* 22737 ( 480) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
       16484, /* 22738 ( 481) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    51034656, /* 22739 ( 481) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  0] -1 */
    52438872, /* 22740 ( 481) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
        3198, /* 22741 ( 481) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
     1420376, /* 22742 ( 481) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  0]  1 */
    51021698, /* 22743 ( 481) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  0] -1 */
     1433658, /* 22744 ( 481) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  0]  1 */
    52451834, /* 22745 ( 481) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
       16484, /* 22746 ( 482) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    51034656, /* 22747 ( 482) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  0] -1 */
    18439610, /* 22748 ( 482) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    35445882, /* 22749 ( 482) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  0] -1 */
    35432600, /* 22750 ( 482) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  0] -1 */
        3198, /* 22751 ( 482) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    51021698, /* 22752 ( 482) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  0] -1 */
    18426648, /* 22753 ( 482) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
       16484, /* 22754 ( 483) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34015422, /* 22755 ( 483) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    35445882, /* 22756 ( 483) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  0] -1 */
    17022432, /* 22757 ( 483) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  0]  1 */
     1420376, /* 22758 ( 483) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  0]  1 */
    51021698, /* 22759 ( 483) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  0] -1 */
    52451834, /* 22760 ( 483) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
    18426648, /* 22761 ( 483) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
       16484, /* 22762 ( 484) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    17009474, /* 22763 ( 484) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  0]  1 */
    34146806, /* 22764 ( 484) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    35563980, /* 22765 ( 484) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6] -1 */
    52569932, /* 22766 ( 484) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    18439610, /* 22767 ( 484) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    51152754, /* 22768 ( 484) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  6] -1 */
    17022432, /* 22769 ( 484) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  0]  1 */
        3198, /* 22770 ( 484) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    34133520, /* 22771 ( 484) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
    52556970, /* 22772 ( 484) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    51139796, /* 22773 ( 484) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
     1420376, /* 22774 ( 484) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  0]  1 */
     1433658, /* 22775 ( 484) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  0]  1 */
    35550698, /* 22776 ( 484) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
    18426648, /* 22777 ( 484) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
       16484, /* 22778 ( 485) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34028706, /* 22779 ( 485) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    17009474, /* 22780 ( 485) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  0]  1 */
    51034658, /* 22781 ( 485) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  0] -1 */
    18439610, /* 22782 ( 485) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    52438874, /* 22783 ( 485) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
    17022432, /* 22784 ( 485) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  0]  1 */
        3198, /* 22785 ( 485) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    35445884, /* 22786 ( 485) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  0] -1 */
    35432598, /* 22787 ( 485) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  0] -1 */
    52451832, /* 22788 ( 485) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
     1420376, /* 22789 ( 485) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  0]  1 */
    51021696, /* 22790 ( 485) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  0] -1 */
     1433658, /* 22791 ( 485) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  0]  1 */
    34015424, /* 22792 ( 485) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    18426648, /* 22793 ( 485) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
       16484, /* 22794 ( 486) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    52438712, /* 22795 ( 486) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
    17009474, /* 22796 ( 486) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  0]  1 */
    52451994, /* 22797 ( 486) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
    18439610, /* 22798 ( 486) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    35432760, /* 22799 ( 486) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  0] -1 */
    34015586, /* 22800 ( 486) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    51021534, /* 22801 ( 486) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  0] -1 */
    17022432, /* 22802 ( 486) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  0]  1 */
        3198, /* 22803 ( 486) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    35445722, /* 22804 ( 486) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  0] -1 */
    51034820, /* 22805 ( 486) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  0] -1 */
     1420376, /* 22806 ( 486) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  0]  1 */
     1433658, /* 22807 ( 486) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  0]  1 */
    34028544, /* 22808 ( 486) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    18426648, /* 22809 ( 486) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
       16484, /* 22810 ( 487) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    35432762, /* 22811 ( 487) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  0] -1 */
    52438710, /* 22812 ( 487) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
    34028546, /* 22813 ( 487) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    17009474, /* 22814 ( 487) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  0]  1 */
    34015584, /* 22815 ( 487) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    35445720, /* 22816 ( 487) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  0] -1 */
    18439610, /* 22817 ( 487) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    52451996, /* 22818 ( 487) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
    17022432, /* 22819 ( 487) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  0]  1 */
        3198, /* 22820 ( 487) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    51034818, /* 22821 ( 487) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  0] -1 */
    51021536, /* 22822 ( 487) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  0] -1 */
     1420376, /* 22823 ( 487) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  0]  1 */
     1433658, /* 22824 ( 487) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  0]  1 */
    18426648, /* 22825 ( 487) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
       16484, /* 22826 ( 488) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    35563820, /* 22827 ( 488) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
    17009474, /* 22828 ( 488) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  0]  1 */
    18439610, /* 22829 ( 488) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    34133684, /* 22830 ( 488) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    18426648, /* 22831 ( 488) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
    17022432, /* 22832 ( 488) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  0]  1 */
        3198, /* 22833 ( 488) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    52556810, /* 22834 ( 488) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    52570092, /* 22835 ( 488) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    34146642, /* 22836 ( 488) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
     1420376, /* 22837 ( 488) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  0]  1 */
    35550858, /* 22838 ( 488) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6] -1 */
    51139632, /* 22839 ( 488) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  6] -1 */
     1433658, /* 22840 ( 488) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  0]  1 */
    51152918, /* 22841 ( 488) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
       16484, /* 22842 ( 489) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    51139794, /* 22843 ( 489) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6] -1 */
    52569930, /* 22844 ( 489) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    35550696, /* 22845 ( 489) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  6] -1 */
    17009474, /* 22846 ( 489) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  0]  1 */
    34146804, /* 22847 ( 489) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
    51152756, /* 22848 ( 489) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
    34133522, /* 22849 ( 489) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    18439610, /* 22850 ( 489) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    17022432, /* 22851 ( 489) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  0]  1 */
        3198, /* 22852 ( 489) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    35563982, /* 22853 ( 489) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
     1420376, /* 22854 ( 489) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  0]  1 */
    52556972, /* 22855 ( 489) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
     1433658, /* 22856 ( 489) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  0]  1 */
    18426648, /* 22857 ( 489) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
       16484, /* 22858 ( 490) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    17009474, /* 22859 ( 490) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  0]  1 */
    34133682, /* 22860 ( 490) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
    18439610, /* 22861 ( 490) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
     1433658, /* 22862 ( 490) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  0]  1 */
    34146644, /* 22863 ( 490) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    18426648, /* 22864 ( 490) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
    35550860, /* 22865 ( 490) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
    17022432, /* 22866 ( 490) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  0]  1 */
        3198, /* 22867 ( 490) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    51152916, /* 22868 ( 490) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6] -1 */
    51139634, /* 22869 ( 490) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
     1420376, /* 22870 ( 490) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  0]  1 */
    35563818, /* 22871 ( 490) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  6] -1 */
    52570094, /* 22872 ( 490) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    52556808, /* 22873 ( 490) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
       16484, /* 22874 ( 475) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
     1433498, /* 22875 ( 475) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  0]  1 */
    18426650, /* 22876 ( 475) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
     1420536, /* 22877 ( 475) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  0]  1 */
        3198, /* 22878 ( 475) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    17009312, /* 22879 ( 475) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  0]  1 */
    17022594, /* 22880 ( 475) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  0]  1 */
    18439608, /* 22881 ( 475) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
       16484, /* 22882 ( 476) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    35432760, /* 22883 ( 476) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  0] -1 */
    34015422, /* 22884 ( 476) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
     1433498, /* 22885 ( 476) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  0]  1 */
    52451832, /* 22886 ( 476) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
    18426650, /* 22887 ( 476) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    51034818, /* 22888 ( 476) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  0] -1 */
     1420536, /* 22889 ( 476) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  0]  1 */
        3198, /* 22890 ( 476) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    51021536, /* 22891 ( 476) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  0] -1 */
    17009312, /* 22892 ( 476) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  0]  1 */
    35445722, /* 22893 ( 476) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  0] -1 */
    34028708, /* 22894 ( 476) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    17022594, /* 22895 ( 476) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  0]  1 */
    52438874, /* 22896 ( 476) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
    18439608, /* 22897 ( 476) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
       16484, /* 22898 ( 477) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    35432760, /* 22899 ( 477) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  0] -1 */
    34015422, /* 22900 ( 477) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    52451832, /* 22901 ( 477) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
     1433498, /* 22902 ( 477) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  0]  1 */
    18426650, /* 22903 ( 477) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    51034818, /* 22904 ( 477) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  0] -1 */
    17009312, /* 22905 ( 477) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  0]  1 */
       16484, /* 22906 ( 478) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    35432760, /* 22907 ( 478) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  0] -1 */
    34015422, /* 22908 ( 478) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
     1433498, /* 22909 ( 478) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  0]  1 */
    51021536, /* 22910 ( 478) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  0] -1 */
    17022594, /* 22911 ( 478) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  0]  1 */
    52438874, /* 22912 ( 478) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
    18439608, /* 22913 ( 478) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
       16484, /* 22914 ( 479) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34015422, /* 22915 ( 479) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    18426650, /* 22916 ( 479) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    51021536, /* 22917 ( 479) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  0] -1 */
     1420536, /* 22918 ( 479) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  0]  1 */
    52451832, /* 22919 ( 479) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
    35445722, /* 22920 ( 479) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  0] -1 */
    17022594, /* 22921 ( 479) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  0]  1 */
       16484, /* 22922 ( 480) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
     1433498, /* 22923 ( 480) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  0]  1 */
    51034818, /* 22924 ( 480) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  0] -1 */
    51021536, /* 22925 ( 480) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  0] -1 */
        3198, /* 22926 ( 480) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
     1420536, /* 22927 ( 480) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  0]  1 */
    52451832, /* 22928 ( 480) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
    52438874, /* 22929 ( 480) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
       16484, /* 22930 ( 481) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    35432760, /* 22931 ( 481) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  0] -1 */
    52451832, /* 22932 ( 481) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
        3198, /* 22933 ( 481) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    17009312, /* 22934 ( 481) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  0]  1 */
    35445722, /* 22935 ( 481) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  0] -1 */
    17022594, /* 22936 ( 481) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  0]  1 */
    52438874, /* 22937 ( 481) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
       16484, /* 22938 ( 482) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    35432760, /* 22939 ( 482) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  0] -1 */
    18426650, /* 22940 ( 482) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    51034818, /* 22941 ( 482) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  0] -1 */
    51021536, /* 22942 ( 482) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  0] -1 */
        3198, /* 22943 ( 482) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    35445722, /* 22944 ( 482) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  0] -1 */
    18439608, /* 22945 ( 482) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
       16484, /* 22946 ( 483) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34015422, /* 22947 ( 483) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    51034818, /* 22948 ( 483) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  0] -1 */
     1420536, /* 22949 ( 483) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  0]  1 */
    17009312, /* 22950 ( 483) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  0]  1 */
    35445722, /* 22951 ( 483) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  0] -1 */
    52438874, /* 22952 ( 483) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
    18439608, /* 22953 ( 483) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
       16484, /* 22954 ( 484) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
     1433498, /* 22955 ( 484) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  0]  1 */
    34146806, /* 22956 ( 484) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    51152916, /* 22957 ( 484) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6] -1 */
    52556972, /* 22958 ( 484) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    18426650, /* 22959 ( 484) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    35550858, /* 22960 ( 484) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6] -1 */
     1420536, /* 22961 ( 484) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  0]  1 */
        3198, /* 22962 ( 484) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    34133520, /* 22963 ( 484) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
    52569930, /* 22964 ( 484) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    35563820, /* 22965 ( 484) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
    17009312, /* 22966 ( 484) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  0]  1 */
    17022594, /* 22967 ( 484) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  0]  1 */
    51139634, /* 22968 ( 484) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
    18439608, /* 22969 ( 484) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
       16484, /* 22970 ( 485) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34028706, /* 22971 ( 485) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
     1433498, /* 22972 ( 485) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  0]  1 */
    35432762, /* 22973 ( 485) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  0] -1 */
    18426650, /* 22974 ( 485) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    52451834, /* 22975 ( 485) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
     1420536, /* 22976 ( 485) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  0]  1 */
        3198, /* 22977 ( 485) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    51034820, /* 22978 ( 485) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  0] -1 */
    51021534, /* 22979 ( 485) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  0] -1 */
    52438872, /* 22980 ( 485) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
    17009312, /* 22981 ( 485) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  0]  1 */
    35445720, /* 22982 ( 485) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  0] -1 */
    17022594, /* 22983 ( 485) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  0]  1 */
    34015424, /* 22984 ( 485) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    18439608, /* 22985 ( 485) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
       16484, /* 22986 ( 486) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    52438712, /* 22987 ( 486) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
     1433498, /* 22988 ( 486) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  0]  1 */
    52451994, /* 22989 ( 486) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
    18426650, /* 22990 ( 486) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    51034656, /* 22991 ( 486) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  0] -1 */
    34028546, /* 22992 ( 486) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    35432598, /* 22993 ( 486) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  0] -1 */
     1420536, /* 22994 ( 486) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  0]  1 */
        3198, /* 22995 ( 486) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    51021698, /* 22996 ( 486) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  0] -1 */
    35445884, /* 22997 ( 486) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  0] -1 */
    17009312, /* 22998 ( 486) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  0]  1 */
    17022594, /* 22999 ( 486) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  0]  1 */
    34015584, /* 23000 ( 486) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    18439608, /* 23001 ( 486) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
       16484, /* 23002 ( 487) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    51034658, /* 23003 ( 487) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  0] -1 */
    52438710, /* 23004 ( 487) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
    34015586, /* 23005 ( 487) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
     1433498, /* 23006 ( 487) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  0]  1 */
    34028544, /* 23007 ( 487) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    51021696, /* 23008 ( 487) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  0] -1 */
    18426650, /* 23009 ( 487) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    52451996, /* 23010 ( 487) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
     1420536, /* 23011 ( 487) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  0]  1 */
        3198, /* 23012 ( 487) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    35445882, /* 23013 ( 487) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  0] -1 */
    35432600, /* 23014 ( 487) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  0] -1 */
    17009312, /* 23015 ( 487) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  0]  1 */
    17022594, /* 23016 ( 487) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  0]  1 */
    18439608, /* 23017 ( 487) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
       16484, /* 23018 ( 488) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    51139796, /* 23019 ( 488) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
     1433498, /* 23020 ( 488) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  0]  1 */
    18426650, /* 23021 ( 488) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    34146644, /* 23022 ( 488) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    18439608, /* 23023 ( 488) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
     1420536, /* 23024 ( 488) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  0]  1 */
        3198, /* 23025 ( 488) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    52556810, /* 23026 ( 488) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    52570092, /* 23027 ( 488) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    34133682, /* 23028 ( 488) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
    17009312, /* 23029 ( 488) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  0]  1 */
    51152754, /* 23030 ( 488) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  6] -1 */
    35550696, /* 23031 ( 488) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  6] -1 */
    17022594, /* 23032 ( 488) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  0]  1 */
    35563982, /* 23033 ( 488) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
       16484, /* 23034 ( 489) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    35563818, /* 23035 ( 489) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  6] -1 */
    52556970, /* 23036 ( 489) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    51139632, /* 23037 ( 489) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  6] -1 */
     1433498, /* 23038 ( 489) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  0]  1 */
    34146804, /* 23039 ( 489) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
    35550860, /* 23040 ( 489) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
    34133522, /* 23041 ( 489) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    18426650, /* 23042 ( 489) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
     1420536, /* 23043 ( 489) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  0]  1 */
        3198, /* 23044 ( 489) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    51152918, /* 23045 ( 489) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
    17009312, /* 23046 ( 489) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  0]  1 */
    52569932, /* 23047 ( 489) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    17022594, /* 23048 ( 489) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  0]  1 */
    18439608, /* 23049 ( 489) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
       16484, /* 23050 ( 490) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
     1433498, /* 23051 ( 490) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  0]  1 */
    34146642, /* 23052 ( 490) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
    18426650, /* 23053 ( 490) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    17022594, /* 23054 ( 490) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  0]  1 */
    34133684, /* 23055 ( 490) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    18439608, /* 23056 ( 490) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
    51152756, /* 23057 ( 490) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
     1420536, /* 23058 ( 490) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  0]  1 */
        3198, /* 23059 ( 490) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    35563980, /* 23060 ( 490) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6] -1 */
    35550698, /* 23061 ( 490) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
    17009312, /* 23062 ( 490) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  0]  1 */
    51139794, /* 23063 ( 490) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6] -1 */
    52570094, /* 23064 ( 490) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    52556808, /* 23065 ( 490) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
       16484, /* 23066 ( 475) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
     1433498, /* 23067 ( 475) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  0]  1 */
     1551756, /* 23068 ( 475) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
     1420536, /* 23069 ( 475) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  0]  1 */
        3198, /* 23070 ( 475) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
      134418, /* 23071 ( 475) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  6]  1 */
      121460, /* 23072 ( 475) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6]  1 */
     1538474, /* 23073 ( 475) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
       16484, /* 23074 ( 476) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    35432760, /* 23075 ( 476) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  0] -1 */
    34015422, /* 23076 ( 476) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
     1433498, /* 23077 ( 476) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  0]  1 */
    35550698, /* 23078 ( 476) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
     1551756, /* 23079 ( 476) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
    34133684, /* 23080 ( 476) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
     1420536, /* 23081 ( 476) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  0]  1 */
        3198, /* 23082 ( 476) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    34146642, /* 23083 ( 476) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
      134418, /* 23084 ( 476) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  6]  1 */
    35445722, /* 23085 ( 476) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  0] -1 */
    34028708, /* 23086 ( 476) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
      121460, /* 23087 ( 476) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6]  1 */
    35563980, /* 23088 ( 476) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6] -1 */
     1538474, /* 23089 ( 476) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
       16484, /* 23090 ( 477) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    35432760, /* 23091 ( 477) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  0] -1 */
    34015422, /* 23092 ( 477) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    35550698, /* 23093 ( 477) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
     1433498, /* 23094 ( 477) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  0]  1 */
     1551756, /* 23095 ( 477) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
    34133684, /* 23096 ( 477) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
      134418, /* 23097 ( 477) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  6]  1 */
       16484, /* 23098 ( 478) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    35432760, /* 23099 ( 478) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  0] -1 */
    34015422, /* 23100 ( 478) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
     1433498, /* 23101 ( 478) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  0]  1 */
    34146642, /* 23102 ( 478) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
      121460, /* 23103 ( 478) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6]  1 */
    35563980, /* 23104 ( 478) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6] -1 */
     1538474, /* 23105 ( 478) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
       16484, /* 23106 ( 479) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34015422, /* 23107 ( 479) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
     1551756, /* 23108 ( 479) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
    34146642, /* 23109 ( 479) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
     1420536, /* 23110 ( 479) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  0]  1 */
    35550698, /* 23111 ( 479) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
    35445722, /* 23112 ( 479) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  0] -1 */
      121460, /* 23113 ( 479) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6]  1 */
       16484, /* 23114 ( 480) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
     1433498, /* 23115 ( 480) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  0]  1 */
    34133684, /* 23116 ( 480) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    34146642, /* 23117 ( 480) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
        3198, /* 23118 ( 480) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
     1420536, /* 23119 ( 480) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  0]  1 */
    35550698, /* 23120 ( 480) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
    35563980, /* 23121 ( 480) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6] -1 */
       16484, /* 23122 ( 481) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    35432760, /* 23123 ( 481) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  0] -1 */
    35550698, /* 23124 ( 481) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
        3198, /* 23125 ( 481) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
      134418, /* 23126 ( 481) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  6]  1 */
    35445722, /* 23127 ( 481) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  0] -1 */
      121460, /* 23128 ( 481) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6]  1 */
    35563980, /* 23129 ( 481) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6] -1 */
       16484, /* 23130 ( 482) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    35432760, /* 23131 ( 482) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  0] -1 */
     1551756, /* 23132 ( 482) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
    34133684, /* 23133 ( 482) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    34146642, /* 23134 ( 482) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
        3198, /* 23135 ( 482) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    35445722, /* 23136 ( 482) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  0] -1 */
     1538474, /* 23137 ( 482) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
       16484, /* 23138 ( 483) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34015422, /* 23139 ( 483) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    34133684, /* 23140 ( 483) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
     1420536, /* 23141 ( 483) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  0]  1 */
      134418, /* 23142 ( 483) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  6]  1 */
    35445722, /* 23143 ( 483) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  0] -1 */
    35563980, /* 23144 ( 483) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6] -1 */
     1538474, /* 23145 ( 483) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
       16484, /* 23146 ( 484) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
     1433498, /* 23147 ( 484) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  0]  1 */
    51034820, /* 23148 ( 484) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  0] -1 */
    51139796, /* 23149 ( 484) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
    52570092, /* 23150 ( 484) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
     1551756, /* 23151 ( 484) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
    52438872, /* 23152 ( 484) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
     1420536, /* 23153 ( 484) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  0]  1 */
        3198, /* 23154 ( 484) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    51021534, /* 23155 ( 484) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  0] -1 */
    52556810, /* 23156 ( 484) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    52451834, /* 23157 ( 484) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
      134418, /* 23158 ( 484) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  6]  1 */
      121460, /* 23159 ( 484) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6]  1 */
    51152754, /* 23160 ( 484) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  6] -1 */
     1538474, /* 23161 ( 484) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
       16484, /* 23162 ( 485) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34015586, /* 23163 ( 485) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
     1433498, /* 23164 ( 485) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  0]  1 */
    35445882, /* 23165 ( 485) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  0] -1 */
     1551756, /* 23166 ( 485) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
    35563820, /* 23167 ( 485) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
     1420536, /* 23168 ( 485) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  0]  1 */
        3198, /* 23169 ( 485) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    34146806, /* 23170 ( 485) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    34133520, /* 23171 ( 485) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
    35550858, /* 23172 ( 485) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6] -1 */
      134418, /* 23173 ( 485) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  6]  1 */
    35432600, /* 23174 ( 485) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  0] -1 */
      121460, /* 23175 ( 485) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6]  1 */
    34028544, /* 23176 ( 485) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
     1538474, /* 23177 ( 485) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
       16484, /* 23178 ( 486) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    35563818, /* 23179 ( 486) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  6] -1 */
     1433498, /* 23180 ( 486) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  0]  1 */
    35550860, /* 23181 ( 486) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
     1551756, /* 23182 ( 486) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
    34133522, /* 23183 ( 486) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    34028546, /* 23184 ( 486) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    35432598, /* 23185 ( 486) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  0] -1 */
     1420536, /* 23186 ( 486) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  0]  1 */
        3198, /* 23187 ( 486) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    34146804, /* 23188 ( 486) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
    35445884, /* 23189 ( 486) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  0] -1 */
      134418, /* 23190 ( 486) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  6]  1 */
      121460, /* 23191 ( 486) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6]  1 */
    34015584, /* 23192 ( 486) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
     1538474, /* 23193 ( 486) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
       16484, /* 23194 ( 487) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34146644, /* 23195 ( 487) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    35550696, /* 23196 ( 487) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  6] -1 */
    34028706, /* 23197 ( 487) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
     1433498, /* 23198 ( 487) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  0]  1 */
    34015424, /* 23199 ( 487) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    34133682, /* 23200 ( 487) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
     1551756, /* 23201 ( 487) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
    35563982, /* 23202 ( 487) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
     1420536, /* 23203 ( 487) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  0]  1 */
        3198, /* 23204 ( 487) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    35432762, /* 23205 ( 487) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  0] -1 */
    35445720, /* 23206 ( 487) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  0] -1 */
      134418, /* 23207 ( 487) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  6]  1 */
      121460, /* 23208 ( 487) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6]  1 */
     1538474, /* 23209 ( 487) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
       16484, /* 23210 ( 488) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    51152916, /* 23211 ( 488) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6] -1 */
     1433498, /* 23212 ( 488) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  0]  1 */
     1551756, /* 23213 ( 488) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
    51034658, /* 23214 ( 488) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  0] -1 */
     1538474, /* 23215 ( 488) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
     1420536, /* 23216 ( 488) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  0]  1 */
        3198, /* 23217 ( 488) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    52569930, /* 23218 ( 488) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    52556972, /* 23219 ( 488) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    51021696, /* 23220 ( 488) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  0] -1 */
      134418, /* 23221 ( 488) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  6]  1 */
    51139634, /* 23222 ( 488) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
    52438710, /* 23223 ( 488) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
      121460, /* 23224 ( 488) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6]  1 */
    52451996, /* 23225 ( 488) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
       16484, /* 23226 ( 489) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    52438712, /* 23227 ( 489) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
    52556970, /* 23228 ( 489) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    51139632, /* 23229 ( 489) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  6] -1 */
     1433498, /* 23230 ( 489) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  0]  1 */
    51021698, /* 23231 ( 489) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  0] -1 */
    52451994, /* 23232 ( 489) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
    51034656, /* 23233 ( 489) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  0] -1 */
     1551756, /* 23234 ( 489) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
     1420536, /* 23235 ( 489) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  0]  1 */
        3198, /* 23236 ( 489) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    51152918, /* 23237 ( 489) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
      134418, /* 23238 ( 489) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  6]  1 */
    52569932, /* 23239 ( 489) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
      121460, /* 23240 ( 489) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6]  1 */
     1538474, /* 23241 ( 489) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
       16484, /* 23242 ( 490) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
     1433498, /* 23243 ( 490) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  0]  1 */
    51021536, /* 23244 ( 490) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  0] -1 */
     1551756, /* 23245 ( 490) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
      121460, /* 23246 ( 490) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6]  1 */
    51034818, /* 23247 ( 490) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  0] -1 */
     1538474, /* 23248 ( 490) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
    51152756, /* 23249 ( 490) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
     1420536, /* 23250 ( 490) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  0]  1 */
        3198, /* 23251 ( 490) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    52438874, /* 23252 ( 490) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
    52451832, /* 23253 ( 490) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
      134418, /* 23254 ( 490) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  6]  1 */
    51139794, /* 23255 ( 490) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6] -1 */
    52570094, /* 23256 ( 490) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    52556808, /* 23257 ( 490) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
       16484, /* 23258 ( 491) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
        3200, /* 23259 ( 491) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
        3198, /* 23260 ( 491) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    18544748, /* 23261 ( 491) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    18557708, /* 23262 ( 491) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    18544746, /* 23263 ( 491) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
       16482, /* 23264 ( 491) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    18557706, /* 23265 ( 491) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
       16484, /* 23266 ( 492) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34015422, /* 23267 ( 492) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
        3200, /* 23268 ( 492) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    52569932, /* 23269 ( 492) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    34028706, /* 23270 ( 492) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
        3198, /* 23271 ( 492) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    18544748, /* 23272 ( 492) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    52556970, /* 23273 ( 492) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    52569930, /* 23274 ( 492) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    52556972, /* 23275 ( 492) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    34015424, /* 23276 ( 492) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    18557708, /* 23277 ( 492) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    34028708, /* 23278 ( 492) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    18544746, /* 23279 ( 492) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
       16482, /* 23280 ( 492) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    18557706, /* 23281 ( 492) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
       16484, /* 23282 ( 493) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34015422, /* 23283 ( 493) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    52556970, /* 23284 ( 493) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    52556972, /* 23285 ( 493) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    34015424, /* 23286 ( 493) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    18557708, /* 23287 ( 493) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
       16482, /* 23288 ( 493) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    18557706, /* 23289 ( 493) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
       16484, /* 23290 ( 494) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34015422, /* 23291 ( 494) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
        3200, /* 23292 ( 494) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34028706, /* 23293 ( 494) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    52556970, /* 23294 ( 494) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    52569930, /* 23295 ( 494) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    18557708, /* 23296 ( 494) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    18544748, /* 23297 ( 494) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
       16484, /* 23298 ( 495) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
        3200, /* 23299 ( 495) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    52569932, /* 23300 ( 495) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
        3198, /* 23301 ( 495) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    52556970, /* 23302 ( 495) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    52556972, /* 23303 ( 495) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    52569930, /* 23304 ( 495) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
       16482, /* 23305 ( 495) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
       16484, /* 23306 ( 496) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    52569932, /* 23307 ( 496) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    34028706, /* 23308 ( 496) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
        3198, /* 23309 ( 496) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    52556970, /* 23310 ( 496) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    34015424, /* 23311 ( 496) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    18544748, /* 23312 ( 496) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    18557706, /* 23313 ( 496) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
       16484, /* 23314 ( 497) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34015422, /* 23315 ( 497) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
        3200, /* 23316 ( 497) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    52569932, /* 23317 ( 497) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    34028706, /* 23318 ( 497) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    52556972, /* 23319 ( 497) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    18544746, /* 23320 ( 497) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
    18557706, /* 23321 ( 497) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
       16484, /* 23322 ( 498) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    35563818, /* 23323 ( 498) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  6] -1 */
        3200, /* 23324 ( 498) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    51034820, /* 23325 ( 498) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  0] -1 */
    35550860, /* 23326 ( 498) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
    51034818, /* 23327 ( 498) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  0] -1 */
        3198, /* 23328 ( 498) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    18544748, /* 23329 ( 498) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    51021534, /* 23330 ( 498) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  0] -1 */
    51021536, /* 23331 ( 498) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  0] -1 */
    35550858, /* 23332 ( 498) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6] -1 */
    18557708, /* 23333 ( 498) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    18544746, /* 23334 ( 498) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
       16482, /* 23335 ( 498) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    35563820, /* 23336 ( 498) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
    18557706, /* 23337 ( 498) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
       16484, /* 23338 ( 499) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    52451834, /* 23339 ( 499) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
    34133522, /* 23340 ( 499) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
        3200, /* 23341 ( 499) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    52438874, /* 23342 ( 499) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
    34133520, /* 23343 ( 499) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
    34146804, /* 23344 ( 499) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
        3198, /* 23345 ( 499) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    18544748, /* 23346 ( 499) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    34146806, /* 23347 ( 499) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    18557708, /* 23348 ( 499) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    52438872, /* 23349 ( 499) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
    18544746, /* 23350 ( 499) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
       16482, /* 23351 ( 499) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    52451832, /* 23352 ( 499) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
    18557706, /* 23353 ( 499) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
       16484, /* 23354 ( 500) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
        3200, /* 23355 ( 500) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    18544746, /* 23356 ( 500) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
    35432760, /* 23357 ( 500) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  0] -1 */
    51139634, /* 23358 ( 500) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
    35432762, /* 23359 ( 500) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  0] -1 */
    35445720, /* 23360 ( 500) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  0] -1 */
        3198, /* 23361 ( 500) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    18544748, /* 23362 ( 500) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    35445722, /* 23363 ( 500) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  0] -1 */
    51152916, /* 23364 ( 500) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6] -1 */
    51152918, /* 23365 ( 500) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
    18557708, /* 23366 ( 500) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    51139632, /* 23367 ( 500) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  6] -1 */
       16482, /* 23368 ( 500) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    18557706, /* 23369 ( 500) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
       16484, /* 23370 ( 501) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    52438710, /* 23371 ( 501) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
        3200, /* 23372 ( 501) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34146644, /* 23373 ( 501) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    52451994, /* 23374 ( 501) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
    52451996, /* 23375 ( 501) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
        3198, /* 23376 ( 501) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    18544748, /* 23377 ( 501) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    18557708, /* 23378 ( 501) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    34133684, /* 23379 ( 501) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    34133682, /* 23380 ( 501) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
    34146642, /* 23381 ( 501) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
    52438712, /* 23382 ( 501) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
    18544746, /* 23383 ( 501) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
       16482, /* 23384 ( 501) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    18557706, /* 23385 ( 501) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
       16484, /* 23386 ( 502) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34015586, /* 23387 ( 502) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    52556810, /* 23388 ( 502) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
        3200, /* 23389 ( 502) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34015584, /* 23390 ( 502) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
       16482, /* 23391 ( 502) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
        3198, /* 23392 ( 502) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    18544748, /* 23393 ( 502) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    52556808, /* 23394 ( 502) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    34028546, /* 23395 ( 502) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    18557708, /* 23396 ( 502) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    52570092, /* 23397 ( 502) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    18544746, /* 23398 ( 502) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
    52570094, /* 23399 ( 502) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    34028544, /* 23400 ( 502) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    18557706, /* 23401 ( 502) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
       16484, /* 23402 ( 491) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
       16320, /* 23403 ( 491) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
        3198, /* 23404 ( 491) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    18557708, /* 23405 ( 491) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    18557868, /* 23406 ( 491) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
    18544586, /* 23407 ( 491) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
        3362, /* 23408 ( 491) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    18544746, /* 23409 ( 491) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
       16484, /* 23410 ( 492) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34015422, /* 23411 ( 492) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
       16320, /* 23412 ( 492) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    52570092, /* 23413 ( 492) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    34015586, /* 23414 ( 492) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
        3198, /* 23415 ( 492) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    18557708, /* 23416 ( 492) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    52556810, /* 23417 ( 492) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    52556970, /* 23418 ( 492) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    52569932, /* 23419 ( 492) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    34028544, /* 23420 ( 492) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    18557868, /* 23421 ( 492) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
    34028708, /* 23422 ( 492) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    18544586, /* 23423 ( 492) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
        3362, /* 23424 ( 492) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    18544746, /* 23425 ( 492) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
       16484, /* 23426 ( 493) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34015422, /* 23427 ( 493) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    52556810, /* 23428 ( 493) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    52569932, /* 23429 ( 493) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    34028544, /* 23430 ( 493) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    18557868, /* 23431 ( 493) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
        3362, /* 23432 ( 493) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    18544746, /* 23433 ( 493) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
       16484, /* 23434 ( 494) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34015422, /* 23435 ( 494) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
       16320, /* 23436 ( 494) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    34015586, /* 23437 ( 494) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    52556810, /* 23438 ( 494) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    52556970, /* 23439 ( 494) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    18557868, /* 23440 ( 494) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
    18557708, /* 23441 ( 494) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
       16484, /* 23442 ( 495) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
       16320, /* 23443 ( 495) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    52570092, /* 23444 ( 495) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
        3198, /* 23445 ( 495) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    52556810, /* 23446 ( 495) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    52569932, /* 23447 ( 495) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    52556970, /* 23448 ( 495) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
        3362, /* 23449 ( 495) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
       16484, /* 23450 ( 496) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    52570092, /* 23451 ( 496) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    34015586, /* 23452 ( 496) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
        3198, /* 23453 ( 496) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    52556810, /* 23454 ( 496) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    34028544, /* 23455 ( 496) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    18557708, /* 23456 ( 496) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    18544746, /* 23457 ( 496) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
       16484, /* 23458 ( 497) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34015422, /* 23459 ( 497) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
       16320, /* 23460 ( 497) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    52570092, /* 23461 ( 497) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    34015586, /* 23462 ( 497) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    52569932, /* 23463 ( 497) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    18544586, /* 23464 ( 497) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    18544746, /* 23465 ( 497) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
       16484, /* 23466 ( 498) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    51139794, /* 23467 ( 498) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6] -1 */
       16320, /* 23468 ( 498) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    35445884, /* 23469 ( 498) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  0] -1 */
    51152756, /* 23470 ( 498) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
    35432762, /* 23471 ( 498) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  0] -1 */
        3198, /* 23472 ( 498) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    18557708, /* 23473 ( 498) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    35432598, /* 23474 ( 498) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  0] -1 */
    35445720, /* 23475 ( 498) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  0] -1 */
    51139634, /* 23476 ( 498) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
    18557868, /* 23477 ( 498) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
    18544586, /* 23478 ( 498) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
        3362, /* 23479 ( 498) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    51152916, /* 23480 ( 498) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6] -1 */
    18544746, /* 23481 ( 498) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
       16484, /* 23482 ( 499) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    35563980, /* 23483 ( 499) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6] -1 */
    51034656, /* 23484 ( 499) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  0] -1 */
       16320, /* 23485 ( 499) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    35563820, /* 23486 ( 499) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
    51021534, /* 23487 ( 499) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  0] -1 */
    51021698, /* 23488 ( 499) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  0] -1 */
        3198, /* 23489 ( 499) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    18557708, /* 23490 ( 499) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    51034820, /* 23491 ( 499) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  0] -1 */
    18557868, /* 23492 ( 499) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
    35550698, /* 23493 ( 499) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
    18544586, /* 23494 ( 499) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
        3362, /* 23495 ( 499) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    35550858, /* 23496 ( 499) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6] -1 */
    18544746, /* 23497 ( 499) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
       16484, /* 23498 ( 500) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
       16320, /* 23499 ( 500) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    18544586, /* 23500 ( 500) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    34133522, /* 23501 ( 500) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    52451832, /* 23502 ( 500) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
    34146644, /* 23503 ( 500) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    34133682, /* 23504 ( 500) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
        3198, /* 23505 ( 500) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    18557708, /* 23506 ( 500) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    34146804, /* 23507 ( 500) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
    52438874, /* 23508 ( 500) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
    52451996, /* 23509 ( 500) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
    18557868, /* 23510 ( 500) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
    52438710, /* 23511 ( 500) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
        3362, /* 23512 ( 500) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    18544746, /* 23513 ( 500) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
       16484, /* 23514 ( 501) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    35550696, /* 23515 ( 501) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  6] -1 */
       16320, /* 23516 ( 501) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    51034818, /* 23517 ( 501) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  0] -1 */
    35550860, /* 23518 ( 501) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
    35563982, /* 23519 ( 501) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
        3198, /* 23520 ( 501) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    18557708, /* 23521 ( 501) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    18557868, /* 23522 ( 501) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
    51034658, /* 23523 ( 501) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  0] -1 */
    51021536, /* 23524 ( 501) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  0] -1 */
    51021696, /* 23525 ( 501) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  0] -1 */
    35563818, /* 23526 ( 501) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  6] -1 */
    18544586, /* 23527 ( 501) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
        3362, /* 23528 ( 501) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    18544746, /* 23529 ( 501) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
       16484, /* 23530 ( 502) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34028546, /* 23531 ( 502) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    52569930, /* 23532 ( 502) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
       16320, /* 23533 ( 502) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    34015424, /* 23534 ( 502) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
        3362, /* 23535 ( 502) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
        3198, /* 23536 ( 502) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    18557708, /* 23537 ( 502) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    52556808, /* 23538 ( 502) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    34028706, /* 23539 ( 502) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    18557868, /* 23540 ( 502) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
    52556972, /* 23541 ( 502) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    18544586, /* 23542 ( 502) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    52570094, /* 23543 ( 502) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    34015584, /* 23544 ( 502) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    18544746, /* 23545 ( 502) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
       16484, /* 23546 ( 491) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
        3360, /* 23547 ( 491) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
        3198, /* 23548 ( 491) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    18557868, /* 23549 ( 491) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
    18544748, /* 23550 ( 491) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    18557706, /* 23551 ( 491) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
       16322, /* 23552 ( 491) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    18544586, /* 23553 ( 491) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
       16484, /* 23554 ( 492) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34015422, /* 23555 ( 492) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
        3360, /* 23556 ( 492) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    52556972, /* 23557 ( 492) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    34028546, /* 23558 ( 492) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
        3198, /* 23559 ( 492) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    18557868, /* 23560 ( 492) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
    52569930, /* 23561 ( 492) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    52556810, /* 23562 ( 492) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    52570092, /* 23563 ( 492) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    34015584, /* 23564 ( 492) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    18544748, /* 23565 ( 492) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    34028708, /* 23566 ( 492) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    18557706, /* 23567 ( 492) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
       16322, /* 23568 ( 492) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    18544586, /* 23569 ( 492) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
       16484, /* 23570 ( 493) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34015422, /* 23571 ( 493) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    52569930, /* 23572 ( 493) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    52570092, /* 23573 ( 493) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    34015584, /* 23574 ( 493) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    18544748, /* 23575 ( 493) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
       16322, /* 23576 ( 493) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    18544586, /* 23577 ( 493) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
       16484, /* 23578 ( 494) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34015422, /* 23579 ( 494) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
        3360, /* 23580 ( 494) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    34028546, /* 23581 ( 494) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    52569930, /* 23582 ( 494) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    52556810, /* 23583 ( 494) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    18544748, /* 23584 ( 494) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    18557868, /* 23585 ( 494) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
       16484, /* 23586 ( 495) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
        3360, /* 23587 ( 495) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    52556972, /* 23588 ( 495) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
        3198, /* 23589 ( 495) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    52569930, /* 23590 ( 495) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    52570092, /* 23591 ( 495) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    52556810, /* 23592 ( 495) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
       16322, /* 23593 ( 495) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
       16484, /* 23594 ( 496) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    52556972, /* 23595 ( 496) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    34028546, /* 23596 ( 496) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
        3198, /* 23597 ( 496) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    52569930, /* 23598 ( 496) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    34015584, /* 23599 ( 496) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    18557868, /* 23600 ( 496) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
    18544586, /* 23601 ( 496) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
       16484, /* 23602 ( 497) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34015422, /* 23603 ( 497) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
        3360, /* 23604 ( 497) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    52556972, /* 23605 ( 497) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    34028546, /* 23606 ( 497) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    52570092, /* 23607 ( 497) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    18557706, /* 23608 ( 497) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
    18544586, /* 23609 ( 497) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
       16484, /* 23610 ( 498) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    52438712, /* 23611 ( 498) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
        3360, /* 23612 ( 498) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    34146806, /* 23613 ( 498) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    52451994, /* 23614 ( 498) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
    34146644, /* 23615 ( 498) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
        3198, /* 23616 ( 498) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    18557868, /* 23617 ( 498) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
    34133520, /* 23618 ( 498) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
    34133682, /* 23619 ( 498) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
    52451832, /* 23620 ( 498) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
    18544748, /* 23621 ( 498) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    18557706, /* 23622 ( 498) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
       16322, /* 23623 ( 498) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    52438874, /* 23624 ( 498) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
    18544586, /* 23625 ( 498) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
       16484, /* 23626 ( 499) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    51139796, /* 23627 ( 499) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
    35432760, /* 23628 ( 499) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  0] -1 */
        3360, /* 23629 ( 499) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    51152916, /* 23630 ( 499) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6] -1 */
    35432598, /* 23631 ( 499) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  0] -1 */
    35445722, /* 23632 ( 499) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  0] -1 */
        3198, /* 23633 ( 499) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    18557868, /* 23634 ( 499) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
    35445884, /* 23635 ( 499) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  0] -1 */
    18544748, /* 23636 ( 499) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    51152754, /* 23637 ( 499) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  6] -1 */
    18557706, /* 23638 ( 499) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
       16322, /* 23639 ( 499) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    51139634, /* 23640 ( 499) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
    18544586, /* 23641 ( 499) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
       16484, /* 23642 ( 500) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
        3360, /* 23643 ( 500) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    18557706, /* 23644 ( 500) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
    51034656, /* 23645 ( 500) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  0] -1 */
    35550858, /* 23646 ( 500) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6] -1 */
    51034818, /* 23647 ( 500) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  0] -1 */
    51021536, /* 23648 ( 500) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  0] -1 */
        3198, /* 23649 ( 500) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    18557868, /* 23650 ( 500) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
    51021698, /* 23651 ( 500) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  0] -1 */
    35563820, /* 23652 ( 500) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
    35563982, /* 23653 ( 500) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
    18544748, /* 23654 ( 500) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    35550696, /* 23655 ( 500) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  6] -1 */
       16322, /* 23656 ( 500) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    18544586, /* 23657 ( 500) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
       16484, /* 23658 ( 501) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    51139632, /* 23659 ( 501) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  6] -1 */
        3360, /* 23660 ( 501) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    35432762, /* 23661 ( 501) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  0] -1 */
    51152756, /* 23662 ( 501) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
    51152918, /* 23663 ( 501) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
        3198, /* 23664 ( 501) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    18557868, /* 23665 ( 501) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
    18544748, /* 23666 ( 501) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    35445882, /* 23667 ( 501) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  0] -1 */
    35445720, /* 23668 ( 501) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  0] -1 */
    35432600, /* 23669 ( 501) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  0] -1 */
    51139794, /* 23670 ( 501) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6] -1 */
    18557706, /* 23671 ( 501) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
       16322, /* 23672 ( 501) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    18544586, /* 23673 ( 501) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
       16484, /* 23674 ( 502) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34028706, /* 23675 ( 502) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    52556970, /* 23676 ( 502) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
        3360, /* 23677 ( 502) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    34028544, /* 23678 ( 502) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
       16322, /* 23679 ( 502) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
        3198, /* 23680 ( 502) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    18557868, /* 23681 ( 502) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
    52556808, /* 23682 ( 502) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    34015586, /* 23683 ( 502) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    18544748, /* 23684 ( 502) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    52569932, /* 23685 ( 502) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    18557706, /* 23686 ( 502) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
    52570094, /* 23687 ( 502) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    34015424, /* 23688 ( 502) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    18544586, /* 23689 ( 502) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
       16484, /* 23690 ( 503) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
        3200, /* 23691 ( 503) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    18426486, /* 23692 ( 503) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
    18439608, /* 23693 ( 503) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
    18426648, /* 23694 ( 503) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
    18439770, /* 23695 ( 503) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
        3362, /* 23696 ( 503) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
       16322, /* 23697 ( 503) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
       16484, /* 23698 ( 504) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
        3200, /* 23699 ( 504) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    52438710, /* 23700 ( 504) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
    34015586, /* 23701 ( 504) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    52451832, /* 23702 ( 504) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
    52438872, /* 23703 ( 504) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
       16322, /* 23704 ( 504) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    52451994, /* 23705 ( 504) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
    18426486, /* 23706 ( 504) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
    18439608, /* 23707 ( 504) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
    18426648, /* 23708 ( 504) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
    34028546, /* 23709 ( 504) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    18439770, /* 23710 ( 504) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
        3362, /* 23711 ( 504) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34015424, /* 23712 ( 504) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    34028708, /* 23713 ( 504) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
       16484, /* 23714 ( 505) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    52438710, /* 23715 ( 505) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
    34015586, /* 23716 ( 505) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    52438872, /* 23717 ( 505) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
    18439608, /* 23718 ( 505) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
    18439770, /* 23719 ( 505) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
    34015424, /* 23720 ( 505) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
       16322, /* 23721 ( 505) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
       16484, /* 23722 ( 506) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
        3200, /* 23723 ( 506) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    52438710, /* 23724 ( 506) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
    52451832, /* 23725 ( 506) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
    52438872, /* 23726 ( 506) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
    52451994, /* 23727 ( 506) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
        3362, /* 23728 ( 506) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
       16322, /* 23729 ( 506) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
       16484, /* 23730 ( 507) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
        3200, /* 23731 ( 507) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34015586, /* 23732 ( 507) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    52451832, /* 23733 ( 507) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
    52438872, /* 23734 ( 507) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
    18426486, /* 23735 ( 507) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
    34028546, /* 23736 ( 507) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    18439770, /* 23737 ( 507) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
       16484, /* 23738 ( 508) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    52438872, /* 23739 ( 508) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
    52451994, /* 23740 ( 508) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
    18426486, /* 23741 ( 508) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
    18439608, /* 23742 ( 508) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
    34028546, /* 23743 ( 508) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
        3362, /* 23744 ( 508) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34015424, /* 23745 ( 508) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
       16484, /* 23746 ( 509) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
        3200, /* 23747 ( 509) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    52438710, /* 23748 ( 509) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
    34015586, /* 23749 ( 509) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    52451994, /* 23750 ( 509) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
    18439608, /* 23751 ( 509) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
    34028546, /* 23752 ( 509) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    18426648, /* 23753 ( 509) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
       16484, /* 23754 ( 510) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
        3200, /* 23755 ( 510) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    35445722, /* 23756 ( 510) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  0] -1 */
    35432762, /* 23757 ( 510) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  0] -1 */
    51021696, /* 23758 ( 510) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  0] -1 */
    51034818, /* 23759 ( 510) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  0] -1 */
    35432600, /* 23760 ( 510) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  0] -1 */
    18426486, /* 23761 ( 510) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
    18439608, /* 23762 ( 510) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
    18426648, /* 23763 ( 510) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
    35445884, /* 23764 ( 510) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  0] -1 */
    18439770, /* 23765 ( 510) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
        3362, /* 23766 ( 510) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    51021534, /* 23767 ( 510) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  0] -1 */
       16322, /* 23768 ( 510) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    51034656, /* 23769 ( 510) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  0] -1 */
       16484, /* 23770 ( 511) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
        3200, /* 23771 ( 511) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34133522, /* 23772 ( 511) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    52556970, /* 23773 ( 511) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    52556808, /* 23774 ( 511) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    34133684, /* 23775 ( 511) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    18426486, /* 23776 ( 511) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
    18439608, /* 23777 ( 511) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
    34146806, /* 23778 ( 511) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    18426648, /* 23779 ( 511) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
    18439770, /* 23780 ( 511) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
        3362, /* 23781 ( 511) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    52569930, /* 23782 ( 511) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    52570092, /* 23783 ( 511) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
       16322, /* 23784 ( 511) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34146644, /* 23785 ( 511) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
       16484, /* 23786 ( 512) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
        3200, /* 23787 ( 512) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    51139634, /* 23788 ( 512) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
    51152756, /* 23789 ( 512) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
    35563980, /* 23790 ( 512) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6] -1 */
       16322, /* 23791 ( 512) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    18426486, /* 23792 ( 512) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
    18439608, /* 23793 ( 512) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
    18426648, /* 23794 ( 512) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
    51139796, /* 23795 ( 512) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
    18439770, /* 23796 ( 512) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
        3362, /* 23797 ( 512) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    51152918, /* 23798 ( 512) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
    35550858, /* 23799 ( 512) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6] -1 */
    35563818, /* 23800 ( 512) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  6] -1 */
    35550696, /* 23801 ( 512) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  6] -1 */
       16484, /* 23802 ( 513) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
        3200, /* 23803 ( 513) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34015422, /* 23804 ( 513) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    34028706, /* 23805 ( 513) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    52438874, /* 23806 ( 513) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
    52451996, /* 23807 ( 513) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
    18426486, /* 23808 ( 513) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
    18439608, /* 23809 ( 513) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
    18426648, /* 23810 ( 513) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
    34028544, /* 23811 ( 513) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    18439770, /* 23812 ( 513) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
        3362, /* 23813 ( 513) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    52438712, /* 23814 ( 513) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
    34015584, /* 23815 ( 513) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
       16322, /* 23816 ( 513) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    52451834, /* 23817 ( 513) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
       16484, /* 23818 ( 514) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
        3200, /* 23819 ( 514) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34133682, /* 23820 ( 514) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
    52556810, /* 23821 ( 514) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    34146642, /* 23822 ( 514) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
    52569932, /* 23823 ( 514) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    52556972, /* 23824 ( 514) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    18426486, /* 23825 ( 514) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
    18439608, /* 23826 ( 514) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
    18426648, /* 23827 ( 514) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
    18439770, /* 23828 ( 514) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
        3362, /* 23829 ( 514) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34146804, /* 23830 ( 514) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
       16322, /* 23831 ( 514) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    52570094, /* 23832 ( 514) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    34133520, /* 23833 ( 514) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
       16484, /* 23834 ( 503) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    18426488, /* 23835 ( 503) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
        3198, /* 23836 ( 503) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    17022432, /* 23837 ( 503) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  0]  1 */
     1420536, /* 23838 ( 503) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  0]  1 */
    18439770, /* 23839 ( 503) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
    17009474, /* 23840 ( 503) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  0]  1 */
     1433498, /* 23841 ( 503) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  0]  1 */
       16484, /* 23842 ( 504) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    18426488, /* 23843 ( 504) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    34015422, /* 23844 ( 504) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    51021698, /* 23845 ( 504) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  0] -1 */
    51034656, /* 23846 ( 504) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  0] -1 */
    35432760, /* 23847 ( 504) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  0] -1 */
     1433498, /* 23848 ( 504) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  0]  1 */
    52451994, /* 23849 ( 504) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
        3198, /* 23850 ( 504) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    17022432, /* 23851 ( 504) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  0]  1 */
     1420536, /* 23852 ( 504) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  0]  1 */
    35445722, /* 23853 ( 504) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  0] -1 */
    18439770, /* 23854 ( 504) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
    17009474, /* 23855 ( 504) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  0]  1 */
    52438712, /* 23856 ( 504) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
    34028708, /* 23857 ( 504) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
       16484, /* 23858 ( 505) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34015422, /* 23859 ( 505) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    51021698, /* 23860 ( 505) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  0] -1 */
    35432760, /* 23861 ( 505) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  0] -1 */
    17022432, /* 23862 ( 505) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  0]  1 */
    18439770, /* 23863 ( 505) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
    52438712, /* 23864 ( 505) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
     1433498, /* 23865 ( 505) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  0]  1 */
       16484, /* 23866 ( 506) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    18426488, /* 23867 ( 506) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    34015422, /* 23868 ( 506) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    51034656, /* 23869 ( 506) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  0] -1 */
    35432760, /* 23870 ( 506) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  0] -1 */
    52451994, /* 23871 ( 506) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
    17009474, /* 23872 ( 506) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  0]  1 */
     1433498, /* 23873 ( 506) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  0]  1 */
       16484, /* 23874 ( 507) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    18426488, /* 23875 ( 507) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    51021698, /* 23876 ( 507) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  0] -1 */
    51034656, /* 23877 ( 507) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  0] -1 */
    35432760, /* 23878 ( 507) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  0] -1 */
        3198, /* 23879 ( 507) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    35445722, /* 23880 ( 507) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  0] -1 */
    18439770, /* 23881 ( 507) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
       16484, /* 23882 ( 508) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    35432760, /* 23883 ( 508) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  0] -1 */
    52451994, /* 23884 ( 508) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
        3198, /* 23885 ( 508) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    17022432, /* 23886 ( 508) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  0]  1 */
    35445722, /* 23887 ( 508) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  0] -1 */
    17009474, /* 23888 ( 508) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  0]  1 */
    52438712, /* 23889 ( 508) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
       16484, /* 23890 ( 509) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    18426488, /* 23891 ( 509) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    34015422, /* 23892 ( 509) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    51021698, /* 23893 ( 509) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  0] -1 */
    52451994, /* 23894 ( 509) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
    17022432, /* 23895 ( 509) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  0]  1 */
    35445722, /* 23896 ( 509) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  0] -1 */
     1420536, /* 23897 ( 509) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  0]  1 */
       16484, /* 23898 ( 510) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    18426488, /* 23899 ( 510) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    34028546, /* 23900 ( 510) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    52438874, /* 23901 ( 510) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
    34015584, /* 23902 ( 510) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    51034818, /* 23903 ( 510) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  0] -1 */
    51021536, /* 23904 ( 510) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  0] -1 */
        3198, /* 23905 ( 510) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    17022432, /* 23906 ( 510) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  0]  1 */
     1420536, /* 23907 ( 510) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  0]  1 */
    35445884, /* 23908 ( 510) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  0] -1 */
    18439770, /* 23909 ( 510) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
    17009474, /* 23910 ( 510) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  0]  1 */
    35432598, /* 23911 ( 510) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  0] -1 */
     1433498, /* 23912 ( 510) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  0]  1 */
    52451832, /* 23913 ( 510) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
       16484, /* 23914 ( 511) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    18426488, /* 23915 ( 511) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    52556810, /* 23916 ( 511) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    35550858, /* 23917 ( 511) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6] -1 */
    34133520, /* 23918 ( 511) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
    51139796, /* 23919 ( 511) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
        3198, /* 23920 ( 511) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    17022432, /* 23921 ( 511) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  0]  1 */
    34146806, /* 23922 ( 511) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
     1420536, /* 23923 ( 511) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  0]  1 */
    18439770, /* 23924 ( 511) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
    17009474, /* 23925 ( 511) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  0]  1 */
    51152754, /* 23926 ( 511) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  6] -1 */
    52570092, /* 23927 ( 511) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
     1433498, /* 23928 ( 511) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  0]  1 */
    35563820, /* 23929 ( 511) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
       16484, /* 23930 ( 512) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    18426488, /* 23931 ( 512) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    35550698, /* 23932 ( 512) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
    52569932, /* 23933 ( 512) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    35563980, /* 23934 ( 512) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6] -1 */
     1433498, /* 23935 ( 512) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  0]  1 */
        3198, /* 23936 ( 512) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    17022432, /* 23937 ( 512) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  0]  1 */
     1420536, /* 23938 ( 512) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  0]  1 */
    34133684, /* 23939 ( 512) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    18439770, /* 23940 ( 512) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
    17009474, /* 23941 ( 512) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  0]  1 */
    51152918, /* 23942 ( 512) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
    52556970, /* 23943 ( 512) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    34146642, /* 23944 ( 512) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
    51139632, /* 23945 ( 512) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  6] -1 */
       16484, /* 23946 ( 513) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    18426488, /* 23947 ( 513) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    52438710, /* 23948 ( 513) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
    34028706, /* 23949 ( 513) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    35432762, /* 23950 ( 513) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  0] -1 */
    52451996, /* 23951 ( 513) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
        3198, /* 23952 ( 513) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    17022432, /* 23953 ( 513) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  0]  1 */
     1420536, /* 23954 ( 513) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  0]  1 */
    35445720, /* 23955 ( 513) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  0] -1 */
    18439770, /* 23956 ( 513) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
    17009474, /* 23957 ( 513) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  0]  1 */
    34015424, /* 23958 ( 513) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    51021696, /* 23959 ( 513) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  0] -1 */
     1433498, /* 23960 ( 513) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  0]  1 */
    51034658, /* 23961 ( 513) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  0] -1 */
       16484, /* 23962 ( 514) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    18426488, /* 23963 ( 514) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    51139794, /* 23964 ( 514) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6] -1 */
    34133522, /* 23965 ( 514) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    35563818, /* 23966 ( 514) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  6] -1 */
    51152756, /* 23967 ( 514) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
    35550860, /* 23968 ( 514) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
        3198, /* 23969 ( 514) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    17022432, /* 23970 ( 514) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  0]  1 */
     1420536, /* 23971 ( 514) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  0]  1 */
    18439770, /* 23972 ( 514) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
    17009474, /* 23973 ( 514) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  0]  1 */
    34146804, /* 23974 ( 514) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
     1433498, /* 23975 ( 514) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  0]  1 */
    52570094, /* 23976 ( 514) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    52556808, /* 23977 ( 514) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
       16484, /* 23978 ( 503) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
       16320, /* 23979 ( 503) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
     1538472, /* 23980 ( 503) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
     1538634, /* 23981 ( 503) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
     1538474, /* 23982 ( 503) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
     1538636, /* 23983 ( 503) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
       16322, /* 23984 ( 503) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
       16482, /* 23985 ( 503) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
       16484, /* 23986 ( 504) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
       16320, /* 23987 ( 504) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    35550696, /* 23988 ( 504) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  6] -1 */
    34028546, /* 23989 ( 504) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    35550858, /* 23990 ( 504) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6] -1 */
    35550698, /* 23991 ( 504) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
       16482, /* 23992 ( 504) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    35550860, /* 23993 ( 504) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
     1538472, /* 23994 ( 504) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
     1538634, /* 23995 ( 504) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
     1538474, /* 23996 ( 504) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
    34028706, /* 23997 ( 504) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
     1538636, /* 23998 ( 504) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
       16322, /* 23999 ( 504) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34028544, /* 24000 ( 504) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    34028708, /* 24001 ( 504) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
       16484, /* 24002 ( 505) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    35550696, /* 24003 ( 505) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  6] -1 */
    34028546, /* 24004 ( 505) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    35550698, /* 24005 ( 505) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
     1538634, /* 24006 ( 505) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
     1538636, /* 24007 ( 505) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
    34028544, /* 24008 ( 505) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
       16482, /* 24009 ( 505) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
       16484, /* 24010 ( 506) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
       16320, /* 24011 ( 506) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    35550696, /* 24012 ( 506) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  6] -1 */
    35550858, /* 24013 ( 506) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6] -1 */
    35550698, /* 24014 ( 506) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
    35550860, /* 24015 ( 506) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
       16322, /* 24016 ( 506) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
       16482, /* 24017 ( 506) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
       16484, /* 24018 ( 507) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
       16320, /* 24019 ( 507) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    34028546, /* 24020 ( 507) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    35550858, /* 24021 ( 507) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6] -1 */
    35550698, /* 24022 ( 507) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
     1538472, /* 24023 ( 507) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
    34028706, /* 24024 ( 507) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
     1538636, /* 24025 ( 507) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
       16484, /* 24026 ( 508) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    35550698, /* 24027 ( 508) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
    35550860, /* 24028 ( 508) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
     1538472, /* 24029 ( 508) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
     1538634, /* 24030 ( 508) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
    34028706, /* 24031 ( 508) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
       16322, /* 24032 ( 508) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34028544, /* 24033 ( 508) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
       16484, /* 24034 ( 509) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
       16320, /* 24035 ( 509) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    35550696, /* 24036 ( 509) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  6] -1 */
    34028546, /* 24037 ( 509) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    35550860, /* 24038 ( 509) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
     1538634, /* 24039 ( 509) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
    34028706, /* 24040 ( 509) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
     1538474, /* 24041 ( 509) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
       16484, /* 24042 ( 510) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
       16320, /* 24043 ( 510) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    34146804, /* 24044 ( 510) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
    34146644, /* 24045 ( 510) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    35432600, /* 24046 ( 510) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  0] -1 */
    35432762, /* 24047 ( 510) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  0] -1 */
    34146642, /* 24048 ( 510) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
     1538472, /* 24049 ( 510) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
     1538634, /* 24050 ( 510) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
     1538474, /* 24051 ( 510) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
    34146806, /* 24052 ( 510) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
     1538636, /* 24053 ( 510) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
       16322, /* 24054 ( 510) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    35432598, /* 24055 ( 510) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  0] -1 */
       16482, /* 24056 ( 510) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    35432760, /* 24057 ( 510) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  0] -1 */
       16484, /* 24058 ( 511) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
       16320, /* 24059 ( 511) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    51034656, /* 24060 ( 511) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  0] -1 */
    52556810, /* 24061 ( 511) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    52556808, /* 24062 ( 511) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    51034658, /* 24063 ( 511) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  0] -1 */
     1538472, /* 24064 ( 511) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
     1538634, /* 24065 ( 511) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
    51034820, /* 24066 ( 511) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  0] -1 */
     1538474, /* 24067 ( 511) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
     1538636, /* 24068 ( 511) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
       16322, /* 24069 ( 511) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    52556970, /* 24070 ( 511) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    52556972, /* 24071 ( 511) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
       16482, /* 24072 ( 511) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    51034818, /* 24073 ( 511) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  0] -1 */
       16484, /* 24074 ( 512) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
       16320, /* 24075 ( 512) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    52451832, /* 24076 ( 512) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
    52451994, /* 24077 ( 512) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
    51139796, /* 24078 ( 512) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
       16482, /* 24079 ( 512) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
     1538472, /* 24080 ( 512) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
     1538634, /* 24081 ( 512) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
     1538474, /* 24082 ( 512) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
    52451834, /* 24083 ( 512) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
     1538636, /* 24084 ( 512) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
       16322, /* 24085 ( 512) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    52451996, /* 24086 ( 512) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
    51139634, /* 24087 ( 512) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
    51139794, /* 24088 ( 512) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6] -1 */
    51139632, /* 24089 ( 512) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  6] -1 */
       16484, /* 24090 ( 513) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
       16320, /* 24091 ( 513) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    34015422, /* 24092 ( 513) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    34015586, /* 24093 ( 513) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    35563820, /* 24094 ( 513) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
    35563982, /* 24095 ( 513) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
     1538472, /* 24096 ( 513) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
     1538634, /* 24097 ( 513) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
     1538474, /* 24098 ( 513) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
    34015584, /* 24099 ( 513) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
     1538636, /* 24100 ( 513) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
       16322, /* 24101 ( 513) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    35563818, /* 24102 ( 513) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  6] -1 */
    34015424, /* 24103 ( 513) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
       16482, /* 24104 ( 513) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    35563980, /* 24105 ( 513) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6] -1 */
       16484, /* 24106 ( 514) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
       16320, /* 24107 ( 514) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    51021536, /* 24108 ( 514) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  0] -1 */
    52569930, /* 24109 ( 514) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    51021696, /* 24110 ( 514) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  0] -1 */
    52570092, /* 24111 ( 514) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    52569932, /* 24112 ( 514) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
     1538472, /* 24113 ( 514) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
     1538634, /* 24114 ( 514) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
     1538474, /* 24115 ( 514) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
     1538636, /* 24116 ( 514) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
       16322, /* 24117 ( 514) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    51021698, /* 24118 ( 514) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  0] -1 */
       16482, /* 24119 ( 514) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    52570094, /* 24120 ( 514) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    51021534, /* 24121 ( 514) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  0] -1 */
       16484, /* 24122 ( 503) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
     1551594, /* 24123 ( 503) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
        3198, /* 24124 ( 503) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
     1420536, /* 24125 ( 503) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  0]  1 */
      121298, /* 24126 ( 503) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6]  1 */
     1538636, /* 24127 ( 503) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
     1433498, /* 24128 ( 503) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  0]  1 */
      134580, /* 24129 ( 503) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  6]  1 */
       16484, /* 24130 ( 504) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
     1551594, /* 24131 ( 504) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
    34015422, /* 24132 ( 504) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    35445722, /* 24133 ( 504) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  0] -1 */
    35432760, /* 24134 ( 504) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  0] -1 */
    34133522, /* 24135 ( 504) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
      134580, /* 24136 ( 504) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  6]  1 */
    35550860, /* 24137 ( 504) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
        3198, /* 24138 ( 504) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
     1420536, /* 24139 ( 504) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  0]  1 */
      121298, /* 24140 ( 504) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6]  1 */
    34146804, /* 24141 ( 504) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
     1538636, /* 24142 ( 504) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
     1433498, /* 24143 ( 504) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  0]  1 */
    35563818, /* 24144 ( 504) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  6] -1 */
    34028708, /* 24145 ( 504) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
       16484, /* 24146 ( 505) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34015422, /* 24147 ( 505) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    35445722, /* 24148 ( 505) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  0] -1 */
    34133522, /* 24149 ( 505) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
     1420536, /* 24150 ( 505) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  0]  1 */
     1538636, /* 24151 ( 505) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
    35563818, /* 24152 ( 505) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  6] -1 */
      134580, /* 24153 ( 505) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  6]  1 */
       16484, /* 24154 ( 506) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
     1551594, /* 24155 ( 506) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
    34015422, /* 24156 ( 506) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    35432760, /* 24157 ( 506) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  0] -1 */
    34133522, /* 24158 ( 506) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    35550860, /* 24159 ( 506) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
     1433498, /* 24160 ( 506) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  0]  1 */
      134580, /* 24161 ( 506) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  6]  1 */
       16484, /* 24162 ( 507) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
     1551594, /* 24163 ( 507) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
    35445722, /* 24164 ( 507) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  0] -1 */
    35432760, /* 24165 ( 507) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  0] -1 */
    34133522, /* 24166 ( 507) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
        3198, /* 24167 ( 507) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    34146804, /* 24168 ( 507) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
     1538636, /* 24169 ( 507) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
       16484, /* 24170 ( 508) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34133522, /* 24171 ( 508) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    35550860, /* 24172 ( 508) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
        3198, /* 24173 ( 508) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
     1420536, /* 24174 ( 508) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  0]  1 */
    34146804, /* 24175 ( 508) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
     1433498, /* 24176 ( 508) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  0]  1 */
    35563818, /* 24177 ( 508) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  6] -1 */
       16484, /* 24178 ( 509) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
     1551594, /* 24179 ( 509) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
    34015422, /* 24180 ( 509) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    35445722, /* 24181 ( 509) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  0] -1 */
    35550860, /* 24182 ( 509) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
     1420536, /* 24183 ( 509) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  0]  1 */
    34146804, /* 24184 ( 509) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
      121298, /* 24185 ( 509) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6]  1 */
       16484, /* 24186 ( 510) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
     1551594, /* 24187 ( 510) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
    34028706, /* 24188 ( 510) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    35563820, /* 24189 ( 510) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
    34015424, /* 24190 ( 510) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    35432762, /* 24191 ( 510) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  0] -1 */
    35445720, /* 24192 ( 510) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  0] -1 */
        3198, /* 24193 ( 510) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
     1420536, /* 24194 ( 510) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  0]  1 */
      121298, /* 24195 ( 510) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6]  1 */
    34146806, /* 24196 ( 510) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
     1538636, /* 24197 ( 510) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
     1433498, /* 24198 ( 510) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  0]  1 */
    34133520, /* 24199 ( 510) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
      134580, /* 24200 ( 510) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  6]  1 */
    35550858, /* 24201 ( 510) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6] -1 */
       16484, /* 24202 ( 511) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
     1551594, /* 24203 ( 511) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
    52569930, /* 24204 ( 511) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    51139634, /* 24205 ( 511) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
    51021534, /* 24206 ( 511) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  0] -1 */
    52451834, /* 24207 ( 511) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
        3198, /* 24208 ( 511) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
     1420536, /* 24209 ( 511) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  0]  1 */
    51034820, /* 24210 ( 511) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  0] -1 */
      121298, /* 24211 ( 511) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6]  1 */
     1538636, /* 24212 ( 511) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
     1433498, /* 24213 ( 511) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  0]  1 */
    52438872, /* 24214 ( 511) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
    52556972, /* 24215 ( 511) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
      134580, /* 24216 ( 511) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  6]  1 */
    51152916, /* 24217 ( 511) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6] -1 */
       16484, /* 24218 ( 512) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
     1551594, /* 24219 ( 512) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
    51152754, /* 24220 ( 512) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  6] -1 */
    52570092, /* 24221 ( 512) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    51139796, /* 24222 ( 512) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
      134580, /* 24223 ( 512) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  6]  1 */
        3198, /* 24224 ( 512) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
     1420536, /* 24225 ( 512) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  0]  1 */
      121298, /* 24226 ( 512) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6]  1 */
    51034658, /* 24227 ( 512) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  0] -1 */
     1538636, /* 24228 ( 512) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
     1433498, /* 24229 ( 512) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  0]  1 */
    52451996, /* 24230 ( 512) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
    52556810, /* 24231 ( 512) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    51021696, /* 24232 ( 512) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  0] -1 */
    52438710, /* 24233 ( 512) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
       16484, /* 24234 ( 513) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
     1551594, /* 24235 ( 513) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
    35550696, /* 24236 ( 513) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  6] -1 */
    34015586, /* 24237 ( 513) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    34146644, /* 24238 ( 513) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    35563982, /* 24239 ( 513) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
        3198, /* 24240 ( 513) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
     1420536, /* 24241 ( 513) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  0]  1 */
      121298, /* 24242 ( 513) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6]  1 */
    34133682, /* 24243 ( 513) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
     1538636, /* 24244 ( 513) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
     1433498, /* 24245 ( 513) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  0]  1 */
    34028544, /* 24246 ( 513) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    35432600, /* 24247 ( 513) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  0] -1 */
      134580, /* 24248 ( 513) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  6]  1 */
    35445882, /* 24249 ( 513) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  0] -1 */
       16484, /* 24250 ( 514) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
     1551594, /* 24251 ( 514) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
    52438712, /* 24252 ( 514) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
    51034656, /* 24253 ( 514) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  0] -1 */
    51139794, /* 24254 ( 514) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6] -1 */
    52451994, /* 24255 ( 514) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
    51152756, /* 24256 ( 514) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
        3198, /* 24257 ( 514) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
     1420536, /* 24258 ( 514) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  0]  1 */
      121298, /* 24259 ( 514) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6]  1 */
     1538636, /* 24260 ( 514) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
     1433498, /* 24261 ( 514) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  0]  1 */
    51021698, /* 24262 ( 514) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  0] -1 */
      134580, /* 24263 ( 514) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  6]  1 */
    52570094, /* 24264 ( 514) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    52556808, /* 24265 ( 514) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
       16484, /* 24266 ( 503) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
        3360, /* 24267 ( 503) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    17127408, /* 24268 ( 503) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  6]  1 */
    17127410, /* 24269 ( 503) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
    17140530, /* 24270 ( 503) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  6]  1 */
    17140532, /* 24271 ( 503) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
       16482, /* 24272 ( 503) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
        3362, /* 24273 ( 503) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
       16484, /* 24274 ( 504) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
        3360, /* 24275 ( 504) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    51139632, /* 24276 ( 504) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  6] -1 */
    34028706, /* 24277 ( 504) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    51139634, /* 24278 ( 504) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
    51152754, /* 24279 ( 504) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  6] -1 */
        3362, /* 24280 ( 504) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    51152756, /* 24281 ( 504) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
    17127408, /* 24282 ( 504) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  6]  1 */
    17127410, /* 24283 ( 504) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
    17140530, /* 24284 ( 504) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  6]  1 */
    34015586, /* 24285 ( 504) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    17140532, /* 24286 ( 504) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
       16482, /* 24287 ( 504) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    34015584, /* 24288 ( 504) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    34028708, /* 24289 ( 504) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
       16484, /* 24290 ( 505) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    51139632, /* 24291 ( 505) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  6] -1 */
    34028706, /* 24292 ( 505) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    51152754, /* 24293 ( 505) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  6] -1 */
    17127410, /* 24294 ( 505) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
    17140532, /* 24295 ( 505) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
    34015584, /* 24296 ( 505) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
        3362, /* 24297 ( 505) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
       16484, /* 24298 ( 506) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
        3360, /* 24299 ( 506) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    51139632, /* 24300 ( 506) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  6] -1 */
    51139634, /* 24301 ( 506) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
    51152754, /* 24302 ( 506) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  6] -1 */
    51152756, /* 24303 ( 506) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
       16482, /* 24304 ( 506) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
        3362, /* 24305 ( 506) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
       16484, /* 24306 ( 507) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
        3360, /* 24307 ( 507) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    34028706, /* 24308 ( 507) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    51139634, /* 24309 ( 507) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
    51152754, /* 24310 ( 507) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  6] -1 */
    17127408, /* 24311 ( 507) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  6]  1 */
    34015586, /* 24312 ( 507) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    17140532, /* 24313 ( 507) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
       16484, /* 24314 ( 508) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    51152754, /* 24315 ( 508) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  6] -1 */
    51152756, /* 24316 ( 508) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
    17127408, /* 24317 ( 508) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  6]  1 */
    17127410, /* 24318 ( 508) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
    34015586, /* 24319 ( 508) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
       16482, /* 24320 ( 508) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    34015584, /* 24321 ( 508) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
       16484, /* 24322 ( 509) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
        3360, /* 24323 ( 509) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    51139632, /* 24324 ( 509) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  6] -1 */
    34028706, /* 24325 ( 509) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    51152756, /* 24326 ( 509) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
    17127410, /* 24327 ( 509) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
    34015586, /* 24328 ( 509) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    17140530, /* 24329 ( 509) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  6]  1 */
       16484, /* 24330 ( 510) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
        3360, /* 24331 ( 510) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    51021698, /* 24332 ( 510) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  0] -1 */
    51034818, /* 24333 ( 510) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  0] -1 */
    34146642, /* 24334 ( 510) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
    34146644, /* 24335 ( 510) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    51021696, /* 24336 ( 510) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  0] -1 */
    17127408, /* 24337 ( 510) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  6]  1 */
    17127410, /* 24338 ( 510) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
    17140530, /* 24339 ( 510) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  6]  1 */
    51034820, /* 24340 ( 510) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  0] -1 */
    17140532, /* 24341 ( 510) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
       16482, /* 24342 ( 510) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    34133520, /* 24343 ( 510) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
        3362, /* 24344 ( 510) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34133522, /* 24345 ( 510) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
       16484, /* 24346 ( 511) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
        3360, /* 24347 ( 511) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    35432760, /* 24348 ( 511) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  0] -1 */
    52569930, /* 24349 ( 511) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    52556808, /* 24350 ( 511) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    35445882, /* 24351 ( 511) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  0] -1 */
    17127408, /* 24352 ( 511) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  6]  1 */
    17127410, /* 24353 ( 511) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
    35445884, /* 24354 ( 511) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  0] -1 */
    17140530, /* 24355 ( 511) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  6]  1 */
    17140532, /* 24356 ( 511) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
       16482, /* 24357 ( 511) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    52556810, /* 24358 ( 511) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    52569932, /* 24359 ( 511) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
        3362, /* 24360 ( 511) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    35432762, /* 24361 ( 511) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  0] -1 */
       16484, /* 24362 ( 512) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
        3360, /* 24363 ( 512) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    35550858, /* 24364 ( 512) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6] -1 */
    35550860, /* 24365 ( 512) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
    52451834, /* 24366 ( 512) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
        3362, /* 24367 ( 512) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    17127408, /* 24368 ( 512) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  6]  1 */
    17127410, /* 24369 ( 512) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
    17140530, /* 24370 ( 512) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  6]  1 */
    35563980, /* 24371 ( 512) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6] -1 */
    17140532, /* 24372 ( 512) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
       16482, /* 24373 ( 512) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    35563982, /* 24374 ( 512) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
    52451832, /* 24375 ( 512) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
    52438712, /* 24376 ( 512) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
    52438710, /* 24377 ( 512) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
       16484, /* 24378 ( 513) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
        3360, /* 24379 ( 513) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    34015422, /* 24380 ( 513) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    34028546, /* 24381 ( 513) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    51152916, /* 24382 ( 513) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6] -1 */
    51152918, /* 24383 ( 513) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
    17127408, /* 24384 ( 513) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  6]  1 */
    17127410, /* 24385 ( 513) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
    17140530, /* 24386 ( 513) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  6]  1 */
    34015424, /* 24387 ( 513) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    17140532, /* 24388 ( 513) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
       16482, /* 24389 ( 513) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    51139794, /* 24390 ( 513) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6] -1 */
    34028544, /* 24391 ( 513) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
        3362, /* 24392 ( 513) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    51139796, /* 24393 ( 513) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
       16484, /* 24394 ( 514) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
        3360, /* 24395 ( 514) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    35445720, /* 24396 ( 514) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  0] -1 */
    52556970, /* 24397 ( 514) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    35432600, /* 24398 ( 514) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  0] -1 */
    52556972, /* 24399 ( 514) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    52570092, /* 24400 ( 514) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    17127408, /* 24401 ( 514) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  6]  1 */
    17127410, /* 24402 ( 514) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
    17140530, /* 24403 ( 514) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  6]  1 */
    17140532, /* 24404 ( 514) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
       16482, /* 24405 ( 514) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    35445722, /* 24406 ( 514) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  0] -1 */
        3362, /* 24407 ( 514) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    52570094, /* 24408 ( 514) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    35432598, /* 24409 ( 514) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  0] -1 */
       16484, /* 24410 ( 503) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    17127570, /* 24411 ( 503) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6]  1 */
        3198, /* 24412 ( 503) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
      121298, /* 24413 ( 503) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6]  1 */
    17022432, /* 24414 ( 503) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  0]  1 */
    17140532, /* 24415 ( 503) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
      134580, /* 24416 ( 503) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  6]  1 */
    17009474, /* 24417 ( 503) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  0]  1 */
       16484, /* 24418 ( 504) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    17127570, /* 24419 ( 504) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6]  1 */
    34015422, /* 24420 ( 504) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    34146804, /* 24421 ( 504) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
    34133522, /* 24422 ( 504) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    51034656, /* 24423 ( 504) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  0] -1 */
    17009474, /* 24424 ( 504) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  0]  1 */
    51152756, /* 24425 ( 504) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
        3198, /* 24426 ( 504) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
      121298, /* 24427 ( 504) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6]  1 */
    17022432, /* 24428 ( 504) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  0]  1 */
    51021698, /* 24429 ( 504) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  0] -1 */
    17140532, /* 24430 ( 504) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
      134580, /* 24431 ( 504) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  6]  1 */
    51139794, /* 24432 ( 504) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6] -1 */
    34028708, /* 24433 ( 504) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
       16484, /* 24434 ( 505) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34015422, /* 24435 ( 505) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    34146804, /* 24436 ( 505) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
    51034656, /* 24437 ( 505) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  0] -1 */
      121298, /* 24438 ( 505) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6]  1 */
    17140532, /* 24439 ( 505) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
    51139794, /* 24440 ( 505) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6] -1 */
    17009474, /* 24441 ( 505) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  0]  1 */
       16484, /* 24442 ( 506) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    17127570, /* 24443 ( 506) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6]  1 */
    34015422, /* 24444 ( 506) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    34133522, /* 24445 ( 506) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    51034656, /* 24446 ( 506) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  0] -1 */
    51152756, /* 24447 ( 506) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
      134580, /* 24448 ( 506) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  6]  1 */
    17009474, /* 24449 ( 506) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  0]  1 */
       16484, /* 24450 ( 507) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    17127570, /* 24451 ( 507) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6]  1 */
    34146804, /* 24452 ( 507) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
    34133522, /* 24453 ( 507) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    51034656, /* 24454 ( 507) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  0] -1 */
        3198, /* 24455 ( 507) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    51021698, /* 24456 ( 507) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  0] -1 */
    17140532, /* 24457 ( 507) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
       16484, /* 24458 ( 508) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    51034656, /* 24459 ( 508) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  0] -1 */
    51152756, /* 24460 ( 508) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
        3198, /* 24461 ( 508) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
      121298, /* 24462 ( 508) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6]  1 */
    51021698, /* 24463 ( 508) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  0] -1 */
      134580, /* 24464 ( 508) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  6]  1 */
    51139794, /* 24465 ( 508) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6] -1 */
       16484, /* 24466 ( 509) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    17127570, /* 24467 ( 509) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6]  1 */
    34015422, /* 24468 ( 509) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    34146804, /* 24469 ( 509) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
    51152756, /* 24470 ( 509) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
      121298, /* 24471 ( 509) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6]  1 */
    51021698, /* 24472 ( 509) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  0] -1 */
    17022432, /* 24473 ( 509) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  0]  1 */
       16484, /* 24474 ( 510) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    17127570, /* 24475 ( 510) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6]  1 */
    34015586, /* 24476 ( 510) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    51152916, /* 24477 ( 510) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6] -1 */
    34028544, /* 24478 ( 510) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    34146644, /* 24479 ( 510) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    34133682, /* 24480 ( 510) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
        3198, /* 24481 ( 510) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
      121298, /* 24482 ( 510) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6]  1 */
    17022432, /* 24483 ( 510) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  0]  1 */
    51034820, /* 24484 ( 510) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  0] -1 */
    17140532, /* 24485 ( 510) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
      134580, /* 24486 ( 510) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  6]  1 */
    51021534, /* 24487 ( 510) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  0] -1 */
    17009474, /* 24488 ( 510) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  0]  1 */
    51139634, /* 24489 ( 510) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
       16484, /* 24490 ( 511) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    17127570, /* 24491 ( 511) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6]  1 */
    52556970, /* 24492 ( 511) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    52451832, /* 24493 ( 511) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
    35432598, /* 24494 ( 511) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  0] -1 */
    35563980, /* 24495 ( 511) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6] -1 */
        3198, /* 24496 ( 511) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
      121298, /* 24497 ( 511) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6]  1 */
    35445884, /* 24498 ( 511) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  0] -1 */
    17022432, /* 24499 ( 511) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  0]  1 */
    17140532, /* 24500 ( 511) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
      134580, /* 24501 ( 511) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  6]  1 */
    35550698, /* 24502 ( 511) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
    52569932, /* 24503 ( 511) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    17009474, /* 24504 ( 511) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  0]  1 */
    52438874, /* 24505 ( 511) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
       16484, /* 24506 ( 512) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    17127570, /* 24507 ( 512) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6]  1 */
    52438872, /* 24508 ( 512) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
    52556972, /* 24509 ( 512) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    52451834, /* 24510 ( 512) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
    17009474, /* 24511 ( 512) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  0]  1 */
        3198, /* 24512 ( 512) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
      121298, /* 24513 ( 512) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6]  1 */
    17022432, /* 24514 ( 512) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  0]  1 */
    35445882, /* 24515 ( 512) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  0] -1 */
    17140532, /* 24516 ( 512) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
      134580, /* 24517 ( 512) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  6]  1 */
    35563982, /* 24518 ( 512) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
    52569930, /* 24519 ( 512) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    35432600, /* 24520 ( 512) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  0] -1 */
    35550696, /* 24521 ( 512) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  6] -1 */
       16484, /* 24522 ( 513) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    17127570, /* 24523 ( 513) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6]  1 */
    51139632, /* 24524 ( 513) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  6] -1 */
    34028546, /* 24525 ( 513) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    51034818, /* 24526 ( 513) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  0] -1 */
    51152918, /* 24527 ( 513) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
        3198, /* 24528 ( 513) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
      121298, /* 24529 ( 513) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6]  1 */
    17022432, /* 24530 ( 513) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  0]  1 */
    51021536, /* 24531 ( 513) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  0] -1 */
    17140532, /* 24532 ( 513) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
      134580, /* 24533 ( 513) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  6]  1 */
    34015584, /* 24534 ( 513) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    34146642, /* 24535 ( 513) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
    17009474, /* 24536 ( 513) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  0]  1 */
    34133684, /* 24537 ( 513) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
       16484, /* 24538 ( 514) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    17127570, /* 24539 ( 514) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6]  1 */
    35563818, /* 24540 ( 514) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  6] -1 */
    35432760, /* 24541 ( 514) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  0] -1 */
    52438712, /* 24542 ( 514) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
    35550860, /* 24543 ( 514) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
    52451994, /* 24544 ( 514) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
        3198, /* 24545 ( 514) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
      121298, /* 24546 ( 514) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6]  1 */
    17022432, /* 24547 ( 514) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  0]  1 */
    17140532, /* 24548 ( 514) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
      134580, /* 24549 ( 514) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  6]  1 */
    35445722, /* 24550 ( 514) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  0] -1 */
    17009474, /* 24551 ( 514) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  0]  1 */
    52570094, /* 24552 ( 514) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    52556808, /* 24553 ( 514) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
       16484, /* 24554 ( 515) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    18557868, /* 24555 ( 515) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
      121458, /* 24556 ( 515) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  6]  1 */
    18439608, /* 24557 ( 515) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
    18426650, /* 24558 ( 515) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
        3198, /* 24559 ( 515) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    18544586, /* 24560 ( 515) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
      134420, /* 24561 ( 515) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6]  1 */
       16484, /* 24562 ( 516) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    18557868, /* 24563 ( 516) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
    34015422, /* 24564 ( 516) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    18439608, /* 24565 ( 516) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
      121458, /* 24566 ( 516) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  6]  1 */
    52556810, /* 24567 ( 516) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    52438874, /* 24568 ( 516) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
    34146644, /* 24569 ( 516) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    18426650, /* 24570 ( 516) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
        3198, /* 24571 ( 516) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    18544586, /* 24572 ( 516) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    52570092, /* 24573 ( 516) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    34133682, /* 24574 ( 516) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
      134420, /* 24575 ( 516) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6]  1 */
    34028708, /* 24576 ( 516) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    52451832, /* 24577 ( 516) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
       16484, /* 24578 ( 517) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    18557868, /* 24579 ( 517) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
    34015422, /* 24580 ( 517) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    52556810, /* 24581 ( 517) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    18439608, /* 24582 ( 517) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
    52438874, /* 24583 ( 517) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
    34133682, /* 24584 ( 517) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
      134420, /* 24585 ( 517) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6]  1 */
       16484, /* 24586 ( 518) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    18557868, /* 24587 ( 518) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
    34015422, /* 24588 ( 518) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    52556810, /* 24589 ( 518) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
      121458, /* 24590 ( 518) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  6]  1 */
    34146644, /* 24591 ( 518) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    18426650, /* 24592 ( 518) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    52451832, /* 24593 ( 518) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
       16484, /* 24594 ( 519) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34015422, /* 24595 ( 519) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    18426650, /* 24596 ( 519) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    18544586, /* 24597 ( 519) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    34133682, /* 24598 ( 519) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
      134420, /* 24599 ( 519) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6]  1 */
    52570092, /* 24600 ( 519) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    52451832, /* 24601 ( 519) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
       16484, /* 24602 ( 520) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    18557868, /* 24603 ( 520) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
    52438874, /* 24604 ( 520) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
    34146644, /* 24605 ( 520) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
        3198, /* 24606 ( 520) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    18544586, /* 24607 ( 520) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    34133682, /* 24608 ( 520) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
    52451832, /* 24609 ( 520) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
       16484, /* 24610 ( 521) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    52556810, /* 24611 ( 521) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    18439608, /* 24612 ( 521) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
    34146644, /* 24613 ( 521) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    18426650, /* 24614 ( 521) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
        3198, /* 24615 ( 521) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    34133682, /* 24616 ( 521) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
    52570092, /* 24617 ( 521) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
       16484, /* 24618 ( 522) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    52556810, /* 24619 ( 522) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
      121458, /* 24620 ( 522) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  6]  1 */
    52438874, /* 24621 ( 522) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
        3198, /* 24622 ( 522) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
      134420, /* 24623 ( 522) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6]  1 */
    52570092, /* 24624 ( 522) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    52451832, /* 24625 ( 522) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
       16484, /* 24626 ( 523) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34015422, /* 24627 ( 523) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    18439608, /* 24628 ( 523) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
      121458, /* 24629 ( 523) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  6]  1 */
    52438874, /* 24630 ( 523) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
    34146644, /* 24631 ( 523) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    18544586, /* 24632 ( 523) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    52570092, /* 24633 ( 523) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
       16484, /* 24634 ( 524) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    18557868, /* 24635 ( 524) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
    51139794, /* 24636 ( 524) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6] -1 */
      121458, /* 24637 ( 524) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  6]  1 */
    18439608, /* 24638 ( 524) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
    51152756, /* 24639 ( 524) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
    51034820, /* 24640 ( 524) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  0] -1 */
    35563980, /* 24641 ( 524) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6] -1 */
    35432762, /* 24642 ( 524) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  0] -1 */
    18426650, /* 24643 ( 524) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
        3198, /* 24644 ( 524) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    18544586, /* 24645 ( 524) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    51021534, /* 24646 ( 524) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  0] -1 */
    35445720, /* 24647 ( 524) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  0] -1 */
    35550698, /* 24648 ( 524) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
      134420, /* 24649 ( 524) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6]  1 */
       16484, /* 24650 ( 525) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    18557868, /* 24651 ( 525) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
      121458, /* 24652 ( 525) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  6]  1 */
    18439608, /* 24653 ( 525) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
    35550858, /* 24654 ( 525) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6] -1 */
    51021698, /* 24655 ( 525) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  0] -1 */
    51034656, /* 24656 ( 525) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  0] -1 */
    51139634, /* 24657 ( 525) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
      134420, /* 24658 ( 525) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6]  1 */
    18426650, /* 24659 ( 525) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
        3198, /* 24660 ( 525) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    18544586, /* 24661 ( 525) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    35445884, /* 24662 ( 525) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  0] -1 */
    51152916, /* 24663 ( 525) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6] -1 */
    35432598, /* 24664 ( 525) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  0] -1 */
    35563820, /* 24665 ( 525) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
       16484, /* 24666 ( 526) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    18557868, /* 24667 ( 526) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
    34028546, /* 24668 ( 526) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
      121458, /* 24669 ( 526) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  6]  1 */
    18439608, /* 24670 ( 526) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
    34015584, /* 24671 ( 526) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    34133520, /* 24672 ( 526) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
      134420, /* 24673 ( 526) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6]  1 */
    18426650, /* 24674 ( 526) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
        3198, /* 24675 ( 526) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    18544586, /* 24676 ( 526) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    34146806, /* 24677 ( 526) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    52451994, /* 24678 ( 526) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
    52556972, /* 24679 ( 526) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    52569930, /* 24680 ( 526) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    52438712, /* 24681 ( 526) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
       16484, /* 24682 ( 527) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    18557868, /* 24683 ( 527) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
    35550696, /* 24684 ( 527) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  6] -1 */
      121458, /* 24685 ( 527) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  6]  1 */
    18439608, /* 24686 ( 527) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
    51034818, /* 24687 ( 527) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  0] -1 */
    35432760, /* 24688 ( 527) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  0] -1 */
    35563982, /* 24689 ( 527) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
    18426650, /* 24690 ( 527) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
        3198, /* 24691 ( 527) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    18544586, /* 24692 ( 527) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    51152754, /* 24693 ( 527) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  6] -1 */
    51139796, /* 24694 ( 527) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
    35445722, /* 24695 ( 527) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  0] -1 */
    51021536, /* 24696 ( 527) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  0] -1 */
      134420, /* 24697 ( 527) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6]  1 */
       16484, /* 24698 ( 528) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    18557868, /* 24699 ( 528) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
    35445882, /* 24700 ( 528) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  0] -1 */
      121458, /* 24701 ( 528) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  6]  1 */
    18439608, /* 24702 ( 528) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
    35550860, /* 24703 ( 528) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
    35432600, /* 24704 ( 528) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  0] -1 */
      134420, /* 24705 ( 528) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6]  1 */
    18426650, /* 24706 ( 528) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
        3198, /* 24707 ( 528) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    18544586, /* 24708 ( 528) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    51152918, /* 24709 ( 528) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
    51021696, /* 24710 ( 528) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  0] -1 */
    51139632, /* 24711 ( 528) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  6] -1 */
    35563818, /* 24712 ( 528) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  6] -1 */
    51034658, /* 24713 ( 528) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  0] -1 */
       16484, /* 24714 ( 529) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    18557868, /* 24715 ( 529) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
    34133522, /* 24716 ( 529) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
      121458, /* 24717 ( 529) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  6]  1 */
    18439608, /* 24718 ( 529) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
    52438710, /* 24719 ( 529) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
    34015586, /* 24720 ( 529) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    52569932, /* 24721 ( 529) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    52451996, /* 24722 ( 529) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
        3198, /* 24723 ( 529) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    18544586, /* 24724 ( 529) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    18426650, /* 24725 ( 529) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    52556970, /* 24726 ( 529) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
      134420, /* 24727 ( 529) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6]  1 */
    34146804, /* 24728 ( 529) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
    34028544, /* 24729 ( 529) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
       16484, /* 24730 ( 530) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    52451834, /* 24731 ( 530) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
    18557868, /* 24732 ( 530) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
      121458, /* 24733 ( 530) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  6]  1 */
    18439608, /* 24734 ( 530) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
    34028706, /* 24735 ( 530) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
      134420, /* 24736 ( 530) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6]  1 */
    18426650, /* 24737 ( 530) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
        3198, /* 24738 ( 530) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    18544586, /* 24739 ( 530) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    34133684, /* 24740 ( 530) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    34146642, /* 24741 ( 530) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
    34015424, /* 24742 ( 530) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    52438872, /* 24743 ( 530) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
    52570094, /* 24744 ( 530) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    52556808, /* 24745 ( 530) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
       16484, /* 24746 ( 515) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    18557868, /* 24747 ( 515) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
      134418, /* 24748 ( 515) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  6]  1 */
    18426648, /* 24749 ( 515) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
    18439610, /* 24750 ( 515) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
        3198, /* 24751 ( 515) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    18544586, /* 24752 ( 515) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
      121460, /* 24753 ( 515) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6]  1 */
       16484, /* 24754 ( 516) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    18557868, /* 24755 ( 516) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
    34015422, /* 24756 ( 516) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    18426648, /* 24757 ( 516) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
      134418, /* 24758 ( 516) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  6]  1 */
    52556810, /* 24759 ( 516) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    52451834, /* 24760 ( 516) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
    34133684, /* 24761 ( 516) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    18439610, /* 24762 ( 516) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
        3198, /* 24763 ( 516) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    18544586, /* 24764 ( 516) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    52570092, /* 24765 ( 516) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    34146642, /* 24766 ( 516) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
      121460, /* 24767 ( 516) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6]  1 */
    34028708, /* 24768 ( 516) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    52438872, /* 24769 ( 516) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
       16484, /* 24770 ( 517) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    18557868, /* 24771 ( 517) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
    34015422, /* 24772 ( 517) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    52556810, /* 24773 ( 517) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    18426648, /* 24774 ( 517) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
    52451834, /* 24775 ( 517) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
    34146642, /* 24776 ( 517) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
      121460, /* 24777 ( 517) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6]  1 */
       16484, /* 24778 ( 518) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    18557868, /* 24779 ( 518) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
    34015422, /* 24780 ( 518) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    52556810, /* 24781 ( 518) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
      134418, /* 24782 ( 518) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  6]  1 */
    34133684, /* 24783 ( 518) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    18439610, /* 24784 ( 518) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    52438872, /* 24785 ( 518) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
       16484, /* 24786 ( 519) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34015422, /* 24787 ( 519) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    18439610, /* 24788 ( 519) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    18544586, /* 24789 ( 519) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    34146642, /* 24790 ( 519) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
      121460, /* 24791 ( 519) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6]  1 */
    52570092, /* 24792 ( 519) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    52438872, /* 24793 ( 519) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
       16484, /* 24794 ( 520) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    18557868, /* 24795 ( 520) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
    52451834, /* 24796 ( 520) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
    34133684, /* 24797 ( 520) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
        3198, /* 24798 ( 520) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    18544586, /* 24799 ( 520) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    34146642, /* 24800 ( 520) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
    52438872, /* 24801 ( 520) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
       16484, /* 24802 ( 521) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    52556810, /* 24803 ( 521) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    18426648, /* 24804 ( 521) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
    34133684, /* 24805 ( 521) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    18439610, /* 24806 ( 521) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
        3198, /* 24807 ( 521) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    34146642, /* 24808 ( 521) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
    52570092, /* 24809 ( 521) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
       16484, /* 24810 ( 522) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    52556810, /* 24811 ( 522) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
      134418, /* 24812 ( 522) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  6]  1 */
    52451834, /* 24813 ( 522) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
        3198, /* 24814 ( 522) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
      121460, /* 24815 ( 522) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6]  1 */
    52570092, /* 24816 ( 522) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    52438872, /* 24817 ( 522) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
       16484, /* 24818 ( 523) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34015422, /* 24819 ( 523) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    18426648, /* 24820 ( 523) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
      134418, /* 24821 ( 523) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  6]  1 */
    52451834, /* 24822 ( 523) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
    34133684, /* 24823 ( 523) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    18544586, /* 24824 ( 523) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    52570092, /* 24825 ( 523) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
       16484, /* 24826 ( 524) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    18557868, /* 24827 ( 524) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
    35563818, /* 24828 ( 524) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  6] -1 */
      134418, /* 24829 ( 524) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  6]  1 */
    18426648, /* 24830 ( 524) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
    35550860, /* 24831 ( 524) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
    35445884, /* 24832 ( 524) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  0] -1 */
    51152916, /* 24833 ( 524) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6] -1 */
    51034658, /* 24834 ( 524) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  0] -1 */
    18439610, /* 24835 ( 524) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
        3198, /* 24836 ( 524) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    18544586, /* 24837 ( 524) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    35432598, /* 24838 ( 524) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  0] -1 */
    51021696, /* 24839 ( 524) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  0] -1 */
    51139634, /* 24840 ( 524) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
      121460, /* 24841 ( 524) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6]  1 */
       16484, /* 24842 ( 525) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    18557868, /* 24843 ( 525) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
      134418, /* 24844 ( 525) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  6]  1 */
    18426648, /* 24845 ( 525) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
    51152754, /* 24846 ( 525) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  6] -1 */
    35445722, /* 24847 ( 525) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  0] -1 */
    35432760, /* 24848 ( 525) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  0] -1 */
    35550698, /* 24849 ( 525) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
      121460, /* 24850 ( 525) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6]  1 */
    18439610, /* 24851 ( 525) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
        3198, /* 24852 ( 525) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    18544586, /* 24853 ( 525) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    51034820, /* 24854 ( 525) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  0] -1 */
    35563980, /* 24855 ( 525) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6] -1 */
    51021534, /* 24856 ( 525) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  0] -1 */
    51139796, /* 24857 ( 525) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
       16484, /* 24858 ( 526) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    18557868, /* 24859 ( 526) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
    34015586, /* 24860 ( 526) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
      134418, /* 24861 ( 526) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  6]  1 */
    18426648, /* 24862 ( 526) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
    34028544, /* 24863 ( 526) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    34133520, /* 24864 ( 526) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
      121460, /* 24865 ( 526) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6]  1 */
    18439610, /* 24866 ( 526) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
        3198, /* 24867 ( 526) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    18544586, /* 24868 ( 526) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    34146806, /* 24869 ( 526) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    52451994, /* 24870 ( 526) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
    52569932, /* 24871 ( 526) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    52556970, /* 24872 ( 526) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    52438712, /* 24873 ( 526) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
       16484, /* 24874 ( 527) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    18557868, /* 24875 ( 527) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
    51139632, /* 24876 ( 527) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  6] -1 */
      134418, /* 24877 ( 527) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  6]  1 */
    18426648, /* 24878 ( 527) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
    35445882, /* 24879 ( 527) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  0] -1 */
    51034656, /* 24880 ( 527) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  0] -1 */
    51152918, /* 24881 ( 527) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
    18439610, /* 24882 ( 527) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
        3198, /* 24883 ( 527) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    18544586, /* 24884 ( 527) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    35550858, /* 24885 ( 527) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6] -1 */
    35563820, /* 24886 ( 527) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
    51021698, /* 24887 ( 527) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  0] -1 */
    35432600, /* 24888 ( 527) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  0] -1 */
      121460, /* 24889 ( 527) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6]  1 */
       16484, /* 24890 ( 528) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    18557868, /* 24891 ( 528) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
    51034818, /* 24892 ( 528) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  0] -1 */
      134418, /* 24893 ( 528) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  6]  1 */
    18426648, /* 24894 ( 528) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
    51152756, /* 24895 ( 528) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
    51021536, /* 24896 ( 528) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  0] -1 */
      121460, /* 24897 ( 528) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6]  1 */
    18439610, /* 24898 ( 528) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
        3198, /* 24899 ( 528) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    18544586, /* 24900 ( 528) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    35563982, /* 24901 ( 528) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
    35445720, /* 24902 ( 528) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  0] -1 */
    35550696, /* 24903 ( 528) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  6] -1 */
    51139794, /* 24904 ( 528) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6] -1 */
    35432762, /* 24905 ( 528) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  0] -1 */
       16484, /* 24906 ( 529) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    18557868, /* 24907 ( 529) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
    34133522, /* 24908 ( 529) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
      134418, /* 24909 ( 529) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  6]  1 */
    18426648, /* 24910 ( 529) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
    52438710, /* 24911 ( 529) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
    34028546, /* 24912 ( 529) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    52556972, /* 24913 ( 529) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    52451996, /* 24914 ( 529) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
        3198, /* 24915 ( 529) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    18544586, /* 24916 ( 529) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    18439610, /* 24917 ( 529) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    52569930, /* 24918 ( 529) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
      121460, /* 24919 ( 529) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6]  1 */
    34146804, /* 24920 ( 529) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
    34015584, /* 24921 ( 529) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
       16484, /* 24922 ( 530) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    52438874, /* 24923 ( 530) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
    18557868, /* 24924 ( 530) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
      134418, /* 24925 ( 530) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  6]  1 */
    18426648, /* 24926 ( 530) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
    34028706, /* 24927 ( 530) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
      121460, /* 24928 ( 530) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6]  1 */
    18439610, /* 24929 ( 530) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
        3198, /* 24930 ( 530) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    18544586, /* 24931 ( 530) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    34146644, /* 24932 ( 530) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    34133682, /* 24933 ( 530) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
    34015424, /* 24934 ( 530) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    52451832, /* 24935 ( 530) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
    52570094, /* 24936 ( 530) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    52556808, /* 24937 ( 530) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
       16484, /* 24938 ( 515) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    18544748, /* 24939 ( 515) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    17009312, /* 24940 ( 515) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  0]  1 */
     1538634, /* 24941 ( 515) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
     1551596, /* 24942 ( 515) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
        3198, /* 24943 ( 515) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    18557706, /* 24944 ( 515) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
    17022594, /* 24945 ( 515) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  0]  1 */
       16484, /* 24946 ( 516) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    18544748, /* 24947 ( 516) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    34015422, /* 24948 ( 516) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
     1538634, /* 24949 ( 516) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
    17009312, /* 24950 ( 516) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  0]  1 */
    52569930, /* 24951 ( 516) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    35563820, /* 24952 ( 516) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
    51034818, /* 24953 ( 516) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  0] -1 */
     1551596, /* 24954 ( 516) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
        3198, /* 24955 ( 516) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    18557706, /* 24956 ( 516) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
    52556972, /* 24957 ( 516) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    51021536, /* 24958 ( 516) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  0] -1 */
    17022594, /* 24959 ( 516) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  0]  1 */
    34028708, /* 24960 ( 516) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    35550858, /* 24961 ( 516) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6] -1 */
       16484, /* 24962 ( 517) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    18544748, /* 24963 ( 517) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    34015422, /* 24964 ( 517) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    52569930, /* 24965 ( 517) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
     1538634, /* 24966 ( 517) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
    35563820, /* 24967 ( 517) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
    51021536, /* 24968 ( 517) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  0] -1 */
    17022594, /* 24969 ( 517) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  0]  1 */
       16484, /* 24970 ( 518) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    18544748, /* 24971 ( 518) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    34015422, /* 24972 ( 518) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    52569930, /* 24973 ( 518) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    17009312, /* 24974 ( 518) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  0]  1 */
    51034818, /* 24975 ( 518) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  0] -1 */
     1551596, /* 24976 ( 518) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
    35550858, /* 24977 ( 518) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6] -1 */
       16484, /* 24978 ( 519) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34015422, /* 24979 ( 519) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
     1551596, /* 24980 ( 519) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
    18557706, /* 24981 ( 519) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
    51021536, /* 24982 ( 519) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  0] -1 */
    17022594, /* 24983 ( 519) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  0]  1 */
    52556972, /* 24984 ( 519) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    35550858, /* 24985 ( 519) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6] -1 */
       16484, /* 24986 ( 520) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    18544748, /* 24987 ( 520) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    35563820, /* 24988 ( 520) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
    51034818, /* 24989 ( 520) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  0] -1 */
        3198, /* 24990 ( 520) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    18557706, /* 24991 ( 520) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
    51021536, /* 24992 ( 520) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  0] -1 */
    35550858, /* 24993 ( 520) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6] -1 */
       16484, /* 24994 ( 521) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    52569930, /* 24995 ( 521) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
     1538634, /* 24996 ( 521) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
    51034818, /* 24997 ( 521) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  0] -1 */
     1551596, /* 24998 ( 521) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
        3198, /* 24999 ( 521) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    51021536, /* 25000 ( 521) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  0] -1 */
    52556972, /* 25001 ( 521) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
       16484, /* 25002 ( 522) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    52569930, /* 25003 ( 522) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    17009312, /* 25004 ( 522) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  0]  1 */
    35563820, /* 25005 ( 522) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
        3198, /* 25006 ( 522) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    17022594, /* 25007 ( 522) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  0]  1 */
    52556972, /* 25008 ( 522) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    35550858, /* 25009 ( 522) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6] -1 */
       16484, /* 25010 ( 523) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34015422, /* 25011 ( 523) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
     1538634, /* 25012 ( 523) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
    17009312, /* 25013 ( 523) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  0]  1 */
    35563820, /* 25014 ( 523) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
    51034818, /* 25015 ( 523) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  0] -1 */
    18557706, /* 25016 ( 523) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
    52556972, /* 25017 ( 523) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
       16484, /* 25018 ( 524) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    18544748, /* 25019 ( 524) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    52438712, /* 25020 ( 524) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
    17009312, /* 25021 ( 524) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  0]  1 */
     1538634, /* 25022 ( 524) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
    52451994, /* 25023 ( 524) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
    35445884, /* 25024 ( 524) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  0] -1 */
    51139796, /* 25025 ( 524) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
    34146644, /* 25026 ( 524) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
     1551596, /* 25027 ( 524) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
        3198, /* 25028 ( 524) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    18557706, /* 25029 ( 524) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
    35432598, /* 25030 ( 524) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  0] -1 */
    34133682, /* 25031 ( 524) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
    51152754, /* 25032 ( 524) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  6] -1 */
    17022594, /* 25033 ( 524) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  0]  1 */
       16484, /* 25034 ( 525) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    18544748, /* 25035 ( 525) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    17009312, /* 25036 ( 525) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  0]  1 */
     1538634, /* 25037 ( 525) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
    51139634, /* 25038 ( 525) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
    35445722, /* 25039 ( 525) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  0] -1 */
    35432760, /* 25040 ( 525) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  0] -1 */
    52451832, /* 25041 ( 525) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
    17022594, /* 25042 ( 525) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  0]  1 */
     1551596, /* 25043 ( 525) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
        3198, /* 25044 ( 525) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    18557706, /* 25045 ( 525) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
    34146806, /* 25046 ( 525) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    52438874, /* 25047 ( 525) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
    34133520, /* 25048 ( 525) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
    51152916, /* 25049 ( 525) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6] -1 */
       16484, /* 25050 ( 526) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    18544748, /* 25051 ( 526) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    34028706, /* 25052 ( 526) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    17009312, /* 25053 ( 526) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  0]  1 */
     1538634, /* 25054 ( 526) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
    34015424, /* 25055 ( 526) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    51021534, /* 25056 ( 526) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  0] -1 */
    17022594, /* 25057 ( 526) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  0]  1 */
     1551596, /* 25058 ( 526) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
        3198, /* 25059 ( 526) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    18557706, /* 25060 ( 526) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
    51034820, /* 25061 ( 526) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  0] -1 */
    35550860, /* 25062 ( 526) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
    52569932, /* 25063 ( 526) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    52556970, /* 25064 ( 526) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    35563818, /* 25065 ( 526) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  6] -1 */
       16484, /* 25066 ( 527) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    18544748, /* 25067 ( 527) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    51139632, /* 25068 ( 527) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  6] -1 */
    17009312, /* 25069 ( 527) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  0]  1 */
     1538634, /* 25070 ( 527) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
    35432762, /* 25071 ( 527) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  0] -1 */
    34133522, /* 25072 ( 527) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    51152918, /* 25073 ( 527) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
     1551596, /* 25074 ( 527) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
        3198, /* 25075 ( 527) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    18557706, /* 25076 ( 527) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
    52438872, /* 25077 ( 527) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
    52451834, /* 25078 ( 527) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
    34146804, /* 25079 ( 527) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
    35445720, /* 25080 ( 527) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  0] -1 */
    17022594, /* 25081 ( 527) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  0]  1 */
       16484, /* 25082 ( 528) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    18544748, /* 25083 ( 528) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    34133684, /* 25084 ( 528) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    17009312, /* 25085 ( 528) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  0]  1 */
     1538634, /* 25086 ( 528) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
    51152756, /* 25087 ( 528) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
    34146642, /* 25088 ( 528) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
    17022594, /* 25089 ( 528) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  0]  1 */
     1551596, /* 25090 ( 528) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
        3198, /* 25091 ( 528) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    18557706, /* 25092 ( 528) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
    52451996, /* 25093 ( 528) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
    35432600, /* 25094 ( 528) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  0] -1 */
    52438710, /* 25095 ( 528) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
    51139794, /* 25096 ( 528) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6] -1 */
    35445882, /* 25097 ( 528) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  0] -1 */
       16484, /* 25098 ( 529) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    18544748, /* 25099 ( 529) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    51034656, /* 25100 ( 529) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  0] -1 */
    17009312, /* 25101 ( 529) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  0]  1 */
     1538634, /* 25102 ( 529) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
    35550696, /* 25103 ( 529) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  6] -1 */
    34028546, /* 25104 ( 529) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    52570092, /* 25105 ( 529) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    35563982, /* 25106 ( 529) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
        3198, /* 25107 ( 529) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    18557706, /* 25108 ( 529) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
     1551596, /* 25109 ( 529) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
    52556810, /* 25110 ( 529) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    17022594, /* 25111 ( 529) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  0]  1 */
    51021698, /* 25112 ( 529) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  0] -1 */
    34015584, /* 25113 ( 529) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
       16484, /* 25114 ( 530) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    35563980, /* 25115 ( 530) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6] -1 */
    18544748, /* 25116 ( 530) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    17009312, /* 25117 ( 530) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  0]  1 */
     1538634, /* 25118 ( 530) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
    34015586, /* 25119 ( 530) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    17022594, /* 25120 ( 530) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  0]  1 */
     1551596, /* 25121 ( 530) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
        3198, /* 25122 ( 530) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    18557706, /* 25123 ( 530) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
    51034658, /* 25124 ( 530) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  0] -1 */
    51021696, /* 25125 ( 530) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  0] -1 */
    34028544, /* 25126 ( 530) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    35550698, /* 25127 ( 530) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
    52570094, /* 25128 ( 530) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    52556808, /* 25129 ( 530) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
       16484, /* 25130 ( 515) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    18544748, /* 25131 ( 515) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    17009472, /* 25132 ( 515) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  0]  1 */
     1538474, /* 25133 ( 515) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
     1551756, /* 25134 ( 515) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
        3198, /* 25135 ( 515) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    18557706, /* 25136 ( 515) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
    17022434, /* 25137 ( 515) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  0]  1 */
       16484, /* 25138 ( 516) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    18544748, /* 25139 ( 516) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    34015422, /* 25140 ( 516) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
     1538474, /* 25141 ( 516) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
    17009472, /* 25142 ( 516) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  0]  1 */
    52569930, /* 25143 ( 516) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    35563980, /* 25144 ( 516) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6] -1 */
    51034658, /* 25145 ( 516) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  0] -1 */
     1551756, /* 25146 ( 516) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
        3198, /* 25147 ( 516) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    18557706, /* 25148 ( 516) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
    52556972, /* 25149 ( 516) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    51021696, /* 25150 ( 516) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  0] -1 */
    17022434, /* 25151 ( 516) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  0]  1 */
    34028708, /* 25152 ( 516) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    35550698, /* 25153 ( 516) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
       16484, /* 25154 ( 517) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    18544748, /* 25155 ( 517) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    34015422, /* 25156 ( 517) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    52569930, /* 25157 ( 517) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
     1538474, /* 25158 ( 517) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
    35563980, /* 25159 ( 517) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6] -1 */
    51021696, /* 25160 ( 517) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  0] -1 */
    17022434, /* 25161 ( 517) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  0]  1 */
       16484, /* 25162 ( 518) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    18544748, /* 25163 ( 518) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    34015422, /* 25164 ( 518) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    52569930, /* 25165 ( 518) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    17009472, /* 25166 ( 518) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  0]  1 */
    51034658, /* 25167 ( 518) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  0] -1 */
     1551756, /* 25168 ( 518) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
    35550698, /* 25169 ( 518) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
       16484, /* 25170 ( 519) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34015422, /* 25171 ( 519) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
     1551756, /* 25172 ( 519) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
    18557706, /* 25173 ( 519) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
    51021696, /* 25174 ( 519) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  0] -1 */
    17022434, /* 25175 ( 519) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  0]  1 */
    52556972, /* 25176 ( 519) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    35550698, /* 25177 ( 519) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
       16484, /* 25178 ( 520) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    18544748, /* 25179 ( 520) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    35563980, /* 25180 ( 520) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6] -1 */
    51034658, /* 25181 ( 520) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  0] -1 */
        3198, /* 25182 ( 520) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    18557706, /* 25183 ( 520) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
    51021696, /* 25184 ( 520) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  0] -1 */
    35550698, /* 25185 ( 520) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
       16484, /* 25186 ( 521) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    52569930, /* 25187 ( 521) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
     1538474, /* 25188 ( 521) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
    51034658, /* 25189 ( 521) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  0] -1 */
     1551756, /* 25190 ( 521) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
        3198, /* 25191 ( 521) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    51021696, /* 25192 ( 521) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  0] -1 */
    52556972, /* 25193 ( 521) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
       16484, /* 25194 ( 522) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    52569930, /* 25195 ( 522) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    17009472, /* 25196 ( 522) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  0]  1 */
    35563980, /* 25197 ( 522) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6] -1 */
        3198, /* 25198 ( 522) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    17022434, /* 25199 ( 522) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  0]  1 */
    52556972, /* 25200 ( 522) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    35550698, /* 25201 ( 522) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
       16484, /* 25202 ( 523) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34015422, /* 25203 ( 523) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
     1538474, /* 25204 ( 523) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
    17009472, /* 25205 ( 523) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  0]  1 */
    35563980, /* 25206 ( 523) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6] -1 */
    51034658, /* 25207 ( 523) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  0] -1 */
    18557706, /* 25208 ( 523) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
    52556972, /* 25209 ( 523) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
       16484, /* 25210 ( 524) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    18544748, /* 25211 ( 524) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    51139794, /* 25212 ( 524) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6] -1 */
    17009472, /* 25213 ( 524) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  0]  1 */
     1538474, /* 25214 ( 524) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
    51152756, /* 25215 ( 524) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
    34146806, /* 25216 ( 524) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    52438874, /* 25217 ( 524) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
    35445882, /* 25218 ( 524) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  0] -1 */
     1551756, /* 25219 ( 524) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
        3198, /* 25220 ( 524) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    18557706, /* 25221 ( 524) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
    34133520, /* 25222 ( 524) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
    35432600, /* 25223 ( 524) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  0] -1 */
    52451832, /* 25224 ( 524) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
    17022434, /* 25225 ( 524) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  0]  1 */
       16484, /* 25226 ( 525) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    18544748, /* 25227 ( 525) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    17009472, /* 25228 ( 525) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  0]  1 */
     1538474, /* 25229 ( 525) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
    52438872, /* 25230 ( 525) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
    34146804, /* 25231 ( 525) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
    34133522, /* 25232 ( 525) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    51152754, /* 25233 ( 525) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  6] -1 */
    17022434, /* 25234 ( 525) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  0]  1 */
     1551756, /* 25235 ( 525) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
        3198, /* 25236 ( 525) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    18557706, /* 25237 ( 525) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
    35445884, /* 25238 ( 525) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  0] -1 */
    51139796, /* 25239 ( 525) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
    35432598, /* 25240 ( 525) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  0] -1 */
    52451834, /* 25241 ( 525) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
       16484, /* 25242 ( 526) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    18544748, /* 25243 ( 526) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    34028546, /* 25244 ( 526) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    17009472, /* 25245 ( 526) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  0]  1 */
     1538474, /* 25246 ( 526) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
    34015584, /* 25247 ( 526) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    51021534, /* 25248 ( 526) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  0] -1 */
    17022434, /* 25249 ( 526) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  0]  1 */
     1551756, /* 25250 ( 526) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
        3198, /* 25251 ( 526) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    18557706, /* 25252 ( 526) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
    51034820, /* 25253 ( 526) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  0] -1 */
    35550860, /* 25254 ( 526) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
    52570092, /* 25255 ( 526) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    52556810, /* 25256 ( 526) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    35563818, /* 25257 ( 526) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  6] -1 */
       16484, /* 25258 ( 527) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    18544748, /* 25259 ( 527) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    52438710, /* 25260 ( 527) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
    17009472, /* 25261 ( 527) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  0]  1 */
     1538474, /* 25262 ( 527) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
    34133684, /* 25263 ( 527) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    35432760, /* 25264 ( 527) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  0] -1 */
    52451996, /* 25265 ( 527) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
     1551756, /* 25266 ( 527) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
        3198, /* 25267 ( 527) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    18557706, /* 25268 ( 527) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
    51139634, /* 25269 ( 527) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
    51152916, /* 25270 ( 527) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6] -1 */
    35445722, /* 25271 ( 527) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  0] -1 */
    34146642, /* 25272 ( 527) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
    17022434, /* 25273 ( 527) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  0]  1 */
       16484, /* 25274 ( 528) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    18544748, /* 25275 ( 528) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    35432762, /* 25276 ( 528) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  0] -1 */
    17009472, /* 25277 ( 528) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  0]  1 */
     1538474, /* 25278 ( 528) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
    52451994, /* 25279 ( 528) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
    35445720, /* 25280 ( 528) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  0] -1 */
    17022434, /* 25281 ( 528) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  0]  1 */
     1551756, /* 25282 ( 528) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
        3198, /* 25283 ( 528) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    18557706, /* 25284 ( 528) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
    51152918, /* 25285 ( 528) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
    34133682, /* 25286 ( 528) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
    51139632, /* 25287 ( 528) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  6] -1 */
    52438712, /* 25288 ( 528) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
    34146644, /* 25289 ( 528) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
       16484, /* 25290 ( 529) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    18544748, /* 25291 ( 529) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    51034656, /* 25292 ( 529) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  0] -1 */
    17009472, /* 25293 ( 529) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  0]  1 */
     1538474, /* 25294 ( 529) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
    35550696, /* 25295 ( 529) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  6] -1 */
    34028706, /* 25296 ( 529) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    52569932, /* 25297 ( 529) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    35563982, /* 25298 ( 529) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
        3198, /* 25299 ( 529) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    18557706, /* 25300 ( 529) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
     1551756, /* 25301 ( 529) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
    52556970, /* 25302 ( 529) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    17022434, /* 25303 ( 529) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  0]  1 */
    51021698, /* 25304 ( 529) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  0] -1 */
    34015424, /* 25305 ( 529) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
       16484, /* 25306 ( 530) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    35563820, /* 25307 ( 530) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
    18544748, /* 25308 ( 530) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    17009472, /* 25309 ( 530) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  0]  1 */
     1538474, /* 25310 ( 530) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
    34015586, /* 25311 ( 530) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    17022434, /* 25312 ( 530) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  0]  1 */
     1551756, /* 25313 ( 530) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
        3198, /* 25314 ( 530) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    18557706, /* 25315 ( 530) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
    51034818, /* 25316 ( 530) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  0] -1 */
    51021536, /* 25317 ( 530) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  0] -1 */
    34028544, /* 25318 ( 530) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    35550858, /* 25319 ( 530) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6] -1 */
    52570094, /* 25320 ( 530) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    52556808, /* 25321 ( 530) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
       16484, /* 25322 ( 515) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    18557708, /* 25323 ( 515) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
     1433496, /* 25324 ( 515) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  0]  1 */
    17127410, /* 25325 ( 515) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
    17140692, /* 25326 ( 515) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6]  1 */
        3198, /* 25327 ( 515) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    18544746, /* 25328 ( 515) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
     1420538, /* 25329 ( 515) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  0]  1 */
       16484, /* 25330 ( 516) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    18557708, /* 25331 ( 516) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    34015422, /* 25332 ( 516) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    17127410, /* 25333 ( 516) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
     1433496, /* 25334 ( 516) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  0]  1 */
    52556970, /* 25335 ( 516) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    51152916, /* 25336 ( 516) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6] -1 */
    35432762, /* 25337 ( 516) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  0] -1 */
    17140692, /* 25338 ( 516) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6]  1 */
        3198, /* 25339 ( 516) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    18544746, /* 25340 ( 516) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
    52569932, /* 25341 ( 516) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    35445720, /* 25342 ( 516) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  0] -1 */
     1420538, /* 25343 ( 516) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  0]  1 */
    34028708, /* 25344 ( 516) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    51139634, /* 25345 ( 516) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
       16484, /* 25346 ( 517) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    18557708, /* 25347 ( 517) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    34015422, /* 25348 ( 517) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    52556970, /* 25349 ( 517) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    17127410, /* 25350 ( 517) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
    51152916, /* 25351 ( 517) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6] -1 */
    35445720, /* 25352 ( 517) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  0] -1 */
     1420538, /* 25353 ( 517) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  0]  1 */
       16484, /* 25354 ( 518) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    18557708, /* 25355 ( 518) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    34015422, /* 25356 ( 518) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    52556970, /* 25357 ( 518) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
     1433496, /* 25358 ( 518) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  0]  1 */
    35432762, /* 25359 ( 518) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  0] -1 */
    17140692, /* 25360 ( 518) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6]  1 */
    51139634, /* 25361 ( 518) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
       16484, /* 25362 ( 519) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34015422, /* 25363 ( 519) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    17140692, /* 25364 ( 519) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6]  1 */
    18544746, /* 25365 ( 519) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
    35445720, /* 25366 ( 519) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  0] -1 */
     1420538, /* 25367 ( 519) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  0]  1 */
    52569932, /* 25368 ( 519) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    51139634, /* 25369 ( 519) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
       16484, /* 25370 ( 520) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    18557708, /* 25371 ( 520) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    51152916, /* 25372 ( 520) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6] -1 */
    35432762, /* 25373 ( 520) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  0] -1 */
        3198, /* 25374 ( 520) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    18544746, /* 25375 ( 520) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
    35445720, /* 25376 ( 520) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  0] -1 */
    51139634, /* 25377 ( 520) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
       16484, /* 25378 ( 521) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    52556970, /* 25379 ( 521) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    17127410, /* 25380 ( 521) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
    35432762, /* 25381 ( 521) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  0] -1 */
    17140692, /* 25382 ( 521) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6]  1 */
        3198, /* 25383 ( 521) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    35445720, /* 25384 ( 521) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  0] -1 */
    52569932, /* 25385 ( 521) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
       16484, /* 25386 ( 522) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    52556970, /* 25387 ( 522) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
     1433496, /* 25388 ( 522) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  0]  1 */
    51152916, /* 25389 ( 522) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6] -1 */
        3198, /* 25390 ( 522) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
     1420538, /* 25391 ( 522) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  0]  1 */
    52569932, /* 25392 ( 522) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    51139634, /* 25393 ( 522) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
       16484, /* 25394 ( 523) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34015422, /* 25395 ( 523) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    17127410, /* 25396 ( 523) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
     1433496, /* 25397 ( 523) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  0]  1 */
    51152916, /* 25398 ( 523) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6] -1 */
    35432762, /* 25399 ( 523) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  0] -1 */
    18544746, /* 25400 ( 523) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
    52569932, /* 25401 ( 523) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
       16484, /* 25402 ( 524) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    18557708, /* 25403 ( 524) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    35563818, /* 25404 ( 524) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  6] -1 */
     1433496, /* 25405 ( 524) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  0]  1 */
    17127410, /* 25406 ( 524) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
    35550860, /* 25407 ( 524) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
    34146806, /* 25408 ( 524) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    52451834, /* 25409 ( 524) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
    51034818, /* 25410 ( 524) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  0] -1 */
    17140692, /* 25411 ( 524) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6]  1 */
        3198, /* 25412 ( 524) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    18544746, /* 25413 ( 524) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
    34133520, /* 25414 ( 524) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
    51021536, /* 25415 ( 524) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  0] -1 */
    52438872, /* 25416 ( 524) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
     1420538, /* 25417 ( 524) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  0]  1 */
       16484, /* 25418 ( 525) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    18557708, /* 25419 ( 525) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
     1433496, /* 25420 ( 525) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  0]  1 */
    17127410, /* 25421 ( 525) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
    52451832, /* 25422 ( 525) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
    34146804, /* 25423 ( 525) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
    34133522, /* 25424 ( 525) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    35550858, /* 25425 ( 525) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6] -1 */
     1420538, /* 25426 ( 525) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  0]  1 */
    17140692, /* 25427 ( 525) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6]  1 */
        3198, /* 25428 ( 525) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    18544746, /* 25429 ( 525) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
    51034820, /* 25430 ( 525) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  0] -1 */
    35563820, /* 25431 ( 525) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
    51021534, /* 25432 ( 525) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  0] -1 */
    52438874, /* 25433 ( 525) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
       16484, /* 25434 ( 526) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    18557708, /* 25435 ( 526) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    34015586, /* 25436 ( 526) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
     1433496, /* 25437 ( 526) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  0]  1 */
    17127410, /* 25438 ( 526) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
    34028544, /* 25439 ( 526) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    35432598, /* 25440 ( 526) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  0] -1 */
     1420538, /* 25441 ( 526) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  0]  1 */
    17140692, /* 25442 ( 526) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6]  1 */
        3198, /* 25443 ( 526) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    18544746, /* 25444 ( 526) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
    35445884, /* 25445 ( 526) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  0] -1 */
    51152756, /* 25446 ( 526) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
    52570092, /* 25447 ( 526) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    52556810, /* 25448 ( 526) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    51139794, /* 25449 ( 526) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6] -1 */
       16484, /* 25450 ( 527) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    18557708, /* 25451 ( 527) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    52438710, /* 25452 ( 527) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
     1433496, /* 25453 ( 527) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  0]  1 */
    17127410, /* 25454 ( 527) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
    34146644, /* 25455 ( 527) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    51034656, /* 25456 ( 527) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  0] -1 */
    52451996, /* 25457 ( 527) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
    17140692, /* 25458 ( 527) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6]  1 */
        3198, /* 25459 ( 527) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    18544746, /* 25460 ( 527) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
    35550698, /* 25461 ( 527) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
    35563980, /* 25462 ( 527) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6] -1 */
    51021698, /* 25463 ( 527) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  0] -1 */
    34133682, /* 25464 ( 527) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
     1420538, /* 25465 ( 527) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  0]  1 */
       16484, /* 25466 ( 528) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    18557708, /* 25467 ( 528) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    51034658, /* 25468 ( 528) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  0] -1 */
     1433496, /* 25469 ( 528) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  0]  1 */
    17127410, /* 25470 ( 528) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
    52451994, /* 25471 ( 528) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
    51021696, /* 25472 ( 528) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  0] -1 */
     1420538, /* 25473 ( 528) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  0]  1 */
    17140692, /* 25474 ( 528) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6]  1 */
        3198, /* 25475 ( 528) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    18544746, /* 25476 ( 528) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
    35563982, /* 25477 ( 528) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
    34146642, /* 25478 ( 528) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
    35550696, /* 25479 ( 528) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  6] -1 */
    52438712, /* 25480 ( 528) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
    34133684, /* 25481 ( 528) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
       16484, /* 25482 ( 529) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    18557708, /* 25483 ( 529) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    35432760, /* 25484 ( 529) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  0] -1 */
     1433496, /* 25485 ( 529) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  0]  1 */
    17127410, /* 25486 ( 529) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
    51139632, /* 25487 ( 529) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  6] -1 */
    34028706, /* 25488 ( 529) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    52556972, /* 25489 ( 529) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    51152918, /* 25490 ( 529) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
        3198, /* 25491 ( 529) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    18544746, /* 25492 ( 529) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
    17140692, /* 25493 ( 529) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6]  1 */
    52569930, /* 25494 ( 529) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
     1420538, /* 25495 ( 529) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  0]  1 */
    35445722, /* 25496 ( 529) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  0] -1 */
    34015424, /* 25497 ( 529) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
       16484, /* 25498 ( 530) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    51139796, /* 25499 ( 530) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
    18557708, /* 25500 ( 530) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
     1433496, /* 25501 ( 530) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  0]  1 */
    17127410, /* 25502 ( 530) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
    34028546, /* 25503 ( 530) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
     1420538, /* 25504 ( 530) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  0]  1 */
    17140692, /* 25505 ( 530) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6]  1 */
        3198, /* 25506 ( 530) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    18544746, /* 25507 ( 530) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
    35445882, /* 25508 ( 530) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  0] -1 */
    35432600, /* 25509 ( 530) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  0] -1 */
    34015584, /* 25510 ( 530) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    51152754, /* 25511 ( 530) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  6] -1 */
    52570094, /* 25512 ( 530) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    52556808, /* 25513 ( 530) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
       16484, /* 25514 ( 515) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    18557708, /* 25515 ( 515) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
     1420376, /* 25516 ( 515) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  0]  1 */
    17140530, /* 25517 ( 515) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  6]  1 */
    17127572, /* 25518 ( 515) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
        3198, /* 25519 ( 515) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    18544746, /* 25520 ( 515) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
     1433658, /* 25521 ( 515) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  0]  1 */
       16484, /* 25522 ( 516) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    18557708, /* 25523 ( 516) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    34015422, /* 25524 ( 516) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    17140530, /* 25525 ( 516) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  6]  1 */
     1420376, /* 25526 ( 516) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  0]  1 */
    52556970, /* 25527 ( 516) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    51139796, /* 25528 ( 516) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
    35445882, /* 25529 ( 516) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  0] -1 */
    17127572, /* 25530 ( 516) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
        3198, /* 25531 ( 516) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    18544746, /* 25532 ( 516) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
    52569932, /* 25533 ( 516) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    35432600, /* 25534 ( 516) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  0] -1 */
     1433658, /* 25535 ( 516) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  0]  1 */
    34028708, /* 25536 ( 516) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    51152754, /* 25537 ( 516) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  6] -1 */
       16484, /* 25538 ( 517) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    18557708, /* 25539 ( 517) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    34015422, /* 25540 ( 517) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    52556970, /* 25541 ( 517) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    17140530, /* 25542 ( 517) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  6]  1 */
    51139796, /* 25543 ( 517) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
    35432600, /* 25544 ( 517) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  0] -1 */
     1433658, /* 25545 ( 517) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  0]  1 */
       16484, /* 25546 ( 518) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    18557708, /* 25547 ( 518) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    34015422, /* 25548 ( 518) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    52556970, /* 25549 ( 518) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
     1420376, /* 25550 ( 518) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  0]  1 */
    35445882, /* 25551 ( 518) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  0] -1 */
    17127572, /* 25552 ( 518) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
    51152754, /* 25553 ( 518) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  6] -1 */
       16484, /* 25554 ( 519) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34015422, /* 25555 ( 519) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    17127572, /* 25556 ( 519) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
    18544746, /* 25557 ( 519) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
    35432600, /* 25558 ( 519) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  0] -1 */
     1433658, /* 25559 ( 519) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  0]  1 */
    52569932, /* 25560 ( 519) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    51152754, /* 25561 ( 519) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  6] -1 */
       16484, /* 25562 ( 520) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    18557708, /* 25563 ( 520) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    51139796, /* 25564 ( 520) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
    35445882, /* 25565 ( 520) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  0] -1 */
        3198, /* 25566 ( 520) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    18544746, /* 25567 ( 520) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
    35432600, /* 25568 ( 520) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  0] -1 */
    51152754, /* 25569 ( 520) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  6] -1 */
       16484, /* 25570 ( 521) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    52556970, /* 25571 ( 521) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    17140530, /* 25572 ( 521) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  6]  1 */
    35445882, /* 25573 ( 521) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  0] -1 */
    17127572, /* 25574 ( 521) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
        3198, /* 25575 ( 521) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    35432600, /* 25576 ( 521) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  0] -1 */
    52569932, /* 25577 ( 521) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
       16484, /* 25578 ( 522) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    52556970, /* 25579 ( 522) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
     1420376, /* 25580 ( 522) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  0]  1 */
    51139796, /* 25581 ( 522) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
        3198, /* 25582 ( 522) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
     1433658, /* 25583 ( 522) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  0]  1 */
    52569932, /* 25584 ( 522) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    51152754, /* 25585 ( 522) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  6] -1 */
       16484, /* 25586 ( 523) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34015422, /* 25587 ( 523) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    17140530, /* 25588 ( 523) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  6]  1 */
     1420376, /* 25589 ( 523) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  0]  1 */
    51139796, /* 25590 ( 523) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
    35445882, /* 25591 ( 523) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  0] -1 */
    18544746, /* 25592 ( 523) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
    52569932, /* 25593 ( 523) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
       16484, /* 25594 ( 524) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    18557708, /* 25595 ( 524) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    52438712, /* 25596 ( 524) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
     1420376, /* 25597 ( 524) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  0]  1 */
    17140530, /* 25598 ( 524) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  6]  1 */
    52451994, /* 25599 ( 524) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
    51034820, /* 25600 ( 524) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  0] -1 */
    35563820, /* 25601 ( 524) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
    34133684, /* 25602 ( 524) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    17127572, /* 25603 ( 524) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
        3198, /* 25604 ( 524) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    18544746, /* 25605 ( 524) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
    51021534, /* 25606 ( 524) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  0] -1 */
    34146642, /* 25607 ( 524) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
    35550858, /* 25608 ( 524) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6] -1 */
     1433658, /* 25609 ( 524) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  0]  1 */
       16484, /* 25610 ( 525) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    18557708, /* 25611 ( 525) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
     1420376, /* 25612 ( 525) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  0]  1 */
    17140530, /* 25613 ( 525) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  6]  1 */
    35550698, /* 25614 ( 525) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
    51021698, /* 25615 ( 525) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  0] -1 */
    51034656, /* 25616 ( 525) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  0] -1 */
    52438872, /* 25617 ( 525) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
     1433658, /* 25618 ( 525) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  0]  1 */
    17127572, /* 25619 ( 525) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
        3198, /* 25620 ( 525) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    18544746, /* 25621 ( 525) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
    34146806, /* 25622 ( 525) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    52451834, /* 25623 ( 525) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
    34133520, /* 25624 ( 525) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
    35563980, /* 25625 ( 525) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6] -1 */
       16484, /* 25626 ( 526) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    18557708, /* 25627 ( 526) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    34028706, /* 25628 ( 526) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
     1420376, /* 25629 ( 526) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  0]  1 */
    17140530, /* 25630 ( 526) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  6]  1 */
    34015424, /* 25631 ( 526) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    35432598, /* 25632 ( 526) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  0] -1 */
     1433658, /* 25633 ( 526) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  0]  1 */
    17127572, /* 25634 ( 526) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
        3198, /* 25635 ( 526) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    18544746, /* 25636 ( 526) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
    35445884, /* 25637 ( 526) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  0] -1 */
    51152756, /* 25638 ( 526) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
    52556972, /* 25639 ( 526) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    52569930, /* 25640 ( 526) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    51139794, /* 25641 ( 526) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6] -1 */
       16484, /* 25642 ( 527) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    18557708, /* 25643 ( 527) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    35550696, /* 25644 ( 527) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  6] -1 */
     1420376, /* 25645 ( 527) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  0]  1 */
    17140530, /* 25646 ( 527) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  6]  1 */
    51034658, /* 25647 ( 527) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  0] -1 */
    34133522, /* 25648 ( 527) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    35563982, /* 25649 ( 527) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
    17127572, /* 25650 ( 527) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
        3198, /* 25651 ( 527) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    18544746, /* 25652 ( 527) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
    52451832, /* 25653 ( 527) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
    52438874, /* 25654 ( 527) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
    34146804, /* 25655 ( 527) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
    51021696, /* 25656 ( 527) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  0] -1 */
     1433658, /* 25657 ( 527) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  0]  1 */
       16484, /* 25658 ( 528) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    18557708, /* 25659 ( 528) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    34146644, /* 25660 ( 528) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
     1420376, /* 25661 ( 528) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  0]  1 */
    17140530, /* 25662 ( 528) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  6]  1 */
    35550860, /* 25663 ( 528) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
    34133682, /* 25664 ( 528) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
     1433658, /* 25665 ( 528) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  0]  1 */
    17127572, /* 25666 ( 528) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
        3198, /* 25667 ( 528) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    18544746, /* 25668 ( 528) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
    52451996, /* 25669 ( 528) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
    51021536, /* 25670 ( 528) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  0] -1 */
    52438710, /* 25671 ( 528) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
    35563818, /* 25672 ( 528) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  6] -1 */
    51034818, /* 25673 ( 528) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  0] -1 */
       16484, /* 25674 ( 529) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    18557708, /* 25675 ( 529) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    35432760, /* 25676 ( 529) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  0] -1 */
     1420376, /* 25677 ( 529) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  0]  1 */
    17140530, /* 25678 ( 529) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  6]  1 */
    51139632, /* 25679 ( 529) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  6] -1 */
    34015586, /* 25680 ( 529) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    52570092, /* 25681 ( 529) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    51152918, /* 25682 ( 529) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
        3198, /* 25683 ( 529) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    18544746, /* 25684 ( 529) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
    17127572, /* 25685 ( 529) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
    52556810, /* 25686 ( 529) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
     1433658, /* 25687 ( 529) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  0]  1 */
    35445722, /* 25688 ( 529) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  0] -1 */
    34028544, /* 25689 ( 529) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
       16484, /* 25690 ( 530) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    51152916, /* 25691 ( 530) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6] -1 */
    18557708, /* 25692 ( 530) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
     1420376, /* 25693 ( 530) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  0]  1 */
    17140530, /* 25694 ( 530) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  6]  1 */
    34028546, /* 25695 ( 530) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
     1433658, /* 25696 ( 530) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  0]  1 */
    17127572, /* 25697 ( 530) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
        3198, /* 25698 ( 530) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    18544746, /* 25699 ( 530) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
    35432762, /* 25700 ( 530) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  0] -1 */
    35445720, /* 25701 ( 530) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  0] -1 */
    34015584, /* 25702 ( 530) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    51139634, /* 25703 ( 530) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
    52570094, /* 25704 ( 530) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    52556808, /* 25705 ( 530) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
       16484, /* 25706 ( 531) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    17140692, /* 25707 ( 531) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6]  1 */
    18439608, /* 25708 ( 531) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
     1551596, /* 25709 ( 531) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
    18426650, /* 25710 ( 531) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
        3198, /* 25711 ( 531) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    17127410, /* 25712 ( 531) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
     1538634, /* 25713 ( 531) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
       16484, /* 25714 ( 532) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    17140692, /* 25715 ( 532) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6]  1 */
    18439608, /* 25716 ( 532) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
    34015422, /* 25717 ( 532) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    35563820, /* 25718 ( 532) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
    52438874, /* 25719 ( 532) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
     1551596, /* 25720 ( 532) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
    51139634, /* 25721 ( 532) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
    18426650, /* 25722 ( 532) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
        3198, /* 25723 ( 532) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    17127410, /* 25724 ( 532) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
    51152916, /* 25725 ( 532) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6] -1 */
    35550858, /* 25726 ( 532) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6] -1 */
    34028708, /* 25727 ( 532) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    52451832, /* 25728 ( 532) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
     1538634, /* 25729 ( 532) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
       16484, /* 25730 ( 533) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34015422, /* 25731 ( 533) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    18439608, /* 25732 ( 533) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
    17140692, /* 25733 ( 533) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6]  1 */
    52438874, /* 25734 ( 533) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
     1551596, /* 25735 ( 533) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
    51139634, /* 25736 ( 533) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
    35550858, /* 25737 ( 533) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6] -1 */
       16484, /* 25738 ( 534) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    17140692, /* 25739 ( 534) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6]  1 */
    35563820, /* 25740 ( 534) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
    52438874, /* 25741 ( 534) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
        3198, /* 25742 ( 534) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    17127410, /* 25743 ( 534) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
    35550858, /* 25744 ( 534) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6] -1 */
    52451832, /* 25745 ( 534) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
       16484, /* 25746 ( 535) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34015422, /* 25747 ( 535) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    18439608, /* 25748 ( 535) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
    52438874, /* 25749 ( 535) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
    17127410, /* 25750 ( 535) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
    51152916, /* 25751 ( 535) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6] -1 */
    35563820, /* 25752 ( 535) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
     1538634, /* 25753 ( 535) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
       16484, /* 25754 ( 536) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34133522, /* 25755 ( 536) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    17140692, /* 25756 ( 536) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6]  1 */
    18439608, /* 25757 ( 536) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
    51034820, /* 25758 ( 536) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  0] -1 */
    52569932, /* 25759 ( 536) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
     1551596, /* 25760 ( 536) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
    35432762, /* 25761 ( 536) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  0] -1 */
    18426650, /* 25762 ( 536) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
        3198, /* 25763 ( 536) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    51021534, /* 25764 ( 536) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  0] -1 */
    35445720, /* 25765 ( 536) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  0] -1 */
    17127410, /* 25766 ( 536) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
    52556970, /* 25767 ( 536) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    34146804, /* 25768 ( 536) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
     1538634, /* 25769 ( 536) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
       16484, /* 25770 ( 537) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34015586, /* 25771 ( 537) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    51139794, /* 25772 ( 537) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6] -1 */
    17140692, /* 25773 ( 537) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6]  1 */
    18439608, /* 25774 ( 537) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
    52438710, /* 25775 ( 537) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
    51152756, /* 25776 ( 537) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
     1551596, /* 25777 ( 537) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
    35563980, /* 25778 ( 537) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6] -1 */
    52451996, /* 25779 ( 537) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
        3198, /* 25780 ( 537) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    18426650, /* 25781 ( 537) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    17127410, /* 25782 ( 537) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
    35550698, /* 25783 ( 537) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
    34028544, /* 25784 ( 537) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
     1538634, /* 25785 ( 537) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
       16484, /* 25786 ( 538) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    35445882, /* 25787 ( 538) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  0] -1 */
    17140692, /* 25788 ( 538) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6]  1 */
    18439608, /* 25789 ( 538) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
    35432600, /* 25790 ( 538) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  0] -1 */
     1551596, /* 25791 ( 538) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
    51034658, /* 25792 ( 538) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  0] -1 */
     1538634, /* 25793 ( 538) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
    18426650, /* 25794 ( 538) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
        3198, /* 25795 ( 538) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    34133684, /* 25796 ( 538) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    17127410, /* 25797 ( 538) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
    34146642, /* 25798 ( 538) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
    51021696, /* 25799 ( 538) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  0] -1 */
    52570094, /* 25800 ( 538) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    52556808, /* 25801 ( 538) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
       16484, /* 25802 ( 531) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
     1551756, /* 25803 ( 531) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
    18426648, /* 25804 ( 531) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
    17127572, /* 25805 ( 531) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
    18439610, /* 25806 ( 531) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
        3198, /* 25807 ( 531) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
     1538474, /* 25808 ( 531) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
    17140530, /* 25809 ( 531) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  6]  1 */
       16484, /* 25810 ( 532) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
     1551756, /* 25811 ( 532) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
    18426648, /* 25812 ( 532) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
    34015422, /* 25813 ( 532) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    51139796, /* 25814 ( 532) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
    52451834, /* 25815 ( 532) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
    17127572, /* 25816 ( 532) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
    35550698, /* 25817 ( 532) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
    18439610, /* 25818 ( 532) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
        3198, /* 25819 ( 532) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
     1538474, /* 25820 ( 532) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
    35563980, /* 25821 ( 532) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6] -1 */
    51152754, /* 25822 ( 532) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  6] -1 */
    34028708, /* 25823 ( 532) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    52438872, /* 25824 ( 532) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
    17140530, /* 25825 ( 532) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  6]  1 */
       16484, /* 25826 ( 533) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34015422, /* 25827 ( 533) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    18426648, /* 25828 ( 533) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
     1551756, /* 25829 ( 533) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
    52451834, /* 25830 ( 533) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
    17127572, /* 25831 ( 533) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
    35550698, /* 25832 ( 533) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
    51152754, /* 25833 ( 533) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  6] -1 */
       16484, /* 25834 ( 534) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
     1551756, /* 25835 ( 534) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
    51139796, /* 25836 ( 534) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
    52451834, /* 25837 ( 534) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
        3198, /* 25838 ( 534) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
     1538474, /* 25839 ( 534) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
    51152754, /* 25840 ( 534) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  6] -1 */
    52438872, /* 25841 ( 534) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
       16484, /* 25842 ( 535) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34015422, /* 25843 ( 535) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    18426648, /* 25844 ( 535) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
    52451834, /* 25845 ( 535) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
     1538474, /* 25846 ( 535) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
    35563980, /* 25847 ( 535) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6] -1 */
    51139796, /* 25848 ( 535) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
    17140530, /* 25849 ( 535) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  6]  1 */
       16484, /* 25850 ( 536) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34133522, /* 25851 ( 536) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
     1551756, /* 25852 ( 536) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
    18426648, /* 25853 ( 536) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
    35445884, /* 25854 ( 536) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  0] -1 */
    52556972, /* 25855 ( 536) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    17127572, /* 25856 ( 536) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
    51034658, /* 25857 ( 536) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  0] -1 */
    18439610, /* 25858 ( 536) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
        3198, /* 25859 ( 536) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    35432598, /* 25860 ( 536) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  0] -1 */
    51021696, /* 25861 ( 536) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  0] -1 */
     1538474, /* 25862 ( 536) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
    52569930, /* 25863 ( 536) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    34146804, /* 25864 ( 536) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
    17140530, /* 25865 ( 536) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  6]  1 */
       16484, /* 25866 ( 537) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34028546, /* 25867 ( 537) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    35563818, /* 25868 ( 537) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  6] -1 */
     1551756, /* 25869 ( 537) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
    18426648, /* 25870 ( 537) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
    52438710, /* 25871 ( 537) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
    35550860, /* 25872 ( 537) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
    17127572, /* 25873 ( 537) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
    51152916, /* 25874 ( 537) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6] -1 */
    52451996, /* 25875 ( 537) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
        3198, /* 25876 ( 537) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    18439610, /* 25877 ( 537) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
     1538474, /* 25878 ( 537) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
    51139634, /* 25879 ( 537) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
    34015584, /* 25880 ( 537) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    17140530, /* 25881 ( 537) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  6]  1 */
       16484, /* 25882 ( 538) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    51034818, /* 25883 ( 538) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  0] -1 */
     1551756, /* 25884 ( 538) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
    18426648, /* 25885 ( 538) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
    51021536, /* 25886 ( 538) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  0] -1 */
    17127572, /* 25887 ( 538) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
    35432762, /* 25888 ( 538) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  0] -1 */
    17140530, /* 25889 ( 538) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  6]  1 */
    18439610, /* 25890 ( 538) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
        3198, /* 25891 ( 538) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    34146644, /* 25892 ( 538) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
     1538474, /* 25893 ( 538) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
    34133682, /* 25894 ( 538) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
    35445720, /* 25895 ( 538) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  0] -1 */
    52570094, /* 25896 ( 538) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    52556808, /* 25897 ( 538) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
       16484, /* 25898 ( 539) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    17140692, /* 25899 ( 539) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6]  1 */
        3198, /* 25900 ( 539) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
     1420536, /* 25901 ( 539) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  0]  1 */
    17127410, /* 25902 ( 539) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
     1433498, /* 25903 ( 539) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  0]  1 */
    18544748, /* 25904 ( 539) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    18557706, /* 25905 ( 539) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
       16484, /* 25906 ( 540) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    17140692, /* 25907 ( 540) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6]  1 */
    34015422, /* 25908 ( 540) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    35432760, /* 25909 ( 540) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  0] -1 */
    51139634, /* 25910 ( 540) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
     1433498, /* 25911 ( 540) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  0]  1 */
        3198, /* 25912 ( 540) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    35445722, /* 25913 ( 540) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  0] -1 */
     1420536, /* 25914 ( 540) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  0]  1 */
    17127410, /* 25915 ( 540) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
    51152916, /* 25916 ( 540) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6] -1 */
    52556972, /* 25917 ( 540) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    52569930, /* 25918 ( 540) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    34028708, /* 25919 ( 540) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    18544748, /* 25920 ( 540) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    18557706, /* 25921 ( 540) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
       16484, /* 25922 ( 541) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34015422, /* 25923 ( 541) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    17140692, /* 25924 ( 541) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6]  1 */
    35432760, /* 25925 ( 541) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  0] -1 */
    51139634, /* 25926 ( 541) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
    52556972, /* 25927 ( 541) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
     1433498, /* 25928 ( 541) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  0]  1 */
    18557706, /* 25929 ( 541) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
       16484, /* 25930 ( 542) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34015422, /* 25931 ( 542) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    17140692, /* 25932 ( 542) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6]  1 */
    51139634, /* 25933 ( 542) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
    35445722, /* 25934 ( 542) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  0] -1 */
     1420536, /* 25935 ( 542) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  0]  1 */
    52569930, /* 25936 ( 542) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    18544748, /* 25937 ( 542) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
       16484, /* 25938 ( 543) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34015422, /* 25939 ( 543) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    35432760, /* 25940 ( 543) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  0] -1 */
    17127410, /* 25941 ( 543) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
    51152916, /* 25942 ( 543) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6] -1 */
    52569930, /* 25943 ( 543) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
     1433498, /* 25944 ( 543) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  0]  1 */
    18544748, /* 25945 ( 543) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
       16484, /* 25946 ( 544) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    17140692, /* 25947 ( 544) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6]  1 */
    35432760, /* 25948 ( 544) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  0] -1 */
        3198, /* 25949 ( 544) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    35445722, /* 25950 ( 544) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  0] -1 */
    17127410, /* 25951 ( 544) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
    52556972, /* 25952 ( 544) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    52569930, /* 25953 ( 544) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
       16484, /* 25954 ( 545) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    35432760, /* 25955 ( 545) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  0] -1 */
    51139634, /* 25956 ( 545) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
        3198, /* 25957 ( 545) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    35445722, /* 25958 ( 545) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  0] -1 */
    51152916, /* 25959 ( 545) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6] -1 */
    18544748, /* 25960 ( 545) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    18557706, /* 25961 ( 545) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
       16484, /* 25962 ( 546) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    51139634, /* 25963 ( 546) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
        3198, /* 25964 ( 546) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
     1420536, /* 25965 ( 546) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  0]  1 */
    52556972, /* 25966 ( 546) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    51152916, /* 25967 ( 546) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6] -1 */
    52569930, /* 25968 ( 546) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
     1433498, /* 25969 ( 546) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  0]  1 */
       16484, /* 25970 ( 547) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34015422, /* 25971 ( 547) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    35445722, /* 25972 ( 547) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  0] -1 */
     1420536, /* 25973 ( 547) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  0]  1 */
    17127410, /* 25974 ( 547) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
    51152916, /* 25975 ( 547) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6] -1 */
    52556972, /* 25976 ( 547) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    18557706, /* 25977 ( 547) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
       16484, /* 25978 ( 548) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    52451834, /* 25979 ( 548) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
    34133522, /* 25980 ( 548) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    17140692, /* 25981 ( 548) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6]  1 */
    35563818, /* 25982 ( 548) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  6] -1 */
    51034820, /* 25983 ( 548) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  0] -1 */
    35550860, /* 25984 ( 548) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
    52438872, /* 25985 ( 548) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
        3198, /* 25986 ( 548) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    51021534, /* 25987 ( 548) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  0] -1 */
     1420536, /* 25988 ( 548) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  0]  1 */
    17127410, /* 25989 ( 548) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
    34146804, /* 25990 ( 548) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
     1433498, /* 25991 ( 548) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  0]  1 */
    18544748, /* 25992 ( 548) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    18557706, /* 25993 ( 548) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
       16484, /* 25994 ( 549) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34028546, /* 25995 ( 549) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    17140692, /* 25996 ( 549) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6]  1 */
    52556810, /* 25997 ( 549) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    34015584, /* 25998 ( 549) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    51139796, /* 25999 ( 549) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
        3198, /* 26000 ( 549) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
     1420536, /* 26001 ( 549) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  0]  1 */
    35445884, /* 26002 ( 549) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  0] -1 */
    17127410, /* 26003 ( 549) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
    51152754, /* 26004 ( 549) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  6] -1 */
    35432598, /* 26005 ( 549) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  0] -1 */
    52570092, /* 26006 ( 549) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
     1433498, /* 26007 ( 549) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  0]  1 */
    18544748, /* 26008 ( 549) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    18557706, /* 26009 ( 549) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
       16484, /* 26010 ( 550) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    17140692, /* 26011 ( 550) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6]  1 */
    35563820, /* 26012 ( 550) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
    52438874, /* 26013 ( 550) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
    51034818, /* 26014 ( 550) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  0] -1 */
    34133520, /* 26015 ( 550) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
        3198, /* 26016 ( 550) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    34146806, /* 26017 ( 550) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    17127410, /* 26018 ( 550) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
     1420536, /* 26019 ( 550) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  0]  1 */
    51021536, /* 26020 ( 550) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  0] -1 */
    35550858, /* 26021 ( 550) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6] -1 */
     1433498, /* 26022 ( 550) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  0]  1 */
    18544748, /* 26023 ( 550) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    52451832, /* 26024 ( 550) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
    18557706, /* 26025 ( 550) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
       16484, /* 26026 ( 551) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    35550696, /* 26027 ( 551) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  6] -1 */
    17140692, /* 26028 ( 551) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6]  1 */
    51021698, /* 26029 ( 551) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  0] -1 */
    34146644, /* 26030 ( 551) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    51034656, /* 26031 ( 551) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  0] -1 */
    35563982, /* 26032 ( 551) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
    52451994, /* 26033 ( 551) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
        3198, /* 26034 ( 551) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
     1420536, /* 26035 ( 551) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  0]  1 */
    17127410, /* 26036 ( 551) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
    34133682, /* 26037 ( 551) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
    52438712, /* 26038 ( 551) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
     1433498, /* 26039 ( 551) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  0]  1 */
    18544748, /* 26040 ( 551) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    18557706, /* 26041 ( 551) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
       16484, /* 26042 ( 552) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    17140692, /* 26043 ( 552) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6]  1 */
    52569932, /* 26044 ( 552) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    34028706, /* 26045 ( 552) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    35432762, /* 26046 ( 552) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  0] -1 */
    35445720, /* 26047 ( 552) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  0] -1 */
        3198, /* 26048 ( 552) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
     1420536, /* 26049 ( 552) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  0]  1 */
    17127410, /* 26050 ( 552) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
    52556970, /* 26051 ( 552) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    51152918, /* 26052 ( 552) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
     1433498, /* 26053 ( 552) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  0]  1 */
    51139632, /* 26054 ( 552) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  6] -1 */
    18544748, /* 26055 ( 552) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    34015424, /* 26056 ( 552) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    18557706, /* 26057 ( 552) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
       16484, /* 26058 ( 553) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    17140692, /* 26059 ( 553) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6]  1 */
    52438710, /* 26060 ( 553) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
    51034658, /* 26061 ( 553) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  0] -1 */
    35563980, /* 26062 ( 553) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6] -1 */
     1433498, /* 26063 ( 553) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  0]  1 */
    52451996, /* 26064 ( 553) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
        3198, /* 26065 ( 553) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
     1420536, /* 26066 ( 553) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  0]  1 */
    17127410, /* 26067 ( 553) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
    34133684, /* 26068 ( 553) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    35550698, /* 26069 ( 553) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
    51021696, /* 26070 ( 553) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  0] -1 */
    34146642, /* 26071 ( 553) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
    18544748, /* 26072 ( 553) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    18557706, /* 26073 ( 553) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
       16484, /* 26074 ( 554) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    35445882, /* 26075 ( 554) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  0] -1 */
    34015586, /* 26076 ( 554) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    17140692, /* 26077 ( 554) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6]  1 */
    51139794, /* 26078 ( 554) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6] -1 */
    51152756, /* 26079 ( 554) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
    35432600, /* 26080 ( 554) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  0] -1 */
        3198, /* 26081 ( 554) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    18544748, /* 26082 ( 554) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    52556808, /* 26083 ( 554) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    17127410, /* 26084 ( 554) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
     1420536, /* 26085 ( 554) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  0]  1 */
     1433498, /* 26086 ( 554) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  0]  1 */
    52570094, /* 26087 ( 554) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    34028544, /* 26088 ( 554) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    18557706, /* 26089 ( 554) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
       16484, /* 26090 ( 539) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
     1551756, /* 26091 ( 539) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
        3198, /* 26092 ( 539) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    17022432, /* 26093 ( 539) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  0]  1 */
     1538474, /* 26094 ( 539) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
    17009474, /* 26095 ( 539) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  0]  1 */
    18557708, /* 26096 ( 539) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    18544746, /* 26097 ( 539) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
       16484, /* 26098 ( 540) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
     1551756, /* 26099 ( 540) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
    34015422, /* 26100 ( 540) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    51034656, /* 26101 ( 540) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  0] -1 */
    35550698, /* 26102 ( 540) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
    17009474, /* 26103 ( 540) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  0]  1 */
        3198, /* 26104 ( 540) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    51021698, /* 26105 ( 540) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  0] -1 */
    17022432, /* 26106 ( 540) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  0]  1 */
     1538474, /* 26107 ( 540) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
    35563980, /* 26108 ( 540) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6] -1 */
    52569932, /* 26109 ( 540) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    52556970, /* 26110 ( 540) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    34028708, /* 26111 ( 540) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    18557708, /* 26112 ( 540) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    18544746, /* 26113 ( 540) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
       16484, /* 26114 ( 541) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34015422, /* 26115 ( 541) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
     1551756, /* 26116 ( 541) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
    51034656, /* 26117 ( 541) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  0] -1 */
    35550698, /* 26118 ( 541) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
    52569932, /* 26119 ( 541) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    17009474, /* 26120 ( 541) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  0]  1 */
    18544746, /* 26121 ( 541) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
       16484, /* 26122 ( 542) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34015422, /* 26123 ( 542) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
     1551756, /* 26124 ( 542) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
    35550698, /* 26125 ( 542) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
    51021698, /* 26126 ( 542) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  0] -1 */
    17022432, /* 26127 ( 542) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  0]  1 */
    52556970, /* 26128 ( 542) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    18557708, /* 26129 ( 542) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
       16484, /* 26130 ( 543) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34015422, /* 26131 ( 543) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    51034656, /* 26132 ( 543) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  0] -1 */
     1538474, /* 26133 ( 543) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
    35563980, /* 26134 ( 543) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6] -1 */
    52556970, /* 26135 ( 543) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    17009474, /* 26136 ( 543) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  0]  1 */
    18557708, /* 26137 ( 543) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
       16484, /* 26138 ( 544) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
     1551756, /* 26139 ( 544) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
    51034656, /* 26140 ( 544) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  0] -1 */
        3198, /* 26141 ( 544) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    51021698, /* 26142 ( 544) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  0] -1 */
     1538474, /* 26143 ( 544) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
    52569932, /* 26144 ( 544) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    52556970, /* 26145 ( 544) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
       16484, /* 26146 ( 545) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    51034656, /* 26147 ( 545) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  0] -1 */
    35550698, /* 26148 ( 545) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
        3198, /* 26149 ( 545) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    51021698, /* 26150 ( 545) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  0] -1 */
    35563980, /* 26151 ( 545) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6] -1 */
    18557708, /* 26152 ( 545) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    18544746, /* 26153 ( 545) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
       16484, /* 26154 ( 546) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    35550698, /* 26155 ( 546) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
        3198, /* 26156 ( 546) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    17022432, /* 26157 ( 546) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  0]  1 */
    52569932, /* 26158 ( 546) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    35563980, /* 26159 ( 546) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6] -1 */
    52556970, /* 26160 ( 546) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    17009474, /* 26161 ( 546) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  0]  1 */
       16484, /* 26162 ( 547) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34015422, /* 26163 ( 547) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    51021698, /* 26164 ( 547) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  0] -1 */
    17022432, /* 26165 ( 547) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  0]  1 */
     1538474, /* 26166 ( 547) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
    35563980, /* 26167 ( 547) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6] -1 */
    52569932, /* 26168 ( 547) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    18544746, /* 26169 ( 547) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
       16484, /* 26170 ( 548) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    52438874, /* 26171 ( 548) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
    34133522, /* 26172 ( 548) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
     1551756, /* 26173 ( 548) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
    51139794, /* 26174 ( 548) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6] -1 */
    35445884, /* 26175 ( 548) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  0] -1 */
    51152756, /* 26176 ( 548) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
    52451832, /* 26177 ( 548) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
        3198, /* 26178 ( 548) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    35432598, /* 26179 ( 548) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  0] -1 */
    17022432, /* 26180 ( 548) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  0]  1 */
     1538474, /* 26181 ( 548) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
    34146804, /* 26182 ( 548) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
    17009474, /* 26183 ( 548) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  0]  1 */
    18557708, /* 26184 ( 548) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    18544746, /* 26185 ( 548) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
       16484, /* 26186 ( 549) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34015586, /* 26187 ( 549) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
     1551756, /* 26188 ( 549) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
    52556810, /* 26189 ( 549) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    34028544, /* 26190 ( 549) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    35563820, /* 26191 ( 549) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
        3198, /* 26192 ( 549) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    17022432, /* 26193 ( 549) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  0]  1 */
    51034820, /* 26194 ( 549) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  0] -1 */
     1538474, /* 26195 ( 549) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
    35550858, /* 26196 ( 549) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6] -1 */
    51021534, /* 26197 ( 549) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  0] -1 */
    52570092, /* 26198 ( 549) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    17009474, /* 26199 ( 549) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  0]  1 */
    18557708, /* 26200 ( 549) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    18544746, /* 26201 ( 549) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
       16484, /* 26202 ( 550) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
     1551756, /* 26203 ( 550) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
    51139796, /* 26204 ( 550) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
    52451834, /* 26205 ( 550) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
    35445882, /* 26206 ( 550) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  0] -1 */
    34133520, /* 26207 ( 550) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
        3198, /* 26208 ( 550) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    34146806, /* 26209 ( 550) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
     1538474, /* 26210 ( 550) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
    17022432, /* 26211 ( 550) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  0]  1 */
    35432600, /* 26212 ( 550) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  0] -1 */
    51152754, /* 26213 ( 550) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  6] -1 */
    17009474, /* 26214 ( 550) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  0]  1 */
    18557708, /* 26215 ( 550) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    52438872, /* 26216 ( 550) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
    18544746, /* 26217 ( 550) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
       16484, /* 26218 ( 551) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    51139632, /* 26219 ( 551) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  6] -1 */
     1551756, /* 26220 ( 551) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
    35445722, /* 26221 ( 551) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  0] -1 */
    34133684, /* 26222 ( 551) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    35432760, /* 26223 ( 551) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  0] -1 */
    51152918, /* 26224 ( 551) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
    52451994, /* 26225 ( 551) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
        3198, /* 26226 ( 551) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    17022432, /* 26227 ( 551) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  0]  1 */
     1538474, /* 26228 ( 551) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
    34146642, /* 26229 ( 551) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
    52438712, /* 26230 ( 551) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
    17009474, /* 26231 ( 551) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  0]  1 */
    18557708, /* 26232 ( 551) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    18544746, /* 26233 ( 551) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
       16484, /* 26234 ( 552) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
     1551756, /* 26235 ( 552) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
    52556972, /* 26236 ( 552) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    34028706, /* 26237 ( 552) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    51034658, /* 26238 ( 552) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  0] -1 */
    51021696, /* 26239 ( 552) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  0] -1 */
        3198, /* 26240 ( 552) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    17022432, /* 26241 ( 552) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  0]  1 */
     1538474, /* 26242 ( 552) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
    52569930, /* 26243 ( 552) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    35563982, /* 26244 ( 552) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
    17009474, /* 26245 ( 552) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  0]  1 */
    35550696, /* 26246 ( 552) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  6] -1 */
    18557708, /* 26247 ( 552) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    34015424, /* 26248 ( 552) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    18544746, /* 26249 ( 552) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
       16484, /* 26250 ( 553) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
     1551756, /* 26251 ( 553) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
    52438710, /* 26252 ( 553) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
    35432762, /* 26253 ( 553) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  0] -1 */
    51152916, /* 26254 ( 553) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6] -1 */
    17009474, /* 26255 ( 553) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  0]  1 */
    52451996, /* 26256 ( 553) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
        3198, /* 26257 ( 553) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    17022432, /* 26258 ( 553) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  0]  1 */
     1538474, /* 26259 ( 553) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
    34146644, /* 26260 ( 553) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    51139634, /* 26261 ( 553) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
    35445720, /* 26262 ( 553) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  0] -1 */
    34133682, /* 26263 ( 553) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
    18557708, /* 26264 ( 553) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    18544746, /* 26265 ( 553) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
       16484, /* 26266 ( 554) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    51034818, /* 26267 ( 554) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  0] -1 */
    34028546, /* 26268 ( 554) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
     1551756, /* 26269 ( 554) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
    35563818, /* 26270 ( 554) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  6] -1 */
    35550860, /* 26271 ( 554) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
    51021536, /* 26272 ( 554) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  0] -1 */
        3198, /* 26273 ( 554) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    18557708, /* 26274 ( 554) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    52556808, /* 26275 ( 554) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
     1538474, /* 26276 ( 554) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
    17022432, /* 26277 ( 554) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  0]  1 */
    17009474, /* 26278 ( 554) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  0]  1 */
    52570094, /* 26279 ( 554) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    34015584, /* 26280 ( 554) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    18544746, /* 26281 ( 554) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
       16484, /* 26282 ( 539) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    18426650, /* 26283 ( 539) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
        3198, /* 26284 ( 539) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
      121298, /* 26285 ( 539) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6]  1 */
    18439608, /* 26286 ( 539) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
      134580, /* 26287 ( 539) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  6]  1 */
    18557708, /* 26288 ( 539) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    18544746, /* 26289 ( 539) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
       16484, /* 26290 ( 540) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    18426650, /* 26291 ( 540) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    34015422, /* 26292 ( 540) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    34133522, /* 26293 ( 540) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    52451832, /* 26294 ( 540) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
      134580, /* 26295 ( 540) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  6]  1 */
        3198, /* 26296 ( 540) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    34146804, /* 26297 ( 540) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
      121298, /* 26298 ( 540) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6]  1 */
    18439608, /* 26299 ( 540) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
    52438874, /* 26300 ( 540) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
    52569932, /* 26301 ( 540) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    52556970, /* 26302 ( 540) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    34028708, /* 26303 ( 540) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    18557708, /* 26304 ( 540) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    18544746, /* 26305 ( 540) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
       16484, /* 26306 ( 541) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34015422, /* 26307 ( 541) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    18426650, /* 26308 ( 541) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    34133522, /* 26309 ( 541) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    52451832, /* 26310 ( 541) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
    52569932, /* 26311 ( 541) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
      134580, /* 26312 ( 541) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  6]  1 */
    18544746, /* 26313 ( 541) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
       16484, /* 26314 ( 542) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34015422, /* 26315 ( 542) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    18426650, /* 26316 ( 542) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    52451832, /* 26317 ( 542) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
    34146804, /* 26318 ( 542) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
      121298, /* 26319 ( 542) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6]  1 */
    52556970, /* 26320 ( 542) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    18557708, /* 26321 ( 542) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
       16484, /* 26322 ( 543) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34015422, /* 26323 ( 543) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    34133522, /* 26324 ( 543) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    18439608, /* 26325 ( 543) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
    52438874, /* 26326 ( 543) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
    52556970, /* 26327 ( 543) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
      134580, /* 26328 ( 543) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  6]  1 */
    18557708, /* 26329 ( 543) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
       16484, /* 26330 ( 544) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    18426650, /* 26331 ( 544) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    34133522, /* 26332 ( 544) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
        3198, /* 26333 ( 544) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    34146804, /* 26334 ( 544) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
    18439608, /* 26335 ( 544) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
    52569932, /* 26336 ( 544) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    52556970, /* 26337 ( 544) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
       16484, /* 26338 ( 545) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34133522, /* 26339 ( 545) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    52451832, /* 26340 ( 545) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
        3198, /* 26341 ( 545) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    34146804, /* 26342 ( 545) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
    52438874, /* 26343 ( 545) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
    18557708, /* 26344 ( 545) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    18544746, /* 26345 ( 545) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
       16484, /* 26346 ( 546) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    52451832, /* 26347 ( 546) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
        3198, /* 26348 ( 546) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
      121298, /* 26349 ( 546) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6]  1 */
    52569932, /* 26350 ( 546) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    52438874, /* 26351 ( 546) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
    52556970, /* 26352 ( 546) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
      134580, /* 26353 ( 546) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  6]  1 */
       16484, /* 26354 ( 547) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34015422, /* 26355 ( 547) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    34146804, /* 26356 ( 547) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
      121298, /* 26357 ( 547) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6]  1 */
    18439608, /* 26358 ( 547) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
    52438874, /* 26359 ( 547) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
    52569932, /* 26360 ( 547) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    18544746, /* 26361 ( 547) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
       16484, /* 26362 ( 548) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    35563980, /* 26363 ( 548) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6] -1 */
    51034656, /* 26364 ( 548) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  0] -1 */
    18426650, /* 26365 ( 548) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    51139794, /* 26366 ( 548) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6] -1 */
    35445884, /* 26367 ( 548) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  0] -1 */
    51152756, /* 26368 ( 548) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
    35550698, /* 26369 ( 548) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
        3198, /* 26370 ( 548) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    35432598, /* 26371 ( 548) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  0] -1 */
      121298, /* 26372 ( 548) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6]  1 */
    18439608, /* 26373 ( 548) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
    51021698, /* 26374 ( 548) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  0] -1 */
      134580, /* 26375 ( 548) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  6]  1 */
    18557708, /* 26376 ( 548) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    18544746, /* 26377 ( 548) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
       16484, /* 26378 ( 549) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34028706, /* 26379 ( 549) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    18426650, /* 26380 ( 549) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    52569930, /* 26381 ( 549) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    34015424, /* 26382 ( 549) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    52451834, /* 26383 ( 549) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
        3198, /* 26384 ( 549) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
      121298, /* 26385 ( 549) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6]  1 */
    34146806, /* 26386 ( 549) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    18439608, /* 26387 ( 549) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
    52438872, /* 26388 ( 549) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
    34133520, /* 26389 ( 549) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
    52556972, /* 26390 ( 549) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
      134580, /* 26391 ( 549) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  6]  1 */
    18557708, /* 26392 ( 549) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    18544746, /* 26393 ( 549) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
       16484, /* 26394 ( 550) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    18426650, /* 26395 ( 550) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    51152916, /* 26396 ( 550) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6] -1 */
    35563820, /* 26397 ( 550) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
    35432762, /* 26398 ( 550) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  0] -1 */
    51021534, /* 26399 ( 550) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  0] -1 */
        3198, /* 26400 ( 550) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    51034820, /* 26401 ( 550) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  0] -1 */
    18439608, /* 26402 ( 550) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
      121298, /* 26403 ( 550) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6]  1 */
    35445720, /* 26404 ( 550) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  0] -1 */
    51139634, /* 26405 ( 550) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
      134580, /* 26406 ( 550) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  6]  1 */
    18557708, /* 26407 ( 550) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    35550858, /* 26408 ( 550) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6] -1 */
    18544746, /* 26409 ( 550) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
       16484, /* 26410 ( 551) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    51139632, /* 26411 ( 551) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  6] -1 */
    18426650, /* 26412 ( 551) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    35445722, /* 26413 ( 551) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  0] -1 */
    51034818, /* 26414 ( 551) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  0] -1 */
    35432760, /* 26415 ( 551) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  0] -1 */
    51152918, /* 26416 ( 551) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
    35550860, /* 26417 ( 551) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
        3198, /* 26418 ( 551) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
      121298, /* 26419 ( 551) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6]  1 */
    18439608, /* 26420 ( 551) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
    51021536, /* 26421 ( 551) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  0] -1 */
    35563818, /* 26422 ( 551) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  6] -1 */
      134580, /* 26423 ( 551) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  6]  1 */
    18557708, /* 26424 ( 551) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    18544746, /* 26425 ( 551) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
       16484, /* 26426 ( 552) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    18426650, /* 26427 ( 552) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    52570092, /* 26428 ( 552) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    34015586, /* 26429 ( 552) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    34146644, /* 26430 ( 552) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    34133682, /* 26431 ( 552) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
        3198, /* 26432 ( 552) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
      121298, /* 26433 ( 552) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6]  1 */
    18439608, /* 26434 ( 552) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
    52556810, /* 26435 ( 552) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    52451996, /* 26436 ( 552) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
      134580, /* 26437 ( 552) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  6]  1 */
    52438710, /* 26438 ( 552) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
    18557708, /* 26439 ( 552) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    34028544, /* 26440 ( 552) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    18544746, /* 26441 ( 552) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
       16484, /* 26442 ( 553) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    18426650, /* 26443 ( 553) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    35550696, /* 26444 ( 553) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  6] -1 */
    35445882, /* 26445 ( 553) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  0] -1 */
    51139796, /* 26446 ( 553) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
      134580, /* 26447 ( 553) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  6]  1 */
    35563982, /* 26448 ( 553) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
        3198, /* 26449 ( 553) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
      121298, /* 26450 ( 553) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6]  1 */
    18439608, /* 26451 ( 553) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
    51034658, /* 26452 ( 553) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  0] -1 */
    51152754, /* 26453 ( 553) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  6] -1 */
    35432600, /* 26454 ( 553) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  0] -1 */
    51021696, /* 26455 ( 553) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  0] -1 */
    18557708, /* 26456 ( 553) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    18544746, /* 26457 ( 553) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
       16484, /* 26458 ( 554) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34133684, /* 26459 ( 554) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    34028546, /* 26460 ( 554) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    18426650, /* 26461 ( 554) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    52438712, /* 26462 ( 554) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
    52451994, /* 26463 ( 554) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
    34146642, /* 26464 ( 554) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
        3198, /* 26465 ( 554) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    18557708, /* 26466 ( 554) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    52556808, /* 26467 ( 554) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    18439608, /* 26468 ( 554) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
      121298, /* 26469 ( 554) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6]  1 */
      134580, /* 26470 ( 554) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  6]  1 */
    52570094, /* 26471 ( 554) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    34015584, /* 26472 ( 554) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    18544746, /* 26473 ( 554) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
       16484, /* 26474 ( 539) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    17127572, /* 26475 ( 539) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
        3198, /* 26476 ( 539) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
     1420536, /* 26477 ( 539) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  0]  1 */
    17140530, /* 26478 ( 539) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  6]  1 */
     1433498, /* 26479 ( 539) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  0]  1 */
    18557868, /* 26480 ( 539) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
    18544586, /* 26481 ( 539) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
       16484, /* 26482 ( 540) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    17127572, /* 26483 ( 540) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
    34015422, /* 26484 ( 540) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    35432760, /* 26485 ( 540) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  0] -1 */
    51152754, /* 26486 ( 540) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  6] -1 */
     1433498, /* 26487 ( 540) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  0]  1 */
        3198, /* 26488 ( 540) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    35445722, /* 26489 ( 540) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  0] -1 */
     1420536, /* 26490 ( 540) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  0]  1 */
    17140530, /* 26491 ( 540) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  6]  1 */
    51139796, /* 26492 ( 540) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
    52570092, /* 26493 ( 540) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    52556810, /* 26494 ( 540) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    34028708, /* 26495 ( 540) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    18557868, /* 26496 ( 540) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
    18544586, /* 26497 ( 540) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
       16484, /* 26498 ( 541) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34015422, /* 26499 ( 541) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    17127572, /* 26500 ( 541) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
    35432760, /* 26501 ( 541) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  0] -1 */
    51152754, /* 26502 ( 541) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  6] -1 */
    52570092, /* 26503 ( 541) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
     1433498, /* 26504 ( 541) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  0]  1 */
    18544586, /* 26505 ( 541) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
       16484, /* 26506 ( 542) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34015422, /* 26507 ( 542) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    17127572, /* 26508 ( 542) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
    51152754, /* 26509 ( 542) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  6] -1 */
    35445722, /* 26510 ( 542) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  0] -1 */
     1420536, /* 26511 ( 542) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  0]  1 */
    52556810, /* 26512 ( 542) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    18557868, /* 26513 ( 542) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
       16484, /* 26514 ( 543) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34015422, /* 26515 ( 543) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    35432760, /* 26516 ( 543) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  0] -1 */
    17140530, /* 26517 ( 543) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  6]  1 */
    51139796, /* 26518 ( 543) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
    52556810, /* 26519 ( 543) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
     1433498, /* 26520 ( 543) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  0]  1 */
    18557868, /* 26521 ( 543) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
       16484, /* 26522 ( 544) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    17127572, /* 26523 ( 544) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
    35432760, /* 26524 ( 544) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  0] -1 */
        3198, /* 26525 ( 544) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    35445722, /* 26526 ( 544) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  0] -1 */
    17140530, /* 26527 ( 544) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  6]  1 */
    52570092, /* 26528 ( 544) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    52556810, /* 26529 ( 544) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
       16484, /* 26530 ( 545) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    35432760, /* 26531 ( 545) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  0] -1 */
    51152754, /* 26532 ( 545) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  6] -1 */
        3198, /* 26533 ( 545) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    35445722, /* 26534 ( 545) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  0] -1 */
    51139796, /* 26535 ( 545) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
    18557868, /* 26536 ( 545) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
    18544586, /* 26537 ( 545) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
       16484, /* 26538 ( 546) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    51152754, /* 26539 ( 546) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  6] -1 */
        3198, /* 26540 ( 546) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
     1420536, /* 26541 ( 546) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  0]  1 */
    52570092, /* 26542 ( 546) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    51139796, /* 26543 ( 546) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
    52556810, /* 26544 ( 546) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
     1433498, /* 26545 ( 546) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  0]  1 */
       16484, /* 26546 ( 547) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34015422, /* 26547 ( 547) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    35445722, /* 26548 ( 547) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  0] -1 */
     1420536, /* 26549 ( 547) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  0]  1 */
    17140530, /* 26550 ( 547) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  6]  1 */
    51139796, /* 26551 ( 547) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
    52570092, /* 26552 ( 547) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    18544586, /* 26553 ( 547) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
       16484, /* 26554 ( 548) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    35563820, /* 26555 ( 548) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
    51034656, /* 26556 ( 548) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  0] -1 */
    17127572, /* 26557 ( 548) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
    52438712, /* 26558 ( 548) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
    34146806, /* 26559 ( 548) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    52451994, /* 26560 ( 548) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
    35550858, /* 26561 ( 548) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6] -1 */
        3198, /* 26562 ( 548) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    34133520, /* 26563 ( 548) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
     1420536, /* 26564 ( 548) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  0]  1 */
    17140530, /* 26565 ( 548) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  6]  1 */
    51021698, /* 26566 ( 548) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  0] -1 */
     1433498, /* 26567 ( 548) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  0]  1 */
    18557868, /* 26568 ( 548) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
    18544586, /* 26569 ( 548) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
       16484, /* 26570 ( 549) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34028546, /* 26571 ( 549) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    17127572, /* 26572 ( 549) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
    52569930, /* 26573 ( 549) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    34015584, /* 26574 ( 549) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    51152916, /* 26575 ( 549) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6] -1 */
        3198, /* 26576 ( 549) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
     1420536, /* 26577 ( 549) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  0]  1 */
    35445884, /* 26578 ( 549) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  0] -1 */
    17140530, /* 26579 ( 549) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  6]  1 */
    51139634, /* 26580 ( 549) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
    35432598, /* 26581 ( 549) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  0] -1 */
    52556972, /* 26582 ( 549) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
     1433498, /* 26583 ( 549) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  0]  1 */
    18557868, /* 26584 ( 549) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
    18544586, /* 26585 ( 549) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
       16484, /* 26586 ( 550) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    17127572, /* 26587 ( 550) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
    52451834, /* 26588 ( 550) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
    35563980, /* 26589 ( 550) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6] -1 */
    34133684, /* 26590 ( 550) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    51021534, /* 26591 ( 550) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  0] -1 */
        3198, /* 26592 ( 550) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    51034820, /* 26593 ( 550) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  0] -1 */
    17140530, /* 26594 ( 550) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  6]  1 */
     1420536, /* 26595 ( 550) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  0]  1 */
    34146642, /* 26596 ( 550) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
    52438872, /* 26597 ( 550) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
     1433498, /* 26598 ( 550) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  0]  1 */
    18557868, /* 26599 ( 550) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
    35550698, /* 26600 ( 550) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
    18544586, /* 26601 ( 550) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
       16484, /* 26602 ( 551) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    52438710, /* 26603 ( 551) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
    17127572, /* 26604 ( 551) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
    34146804, /* 26605 ( 551) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
    51034658, /* 26606 ( 551) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  0] -1 */
    34133522, /* 26607 ( 551) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    52451996, /* 26608 ( 551) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
    35550860, /* 26609 ( 551) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
        3198, /* 26610 ( 551) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
     1420536, /* 26611 ( 551) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  0]  1 */
    17140530, /* 26612 ( 551) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  6]  1 */
    51021696, /* 26613 ( 551) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  0] -1 */
    35563818, /* 26614 ( 551) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  6] -1 */
     1433498, /* 26615 ( 551) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  0]  1 */
    18557868, /* 26616 ( 551) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
    18544586, /* 26617 ( 551) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
       16484, /* 26618 ( 552) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    17127572, /* 26619 ( 552) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
    52569932, /* 26620 ( 552) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    34015586, /* 26621 ( 552) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    35445882, /* 26622 ( 552) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  0] -1 */
    35432600, /* 26623 ( 552) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  0] -1 */
        3198, /* 26624 ( 552) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
     1420536, /* 26625 ( 552) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  0]  1 */
    17140530, /* 26626 ( 552) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  6]  1 */
    52556970, /* 26627 ( 552) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    51152918, /* 26628 ( 552) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
     1433498, /* 26629 ( 552) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  0]  1 */
    51139632, /* 26630 ( 552) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  6] -1 */
    18557868, /* 26631 ( 552) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
    34028544, /* 26632 ( 552) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    18544586, /* 26633 ( 552) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
       16484, /* 26634 ( 553) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    17127572, /* 26635 ( 553) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
    35550696, /* 26636 ( 553) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  6] -1 */
    34146644, /* 26637 ( 553) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    52438874, /* 26638 ( 553) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
     1433498, /* 26639 ( 553) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  0]  1 */
    35563982, /* 26640 ( 553) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
        3198, /* 26641 ( 553) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
     1420536, /* 26642 ( 553) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  0]  1 */
    17140530, /* 26643 ( 553) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  6]  1 */
    51034818, /* 26644 ( 553) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  0] -1 */
    52451832, /* 26645 ( 553) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
    34133682, /* 26646 ( 553) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
    51021536, /* 26647 ( 553) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  0] -1 */
    18557868, /* 26648 ( 553) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
    18544586, /* 26649 ( 553) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
       16484, /* 26650 ( 554) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    35432762, /* 26651 ( 554) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  0] -1 */
    34028706, /* 26652 ( 554) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    17127572, /* 26653 ( 554) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
    51139794, /* 26654 ( 554) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6] -1 */
    51152756, /* 26655 ( 554) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
    35445720, /* 26656 ( 554) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  0] -1 */
        3198, /* 26657 ( 554) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    18557868, /* 26658 ( 554) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
    52556808, /* 26659 ( 554) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    17140530, /* 26660 ( 554) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  6]  1 */
     1420536, /* 26661 ( 554) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  0]  1 */
     1433498, /* 26662 ( 554) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  0]  1 */
    52570094, /* 26663 ( 554) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    34015424, /* 26664 ( 554) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    18544586, /* 26665 ( 554) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
       16484, /* 26666 ( 539) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
     1551596, /* 26667 ( 539) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
        3198, /* 26668 ( 539) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    17022432, /* 26669 ( 539) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  0]  1 */
     1538634, /* 26670 ( 539) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
    17009474, /* 26671 ( 539) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  0]  1 */
    18557868, /* 26672 ( 539) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
    18544586, /* 26673 ( 539) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
       16484, /* 26674 ( 540) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
     1551596, /* 26675 ( 540) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
    34015422, /* 26676 ( 540) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    51034656, /* 26677 ( 540) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  0] -1 */
    35550858, /* 26678 ( 540) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6] -1 */
    17009474, /* 26679 ( 540) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  0]  1 */
        3198, /* 26680 ( 540) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    51021698, /* 26681 ( 540) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  0] -1 */
    17022432, /* 26682 ( 540) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  0]  1 */
     1538634, /* 26683 ( 540) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
    35563820, /* 26684 ( 540) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
    52570092, /* 26685 ( 540) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    52556810, /* 26686 ( 540) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    34028708, /* 26687 ( 540) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    18557868, /* 26688 ( 540) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
    18544586, /* 26689 ( 540) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
       16484, /* 26690 ( 541) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34015422, /* 26691 ( 541) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
     1551596, /* 26692 ( 541) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
    51034656, /* 26693 ( 541) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  0] -1 */
    35550858, /* 26694 ( 541) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6] -1 */
    52570092, /* 26695 ( 541) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    17009474, /* 26696 ( 541) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  0]  1 */
    18544586, /* 26697 ( 541) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
       16484, /* 26698 ( 542) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34015422, /* 26699 ( 542) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
     1551596, /* 26700 ( 542) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
    35550858, /* 26701 ( 542) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6] -1 */
    51021698, /* 26702 ( 542) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  0] -1 */
    17022432, /* 26703 ( 542) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  0]  1 */
    52556810, /* 26704 ( 542) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    18557868, /* 26705 ( 542) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
       16484, /* 26706 ( 543) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34015422, /* 26707 ( 543) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    51034656, /* 26708 ( 543) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  0] -1 */
     1538634, /* 26709 ( 543) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
    35563820, /* 26710 ( 543) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
    52556810, /* 26711 ( 543) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    17009474, /* 26712 ( 543) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  0]  1 */
    18557868, /* 26713 ( 543) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
       16484, /* 26714 ( 544) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
     1551596, /* 26715 ( 544) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
    51034656, /* 26716 ( 544) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  0] -1 */
        3198, /* 26717 ( 544) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    51021698, /* 26718 ( 544) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  0] -1 */
     1538634, /* 26719 ( 544) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
    52570092, /* 26720 ( 544) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    52556810, /* 26721 ( 544) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
       16484, /* 26722 ( 545) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    51034656, /* 26723 ( 545) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  0] -1 */
    35550858, /* 26724 ( 545) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6] -1 */
        3198, /* 26725 ( 545) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    51021698, /* 26726 ( 545) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  0] -1 */
    35563820, /* 26727 ( 545) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
    18557868, /* 26728 ( 545) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
    18544586, /* 26729 ( 545) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
       16484, /* 26730 ( 546) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    35550858, /* 26731 ( 546) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6] -1 */
        3198, /* 26732 ( 546) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    17022432, /* 26733 ( 546) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  0]  1 */
    52570092, /* 26734 ( 546) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    35563820, /* 26735 ( 546) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
    52556810, /* 26736 ( 546) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    17009474, /* 26737 ( 546) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  0]  1 */
       16484, /* 26738 ( 547) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34015422, /* 26739 ( 547) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    51021698, /* 26740 ( 547) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  0] -1 */
    17022432, /* 26741 ( 547) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  0]  1 */
     1538634, /* 26742 ( 547) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
    35563820, /* 26743 ( 547) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
    52570092, /* 26744 ( 547) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    18544586, /* 26745 ( 547) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
       16484, /* 26746 ( 548) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    51139796, /* 26747 ( 548) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
    35432760, /* 26748 ( 548) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  0] -1 */
     1551596, /* 26749 ( 548) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
    52438712, /* 26750 ( 548) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
    34146806, /* 26751 ( 548) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    52451994, /* 26752 ( 548) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
    51152754, /* 26753 ( 548) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  6] -1 */
        3198, /* 26754 ( 548) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    34133520, /* 26755 ( 548) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
    17022432, /* 26756 ( 548) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  0]  1 */
     1538634, /* 26757 ( 548) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
    35445722, /* 26758 ( 548) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  0] -1 */
    17009474, /* 26759 ( 548) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  0]  1 */
    18557868, /* 26760 ( 548) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
    18544586, /* 26761 ( 548) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
       16484, /* 26762 ( 549) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34015586, /* 26763 ( 549) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
     1551596, /* 26764 ( 549) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
    52556970, /* 26765 ( 549) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    34028544, /* 26766 ( 549) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    35563980, /* 26767 ( 549) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6] -1 */
        3198, /* 26768 ( 549) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    17022432, /* 26769 ( 549) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  0]  1 */
    51034820, /* 26770 ( 549) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  0] -1 */
     1538634, /* 26771 ( 549) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
    35550698, /* 26772 ( 549) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
    51021534, /* 26773 ( 549) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  0] -1 */
    52569932, /* 26774 ( 549) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    17009474, /* 26775 ( 549) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  0]  1 */
    18557868, /* 26776 ( 549) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
    18544586, /* 26777 ( 549) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
       16484, /* 26778 ( 550) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
     1551596, /* 26779 ( 550) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
    52438874, /* 26780 ( 550) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
    51152916, /* 26781 ( 550) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6] -1 */
    34146644, /* 26782 ( 550) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    35432598, /* 26783 ( 550) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  0] -1 */
        3198, /* 26784 ( 550) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    35445884, /* 26785 ( 550) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  0] -1 */
     1538634, /* 26786 ( 550) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
    17022432, /* 26787 ( 550) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  0]  1 */
    34133682, /* 26788 ( 550) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
    52451832, /* 26789 ( 550) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
    17009474, /* 26790 ( 550) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  0]  1 */
    18557868, /* 26791 ( 550) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
    51139634, /* 26792 ( 550) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
    18544586, /* 26793 ( 550) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
       16484, /* 26794 ( 551) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    52438710, /* 26795 ( 551) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
     1551596, /* 26796 ( 551) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
    34146804, /* 26797 ( 551) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
    35432762, /* 26798 ( 551) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  0] -1 */
    34133522, /* 26799 ( 551) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    52451996, /* 26800 ( 551) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
    51152756, /* 26801 ( 551) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
        3198, /* 26802 ( 551) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    17022432, /* 26803 ( 551) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  0]  1 */
     1538634, /* 26804 ( 551) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
    35445720, /* 26805 ( 551) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  0] -1 */
    51139794, /* 26806 ( 551) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6] -1 */
    17009474, /* 26807 ( 551) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  0]  1 */
    18557868, /* 26808 ( 551) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
    18544586, /* 26809 ( 551) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
       16484, /* 26810 ( 552) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
     1551596, /* 26811 ( 552) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
    52556972, /* 26812 ( 552) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    34028546, /* 26813 ( 552) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    51034818, /* 26814 ( 552) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  0] -1 */
    51021536, /* 26815 ( 552) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  0] -1 */
        3198, /* 26816 ( 552) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    17022432, /* 26817 ( 552) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  0]  1 */
     1538634, /* 26818 ( 552) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
    52569930, /* 26819 ( 552) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    35563982, /* 26820 ( 552) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
    17009474, /* 26821 ( 552) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  0]  1 */
    35550696, /* 26822 ( 552) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  6] -1 */
    18557868, /* 26823 ( 552) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
    34015584, /* 26824 ( 552) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    18544586, /* 26825 ( 552) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
       16484, /* 26826 ( 553) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
     1551596, /* 26827 ( 553) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
    51139632, /* 26828 ( 553) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  6] -1 */
    34133684, /* 26829 ( 553) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    52451834, /* 26830 ( 553) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
    17009474, /* 26831 ( 553) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  0]  1 */
    51152918, /* 26832 ( 553) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
        3198, /* 26833 ( 553) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    17022432, /* 26834 ( 553) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  0]  1 */
     1538634, /* 26835 ( 553) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
    35445882, /* 26836 ( 553) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  0] -1 */
    52438872, /* 26837 ( 553) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
    34146642, /* 26838 ( 553) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
    35432600, /* 26839 ( 553) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  0] -1 */
    18557868, /* 26840 ( 553) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
    18544586, /* 26841 ( 553) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
       16484, /* 26842 ( 554) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    51034658, /* 26843 ( 554) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  0] -1 */
    34028706, /* 26844 ( 554) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
     1551596, /* 26845 ( 554) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
    35563818, /* 26846 ( 554) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  6] -1 */
    35550860, /* 26847 ( 554) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
    51021696, /* 26848 ( 554) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  0] -1 */
        3198, /* 26849 ( 554) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    18557868, /* 26850 ( 554) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
    52556808, /* 26851 ( 554) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
     1538634, /* 26852 ( 554) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
    17022432, /* 26853 ( 554) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  0]  1 */
    17009474, /* 26854 ( 554) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  0]  1 */
    52570094, /* 26855 ( 554) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    34015424, /* 26856 ( 554) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    18544586, /* 26857 ( 554) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
       16484, /* 26858 ( 539) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    18439610, /* 26859 ( 539) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
        3198, /* 26860 ( 539) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
      121298, /* 26861 ( 539) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6]  1 */
    18426648, /* 26862 ( 539) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
      134580, /* 26863 ( 539) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  6]  1 */
    18544748, /* 26864 ( 539) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    18557706, /* 26865 ( 539) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
       16484, /* 26866 ( 540) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    18439610, /* 26867 ( 540) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    34015422, /* 26868 ( 540) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    34133522, /* 26869 ( 540) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    52438872, /* 26870 ( 540) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
      134580, /* 26871 ( 540) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  6]  1 */
        3198, /* 26872 ( 540) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    34146804, /* 26873 ( 540) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
      121298, /* 26874 ( 540) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6]  1 */
    18426648, /* 26875 ( 540) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
    52451834, /* 26876 ( 540) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
    52556972, /* 26877 ( 540) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    52569930, /* 26878 ( 540) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    34028708, /* 26879 ( 540) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    18544748, /* 26880 ( 540) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    18557706, /* 26881 ( 540) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
       16484, /* 26882 ( 541) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34015422, /* 26883 ( 541) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    18439610, /* 26884 ( 541) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    34133522, /* 26885 ( 541) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    52438872, /* 26886 ( 541) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
    52556972, /* 26887 ( 541) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
      134580, /* 26888 ( 541) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  6]  1 */
    18557706, /* 26889 ( 541) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
       16484, /* 26890 ( 542) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34015422, /* 26891 ( 542) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    18439610, /* 26892 ( 542) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    52438872, /* 26893 ( 542) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
    34146804, /* 26894 ( 542) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
      121298, /* 26895 ( 542) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6]  1 */
    52569930, /* 26896 ( 542) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    18544748, /* 26897 ( 542) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
       16484, /* 26898 ( 543) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34015422, /* 26899 ( 543) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    34133522, /* 26900 ( 543) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    18426648, /* 26901 ( 543) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
    52451834, /* 26902 ( 543) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
    52569930, /* 26903 ( 543) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
      134580, /* 26904 ( 543) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  6]  1 */
    18544748, /* 26905 ( 543) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
       16484, /* 26906 ( 544) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    18439610, /* 26907 ( 544) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    34133522, /* 26908 ( 544) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
        3198, /* 26909 ( 544) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    34146804, /* 26910 ( 544) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
    18426648, /* 26911 ( 544) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
    52556972, /* 26912 ( 544) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    52569930, /* 26913 ( 544) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
       16484, /* 26914 ( 545) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34133522, /* 26915 ( 545) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    52438872, /* 26916 ( 545) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
        3198, /* 26917 ( 545) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    34146804, /* 26918 ( 545) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
    52451834, /* 26919 ( 545) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
    18544748, /* 26920 ( 545) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    18557706, /* 26921 ( 545) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
       16484, /* 26922 ( 546) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    52438872, /* 26923 ( 546) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
        3198, /* 26924 ( 546) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
      121298, /* 26925 ( 546) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6]  1 */
    52556972, /* 26926 ( 546) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    52451834, /* 26927 ( 546) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
    52569930, /* 26928 ( 546) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
      134580, /* 26929 ( 546) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  6]  1 */
       16484, /* 26930 ( 547) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34015422, /* 26931 ( 547) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    34146804, /* 26932 ( 547) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
      121298, /* 26933 ( 547) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6]  1 */
    18426648, /* 26934 ( 547) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
    52451834, /* 26935 ( 547) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
    52556972, /* 26936 ( 547) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    18557706, /* 26937 ( 547) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
       16484, /* 26938 ( 548) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    51152916, /* 26939 ( 548) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6] -1 */
    35432760, /* 26940 ( 548) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  0] -1 */
    18439610, /* 26941 ( 548) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    35563818, /* 26942 ( 548) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  6] -1 */
    51034820, /* 26943 ( 548) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  0] -1 */
    35550860, /* 26944 ( 548) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
    51139634, /* 26945 ( 548) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
        3198, /* 26946 ( 548) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    51021534, /* 26947 ( 548) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  0] -1 */
      121298, /* 26948 ( 548) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6]  1 */
    18426648, /* 26949 ( 548) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
    35445722, /* 26950 ( 548) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  0] -1 */
      134580, /* 26951 ( 548) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  6]  1 */
    18544748, /* 26952 ( 548) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    18557706, /* 26953 ( 548) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
       16484, /* 26954 ( 549) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34028706, /* 26955 ( 549) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    18439610, /* 26956 ( 549) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    52556970, /* 26957 ( 549) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    34015424, /* 26958 ( 549) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    52438874, /* 26959 ( 549) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
        3198, /* 26960 ( 549) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
      121298, /* 26961 ( 549) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6]  1 */
    34146806, /* 26962 ( 549) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    18426648, /* 26963 ( 549) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
    52451832, /* 26964 ( 549) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
    34133520, /* 26965 ( 549) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
    52569932, /* 26966 ( 549) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
      134580, /* 26967 ( 549) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  6]  1 */
    18544748, /* 26968 ( 549) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    18557706, /* 26969 ( 549) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
       16484, /* 26970 ( 550) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    18439610, /* 26971 ( 550) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    35563980, /* 26972 ( 550) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6] -1 */
    51139796, /* 26973 ( 550) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
    51034658, /* 26974 ( 550) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  0] -1 */
    35432598, /* 26975 ( 550) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  0] -1 */
        3198, /* 26976 ( 550) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    35445884, /* 26977 ( 550) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  0] -1 */
    18426648, /* 26978 ( 550) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
      121298, /* 26979 ( 550) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6]  1 */
    51021696, /* 26980 ( 550) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  0] -1 */
    35550698, /* 26981 ( 550) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
      134580, /* 26982 ( 550) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  6]  1 */
    18544748, /* 26983 ( 550) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    51152754, /* 26984 ( 550) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  6] -1 */
    18557706, /* 26985 ( 550) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
       16484, /* 26986 ( 551) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    35550696, /* 26987 ( 551) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  6] -1 */
    18439610, /* 26988 ( 551) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    51021698, /* 26989 ( 551) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  0] -1 */
    35445882, /* 26990 ( 551) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  0] -1 */
    51034656, /* 26991 ( 551) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  0] -1 */
    35563982, /* 26992 ( 551) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
    51152756, /* 26993 ( 551) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
        3198, /* 26994 ( 551) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
      121298, /* 26995 ( 551) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6]  1 */
    18426648, /* 26996 ( 551) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
    35432600, /* 26997 ( 551) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  0] -1 */
    51139794, /* 26998 ( 551) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6] -1 */
      134580, /* 26999 ( 551) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  6]  1 */
    18544748, /* 27000 ( 551) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    18557706, /* 27001 ( 551) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
       16484, /* 27002 ( 552) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    18439610, /* 27003 ( 552) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    52570092, /* 27004 ( 552) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    34028546, /* 27005 ( 552) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    34133684, /* 27006 ( 552) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    34146642, /* 27007 ( 552) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
        3198, /* 27008 ( 552) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
      121298, /* 27009 ( 552) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6]  1 */
    18426648, /* 27010 ( 552) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
    52556810, /* 27011 ( 552) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    52451996, /* 27012 ( 552) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
      134580, /* 27013 ( 552) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  6]  1 */
    52438710, /* 27014 ( 552) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
    18544748, /* 27015 ( 552) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    34015584, /* 27016 ( 552) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    18557706, /* 27017 ( 552) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
       16484, /* 27018 ( 553) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    18439610, /* 27019 ( 553) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    51139632, /* 27020 ( 553) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  6] -1 */
    51034818, /* 27021 ( 553) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  0] -1 */
    35563820, /* 27022 ( 553) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
      134580, /* 27023 ( 553) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  6]  1 */
    51152918, /* 27024 ( 553) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
        3198, /* 27025 ( 553) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
      121298, /* 27026 ( 553) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6]  1 */
    18426648, /* 27027 ( 553) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
    35432762, /* 27028 ( 553) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  0] -1 */
    35550858, /* 27029 ( 553) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6] -1 */
    51021536, /* 27030 ( 553) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  0] -1 */
    35445720, /* 27031 ( 553) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  0] -1 */
    18544748, /* 27032 ( 553) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    18557706, /* 27033 ( 553) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
       16484, /* 27034 ( 554) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34146644, /* 27035 ( 554) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    34015586, /* 27036 ( 554) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    18439610, /* 27037 ( 554) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    52438712, /* 27038 ( 554) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
    52451994, /* 27039 ( 554) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
    34133682, /* 27040 ( 554) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
        3198, /* 27041 ( 554) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    18544748, /* 27042 ( 554) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    52556808, /* 27043 ( 554) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    18426648, /* 27044 ( 554) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
      121298, /* 27045 ( 554) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6]  1 */
      134580, /* 27046 ( 554) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  6]  1 */
    52570094, /* 27047 ( 554) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    34028544, /* 27048 ( 554) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    18557706, /* 27049 ( 554) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
       16484, /* 27050 ( 555) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    18557868, /* 27051 ( 555) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
      121458, /* 27052 ( 555) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  6]  1 */
    18439608, /* 27053 ( 555) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
      134580, /* 27054 ( 555) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  6]  1 */
        3362, /* 27055 ( 555) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
       16320, /* 27056 ( 555) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    18426486, /* 27057 ( 555) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
      134420, /* 27058 ( 555) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6]  1 */
      121298, /* 27059 ( 555) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6]  1 */
        3198, /* 27060 ( 555) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    18544586, /* 27061 ( 555) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    18426650, /* 27062 ( 555) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    18439772, /* 27063 ( 555) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    18557708, /* 27064 ( 555) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    18544746, /* 27065 ( 555) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
       16484, /* 27066 ( 556) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    18557868, /* 27067 ( 556) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
    18439608, /* 27068 ( 556) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
      134580, /* 27069 ( 556) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  6]  1 */
       16320, /* 27070 ( 556) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    18426486, /* 27071 ( 556) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
    52451996, /* 27072 ( 556) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
        3198, /* 27073 ( 556) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    52556970, /* 27074 ( 556) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    52438874, /* 27075 ( 556) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
    34146644, /* 27076 ( 556) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    52569932, /* 27077 ( 556) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    34133682, /* 27078 ( 556) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
    18439772, /* 27079 ( 556) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    34028708, /* 27080 ( 556) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    18544746, /* 27081 ( 556) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
    34015586, /* 27082 ( 556) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    34133522, /* 27083 ( 556) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    52556810, /* 27084 ( 556) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    18426650, /* 27085 ( 556) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
      134420, /* 27086 ( 556) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6]  1 */
    34146804, /* 27087 ( 556) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
    18557708, /* 27088 ( 556) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    52570092, /* 27089 ( 556) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    34028544, /* 27090 ( 556) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    52451832, /* 27091 ( 556) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
    34015422, /* 27092 ( 556) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
      121458, /* 27093 ( 556) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  6]  1 */
    52438710, /* 27094 ( 556) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
        3362, /* 27095 ( 556) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
      121298, /* 27096 ( 556) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6]  1 */
    18544586, /* 27097 ( 556) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
       16484, /* 27098 ( 557) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34015586, /* 27099 ( 557) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    34133522, /* 27100 ( 557) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    34015422, /* 27101 ( 557) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    52556810, /* 27102 ( 557) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    18439608, /* 27103 ( 557) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
    52438710, /* 27104 ( 557) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
      134580, /* 27105 ( 557) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  6]  1 */
    18557868, /* 27106 ( 557) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
    52438874, /* 27107 ( 557) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
       16320, /* 27108 ( 557) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
      134420, /* 27109 ( 557) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6]  1 */
    52556970, /* 27110 ( 557) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    34133682, /* 27111 ( 557) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
    18439772, /* 27112 ( 557) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    18557708, /* 27113 ( 557) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
       16484, /* 27114 ( 558) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    18557868, /* 27115 ( 558) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
    34133522, /* 27116 ( 558) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    34015422, /* 27117 ( 558) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    52556810, /* 27118 ( 558) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    52438710, /* 27119 ( 558) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
      121458, /* 27120 ( 558) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  6]  1 */
      134580, /* 27121 ( 558) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  6]  1 */
        3362, /* 27122 ( 558) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34146644, /* 27123 ( 558) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    52569932, /* 27124 ( 558) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    18426650, /* 27125 ( 558) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    18439772, /* 27126 ( 558) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    18544746, /* 27127 ( 558) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
    34028544, /* 27128 ( 558) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    52451832, /* 27129 ( 558) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
       16484, /* 27130 ( 559) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34015422, /* 27131 ( 559) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    52438710, /* 27132 ( 559) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
        3362, /* 27133 ( 559) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
      134420, /* 27134 ( 559) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6]  1 */
      121298, /* 27135 ( 559) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6]  1 */
    18544586, /* 27136 ( 559) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    18426650, /* 27137 ( 559) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    52556970, /* 27138 ( 559) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    18557708, /* 27139 ( 559) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    34133682, /* 27140 ( 559) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
    18439772, /* 27141 ( 559) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    34146804, /* 27142 ( 559) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
    52570092, /* 27143 ( 559) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    34028544, /* 27144 ( 559) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    52451832, /* 27145 ( 559) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
       16484, /* 27146 ( 560) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34015586, /* 27147 ( 560) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    18557868, /* 27148 ( 560) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
      134580, /* 27149 ( 560) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  6]  1 */
    52438874, /* 27150 ( 560) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
    34146644, /* 27151 ( 560) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    18426486, /* 27152 ( 560) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
    52569932, /* 27153 ( 560) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
      121298, /* 27154 ( 560) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6]  1 */
        3198, /* 27155 ( 560) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    18544586, /* 27156 ( 560) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    52556970, /* 27157 ( 560) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    34133682, /* 27158 ( 560) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
    18439772, /* 27159 ( 560) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    34028544, /* 27160 ( 560) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    52451832, /* 27161 ( 560) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
       16484, /* 27162 ( 561) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34133522, /* 27163 ( 561) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    52556810, /* 27164 ( 561) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    18439608, /* 27165 ( 561) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
        3362, /* 27166 ( 561) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34146644, /* 27167 ( 561) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
       16320, /* 27168 ( 561) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    18426486, /* 27169 ( 561) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
    52569932, /* 27170 ( 561) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    18426650, /* 27171 ( 561) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
        3198, /* 27172 ( 561) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    52556970, /* 27173 ( 561) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    34133682, /* 27174 ( 561) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
    18439772, /* 27175 ( 561) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    34146804, /* 27176 ( 561) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
    52570092, /* 27177 ( 561) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
       16484, /* 27178 ( 562) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34015586, /* 27179 ( 562) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    34133522, /* 27180 ( 562) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    52556810, /* 27181 ( 562) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
      121458, /* 27182 ( 562) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  6]  1 */
    52438874, /* 27183 ( 562) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
    18426486, /* 27184 ( 562) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
      134420, /* 27185 ( 562) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6]  1 */
        3198, /* 27186 ( 562) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    18557708, /* 27187 ( 562) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    18439772, /* 27188 ( 562) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    34146804, /* 27189 ( 562) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
    52570092, /* 27190 ( 562) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    18544746, /* 27191 ( 562) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
    34028544, /* 27192 ( 562) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    52451832, /* 27193 ( 562) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
       16484, /* 27194 ( 563) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34015586, /* 27195 ( 563) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    34015422, /* 27196 ( 563) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    18439608, /* 27197 ( 563) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
    52438710, /* 27198 ( 563) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
      121458, /* 27199 ( 563) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  6]  1 */
    52438874, /* 27200 ( 563) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
       16320, /* 27201 ( 563) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    34146644, /* 27202 ( 563) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    52569932, /* 27203 ( 563) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
      121298, /* 27204 ( 563) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6]  1 */
    18544586, /* 27205 ( 563) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    18439772, /* 27206 ( 563) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    34146804, /* 27207 ( 563) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
    52570092, /* 27208 ( 563) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    18544746, /* 27209 ( 563) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
       16484, /* 27210 ( 564) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    18557868, /* 27211 ( 564) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
    18439608, /* 27212 ( 564) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
      134580, /* 27213 ( 564) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  6]  1 */
       16320, /* 27214 ( 564) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    18426486, /* 27215 ( 564) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
        3198, /* 27216 ( 564) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    52438872, /* 27217 ( 564) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
    52570094, /* 27218 ( 564) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    52451834, /* 27219 ( 564) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
    34015584, /* 27220 ( 564) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    34146806, /* 27221 ( 564) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    34133684, /* 27222 ( 564) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    52556972, /* 27223 ( 564) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    18439772, /* 27224 ( 564) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    34015424, /* 27225 ( 564) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    52438712, /* 27226 ( 564) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
    18544746, /* 27227 ( 564) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
    34028546, /* 27228 ( 564) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    34028706, /* 27229 ( 564) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    52451994, /* 27230 ( 564) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
    18426650, /* 27231 ( 564) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    34146642, /* 27232 ( 564) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
    52569930, /* 27233 ( 564) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
      134420, /* 27234 ( 564) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6]  1 */
    18557708, /* 27235 ( 564) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    52556808, /* 27236 ( 564) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
      121458, /* 27237 ( 564) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  6]  1 */
        3362, /* 27238 ( 564) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34133520, /* 27239 ( 564) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
      121298, /* 27240 ( 564) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6]  1 */
    18544586, /* 27241 ( 564) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
       16484, /* 27242 ( 565) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    18557868, /* 27243 ( 565) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
    18439608, /* 27244 ( 565) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
      134580, /* 27245 ( 565) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  6]  1 */
       16320, /* 27246 ( 565) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    18426486, /* 27247 ( 565) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
    35563980, /* 27248 ( 565) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6] -1 */
    35445720, /* 27249 ( 565) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  0] -1 */
        3198, /* 27250 ( 565) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    51152916, /* 27251 ( 565) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6] -1 */
    35432598, /* 27252 ( 565) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  0] -1 */
    51034820, /* 27253 ( 565) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  0] -1 */
    51021698, /* 27254 ( 565) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  0] -1 */
    18439772, /* 27255 ( 565) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    18544746, /* 27256 ( 565) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
    51034656, /* 27257 ( 565) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  0] -1 */
    18426650, /* 27258 ( 565) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    51021534, /* 27259 ( 565) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  0] -1 */
    35445884, /* 27260 ( 565) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  0] -1 */
      134420, /* 27261 ( 565) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6]  1 */
    18557708, /* 27262 ( 565) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    35550858, /* 27263 ( 565) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6] -1 */
    35563820, /* 27264 ( 565) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
    51139794, /* 27265 ( 565) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6] -1 */
      121458, /* 27266 ( 565) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  6]  1 */
    51152756, /* 27267 ( 565) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
        3362, /* 27268 ( 565) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    51139634, /* 27269 ( 565) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
    35432762, /* 27270 ( 565) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  0] -1 */
      121298, /* 27271 ( 565) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6]  1 */
    18544586, /* 27272 ( 565) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    35550698, /* 27273 ( 565) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
       16484, /* 27274 ( 566) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    18557868, /* 27275 ( 566) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
    35445882, /* 27276 ( 566) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  0] -1 */
    18439608, /* 27277 ( 566) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
      134580, /* 27278 ( 566) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  6]  1 */
       16320, /* 27279 ( 566) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    18426486, /* 27280 ( 566) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
        3198, /* 27281 ( 566) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    51152754, /* 27282 ( 566) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  6] -1 */
    51021696, /* 27283 ( 566) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  0] -1 */
    51139632, /* 27284 ( 566) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  6] -1 */
    35563818, /* 27285 ( 566) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  6] -1 */
    51034658, /* 27286 ( 566) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  0] -1 */
    35550696, /* 27287 ( 566) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  6] -1 */
    51021536, /* 27288 ( 566) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  0] -1 */
    18439772, /* 27289 ( 566) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    18544746, /* 27290 ( 566) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
    35432760, /* 27291 ( 566) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  0] -1 */
    51034818, /* 27292 ( 566) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  0] -1 */
    35563982, /* 27293 ( 566) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
    18426650, /* 27294 ( 566) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    35445722, /* 27295 ( 566) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  0] -1 */
    51152918, /* 27296 ( 566) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
      134420, /* 27297 ( 566) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6]  1 */
    18557708, /* 27298 ( 566) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
      121458, /* 27299 ( 566) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  6]  1 */
        3362, /* 27300 ( 566) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    35550860, /* 27301 ( 566) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
    35432600, /* 27302 ( 566) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  0] -1 */
      121298, /* 27303 ( 566) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6]  1 */
    18544586, /* 27304 ( 566) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    51139796, /* 27305 ( 566) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
       16484, /* 27306 ( 555) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    18557868, /* 27307 ( 555) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
      134418, /* 27308 ( 555) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  6]  1 */
    18426648, /* 27309 ( 555) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
      134580, /* 27310 ( 555) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  6]  1 */
       16322, /* 27311 ( 555) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
        3360, /* 27312 ( 555) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    18426486, /* 27313 ( 555) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
      121460, /* 27314 ( 555) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6]  1 */
      121298, /* 27315 ( 555) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6]  1 */
        3198, /* 27316 ( 555) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    18544586, /* 27317 ( 555) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    18439610, /* 27318 ( 555) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    18439772, /* 27319 ( 555) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    18544748, /* 27320 ( 555) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    18557706, /* 27321 ( 555) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
       16484, /* 27322 ( 556) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    18557868, /* 27323 ( 556) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
    18426648, /* 27324 ( 556) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
      134580, /* 27325 ( 556) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  6]  1 */
        3360, /* 27326 ( 556) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    18426486, /* 27327 ( 556) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
    52451996, /* 27328 ( 556) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
        3198, /* 27329 ( 556) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    52569930, /* 27330 ( 556) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    52451834, /* 27331 ( 556) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
    34133684, /* 27332 ( 556) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    52556972, /* 27333 ( 556) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    34146642, /* 27334 ( 556) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
    18439772, /* 27335 ( 556) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    34028708, /* 27336 ( 556) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    18557706, /* 27337 ( 556) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
    34028546, /* 27338 ( 556) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    34133522, /* 27339 ( 556) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    52556810, /* 27340 ( 556) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    18439610, /* 27341 ( 556) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
      121460, /* 27342 ( 556) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6]  1 */
    34146804, /* 27343 ( 556) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
    18544748, /* 27344 ( 556) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    52570092, /* 27345 ( 556) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    34015584, /* 27346 ( 556) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    52438872, /* 27347 ( 556) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
    34015422, /* 27348 ( 556) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
      134418, /* 27349 ( 556) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  6]  1 */
    52438710, /* 27350 ( 556) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
       16322, /* 27351 ( 556) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
      121298, /* 27352 ( 556) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6]  1 */
    18544586, /* 27353 ( 556) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
       16484, /* 27354 ( 557) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34028546, /* 27355 ( 557) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    34133522, /* 27356 ( 557) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    34015422, /* 27357 ( 557) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    52556810, /* 27358 ( 557) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    18426648, /* 27359 ( 557) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
    52438710, /* 27360 ( 557) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
      134580, /* 27361 ( 557) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  6]  1 */
    18557868, /* 27362 ( 557) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
    52451834, /* 27363 ( 557) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
        3360, /* 27364 ( 557) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
      121460, /* 27365 ( 557) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6]  1 */
    52569930, /* 27366 ( 557) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    34146642, /* 27367 ( 557) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
    18439772, /* 27368 ( 557) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    18544748, /* 27369 ( 557) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
       16484, /* 27370 ( 558) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    18557868, /* 27371 ( 558) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
    34133522, /* 27372 ( 558) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    34015422, /* 27373 ( 558) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    52556810, /* 27374 ( 558) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    52438710, /* 27375 ( 558) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
      134418, /* 27376 ( 558) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  6]  1 */
      134580, /* 27377 ( 558) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  6]  1 */
       16322, /* 27378 ( 558) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34133684, /* 27379 ( 558) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    52556972, /* 27380 ( 558) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    18439610, /* 27381 ( 558) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    18439772, /* 27382 ( 558) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    18557706, /* 27383 ( 558) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
    34015584, /* 27384 ( 558) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    52438872, /* 27385 ( 558) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
       16484, /* 27386 ( 559) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34015422, /* 27387 ( 559) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    52438710, /* 27388 ( 559) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
       16322, /* 27389 ( 559) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
      121460, /* 27390 ( 559) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6]  1 */
      121298, /* 27391 ( 559) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6]  1 */
    18544586, /* 27392 ( 559) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    18439610, /* 27393 ( 559) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    52569930, /* 27394 ( 559) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    18544748, /* 27395 ( 559) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    34146642, /* 27396 ( 559) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
    18439772, /* 27397 ( 559) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    34146804, /* 27398 ( 559) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
    52570092, /* 27399 ( 559) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    34015584, /* 27400 ( 559) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    52438872, /* 27401 ( 559) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
       16484, /* 27402 ( 560) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34028546, /* 27403 ( 560) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    18557868, /* 27404 ( 560) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
      134580, /* 27405 ( 560) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  6]  1 */
    52451834, /* 27406 ( 560) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
    34133684, /* 27407 ( 560) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    18426486, /* 27408 ( 560) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
    52556972, /* 27409 ( 560) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
      121298, /* 27410 ( 560) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6]  1 */
        3198, /* 27411 ( 560) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    18544586, /* 27412 ( 560) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    52569930, /* 27413 ( 560) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    34146642, /* 27414 ( 560) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
    18439772, /* 27415 ( 560) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    34015584, /* 27416 ( 560) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    52438872, /* 27417 ( 560) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
       16484, /* 27418 ( 561) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34133522, /* 27419 ( 561) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    52556810, /* 27420 ( 561) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    18426648, /* 27421 ( 561) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
       16322, /* 27422 ( 561) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34133684, /* 27423 ( 561) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
        3360, /* 27424 ( 561) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    18426486, /* 27425 ( 561) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
    52556972, /* 27426 ( 561) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    18439610, /* 27427 ( 561) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
        3198, /* 27428 ( 561) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    52569930, /* 27429 ( 561) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    34146642, /* 27430 ( 561) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
    18439772, /* 27431 ( 561) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    34146804, /* 27432 ( 561) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
    52570092, /* 27433 ( 561) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
       16484, /* 27434 ( 562) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34028546, /* 27435 ( 562) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    34133522, /* 27436 ( 562) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    52556810, /* 27437 ( 562) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
      134418, /* 27438 ( 562) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  6]  1 */
    52451834, /* 27439 ( 562) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
    18426486, /* 27440 ( 562) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
      121460, /* 27441 ( 562) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6]  1 */
        3198, /* 27442 ( 562) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    18544748, /* 27443 ( 562) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    18439772, /* 27444 ( 562) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    34146804, /* 27445 ( 562) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
    52570092, /* 27446 ( 562) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    18557706, /* 27447 ( 562) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
    34015584, /* 27448 ( 562) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    52438872, /* 27449 ( 562) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
       16484, /* 27450 ( 563) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34028546, /* 27451 ( 563) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    34015422, /* 27452 ( 563) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    18426648, /* 27453 ( 563) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
    52438710, /* 27454 ( 563) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
      134418, /* 27455 ( 563) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  6]  1 */
    52451834, /* 27456 ( 563) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
        3360, /* 27457 ( 563) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    34133684, /* 27458 ( 563) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    52556972, /* 27459 ( 563) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
      121298, /* 27460 ( 563) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6]  1 */
    18544586, /* 27461 ( 563) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    18439772, /* 27462 ( 563) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    34146804, /* 27463 ( 563) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
    52570092, /* 27464 ( 563) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    18557706, /* 27465 ( 563) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
       16484, /* 27466 ( 564) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    18557868, /* 27467 ( 564) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
    18426648, /* 27468 ( 564) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
      134580, /* 27469 ( 564) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  6]  1 */
        3360, /* 27470 ( 564) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    18426486, /* 27471 ( 564) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
        3198, /* 27472 ( 564) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    52451832, /* 27473 ( 564) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
    52570094, /* 27474 ( 564) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    52438874, /* 27475 ( 564) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
    34028544, /* 27476 ( 564) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    34146806, /* 27477 ( 564) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    34146644, /* 27478 ( 564) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    52569932, /* 27479 ( 564) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    18439772, /* 27480 ( 564) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    34015424, /* 27481 ( 564) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    52438712, /* 27482 ( 564) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
    18557706, /* 27483 ( 564) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
    34015586, /* 27484 ( 564) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    34028706, /* 27485 ( 564) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    52451994, /* 27486 ( 564) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
    18439610, /* 27487 ( 564) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    34133682, /* 27488 ( 564) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
    52556970, /* 27489 ( 564) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
      121460, /* 27490 ( 564) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6]  1 */
    18544748, /* 27491 ( 564) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    52556808, /* 27492 ( 564) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
      134418, /* 27493 ( 564) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  6]  1 */
       16322, /* 27494 ( 564) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34133520, /* 27495 ( 564) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
      121298, /* 27496 ( 564) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6]  1 */
    18544586, /* 27497 ( 564) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
       16484, /* 27498 ( 565) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    18557868, /* 27499 ( 565) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
    18426648, /* 27500 ( 565) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
      134580, /* 27501 ( 565) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  6]  1 */
        3360, /* 27502 ( 565) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    18426486, /* 27503 ( 565) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
    51152916, /* 27504 ( 565) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6] -1 */
    51021696, /* 27505 ( 565) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  0] -1 */
        3198, /* 27506 ( 565) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    35563980, /* 27507 ( 565) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6] -1 */
    51021534, /* 27508 ( 565) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  0] -1 */
    35445884, /* 27509 ( 565) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  0] -1 */
    35445722, /* 27510 ( 565) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  0] -1 */
    18439772, /* 27511 ( 565) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    18557706, /* 27512 ( 565) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
    35432760, /* 27513 ( 565) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  0] -1 */
    18439610, /* 27514 ( 565) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    35432598, /* 27515 ( 565) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  0] -1 */
    51034820, /* 27516 ( 565) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  0] -1 */
      121460, /* 27517 ( 565) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6]  1 */
    18544748, /* 27518 ( 565) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    51152754, /* 27519 ( 565) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  6] -1 */
    51139796, /* 27520 ( 565) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
    35563818, /* 27521 ( 565) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  6] -1 */
      134418, /* 27522 ( 565) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  6]  1 */
    35550860, /* 27523 ( 565) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
       16322, /* 27524 ( 565) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    35550698, /* 27525 ( 565) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
    51034658, /* 27526 ( 565) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  0] -1 */
      121298, /* 27527 ( 565) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6]  1 */
    18544586, /* 27528 ( 565) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    51139634, /* 27529 ( 565) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
       16484, /* 27530 ( 566) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    18557868, /* 27531 ( 566) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
    51034818, /* 27532 ( 566) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  0] -1 */
    18426648, /* 27533 ( 566) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
      134580, /* 27534 ( 566) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  6]  1 */
        3360, /* 27535 ( 566) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    18426486, /* 27536 ( 566) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
        3198, /* 27537 ( 566) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    35550858, /* 27538 ( 566) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6] -1 */
    35445720, /* 27539 ( 566) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  0] -1 */
    35550696, /* 27540 ( 566) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  6] -1 */
    51139794, /* 27541 ( 566) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6] -1 */
    35432762, /* 27542 ( 566) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  0] -1 */
    51139632, /* 27543 ( 566) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  6] -1 */
    35432600, /* 27544 ( 566) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  0] -1 */
    18439772, /* 27545 ( 566) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    18557706, /* 27546 ( 566) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
    51034656, /* 27547 ( 566) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  0] -1 */
    35445882, /* 27548 ( 566) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  0] -1 */
    51152918, /* 27549 ( 566) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
    18439610, /* 27550 ( 566) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    51021698, /* 27551 ( 566) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  0] -1 */
    35563982, /* 27552 ( 566) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
      121460, /* 27553 ( 566) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6]  1 */
    18544748, /* 27554 ( 566) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
      134418, /* 27555 ( 566) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  6]  1 */
       16322, /* 27556 ( 566) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    51152756, /* 27557 ( 566) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
    51021536, /* 27558 ( 566) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  0] -1 */
      121298, /* 27559 ( 566) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6]  1 */
    18544586, /* 27560 ( 566) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    35563820, /* 27561 ( 566) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
       16484, /* 27562 ( 555) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    18544748, /* 27563 ( 555) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    17009312, /* 27564 ( 555) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  0]  1 */
     1538634, /* 27565 ( 555) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
    17009474, /* 27566 ( 555) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  0]  1 */
       16322, /* 27567 ( 555) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
        3360, /* 27568 ( 555) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
     1538472, /* 27569 ( 555) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
    17022594, /* 27570 ( 555) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  0]  1 */
    17022432, /* 27571 ( 555) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  0]  1 */
        3198, /* 27572 ( 555) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    18557706, /* 27573 ( 555) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
     1551596, /* 27574 ( 555) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
     1551758, /* 27575 ( 555) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
    18557868, /* 27576 ( 555) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
    18544586, /* 27577 ( 555) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
       16484, /* 27578 ( 556) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    18544748, /* 27579 ( 556) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
     1538634, /* 27580 ( 556) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
    17009474, /* 27581 ( 556) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  0]  1 */
        3360, /* 27582 ( 556) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
     1538472, /* 27583 ( 556) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
    35563982, /* 27584 ( 556) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
        3198, /* 27585 ( 556) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    52556810, /* 27586 ( 556) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    35563820, /* 27587 ( 556) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
    51034818, /* 27588 ( 556) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  0] -1 */
    52570092, /* 27589 ( 556) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    51021536, /* 27590 ( 556) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  0] -1 */
     1551758, /* 27591 ( 556) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
    34028708, /* 27592 ( 556) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    18544586, /* 27593 ( 556) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    34028546, /* 27594 ( 556) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    51034656, /* 27595 ( 556) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  0] -1 */
    52569930, /* 27596 ( 556) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
     1551596, /* 27597 ( 556) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
    17022594, /* 27598 ( 556) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  0]  1 */
    51021698, /* 27599 ( 556) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  0] -1 */
    18557868, /* 27600 ( 556) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
    52556972, /* 27601 ( 556) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    34015584, /* 27602 ( 556) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    35550858, /* 27603 ( 556) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6] -1 */
    34015422, /* 27604 ( 556) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    17009312, /* 27605 ( 556) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  0]  1 */
    35550696, /* 27606 ( 556) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  6] -1 */
       16322, /* 27607 ( 556) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    17022432, /* 27608 ( 556) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  0]  1 */
    18557706, /* 27609 ( 556) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
       16484, /* 27610 ( 557) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34028546, /* 27611 ( 557) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    51034656, /* 27612 ( 557) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  0] -1 */
    34015422, /* 27613 ( 557) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    52569930, /* 27614 ( 557) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
     1538634, /* 27615 ( 557) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
    35550696, /* 27616 ( 557) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  6] -1 */
    17009474, /* 27617 ( 557) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  0]  1 */
    18544748, /* 27618 ( 557) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    35563820, /* 27619 ( 557) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
        3360, /* 27620 ( 557) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    17022594, /* 27621 ( 557) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  0]  1 */
    52556810, /* 27622 ( 557) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    51021536, /* 27623 ( 557) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  0] -1 */
     1551758, /* 27624 ( 557) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
    18557868, /* 27625 ( 557) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
       16484, /* 27626 ( 558) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    18544748, /* 27627 ( 558) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    51034656, /* 27628 ( 558) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  0] -1 */
    34015422, /* 27629 ( 558) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    52569930, /* 27630 ( 558) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    35550696, /* 27631 ( 558) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  6] -1 */
    17009312, /* 27632 ( 558) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  0]  1 */
    17009474, /* 27633 ( 558) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  0]  1 */
       16322, /* 27634 ( 558) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    51034818, /* 27635 ( 558) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  0] -1 */
    52570092, /* 27636 ( 558) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
     1551596, /* 27637 ( 558) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
     1551758, /* 27638 ( 558) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
    18544586, /* 27639 ( 558) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    34015584, /* 27640 ( 558) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    35550858, /* 27641 ( 558) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6] -1 */
       16484, /* 27642 ( 559) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34015422, /* 27643 ( 559) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    35550696, /* 27644 ( 559) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  6] -1 */
       16322, /* 27645 ( 559) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    17022594, /* 27646 ( 559) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  0]  1 */
    17022432, /* 27647 ( 559) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  0]  1 */
    18557706, /* 27648 ( 559) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
     1551596, /* 27649 ( 559) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
    52556810, /* 27650 ( 559) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    18557868, /* 27651 ( 559) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
    51021536, /* 27652 ( 559) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  0] -1 */
     1551758, /* 27653 ( 559) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
    51021698, /* 27654 ( 559) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  0] -1 */
    52556972, /* 27655 ( 559) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    34015584, /* 27656 ( 559) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    35550858, /* 27657 ( 559) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6] -1 */
       16484, /* 27658 ( 560) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34028546, /* 27659 ( 560) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    18544748, /* 27660 ( 560) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    17009474, /* 27661 ( 560) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  0]  1 */
    35563820, /* 27662 ( 560) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
    51034818, /* 27663 ( 560) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  0] -1 */
     1538472, /* 27664 ( 560) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
    52570092, /* 27665 ( 560) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    17022432, /* 27666 ( 560) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  0]  1 */
        3198, /* 27667 ( 560) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    18557706, /* 27668 ( 560) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
    52556810, /* 27669 ( 560) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    51021536, /* 27670 ( 560) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  0] -1 */
     1551758, /* 27671 ( 560) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
    34015584, /* 27672 ( 560) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    35550858, /* 27673 ( 560) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6] -1 */
       16484, /* 27674 ( 561) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    51034656, /* 27675 ( 561) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  0] -1 */
    52569930, /* 27676 ( 561) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
     1538634, /* 27677 ( 561) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
       16322, /* 27678 ( 561) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    51034818, /* 27679 ( 561) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  0] -1 */
        3360, /* 27680 ( 561) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
     1538472, /* 27681 ( 561) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
    52570092, /* 27682 ( 561) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
     1551596, /* 27683 ( 561) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
        3198, /* 27684 ( 561) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    52556810, /* 27685 ( 561) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    51021536, /* 27686 ( 561) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  0] -1 */
     1551758, /* 27687 ( 561) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
    51021698, /* 27688 ( 561) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  0] -1 */
    52556972, /* 27689 ( 561) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
       16484, /* 27690 ( 562) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34028546, /* 27691 ( 562) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    51034656, /* 27692 ( 562) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  0] -1 */
    52569930, /* 27693 ( 562) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    17009312, /* 27694 ( 562) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  0]  1 */
    35563820, /* 27695 ( 562) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
     1538472, /* 27696 ( 562) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
    17022594, /* 27697 ( 562) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  0]  1 */
        3198, /* 27698 ( 562) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    18557868, /* 27699 ( 562) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
     1551758, /* 27700 ( 562) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
    51021698, /* 27701 ( 562) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  0] -1 */
    52556972, /* 27702 ( 562) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    18544586, /* 27703 ( 562) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    34015584, /* 27704 ( 562) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    35550858, /* 27705 ( 562) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6] -1 */
       16484, /* 27706 ( 563) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34028546, /* 27707 ( 563) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    34015422, /* 27708 ( 563) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
     1538634, /* 27709 ( 563) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
    35550696, /* 27710 ( 563) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  6] -1 */
    17009312, /* 27711 ( 563) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  0]  1 */
    35563820, /* 27712 ( 563) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
        3360, /* 27713 ( 563) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    51034818, /* 27714 ( 563) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  0] -1 */
    52570092, /* 27715 ( 563) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    17022432, /* 27716 ( 563) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  0]  1 */
    18557706, /* 27717 ( 563) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
     1551758, /* 27718 ( 563) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
    51021698, /* 27719 ( 563) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  0] -1 */
    52556972, /* 27720 ( 563) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    18544586, /* 27721 ( 563) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
       16484, /* 27722 ( 564) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    18544748, /* 27723 ( 564) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
     1538634, /* 27724 ( 564) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
    17009474, /* 27725 ( 564) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  0]  1 */
        3360, /* 27726 ( 564) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
     1538472, /* 27727 ( 564) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
        3198, /* 27728 ( 564) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    35550698, /* 27729 ( 564) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
    52570094, /* 27730 ( 564) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    35563980, /* 27731 ( 564) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6] -1 */
    34015424, /* 27732 ( 564) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    51034820, /* 27733 ( 564) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  0] -1 */
    51034658, /* 27734 ( 564) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  0] -1 */
    52569932, /* 27735 ( 564) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
     1551758, /* 27736 ( 564) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
    34028544, /* 27737 ( 564) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    35563818, /* 27738 ( 564) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  6] -1 */
    18544586, /* 27739 ( 564) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    34028706, /* 27740 ( 564) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    34015586, /* 27741 ( 564) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    35550860, /* 27742 ( 564) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
     1551596, /* 27743 ( 564) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
    51021696, /* 27744 ( 564) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  0] -1 */
    52556970, /* 27745 ( 564) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    17022594, /* 27746 ( 564) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  0]  1 */
    18557868, /* 27747 ( 564) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
    52556808, /* 27748 ( 564) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    17009312, /* 27749 ( 564) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  0]  1 */
       16322, /* 27750 ( 564) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    51021534, /* 27751 ( 564) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  0] -1 */
    17022432, /* 27752 ( 564) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  0]  1 */
    18557706, /* 27753 ( 564) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
       16484, /* 27754 ( 565) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    18544748, /* 27755 ( 565) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
     1538634, /* 27756 ( 565) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
    17009474, /* 27757 ( 565) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  0]  1 */
        3360, /* 27758 ( 565) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
     1538472, /* 27759 ( 565) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
    51139796, /* 27760 ( 565) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
    34133682, /* 27761 ( 565) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
        3198, /* 27762 ( 565) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    52438874, /* 27763 ( 565) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
    34133520, /* 27764 ( 565) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
    35445884, /* 27765 ( 565) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  0] -1 */
    35445722, /* 27766 ( 565) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  0] -1 */
     1551758, /* 27767 ( 565) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
    18544586, /* 27768 ( 565) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    35432760, /* 27769 ( 565) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  0] -1 */
     1551596, /* 27770 ( 565) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
    35432598, /* 27771 ( 565) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  0] -1 */
    34146806, /* 27772 ( 565) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    17022594, /* 27773 ( 565) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  0]  1 */
    18557868, /* 27774 ( 565) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
    51139634, /* 27775 ( 565) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
    51152916, /* 27776 ( 565) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6] -1 */
    52438712, /* 27777 ( 565) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
    17009312, /* 27778 ( 565) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  0]  1 */
    52451994, /* 27779 ( 565) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
       16322, /* 27780 ( 565) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    52451832, /* 27781 ( 565) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
    34146644, /* 27782 ( 565) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    17022432, /* 27783 ( 565) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  0]  1 */
    18557706, /* 27784 ( 565) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
    51152754, /* 27785 ( 565) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  6] -1 */
       16484, /* 27786 ( 566) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    18544748, /* 27787 ( 566) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    34133684, /* 27788 ( 566) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
     1538634, /* 27789 ( 566) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
    17009474, /* 27790 ( 566) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  0]  1 */
        3360, /* 27791 ( 566) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
     1538472, /* 27792 ( 566) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
        3198, /* 27793 ( 566) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    52438872, /* 27794 ( 566) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
    35432600, /* 27795 ( 566) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  0] -1 */
    52438710, /* 27796 ( 566) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
    51139794, /* 27797 ( 566) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6] -1 */
    35445882, /* 27798 ( 566) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  0] -1 */
    51139632, /* 27799 ( 566) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  6] -1 */
    35445720, /* 27800 ( 566) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  0] -1 */
     1551758, /* 27801 ( 566) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
    18544586, /* 27802 ( 566) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    34133522, /* 27803 ( 566) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    35432762, /* 27804 ( 566) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  0] -1 */
    51152918, /* 27805 ( 566) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
     1551596, /* 27806 ( 566) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
    34146804, /* 27807 ( 566) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
    52451996, /* 27808 ( 566) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
    17022594, /* 27809 ( 566) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  0]  1 */
    18557868, /* 27810 ( 566) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
    17009312, /* 27811 ( 566) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  0]  1 */
       16322, /* 27812 ( 566) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    51152756, /* 27813 ( 566) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
    34146642, /* 27814 ( 566) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
    17022432, /* 27815 ( 566) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  0]  1 */
    18557706, /* 27816 ( 566) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
    52451834, /* 27817 ( 566) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
       16484, /* 27818 ( 555) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    18544748, /* 27819 ( 555) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    17009472, /* 27820 ( 555) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  0]  1 */
     1538474, /* 27821 ( 555) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
    17009474, /* 27822 ( 555) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  0]  1 */
       16482, /* 27823 ( 555) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
        3200, /* 27824 ( 555) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
     1538472, /* 27825 ( 555) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
    17022434, /* 27826 ( 555) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  0]  1 */
    17022432, /* 27827 ( 555) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  0]  1 */
        3198, /* 27828 ( 555) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    18557706, /* 27829 ( 555) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
     1551756, /* 27830 ( 555) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
     1551758, /* 27831 ( 555) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
    18557708, /* 27832 ( 555) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    18544746, /* 27833 ( 555) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
       16484, /* 27834 ( 556) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    18544748, /* 27835 ( 556) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
     1538474, /* 27836 ( 556) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
    17009474, /* 27837 ( 556) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  0]  1 */
        3200, /* 27838 ( 556) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
     1538472, /* 27839 ( 556) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
    35563982, /* 27840 ( 556) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
        3198, /* 27841 ( 556) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    52556970, /* 27842 ( 556) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    35563980, /* 27843 ( 556) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6] -1 */
    51034658, /* 27844 ( 556) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  0] -1 */
    52569932, /* 27845 ( 556) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    51021696, /* 27846 ( 556) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  0] -1 */
     1551758, /* 27847 ( 556) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
    34028708, /* 27848 ( 556) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    18544746, /* 27849 ( 556) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
    34028706, /* 27850 ( 556) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    51034656, /* 27851 ( 556) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  0] -1 */
    52569930, /* 27852 ( 556) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
     1551756, /* 27853 ( 556) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
    17022434, /* 27854 ( 556) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  0]  1 */
    51021698, /* 27855 ( 556) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  0] -1 */
    18557708, /* 27856 ( 556) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    52556972, /* 27857 ( 556) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    34015424, /* 27858 ( 556) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    35550698, /* 27859 ( 556) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
    34015422, /* 27860 ( 556) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    17009472, /* 27861 ( 556) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  0]  1 */
    35550696, /* 27862 ( 556) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  6] -1 */
       16482, /* 27863 ( 556) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    17022432, /* 27864 ( 556) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  0]  1 */
    18557706, /* 27865 ( 556) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
       16484, /* 27866 ( 557) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34028706, /* 27867 ( 557) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    51034656, /* 27868 ( 557) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  0] -1 */
    34015422, /* 27869 ( 557) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    52569930, /* 27870 ( 557) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
     1538474, /* 27871 ( 557) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
    35550696, /* 27872 ( 557) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  6] -1 */
    17009474, /* 27873 ( 557) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  0]  1 */
    18544748, /* 27874 ( 557) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    35563980, /* 27875 ( 557) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6] -1 */
        3200, /* 27876 ( 557) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    17022434, /* 27877 ( 557) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  0]  1 */
    52556970, /* 27878 ( 557) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    51021696, /* 27879 ( 557) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  0] -1 */
     1551758, /* 27880 ( 557) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
    18557708, /* 27881 ( 557) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
       16484, /* 27882 ( 558) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    18544748, /* 27883 ( 558) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    51034656, /* 27884 ( 558) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  0] -1 */
    34015422, /* 27885 ( 558) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    52569930, /* 27886 ( 558) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    35550696, /* 27887 ( 558) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  6] -1 */
    17009472, /* 27888 ( 558) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  0]  1 */
    17009474, /* 27889 ( 558) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  0]  1 */
       16482, /* 27890 ( 558) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    51034658, /* 27891 ( 558) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  0] -1 */
    52569932, /* 27892 ( 558) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
     1551756, /* 27893 ( 558) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
     1551758, /* 27894 ( 558) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
    18544746, /* 27895 ( 558) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
    34015424, /* 27896 ( 558) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    35550698, /* 27897 ( 558) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
       16484, /* 27898 ( 559) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34015422, /* 27899 ( 559) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    35550696, /* 27900 ( 559) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  6] -1 */
       16482, /* 27901 ( 559) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    17022434, /* 27902 ( 559) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  0]  1 */
    17022432, /* 27903 ( 559) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  0]  1 */
    18557706, /* 27904 ( 559) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
     1551756, /* 27905 ( 559) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
    52556970, /* 27906 ( 559) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    18557708, /* 27907 ( 559) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    51021696, /* 27908 ( 559) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  0] -1 */
     1551758, /* 27909 ( 559) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
    51021698, /* 27910 ( 559) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  0] -1 */
    52556972, /* 27911 ( 559) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    34015424, /* 27912 ( 559) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    35550698, /* 27913 ( 559) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
       16484, /* 27914 ( 560) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34028706, /* 27915 ( 560) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    18544748, /* 27916 ( 560) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    17009474, /* 27917 ( 560) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  0]  1 */
    35563980, /* 27918 ( 560) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6] -1 */
    51034658, /* 27919 ( 560) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  0] -1 */
     1538472, /* 27920 ( 560) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
    52569932, /* 27921 ( 560) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    17022432, /* 27922 ( 560) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  0]  1 */
        3198, /* 27923 ( 560) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    18557706, /* 27924 ( 560) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
    52556970, /* 27925 ( 560) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    51021696, /* 27926 ( 560) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  0] -1 */
     1551758, /* 27927 ( 560) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
    34015424, /* 27928 ( 560) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    35550698, /* 27929 ( 560) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
       16484, /* 27930 ( 561) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    51034656, /* 27931 ( 561) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  0] -1 */
    52569930, /* 27932 ( 561) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
     1538474, /* 27933 ( 561) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
       16482, /* 27934 ( 561) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    51034658, /* 27935 ( 561) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  0] -1 */
        3200, /* 27936 ( 561) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
     1538472, /* 27937 ( 561) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
    52569932, /* 27938 ( 561) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
     1551756, /* 27939 ( 561) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
        3198, /* 27940 ( 561) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    52556970, /* 27941 ( 561) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    51021696, /* 27942 ( 561) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  0] -1 */
     1551758, /* 27943 ( 561) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
    51021698, /* 27944 ( 561) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  0] -1 */
    52556972, /* 27945 ( 561) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
       16484, /* 27946 ( 562) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34028706, /* 27947 ( 562) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    51034656, /* 27948 ( 562) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  0] -1 */
    52569930, /* 27949 ( 562) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    17009472, /* 27950 ( 562) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  0]  1 */
    35563980, /* 27951 ( 562) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6] -1 */
     1538472, /* 27952 ( 562) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
    17022434, /* 27953 ( 562) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  0]  1 */
        3198, /* 27954 ( 562) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    18557708, /* 27955 ( 562) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
     1551758, /* 27956 ( 562) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
    51021698, /* 27957 ( 562) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  0] -1 */
    52556972, /* 27958 ( 562) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    18544746, /* 27959 ( 562) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
    34015424, /* 27960 ( 562) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    35550698, /* 27961 ( 562) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
       16484, /* 27962 ( 563) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34028706, /* 27963 ( 563) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    34015422, /* 27964 ( 563) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
     1538474, /* 27965 ( 563) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
    35550696, /* 27966 ( 563) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  6] -1 */
    17009472, /* 27967 ( 563) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  0]  1 */
    35563980, /* 27968 ( 563) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6] -1 */
        3200, /* 27969 ( 563) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    51034658, /* 27970 ( 563) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  0] -1 */
    52569932, /* 27971 ( 563) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    17022432, /* 27972 ( 563) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  0]  1 */
    18557706, /* 27973 ( 563) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
     1551758, /* 27974 ( 563) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
    51021698, /* 27975 ( 563) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  0] -1 */
    52556972, /* 27976 ( 563) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    18544746, /* 27977 ( 563) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
       16484, /* 27978 ( 564) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    18544748, /* 27979 ( 564) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
     1538474, /* 27980 ( 564) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
    17009474, /* 27981 ( 564) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  0]  1 */
        3200, /* 27982 ( 564) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
     1538472, /* 27983 ( 564) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
        3198, /* 27984 ( 564) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    35550858, /* 27985 ( 564) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6] -1 */
    52570094, /* 27986 ( 564) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    35563820, /* 27987 ( 564) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
    34015584, /* 27988 ( 564) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    51034820, /* 27989 ( 564) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  0] -1 */
    51034818, /* 27990 ( 564) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  0] -1 */
    52570092, /* 27991 ( 564) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
     1551758, /* 27992 ( 564) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
    34028544, /* 27993 ( 564) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    35563818, /* 27994 ( 564) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  6] -1 */
    18544746, /* 27995 ( 564) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
    34028546, /* 27996 ( 564) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    34015586, /* 27997 ( 564) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    35550860, /* 27998 ( 564) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
     1551756, /* 27999 ( 564) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
    51021536, /* 28000 ( 564) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  0] -1 */
    52556810, /* 28001 ( 564) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    17022434, /* 28002 ( 564) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  0]  1 */
    18557708, /* 28003 ( 564) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    52556808, /* 28004 ( 564) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    17009472, /* 28005 ( 564) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  0]  1 */
       16482, /* 28006 ( 564) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    51021534, /* 28007 ( 564) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  0] -1 */
    17022432, /* 28008 ( 564) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  0]  1 */
    18557706, /* 28009 ( 564) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
       16484, /* 28010 ( 565) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    18544748, /* 28011 ( 565) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
     1538474, /* 28012 ( 565) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
    17009474, /* 28013 ( 565) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  0]  1 */
        3200, /* 28014 ( 565) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
     1538472, /* 28015 ( 565) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
    52438874, /* 28016 ( 565) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
    35432600, /* 28017 ( 565) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  0] -1 */
        3198, /* 28018 ( 565) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    51139796, /* 28019 ( 565) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
    35432598, /* 28020 ( 565) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  0] -1 */
    34146806, /* 28021 ( 565) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    34146804, /* 28022 ( 565) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
     1551758, /* 28023 ( 565) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
    18544746, /* 28024 ( 565) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
    34133522, /* 28025 ( 565) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
     1551756, /* 28026 ( 565) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
    34133520, /* 28027 ( 565) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
    35445884, /* 28028 ( 565) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  0] -1 */
    17022434, /* 28029 ( 565) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  0]  1 */
    18557708, /* 28030 ( 565) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    52438872, /* 28031 ( 565) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
    52451834, /* 28032 ( 565) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
    51139794, /* 28033 ( 565) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6] -1 */
    17009472, /* 28034 ( 565) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  0]  1 */
    51152756, /* 28035 ( 565) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
       16482, /* 28036 ( 565) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    51152754, /* 28037 ( 565) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  6] -1 */
    35445882, /* 28038 ( 565) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  0] -1 */
    17022432, /* 28039 ( 565) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  0]  1 */
    18557706, /* 28040 ( 565) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
    52451832, /* 28041 ( 565) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
       16484, /* 28042 ( 566) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    18544748, /* 28043 ( 566) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    35432762, /* 28044 ( 566) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  0] -1 */
     1538474, /* 28045 ( 566) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
    17009474, /* 28046 ( 566) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  0]  1 */
        3200, /* 28047 ( 566) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
     1538472, /* 28048 ( 566) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
        3198, /* 28049 ( 566) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    51139634, /* 28050 ( 566) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
    34133682, /* 28051 ( 566) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
    51139632, /* 28052 ( 566) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  6] -1 */
    52438712, /* 28053 ( 566) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
    34146644, /* 28054 ( 566) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    52438710, /* 28055 ( 566) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
    34146642, /* 28056 ( 566) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
     1551758, /* 28057 ( 566) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
    18544746, /* 28058 ( 566) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
    35432760, /* 28059 ( 566) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  0] -1 */
    34133684, /* 28060 ( 566) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    52451996, /* 28061 ( 566) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
     1551756, /* 28062 ( 566) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
    35445722, /* 28063 ( 566) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  0] -1 */
    51152918, /* 28064 ( 566) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
    17022434, /* 28065 ( 566) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  0]  1 */
    18557708, /* 28066 ( 566) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    17009472, /* 28067 ( 566) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  0]  1 */
       16482, /* 28068 ( 566) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    52451994, /* 28069 ( 566) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
    35445720, /* 28070 ( 566) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  0] -1 */
    17022432, /* 28071 ( 566) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  0]  1 */
    18557706, /* 28072 ( 566) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
    51152916, /* 28073 ( 566) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6] -1 */
       16484, /* 28074 ( 555) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    18557708, /* 28075 ( 555) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
     1433496, /* 28076 ( 555) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  0]  1 */
    17127410, /* 28077 ( 555) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
     1433498, /* 28078 ( 555) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  0]  1 */
       16482, /* 28079 ( 555) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
        3200, /* 28080 ( 555) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    17127408, /* 28081 ( 555) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  6]  1 */
     1420538, /* 28082 ( 555) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  0]  1 */
     1420536, /* 28083 ( 555) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  0]  1 */
        3198, /* 28084 ( 555) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    18544746, /* 28085 ( 555) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
    17140692, /* 28086 ( 555) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6]  1 */
    17140694, /* 28087 ( 555) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
    18544748, /* 28088 ( 555) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    18557706, /* 28089 ( 555) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
       16484, /* 28090 ( 556) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    18557708, /* 28091 ( 556) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    17127410, /* 28092 ( 556) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
     1433498, /* 28093 ( 556) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  0]  1 */
        3200, /* 28094 ( 556) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    17127408, /* 28095 ( 556) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  6]  1 */
    51152918, /* 28096 ( 556) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
        3198, /* 28097 ( 556) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    52569930, /* 28098 ( 556) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    51152916, /* 28099 ( 556) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6] -1 */
    35432762, /* 28100 ( 556) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  0] -1 */
    52556972, /* 28101 ( 556) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    35445720, /* 28102 ( 556) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  0] -1 */
    17140694, /* 28103 ( 556) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
    34028708, /* 28104 ( 556) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    18557706, /* 28105 ( 556) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
    34028706, /* 28106 ( 556) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    35432760, /* 28107 ( 556) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  0] -1 */
    52556970, /* 28108 ( 556) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    17140692, /* 28109 ( 556) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6]  1 */
     1420538, /* 28110 ( 556) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  0]  1 */
    35445722, /* 28111 ( 556) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  0] -1 */
    18544748, /* 28112 ( 556) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    52569932, /* 28113 ( 556) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    34015424, /* 28114 ( 556) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    51139634, /* 28115 ( 556) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
    34015422, /* 28116 ( 556) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
     1433496, /* 28117 ( 556) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  0]  1 */
    51139632, /* 28118 ( 556) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  6] -1 */
       16482, /* 28119 ( 556) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
     1420536, /* 28120 ( 556) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  0]  1 */
    18544746, /* 28121 ( 556) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
       16484, /* 28122 ( 557) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34028706, /* 28123 ( 557) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    35432760, /* 28124 ( 557) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  0] -1 */
    34015422, /* 28125 ( 557) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    52556970, /* 28126 ( 557) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    17127410, /* 28127 ( 557) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
    51139632, /* 28128 ( 557) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  6] -1 */
     1433498, /* 28129 ( 557) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  0]  1 */
    18557708, /* 28130 ( 557) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    51152916, /* 28131 ( 557) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6] -1 */
        3200, /* 28132 ( 557) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
     1420538, /* 28133 ( 557) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  0]  1 */
    52569930, /* 28134 ( 557) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    35445720, /* 28135 ( 557) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  0] -1 */
    17140694, /* 28136 ( 557) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
    18544748, /* 28137 ( 557) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
       16484, /* 28138 ( 558) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    18557708, /* 28139 ( 558) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    35432760, /* 28140 ( 558) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  0] -1 */
    34015422, /* 28141 ( 558) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    52556970, /* 28142 ( 558) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    51139632, /* 28143 ( 558) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  6] -1 */
     1433496, /* 28144 ( 558) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  0]  1 */
     1433498, /* 28145 ( 558) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  0]  1 */
       16482, /* 28146 ( 558) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    35432762, /* 28147 ( 558) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  0] -1 */
    52556972, /* 28148 ( 558) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    17140692, /* 28149 ( 558) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6]  1 */
    17140694, /* 28150 ( 558) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
    18557706, /* 28151 ( 558) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
    34015424, /* 28152 ( 558) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    51139634, /* 28153 ( 558) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
       16484, /* 28154 ( 559) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34015422, /* 28155 ( 559) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    51139632, /* 28156 ( 559) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  6] -1 */
       16482, /* 28157 ( 559) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
     1420538, /* 28158 ( 559) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  0]  1 */
     1420536, /* 28159 ( 559) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  0]  1 */
    18544746, /* 28160 ( 559) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
    17140692, /* 28161 ( 559) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6]  1 */
    52569930, /* 28162 ( 559) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    18544748, /* 28163 ( 559) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    35445720, /* 28164 ( 559) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  0] -1 */
    17140694, /* 28165 ( 559) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
    35445722, /* 28166 ( 559) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  0] -1 */
    52569932, /* 28167 ( 559) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    34015424, /* 28168 ( 559) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    51139634, /* 28169 ( 559) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
       16484, /* 28170 ( 560) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34028706, /* 28171 ( 560) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    18557708, /* 28172 ( 560) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
     1433498, /* 28173 ( 560) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  0]  1 */
    51152916, /* 28174 ( 560) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6] -1 */
    35432762, /* 28175 ( 560) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  0] -1 */
    17127408, /* 28176 ( 560) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  6]  1 */
    52556972, /* 28177 ( 560) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
     1420536, /* 28178 ( 560) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  0]  1 */
        3198, /* 28179 ( 560) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    18544746, /* 28180 ( 560) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
    52569930, /* 28181 ( 560) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    35445720, /* 28182 ( 560) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  0] -1 */
    17140694, /* 28183 ( 560) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
    34015424, /* 28184 ( 560) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    51139634, /* 28185 ( 560) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
       16484, /* 28186 ( 561) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    35432760, /* 28187 ( 561) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  0] -1 */
    52556970, /* 28188 ( 561) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    17127410, /* 28189 ( 561) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
       16482, /* 28190 ( 561) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    35432762, /* 28191 ( 561) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  0] -1 */
        3200, /* 28192 ( 561) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    17127408, /* 28193 ( 561) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  6]  1 */
    52556972, /* 28194 ( 561) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    17140692, /* 28195 ( 561) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6]  1 */
        3198, /* 28196 ( 561) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    52569930, /* 28197 ( 561) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    35445720, /* 28198 ( 561) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  0] -1 */
    17140694, /* 28199 ( 561) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
    35445722, /* 28200 ( 561) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  0] -1 */
    52569932, /* 28201 ( 561) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
       16484, /* 28202 ( 562) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34028706, /* 28203 ( 562) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    35432760, /* 28204 ( 562) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  0] -1 */
    52556970, /* 28205 ( 562) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
     1433496, /* 28206 ( 562) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  0]  1 */
    51152916, /* 28207 ( 562) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6] -1 */
    17127408, /* 28208 ( 562) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  6]  1 */
     1420538, /* 28209 ( 562) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  0]  1 */
        3198, /* 28210 ( 562) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    18544748, /* 28211 ( 562) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    17140694, /* 28212 ( 562) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
    35445722, /* 28213 ( 562) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  0] -1 */
    52569932, /* 28214 ( 562) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    18557706, /* 28215 ( 562) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
    34015424, /* 28216 ( 562) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    51139634, /* 28217 ( 562) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
       16484, /* 28218 ( 563) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34028706, /* 28219 ( 563) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    34015422, /* 28220 ( 563) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    17127410, /* 28221 ( 563) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
    51139632, /* 28222 ( 563) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  6] -1 */
     1433496, /* 28223 ( 563) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  0]  1 */
    51152916, /* 28224 ( 563) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6] -1 */
        3200, /* 28225 ( 563) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    35432762, /* 28226 ( 563) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  0] -1 */
    52556972, /* 28227 ( 563) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
     1420536, /* 28228 ( 563) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  0]  1 */
    18544746, /* 28229 ( 563) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
    17140694, /* 28230 ( 563) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
    35445722, /* 28231 ( 563) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  0] -1 */
    52569932, /* 28232 ( 563) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    18557706, /* 28233 ( 563) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
       16484, /* 28234 ( 564) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    18557708, /* 28235 ( 564) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    17127410, /* 28236 ( 564) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
     1433498, /* 28237 ( 564) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  0]  1 */
        3200, /* 28238 ( 564) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    17127408, /* 28239 ( 564) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  6]  1 */
        3198, /* 28240 ( 564) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    51152754, /* 28241 ( 564) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  6] -1 */
    52570094, /* 28242 ( 564) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    51139796, /* 28243 ( 564) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
    34028544, /* 28244 ( 564) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    35445884, /* 28245 ( 564) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  0] -1 */
    35445882, /* 28246 ( 564) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  0] -1 */
    52570092, /* 28247 ( 564) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    17140694, /* 28248 ( 564) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
    34015584, /* 28249 ( 564) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    51139794, /* 28250 ( 564) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6] -1 */
    18557706, /* 28251 ( 564) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
    34015586, /* 28252 ( 564) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    34028546, /* 28253 ( 564) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    51152756, /* 28254 ( 564) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
    17140692, /* 28255 ( 564) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6]  1 */
    35432600, /* 28256 ( 564) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  0] -1 */
    52556810, /* 28257 ( 564) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
     1420538, /* 28258 ( 564) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  0]  1 */
    18544748, /* 28259 ( 564) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    52556808, /* 28260 ( 564) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
     1433496, /* 28261 ( 564) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  0]  1 */
       16482, /* 28262 ( 564) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    35432598, /* 28263 ( 564) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  0] -1 */
     1420536, /* 28264 ( 564) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  0]  1 */
    18544746, /* 28265 ( 564) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
       16484, /* 28266 ( 565) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    18557708, /* 28267 ( 565) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    17127410, /* 28268 ( 565) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
     1433498, /* 28269 ( 565) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  0]  1 */
        3200, /* 28270 ( 565) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    17127408, /* 28271 ( 565) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  6]  1 */
    52451834, /* 28272 ( 565) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
    51021536, /* 28273 ( 565) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  0] -1 */
        3198, /* 28274 ( 565) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    35563820, /* 28275 ( 565) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
    51021534, /* 28276 ( 565) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  0] -1 */
    34146806, /* 28277 ( 565) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    34146804, /* 28278 ( 565) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
    17140694, /* 28279 ( 565) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
    18557706, /* 28280 ( 565) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
    34133522, /* 28281 ( 565) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    17140692, /* 28282 ( 565) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6]  1 */
    34133520, /* 28283 ( 565) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
    51034820, /* 28284 ( 565) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  0] -1 */
     1420538, /* 28285 ( 565) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  0]  1 */
    18544748, /* 28286 ( 565) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    52451832, /* 28287 ( 565) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
    52438874, /* 28288 ( 565) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
    35563818, /* 28289 ( 565) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  6] -1 */
     1433496, /* 28290 ( 565) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  0]  1 */
    35550860, /* 28291 ( 565) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
       16482, /* 28292 ( 565) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    35550858, /* 28293 ( 565) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6] -1 */
    51034818, /* 28294 ( 565) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  0] -1 */
     1420536, /* 28295 ( 565) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  0]  1 */
    18544746, /* 28296 ( 565) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
    52438872, /* 28297 ( 565) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
       16484, /* 28298 ( 566) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    18557708, /* 28299 ( 566) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    51034658, /* 28300 ( 566) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  0] -1 */
    17127410, /* 28301 ( 566) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
     1433498, /* 28302 ( 566) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  0]  1 */
        3200, /* 28303 ( 566) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    17127408, /* 28304 ( 566) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  6]  1 */
        3198, /* 28305 ( 566) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    35550698, /* 28306 ( 566) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
    34146642, /* 28307 ( 566) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
    35550696, /* 28308 ( 566) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  6] -1 */
    52438712, /* 28309 ( 566) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
    34133684, /* 28310 ( 566) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    52438710, /* 28311 ( 566) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
    34133682, /* 28312 ( 566) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
    17140694, /* 28313 ( 566) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
    18557706, /* 28314 ( 566) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
    51034656, /* 28315 ( 566) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  0] -1 */
    34146644, /* 28316 ( 566) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    52451996, /* 28317 ( 566) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
    17140692, /* 28318 ( 566) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6]  1 */
    51021698, /* 28319 ( 566) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  0] -1 */
    35563982, /* 28320 ( 566) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
     1420538, /* 28321 ( 566) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  0]  1 */
    18544748, /* 28322 ( 566) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
     1433496, /* 28323 ( 566) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  0]  1 */
       16482, /* 28324 ( 566) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    52451994, /* 28325 ( 566) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
    51021696, /* 28326 ( 566) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  0] -1 */
     1420536, /* 28327 ( 566) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  0]  1 */
    18544746, /* 28328 ( 566) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
    35563980, /* 28329 ( 566) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6] -1 */
       16484, /* 28330 ( 555) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    18557708, /* 28331 ( 555) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
     1420376, /* 28332 ( 555) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  0]  1 */
    17140530, /* 28333 ( 555) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  6]  1 */
     1433498, /* 28334 ( 555) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  0]  1 */
        3362, /* 28335 ( 555) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
       16320, /* 28336 ( 555) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    17127408, /* 28337 ( 555) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  6]  1 */
     1433658, /* 28338 ( 555) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  0]  1 */
     1420536, /* 28339 ( 555) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  0]  1 */
        3198, /* 28340 ( 555) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    18544746, /* 28341 ( 555) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
    17127572, /* 28342 ( 555) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
    17140694, /* 28343 ( 555) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
    18557868, /* 28344 ( 555) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
    18544586, /* 28345 ( 555) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
       16484, /* 28346 ( 556) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    18557708, /* 28347 ( 556) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    17140530, /* 28348 ( 556) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  6]  1 */
     1433498, /* 28349 ( 556) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  0]  1 */
       16320, /* 28350 ( 556) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    17127408, /* 28351 ( 556) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  6]  1 */
    51152918, /* 28352 ( 556) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
        3198, /* 28353 ( 556) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    52556810, /* 28354 ( 556) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    51139796, /* 28355 ( 556) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
    35445882, /* 28356 ( 556) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  0] -1 */
    52570092, /* 28357 ( 556) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    35432600, /* 28358 ( 556) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  0] -1 */
    17140694, /* 28359 ( 556) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
    34028708, /* 28360 ( 556) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    18544586, /* 28361 ( 556) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    34015586, /* 28362 ( 556) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    35432760, /* 28363 ( 556) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  0] -1 */
    52556970, /* 28364 ( 556) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    17127572, /* 28365 ( 556) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
     1433658, /* 28366 ( 556) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  0]  1 */
    35445722, /* 28367 ( 556) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  0] -1 */
    18557868, /* 28368 ( 556) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
    52569932, /* 28369 ( 556) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    34028544, /* 28370 ( 556) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    51152754, /* 28371 ( 556) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  6] -1 */
    34015422, /* 28372 ( 556) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
     1420376, /* 28373 ( 556) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  0]  1 */
    51139632, /* 28374 ( 556) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  6] -1 */
        3362, /* 28375 ( 556) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
     1420536, /* 28376 ( 556) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  0]  1 */
    18544746, /* 28377 ( 556) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
       16484, /* 28378 ( 557) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34015586, /* 28379 ( 557) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    35432760, /* 28380 ( 557) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  0] -1 */
    34015422, /* 28381 ( 557) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    52556970, /* 28382 ( 557) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    17140530, /* 28383 ( 557) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  6]  1 */
    51139632, /* 28384 ( 557) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  6] -1 */
     1433498, /* 28385 ( 557) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  0]  1 */
    18557708, /* 28386 ( 557) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    51139796, /* 28387 ( 557) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
       16320, /* 28388 ( 557) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
     1433658, /* 28389 ( 557) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  0]  1 */
    52556810, /* 28390 ( 557) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    35432600, /* 28391 ( 557) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  0] -1 */
    17140694, /* 28392 ( 557) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
    18557868, /* 28393 ( 557) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
       16484, /* 28394 ( 558) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    18557708, /* 28395 ( 558) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    35432760, /* 28396 ( 558) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  0] -1 */
    34015422, /* 28397 ( 558) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    52556970, /* 28398 ( 558) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    51139632, /* 28399 ( 558) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  6] -1 */
     1420376, /* 28400 ( 558) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  0]  1 */
     1433498, /* 28401 ( 558) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  0]  1 */
        3362, /* 28402 ( 558) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    35445882, /* 28403 ( 558) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  0] -1 */
    52570092, /* 28404 ( 558) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    17127572, /* 28405 ( 558) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
    17140694, /* 28406 ( 558) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
    18544586, /* 28407 ( 558) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    34028544, /* 28408 ( 558) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    51152754, /* 28409 ( 558) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  6] -1 */
       16484, /* 28410 ( 559) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34015422, /* 28411 ( 559) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    51139632, /* 28412 ( 559) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  6] -1 */
        3362, /* 28413 ( 559) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
     1433658, /* 28414 ( 559) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  0]  1 */
     1420536, /* 28415 ( 559) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  0]  1 */
    18544746, /* 28416 ( 559) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
    17127572, /* 28417 ( 559) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
    52556810, /* 28418 ( 559) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    18557868, /* 28419 ( 559) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
    35432600, /* 28420 ( 559) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  0] -1 */
    17140694, /* 28421 ( 559) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
    35445722, /* 28422 ( 559) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  0] -1 */
    52569932, /* 28423 ( 559) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    34028544, /* 28424 ( 559) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    51152754, /* 28425 ( 559) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  6] -1 */
       16484, /* 28426 ( 560) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34015586, /* 28427 ( 560) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    18557708, /* 28428 ( 560) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
     1433498, /* 28429 ( 560) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  0]  1 */
    51139796, /* 28430 ( 560) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
    35445882, /* 28431 ( 560) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  0] -1 */
    17127408, /* 28432 ( 560) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  6]  1 */
    52570092, /* 28433 ( 560) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
     1420536, /* 28434 ( 560) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  0]  1 */
        3198, /* 28435 ( 560) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    18544746, /* 28436 ( 560) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
    52556810, /* 28437 ( 560) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    35432600, /* 28438 ( 560) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  0] -1 */
    17140694, /* 28439 ( 560) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
    34028544, /* 28440 ( 560) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    51152754, /* 28441 ( 560) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  6] -1 */
       16484, /* 28442 ( 561) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    35432760, /* 28443 ( 561) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  0] -1 */
    52556970, /* 28444 ( 561) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    17140530, /* 28445 ( 561) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  6]  1 */
        3362, /* 28446 ( 561) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    35445882, /* 28447 ( 561) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  0] -1 */
       16320, /* 28448 ( 561) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    17127408, /* 28449 ( 561) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  6]  1 */
    52570092, /* 28450 ( 561) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    17127572, /* 28451 ( 561) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
        3198, /* 28452 ( 561) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    52556810, /* 28453 ( 561) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    35432600, /* 28454 ( 561) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  0] -1 */
    17140694, /* 28455 ( 561) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
    35445722, /* 28456 ( 561) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  0] -1 */
    52569932, /* 28457 ( 561) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
       16484, /* 28458 ( 562) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34015586, /* 28459 ( 562) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    35432760, /* 28460 ( 562) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  0] -1 */
    52556970, /* 28461 ( 562) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
     1420376, /* 28462 ( 562) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  0]  1 */
    51139796, /* 28463 ( 562) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
    17127408, /* 28464 ( 562) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  6]  1 */
     1433658, /* 28465 ( 562) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  0]  1 */
        3198, /* 28466 ( 562) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    18557868, /* 28467 ( 562) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
    17140694, /* 28468 ( 562) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
    35445722, /* 28469 ( 562) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  0] -1 */
    52569932, /* 28470 ( 562) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    18544586, /* 28471 ( 562) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    34028544, /* 28472 ( 562) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    51152754, /* 28473 ( 562) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  6] -1 */
       16484, /* 28474 ( 563) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34015586, /* 28475 ( 563) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    34015422, /* 28476 ( 563) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    17140530, /* 28477 ( 563) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  6]  1 */
    51139632, /* 28478 ( 563) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  6] -1 */
     1420376, /* 28479 ( 563) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  0]  1 */
    51139796, /* 28480 ( 563) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
       16320, /* 28481 ( 563) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    35445882, /* 28482 ( 563) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  0] -1 */
    52570092, /* 28483 ( 563) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
     1420536, /* 28484 ( 563) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  0]  1 */
    18544746, /* 28485 ( 563) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
    17140694, /* 28486 ( 563) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
    35445722, /* 28487 ( 563) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  0] -1 */
    52569932, /* 28488 ( 563) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    18544586, /* 28489 ( 563) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
       16484, /* 28490 ( 564) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    18557708, /* 28491 ( 564) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    17140530, /* 28492 ( 564) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  6]  1 */
     1433498, /* 28493 ( 564) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  0]  1 */
       16320, /* 28494 ( 564) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    17127408, /* 28495 ( 564) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  6]  1 */
        3198, /* 28496 ( 564) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    51139634, /* 28497 ( 564) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
    52570094, /* 28498 ( 564) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    51152916, /* 28499 ( 564) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6] -1 */
    34015424, /* 28500 ( 564) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    35445884, /* 28501 ( 564) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  0] -1 */
    35432762, /* 28502 ( 564) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  0] -1 */
    52556972, /* 28503 ( 564) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    17140694, /* 28504 ( 564) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
    34015584, /* 28505 ( 564) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    51139794, /* 28506 ( 564) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6] -1 */
    18544586, /* 28507 ( 564) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    34028706, /* 28508 ( 564) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    34028546, /* 28509 ( 564) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    51152756, /* 28510 ( 564) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
    17127572, /* 28511 ( 564) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
    35445720, /* 28512 ( 564) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  0] -1 */
    52569930, /* 28513 ( 564) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
     1433658, /* 28514 ( 564) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  0]  1 */
    18557868, /* 28515 ( 564) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
    52556808, /* 28516 ( 564) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
     1420376, /* 28517 ( 564) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  0]  1 */
        3362, /* 28518 ( 564) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    35432598, /* 28519 ( 564) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  0] -1 */
     1420536, /* 28520 ( 564) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  0]  1 */
    18544746, /* 28521 ( 564) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
       16484, /* 28522 ( 565) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    18557708, /* 28523 ( 565) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    17140530, /* 28524 ( 565) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  6]  1 */
     1433498, /* 28525 ( 565) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  0]  1 */
       16320, /* 28526 ( 565) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    17127408, /* 28527 ( 565) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  6]  1 */
    35563820, /* 28528 ( 565) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
    34146642, /* 28529 ( 565) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
        3198, /* 28530 ( 565) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    52451834, /* 28531 ( 565) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
    34133520, /* 28532 ( 565) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
    51034820, /* 28533 ( 565) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  0] -1 */
    51021698, /* 28534 ( 565) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  0] -1 */
    17140694, /* 28535 ( 565) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
    18544586, /* 28536 ( 565) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    51034656, /* 28537 ( 565) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  0] -1 */
    17127572, /* 28538 ( 565) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
    51021534, /* 28539 ( 565) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  0] -1 */
    34146806, /* 28540 ( 565) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
     1433658, /* 28541 ( 565) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  0]  1 */
    18557868, /* 28542 ( 565) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
    35550698, /* 28543 ( 565) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
    35563980, /* 28544 ( 565) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6] -1 */
    52438712, /* 28545 ( 565) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
     1420376, /* 28546 ( 565) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  0]  1 */
    52451994, /* 28547 ( 565) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
        3362, /* 28548 ( 565) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    52438872, /* 28549 ( 565) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
    34133684, /* 28550 ( 565) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
     1420536, /* 28551 ( 565) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  0]  1 */
    18544746, /* 28552 ( 565) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
    35550858, /* 28553 ( 565) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6] -1 */
       16484, /* 28554 ( 566) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    18557708, /* 28555 ( 566) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    34146644, /* 28556 ( 566) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    17140530, /* 28557 ( 566) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  6]  1 */
     1433498, /* 28558 ( 566) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  0]  1 */
       16320, /* 28559 ( 566) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    17127408, /* 28560 ( 566) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  6]  1 */
        3198, /* 28561 ( 566) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    52451832, /* 28562 ( 566) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
    51021536, /* 28563 ( 566) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  0] -1 */
    52438710, /* 28564 ( 566) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
    35563818, /* 28565 ( 566) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  6] -1 */
    51034818, /* 28566 ( 566) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  0] -1 */
    35550696, /* 28567 ( 566) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  6] -1 */
    51021696, /* 28568 ( 566) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  0] -1 */
    17140694, /* 28569 ( 566) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
    18544586, /* 28570 ( 566) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    34133522, /* 28571 ( 566) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    51034658, /* 28572 ( 566) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  0] -1 */
    35563982, /* 28573 ( 566) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
    17127572, /* 28574 ( 566) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
    34146804, /* 28575 ( 566) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
    52451996, /* 28576 ( 566) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
     1433658, /* 28577 ( 566) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  0]  1 */
    18557868, /* 28578 ( 566) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
     1420376, /* 28579 ( 566) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  0]  1 */
        3362, /* 28580 ( 566) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    35550860, /* 28581 ( 566) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
    34133682, /* 28582 ( 566) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
     1420536, /* 28583 ( 566) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  0]  1 */
    18544746, /* 28584 ( 566) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
    52438874, /* 28585 ( 566) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
       16484, /* 28586 ( 567) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    17140692, /* 28587 ( 567) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6]  1 */
     1538474, /* 28588 ( 567) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
    18439608, /* 28589 ( 567) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
        3362, /* 28590 ( 567) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    17127570, /* 28591 ( 567) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6]  1 */
       16320, /* 28592 ( 567) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    18426486, /* 28593 ( 567) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
     1551596, /* 28594 ( 567) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
    18426650, /* 28595 ( 567) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
        3198, /* 28596 ( 567) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
     1551756, /* 28597 ( 567) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
    17127410, /* 28598 ( 567) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
    17140532, /* 28599 ( 567) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
    18439772, /* 28600 ( 567) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
     1538634, /* 28601 ( 567) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
       16484, /* 28602 ( 568) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    18439608, /* 28603 ( 568) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
    17127570, /* 28604 ( 568) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6]  1 */
       16320, /* 28605 ( 568) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    18426486, /* 28606 ( 568) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
     1551596, /* 28607 ( 568) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
    35563980, /* 28608 ( 568) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6] -1 */
    52451996, /* 28609 ( 568) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
        3198, /* 28610 ( 568) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    17127410, /* 28611 ( 568) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
    17140532, /* 28612 ( 568) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
    51152916, /* 28613 ( 568) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6] -1 */
     1538474, /* 28614 ( 568) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
    52438874, /* 28615 ( 568) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
     1551756, /* 28616 ( 568) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
    18439772, /* 28617 ( 568) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    34028708, /* 28618 ( 568) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    34015586, /* 28619 ( 568) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    17140692, /* 28620 ( 568) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6]  1 */
    18426650, /* 28621 ( 568) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    35550858, /* 28622 ( 568) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6] -1 */
    34028544, /* 28623 ( 568) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    52451832, /* 28624 ( 568) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
    35563820, /* 28625 ( 568) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
    51139794, /* 28626 ( 568) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6] -1 */
    34015422, /* 28627 ( 568) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    52438710, /* 28628 ( 568) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
    51152756, /* 28629 ( 568) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
        3362, /* 28630 ( 568) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    51139634, /* 28631 ( 568) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
    35550698, /* 28632 ( 568) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
     1538634, /* 28633 ( 568) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
       16484, /* 28634 ( 569) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34015586, /* 28635 ( 569) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    51139794, /* 28636 ( 569) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6] -1 */
    34015422, /* 28637 ( 569) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    18439608, /* 28638 ( 569) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
    52438710, /* 28639 ( 569) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
    35550858, /* 28640 ( 569) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6] -1 */
    17140692, /* 28641 ( 569) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6]  1 */
    52438874, /* 28642 ( 569) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
       16320, /* 28643 ( 569) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
     1551596, /* 28644 ( 569) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
    51139634, /* 28645 ( 569) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
     1551756, /* 28646 ( 569) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
    17140532, /* 28647 ( 569) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
    35550698, /* 28648 ( 569) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
    18439772, /* 28649 ( 569) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
       16484, /* 28650 ( 570) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34015422, /* 28651 ( 570) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    52438710, /* 28652 ( 570) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
    17140692, /* 28653 ( 570) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6]  1 */
    51152756, /* 28654 ( 570) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
        3362, /* 28655 ( 570) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    17127570, /* 28656 ( 570) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6]  1 */
    35563820, /* 28657 ( 570) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
    51139634, /* 28658 ( 570) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
    18426650, /* 28659 ( 570) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
     1551756, /* 28660 ( 570) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
    35550698, /* 28661 ( 570) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
    18439772, /* 28662 ( 570) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    34028544, /* 28663 ( 570) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    52451832, /* 28664 ( 570) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
     1538634, /* 28665 ( 570) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
       16484, /* 28666 ( 571) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    51139794, /* 28667 ( 571) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6] -1 */
    34015422, /* 28668 ( 571) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
     1538474, /* 28669 ( 571) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
    52438710, /* 28670 ( 571) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
    35550858, /* 28671 ( 571) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6] -1 */
        3362, /* 28672 ( 571) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
     1551596, /* 28673 ( 571) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
    35563980, /* 28674 ( 571) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6] -1 */
    18426650, /* 28675 ( 571) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    17127410, /* 28676 ( 571) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
    51152916, /* 28677 ( 571) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6] -1 */
    17140532, /* 28678 ( 571) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
    18439772, /* 28679 ( 571) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    34028544, /* 28680 ( 571) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    52451832, /* 28681 ( 571) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
       16484, /* 28682 ( 572) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34015586, /* 28683 ( 572) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    51139794, /* 28684 ( 572) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6] -1 */
    17140692, /* 28685 ( 572) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6]  1 */
     1538474, /* 28686 ( 572) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
    35550858, /* 28687 ( 572) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6] -1 */
    51152756, /* 28688 ( 572) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
    35563820, /* 28689 ( 572) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
    52438874, /* 28690 ( 572) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
    18426486, /* 28691 ( 572) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
        3198, /* 28692 ( 572) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
     1551756, /* 28693 ( 572) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
    17127410, /* 28694 ( 572) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
    18439772, /* 28695 ( 572) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    34028544, /* 28696 ( 572) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    52451832, /* 28697 ( 572) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
       16484, /* 28698 ( 573) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    51139794, /* 28699 ( 573) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6] -1 */
    18439608, /* 28700 ( 573) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
    35550858, /* 28701 ( 573) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6] -1 */
        3362, /* 28702 ( 573) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    51152756, /* 28703 ( 573) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
       16320, /* 28704 ( 573) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    18426486, /* 28705 ( 573) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
    35563980, /* 28706 ( 573) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6] -1 */
    51139634, /* 28707 ( 573) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
    18426650, /* 28708 ( 573) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
        3198, /* 28709 ( 573) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    51152916, /* 28710 ( 573) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6] -1 */
    35550698, /* 28711 ( 573) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
    18439772, /* 28712 ( 573) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    35563820, /* 28713 ( 573) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
       16484, /* 28714 ( 574) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34015586, /* 28715 ( 574) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    17127570, /* 28716 ( 574) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6]  1 */
    52438874, /* 28717 ( 574) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
    18426486, /* 28718 ( 574) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
    35563980, /* 28719 ( 574) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6] -1 */
    51139634, /* 28720 ( 574) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
     1551596, /* 28721 ( 574) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
        3198, /* 28722 ( 574) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    17140532, /* 28723 ( 574) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
    51152916, /* 28724 ( 574) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6] -1 */
    35550698, /* 28725 ( 574) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
    18439772, /* 28726 ( 574) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    34028544, /* 28727 ( 574) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    52451832, /* 28728 ( 574) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
     1538634, /* 28729 ( 574) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
       16484, /* 28730 ( 575) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34015586, /* 28731 ( 575) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    34015422, /* 28732 ( 575) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
     1538474, /* 28733 ( 575) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
    18439608, /* 28734 ( 575) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
    52438710, /* 28735 ( 575) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
    17127570, /* 28736 ( 575) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6]  1 */
    51152756, /* 28737 ( 575) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
    52438874, /* 28738 ( 575) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
       16320, /* 28739 ( 575) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    35563980, /* 28740 ( 575) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6] -1 */
    17127410, /* 28741 ( 575) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
    51152916, /* 28742 ( 575) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6] -1 */
    18439772, /* 28743 ( 575) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    35563820, /* 28744 ( 575) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
     1538634, /* 28745 ( 575) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
       16484, /* 28746 ( 576) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    35445882, /* 28747 ( 576) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  0] -1 */
    18439608, /* 28748 ( 576) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
    17127570, /* 28749 ( 576) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6]  1 */
       16320, /* 28750 ( 576) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    18426486, /* 28751 ( 576) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
     1551596, /* 28752 ( 576) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
        3198, /* 28753 ( 576) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    17127410, /* 28754 ( 576) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
    17140532, /* 28755 ( 576) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
    51021696, /* 28756 ( 576) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  0] -1 */
    52570094, /* 28757 ( 576) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    51034658, /* 28758 ( 576) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  0] -1 */
     1538474, /* 28759 ( 576) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
    34146806, /* 28760 ( 576) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
     1551756, /* 28761 ( 576) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
    34133684, /* 28762 ( 576) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    51021536, /* 28763 ( 576) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  0] -1 */
    18439772, /* 28764 ( 576) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    52556972, /* 28765 ( 576) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    17140692, /* 28766 ( 576) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6]  1 */
    35432760, /* 28767 ( 576) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  0] -1 */
    51034818, /* 28768 ( 576) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  0] -1 */
    18426650, /* 28769 ( 576) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    35445722, /* 28770 ( 576) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  0] -1 */
    34146642, /* 28771 ( 576) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
    52569930, /* 28772 ( 576) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    52556808, /* 28773 ( 576) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
        3362, /* 28774 ( 576) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    35432600, /* 28775 ( 576) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  0] -1 */
    34133520, /* 28776 ( 576) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
     1538634, /* 28777 ( 576) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
       16484, /* 28778 ( 577) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    18439608, /* 28779 ( 577) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
    17127570, /* 28780 ( 577) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6]  1 */
       16320, /* 28781 ( 577) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    18426486, /* 28782 ( 577) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
     1551596, /* 28783 ( 577) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
    35445720, /* 28784 ( 577) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  0] -1 */
        3198, /* 28785 ( 577) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    52556970, /* 28786 ( 577) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    17127410, /* 28787 ( 577) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
    17140532, /* 28788 ( 577) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
    35432598, /* 28789 ( 577) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  0] -1 */
     1538474, /* 28790 ( 577) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
    51034820, /* 28791 ( 577) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  0] -1 */
    51021698, /* 28792 ( 577) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  0] -1 */
    34146644, /* 28793 ( 577) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    52569932, /* 28794 ( 577) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
     1551756, /* 28795 ( 577) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
    34133682, /* 28796 ( 577) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
    18439772, /* 28797 ( 577) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    34133522, /* 28798 ( 577) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    52556810, /* 28799 ( 577) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    17140692, /* 28800 ( 577) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6]  1 */
    51034656, /* 28801 ( 577) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  0] -1 */
    18426650, /* 28802 ( 577) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    51021534, /* 28803 ( 577) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  0] -1 */
    35445884, /* 28804 ( 577) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  0] -1 */
    34146804, /* 28805 ( 577) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
    52570092, /* 28806 ( 577) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
        3362, /* 28807 ( 577) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    35432762, /* 28808 ( 577) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  0] -1 */
     1538634, /* 28809 ( 577) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
       16484, /* 28810 ( 578) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    18439608, /* 28811 ( 578) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
    17127570, /* 28812 ( 578) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6]  1 */
       16320, /* 28813 ( 578) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    18426486, /* 28814 ( 578) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
     1551596, /* 28815 ( 578) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
        3198, /* 28816 ( 578) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    51152754, /* 28817 ( 578) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  6] -1 */
    17127410, /* 28818 ( 578) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
    17140532, /* 28819 ( 578) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
    52438872, /* 28820 ( 578) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
    51139632, /* 28821 ( 578) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  6] -1 */
    35563818, /* 28822 ( 578) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  6] -1 */
    52451834, /* 28823 ( 578) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
    35550696, /* 28824 ( 578) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  6] -1 */
     1538474, /* 28825 ( 578) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
    34015584, /* 28826 ( 578) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
     1551756, /* 28827 ( 578) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
    18439772, /* 28828 ( 578) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    34015424, /* 28829 ( 578) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    52438712, /* 28830 ( 578) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
    34028546, /* 28831 ( 578) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    17140692, /* 28832 ( 578) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6]  1 */
    34028706, /* 28833 ( 578) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    35563982, /* 28834 ( 578) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
    52451994, /* 28835 ( 578) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
    18426650, /* 28836 ( 578) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    51152918, /* 28837 ( 578) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
        3362, /* 28838 ( 578) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    35550860, /* 28839 ( 578) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
    51139796, /* 28840 ( 578) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
     1538634, /* 28841 ( 578) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
       16484, /* 28842 ( 567) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
     1551756, /* 28843 ( 567) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
    17127410, /* 28844 ( 567) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
    18426648, /* 28845 ( 567) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
       16322, /* 28846 ( 567) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
     1551594, /* 28847 ( 567) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
        3360, /* 28848 ( 567) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    18426486, /* 28849 ( 567) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
    17127572, /* 28850 ( 567) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
    18439610, /* 28851 ( 567) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
        3198, /* 28852 ( 567) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    17140692, /* 28853 ( 567) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6]  1 */
     1538474, /* 28854 ( 567) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
     1538636, /* 28855 ( 567) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
    18439772, /* 28856 ( 567) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    17140530, /* 28857 ( 567) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  6]  1 */
       16484, /* 28858 ( 568) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    18426648, /* 28859 ( 568) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
     1551594, /* 28860 ( 568) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
        3360, /* 28861 ( 568) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    18426486, /* 28862 ( 568) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
    17127572, /* 28863 ( 568) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
    51152916, /* 28864 ( 568) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6] -1 */
    52451996, /* 28865 ( 568) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
        3198, /* 28866 ( 568) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
     1538474, /* 28867 ( 568) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
     1538636, /* 28868 ( 568) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
    35563980, /* 28869 ( 568) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6] -1 */
    17127410, /* 28870 ( 568) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
    52451834, /* 28871 ( 568) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
    17140692, /* 28872 ( 568) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6]  1 */
    18439772, /* 28873 ( 568) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    34028708, /* 28874 ( 568) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    34028546, /* 28875 ( 568) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
     1551756, /* 28876 ( 568) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
    18439610, /* 28877 ( 568) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    51152754, /* 28878 ( 568) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  6] -1 */
    34015584, /* 28879 ( 568) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    52438872, /* 28880 ( 568) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
    51139796, /* 28881 ( 568) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
    35563818, /* 28882 ( 568) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  6] -1 */
    34015422, /* 28883 ( 568) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    52438710, /* 28884 ( 568) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
    35550860, /* 28885 ( 568) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
       16322, /* 28886 ( 568) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    35550698, /* 28887 ( 568) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
    51139634, /* 28888 ( 568) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
    17140530, /* 28889 ( 568) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  6]  1 */
       16484, /* 28890 ( 569) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34028546, /* 28891 ( 569) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    35563818, /* 28892 ( 569) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  6] -1 */
    34015422, /* 28893 ( 569) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    18426648, /* 28894 ( 569) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
    52438710, /* 28895 ( 569) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
    51152754, /* 28896 ( 569) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  6] -1 */
     1551756, /* 28897 ( 569) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
    52451834, /* 28898 ( 569) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
        3360, /* 28899 ( 569) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    17127572, /* 28900 ( 569) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
    35550698, /* 28901 ( 569) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
    17140692, /* 28902 ( 569) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6]  1 */
     1538636, /* 28903 ( 569) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
    51139634, /* 28904 ( 569) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
    18439772, /* 28905 ( 569) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
       16484, /* 28906 ( 570) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34015422, /* 28907 ( 570) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    52438710, /* 28908 ( 570) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
     1551756, /* 28909 ( 570) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
    35550860, /* 28910 ( 570) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
       16322, /* 28911 ( 570) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
     1551594, /* 28912 ( 570) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
    51139796, /* 28913 ( 570) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
    35550698, /* 28914 ( 570) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
    18439610, /* 28915 ( 570) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    17140692, /* 28916 ( 570) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6]  1 */
    51139634, /* 28917 ( 570) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
    18439772, /* 28918 ( 570) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    34015584, /* 28919 ( 570) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    52438872, /* 28920 ( 570) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
    17140530, /* 28921 ( 570) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  6]  1 */
       16484, /* 28922 ( 571) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    35563818, /* 28923 ( 571) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  6] -1 */
    34015422, /* 28924 ( 571) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    17127410, /* 28925 ( 571) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
    52438710, /* 28926 ( 571) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
    51152754, /* 28927 ( 571) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  6] -1 */
       16322, /* 28928 ( 571) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    17127572, /* 28929 ( 571) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
    51152916, /* 28930 ( 571) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6] -1 */
    18439610, /* 28931 ( 571) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
     1538474, /* 28932 ( 571) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
    35563980, /* 28933 ( 571) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6] -1 */
     1538636, /* 28934 ( 571) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
    18439772, /* 28935 ( 571) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    34015584, /* 28936 ( 571) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    52438872, /* 28937 ( 571) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
       16484, /* 28938 ( 572) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34028546, /* 28939 ( 572) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    35563818, /* 28940 ( 572) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  6] -1 */
     1551756, /* 28941 ( 572) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
    17127410, /* 28942 ( 572) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
    51152754, /* 28943 ( 572) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  6] -1 */
    35550860, /* 28944 ( 572) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
    51139796, /* 28945 ( 572) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
    52451834, /* 28946 ( 572) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
    18426486, /* 28947 ( 572) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
        3198, /* 28948 ( 572) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    17140692, /* 28949 ( 572) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6]  1 */
     1538474, /* 28950 ( 572) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
    18439772, /* 28951 ( 572) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    34015584, /* 28952 ( 572) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    52438872, /* 28953 ( 572) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
       16484, /* 28954 ( 573) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    35563818, /* 28955 ( 573) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  6] -1 */
    18426648, /* 28956 ( 573) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
    51152754, /* 28957 ( 573) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  6] -1 */
       16322, /* 28958 ( 573) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    35550860, /* 28959 ( 573) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
        3360, /* 28960 ( 573) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    18426486, /* 28961 ( 573) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
    51152916, /* 28962 ( 573) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6] -1 */
    35550698, /* 28963 ( 573) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
    18439610, /* 28964 ( 573) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
        3198, /* 28965 ( 573) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    35563980, /* 28966 ( 573) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6] -1 */
    51139634, /* 28967 ( 573) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
    18439772, /* 28968 ( 573) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    51139796, /* 28969 ( 573) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
       16484, /* 28970 ( 574) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34028546, /* 28971 ( 574) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
     1551594, /* 28972 ( 574) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
    52451834, /* 28973 ( 574) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
    18426486, /* 28974 ( 574) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
    51152916, /* 28975 ( 574) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6] -1 */
    35550698, /* 28976 ( 574) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
    17127572, /* 28977 ( 574) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
        3198, /* 28978 ( 574) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
     1538636, /* 28979 ( 574) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
    35563980, /* 28980 ( 574) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6] -1 */
    51139634, /* 28981 ( 574) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
    18439772, /* 28982 ( 574) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    34015584, /* 28983 ( 574) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    52438872, /* 28984 ( 574) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
    17140530, /* 28985 ( 574) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  6]  1 */
       16484, /* 28986 ( 575) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34028546, /* 28987 ( 575) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    34015422, /* 28988 ( 575) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    17127410, /* 28989 ( 575) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
    18426648, /* 28990 ( 575) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
    52438710, /* 28991 ( 575) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
     1551594, /* 28992 ( 575) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
    35550860, /* 28993 ( 575) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
    52451834, /* 28994 ( 575) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
        3360, /* 28995 ( 575) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    51152916, /* 28996 ( 575) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6] -1 */
     1538474, /* 28997 ( 575) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
    35563980, /* 28998 ( 575) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6] -1 */
    18439772, /* 28999 ( 575) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    51139796, /* 29000 ( 575) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
    17140530, /* 29001 ( 575) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  6]  1 */
       16484, /* 29002 ( 576) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    51034818, /* 29003 ( 576) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  0] -1 */
    18426648, /* 29004 ( 576) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
     1551594, /* 29005 ( 576) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
        3360, /* 29006 ( 576) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    18426486, /* 29007 ( 576) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
    17127572, /* 29008 ( 576) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
        3198, /* 29009 ( 576) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
     1538474, /* 29010 ( 576) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
     1538636, /* 29011 ( 576) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
    35445720, /* 29012 ( 576) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  0] -1 */
    52570094, /* 29013 ( 576) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    35432762, /* 29014 ( 576) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  0] -1 */
    17127410, /* 29015 ( 576) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
    34146806, /* 29016 ( 576) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    17140692, /* 29017 ( 576) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6]  1 */
    34146644, /* 29018 ( 576) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    35432600, /* 29019 ( 576) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  0] -1 */
    18439772, /* 29020 ( 576) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    52569932, /* 29021 ( 576) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
     1551756, /* 29022 ( 576) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
    51034656, /* 29023 ( 576) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  0] -1 */
    35445882, /* 29024 ( 576) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  0] -1 */
    18439610, /* 29025 ( 576) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    51021698, /* 29026 ( 576) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  0] -1 */
    34133682, /* 29027 ( 576) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
    52556970, /* 29028 ( 576) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    52556808, /* 29029 ( 576) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
       16322, /* 29030 ( 576) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    51021536, /* 29031 ( 576) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  0] -1 */
    34133520, /* 29032 ( 576) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
    17140530, /* 29033 ( 576) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  6]  1 */
       16484, /* 29034 ( 577) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    18426648, /* 29035 ( 577) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
     1551594, /* 29036 ( 577) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
        3360, /* 29037 ( 577) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    18426486, /* 29038 ( 577) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
    17127572, /* 29039 ( 577) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
    51021696, /* 29040 ( 577) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  0] -1 */
        3198, /* 29041 ( 577) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    52569930, /* 29042 ( 577) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
     1538474, /* 29043 ( 577) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
     1538636, /* 29044 ( 577) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
    51021534, /* 29045 ( 577) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  0] -1 */
    17127410, /* 29046 ( 577) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
    35445884, /* 29047 ( 577) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  0] -1 */
    35445722, /* 29048 ( 577) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  0] -1 */
    34133684, /* 29049 ( 577) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    52556972, /* 29050 ( 577) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    17140692, /* 29051 ( 577) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6]  1 */
    34146642, /* 29052 ( 577) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
    18439772, /* 29053 ( 577) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    34133522, /* 29054 ( 577) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    52556810, /* 29055 ( 577) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
     1551756, /* 29056 ( 577) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
    35432760, /* 29057 ( 577) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  0] -1 */
    18439610, /* 29058 ( 577) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    35432598, /* 29059 ( 577) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  0] -1 */
    51034820, /* 29060 ( 577) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  0] -1 */
    34146804, /* 29061 ( 577) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
    52570092, /* 29062 ( 577) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
       16322, /* 29063 ( 577) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    51034658, /* 29064 ( 577) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  0] -1 */
    17140530, /* 29065 ( 577) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  6]  1 */
       16484, /* 29066 ( 578) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    18426648, /* 29067 ( 578) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
     1551594, /* 29068 ( 578) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
        3360, /* 29069 ( 578) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    18426486, /* 29070 ( 578) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
    17127572, /* 29071 ( 578) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
        3198, /* 29072 ( 578) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    35550858, /* 29073 ( 578) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6] -1 */
     1538474, /* 29074 ( 578) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
     1538636, /* 29075 ( 578) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
    52451832, /* 29076 ( 578) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
    35550696, /* 29077 ( 578) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  6] -1 */
    51139794, /* 29078 ( 578) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6] -1 */
    52438874, /* 29079 ( 578) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
    51139632, /* 29080 ( 578) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  6] -1 */
    17127410, /* 29081 ( 578) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
    34028544, /* 29082 ( 578) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    17140692, /* 29083 ( 578) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6]  1 */
    18439772, /* 29084 ( 578) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    34015424, /* 29085 ( 578) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    52438712, /* 29086 ( 578) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
    34015586, /* 29087 ( 578) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
     1551756, /* 29088 ( 578) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
    34028706, /* 29089 ( 578) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    51152918, /* 29090 ( 578) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
    52451994, /* 29091 ( 578) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
    18439610, /* 29092 ( 578) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    35563982, /* 29093 ( 578) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
       16322, /* 29094 ( 578) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    51152756, /* 29095 ( 578) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
    35563820, /* 29096 ( 578) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
    17140530, /* 29097 ( 578) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  6]  1 */
       16484, /* 29098 ( 567) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    18426650, /* 29099 ( 567) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    17140530, /* 29100 ( 567) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  6]  1 */
     1538634, /* 29101 ( 567) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
       16322, /* 29102 ( 567) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    18426488, /* 29103 ( 567) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
        3360, /* 29104 ( 567) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
     1538472, /* 29105 ( 567) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
    17140692, /* 29106 ( 567) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6]  1 */
     1551596, /* 29107 ( 567) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
        3198, /* 29108 ( 567) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    17127572, /* 29109 ( 567) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
    18439608, /* 29110 ( 567) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
    18439770, /* 29111 ( 567) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
     1551758, /* 29112 ( 567) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
    17127410, /* 29113 ( 567) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
       16484, /* 29114 ( 568) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
     1538634, /* 29115 ( 568) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
    18426488, /* 29116 ( 568) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
        3360, /* 29117 ( 568) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
     1538472, /* 29118 ( 568) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
    17140692, /* 29119 ( 568) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6]  1 */
    51139796, /* 29120 ( 568) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
    35563982, /* 29121 ( 568) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
        3198, /* 29122 ( 568) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    18439608, /* 29123 ( 568) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
    18439770, /* 29124 ( 568) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
    52438874, /* 29125 ( 568) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
    17140530, /* 29126 ( 568) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  6]  1 */
    35563820, /* 29127 ( 568) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
    17127572, /* 29128 ( 568) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
     1551758, /* 29129 ( 568) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
    34028708, /* 29130 ( 568) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    34028546, /* 29131 ( 568) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    18426650, /* 29132 ( 568) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
     1551596, /* 29133 ( 568) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
    51139634, /* 29134 ( 568) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
    34015584, /* 29135 ( 568) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    35550858, /* 29136 ( 568) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6] -1 */
    51152916, /* 29137 ( 568) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6] -1 */
    52438712, /* 29138 ( 568) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
    34015422, /* 29139 ( 568) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    35550696, /* 29140 ( 568) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  6] -1 */
    52451994, /* 29141 ( 568) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
       16322, /* 29142 ( 568) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    52451832, /* 29143 ( 568) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
    51152754, /* 29144 ( 568) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  6] -1 */
    17127410, /* 29145 ( 568) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
       16484, /* 29146 ( 569) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34028546, /* 29147 ( 569) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    52438712, /* 29148 ( 569) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
    34015422, /* 29149 ( 569) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
     1538634, /* 29150 ( 569) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
    35550696, /* 29151 ( 569) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  6] -1 */
    51139634, /* 29152 ( 569) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
    18426650, /* 29153 ( 569) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    35563820, /* 29154 ( 569) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
        3360, /* 29155 ( 569) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    17140692, /* 29156 ( 569) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6]  1 */
    52451832, /* 29157 ( 569) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
    17127572, /* 29158 ( 569) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
    18439770, /* 29159 ( 569) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
    51152754, /* 29160 ( 569) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  6] -1 */
     1551758, /* 29161 ( 569) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
       16484, /* 29162 ( 570) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34015422, /* 29163 ( 570) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    35550696, /* 29164 ( 570) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  6] -1 */
    18426650, /* 29165 ( 570) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    52451994, /* 29166 ( 570) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
       16322, /* 29167 ( 570) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    18426488, /* 29168 ( 570) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    51152916, /* 29169 ( 570) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6] -1 */
    52451832, /* 29170 ( 570) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
     1551596, /* 29171 ( 570) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
    17127572, /* 29172 ( 570) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
    51152754, /* 29173 ( 570) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  6] -1 */
     1551758, /* 29174 ( 570) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
    34015584, /* 29175 ( 570) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    35550858, /* 29176 ( 570) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6] -1 */
    17127410, /* 29177 ( 570) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
       16484, /* 29178 ( 571) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    52438712, /* 29179 ( 571) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
    34015422, /* 29180 ( 571) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    17140530, /* 29181 ( 571) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  6]  1 */
    35550696, /* 29182 ( 571) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  6] -1 */
    51139634, /* 29183 ( 571) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
       16322, /* 29184 ( 571) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    17140692, /* 29185 ( 571) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6]  1 */
    51139796, /* 29186 ( 571) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
     1551596, /* 29187 ( 571) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
    18439608, /* 29188 ( 571) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
    52438874, /* 29189 ( 571) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
    18439770, /* 29190 ( 571) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
     1551758, /* 29191 ( 571) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
    34015584, /* 29192 ( 571) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    35550858, /* 29193 ( 571) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6] -1 */
       16484, /* 29194 ( 572) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34028546, /* 29195 ( 572) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    52438712, /* 29196 ( 572) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
    18426650, /* 29197 ( 572) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    17140530, /* 29198 ( 572) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  6]  1 */
    51139634, /* 29199 ( 572) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
    52451994, /* 29200 ( 572) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
    51152916, /* 29201 ( 572) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6] -1 */
    35563820, /* 29202 ( 572) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
     1538472, /* 29203 ( 572) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
        3198, /* 29204 ( 572) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    17127572, /* 29205 ( 572) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
    18439608, /* 29206 ( 572) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
     1551758, /* 29207 ( 572) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
    34015584, /* 29208 ( 572) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    35550858, /* 29209 ( 572) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6] -1 */
       16484, /* 29210 ( 573) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    52438712, /* 29211 ( 573) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
     1538634, /* 29212 ( 573) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
    51139634, /* 29213 ( 573) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
       16322, /* 29214 ( 573) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    52451994, /* 29215 ( 573) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
        3360, /* 29216 ( 573) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
     1538472, /* 29217 ( 573) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
    51139796, /* 29218 ( 573) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
    52451832, /* 29219 ( 573) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
     1551596, /* 29220 ( 573) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
        3198, /* 29221 ( 573) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    52438874, /* 29222 ( 573) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
    51152754, /* 29223 ( 573) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  6] -1 */
     1551758, /* 29224 ( 573) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
    51152916, /* 29225 ( 573) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6] -1 */
       16484, /* 29226 ( 574) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34028546, /* 29227 ( 574) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    18426488, /* 29228 ( 574) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    35563820, /* 29229 ( 574) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
     1538472, /* 29230 ( 574) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
    51139796, /* 29231 ( 574) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
    52451832, /* 29232 ( 574) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
    17140692, /* 29233 ( 574) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6]  1 */
        3198, /* 29234 ( 574) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    18439770, /* 29235 ( 574) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
    52438874, /* 29236 ( 574) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
    51152754, /* 29237 ( 574) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  6] -1 */
     1551758, /* 29238 ( 574) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
    34015584, /* 29239 ( 574) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    35550858, /* 29240 ( 574) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6] -1 */
    17127410, /* 29241 ( 574) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
       16484, /* 29242 ( 575) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34028546, /* 29243 ( 575) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    34015422, /* 29244 ( 575) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    17140530, /* 29245 ( 575) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  6]  1 */
     1538634, /* 29246 ( 575) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
    35550696, /* 29247 ( 575) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  6] -1 */
    18426488, /* 29248 ( 575) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    52451994, /* 29249 ( 575) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
    35563820, /* 29250 ( 575) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
        3360, /* 29251 ( 575) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    51139796, /* 29252 ( 575) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
    18439608, /* 29253 ( 575) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
    52438874, /* 29254 ( 575) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
     1551758, /* 29255 ( 575) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
    51152916, /* 29256 ( 575) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6] -1 */
    17127410, /* 29257 ( 575) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
       16484, /* 29258 ( 576) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34133684, /* 29259 ( 576) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
     1538634, /* 29260 ( 576) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
    18426488, /* 29261 ( 576) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
        3360, /* 29262 ( 576) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
     1538472, /* 29263 ( 576) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
    17140692, /* 29264 ( 576) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6]  1 */
        3198, /* 29265 ( 576) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    18439608, /* 29266 ( 576) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
    18439770, /* 29267 ( 576) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
    35432600, /* 29268 ( 576) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  0] -1 */
    52570094, /* 29269 ( 576) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    35445882, /* 29270 ( 576) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  0] -1 */
    17140530, /* 29271 ( 576) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  6]  1 */
    51034820, /* 29272 ( 576) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  0] -1 */
    17127572, /* 29273 ( 576) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
    51034658, /* 29274 ( 576) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  0] -1 */
    35445720, /* 29275 ( 576) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  0] -1 */
     1551758, /* 29276 ( 576) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
    52569932, /* 29277 ( 576) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    18426650, /* 29278 ( 576) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    34133522, /* 29279 ( 576) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    35432762, /* 29280 ( 576) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  0] -1 */
     1551596, /* 29281 ( 576) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
    34146804, /* 29282 ( 576) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
    51021696, /* 29283 ( 576) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  0] -1 */
    52556970, /* 29284 ( 576) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    52556808, /* 29285 ( 576) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
       16322, /* 29286 ( 576) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34146642, /* 29287 ( 576) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
    51021534, /* 29288 ( 576) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  0] -1 */
    17127410, /* 29289 ( 576) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
       16484, /* 29290 ( 577) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
     1538634, /* 29291 ( 577) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
    18426488, /* 29292 ( 577) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
        3360, /* 29293 ( 577) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
     1538472, /* 29294 ( 577) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
    17140692, /* 29295 ( 577) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6]  1 */
    34133682, /* 29296 ( 577) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
        3198, /* 29297 ( 577) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    52556810, /* 29298 ( 577) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    18439608, /* 29299 ( 577) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
    18439770, /* 29300 ( 577) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
    34133520, /* 29301 ( 577) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
    17140530, /* 29302 ( 577) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  6]  1 */
    35445884, /* 29303 ( 577) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  0] -1 */
    35445722, /* 29304 ( 577) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  0] -1 */
    51034818, /* 29305 ( 577) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  0] -1 */
    52570092, /* 29306 ( 577) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    17127572, /* 29307 ( 577) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
    51021536, /* 29308 ( 577) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  0] -1 */
     1551758, /* 29309 ( 577) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
    51034656, /* 29310 ( 577) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  0] -1 */
    52569930, /* 29311 ( 577) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    18426650, /* 29312 ( 577) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    35432760, /* 29313 ( 577) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  0] -1 */
     1551596, /* 29314 ( 577) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
    35432598, /* 29315 ( 577) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  0] -1 */
    34146806, /* 29316 ( 577) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    51021698, /* 29317 ( 577) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  0] -1 */
    52556972, /* 29318 ( 577) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
       16322, /* 29319 ( 577) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34146644, /* 29320 ( 577) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    17127410, /* 29321 ( 577) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
       16484, /* 29322 ( 578) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
     1538634, /* 29323 ( 578) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
    18426488, /* 29324 ( 578) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
        3360, /* 29325 ( 578) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
     1538472, /* 29326 ( 578) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
    17140692, /* 29327 ( 578) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6]  1 */
        3198, /* 29328 ( 578) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    52438872, /* 29329 ( 578) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
    18439608, /* 29330 ( 578) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
    18439770, /* 29331 ( 578) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
    35550698, /* 29332 ( 578) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
    52438710, /* 29333 ( 578) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
    51139794, /* 29334 ( 578) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6] -1 */
    35563980, /* 29335 ( 578) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6] -1 */
    51139632, /* 29336 ( 578) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  6] -1 */
    17140530, /* 29337 ( 578) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  6]  1 */
    34015424, /* 29338 ( 578) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    17127572, /* 29339 ( 578) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
     1551758, /* 29340 ( 578) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
    34028544, /* 29341 ( 578) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    35563818, /* 29342 ( 578) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  6] -1 */
    34028706, /* 29343 ( 578) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    18426650, /* 29344 ( 578) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    34015586, /* 29345 ( 578) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    51152918, /* 29346 ( 578) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
    35550860, /* 29347 ( 578) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
     1551596, /* 29348 ( 578) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
    52451996, /* 29349 ( 578) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
       16322, /* 29350 ( 578) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    51152756, /* 29351 ( 578) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
    52451834, /* 29352 ( 578) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
    17127410, /* 29353 ( 578) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
       16484, /* 29354 ( 567) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    17127572, /* 29355 ( 567) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
    18439608, /* 29356 ( 567) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
     1538474, /* 29357 ( 567) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
       16482, /* 29358 ( 567) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    17127570, /* 29359 ( 567) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6]  1 */
        3200, /* 29360 ( 567) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
     1538472, /* 29361 ( 567) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
    18439610, /* 29362 ( 567) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
     1551756, /* 29363 ( 567) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
        3198, /* 29364 ( 567) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    18426650, /* 29365 ( 567) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    17140530, /* 29366 ( 567) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  6]  1 */
    17140532, /* 29367 ( 567) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
     1551758, /* 29368 ( 567) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
    18426648, /* 29369 ( 567) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
       16484, /* 29370 ( 568) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
     1538474, /* 29371 ( 568) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
    17127570, /* 29372 ( 568) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6]  1 */
        3200, /* 29373 ( 568) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
     1538472, /* 29374 ( 568) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
    18439610, /* 29375 ( 568) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    52438874, /* 29376 ( 568) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
    35563982, /* 29377 ( 568) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
        3198, /* 29378 ( 568) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    17140530, /* 29379 ( 568) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  6]  1 */
    17140532, /* 29380 ( 568) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
    51139796, /* 29381 ( 568) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
    18439608, /* 29382 ( 568) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
    35563980, /* 29383 ( 568) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6] -1 */
    18426650, /* 29384 ( 568) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
     1551758, /* 29385 ( 568) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
    34028708, /* 29386 ( 568) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    34028706, /* 29387 ( 568) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    17127572, /* 29388 ( 568) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
     1551756, /* 29389 ( 568) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
    52438872, /* 29390 ( 568) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
    34015424, /* 29391 ( 568) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    35550698, /* 29392 ( 568) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
    52451834, /* 29393 ( 568) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
    51139794, /* 29394 ( 568) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6] -1 */
    34015422, /* 29395 ( 568) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    35550696, /* 29396 ( 568) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  6] -1 */
    51152756, /* 29397 ( 568) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
       16482, /* 29398 ( 568) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    51152754, /* 29399 ( 568) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  6] -1 */
    52451832, /* 29400 ( 568) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
    18426648, /* 29401 ( 568) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
       16484, /* 29402 ( 569) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34028706, /* 29403 ( 569) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    51139794, /* 29404 ( 569) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6] -1 */
    34015422, /* 29405 ( 569) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
     1538474, /* 29406 ( 569) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
    35550696, /* 29407 ( 569) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  6] -1 */
    52438872, /* 29408 ( 569) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
    17127572, /* 29409 ( 569) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
    35563980, /* 29410 ( 569) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6] -1 */
        3200, /* 29411 ( 569) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    18439610, /* 29412 ( 569) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    51152754, /* 29413 ( 569) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  6] -1 */
    18426650, /* 29414 ( 569) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    17140532, /* 29415 ( 569) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
    52451832, /* 29416 ( 569) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
     1551758, /* 29417 ( 569) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
       16484, /* 29418 ( 570) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34015422, /* 29419 ( 570) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    35550696, /* 29420 ( 570) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  6] -1 */
    17127572, /* 29421 ( 570) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
    51152756, /* 29422 ( 570) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
       16482, /* 29423 ( 570) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    17127570, /* 29424 ( 570) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6]  1 */
    52451834, /* 29425 ( 570) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
    51152754, /* 29426 ( 570) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  6] -1 */
     1551756, /* 29427 ( 570) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
    18426650, /* 29428 ( 570) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    52451832, /* 29429 ( 570) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
     1551758, /* 29430 ( 570) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
    34015424, /* 29431 ( 570) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    35550698, /* 29432 ( 570) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
    18426648, /* 29433 ( 570) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
       16484, /* 29434 ( 571) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    51139794, /* 29435 ( 571) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6] -1 */
    34015422, /* 29436 ( 571) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    18439608, /* 29437 ( 571) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
    35550696, /* 29438 ( 571) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  6] -1 */
    52438872, /* 29439 ( 571) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
       16482, /* 29440 ( 571) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    18439610, /* 29441 ( 571) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    52438874, /* 29442 ( 571) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
     1551756, /* 29443 ( 571) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
    17140530, /* 29444 ( 571) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  6]  1 */
    51139796, /* 29445 ( 571) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
    17140532, /* 29446 ( 571) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
     1551758, /* 29447 ( 571) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
    34015424, /* 29448 ( 571) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    35550698, /* 29449 ( 571) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
       16484, /* 29450 ( 572) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34028706, /* 29451 ( 572) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    51139794, /* 29452 ( 572) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6] -1 */
    17127572, /* 29453 ( 572) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
    18439608, /* 29454 ( 572) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
    52438872, /* 29455 ( 572) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
    51152756, /* 29456 ( 572) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
    52451834, /* 29457 ( 572) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
    35563980, /* 29458 ( 572) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6] -1 */
     1538472, /* 29459 ( 572) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
        3198, /* 29460 ( 572) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    18426650, /* 29461 ( 572) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    17140530, /* 29462 ( 572) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  6]  1 */
     1551758, /* 29463 ( 572) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
    34015424, /* 29464 ( 572) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    35550698, /* 29465 ( 572) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
       16484, /* 29466 ( 573) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    51139794, /* 29467 ( 573) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6] -1 */
     1538474, /* 29468 ( 573) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
    52438872, /* 29469 ( 573) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
       16482, /* 29470 ( 573) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    51152756, /* 29471 ( 573) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
        3200, /* 29472 ( 573) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
     1538472, /* 29473 ( 573) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
    52438874, /* 29474 ( 573) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
    51152754, /* 29475 ( 573) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  6] -1 */
     1551756, /* 29476 ( 573) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
        3198, /* 29477 ( 573) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    51139796, /* 29478 ( 573) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
    52451832, /* 29479 ( 573) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
     1551758, /* 29480 ( 573) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
    52451834, /* 29481 ( 573) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
       16484, /* 29482 ( 574) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34028706, /* 29483 ( 574) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    17127570, /* 29484 ( 574) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6]  1 */
    35563980, /* 29485 ( 574) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6] -1 */
     1538472, /* 29486 ( 574) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
    52438874, /* 29487 ( 574) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
    51152754, /* 29488 ( 574) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  6] -1 */
    18439610, /* 29489 ( 574) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
        3198, /* 29490 ( 574) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    17140532, /* 29491 ( 574) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
    51139796, /* 29492 ( 574) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
    52451832, /* 29493 ( 574) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
     1551758, /* 29494 ( 574) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
    34015424, /* 29495 ( 574) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    35550698, /* 29496 ( 574) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
    18426648, /* 29497 ( 574) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
       16484, /* 29498 ( 575) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34028706, /* 29499 ( 575) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    34015422, /* 29500 ( 575) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    18439608, /* 29501 ( 575) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
     1538474, /* 29502 ( 575) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
    35550696, /* 29503 ( 575) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  6] -1 */
    17127570, /* 29504 ( 575) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6]  1 */
    51152756, /* 29505 ( 575) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
    35563980, /* 29506 ( 575) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6] -1 */
        3200, /* 29507 ( 575) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    52438874, /* 29508 ( 575) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
    17140530, /* 29509 ( 575) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  6]  1 */
    51139796, /* 29510 ( 575) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
     1551758, /* 29511 ( 575) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
    52451834, /* 29512 ( 575) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
    18426648, /* 29513 ( 575) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
       16484, /* 29514 ( 576) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    35432762, /* 29515 ( 576) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  0] -1 */
     1538474, /* 29516 ( 576) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
    17127570, /* 29517 ( 576) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6]  1 */
        3200, /* 29518 ( 576) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
     1538472, /* 29519 ( 576) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
    18439610, /* 29520 ( 576) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
        3198, /* 29521 ( 576) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    17140530, /* 29522 ( 576) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  6]  1 */
    17140532, /* 29523 ( 576) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
    34133682, /* 29524 ( 576) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
    52570094, /* 29525 ( 576) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    34146644, /* 29526 ( 576) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    18439608, /* 29527 ( 576) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
    51034820, /* 29528 ( 576) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  0] -1 */
    18426650, /* 29529 ( 576) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    51034818, /* 29530 ( 576) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  0] -1 */
    34146642, /* 29531 ( 576) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
     1551758, /* 29532 ( 576) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
    52570092, /* 29533 ( 576) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    17127572, /* 29534 ( 576) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
    35432760, /* 29535 ( 576) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  0] -1 */
    34133684, /* 29536 ( 576) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
     1551756, /* 29537 ( 576) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
    35445722, /* 29538 ( 576) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  0] -1 */
    51021536, /* 29539 ( 576) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  0] -1 */
    52556810, /* 29540 ( 576) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    52556808, /* 29541 ( 576) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
       16482, /* 29542 ( 576) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    35445720, /* 29543 ( 576) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  0] -1 */
    51021534, /* 29544 ( 576) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  0] -1 */
    18426648, /* 29545 ( 576) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
       16484, /* 29546 ( 577) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
     1538474, /* 29547 ( 577) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
    17127570, /* 29548 ( 577) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6]  1 */
        3200, /* 29549 ( 577) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
     1538472, /* 29550 ( 577) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
    18439610, /* 29551 ( 577) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    35432600, /* 29552 ( 577) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  0] -1 */
        3198, /* 29553 ( 577) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    52556970, /* 29554 ( 577) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    17140530, /* 29555 ( 577) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  6]  1 */
    17140532, /* 29556 ( 577) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
    35432598, /* 29557 ( 577) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  0] -1 */
    18439608, /* 29558 ( 577) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
    34146806, /* 29559 ( 577) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    34146804, /* 29560 ( 577) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
    51034658, /* 29561 ( 577) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  0] -1 */
    52569932, /* 29562 ( 577) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    18426650, /* 29563 ( 577) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    51021696, /* 29564 ( 577) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  0] -1 */
     1551758, /* 29565 ( 577) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
    51034656, /* 29566 ( 577) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  0] -1 */
    52569930, /* 29567 ( 577) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    17127572, /* 29568 ( 577) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
    34133522, /* 29569 ( 577) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
     1551756, /* 29570 ( 577) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
    34133520, /* 29571 ( 577) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
    35445884, /* 29572 ( 577) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  0] -1 */
    51021698, /* 29573 ( 577) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  0] -1 */
    52556972, /* 29574 ( 577) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
       16482, /* 29575 ( 577) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    35445882, /* 29576 ( 577) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  0] -1 */
    18426648, /* 29577 ( 577) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
       16484, /* 29578 ( 578) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
     1538474, /* 29579 ( 578) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
    17127570, /* 29580 ( 578) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6]  1 */
        3200, /* 29581 ( 578) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
     1538472, /* 29582 ( 578) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
    18439610, /* 29583 ( 578) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
        3198, /* 29584 ( 578) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    51139634, /* 29585 ( 578) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
    17140530, /* 29586 ( 578) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  6]  1 */
    17140532, /* 29587 ( 578) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
    35550858, /* 29588 ( 578) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6] -1 */
    51139632, /* 29589 ( 578) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  6] -1 */
    52438712, /* 29590 ( 578) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
    35563820, /* 29591 ( 578) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
    52438710, /* 29592 ( 578) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
    18439608, /* 29593 ( 578) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
    34015584, /* 29594 ( 578) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    18426650, /* 29595 ( 578) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
     1551758, /* 29596 ( 578) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
    34028544, /* 29597 ( 578) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    35563818, /* 29598 ( 578) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  6] -1 */
    34028546, /* 29599 ( 578) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    17127572, /* 29600 ( 578) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
    34015586, /* 29601 ( 578) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    52451996, /* 29602 ( 578) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
    35550860, /* 29603 ( 578) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
     1551756, /* 29604 ( 578) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
    51152918, /* 29605 ( 578) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
       16482, /* 29606 ( 578) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    52451994, /* 29607 ( 578) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
    51152916, /* 29608 ( 578) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6] -1 */
    18426648, /* 29609 ( 578) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
       16484, /* 29610 ( 567) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
     1551596, /* 29611 ( 567) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
    18426648, /* 29612 ( 567) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
    17127410, /* 29613 ( 567) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
       16482, /* 29614 ( 567) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
     1551594, /* 29615 ( 567) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
        3200, /* 29616 ( 567) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    17127408, /* 29617 ( 567) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  6]  1 */
    18426650, /* 29618 ( 567) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    17140692, /* 29619 ( 567) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6]  1 */
        3198, /* 29620 ( 567) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    18439610, /* 29621 ( 567) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
     1538634, /* 29622 ( 567) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
     1538636, /* 29623 ( 567) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
    17140694, /* 29624 ( 567) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
    18439608, /* 29625 ( 567) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
       16484, /* 29626 ( 568) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    17127410, /* 29627 ( 568) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
     1551594, /* 29628 ( 568) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
        3200, /* 29629 ( 568) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    17127408, /* 29630 ( 568) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  6]  1 */
    18426650, /* 29631 ( 568) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    52451834, /* 29632 ( 568) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
    51152918, /* 29633 ( 568) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
        3198, /* 29634 ( 568) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
     1538634, /* 29635 ( 568) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
     1538636, /* 29636 ( 568) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
    35563820, /* 29637 ( 568) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
    18426648, /* 29638 ( 568) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
    51152916, /* 29639 ( 568) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6] -1 */
    18439610, /* 29640 ( 568) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    17140694, /* 29641 ( 568) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
    34028708, /* 29642 ( 568) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    34028706, /* 29643 ( 568) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
     1551596, /* 29644 ( 568) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
    17140692, /* 29645 ( 568) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6]  1 */
    52451832, /* 29646 ( 568) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
    34015424, /* 29647 ( 568) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    51139634, /* 29648 ( 568) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
    52438874, /* 29649 ( 568) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
    35563818, /* 29650 ( 568) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  6] -1 */
    34015422, /* 29651 ( 568) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    51139632, /* 29652 ( 568) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  6] -1 */
    35550860, /* 29653 ( 568) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
       16482, /* 29654 ( 568) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    35550858, /* 29655 ( 568) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6] -1 */
    52438872, /* 29656 ( 568) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
    18439608, /* 29657 ( 568) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
       16484, /* 29658 ( 569) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34028706, /* 29659 ( 569) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    35563818, /* 29660 ( 569) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  6] -1 */
    34015422, /* 29661 ( 569) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    17127410, /* 29662 ( 569) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
    51139632, /* 29663 ( 569) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  6] -1 */
    52451832, /* 29664 ( 569) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
     1551596, /* 29665 ( 569) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
    51152916, /* 29666 ( 569) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6] -1 */
        3200, /* 29667 ( 569) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    18426650, /* 29668 ( 569) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    35550858, /* 29669 ( 569) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6] -1 */
    18439610, /* 29670 ( 569) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
     1538636, /* 29671 ( 569) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
    52438872, /* 29672 ( 569) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
    17140694, /* 29673 ( 569) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
       16484, /* 29674 ( 570) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34015422, /* 29675 ( 570) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    51139632, /* 29676 ( 570) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  6] -1 */
     1551596, /* 29677 ( 570) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
    35550860, /* 29678 ( 570) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
       16482, /* 29679 ( 570) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
     1551594, /* 29680 ( 570) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
    52438874, /* 29681 ( 570) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
    35550858, /* 29682 ( 570) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6] -1 */
    17140692, /* 29683 ( 570) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6]  1 */
    18439610, /* 29684 ( 570) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    52438872, /* 29685 ( 570) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
    17140694, /* 29686 ( 570) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
    34015424, /* 29687 ( 570) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    51139634, /* 29688 ( 570) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
    18439608, /* 29689 ( 570) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
       16484, /* 29690 ( 571) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    35563818, /* 29691 ( 571) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  6] -1 */
    34015422, /* 29692 ( 571) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    18426648, /* 29693 ( 571) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
    51139632, /* 29694 ( 571) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  6] -1 */
    52451832, /* 29695 ( 571) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
       16482, /* 29696 ( 571) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    18426650, /* 29697 ( 571) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    52451834, /* 29698 ( 571) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
    17140692, /* 29699 ( 571) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6]  1 */
     1538634, /* 29700 ( 571) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
    35563820, /* 29701 ( 571) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
     1538636, /* 29702 ( 571) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
    17140694, /* 29703 ( 571) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
    34015424, /* 29704 ( 571) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    51139634, /* 29705 ( 571) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
       16484, /* 29706 ( 572) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34028706, /* 29707 ( 572) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    35563818, /* 29708 ( 572) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  6] -1 */
     1551596, /* 29709 ( 572) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
    18426648, /* 29710 ( 572) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
    52451832, /* 29711 ( 572) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
    35550860, /* 29712 ( 572) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
    52438874, /* 29713 ( 572) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
    51152916, /* 29714 ( 572) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6] -1 */
    17127408, /* 29715 ( 572) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  6]  1 */
        3198, /* 29716 ( 572) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    18439610, /* 29717 ( 572) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
     1538634, /* 29718 ( 572) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
    17140694, /* 29719 ( 572) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
    34015424, /* 29720 ( 572) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    51139634, /* 29721 ( 572) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
       16484, /* 29722 ( 573) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    35563818, /* 29723 ( 573) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  6] -1 */
    17127410, /* 29724 ( 573) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
    52451832, /* 29725 ( 573) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
       16482, /* 29726 ( 573) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    35550860, /* 29727 ( 573) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
        3200, /* 29728 ( 573) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    17127408, /* 29729 ( 573) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  6]  1 */
    52451834, /* 29730 ( 573) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
    35550858, /* 29731 ( 573) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6] -1 */
    17140692, /* 29732 ( 573) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6]  1 */
        3198, /* 29733 ( 573) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    35563820, /* 29734 ( 573) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
    52438872, /* 29735 ( 573) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
    17140694, /* 29736 ( 573) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
    52438874, /* 29737 ( 573) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
       16484, /* 29738 ( 574) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34028706, /* 29739 ( 574) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
     1551594, /* 29740 ( 574) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
    51152916, /* 29741 ( 574) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6] -1 */
    17127408, /* 29742 ( 574) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  6]  1 */
    52451834, /* 29743 ( 574) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
    35550858, /* 29744 ( 574) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6] -1 */
    18426650, /* 29745 ( 574) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
        3198, /* 29746 ( 574) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
     1538636, /* 29747 ( 574) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
    35563820, /* 29748 ( 574) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
    52438872, /* 29749 ( 574) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
    17140694, /* 29750 ( 574) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
    34015424, /* 29751 ( 574) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    51139634, /* 29752 ( 574) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
    18439608, /* 29753 ( 574) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
       16484, /* 29754 ( 575) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34028706, /* 29755 ( 575) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    34015422, /* 29756 ( 575) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    18426648, /* 29757 ( 575) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
    17127410, /* 29758 ( 575) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
    51139632, /* 29759 ( 575) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  6] -1 */
     1551594, /* 29760 ( 575) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
    35550860, /* 29761 ( 575) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
    51152916, /* 29762 ( 575) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6] -1 */
        3200, /* 29763 ( 575) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    52451834, /* 29764 ( 575) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
     1538634, /* 29765 ( 575) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
    35563820, /* 29766 ( 575) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
    17140694, /* 29767 ( 575) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
    52438874, /* 29768 ( 575) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
    18439608, /* 29769 ( 575) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
       16484, /* 29770 ( 576) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    51034658, /* 29771 ( 576) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  0] -1 */
    17127410, /* 29772 ( 576) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
     1551594, /* 29773 ( 576) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
        3200, /* 29774 ( 576) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    17127408, /* 29775 ( 576) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  6]  1 */
    18426650, /* 29776 ( 576) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
        3198, /* 29777 ( 576) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
     1538634, /* 29778 ( 576) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
     1538636, /* 29779 ( 576) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
    34146642, /* 29780 ( 576) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
    52570094, /* 29781 ( 576) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    34133684, /* 29782 ( 576) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    18426648, /* 29783 ( 576) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
    35445884, /* 29784 ( 576) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  0] -1 */
    18439610, /* 29785 ( 576) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    35445882, /* 29786 ( 576) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  0] -1 */
    34133682, /* 29787 ( 576) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
    17140694, /* 29788 ( 576) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
    52570092, /* 29789 ( 576) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
     1551596, /* 29790 ( 576) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
    51034656, /* 29791 ( 576) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  0] -1 */
    34146644, /* 29792 ( 576) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    17140692, /* 29793 ( 576) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6]  1 */
    51021698, /* 29794 ( 576) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  0] -1 */
    35432600, /* 29795 ( 576) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  0] -1 */
    52556810, /* 29796 ( 576) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    52556808, /* 29797 ( 576) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
       16482, /* 29798 ( 576) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    51021696, /* 29799 ( 576) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  0] -1 */
    35432598, /* 29800 ( 576) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  0] -1 */
    18439608, /* 29801 ( 576) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
       16484, /* 29802 ( 577) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    17127410, /* 29803 ( 577) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
     1551594, /* 29804 ( 577) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
        3200, /* 29805 ( 577) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    17127408, /* 29806 ( 577) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  6]  1 */
    18426650, /* 29807 ( 577) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    51021536, /* 29808 ( 577) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  0] -1 */
        3198, /* 29809 ( 577) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    52569930, /* 29810 ( 577) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
     1538634, /* 29811 ( 577) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
     1538636, /* 29812 ( 577) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
    51021534, /* 29813 ( 577) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  0] -1 */
    18426648, /* 29814 ( 577) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
    34146806, /* 29815 ( 577) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    34146804, /* 29816 ( 577) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
    35432762, /* 29817 ( 577) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  0] -1 */
    52556972, /* 29818 ( 577) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    18439610, /* 29819 ( 577) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    35445720, /* 29820 ( 577) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  0] -1 */
    17140694, /* 29821 ( 577) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
    35432760, /* 29822 ( 577) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  0] -1 */
    52556970, /* 29823 ( 577) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
     1551596, /* 29824 ( 577) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
    34133522, /* 29825 ( 577) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    17140692, /* 29826 ( 577) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6]  1 */
    34133520, /* 29827 ( 577) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
    51034820, /* 29828 ( 577) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  0] -1 */
    35445722, /* 29829 ( 577) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  0] -1 */
    52569932, /* 29830 ( 577) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
       16482, /* 29831 ( 577) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    51034818, /* 29832 ( 577) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  0] -1 */
    18439608, /* 29833 ( 577) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
       16484, /* 29834 ( 578) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    17127410, /* 29835 ( 578) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
     1551594, /* 29836 ( 578) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
        3200, /* 29837 ( 578) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    17127408, /* 29838 ( 578) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  6]  1 */
    18426650, /* 29839 ( 578) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
        3198, /* 29840 ( 578) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    35550698, /* 29841 ( 578) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
     1538634, /* 29842 ( 578) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
     1538636, /* 29843 ( 578) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
    51152754, /* 29844 ( 578) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  6] -1 */
    35550696, /* 29845 ( 578) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  6] -1 */
    52438712, /* 29846 ( 578) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
    51139796, /* 29847 ( 578) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
    52438710, /* 29848 ( 578) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
    18426648, /* 29849 ( 578) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
    34028544, /* 29850 ( 578) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    18439610, /* 29851 ( 578) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    17140694, /* 29852 ( 578) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
    34015584, /* 29853 ( 578) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    51139794, /* 29854 ( 578) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6] -1 */
    34015586, /* 29855 ( 578) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
     1551596, /* 29856 ( 578) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
    34028546, /* 29857 ( 578) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    52451996, /* 29858 ( 578) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
    51152756, /* 29859 ( 578) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
    17140692, /* 29860 ( 578) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6]  1 */
    35563982, /* 29861 ( 578) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
       16482, /* 29862 ( 578) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    52451994, /* 29863 ( 578) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
    35563980, /* 29864 ( 578) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6] -1 */
    18439608, /* 29865 ( 578) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
       16484, /* 29866 ( 567) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    18439610, /* 29867 ( 567) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
     1538634, /* 29868 ( 567) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
    17140530, /* 29869 ( 567) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  6]  1 */
        3362, /* 29870 ( 567) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    18426488, /* 29871 ( 567) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
       16320, /* 29872 ( 567) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    17127408, /* 29873 ( 567) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  6]  1 */
     1551756, /* 29874 ( 567) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
    17127572, /* 29875 ( 567) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
        3198, /* 29876 ( 567) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
     1551596, /* 29877 ( 567) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
    18426648, /* 29878 ( 567) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
    18439770, /* 29879 ( 567) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
    17140694, /* 29880 ( 567) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
     1538474, /* 29881 ( 567) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
       16484, /* 29882 ( 568) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    17140530, /* 29883 ( 568) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  6]  1 */
    18426488, /* 29884 ( 568) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
       16320, /* 29885 ( 568) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    17127408, /* 29886 ( 568) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  6]  1 */
     1551756, /* 29887 ( 568) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
    35563820, /* 29888 ( 568) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
    51152918, /* 29889 ( 568) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
        3198, /* 29890 ( 568) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    18426648, /* 29891 ( 568) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
    18439770, /* 29892 ( 568) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
    52451834, /* 29893 ( 568) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
     1538634, /* 29894 ( 568) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
    51139796, /* 29895 ( 568) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
     1551596, /* 29896 ( 568) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
    17140694, /* 29897 ( 568) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
    34028708, /* 29898 ( 568) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    34015586, /* 29899 ( 568) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    18439610, /* 29900 ( 568) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    17127572, /* 29901 ( 568) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
    35550698, /* 29902 ( 568) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
    34028544, /* 29903 ( 568) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    51152754, /* 29904 ( 568) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  6] -1 */
    35563980, /* 29905 ( 568) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6] -1 */
    52438712, /* 29906 ( 568) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
    34015422, /* 29907 ( 568) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    51139632, /* 29908 ( 568) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  6] -1 */
    52451994, /* 29909 ( 568) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
        3362, /* 29910 ( 568) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    52438872, /* 29911 ( 568) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
    35550858, /* 29912 ( 568) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6] -1 */
     1538474, /* 29913 ( 568) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
       16484, /* 29914 ( 569) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34015586, /* 29915 ( 569) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    52438712, /* 29916 ( 569) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
    34015422, /* 29917 ( 569) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    17140530, /* 29918 ( 569) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  6]  1 */
    51139632, /* 29919 ( 569) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  6] -1 */
    35550698, /* 29920 ( 569) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
    18439610, /* 29921 ( 569) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    51139796, /* 29922 ( 569) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
       16320, /* 29923 ( 569) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
     1551756, /* 29924 ( 569) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
    52438872, /* 29925 ( 569) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
     1551596, /* 29926 ( 569) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
    18439770, /* 29927 ( 569) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
    35550858, /* 29928 ( 569) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6] -1 */
    17140694, /* 29929 ( 569) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
       16484, /* 29930 ( 570) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34015422, /* 29931 ( 570) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    51139632, /* 29932 ( 570) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  6] -1 */
    18439610, /* 29933 ( 570) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    52451994, /* 29934 ( 570) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
        3362, /* 29935 ( 570) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    18426488, /* 29936 ( 570) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    35563980, /* 29937 ( 570) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6] -1 */
    52438872, /* 29938 ( 570) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
    17127572, /* 29939 ( 570) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
     1551596, /* 29940 ( 570) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
    35550858, /* 29941 ( 570) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6] -1 */
    17140694, /* 29942 ( 570) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
    34028544, /* 29943 ( 570) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    51152754, /* 29944 ( 570) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  6] -1 */
     1538474, /* 29945 ( 570) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
       16484, /* 29946 ( 571) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    52438712, /* 29947 ( 571) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
    34015422, /* 29948 ( 571) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
     1538634, /* 29949 ( 571) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
    51139632, /* 29950 ( 571) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  6] -1 */
    35550698, /* 29951 ( 571) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
        3362, /* 29952 ( 571) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
     1551756, /* 29953 ( 571) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
    35563820, /* 29954 ( 571) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
    17127572, /* 29955 ( 571) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
    18426648, /* 29956 ( 571) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
    52451834, /* 29957 ( 571) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
    18439770, /* 29958 ( 571) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
    17140694, /* 29959 ( 571) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
    34028544, /* 29960 ( 571) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    51152754, /* 29961 ( 571) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  6] -1 */
       16484, /* 29962 ( 572) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34015586, /* 29963 ( 572) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    52438712, /* 29964 ( 572) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
    18439610, /* 29965 ( 572) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
     1538634, /* 29966 ( 572) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
    35550698, /* 29967 ( 572) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
    52451994, /* 29968 ( 572) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
    35563980, /* 29969 ( 572) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6] -1 */
    51139796, /* 29970 ( 572) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
    17127408, /* 29971 ( 572) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  6]  1 */
        3198, /* 29972 ( 572) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
     1551596, /* 29973 ( 572) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
    18426648, /* 29974 ( 572) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
    17140694, /* 29975 ( 572) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
    34028544, /* 29976 ( 572) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    51152754, /* 29977 ( 572) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  6] -1 */
       16484, /* 29978 ( 573) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    52438712, /* 29979 ( 573) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
    17140530, /* 29980 ( 573) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  6]  1 */
    35550698, /* 29981 ( 573) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
        3362, /* 29982 ( 573) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    52451994, /* 29983 ( 573) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
       16320, /* 29984 ( 573) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    17127408, /* 29985 ( 573) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  6]  1 */
    35563820, /* 29986 ( 573) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
    52438872, /* 29987 ( 573) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
    17127572, /* 29988 ( 573) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
        3198, /* 29989 ( 573) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    52451834, /* 29990 ( 573) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
    35550858, /* 29991 ( 573) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6] -1 */
    17140694, /* 29992 ( 573) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
    35563980, /* 29993 ( 573) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6] -1 */
       16484, /* 29994 ( 574) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34015586, /* 29995 ( 574) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    18426488, /* 29996 ( 574) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    51139796, /* 29997 ( 574) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
    17127408, /* 29998 ( 574) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  6]  1 */
    35563820, /* 29999 ( 574) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
    52438872, /* 30000 ( 574) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
     1551756, /* 30001 ( 574) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
        3198, /* 30002 ( 574) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    18439770, /* 30003 ( 574) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
    52451834, /* 30004 ( 574) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
    35550858, /* 30005 ( 574) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6] -1 */
    17140694, /* 30006 ( 574) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
    34028544, /* 30007 ( 574) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    51152754, /* 30008 ( 574) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  6] -1 */
     1538474, /* 30009 ( 574) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
       16484, /* 30010 ( 575) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34015586, /* 30011 ( 575) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    34015422, /* 30012 ( 575) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
     1538634, /* 30013 ( 575) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
    17140530, /* 30014 ( 575) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  6]  1 */
    51139632, /* 30015 ( 575) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  6] -1 */
    18426488, /* 30016 ( 575) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    52451994, /* 30017 ( 575) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
    51139796, /* 30018 ( 575) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
       16320, /* 30019 ( 575) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    35563820, /* 30020 ( 575) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
    18426648, /* 30021 ( 575) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
    52451834, /* 30022 ( 575) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
    17140694, /* 30023 ( 575) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
    35563980, /* 30024 ( 575) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6] -1 */
     1538474, /* 30025 ( 575) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
       16484, /* 30026 ( 576) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34146644, /* 30027 ( 576) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    17140530, /* 30028 ( 576) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  6]  1 */
    18426488, /* 30029 ( 576) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
       16320, /* 30030 ( 576) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    17127408, /* 30031 ( 576) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  6]  1 */
     1551756, /* 30032 ( 576) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
        3198, /* 30033 ( 576) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    18426648, /* 30034 ( 576) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
    18439770, /* 30035 ( 576) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
    51021536, /* 30036 ( 576) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  0] -1 */
    52570094, /* 30037 ( 576) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    51034818, /* 30038 ( 576) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  0] -1 */
     1538634, /* 30039 ( 576) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
    35445884, /* 30040 ( 576) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  0] -1 */
     1551596, /* 30041 ( 576) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
    35432762, /* 30042 ( 576) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  0] -1 */
    51021696, /* 30043 ( 576) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  0] -1 */
    17140694, /* 30044 ( 576) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
    52556972, /* 30045 ( 576) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    18439610, /* 30046 ( 576) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    34133522, /* 30047 ( 576) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    51034658, /* 30048 ( 576) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  0] -1 */
    17127572, /* 30049 ( 576) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
    34146804, /* 30050 ( 576) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
    35445720, /* 30051 ( 576) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  0] -1 */
    52569930, /* 30052 ( 576) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    52556808, /* 30053 ( 576) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
        3362, /* 30054 ( 576) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34133682, /* 30055 ( 576) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
    35432598, /* 30056 ( 576) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  0] -1 */
     1538474, /* 30057 ( 576) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
       16484, /* 30058 ( 577) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    17140530, /* 30059 ( 577) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  6]  1 */
    18426488, /* 30060 ( 577) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
       16320, /* 30061 ( 577) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    17127408, /* 30062 ( 577) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  6]  1 */
     1551756, /* 30063 ( 577) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
    34146642, /* 30064 ( 577) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
        3198, /* 30065 ( 577) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    52556810, /* 30066 ( 577) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    18426648, /* 30067 ( 577) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
    18439770, /* 30068 ( 577) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
    34133520, /* 30069 ( 577) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
     1538634, /* 30070 ( 577) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
    51034820, /* 30071 ( 577) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  0] -1 */
    51021698, /* 30072 ( 577) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  0] -1 */
    35445882, /* 30073 ( 577) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  0] -1 */
    52570092, /* 30074 ( 577) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
     1551596, /* 30075 ( 577) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
    35432600, /* 30076 ( 577) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  0] -1 */
    17140694, /* 30077 ( 577) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
    35432760, /* 30078 ( 577) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  0] -1 */
    52556970, /* 30079 ( 577) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    18439610, /* 30080 ( 577) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    51034656, /* 30081 ( 577) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  0] -1 */
    17127572, /* 30082 ( 577) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
    51021534, /* 30083 ( 577) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  0] -1 */
    34146806, /* 30084 ( 577) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    35445722, /* 30085 ( 577) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  0] -1 */
    52569932, /* 30086 ( 577) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
        3362, /* 30087 ( 577) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34133684, /* 30088 ( 577) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
     1538474, /* 30089 ( 577) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
       16484, /* 30090 ( 578) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    17140530, /* 30091 ( 578) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  6]  1 */
    18426488, /* 30092 ( 578) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
       16320, /* 30093 ( 578) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    17127408, /* 30094 ( 578) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  6]  1 */
     1551756, /* 30095 ( 578) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
        3198, /* 30096 ( 578) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    52451832, /* 30097 ( 578) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
    18426648, /* 30098 ( 578) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
    18439770, /* 30099 ( 578) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
    51139634, /* 30100 ( 578) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
    52438710, /* 30101 ( 578) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
    35563818, /* 30102 ( 578) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  6] -1 */
    51152916, /* 30103 ( 578) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6] -1 */
    35550696, /* 30104 ( 578) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  6] -1 */
     1538634, /* 30105 ( 578) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
    34015424, /* 30106 ( 578) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
     1551596, /* 30107 ( 578) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
    17140694, /* 30108 ( 578) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
    34015584, /* 30109 ( 578) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    51139794, /* 30110 ( 578) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6] -1 */
    34028706, /* 30111 ( 578) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    18439610, /* 30112 ( 578) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    34028546, /* 30113 ( 578) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    35563982, /* 30114 ( 578) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
    51152756, /* 30115 ( 578) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
    17127572, /* 30116 ( 578) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
    52451996, /* 30117 ( 578) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
        3362, /* 30118 ( 578) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    35550860, /* 30119 ( 578) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
    52438874, /* 30120 ( 578) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
     1538474, /* 30121 ( 578) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
       16484, /* 30122 ( 579) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    18426488, /* 30123 ( 579) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    18426648, /* 30124 ( 579) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
    18439608, /* 30125 ( 579) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
        3200, /* 30126 ( 579) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    18439610, /* 30127 ( 579) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
        3362, /* 30128 ( 579) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
       16320, /* 30129 ( 579) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    18426486, /* 30130 ( 579) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
    18426650, /* 30131 ( 579) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
        3198, /* 30132 ( 579) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    18439770, /* 30133 ( 579) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
    18439772, /* 30134 ( 579) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
        3360, /* 30135 ( 579) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
       16482, /* 30136 ( 579) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
       16322, /* 30137 ( 579) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
       16484, /* 30138 ( 580) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    18439608, /* 30139 ( 580) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
       16320, /* 30140 ( 580) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    18426486, /* 30141 ( 580) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
    52451996, /* 30142 ( 580) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
        3198, /* 30143 ( 580) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    52438872, /* 30144 ( 580) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
    52451834, /* 30145 ( 580) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
    52438874, /* 30146 ( 580) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
    34015584, /* 30147 ( 580) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    18439772, /* 30148 ( 580) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    34015424, /* 30149 ( 580) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    34028708, /* 30150 ( 580) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    52438712, /* 30151 ( 580) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
    34028546, /* 30152 ( 580) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    18426648, /* 30153 ( 580) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
    34015586, /* 30154 ( 580) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    18439610, /* 30155 ( 580) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    34028706, /* 30156 ( 580) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    52451994, /* 30157 ( 580) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
    18426650, /* 30158 ( 580) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
        3360, /* 30159 ( 580) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    34028544, /* 30160 ( 580) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    52451832, /* 30161 ( 580) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
       16322, /* 30162 ( 580) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    18426488, /* 30163 ( 580) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    34015422, /* 30164 ( 580) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    52438710, /* 30165 ( 580) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
        3200, /* 30166 ( 580) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
        3362, /* 30167 ( 580) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    18439770, /* 30168 ( 580) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
       16482, /* 30169 ( 580) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
       16484, /* 30170 ( 581) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34015586, /* 30171 ( 581) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    34015422, /* 30172 ( 581) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    18439608, /* 30173 ( 581) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
    52438710, /* 30174 ( 581) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
    18439610, /* 30175 ( 581) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    52438874, /* 30176 ( 581) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
       16320, /* 30177 ( 581) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    34015584, /* 30178 ( 581) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    18439770, /* 30179 ( 581) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
    18439772, /* 30180 ( 581) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    52438712, /* 30181 ( 581) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
    52438872, /* 30182 ( 581) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
       16482, /* 30183 ( 581) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    34015424, /* 30184 ( 581) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
       16322, /* 30185 ( 581) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
       16484, /* 30186 ( 582) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    18426488, /* 30187 ( 582) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    34015422, /* 30188 ( 582) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    52438710, /* 30189 ( 582) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
        3200, /* 30190 ( 582) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    18439610, /* 30191 ( 582) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
        3362, /* 30192 ( 582) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34015584, /* 30193 ( 582) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    34028706, /* 30194 ( 582) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    52451994, /* 30195 ( 582) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
    18426650, /* 30196 ( 582) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    18439772, /* 30197 ( 582) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    52438872, /* 30198 ( 582) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
    34028544, /* 30199 ( 582) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    52451832, /* 30200 ( 582) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
       16322, /* 30201 ( 582) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
       16484, /* 30202 ( 583) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    18426488, /* 30203 ( 583) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    34015586, /* 30204 ( 583) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    34028546, /* 30205 ( 583) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    52451834, /* 30206 ( 583) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
        3200, /* 30207 ( 583) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    52438874, /* 30208 ( 583) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
    34015584, /* 30209 ( 583) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    18426486, /* 30210 ( 583) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
        3198, /* 30211 ( 583) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    18439770, /* 30212 ( 583) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
    18439772, /* 30213 ( 583) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    52438872, /* 30214 ( 583) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
       16482, /* 30215 ( 583) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    34028544, /* 30216 ( 583) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    52451832, /* 30217 ( 583) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
       16484, /* 30218 ( 584) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    52451834, /* 30219 ( 584) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
    34028546, /* 30220 ( 584) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    18439608, /* 30221 ( 584) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
        3362, /* 30222 ( 584) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
       16320, /* 30223 ( 584) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    18426486, /* 30224 ( 584) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
    34015584, /* 30225 ( 584) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    34028706, /* 30226 ( 584) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    52451994, /* 30227 ( 584) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
    18426650, /* 30228 ( 584) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
        3198, /* 30229 ( 584) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    18439772, /* 30230 ( 584) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    52438712, /* 30231 ( 584) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
    52438872, /* 30232 ( 584) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
    34015424, /* 30233 ( 584) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
       16484, /* 30234 ( 585) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    18426488, /* 30235 ( 585) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    34015586, /* 30236 ( 585) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    18426648, /* 30237 ( 585) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
    34015422, /* 30238 ( 585) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    18439608, /* 30239 ( 585) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
        3200, /* 30240 ( 585) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    52438710, /* 30241 ( 585) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
    34028546, /* 30242 ( 585) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    52451834, /* 30243 ( 585) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
    52438874, /* 30244 ( 585) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
       16320, /* 30245 ( 585) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    34028706, /* 30246 ( 585) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    52451994, /* 30247 ( 585) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
    18439772, /* 30248 ( 585) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
        3360, /* 30249 ( 585) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
       16484, /* 30250 ( 586) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    18439608, /* 30251 ( 586) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
       16320, /* 30252 ( 586) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    18426486, /* 30253 ( 586) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
        3198, /* 30254 ( 586) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    52556970, /* 30255 ( 586) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    52570094, /* 30256 ( 586) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    34146644, /* 30257 ( 586) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    52569932, /* 30258 ( 586) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    34146806, /* 30259 ( 586) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    34133684, /* 30260 ( 586) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    34133682, /* 30261 ( 586) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
    52556972, /* 30262 ( 586) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    18439772, /* 30263 ( 586) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    18426648, /* 30264 ( 586) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
    34133522, /* 30265 ( 586) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    52556810, /* 30266 ( 586) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    18439610, /* 30267 ( 586) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    18426650, /* 30268 ( 586) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    34146642, /* 30269 ( 586) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
    52569930, /* 30270 ( 586) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
        3360, /* 30271 ( 586) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    34146804, /* 30272 ( 586) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
    52570092, /* 30273 ( 586) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    52556808, /* 30274 ( 586) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    18426488, /* 30275 ( 586) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
       16322, /* 30276 ( 586) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
        3200, /* 30277 ( 586) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
        3362, /* 30278 ( 586) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34133520, /* 30279 ( 586) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
    18439770, /* 30280 ( 586) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
       16482, /* 30281 ( 586) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
       16484, /* 30282 ( 587) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    35445882, /* 30283 ( 587) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  0] -1 */
    18439608, /* 30284 ( 587) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
       16320, /* 30285 ( 587) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    18426486, /* 30286 ( 587) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
    35445720, /* 30287 ( 587) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  0] -1 */
        3198, /* 30288 ( 587) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    35432598, /* 30289 ( 587) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  0] -1 */
    51021696, /* 30290 ( 587) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  0] -1 */
    51034658, /* 30291 ( 587) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  0] -1 */
    51034820, /* 30292 ( 587) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  0] -1 */
    51021698, /* 30293 ( 587) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  0] -1 */
    51021536, /* 30294 ( 587) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  0] -1 */
    18439772, /* 30295 ( 587) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    18426648, /* 30296 ( 587) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
    18439610, /* 30297 ( 587) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    51034656, /* 30298 ( 587) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  0] -1 */
    51034818, /* 30299 ( 587) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  0] -1 */
    35432760, /* 30300 ( 587) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  0] -1 */
    18426650, /* 30301 ( 587) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    51021534, /* 30302 ( 587) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  0] -1 */
    35445722, /* 30303 ( 587) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  0] -1 */
    35445884, /* 30304 ( 587) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  0] -1 */
        3360, /* 30305 ( 587) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
       16322, /* 30306 ( 587) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    18426488, /* 30307 ( 587) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
        3200, /* 30308 ( 587) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
        3362, /* 30309 ( 587) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    35432600, /* 30310 ( 587) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  0] -1 */
    35432762, /* 30311 ( 587) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  0] -1 */
    18439770, /* 30312 ( 587) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
       16482, /* 30313 ( 587) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
       16484, /* 30314 ( 588) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    18439608, /* 30315 ( 588) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
       16320, /* 30316 ( 588) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    18426486, /* 30317 ( 588) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
    35563980, /* 30318 ( 588) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6] -1 */
        3198, /* 30319 ( 588) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    51152754, /* 30320 ( 588) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  6] -1 */
    51152916, /* 30321 ( 588) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6] -1 */
    51139632, /* 30322 ( 588) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  6] -1 */
    35563818, /* 30323 ( 588) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  6] -1 */
    35550696, /* 30324 ( 588) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  6] -1 */
    18439772, /* 30325 ( 588) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    18426648, /* 30326 ( 588) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
    18439610, /* 30327 ( 588) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    35563982, /* 30328 ( 588) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
    18426650, /* 30329 ( 588) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    51152918, /* 30330 ( 588) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
        3360, /* 30331 ( 588) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    35550858, /* 30332 ( 588) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6] -1 */
    35563820, /* 30333 ( 588) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
       16322, /* 30334 ( 588) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    18426488, /* 30335 ( 588) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    51139794, /* 30336 ( 588) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6] -1 */
        3200, /* 30337 ( 588) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    51152756, /* 30338 ( 588) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
        3362, /* 30339 ( 588) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    35550860, /* 30340 ( 588) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
    51139634, /* 30341 ( 588) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
    51139796, /* 30342 ( 588) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
    18439770, /* 30343 ( 588) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
    35550698, /* 30344 ( 588) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
       16482, /* 30345 ( 588) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
       16484, /* 30346 ( 579) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
     1551594, /* 30347 ( 579) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
     1538474, /* 30348 ( 579) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
     1538634, /* 30349 ( 579) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
       16320, /* 30350 ( 579) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
     1551756, /* 30351 ( 579) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
       16322, /* 30352 ( 579) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
        3360, /* 30353 ( 579) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
     1538472, /* 30354 ( 579) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
     1551596, /* 30355 ( 579) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
        3198, /* 30356 ( 579) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
     1538636, /* 30357 ( 579) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
     1551758, /* 30358 ( 579) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
        3200, /* 30359 ( 579) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
        3362, /* 30360 ( 579) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
       16482, /* 30361 ( 579) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
       16484, /* 30362 ( 580) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
     1538634, /* 30363 ( 580) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
        3360, /* 30364 ( 580) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
     1538472, /* 30365 ( 580) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
    35563982, /* 30366 ( 580) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
        3198, /* 30367 ( 580) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    35550698, /* 30368 ( 580) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
    35563980, /* 30369 ( 580) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6] -1 */
    35563820, /* 30370 ( 580) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
    34015424, /* 30371 ( 580) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
     1551758, /* 30372 ( 580) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
    34028544, /* 30373 ( 580) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    34028708, /* 30374 ( 580) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    35563818, /* 30375 ( 580) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  6] -1 */
    34028706, /* 30376 ( 580) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
     1538474, /* 30377 ( 580) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
    34028546, /* 30378 ( 580) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
     1551756, /* 30379 ( 580) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
    34015586, /* 30380 ( 580) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    35550860, /* 30381 ( 580) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
     1551596, /* 30382 ( 580) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
        3200, /* 30383 ( 580) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34015584, /* 30384 ( 580) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    35550858, /* 30385 ( 580) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6] -1 */
       16482, /* 30386 ( 580) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
     1551594, /* 30387 ( 580) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
    34015422, /* 30388 ( 580) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    35550696, /* 30389 ( 580) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  6] -1 */
       16320, /* 30390 ( 580) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
       16322, /* 30391 ( 580) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
     1538636, /* 30392 ( 580) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
        3362, /* 30393 ( 580) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
       16484, /* 30394 ( 581) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34028546, /* 30395 ( 581) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    34015422, /* 30396 ( 581) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
     1538634, /* 30397 ( 581) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
    35550696, /* 30398 ( 581) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  6] -1 */
     1551756, /* 30399 ( 581) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
    35563820, /* 30400 ( 581) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
        3360, /* 30401 ( 581) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    34015424, /* 30402 ( 581) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
     1538636, /* 30403 ( 581) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
     1551758, /* 30404 ( 581) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
    35563818, /* 30405 ( 581) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  6] -1 */
    35550698, /* 30406 ( 581) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
        3362, /* 30407 ( 581) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34028544, /* 30408 ( 581) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
       16482, /* 30409 ( 581) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
       16484, /* 30410 ( 582) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
     1551594, /* 30411 ( 582) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
    34015422, /* 30412 ( 582) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    35550696, /* 30413 ( 582) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  6] -1 */
       16320, /* 30414 ( 582) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
     1551756, /* 30415 ( 582) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
       16322, /* 30416 ( 582) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34015424, /* 30417 ( 582) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    34015586, /* 30418 ( 582) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    35550860, /* 30419 ( 582) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
     1551596, /* 30420 ( 582) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
     1551758, /* 30421 ( 582) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
    35550698, /* 30422 ( 582) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
    34015584, /* 30423 ( 582) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    35550858, /* 30424 ( 582) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6] -1 */
       16482, /* 30425 ( 582) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
       16484, /* 30426 ( 583) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
     1551594, /* 30427 ( 583) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
    34028546, /* 30428 ( 583) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    34028706, /* 30429 ( 583) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    35563980, /* 30430 ( 583) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6] -1 */
       16320, /* 30431 ( 583) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    35563820, /* 30432 ( 583) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
    34015424, /* 30433 ( 583) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
     1538472, /* 30434 ( 583) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
        3198, /* 30435 ( 583) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
     1538636, /* 30436 ( 583) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
     1551758, /* 30437 ( 583) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
    35550698, /* 30438 ( 583) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
        3362, /* 30439 ( 583) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34015584, /* 30440 ( 583) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    35550858, /* 30441 ( 583) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6] -1 */
       16484, /* 30442 ( 584) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    35563980, /* 30443 ( 584) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6] -1 */
    34028706, /* 30444 ( 584) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
     1538634, /* 30445 ( 584) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
       16322, /* 30446 ( 584) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
        3360, /* 30447 ( 584) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
     1538472, /* 30448 ( 584) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
    34015424, /* 30449 ( 584) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    34015586, /* 30450 ( 584) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    35550860, /* 30451 ( 584) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
     1551596, /* 30452 ( 584) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
        3198, /* 30453 ( 584) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
     1551758, /* 30454 ( 584) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
    35563818, /* 30455 ( 584) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  6] -1 */
    35550698, /* 30456 ( 584) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
    34028544, /* 30457 ( 584) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
       16484, /* 30458 ( 585) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
     1551594, /* 30459 ( 585) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
    34028546, /* 30460 ( 585) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
     1538474, /* 30461 ( 585) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
    34015422, /* 30462 ( 585) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
     1538634, /* 30463 ( 585) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
       16320, /* 30464 ( 585) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    35550696, /* 30465 ( 585) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  6] -1 */
    34028706, /* 30466 ( 585) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    35563980, /* 30467 ( 585) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6] -1 */
    35563820, /* 30468 ( 585) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
        3360, /* 30469 ( 585) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    34015586, /* 30470 ( 585) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    35550860, /* 30471 ( 585) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
     1551758, /* 30472 ( 585) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
        3200, /* 30473 ( 585) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
       16484, /* 30474 ( 586) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
     1538634, /* 30475 ( 586) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
        3360, /* 30476 ( 586) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
     1538472, /* 30477 ( 586) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
        3198, /* 30478 ( 586) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    52556810, /* 30479 ( 586) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    52570094, /* 30480 ( 586) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    51034818, /* 30481 ( 586) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  0] -1 */
    52570092, /* 30482 ( 586) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    51034820, /* 30483 ( 586) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  0] -1 */
    51034658, /* 30484 ( 586) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  0] -1 */
    51021536, /* 30485 ( 586) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  0] -1 */
    52569932, /* 30486 ( 586) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
     1551758, /* 30487 ( 586) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
     1538474, /* 30488 ( 586) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
    51034656, /* 30489 ( 586) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  0] -1 */
    52569930, /* 30490 ( 586) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
     1551756, /* 30491 ( 586) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
     1551596, /* 30492 ( 586) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
    51021696, /* 30493 ( 586) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  0] -1 */
    52556970, /* 30494 ( 586) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
        3200, /* 30495 ( 586) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    51021698, /* 30496 ( 586) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  0] -1 */
    52556972, /* 30497 ( 586) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    52556808, /* 30498 ( 586) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
     1551594, /* 30499 ( 586) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
       16482, /* 30500 ( 586) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
       16320, /* 30501 ( 586) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
       16322, /* 30502 ( 586) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    51021534, /* 30503 ( 586) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  0] -1 */
     1538636, /* 30504 ( 586) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
        3362, /* 30505 ( 586) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
       16484, /* 30506 ( 587) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34133684, /* 30507 ( 587) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
     1538634, /* 30508 ( 587) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
        3360, /* 30509 ( 587) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
     1538472, /* 30510 ( 587) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
    34133682, /* 30511 ( 587) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
        3198, /* 30512 ( 587) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    34133520, /* 30513 ( 587) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
    35432600, /* 30514 ( 587) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  0] -1 */
    35445882, /* 30515 ( 587) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  0] -1 */
    35445884, /* 30516 ( 587) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  0] -1 */
    35445722, /* 30517 ( 587) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  0] -1 */
    35445720, /* 30518 ( 587) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  0] -1 */
     1551758, /* 30519 ( 587) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
     1538474, /* 30520 ( 587) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
     1551756, /* 30521 ( 587) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
    35432760, /* 30522 ( 587) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  0] -1 */
    35432762, /* 30523 ( 587) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  0] -1 */
    34133522, /* 30524 ( 587) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
     1551596, /* 30525 ( 587) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
    35432598, /* 30526 ( 587) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  0] -1 */
    34146804, /* 30527 ( 587) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
    34146806, /* 30528 ( 587) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
        3200, /* 30529 ( 587) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
       16482, /* 30530 ( 587) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
     1551594, /* 30531 ( 587) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
       16320, /* 30532 ( 587) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
       16322, /* 30533 ( 587) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34146642, /* 30534 ( 587) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
    34146644, /* 30535 ( 587) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
     1538636, /* 30536 ( 587) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
        3362, /* 30537 ( 587) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
       16484, /* 30538 ( 588) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
     1538634, /* 30539 ( 588) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
        3360, /* 30540 ( 588) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
     1538472, /* 30541 ( 588) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
    51139796, /* 30542 ( 588) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
        3198, /* 30543 ( 588) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    52438872, /* 30544 ( 588) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
    52438874, /* 30545 ( 588) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
    52438710, /* 30546 ( 588) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
    51139794, /* 30547 ( 588) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6] -1 */
    51139632, /* 30548 ( 588) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  6] -1 */
     1551758, /* 30549 ( 588) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
     1538474, /* 30550 ( 588) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
     1551756, /* 30551 ( 588) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
    51152918, /* 30552 ( 588) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
     1551596, /* 30553 ( 588) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
    52451996, /* 30554 ( 588) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
        3200, /* 30555 ( 588) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    51139634, /* 30556 ( 588) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
    51152916, /* 30557 ( 588) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6] -1 */
       16482, /* 30558 ( 588) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
     1551594, /* 30559 ( 588) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
    52438712, /* 30560 ( 588) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
       16320, /* 30561 ( 588) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    52451994, /* 30562 ( 588) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
       16322, /* 30563 ( 588) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    51152756, /* 30564 ( 588) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
    52451832, /* 30565 ( 588) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
    52451834, /* 30566 ( 588) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
     1538636, /* 30567 ( 588) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
    51152754, /* 30568 ( 588) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  6] -1 */
        3362, /* 30569 ( 588) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
       16484, /* 30570 ( 579) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    17127570, /* 30571 ( 579) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6]  1 */
    17140530, /* 30572 ( 579) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  6]  1 */
    17127410, /* 30573 ( 579) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
        3360, /* 30574 ( 579) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    17127572, /* 30575 ( 579) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
       16482, /* 30576 ( 579) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
        3200, /* 30577 ( 579) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    17127408, /* 30578 ( 579) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  6]  1 */
    17140692, /* 30579 ( 579) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6]  1 */
        3198, /* 30580 ( 579) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    17140532, /* 30581 ( 579) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
    17140694, /* 30582 ( 579) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
       16320, /* 30583 ( 579) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
       16322, /* 30584 ( 579) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
        3362, /* 30585 ( 579) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
       16484, /* 30586 ( 580) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    17127410, /* 30587 ( 580) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
        3200, /* 30588 ( 580) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    17127408, /* 30589 ( 580) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  6]  1 */
    51152918, /* 30590 ( 580) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
        3198, /* 30591 ( 580) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    51152754, /* 30592 ( 580) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  6] -1 */
    51139796, /* 30593 ( 580) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
    51152916, /* 30594 ( 580) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6] -1 */
    34028544, /* 30595 ( 580) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    17140694, /* 30596 ( 580) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
    34015584, /* 30597 ( 580) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    34028708, /* 30598 ( 580) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    51139794, /* 30599 ( 580) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6] -1 */
    34015586, /* 30600 ( 580) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    17140530, /* 30601 ( 580) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  6]  1 */
    34028706, /* 30602 ( 580) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    17127572, /* 30603 ( 580) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
    34028546, /* 30604 ( 580) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    51152756, /* 30605 ( 580) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
    17140692, /* 30606 ( 580) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6]  1 */
       16320, /* 30607 ( 580) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    34015424, /* 30608 ( 580) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    51139634, /* 30609 ( 580) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
        3362, /* 30610 ( 580) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    17127570, /* 30611 ( 580) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6]  1 */
    34015422, /* 30612 ( 580) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    51139632, /* 30613 ( 580) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  6] -1 */
        3360, /* 30614 ( 580) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
       16482, /* 30615 ( 580) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    17140532, /* 30616 ( 580) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
       16322, /* 30617 ( 580) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
       16484, /* 30618 ( 581) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34028706, /* 30619 ( 581) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    34015422, /* 30620 ( 581) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    17127410, /* 30621 ( 581) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
    51139632, /* 30622 ( 581) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  6] -1 */
    17127572, /* 30623 ( 581) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
    51152916, /* 30624 ( 581) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6] -1 */
        3200, /* 30625 ( 581) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34028544, /* 30626 ( 581) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    17140532, /* 30627 ( 581) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
    17140694, /* 30628 ( 581) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
    51139794, /* 30629 ( 581) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6] -1 */
    51152754, /* 30630 ( 581) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  6] -1 */
       16322, /* 30631 ( 581) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34015584, /* 30632 ( 581) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
        3362, /* 30633 ( 581) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
       16484, /* 30634 ( 582) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    17127570, /* 30635 ( 582) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6]  1 */
    34015422, /* 30636 ( 582) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    51139632, /* 30637 ( 582) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  6] -1 */
        3360, /* 30638 ( 582) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    17127572, /* 30639 ( 582) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
       16482, /* 30640 ( 582) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    34028544, /* 30641 ( 582) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    34028546, /* 30642 ( 582) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    51152756, /* 30643 ( 582) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
    17140692, /* 30644 ( 582) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6]  1 */
    17140694, /* 30645 ( 582) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
    51152754, /* 30646 ( 582) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  6] -1 */
    34015424, /* 30647 ( 582) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    51139634, /* 30648 ( 582) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
        3362, /* 30649 ( 582) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
       16484, /* 30650 ( 583) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    17127570, /* 30651 ( 583) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6]  1 */
    34028706, /* 30652 ( 583) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    34015586, /* 30653 ( 583) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    51139796, /* 30654 ( 583) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
        3360, /* 30655 ( 583) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    51152916, /* 30656 ( 583) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6] -1 */
    34028544, /* 30657 ( 583) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    17127408, /* 30658 ( 583) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  6]  1 */
        3198, /* 30659 ( 583) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    17140532, /* 30660 ( 583) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
    17140694, /* 30661 ( 583) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
    51152754, /* 30662 ( 583) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  6] -1 */
       16322, /* 30663 ( 583) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34015424, /* 30664 ( 583) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    51139634, /* 30665 ( 583) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
       16484, /* 30666 ( 584) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    51139796, /* 30667 ( 584) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
    34015586, /* 30668 ( 584) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    17127410, /* 30669 ( 584) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
       16482, /* 30670 ( 584) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
        3200, /* 30671 ( 584) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    17127408, /* 30672 ( 584) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  6]  1 */
    34028544, /* 30673 ( 584) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    34028546, /* 30674 ( 584) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    51152756, /* 30675 ( 584) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
    17140692, /* 30676 ( 584) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6]  1 */
        3198, /* 30677 ( 584) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    17140694, /* 30678 ( 584) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
    51139794, /* 30679 ( 584) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6] -1 */
    51152754, /* 30680 ( 584) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  6] -1 */
    34015584, /* 30681 ( 584) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
       16484, /* 30682 ( 585) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    17127570, /* 30683 ( 585) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6]  1 */
    34028706, /* 30684 ( 585) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    17140530, /* 30685 ( 585) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  6]  1 */
    34015422, /* 30686 ( 585) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    17127410, /* 30687 ( 585) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
        3360, /* 30688 ( 585) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    51139632, /* 30689 ( 585) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  6] -1 */
    34015586, /* 30690 ( 585) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    51139796, /* 30691 ( 585) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
    51152916, /* 30692 ( 585) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6] -1 */
        3200, /* 30693 ( 585) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34028546, /* 30694 ( 585) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    51152756, /* 30695 ( 585) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
    17140694, /* 30696 ( 585) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
       16320, /* 30697 ( 585) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
       16484, /* 30698 ( 586) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    17127410, /* 30699 ( 586) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
        3200, /* 30700 ( 586) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    17127408, /* 30701 ( 586) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  6]  1 */
        3198, /* 30702 ( 586) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    52569930, /* 30703 ( 586) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    52570094, /* 30704 ( 586) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    35432762, /* 30705 ( 586) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  0] -1 */
    52556972, /* 30706 ( 586) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    35445884, /* 30707 ( 586) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  0] -1 */
    35445882, /* 30708 ( 586) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  0] -1 */
    35445720, /* 30709 ( 586) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  0] -1 */
    52570092, /* 30710 ( 586) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    17140694, /* 30711 ( 586) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
    17140530, /* 30712 ( 586) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  6]  1 */
    35432760, /* 30713 ( 586) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  0] -1 */
    52556970, /* 30714 ( 586) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    17127572, /* 30715 ( 586) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
    17140692, /* 30716 ( 586) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6]  1 */
    35432600, /* 30717 ( 586) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  0] -1 */
    52556810, /* 30718 ( 586) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
       16320, /* 30719 ( 586) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    35445722, /* 30720 ( 586) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  0] -1 */
    52569932, /* 30721 ( 586) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    52556808, /* 30722 ( 586) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    17127570, /* 30723 ( 586) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6]  1 */
        3362, /* 30724 ( 586) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
        3360, /* 30725 ( 586) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
       16482, /* 30726 ( 586) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    35432598, /* 30727 ( 586) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  0] -1 */
    17140532, /* 30728 ( 586) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
       16322, /* 30729 ( 586) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
       16484, /* 30730 ( 587) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    51034658, /* 30731 ( 587) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  0] -1 */
    17127410, /* 30732 ( 587) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
        3200, /* 30733 ( 587) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    17127408, /* 30734 ( 587) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  6]  1 */
    51021536, /* 30735 ( 587) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  0] -1 */
        3198, /* 30736 ( 587) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    51021534, /* 30737 ( 587) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  0] -1 */
    34146642, /* 30738 ( 587) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
    34133684, /* 30739 ( 587) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    34146806, /* 30740 ( 587) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    34146804, /* 30741 ( 587) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
    34133682, /* 30742 ( 587) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
    17140694, /* 30743 ( 587) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
    17140530, /* 30744 ( 587) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  6]  1 */
    17127572, /* 30745 ( 587) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
    34133522, /* 30746 ( 587) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    34146644, /* 30747 ( 587) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    51034656, /* 30748 ( 587) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  0] -1 */
    17140692, /* 30749 ( 587) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6]  1 */
    34133520, /* 30750 ( 587) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
    51021698, /* 30751 ( 587) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  0] -1 */
    51034820, /* 30752 ( 587) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  0] -1 */
       16320, /* 30753 ( 587) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
        3362, /* 30754 ( 587) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    17127570, /* 30755 ( 587) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6]  1 */
        3360, /* 30756 ( 587) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
       16482, /* 30757 ( 587) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    51021696, /* 30758 ( 587) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  0] -1 */
    51034818, /* 30759 ( 587) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  0] -1 */
    17140532, /* 30760 ( 587) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
       16322, /* 30761 ( 587) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
       16484, /* 30762 ( 588) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    17127410, /* 30763 ( 588) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
        3200, /* 30764 ( 588) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    17127408, /* 30765 ( 588) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  6]  1 */
    52451834, /* 30766 ( 588) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
        3198, /* 30767 ( 588) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    35550698, /* 30768 ( 588) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
    35563820, /* 30769 ( 588) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
    35550696, /* 30770 ( 588) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  6] -1 */
    52438712, /* 30771 ( 588) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
    52438710, /* 30772 ( 588) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
    17140694, /* 30773 ( 588) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
    17140530, /* 30774 ( 588) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  6]  1 */
    17127572, /* 30775 ( 588) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
    52451996, /* 30776 ( 588) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
    17140692, /* 30777 ( 588) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6]  1 */
    35563982, /* 30778 ( 588) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
       16320, /* 30779 ( 588) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    52451832, /* 30780 ( 588) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
    52438874, /* 30781 ( 588) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
        3362, /* 30782 ( 588) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    17127570, /* 30783 ( 588) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6]  1 */
    35563818, /* 30784 ( 588) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  6] -1 */
        3360, /* 30785 ( 588) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    35550860, /* 30786 ( 588) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
       16482, /* 30787 ( 588) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    52451994, /* 30788 ( 588) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
    35550858, /* 30789 ( 588) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6] -1 */
    35563980, /* 30790 ( 588) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6] -1 */
    17140532, /* 30791 ( 588) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
    52438872, /* 30792 ( 588) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
       16322, /* 30793 ( 588) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
       16484, /* 30794 ( 589) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    18426488, /* 30795 ( 589) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
      121460, /* 30796 ( 589) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6]  1 */
      121458, /* 30797 ( 589) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  6]  1 */
      134418, /* 30798 ( 589) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  6]  1 */
        3200, /* 30799 ( 589) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    18426486, /* 30800 ( 589) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
      134420, /* 30801 ( 589) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6]  1 */
        3198, /* 30802 ( 589) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    18544748, /* 30803 ( 589) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    18439770, /* 30804 ( 589) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
    18439772, /* 30805 ( 589) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    18557708, /* 30806 ( 589) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    18544746, /* 30807 ( 589) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
       16482, /* 30808 ( 589) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    18557706, /* 30809 ( 589) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
       16484, /* 30810 ( 590) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
      134418, /* 30811 ( 590) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  6]  1 */
    18426486, /* 30812 ( 590) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
    52451996, /* 30813 ( 590) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
        3198, /* 30814 ( 590) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    52556970, /* 30815 ( 590) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    34146644, /* 30816 ( 590) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    52569932, /* 30817 ( 590) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    34133684, /* 30818 ( 590) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    52556972, /* 30819 ( 590) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    34133682, /* 30820 ( 590) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
    18439772, /* 30821 ( 590) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    34015424, /* 30822 ( 590) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    34028708, /* 30823 ( 590) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    18544746, /* 30824 ( 590) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
    52438712, /* 30825 ( 590) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
    34028706, /* 30826 ( 590) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    52451994, /* 30827 ( 590) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
    34146642, /* 30828 ( 590) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
    52569930, /* 30829 ( 590) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
      134420, /* 30830 ( 590) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6]  1 */
    18557708, /* 30831 ( 590) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    18544748, /* 30832 ( 590) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    18426488, /* 30833 ( 590) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
      121460, /* 30834 ( 590) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6]  1 */
    34015422, /* 30835 ( 590) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
      121458, /* 30836 ( 590) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  6]  1 */
        3200, /* 30837 ( 590) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    52438710, /* 30838 ( 590) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
    18439770, /* 30839 ( 590) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
       16482, /* 30840 ( 590) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    18557706, /* 30841 ( 590) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
       16484, /* 30842 ( 591) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34015422, /* 30843 ( 591) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
      134418, /* 30844 ( 591) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  6]  1 */
    52438710, /* 30845 ( 591) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
      134420, /* 30846 ( 591) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6]  1 */
    34133684, /* 30847 ( 591) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    52556970, /* 30848 ( 591) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    34133682, /* 30849 ( 591) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
    18439770, /* 30850 ( 591) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
    18439772, /* 30851 ( 591) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    52438712, /* 30852 ( 591) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
    52556972, /* 30853 ( 591) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    18557708, /* 30854 ( 591) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
       16482, /* 30855 ( 591) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    34015424, /* 30856 ( 591) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    18557706, /* 30857 ( 591) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
       16484, /* 30858 ( 592) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    18426488, /* 30859 ( 592) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
      121460, /* 30860 ( 592) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6]  1 */
    34015422, /* 30861 ( 592) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    52438710, /* 30862 ( 592) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
        3200, /* 30863 ( 592) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34028706, /* 30864 ( 592) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    52451994, /* 30865 ( 592) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
      134420, /* 30866 ( 592) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6]  1 */
    52556970, /* 30867 ( 592) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    34133682, /* 30868 ( 592) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
    34146642, /* 30869 ( 592) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
    18439772, /* 30870 ( 592) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    18557708, /* 30871 ( 592) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    18544748, /* 30872 ( 592) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    52569930, /* 30873 ( 592) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
       16484, /* 30874 ( 593) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    18426488, /* 30875 ( 593) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
        3200, /* 30876 ( 593) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34146644, /* 30877 ( 593) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    52569932, /* 30878 ( 593) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    18426486, /* 30879 ( 593) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
        3198, /* 30880 ( 593) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    34133684, /* 30881 ( 593) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    52556972, /* 30882 ( 593) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    34133682, /* 30883 ( 593) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
    34146642, /* 30884 ( 593) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
    18439772, /* 30885 ( 593) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    18439770, /* 30886 ( 593) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
    52556970, /* 30887 ( 593) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
       16482, /* 30888 ( 593) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    52569930, /* 30889 ( 593) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
       16484, /* 30890 ( 594) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
      121460, /* 30891 ( 594) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6]  1 */
      134418, /* 30892 ( 594) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  6]  1 */
    34146644, /* 30893 ( 594) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    52569932, /* 30894 ( 594) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    18426486, /* 30895 ( 594) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
    34028706, /* 30896 ( 594) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    52451994, /* 30897 ( 594) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
        3198, /* 30898 ( 594) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    52556970, /* 30899 ( 594) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    34133682, /* 30900 ( 594) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
    18439772, /* 30901 ( 594) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    52438712, /* 30902 ( 594) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
    18544748, /* 30903 ( 594) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    34015424, /* 30904 ( 594) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    18557706, /* 30905 ( 594) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
       16484, /* 30906 ( 595) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    18426488, /* 30907 ( 595) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    34015422, /* 30908 ( 595) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
      134418, /* 30909 ( 595) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  6]  1 */
        3200, /* 30910 ( 595) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    52438710, /* 30911 ( 595) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
      121458, /* 30912 ( 595) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  6]  1 */
    34146644, /* 30913 ( 595) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    52569932, /* 30914 ( 595) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    34028706, /* 30915 ( 595) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    52451994, /* 30916 ( 595) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
    34133684, /* 30917 ( 595) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    52556972, /* 30918 ( 595) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    18439772, /* 30919 ( 595) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    18544746, /* 30920 ( 595) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
    18557706, /* 30921 ( 595) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
       16484, /* 30922 ( 596) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
      134418, /* 30923 ( 596) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  6]  1 */
    18426486, /* 30924 ( 596) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
        3198, /* 30925 ( 596) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    52438872, /* 30926 ( 596) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
    52570094, /* 30927 ( 596) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    52451834, /* 30928 ( 596) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
    52438874, /* 30929 ( 596) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
    34015584, /* 30930 ( 596) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    34146806, /* 30931 ( 596) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    18439772, /* 30932 ( 596) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    34028546, /* 30933 ( 596) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    18544746, /* 30934 ( 596) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
    34015586, /* 30935 ( 596) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    34133522, /* 30936 ( 596) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    52556810, /* 30937 ( 596) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
      134420, /* 30938 ( 596) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6]  1 */
    34146804, /* 30939 ( 596) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
    18557708, /* 30940 ( 596) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    52570092, /* 30941 ( 596) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    18544748, /* 30942 ( 596) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    34028544, /* 30943 ( 596) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    52451832, /* 30944 ( 596) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
    52556808, /* 30945 ( 596) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    18426488, /* 30946 ( 596) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
      121460, /* 30947 ( 596) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6]  1 */
      121458, /* 30948 ( 596) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  6]  1 */
        3200, /* 30949 ( 596) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34133520, /* 30950 ( 596) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
    18439770, /* 30951 ( 596) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
       16482, /* 30952 ( 596) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    18557706, /* 30953 ( 596) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
       16484, /* 30954 ( 597) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    35445882, /* 30955 ( 597) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  0] -1 */
      134418, /* 30956 ( 597) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  6]  1 */
    18426486, /* 30957 ( 597) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
        3198, /* 30958 ( 597) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    51152754, /* 30959 ( 597) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  6] -1 */
    35432598, /* 30960 ( 597) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  0] -1 */
    35563818, /* 30961 ( 597) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  6] -1 */
    51034820, /* 30962 ( 597) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  0] -1 */
    51021536, /* 30963 ( 597) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  0] -1 */
    18439772, /* 30964 ( 597) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    18544746, /* 30965 ( 597) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
    51034818, /* 30966 ( 597) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  0] -1 */
    51021534, /* 30967 ( 597) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  0] -1 */
    35445884, /* 30968 ( 597) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  0] -1 */
      134420, /* 30969 ( 597) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6]  1 */
    18557708, /* 30970 ( 597) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    35550858, /* 30971 ( 597) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6] -1 */
    18544748, /* 30972 ( 597) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    35563820, /* 30973 ( 597) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
    18426488, /* 30974 ( 597) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
      121460, /* 30975 ( 597) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6]  1 */
    51139794, /* 30976 ( 597) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6] -1 */
      121458, /* 30977 ( 597) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  6]  1 */
        3200, /* 30978 ( 597) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    51152756, /* 30979 ( 597) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
    35550860, /* 30980 ( 597) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
    35432600, /* 30981 ( 597) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  0] -1 */
    51139796, /* 30982 ( 597) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
    18439770, /* 30983 ( 597) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
       16482, /* 30984 ( 597) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    18557706, /* 30985 ( 597) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
       16484, /* 30986 ( 598) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
      134418, /* 30987 ( 598) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  6]  1 */
    18426486, /* 30988 ( 598) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
    35563980, /* 30989 ( 598) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6] -1 */
    35445720, /* 30990 ( 598) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  0] -1 */
        3198, /* 30991 ( 598) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    51152916, /* 30992 ( 598) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6] -1 */
    51021696, /* 30993 ( 598) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  0] -1 */
    51139632, /* 30994 ( 598) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  6] -1 */
    51034658, /* 30995 ( 598) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  0] -1 */
    35550696, /* 30996 ( 598) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  6] -1 */
    51021698, /* 30997 ( 598) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  0] -1 */
    18439772, /* 30998 ( 598) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    18544746, /* 30999 ( 598) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
    51034656, /* 31000 ( 598) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  0] -1 */
    35432760, /* 31001 ( 598) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  0] -1 */
    35563982, /* 31002 ( 598) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
    35445722, /* 31003 ( 598) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  0] -1 */
    51152918, /* 31004 ( 598) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
      134420, /* 31005 ( 598) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6]  1 */
    18557708, /* 31006 ( 598) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    18544748, /* 31007 ( 598) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    18426488, /* 31008 ( 598) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
      121460, /* 31009 ( 598) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6]  1 */
      121458, /* 31010 ( 598) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  6]  1 */
        3200, /* 31011 ( 598) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    51139634, /* 31012 ( 598) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
    35432762, /* 31013 ( 598) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  0] -1 */
    18439770, /* 31014 ( 598) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
    35550698, /* 31015 ( 598) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
       16482, /* 31016 ( 598) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    18557706, /* 31017 ( 598) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
       16484, /* 31018 ( 589) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
     1551594, /* 31019 ( 589) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
    17022434, /* 31020 ( 589) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  0]  1 */
    17009312, /* 31021 ( 589) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  0]  1 */
    17009472, /* 31022 ( 589) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  0]  1 */
       16320, /* 31023 ( 589) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
     1538472, /* 31024 ( 589) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
    17022594, /* 31025 ( 589) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  0]  1 */
        3198, /* 31026 ( 589) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    18557708, /* 31027 ( 589) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
     1538636, /* 31028 ( 589) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
     1551758, /* 31029 ( 589) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
    18557868, /* 31030 ( 589) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
    18544586, /* 31031 ( 589) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
        3362, /* 31032 ( 589) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    18544746, /* 31033 ( 589) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
       16484, /* 31034 ( 590) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    17009472, /* 31035 ( 590) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  0]  1 */
     1538472, /* 31036 ( 590) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
    35563982, /* 31037 ( 590) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
        3198, /* 31038 ( 590) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    52556810, /* 31039 ( 590) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    51034818, /* 31040 ( 590) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  0] -1 */
    52570092, /* 31041 ( 590) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    51034658, /* 31042 ( 590) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  0] -1 */
    52569932, /* 31043 ( 590) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    51021536, /* 31044 ( 590) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  0] -1 */
     1551758, /* 31045 ( 590) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
    34028544, /* 31046 ( 590) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    34028708, /* 31047 ( 590) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    18544586, /* 31048 ( 590) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    35563818, /* 31049 ( 590) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  6] -1 */
    34015586, /* 31050 ( 590) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    35550860, /* 31051 ( 590) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
    51021696, /* 31052 ( 590) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  0] -1 */
    52556970, /* 31053 ( 590) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    17022594, /* 31054 ( 590) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  0]  1 */
    18557868, /* 31055 ( 590) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
    18557708, /* 31056 ( 590) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
     1551594, /* 31057 ( 590) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
    17022434, /* 31058 ( 590) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  0]  1 */
    34015422, /* 31059 ( 590) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    17009312, /* 31060 ( 590) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  0]  1 */
       16320, /* 31061 ( 590) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    35550696, /* 31062 ( 590) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  6] -1 */
     1538636, /* 31063 ( 590) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
        3362, /* 31064 ( 590) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    18544746, /* 31065 ( 590) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
       16484, /* 31066 ( 591) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34015422, /* 31067 ( 591) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    17009472, /* 31068 ( 591) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  0]  1 */
    35550696, /* 31069 ( 591) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  6] -1 */
    17022594, /* 31070 ( 591) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  0]  1 */
    51034658, /* 31071 ( 591) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  0] -1 */
    52556810, /* 31072 ( 591) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    51021536, /* 31073 ( 591) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  0] -1 */
     1538636, /* 31074 ( 591) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
     1551758, /* 31075 ( 591) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
    35563818, /* 31076 ( 591) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  6] -1 */
    52569932, /* 31077 ( 591) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    18557868, /* 31078 ( 591) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
        3362, /* 31079 ( 591) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34028544, /* 31080 ( 591) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    18544746, /* 31081 ( 591) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
       16484, /* 31082 ( 592) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
     1551594, /* 31083 ( 592) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
    17022434, /* 31084 ( 592) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  0]  1 */
    34015422, /* 31085 ( 592) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    35550696, /* 31086 ( 592) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  6] -1 */
       16320, /* 31087 ( 592) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    34015586, /* 31088 ( 592) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    35550860, /* 31089 ( 592) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
    17022594, /* 31090 ( 592) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  0]  1 */
    52556810, /* 31091 ( 592) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    51021536, /* 31092 ( 592) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  0] -1 */
    51021696, /* 31093 ( 592) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  0] -1 */
     1551758, /* 31094 ( 592) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
    18557868, /* 31095 ( 592) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
    18557708, /* 31096 ( 592) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    52556970, /* 31097 ( 592) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
       16484, /* 31098 ( 593) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
     1551594, /* 31099 ( 593) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
       16320, /* 31100 ( 593) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    51034818, /* 31101 ( 593) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  0] -1 */
    52570092, /* 31102 ( 593) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
     1538472, /* 31103 ( 593) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
        3198, /* 31104 ( 593) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    51034658, /* 31105 ( 593) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  0] -1 */
    52569932, /* 31106 ( 593) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    51021536, /* 31107 ( 593) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  0] -1 */
    51021696, /* 31108 ( 593) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  0] -1 */
     1551758, /* 31109 ( 593) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
     1538636, /* 31110 ( 593) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
    52556810, /* 31111 ( 593) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
        3362, /* 31112 ( 593) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    52556970, /* 31113 ( 593) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
       16484, /* 31114 ( 594) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    17022434, /* 31115 ( 594) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  0]  1 */
    17009472, /* 31116 ( 594) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  0]  1 */
    51034818, /* 31117 ( 594) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  0] -1 */
    52570092, /* 31118 ( 594) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
     1538472, /* 31119 ( 594) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
    34015586, /* 31120 ( 594) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    35550860, /* 31121 ( 594) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
        3198, /* 31122 ( 594) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    52556810, /* 31123 ( 594) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    51021536, /* 31124 ( 594) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  0] -1 */
     1551758, /* 31125 ( 594) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
    35563818, /* 31126 ( 594) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  6] -1 */
    18557708, /* 31127 ( 594) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    34028544, /* 31128 ( 594) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    18544746, /* 31129 ( 594) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
       16484, /* 31130 ( 595) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
     1551594, /* 31131 ( 595) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
    34015422, /* 31132 ( 595) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    17009472, /* 31133 ( 595) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  0]  1 */
       16320, /* 31134 ( 595) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    35550696, /* 31135 ( 595) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  6] -1 */
    17009312, /* 31136 ( 595) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  0]  1 */
    51034818, /* 31137 ( 595) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  0] -1 */
    52570092, /* 31138 ( 595) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    34015586, /* 31139 ( 595) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    35550860, /* 31140 ( 595) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
    51034658, /* 31141 ( 595) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  0] -1 */
    52569932, /* 31142 ( 595) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
     1551758, /* 31143 ( 595) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
    18544586, /* 31144 ( 595) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    18544746, /* 31145 ( 595) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
       16484, /* 31146 ( 596) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    17009472, /* 31147 ( 596) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  0]  1 */
     1538472, /* 31148 ( 596) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
        3198, /* 31149 ( 596) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    35550698, /* 31150 ( 596) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
    52570094, /* 31151 ( 596) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    35563980, /* 31152 ( 596) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6] -1 */
    35563820, /* 31153 ( 596) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
    34015424, /* 31154 ( 596) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    51034820, /* 31155 ( 596) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  0] -1 */
     1551758, /* 31156 ( 596) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
    34028706, /* 31157 ( 596) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    18544586, /* 31158 ( 596) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    34028546, /* 31159 ( 596) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    51034656, /* 31160 ( 596) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  0] -1 */
    52569930, /* 31161 ( 596) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    17022594, /* 31162 ( 596) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  0]  1 */
    51021698, /* 31163 ( 596) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  0] -1 */
    18557868, /* 31164 ( 596) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
    52556972, /* 31165 ( 596) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    18557708, /* 31166 ( 596) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    34015584, /* 31167 ( 596) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    35550858, /* 31168 ( 596) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6] -1 */
    52556808, /* 31169 ( 596) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
     1551594, /* 31170 ( 596) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
    17022434, /* 31171 ( 596) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  0]  1 */
    17009312, /* 31172 ( 596) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  0]  1 */
       16320, /* 31173 ( 596) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    51021534, /* 31174 ( 596) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  0] -1 */
     1538636, /* 31175 ( 596) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
        3362, /* 31176 ( 596) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    18544746, /* 31177 ( 596) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
       16484, /* 31178 ( 597) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34133684, /* 31179 ( 597) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    17009472, /* 31180 ( 597) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  0]  1 */
     1538472, /* 31181 ( 597) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
        3198, /* 31182 ( 597) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    52438872, /* 31183 ( 597) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
    34133520, /* 31184 ( 597) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
    51139794, /* 31185 ( 597) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6] -1 */
    35445884, /* 31186 ( 597) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  0] -1 */
    35445720, /* 31187 ( 597) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  0] -1 */
     1551758, /* 31188 ( 597) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
    18544586, /* 31189 ( 597) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    35432762, /* 31190 ( 597) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  0] -1 */
    35432598, /* 31191 ( 597) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  0] -1 */
    34146806, /* 31192 ( 597) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    17022594, /* 31193 ( 597) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  0]  1 */
    18557868, /* 31194 ( 597) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
    51139634, /* 31195 ( 597) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
    18557708, /* 31196 ( 597) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    51152916, /* 31197 ( 597) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6] -1 */
     1551594, /* 31198 ( 597) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
    17022434, /* 31199 ( 597) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  0]  1 */
    52438712, /* 31200 ( 597) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
    17009312, /* 31201 ( 597) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  0]  1 */
       16320, /* 31202 ( 597) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    52451994, /* 31203 ( 597) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
    51152756, /* 31204 ( 597) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
    34146642, /* 31205 ( 597) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
    52451834, /* 31206 ( 597) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
     1538636, /* 31207 ( 597) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
        3362, /* 31208 ( 597) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    18544746, /* 31209 ( 597) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
       16484, /* 31210 ( 598) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    17009472, /* 31211 ( 598) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  0]  1 */
     1538472, /* 31212 ( 598) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
    51139796, /* 31213 ( 598) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
    34133682, /* 31214 ( 598) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
        3198, /* 31215 ( 598) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    52438874, /* 31216 ( 598) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
    35432600, /* 31217 ( 598) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  0] -1 */
    52438710, /* 31218 ( 598) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
    35445882, /* 31219 ( 598) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  0] -1 */
    51139632, /* 31220 ( 598) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  6] -1 */
    35445722, /* 31221 ( 598) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  0] -1 */
     1551758, /* 31222 ( 598) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
    18544586, /* 31223 ( 598) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    35432760, /* 31224 ( 598) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  0] -1 */
    34133522, /* 31225 ( 598) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    51152918, /* 31226 ( 598) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
    34146804, /* 31227 ( 598) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
    52451996, /* 31228 ( 598) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
    17022594, /* 31229 ( 598) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  0]  1 */
    18557868, /* 31230 ( 598) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
    18557708, /* 31231 ( 598) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
     1551594, /* 31232 ( 598) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
    17022434, /* 31233 ( 598) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  0]  1 */
    17009312, /* 31234 ( 598) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  0]  1 */
       16320, /* 31235 ( 598) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    52451832, /* 31236 ( 598) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
    34146644, /* 31237 ( 598) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
     1538636, /* 31238 ( 598) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
    51152754, /* 31239 ( 598) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  6] -1 */
        3362, /* 31240 ( 598) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    18544746, /* 31241 ( 598) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
       16484, /* 31242 ( 589) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    17127570, /* 31243 ( 589) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6]  1 */
     1433658, /* 31244 ( 589) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  0]  1 */
     1433496, /* 31245 ( 589) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  0]  1 */
     1420376, /* 31246 ( 589) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  0]  1 */
        3360, /* 31247 ( 589) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    17127408, /* 31248 ( 589) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  6]  1 */
     1420538, /* 31249 ( 589) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  0]  1 */
        3198, /* 31250 ( 589) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    18557868, /* 31251 ( 589) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
    17140532, /* 31252 ( 589) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
    17140694, /* 31253 ( 589) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
    18544748, /* 31254 ( 589) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    18557706, /* 31255 ( 589) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
       16322, /* 31256 ( 589) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    18544586, /* 31257 ( 589) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
       16484, /* 31258 ( 590) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
     1420376, /* 31259 ( 590) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  0]  1 */
    17127408, /* 31260 ( 590) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  6]  1 */
    51152918, /* 31261 ( 590) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
        3198, /* 31262 ( 590) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    52569930, /* 31263 ( 590) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    35432762, /* 31264 ( 590) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  0] -1 */
    52556972, /* 31265 ( 590) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    35445882, /* 31266 ( 590) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  0] -1 */
    52570092, /* 31267 ( 590) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    35445720, /* 31268 ( 590) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  0] -1 */
    17140694, /* 31269 ( 590) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
    34015584, /* 31270 ( 590) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    34028708, /* 31271 ( 590) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    18557706, /* 31272 ( 590) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
    51139794, /* 31273 ( 590) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6] -1 */
    34028546, /* 31274 ( 590) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    51152756, /* 31275 ( 590) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
    35432600, /* 31276 ( 590) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  0] -1 */
    52556810, /* 31277 ( 590) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
     1420538, /* 31278 ( 590) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  0]  1 */
    18544748, /* 31279 ( 590) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    18557868, /* 31280 ( 590) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
    17127570, /* 31281 ( 590) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6]  1 */
     1433658, /* 31282 ( 590) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  0]  1 */
    34015422, /* 31283 ( 590) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
     1433496, /* 31284 ( 590) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  0]  1 */
        3360, /* 31285 ( 590) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    51139632, /* 31286 ( 590) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  6] -1 */
    17140532, /* 31287 ( 590) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
       16322, /* 31288 ( 590) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    18544586, /* 31289 ( 590) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
       16484, /* 31290 ( 591) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34015422, /* 31291 ( 591) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
     1420376, /* 31292 ( 591) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  0]  1 */
    51139632, /* 31293 ( 591) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  6] -1 */
     1420538, /* 31294 ( 591) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  0]  1 */
    35445882, /* 31295 ( 591) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  0] -1 */
    52569930, /* 31296 ( 591) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    35445720, /* 31297 ( 591) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  0] -1 */
    17140532, /* 31298 ( 591) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
    17140694, /* 31299 ( 591) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
    51139794, /* 31300 ( 591) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6] -1 */
    52570092, /* 31301 ( 591) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    18544748, /* 31302 ( 591) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
       16322, /* 31303 ( 591) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34015584, /* 31304 ( 591) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    18544586, /* 31305 ( 591) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
       16484, /* 31306 ( 592) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    17127570, /* 31307 ( 592) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6]  1 */
     1433658, /* 31308 ( 592) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  0]  1 */
    34015422, /* 31309 ( 592) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    51139632, /* 31310 ( 592) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  6] -1 */
        3360, /* 31311 ( 592) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    34028546, /* 31312 ( 592) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    51152756, /* 31313 ( 592) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
     1420538, /* 31314 ( 592) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  0]  1 */
    52569930, /* 31315 ( 592) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    35445720, /* 31316 ( 592) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  0] -1 */
    35432600, /* 31317 ( 592) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  0] -1 */
    17140694, /* 31318 ( 592) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
    18544748, /* 31319 ( 592) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    18557868, /* 31320 ( 592) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
    52556810, /* 31321 ( 592) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
       16484, /* 31322 ( 593) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    17127570, /* 31323 ( 593) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6]  1 */
        3360, /* 31324 ( 593) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    35432762, /* 31325 ( 593) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  0] -1 */
    52556972, /* 31326 ( 593) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    17127408, /* 31327 ( 593) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  6]  1 */
        3198, /* 31328 ( 593) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    35445882, /* 31329 ( 593) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  0] -1 */
    52570092, /* 31330 ( 593) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    35445720, /* 31331 ( 593) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  0] -1 */
    35432600, /* 31332 ( 593) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  0] -1 */
    17140694, /* 31333 ( 593) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
    17140532, /* 31334 ( 593) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
    52569930, /* 31335 ( 593) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
       16322, /* 31336 ( 593) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    52556810, /* 31337 ( 593) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
       16484, /* 31338 ( 594) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
     1433658, /* 31339 ( 594) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  0]  1 */
     1420376, /* 31340 ( 594) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  0]  1 */
    35432762, /* 31341 ( 594) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  0] -1 */
    52556972, /* 31342 ( 594) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    17127408, /* 31343 ( 594) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  6]  1 */
    34028546, /* 31344 ( 594) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    51152756, /* 31345 ( 594) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
        3198, /* 31346 ( 594) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    52569930, /* 31347 ( 594) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    35445720, /* 31348 ( 594) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  0] -1 */
    17140694, /* 31349 ( 594) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
    51139794, /* 31350 ( 594) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6] -1 */
    18557868, /* 31351 ( 594) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
    34015584, /* 31352 ( 594) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    18544586, /* 31353 ( 594) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
       16484, /* 31354 ( 595) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    17127570, /* 31355 ( 595) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6]  1 */
    34015422, /* 31356 ( 595) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
     1420376, /* 31357 ( 595) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  0]  1 */
        3360, /* 31358 ( 595) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    51139632, /* 31359 ( 595) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  6] -1 */
     1433496, /* 31360 ( 595) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  0]  1 */
    35432762, /* 31361 ( 595) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  0] -1 */
    52556972, /* 31362 ( 595) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    34028546, /* 31363 ( 595) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    51152756, /* 31364 ( 595) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
    35445882, /* 31365 ( 595) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  0] -1 */
    52570092, /* 31366 ( 595) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    17140694, /* 31367 ( 595) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
    18557706, /* 31368 ( 595) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
    18544586, /* 31369 ( 595) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
       16484, /* 31370 ( 596) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
     1420376, /* 31371 ( 596) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  0]  1 */
    17127408, /* 31372 ( 596) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  6]  1 */
        3198, /* 31373 ( 596) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    51152754, /* 31374 ( 596) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  6] -1 */
    52570094, /* 31375 ( 596) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    51139796, /* 31376 ( 596) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
    51152916, /* 31377 ( 596) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6] -1 */
    34028544, /* 31378 ( 596) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    35445884, /* 31379 ( 596) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  0] -1 */
    17140694, /* 31380 ( 596) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
    34015586, /* 31381 ( 596) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    18557706, /* 31382 ( 596) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
    34028706, /* 31383 ( 596) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    35432760, /* 31384 ( 596) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  0] -1 */
    52556970, /* 31385 ( 596) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
     1420538, /* 31386 ( 596) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  0]  1 */
    35445722, /* 31387 ( 596) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  0] -1 */
    18544748, /* 31388 ( 596) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    52569932, /* 31389 ( 596) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    18557868, /* 31390 ( 596) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
    34015424, /* 31391 ( 596) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    51139634, /* 31392 ( 596) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
    52556808, /* 31393 ( 596) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    17127570, /* 31394 ( 596) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6]  1 */
     1433658, /* 31395 ( 596) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  0]  1 */
     1433496, /* 31396 ( 596) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  0]  1 */
        3360, /* 31397 ( 596) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    35432598, /* 31398 ( 596) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  0] -1 */
    17140532, /* 31399 ( 596) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
       16322, /* 31400 ( 596) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    18544586, /* 31401 ( 596) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
       16484, /* 31402 ( 597) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    51034658, /* 31403 ( 597) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  0] -1 */
     1420376, /* 31404 ( 597) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  0]  1 */
    17127408, /* 31405 ( 597) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  6]  1 */
        3198, /* 31406 ( 597) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    35550698, /* 31407 ( 597) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
    51021534, /* 31408 ( 597) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  0] -1 */
    52438712, /* 31409 ( 597) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
    34146806, /* 31410 ( 597) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    34133682, /* 31411 ( 597) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
    17140694, /* 31412 ( 597) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
    18557706, /* 31413 ( 597) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
    34146644, /* 31414 ( 597) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    34133520, /* 31415 ( 597) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
    51034820, /* 31416 ( 597) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  0] -1 */
     1420538, /* 31417 ( 597) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  0]  1 */
    18544748, /* 31418 ( 597) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    52451832, /* 31419 ( 597) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
    18557868, /* 31420 ( 597) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
    52438874, /* 31421 ( 597) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
    17127570, /* 31422 ( 597) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6]  1 */
     1433658, /* 31423 ( 597) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  0]  1 */
    35563818, /* 31424 ( 597) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  6] -1 */
     1433496, /* 31425 ( 597) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  0]  1 */
        3360, /* 31426 ( 597) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    35550860, /* 31427 ( 597) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
    52451994, /* 31428 ( 597) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
    51021696, /* 31429 ( 597) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  0] -1 */
    35563980, /* 31430 ( 597) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6] -1 */
    17140532, /* 31431 ( 597) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
       16322, /* 31432 ( 597) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    18544586, /* 31433 ( 597) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
       16484, /* 31434 ( 598) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
     1420376, /* 31435 ( 598) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  0]  1 */
    17127408, /* 31436 ( 598) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  6]  1 */
    52451834, /* 31437 ( 598) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
    51021536, /* 31438 ( 598) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  0] -1 */
        3198, /* 31439 ( 598) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    35563820, /* 31440 ( 598) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
    34146642, /* 31441 ( 598) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
    35550696, /* 31442 ( 598) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  6] -1 */
    34133684, /* 31443 ( 598) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    52438710, /* 31444 ( 598) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
    34146804, /* 31445 ( 598) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
    17140694, /* 31446 ( 598) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
    18557706, /* 31447 ( 598) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
    34133522, /* 31448 ( 598) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    51034656, /* 31449 ( 598) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  0] -1 */
    52451996, /* 31450 ( 598) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
    51021698, /* 31451 ( 598) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  0] -1 */
    35563982, /* 31452 ( 598) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
     1420538, /* 31453 ( 598) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  0]  1 */
    18544748, /* 31454 ( 598) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    18557868, /* 31455 ( 598) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
    17127570, /* 31456 ( 598) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6]  1 */
     1433658, /* 31457 ( 598) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  0]  1 */
     1433496, /* 31458 ( 598) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  0]  1 */
        3360, /* 31459 ( 598) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    35550858, /* 31460 ( 598) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6] -1 */
    51034818, /* 31461 ( 598) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  0] -1 */
    17140532, /* 31462 ( 598) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
    52438872, /* 31463 ( 598) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
       16322, /* 31464 ( 598) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    18544586, /* 31465 ( 598) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
       16484, /* 31466 ( 599) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    17009312, /* 31467 ( 599) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  0]  1 */
    18439608, /* 31468 ( 599) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
    17009472, /* 31469 ( 599) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  0]  1 */
        3362, /* 31470 ( 599) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
     1433658, /* 31471 ( 599) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  0]  1 */
       16320, /* 31472 ( 599) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    18426486, /* 31473 ( 599) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
    17022434, /* 31474 ( 599) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  0]  1 */
    18426650, /* 31475 ( 599) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
        3198, /* 31476 ( 599) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
     1420376, /* 31477 ( 599) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  0]  1 */
     1420536, /* 31478 ( 599) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  0]  1 */
    18439772, /* 31479 ( 599) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
     1433498, /* 31480 ( 599) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  0]  1 */
    17022594, /* 31481 ( 599) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  0]  1 */
       16484, /* 31482 ( 600) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    35445882, /* 31483 ( 600) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  0] -1 */
    18439608, /* 31484 ( 600) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
       16320, /* 31485 ( 600) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    18426486, /* 31486 ( 600) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
    52451996, /* 31487 ( 600) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
        3198, /* 31488 ( 600) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
     1420376, /* 31489 ( 600) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  0]  1 */
    51021696, /* 31490 ( 600) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  0] -1 */
    51034658, /* 31491 ( 600) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  0] -1 */
     1433658, /* 31492 ( 600) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  0]  1 */
    52438874, /* 31493 ( 600) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
    51021536, /* 31494 ( 600) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  0] -1 */
    18439772, /* 31495 ( 600) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    34028708, /* 31496 ( 600) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    34015586, /* 31497 ( 600) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    17009472, /* 31498 ( 600) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  0]  1 */
    35432760, /* 31499 ( 600) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  0] -1 */
    17022434, /* 31500 ( 600) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  0]  1 */
    51034818, /* 31501 ( 600) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  0] -1 */
    18426650, /* 31502 ( 600) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    35445722, /* 31503 ( 600) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  0] -1 */
    34028544, /* 31504 ( 600) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    52451832, /* 31505 ( 600) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
    34015422, /* 31506 ( 600) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    17009312, /* 31507 ( 600) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  0]  1 */
    52438710, /* 31508 ( 600) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
        3362, /* 31509 ( 600) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    35432600, /* 31510 ( 600) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  0] -1 */
     1420536, /* 31511 ( 600) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  0]  1 */
     1433498, /* 31512 ( 600) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  0]  1 */
    17022594, /* 31513 ( 600) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  0]  1 */
       16484, /* 31514 ( 601) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34015586, /* 31515 ( 601) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    34015422, /* 31516 ( 601) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    18439608, /* 31517 ( 601) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
    52438710, /* 31518 ( 601) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
     1433658, /* 31519 ( 601) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  0]  1 */
    52438874, /* 31520 ( 601) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
       16320, /* 31521 ( 601) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    35432600, /* 31522 ( 601) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  0] -1 */
    35432760, /* 31523 ( 601) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  0] -1 */
    17022434, /* 31524 ( 601) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  0]  1 */
    51021536, /* 31525 ( 601) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  0] -1 */
    18439772, /* 31526 ( 601) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    51021696, /* 31527 ( 601) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  0] -1 */
     1433498, /* 31528 ( 601) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  0]  1 */
    17022594, /* 31529 ( 601) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  0]  1 */
       16484, /* 31530 ( 602) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    35445882, /* 31531 ( 602) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  0] -1 */
    34015422, /* 31532 ( 602) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    17009312, /* 31533 ( 602) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  0]  1 */
    52438710, /* 31534 ( 602) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
        3362, /* 31535 ( 602) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    35432760, /* 31536 ( 602) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  0] -1 */
    51034818, /* 31537 ( 602) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  0] -1 */
    17022434, /* 31538 ( 602) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  0]  1 */
    18426650, /* 31539 ( 602) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
     1420376, /* 31540 ( 602) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  0]  1 */
    18439772, /* 31541 ( 602) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    51021696, /* 31542 ( 602) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  0] -1 */
     1433498, /* 31543 ( 602) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  0]  1 */
    34028544, /* 31544 ( 602) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    52451832, /* 31545 ( 602) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
       16484, /* 31546 ( 603) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34015586, /* 31547 ( 603) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    17009312, /* 31548 ( 603) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  0]  1 */
     1433658, /* 31549 ( 603) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  0]  1 */
    52438874, /* 31550 ( 603) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
    18426486, /* 31551 ( 603) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
    35432760, /* 31552 ( 603) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  0] -1 */
        3198, /* 31553 ( 603) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
     1420376, /* 31554 ( 603) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  0]  1 */
    35445722, /* 31555 ( 603) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  0] -1 */
    18439772, /* 31556 ( 603) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    51021696, /* 31557 ( 603) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  0] -1 */
    17022594, /* 31558 ( 603) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  0]  1 */
    34028544, /* 31559 ( 603) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    52451832, /* 31560 ( 603) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
    51034658, /* 31561 ( 603) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  0] -1 */
       16484, /* 31562 ( 604) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    35445882, /* 31563 ( 604) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  0] -1 */
    18439608, /* 31564 ( 604) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
        3362, /* 31565 ( 604) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
       16320, /* 31566 ( 604) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    35432600, /* 31567 ( 604) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  0] -1 */
    18426486, /* 31568 ( 604) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
    35432760, /* 31569 ( 604) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  0] -1 */
    51034818, /* 31570 ( 604) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  0] -1 */
    18426650, /* 31571 ( 604) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
        3198, /* 31572 ( 604) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    35445722, /* 31573 ( 604) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  0] -1 */
    51021536, /* 31574 ( 604) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  0] -1 */
    18439772, /* 31575 ( 604) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    51021696, /* 31576 ( 604) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  0] -1 */
    51034658, /* 31577 ( 604) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  0] -1 */
       16484, /* 31578 ( 605) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    35445882, /* 31579 ( 605) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  0] -1 */
    34015586, /* 31580 ( 605) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    34015422, /* 31581 ( 605) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    17009312, /* 31582 ( 605) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  0]  1 */
    18439608, /* 31583 ( 605) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
    52438710, /* 31584 ( 605) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
    17009472, /* 31585 ( 605) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  0]  1 */
    52438874, /* 31586 ( 605) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
       16320, /* 31587 ( 605) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    51034818, /* 31588 ( 605) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  0] -1 */
     1420376, /* 31589 ( 605) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  0]  1 */
     1420536, /* 31590 ( 605) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  0]  1 */
    35445722, /* 31591 ( 605) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  0] -1 */
    18439772, /* 31592 ( 605) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    51034658, /* 31593 ( 605) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  0] -1 */
       16484, /* 31594 ( 606) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    18439608, /* 31595 ( 606) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
       16320, /* 31596 ( 606) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    18426486, /* 31597 ( 606) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
    35563980, /* 31598 ( 606) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6] -1 */
        3198, /* 31599 ( 606) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
     1420376, /* 31600 ( 606) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  0]  1 */
    51152916, /* 31601 ( 606) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6] -1 */
    52570094, /* 31602 ( 606) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
     1433658, /* 31603 ( 606) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  0]  1 */
    34146806, /* 31604 ( 606) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    34133684, /* 31605 ( 606) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    52556972, /* 31606 ( 606) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    18439772, /* 31607 ( 606) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    17009472, /* 31608 ( 606) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  0]  1 */
    17022434, /* 31609 ( 606) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  0]  1 */
    18426650, /* 31610 ( 606) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    34146642, /* 31611 ( 606) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
    52569930, /* 31612 ( 606) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    35550858, /* 31613 ( 606) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6] -1 */
    35563820, /* 31614 ( 606) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
    52556808, /* 31615 ( 606) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    51139794, /* 31616 ( 606) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6] -1 */
    17009312, /* 31617 ( 606) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  0]  1 */
    51152756, /* 31618 ( 606) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
        3362, /* 31619 ( 606) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    51139634, /* 31620 ( 606) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
    34133520, /* 31621 ( 606) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
     1420536, /* 31622 ( 606) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  0]  1 */
    35550698, /* 31623 ( 606) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
     1433498, /* 31624 ( 606) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  0]  1 */
    17022594, /* 31625 ( 606) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  0]  1 */
       16484, /* 31626 ( 607) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    18439608, /* 31627 ( 607) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
       16320, /* 31628 ( 607) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    18426486, /* 31629 ( 607) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
    35445720, /* 31630 ( 607) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  0] -1 */
        3198, /* 31631 ( 607) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
     1420376, /* 31632 ( 607) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  0]  1 */
    35432598, /* 31633 ( 607) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  0] -1 */
    52438872, /* 31634 ( 607) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
    52451834, /* 31635 ( 607) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
    51034820, /* 31636 ( 607) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  0] -1 */
     1433658, /* 31637 ( 607) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  0]  1 */
    51021698, /* 31638 ( 607) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  0] -1 */
    34015584, /* 31639 ( 607) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    18439772, /* 31640 ( 607) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    52438712, /* 31641 ( 607) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
    34015424, /* 31642 ( 607) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    34028546, /* 31643 ( 607) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    17009472, /* 31644 ( 607) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  0]  1 */
    51034656, /* 31645 ( 607) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  0] -1 */
    17022434, /* 31646 ( 607) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  0]  1 */
    34028706, /* 31647 ( 607) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    52451994, /* 31648 ( 607) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
    18426650, /* 31649 ( 607) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    51021534, /* 31650 ( 607) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  0] -1 */
    35445884, /* 31651 ( 607) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  0] -1 */
    17009312, /* 31652 ( 607) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  0]  1 */
        3362, /* 31653 ( 607) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    35432762, /* 31654 ( 607) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  0] -1 */
     1420536, /* 31655 ( 607) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  0]  1 */
     1433498, /* 31656 ( 607) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  0]  1 */
    17022594, /* 31657 ( 607) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  0]  1 */
       16484, /* 31658 ( 608) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    18439608, /* 31659 ( 608) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
       16320, /* 31660 ( 608) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    18426486, /* 31661 ( 608) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
        3198, /* 31662 ( 608) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
     1420376, /* 31663 ( 608) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  0]  1 */
    51152754, /* 31664 ( 608) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  6] -1 */
    52556970, /* 31665 ( 608) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    51139632, /* 31666 ( 608) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  6] -1 */
    35563818, /* 31667 ( 608) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  6] -1 */
    35550696, /* 31668 ( 608) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  6] -1 */
     1433658, /* 31669 ( 608) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  0]  1 */
    34146644, /* 31670 ( 608) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    52569932, /* 31671 ( 608) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    34133682, /* 31672 ( 608) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
    18439772, /* 31673 ( 608) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    34133522, /* 31674 ( 608) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    52556810, /* 31675 ( 608) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    17009472, /* 31676 ( 608) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  0]  1 */
    17022434, /* 31677 ( 608) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  0]  1 */
    35563982, /* 31678 ( 608) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
    18426650, /* 31679 ( 608) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    51152918, /* 31680 ( 608) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
    34146804, /* 31681 ( 608) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
    52570092, /* 31682 ( 608) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    17009312, /* 31683 ( 608) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  0]  1 */
        3362, /* 31684 ( 608) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    35550860, /* 31685 ( 608) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
    51139796, /* 31686 ( 608) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
     1420536, /* 31687 ( 608) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  0]  1 */
     1433498, /* 31688 ( 608) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  0]  1 */
    17022594, /* 31689 ( 608) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  0]  1 */
       16484, /* 31690 ( 599) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
     1420376, /* 31691 ( 599) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  0]  1 */
    18426648, /* 31692 ( 599) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
     1433496, /* 31693 ( 599) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  0]  1 */
       16322, /* 31694 ( 599) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    17022594, /* 31695 ( 599) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  0]  1 */
        3360, /* 31696 ( 599) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    18426486, /* 31697 ( 599) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
     1420538, /* 31698 ( 599) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  0]  1 */
    18439610, /* 31699 ( 599) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
        3198, /* 31700 ( 599) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    17009312, /* 31701 ( 599) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  0]  1 */
    17022432, /* 31702 ( 599) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  0]  1 */
    18439772, /* 31703 ( 599) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    17009474, /* 31704 ( 599) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  0]  1 */
     1433658, /* 31705 ( 599) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  0]  1 */
       16484, /* 31706 ( 600) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    51034818, /* 31707 ( 600) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  0] -1 */
    18426648, /* 31708 ( 600) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
        3360, /* 31709 ( 600) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    18426486, /* 31710 ( 600) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
    52451996, /* 31711 ( 600) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
        3198, /* 31712 ( 600) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    17009312, /* 31713 ( 600) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  0]  1 */
    35445720, /* 31714 ( 600) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  0] -1 */
    35432762, /* 31715 ( 600) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  0] -1 */
    17022594, /* 31716 ( 600) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  0]  1 */
    52451834, /* 31717 ( 600) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
    35432600, /* 31718 ( 600) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  0] -1 */
    18439772, /* 31719 ( 600) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    34028708, /* 31720 ( 600) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    34028546, /* 31721 ( 600) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
     1433496, /* 31722 ( 600) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  0]  1 */
    51034656, /* 31723 ( 600) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  0] -1 */
     1420538, /* 31724 ( 600) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  0]  1 */
    35445882, /* 31725 ( 600) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  0] -1 */
    18439610, /* 31726 ( 600) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    51021698, /* 31727 ( 600) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  0] -1 */
    34015584, /* 31728 ( 600) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    52438872, /* 31729 ( 600) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
    34015422, /* 31730 ( 600) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
     1420376, /* 31731 ( 600) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  0]  1 */
    52438710, /* 31732 ( 600) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
       16322, /* 31733 ( 600) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    51021536, /* 31734 ( 600) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  0] -1 */
    17022432, /* 31735 ( 600) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  0]  1 */
    17009474, /* 31736 ( 600) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  0]  1 */
     1433658, /* 31737 ( 600) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  0]  1 */
       16484, /* 31738 ( 601) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34028546, /* 31739 ( 601) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    34015422, /* 31740 ( 601) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    18426648, /* 31741 ( 601) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
    52438710, /* 31742 ( 601) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
    17022594, /* 31743 ( 601) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  0]  1 */
    52451834, /* 31744 ( 601) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
        3360, /* 31745 ( 601) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    51021536, /* 31746 ( 601) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  0] -1 */
    51034656, /* 31747 ( 601) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  0] -1 */
     1420538, /* 31748 ( 601) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  0]  1 */
    35432600, /* 31749 ( 601) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  0] -1 */
    18439772, /* 31750 ( 601) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    35445720, /* 31751 ( 601) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  0] -1 */
    17009474, /* 31752 ( 601) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  0]  1 */
     1433658, /* 31753 ( 601) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  0]  1 */
       16484, /* 31754 ( 602) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    51034818, /* 31755 ( 602) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  0] -1 */
    34015422, /* 31756 ( 602) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
     1420376, /* 31757 ( 602) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  0]  1 */
    52438710, /* 31758 ( 602) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
       16322, /* 31759 ( 602) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    51034656, /* 31760 ( 602) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  0] -1 */
    35445882, /* 31761 ( 602) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  0] -1 */
     1420538, /* 31762 ( 602) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  0]  1 */
    18439610, /* 31763 ( 602) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    17009312, /* 31764 ( 602) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  0]  1 */
    18439772, /* 31765 ( 602) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    35445720, /* 31766 ( 602) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  0] -1 */
    17009474, /* 31767 ( 602) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  0]  1 */
    34015584, /* 31768 ( 602) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    52438872, /* 31769 ( 602) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
       16484, /* 31770 ( 603) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34028546, /* 31771 ( 603) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
     1420376, /* 31772 ( 603) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  0]  1 */
    17022594, /* 31773 ( 603) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  0]  1 */
    52451834, /* 31774 ( 603) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
    18426486, /* 31775 ( 603) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
    51034656, /* 31776 ( 603) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  0] -1 */
        3198, /* 31777 ( 603) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    17009312, /* 31778 ( 603) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  0]  1 */
    51021698, /* 31779 ( 603) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  0] -1 */
    18439772, /* 31780 ( 603) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    35445720, /* 31781 ( 603) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  0] -1 */
     1433658, /* 31782 ( 603) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  0]  1 */
    34015584, /* 31783 ( 603) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    52438872, /* 31784 ( 603) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
    35432762, /* 31785 ( 603) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  0] -1 */
       16484, /* 31786 ( 604) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    51034818, /* 31787 ( 604) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  0] -1 */
    18426648, /* 31788 ( 604) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
       16322, /* 31789 ( 604) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
        3360, /* 31790 ( 604) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    51021536, /* 31791 ( 604) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  0] -1 */
    18426486, /* 31792 ( 604) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
    51034656, /* 31793 ( 604) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  0] -1 */
    35445882, /* 31794 ( 604) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  0] -1 */
    18439610, /* 31795 ( 604) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
        3198, /* 31796 ( 604) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    51021698, /* 31797 ( 604) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  0] -1 */
    35432600, /* 31798 ( 604) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  0] -1 */
    18439772, /* 31799 ( 604) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    35445720, /* 31800 ( 604) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  0] -1 */
    35432762, /* 31801 ( 604) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  0] -1 */
       16484, /* 31802 ( 605) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    51034818, /* 31803 ( 605) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  0] -1 */
    34028546, /* 31804 ( 605) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    34015422, /* 31805 ( 605) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
     1420376, /* 31806 ( 605) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  0]  1 */
    18426648, /* 31807 ( 605) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
    52438710, /* 31808 ( 605) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
     1433496, /* 31809 ( 605) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  0]  1 */
    52451834, /* 31810 ( 605) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
        3360, /* 31811 ( 605) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    35445882, /* 31812 ( 605) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  0] -1 */
    17009312, /* 31813 ( 605) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  0]  1 */
    17022432, /* 31814 ( 605) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  0]  1 */
    51021698, /* 31815 ( 605) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  0] -1 */
    18439772, /* 31816 ( 605) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    35432762, /* 31817 ( 605) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  0] -1 */
       16484, /* 31818 ( 606) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    18426648, /* 31819 ( 606) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
        3360, /* 31820 ( 606) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    18426486, /* 31821 ( 606) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
    51152916, /* 31822 ( 606) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6] -1 */
        3198, /* 31823 ( 606) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    17009312, /* 31824 ( 606) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  0]  1 */
    35563980, /* 31825 ( 606) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6] -1 */
    52570094, /* 31826 ( 606) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    17022594, /* 31827 ( 606) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  0]  1 */
    34146806, /* 31828 ( 606) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    34146644, /* 31829 ( 606) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    52569932, /* 31830 ( 606) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    18439772, /* 31831 ( 606) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
     1433496, /* 31832 ( 606) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  0]  1 */
     1420538, /* 31833 ( 606) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  0]  1 */
    18439610, /* 31834 ( 606) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    34133682, /* 31835 ( 606) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
    52556970, /* 31836 ( 606) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    51152754, /* 31837 ( 606) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  6] -1 */
    51139796, /* 31838 ( 606) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
    52556808, /* 31839 ( 606) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    35563818, /* 31840 ( 606) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  6] -1 */
     1420376, /* 31841 ( 606) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  0]  1 */
    35550860, /* 31842 ( 606) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
       16322, /* 31843 ( 606) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    35550698, /* 31844 ( 606) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
    34133520, /* 31845 ( 606) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
    17022432, /* 31846 ( 606) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  0]  1 */
    51139634, /* 31847 ( 606) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
    17009474, /* 31848 ( 606) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  0]  1 */
     1433658, /* 31849 ( 606) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  0]  1 */
       16484, /* 31850 ( 607) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    18426648, /* 31851 ( 607) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
        3360, /* 31852 ( 607) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    18426486, /* 31853 ( 607) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
    51021696, /* 31854 ( 607) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  0] -1 */
        3198, /* 31855 ( 607) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    17009312, /* 31856 ( 607) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  0]  1 */
    51021534, /* 31857 ( 607) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  0] -1 */
    52451832, /* 31858 ( 607) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
    52438874, /* 31859 ( 607) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
    35445884, /* 31860 ( 607) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  0] -1 */
    17022594, /* 31861 ( 607) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  0]  1 */
    35445722, /* 31862 ( 607) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  0] -1 */
    34028544, /* 31863 ( 607) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    18439772, /* 31864 ( 607) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    52438712, /* 31865 ( 607) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
    34015424, /* 31866 ( 607) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    34015586, /* 31867 ( 607) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
     1433496, /* 31868 ( 607) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  0]  1 */
    35432760, /* 31869 ( 607) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  0] -1 */
     1420538, /* 31870 ( 607) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  0]  1 */
    34028706, /* 31871 ( 607) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    52451994, /* 31872 ( 607) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
    18439610, /* 31873 ( 607) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    35432598, /* 31874 ( 607) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  0] -1 */
    51034820, /* 31875 ( 607) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  0] -1 */
     1420376, /* 31876 ( 607) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  0]  1 */
       16322, /* 31877 ( 607) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    51034658, /* 31878 ( 607) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  0] -1 */
    17022432, /* 31879 ( 607) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  0]  1 */
    17009474, /* 31880 ( 607) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  0]  1 */
     1433658, /* 31881 ( 607) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  0]  1 */
       16484, /* 31882 ( 608) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    18426648, /* 31883 ( 608) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
        3360, /* 31884 ( 608) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    18426486, /* 31885 ( 608) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
        3198, /* 31886 ( 608) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    17009312, /* 31887 ( 608) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  0]  1 */
    35550858, /* 31888 ( 608) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6] -1 */
    52569930, /* 31889 ( 608) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    35550696, /* 31890 ( 608) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  6] -1 */
    51139794, /* 31891 ( 608) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6] -1 */
    51139632, /* 31892 ( 608) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  6] -1 */
    17022594, /* 31893 ( 608) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  0]  1 */
    34133684, /* 31894 ( 608) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    52556972, /* 31895 ( 608) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    34146642, /* 31896 ( 608) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
    18439772, /* 31897 ( 608) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    34133522, /* 31898 ( 608) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    52556810, /* 31899 ( 608) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
     1433496, /* 31900 ( 608) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  0]  1 */
     1420538, /* 31901 ( 608) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  0]  1 */
    51152918, /* 31902 ( 608) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
    18439610, /* 31903 ( 608) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    35563982, /* 31904 ( 608) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
    34146804, /* 31905 ( 608) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
    52570092, /* 31906 ( 608) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
     1420376, /* 31907 ( 608) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  0]  1 */
       16322, /* 31908 ( 608) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    51152756, /* 31909 ( 608) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
    35563820, /* 31910 ( 608) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
    17022432, /* 31911 ( 608) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  0]  1 */
    17009474, /* 31912 ( 608) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  0]  1 */
     1433658, /* 31913 ( 608) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  0]  1 */
       16484, /* 31914 ( 599) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
     1433496, /* 31915 ( 599) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  0]  1 */
     1538634, /* 31916 ( 599) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
     1420376, /* 31917 ( 599) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  0]  1 */
       16322, /* 31918 ( 599) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
      121460, /* 31919 ( 599) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6]  1 */
        3360, /* 31920 ( 599) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
     1538472, /* 31921 ( 599) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
     1433658, /* 31922 ( 599) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  0]  1 */
     1551596, /* 31923 ( 599) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
        3198, /* 31924 ( 599) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
      134418, /* 31925 ( 599) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  6]  1 */
      121298, /* 31926 ( 599) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6]  1 */
     1551758, /* 31927 ( 599) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
      134580, /* 31928 ( 599) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  6]  1 */
     1420538, /* 31929 ( 599) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  0]  1 */
       16484, /* 31930 ( 600) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34133684, /* 31931 ( 600) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
     1538634, /* 31932 ( 600) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
        3360, /* 31933 ( 600) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
     1538472, /* 31934 ( 600) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
    35563982, /* 31935 ( 600) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
        3198, /* 31936 ( 600) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
      134418, /* 31937 ( 600) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  6]  1 */
    35432600, /* 31938 ( 600) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  0] -1 */
    35445882, /* 31939 ( 600) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  0] -1 */
      121460, /* 31940 ( 600) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6]  1 */
    35563820, /* 31941 ( 600) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
    35445720, /* 31942 ( 600) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  0] -1 */
     1551758, /* 31943 ( 600) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
    34028708, /* 31944 ( 600) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    34028546, /* 31945 ( 600) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
     1420376, /* 31946 ( 600) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  0]  1 */
    34133522, /* 31947 ( 600) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
     1433658, /* 31948 ( 600) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  0]  1 */
    35432762, /* 31949 ( 600) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  0] -1 */
     1551596, /* 31950 ( 600) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
    34146804, /* 31951 ( 600) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
    34015584, /* 31952 ( 600) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    35550858, /* 31953 ( 600) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6] -1 */
    34015422, /* 31954 ( 600) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
     1433496, /* 31955 ( 600) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  0]  1 */
    35550696, /* 31956 ( 600) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  6] -1 */
       16322, /* 31957 ( 600) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34146642, /* 31958 ( 600) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
      121298, /* 31959 ( 600) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6]  1 */
      134580, /* 31960 ( 600) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  6]  1 */
     1420538, /* 31961 ( 600) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  0]  1 */
       16484, /* 31962 ( 601) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34028546, /* 31963 ( 601) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    34015422, /* 31964 ( 601) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
     1538634, /* 31965 ( 601) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
    35550696, /* 31966 ( 601) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  6] -1 */
      121460, /* 31967 ( 601) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6]  1 */
    35563820, /* 31968 ( 601) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
        3360, /* 31969 ( 601) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    34146642, /* 31970 ( 601) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
    34133522, /* 31971 ( 601) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
     1433658, /* 31972 ( 601) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  0]  1 */
    35445720, /* 31973 ( 601) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  0] -1 */
     1551758, /* 31974 ( 601) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
    35432600, /* 31975 ( 601) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  0] -1 */
      134580, /* 31976 ( 601) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  6]  1 */
     1420538, /* 31977 ( 601) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  0]  1 */
       16484, /* 31978 ( 602) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34133684, /* 31979 ( 602) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    34015422, /* 31980 ( 602) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
     1433496, /* 31981 ( 602) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  0]  1 */
    35550696, /* 31982 ( 602) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  6] -1 */
       16322, /* 31983 ( 602) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34133522, /* 31984 ( 602) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    35432762, /* 31985 ( 602) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  0] -1 */
     1433658, /* 31986 ( 602) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  0]  1 */
     1551596, /* 31987 ( 602) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
      134418, /* 31988 ( 602) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  6]  1 */
     1551758, /* 31989 ( 602) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
    35432600, /* 31990 ( 602) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  0] -1 */
      134580, /* 31991 ( 602) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  6]  1 */
    34015584, /* 31992 ( 602) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    35550858, /* 31993 ( 602) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6] -1 */
       16484, /* 31994 ( 603) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34028546, /* 31995 ( 603) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
     1433496, /* 31996 ( 603) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  0]  1 */
      121460, /* 31997 ( 603) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6]  1 */
    35563820, /* 31998 ( 603) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
     1538472, /* 31999 ( 603) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
    34133522, /* 32000 ( 603) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
        3198, /* 32001 ( 603) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
      134418, /* 32002 ( 603) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  6]  1 */
    34146804, /* 32003 ( 603) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
     1551758, /* 32004 ( 603) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
    35432600, /* 32005 ( 603) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  0] -1 */
     1420538, /* 32006 ( 603) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  0]  1 */
    34015584, /* 32007 ( 603) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    35550858, /* 32008 ( 603) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6] -1 */
    35445882, /* 32009 ( 603) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  0] -1 */
       16484, /* 32010 ( 604) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34133684, /* 32011 ( 604) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
     1538634, /* 32012 ( 604) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
       16322, /* 32013 ( 604) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
        3360, /* 32014 ( 604) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    34146642, /* 32015 ( 604) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
     1538472, /* 32016 ( 604) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
    34133522, /* 32017 ( 604) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    35432762, /* 32018 ( 604) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  0] -1 */
     1551596, /* 32019 ( 604) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
        3198, /* 32020 ( 604) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    34146804, /* 32021 ( 604) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
    35445720, /* 32022 ( 604) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  0] -1 */
     1551758, /* 32023 ( 604) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
    35432600, /* 32024 ( 604) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  0] -1 */
    35445882, /* 32025 ( 604) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  0] -1 */
       16484, /* 32026 ( 605) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34133684, /* 32027 ( 605) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    34028546, /* 32028 ( 605) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    34015422, /* 32029 ( 605) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
     1433496, /* 32030 ( 605) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  0]  1 */
     1538634, /* 32031 ( 605) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
    35550696, /* 32032 ( 605) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  6] -1 */
     1420376, /* 32033 ( 605) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  0]  1 */
    35563820, /* 32034 ( 605) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
        3360, /* 32035 ( 605) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    35432762, /* 32036 ( 605) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  0] -1 */
      134418, /* 32037 ( 605) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  6]  1 */
      121298, /* 32038 ( 605) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6]  1 */
    34146804, /* 32039 ( 605) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
     1551758, /* 32040 ( 605) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
    35445882, /* 32041 ( 605) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  0] -1 */
       16484, /* 32042 ( 606) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
     1538634, /* 32043 ( 606) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
        3360, /* 32044 ( 606) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
     1538472, /* 32045 ( 606) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
    51139796, /* 32046 ( 606) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
        3198, /* 32047 ( 606) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
      134418, /* 32048 ( 606) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  6]  1 */
    52438874, /* 32049 ( 606) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
    52570094, /* 32050 ( 606) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
      121460, /* 32051 ( 606) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6]  1 */
    51034820, /* 32052 ( 606) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  0] -1 */
    51034658, /* 32053 ( 606) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  0] -1 */
    52569932, /* 32054 ( 606) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
     1551758, /* 32055 ( 606) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
     1420376, /* 32056 ( 606) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  0]  1 */
     1433658, /* 32057 ( 606) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  0]  1 */
     1551596, /* 32058 ( 606) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
    51021696, /* 32059 ( 606) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  0] -1 */
    52556970, /* 32060 ( 606) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    51139634, /* 32061 ( 606) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
    51152916, /* 32062 ( 606) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6] -1 */
    52556808, /* 32063 ( 606) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    52438712, /* 32064 ( 606) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
     1433496, /* 32065 ( 606) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  0]  1 */
    52451994, /* 32066 ( 606) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
       16322, /* 32067 ( 606) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    52451832, /* 32068 ( 606) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
    51021534, /* 32069 ( 606) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  0] -1 */
      121298, /* 32070 ( 606) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6]  1 */
    51152754, /* 32071 ( 606) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  6] -1 */
      134580, /* 32072 ( 606) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  6]  1 */
     1420538, /* 32073 ( 606) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  0]  1 */
       16484, /* 32074 ( 607) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
     1538634, /* 32075 ( 607) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
        3360, /* 32076 ( 607) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
     1538472, /* 32077 ( 607) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
    34133682, /* 32078 ( 607) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
        3198, /* 32079 ( 607) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
      134418, /* 32080 ( 607) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  6]  1 */
    34133520, /* 32081 ( 607) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
    35550698, /* 32082 ( 607) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
    35563980, /* 32083 ( 607) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6] -1 */
    35445884, /* 32084 ( 607) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  0] -1 */
      121460, /* 32085 ( 607) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6]  1 */
    35445722, /* 32086 ( 607) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  0] -1 */
    34015424, /* 32087 ( 607) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
     1551758, /* 32088 ( 607) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
    35563818, /* 32089 ( 607) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  6] -1 */
    34028544, /* 32090 ( 607) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    34028706, /* 32091 ( 607) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
     1420376, /* 32092 ( 607) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  0]  1 */
    35432760, /* 32093 ( 607) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  0] -1 */
     1433658, /* 32094 ( 607) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  0]  1 */
    34015586, /* 32095 ( 607) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    35550860, /* 32096 ( 607) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
     1551596, /* 32097 ( 607) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
    35432598, /* 32098 ( 607) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  0] -1 */
    34146806, /* 32099 ( 607) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
     1433496, /* 32100 ( 607) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  0]  1 */
       16322, /* 32101 ( 607) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34146644, /* 32102 ( 607) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
      121298, /* 32103 ( 607) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6]  1 */
      134580, /* 32104 ( 607) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  6]  1 */
     1420538, /* 32105 ( 607) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  0]  1 */
       16484, /* 32106 ( 608) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
     1538634, /* 32107 ( 608) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
        3360, /* 32108 ( 608) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
     1538472, /* 32109 ( 608) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
        3198, /* 32110 ( 608) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
      134418, /* 32111 ( 608) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  6]  1 */
    52438872, /* 32112 ( 608) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
    52556810, /* 32113 ( 608) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    52438710, /* 32114 ( 608) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
    51139794, /* 32115 ( 608) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6] -1 */
    51139632, /* 32116 ( 608) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  6] -1 */
      121460, /* 32117 ( 608) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6]  1 */
    51034818, /* 32118 ( 608) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  0] -1 */
    52570092, /* 32119 ( 608) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    51021536, /* 32120 ( 608) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  0] -1 */
     1551758, /* 32121 ( 608) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
    51034656, /* 32122 ( 608) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  0] -1 */
    52569930, /* 32123 ( 608) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
     1420376, /* 32124 ( 608) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  0]  1 */
     1433658, /* 32125 ( 608) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  0]  1 */
    51152918, /* 32126 ( 608) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
     1551596, /* 32127 ( 608) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
    52451996, /* 32128 ( 608) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
    51021698, /* 32129 ( 608) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  0] -1 */
    52556972, /* 32130 ( 608) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
     1433496, /* 32131 ( 608) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  0]  1 */
       16322, /* 32132 ( 608) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    51152756, /* 32133 ( 608) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
    52451834, /* 32134 ( 608) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
      121298, /* 32135 ( 608) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6]  1 */
      134580, /* 32136 ( 608) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  6]  1 */
     1420538, /* 32137 ( 608) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  0]  1 */
       16484, /* 32138 ( 599) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
      134418, /* 32139 ( 599) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  6]  1 */
     1538474, /* 32140 ( 599) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
      121458, /* 32141 ( 599) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  6]  1 */
       16482, /* 32142 ( 599) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
     1420538, /* 32143 ( 599) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  0]  1 */
        3200, /* 32144 ( 599) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
     1538472, /* 32145 ( 599) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
      134420, /* 32146 ( 599) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6]  1 */
     1551756, /* 32147 ( 599) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
        3198, /* 32148 ( 599) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
     1433496, /* 32149 ( 599) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  0]  1 */
     1420536, /* 32150 ( 599) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  0]  1 */
     1551758, /* 32151 ( 599) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
     1433498, /* 32152 ( 599) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  0]  1 */
      121460, /* 32153 ( 599) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6]  1 */
       16484, /* 32154 ( 600) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    35432762, /* 32155 ( 600) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  0] -1 */
     1538474, /* 32156 ( 600) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
        3200, /* 32157 ( 600) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
     1538472, /* 32158 ( 600) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
    35563982, /* 32159 ( 600) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
        3198, /* 32160 ( 600) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
     1433496, /* 32161 ( 600) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  0]  1 */
    34133682, /* 32162 ( 600) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
    34146644, /* 32163 ( 600) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
     1420538, /* 32164 ( 600) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  0]  1 */
    35563980, /* 32165 ( 600) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6] -1 */
    34146642, /* 32166 ( 600) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
     1551758, /* 32167 ( 600) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
    34028708, /* 32168 ( 600) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    34028706, /* 32169 ( 600) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
      121458, /* 32170 ( 600) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  6]  1 */
    35432760, /* 32171 ( 600) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  0] -1 */
      134420, /* 32172 ( 600) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6]  1 */
    34133684, /* 32173 ( 600) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
     1551756, /* 32174 ( 600) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
    35445722, /* 32175 ( 600) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  0] -1 */
    34015424, /* 32176 ( 600) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    35550698, /* 32177 ( 600) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
    34015422, /* 32178 ( 600) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
      134418, /* 32179 ( 600) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  6]  1 */
    35550696, /* 32180 ( 600) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  6] -1 */
       16482, /* 32181 ( 600) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    35445720, /* 32182 ( 600) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  0] -1 */
     1420536, /* 32183 ( 600) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  0]  1 */
     1433498, /* 32184 ( 600) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  0]  1 */
      121460, /* 32185 ( 600) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6]  1 */
       16484, /* 32186 ( 601) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34028706, /* 32187 ( 601) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    34015422, /* 32188 ( 601) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
     1538474, /* 32189 ( 601) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
    35550696, /* 32190 ( 601) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  6] -1 */
     1420538, /* 32191 ( 601) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  0]  1 */
    35563980, /* 32192 ( 601) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6] -1 */
        3200, /* 32193 ( 601) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    35445720, /* 32194 ( 601) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  0] -1 */
    35432760, /* 32195 ( 601) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  0] -1 */
      134420, /* 32196 ( 601) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6]  1 */
    34146642, /* 32197 ( 601) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
     1551758, /* 32198 ( 601) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
    34133682, /* 32199 ( 601) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
     1433498, /* 32200 ( 601) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  0]  1 */
      121460, /* 32201 ( 601) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6]  1 */
       16484, /* 32202 ( 602) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    35432762, /* 32203 ( 602) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  0] -1 */
    34015422, /* 32204 ( 602) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
      134418, /* 32205 ( 602) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  6]  1 */
    35550696, /* 32206 ( 602) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  6] -1 */
       16482, /* 32207 ( 602) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    35432760, /* 32208 ( 602) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  0] -1 */
    34133684, /* 32209 ( 602) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
      134420, /* 32210 ( 602) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6]  1 */
     1551756, /* 32211 ( 602) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
     1433496, /* 32212 ( 602) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  0]  1 */
     1551758, /* 32213 ( 602) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
    34133682, /* 32214 ( 602) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
     1433498, /* 32215 ( 602) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  0]  1 */
    34015424, /* 32216 ( 602) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    35550698, /* 32217 ( 602) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
       16484, /* 32218 ( 603) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34028706, /* 32219 ( 603) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
      134418, /* 32220 ( 603) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  6]  1 */
     1420538, /* 32221 ( 603) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  0]  1 */
    35563980, /* 32222 ( 603) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6] -1 */
     1538472, /* 32223 ( 603) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
    35432760, /* 32224 ( 603) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  0] -1 */
        3198, /* 32225 ( 603) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
     1433496, /* 32226 ( 603) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  0]  1 */
    35445722, /* 32227 ( 603) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  0] -1 */
     1551758, /* 32228 ( 603) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
    34133682, /* 32229 ( 603) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
      121460, /* 32230 ( 603) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6]  1 */
    34015424, /* 32231 ( 603) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    35550698, /* 32232 ( 603) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
    34146644, /* 32233 ( 603) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
       16484, /* 32234 ( 604) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    35432762, /* 32235 ( 604) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  0] -1 */
     1538474, /* 32236 ( 604) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
       16482, /* 32237 ( 604) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
        3200, /* 32238 ( 604) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    35445720, /* 32239 ( 604) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  0] -1 */
     1538472, /* 32240 ( 604) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
    35432760, /* 32241 ( 604) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  0] -1 */
    34133684, /* 32242 ( 604) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
     1551756, /* 32243 ( 604) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
        3198, /* 32244 ( 604) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    35445722, /* 32245 ( 604) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  0] -1 */
    34146642, /* 32246 ( 604) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
     1551758, /* 32247 ( 604) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
    34133682, /* 32248 ( 604) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
    34146644, /* 32249 ( 604) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
       16484, /* 32250 ( 605) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    35432762, /* 32251 ( 605) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  0] -1 */
    34028706, /* 32252 ( 605) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    34015422, /* 32253 ( 605) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
      134418, /* 32254 ( 605) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  6]  1 */
     1538474, /* 32255 ( 605) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
    35550696, /* 32256 ( 605) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  6] -1 */
      121458, /* 32257 ( 605) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  6]  1 */
    35563980, /* 32258 ( 605) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6] -1 */
        3200, /* 32259 ( 605) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34133684, /* 32260 ( 605) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
     1433496, /* 32261 ( 605) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  0]  1 */
     1420536, /* 32262 ( 605) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  0]  1 */
    35445722, /* 32263 ( 605) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  0] -1 */
     1551758, /* 32264 ( 605) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
    34146644, /* 32265 ( 605) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
       16484, /* 32266 ( 606) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
     1538474, /* 32267 ( 606) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
        3200, /* 32268 ( 606) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
     1538472, /* 32269 ( 606) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
    52438874, /* 32270 ( 606) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
        3198, /* 32271 ( 606) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
     1433496, /* 32272 ( 606) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  0]  1 */
    51139796, /* 32273 ( 606) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
    52570094, /* 32274 ( 606) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
     1420538, /* 32275 ( 606) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  0]  1 */
    51034820, /* 32276 ( 606) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  0] -1 */
    51034818, /* 32277 ( 606) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  0] -1 */
    52570092, /* 32278 ( 606) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
     1551758, /* 32279 ( 606) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
      121458, /* 32280 ( 606) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  6]  1 */
      134420, /* 32281 ( 606) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6]  1 */
     1551756, /* 32282 ( 606) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
    51021536, /* 32283 ( 606) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  0] -1 */
    52556810, /* 32284 ( 606) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    52438872, /* 32285 ( 606) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
    52451834, /* 32286 ( 606) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
    52556808, /* 32287 ( 606) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    51139794, /* 32288 ( 606) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6] -1 */
      134418, /* 32289 ( 606) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  6]  1 */
    51152756, /* 32290 ( 606) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
       16482, /* 32291 ( 606) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    51152754, /* 32292 ( 606) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  6] -1 */
    51021534, /* 32293 ( 606) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  0] -1 */
     1420536, /* 32294 ( 606) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  0]  1 */
    52451832, /* 32295 ( 606) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
     1433498, /* 32296 ( 606) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  0]  1 */
      121460, /* 32297 ( 606) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6]  1 */
       16484, /* 32298 ( 607) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
     1538474, /* 32299 ( 607) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
        3200, /* 32300 ( 607) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
     1538472, /* 32301 ( 607) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
    35432600, /* 32302 ( 607) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  0] -1 */
        3198, /* 32303 ( 607) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
     1433496, /* 32304 ( 607) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  0]  1 */
    35432598, /* 32305 ( 607) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  0] -1 */
    35550858, /* 32306 ( 607) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6] -1 */
    35563820, /* 32307 ( 607) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
    34146806, /* 32308 ( 607) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
     1420538, /* 32309 ( 607) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  0]  1 */
    34146804, /* 32310 ( 607) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
    34015584, /* 32311 ( 607) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
     1551758, /* 32312 ( 607) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
    35563818, /* 32313 ( 607) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  6] -1 */
    34028544, /* 32314 ( 607) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    34028546, /* 32315 ( 607) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
      121458, /* 32316 ( 607) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  6]  1 */
    34133522, /* 32317 ( 607) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
      134420, /* 32318 ( 607) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6]  1 */
    34015586, /* 32319 ( 607) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    35550860, /* 32320 ( 607) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
     1551756, /* 32321 ( 607) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
    34133520, /* 32322 ( 607) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
    35445884, /* 32323 ( 607) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  0] -1 */
      134418, /* 32324 ( 607) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  6]  1 */
       16482, /* 32325 ( 607) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    35445882, /* 32326 ( 607) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  0] -1 */
     1420536, /* 32327 ( 607) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  0]  1 */
     1433498, /* 32328 ( 607) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  0]  1 */
      121460, /* 32329 ( 607) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6]  1 */
       16484, /* 32330 ( 608) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
     1538474, /* 32331 ( 608) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
        3200, /* 32332 ( 608) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
     1538472, /* 32333 ( 608) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
        3198, /* 32334 ( 608) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
     1433496, /* 32335 ( 608) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  0]  1 */
    51139634, /* 32336 ( 608) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
    52556970, /* 32337 ( 608) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    51139632, /* 32338 ( 608) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  6] -1 */
    52438712, /* 32339 ( 608) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
    52438710, /* 32340 ( 608) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
     1420538, /* 32341 ( 608) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  0]  1 */
    51034658, /* 32342 ( 608) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  0] -1 */
    52569932, /* 32343 ( 608) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    51021696, /* 32344 ( 608) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  0] -1 */
     1551758, /* 32345 ( 608) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
    51034656, /* 32346 ( 608) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  0] -1 */
    52569930, /* 32347 ( 608) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
      121458, /* 32348 ( 608) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  6]  1 */
      134420, /* 32349 ( 608) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6]  1 */
    52451996, /* 32350 ( 608) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
     1551756, /* 32351 ( 608) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
    51152918, /* 32352 ( 608) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
    51021698, /* 32353 ( 608) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  0] -1 */
    52556972, /* 32354 ( 608) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
      134418, /* 32355 ( 608) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  6]  1 */
       16482, /* 32356 ( 608) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    52451994, /* 32357 ( 608) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
    51152916, /* 32358 ( 608) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6] -1 */
     1420536, /* 32359 ( 608) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  0]  1 */
     1433498, /* 32360 ( 608) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  0]  1 */
      121460, /* 32361 ( 608) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6]  1 */
       16484, /* 32362 ( 599) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
      121458, /* 32363 ( 599) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  6]  1 */
    17127410, /* 32364 ( 599) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
      134418, /* 32365 ( 599) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  6]  1 */
       16482, /* 32366 ( 599) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    17022434, /* 32367 ( 599) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  0]  1 */
        3200, /* 32368 ( 599) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    17127408, /* 32369 ( 599) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  6]  1 */
      121460, /* 32370 ( 599) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6]  1 */
    17140692, /* 32371 ( 599) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6]  1 */
        3198, /* 32372 ( 599) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    17009472, /* 32373 ( 599) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  0]  1 */
    17022432, /* 32374 ( 599) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  0]  1 */
    17140694, /* 32375 ( 599) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
    17009474, /* 32376 ( 599) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  0]  1 */
      134420, /* 32377 ( 599) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6]  1 */
       16484, /* 32378 ( 600) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    51034658, /* 32379 ( 600) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  0] -1 */
    17127410, /* 32380 ( 600) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
        3200, /* 32381 ( 600) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    17127408, /* 32382 ( 600) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  6]  1 */
    51152918, /* 32383 ( 600) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
        3198, /* 32384 ( 600) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    17009472, /* 32385 ( 600) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  0]  1 */
    34146642, /* 32386 ( 600) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
    34133684, /* 32387 ( 600) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    17022434, /* 32388 ( 600) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  0]  1 */
    51152916, /* 32389 ( 600) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6] -1 */
    34133682, /* 32390 ( 600) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
    17140694, /* 32391 ( 600) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
    34028708, /* 32392 ( 600) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    34028706, /* 32393 ( 600) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
      134418, /* 32394 ( 600) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  6]  1 */
    51034656, /* 32395 ( 600) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  0] -1 */
      121460, /* 32396 ( 600) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6]  1 */
    34146644, /* 32397 ( 600) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    17140692, /* 32398 ( 600) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6]  1 */
    51021698, /* 32399 ( 600) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  0] -1 */
    34015424, /* 32400 ( 600) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    51139634, /* 32401 ( 600) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
    34015422, /* 32402 ( 600) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
      121458, /* 32403 ( 600) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  6]  1 */
    51139632, /* 32404 ( 600) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  6] -1 */
       16482, /* 32405 ( 600) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    51021696, /* 32406 ( 600) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  0] -1 */
    17022432, /* 32407 ( 600) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  0]  1 */
    17009474, /* 32408 ( 600) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  0]  1 */
      134420, /* 32409 ( 600) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6]  1 */
       16484, /* 32410 ( 601) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34028706, /* 32411 ( 601) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    34015422, /* 32412 ( 601) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    17127410, /* 32413 ( 601) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
    51139632, /* 32414 ( 601) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  6] -1 */
    17022434, /* 32415 ( 601) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  0]  1 */
    51152916, /* 32416 ( 601) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6] -1 */
        3200, /* 32417 ( 601) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    51021696, /* 32418 ( 601) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  0] -1 */
    51034656, /* 32419 ( 601) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  0] -1 */
      121460, /* 32420 ( 601) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6]  1 */
    34133682, /* 32421 ( 601) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
    17140694, /* 32422 ( 601) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
    34146642, /* 32423 ( 601) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
    17009474, /* 32424 ( 601) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  0]  1 */
      134420, /* 32425 ( 601) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6]  1 */
       16484, /* 32426 ( 602) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    51034658, /* 32427 ( 602) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  0] -1 */
    34015422, /* 32428 ( 602) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
      121458, /* 32429 ( 602) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  6]  1 */
    51139632, /* 32430 ( 602) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  6] -1 */
       16482, /* 32431 ( 602) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    51034656, /* 32432 ( 602) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  0] -1 */
    34146644, /* 32433 ( 602) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
      121460, /* 32434 ( 602) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6]  1 */
    17140692, /* 32435 ( 602) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6]  1 */
    17009472, /* 32436 ( 602) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  0]  1 */
    17140694, /* 32437 ( 602) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
    34146642, /* 32438 ( 602) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
    17009474, /* 32439 ( 602) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  0]  1 */
    34015424, /* 32440 ( 602) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    51139634, /* 32441 ( 602) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
       16484, /* 32442 ( 603) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34028706, /* 32443 ( 603) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
      121458, /* 32444 ( 603) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  6]  1 */
    17022434, /* 32445 ( 603) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  0]  1 */
    51152916, /* 32446 ( 603) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6] -1 */
    17127408, /* 32447 ( 603) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  6]  1 */
    51034656, /* 32448 ( 603) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  0] -1 */
        3198, /* 32449 ( 603) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    17009472, /* 32450 ( 603) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  0]  1 */
    51021698, /* 32451 ( 603) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  0] -1 */
    17140694, /* 32452 ( 603) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
    34146642, /* 32453 ( 603) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
      134420, /* 32454 ( 603) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6]  1 */
    34015424, /* 32455 ( 603) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    51139634, /* 32456 ( 603) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
    34133684, /* 32457 ( 603) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
       16484, /* 32458 ( 604) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    51034658, /* 32459 ( 604) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  0] -1 */
    17127410, /* 32460 ( 604) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
       16482, /* 32461 ( 604) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
        3200, /* 32462 ( 604) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    51021696, /* 32463 ( 604) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  0] -1 */
    17127408, /* 32464 ( 604) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  6]  1 */
    51034656, /* 32465 ( 604) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  0] -1 */
    34146644, /* 32466 ( 604) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    17140692, /* 32467 ( 604) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6]  1 */
        3198, /* 32468 ( 604) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    51021698, /* 32469 ( 604) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  0] -1 */
    34133682, /* 32470 ( 604) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
    17140694, /* 32471 ( 604) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
    34146642, /* 32472 ( 604) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
    34133684, /* 32473 ( 604) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
       16484, /* 32474 ( 605) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    51034658, /* 32475 ( 605) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  0] -1 */
    34028706, /* 32476 ( 605) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    34015422, /* 32477 ( 605) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
      121458, /* 32478 ( 605) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  6]  1 */
    17127410, /* 32479 ( 605) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
    51139632, /* 32480 ( 605) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  6] -1 */
      134418, /* 32481 ( 605) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  6]  1 */
    51152916, /* 32482 ( 605) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6] -1 */
        3200, /* 32483 ( 605) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34146644, /* 32484 ( 605) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    17009472, /* 32485 ( 605) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  0]  1 */
    17022432, /* 32486 ( 605) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  0]  1 */
    51021698, /* 32487 ( 605) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  0] -1 */
    17140694, /* 32488 ( 605) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
    34133684, /* 32489 ( 605) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
       16484, /* 32490 ( 606) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    17127410, /* 32491 ( 606) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
        3200, /* 32492 ( 606) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    17127408, /* 32493 ( 606) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  6]  1 */
    52451834, /* 32494 ( 606) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
        3198, /* 32495 ( 606) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    17009472, /* 32496 ( 606) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  0]  1 */
    35563820, /* 32497 ( 606) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
    52570094, /* 32498 ( 606) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    17022434, /* 32499 ( 606) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  0]  1 */
    35445884, /* 32500 ( 606) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  0] -1 */
    35445882, /* 32501 ( 606) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  0] -1 */
    52570092, /* 32502 ( 606) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    17140694, /* 32503 ( 606) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
      134418, /* 32504 ( 606) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  6]  1 */
      121460, /* 32505 ( 606) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6]  1 */
    17140692, /* 32506 ( 606) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6]  1 */
    35432600, /* 32507 ( 606) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  0] -1 */
    52556810, /* 32508 ( 606) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    52451832, /* 32509 ( 606) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
    52438874, /* 32510 ( 606) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
    52556808, /* 32511 ( 606) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    35563818, /* 32512 ( 606) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  6] -1 */
      121458, /* 32513 ( 606) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  6]  1 */
    35550860, /* 32514 ( 606) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
       16482, /* 32515 ( 606) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    35550858, /* 32516 ( 606) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6] -1 */
    35432598, /* 32517 ( 606) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  0] -1 */
    17022432, /* 32518 ( 606) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  0]  1 */
    52438872, /* 32519 ( 606) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
    17009474, /* 32520 ( 606) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  0]  1 */
      134420, /* 32521 ( 606) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6]  1 */
       16484, /* 32522 ( 607) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    17127410, /* 32523 ( 607) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
        3200, /* 32524 ( 607) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    17127408, /* 32525 ( 607) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  6]  1 */
    51021536, /* 32526 ( 607) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  0] -1 */
        3198, /* 32527 ( 607) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    17009472, /* 32528 ( 607) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  0]  1 */
    51021534, /* 32529 ( 607) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  0] -1 */
    51152754, /* 32530 ( 607) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  6] -1 */
    51139796, /* 32531 ( 607) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
    34146806, /* 32532 ( 607) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    17022434, /* 32533 ( 607) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  0]  1 */
    34146804, /* 32534 ( 607) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
    34028544, /* 32535 ( 607) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    17140694, /* 32536 ( 607) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
    51139794, /* 32537 ( 607) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6] -1 */
    34015584, /* 32538 ( 607) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    34015586, /* 32539 ( 607) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
      134418, /* 32540 ( 607) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  6]  1 */
    34133522, /* 32541 ( 607) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
      121460, /* 32542 ( 607) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6]  1 */
    34028546, /* 32543 ( 607) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    51152756, /* 32544 ( 607) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
    17140692, /* 32545 ( 607) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6]  1 */
    34133520, /* 32546 ( 607) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
    51034820, /* 32547 ( 607) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  0] -1 */
      121458, /* 32548 ( 607) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  6]  1 */
       16482, /* 32549 ( 607) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    51034818, /* 32550 ( 607) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  0] -1 */
    17022432, /* 32551 ( 607) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  0]  1 */
    17009474, /* 32552 ( 607) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  0]  1 */
      134420, /* 32553 ( 607) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6]  1 */
       16484, /* 32554 ( 608) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    17127410, /* 32555 ( 608) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
        3200, /* 32556 ( 608) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    17127408, /* 32557 ( 608) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  6]  1 */
        3198, /* 32558 ( 608) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    17009472, /* 32559 ( 608) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  0]  1 */
    35550698, /* 32560 ( 608) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
    52569930, /* 32561 ( 608) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    35550696, /* 32562 ( 608) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  6] -1 */
    52438712, /* 32563 ( 608) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
    52438710, /* 32564 ( 608) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
    17022434, /* 32565 ( 608) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  0]  1 */
    35432762, /* 32566 ( 608) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  0] -1 */
    52556972, /* 32567 ( 608) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    35445720, /* 32568 ( 608) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  0] -1 */
    17140694, /* 32569 ( 608) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
    35432760, /* 32570 ( 608) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  0] -1 */
    52556970, /* 32571 ( 608) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
      134418, /* 32572 ( 608) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  6]  1 */
      121460, /* 32573 ( 608) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6]  1 */
    52451996, /* 32574 ( 608) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
    17140692, /* 32575 ( 608) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6]  1 */
    35563982, /* 32576 ( 608) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
    35445722, /* 32577 ( 608) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  0] -1 */
    52569932, /* 32578 ( 608) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
      121458, /* 32579 ( 608) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  6]  1 */
       16482, /* 32580 ( 608) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    52451994, /* 32581 ( 608) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
    35563980, /* 32582 ( 608) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6] -1 */
    17022432, /* 32583 ( 608) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  0]  1 */
    17009474, /* 32584 ( 608) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  0]  1 */
      134420, /* 32585 ( 608) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6]  1 */
       16484, /* 32586 ( 599) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    17009472, /* 32587 ( 599) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  0]  1 */
    17140530, /* 32588 ( 599) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  6]  1 */
    17009312, /* 32589 ( 599) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  0]  1 */
        3362, /* 32590 ( 599) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
      134420, /* 32591 ( 599) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6]  1 */
       16320, /* 32592 ( 599) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    17127408, /* 32593 ( 599) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  6]  1 */
    17022594, /* 32594 ( 599) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  0]  1 */
    17127572, /* 32595 ( 599) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
        3198, /* 32596 ( 599) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
      121458, /* 32597 ( 599) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  6]  1 */
      121298, /* 32598 ( 599) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6]  1 */
    17140694, /* 32599 ( 599) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
      134580, /* 32600 ( 599) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  6]  1 */
    17022434, /* 32601 ( 599) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  0]  1 */
       16484, /* 32602 ( 600) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34146644, /* 32603 ( 600) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    17140530, /* 32604 ( 600) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  6]  1 */
       16320, /* 32605 ( 600) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    17127408, /* 32606 ( 600) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  6]  1 */
    51152918, /* 32607 ( 600) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
        3198, /* 32608 ( 600) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
      121458, /* 32609 ( 600) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  6]  1 */
    51021536, /* 32610 ( 600) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  0] -1 */
    51034818, /* 32611 ( 600) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  0] -1 */
      134420, /* 32612 ( 600) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6]  1 */
    51139796, /* 32613 ( 600) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
    51021696, /* 32614 ( 600) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  0] -1 */
    17140694, /* 32615 ( 600) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
    34028708, /* 32616 ( 600) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    34015586, /* 32617 ( 600) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    17009312, /* 32618 ( 600) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  0]  1 */
    34133522, /* 32619 ( 600) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    17022594, /* 32620 ( 600) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  0]  1 */
    51034658, /* 32621 ( 600) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  0] -1 */
    17127572, /* 32622 ( 600) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
    34146804, /* 32623 ( 600) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
    34028544, /* 32624 ( 600) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    51152754, /* 32625 ( 600) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  6] -1 */
    34015422, /* 32626 ( 600) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    17009472, /* 32627 ( 600) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  0]  1 */
    51139632, /* 32628 ( 600) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  6] -1 */
        3362, /* 32629 ( 600) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34133682, /* 32630 ( 600) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
      121298, /* 32631 ( 600) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6]  1 */
      134580, /* 32632 ( 600) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  6]  1 */
    17022434, /* 32633 ( 600) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  0]  1 */
       16484, /* 32634 ( 601) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34015586, /* 32635 ( 601) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    34015422, /* 32636 ( 601) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    17140530, /* 32637 ( 601) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  6]  1 */
    51139632, /* 32638 ( 601) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  6] -1 */
      134420, /* 32639 ( 601) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6]  1 */
    51139796, /* 32640 ( 601) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
       16320, /* 32641 ( 601) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    34133682, /* 32642 ( 601) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
    34133522, /* 32643 ( 601) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    17022594, /* 32644 ( 601) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  0]  1 */
    51021696, /* 32645 ( 601) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  0] -1 */
    17140694, /* 32646 ( 601) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
    51021536, /* 32647 ( 601) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  0] -1 */
      134580, /* 32648 ( 601) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  6]  1 */
    17022434, /* 32649 ( 601) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  0]  1 */
       16484, /* 32650 ( 602) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34146644, /* 32651 ( 602) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    34015422, /* 32652 ( 602) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    17009472, /* 32653 ( 602) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  0]  1 */
    51139632, /* 32654 ( 602) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  6] -1 */
        3362, /* 32655 ( 602) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34133522, /* 32656 ( 602) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    51034658, /* 32657 ( 602) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  0] -1 */
    17022594, /* 32658 ( 602) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  0]  1 */
    17127572, /* 32659 ( 602) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
      121458, /* 32660 ( 602) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  6]  1 */
    17140694, /* 32661 ( 602) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
    51021536, /* 32662 ( 602) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  0] -1 */
      134580, /* 32663 ( 602) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  6]  1 */
    34028544, /* 32664 ( 602) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    51152754, /* 32665 ( 602) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  6] -1 */
       16484, /* 32666 ( 603) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34015586, /* 32667 ( 603) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    17009472, /* 32668 ( 603) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  0]  1 */
      134420, /* 32669 ( 603) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6]  1 */
    51139796, /* 32670 ( 603) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
    17127408, /* 32671 ( 603) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  6]  1 */
    34133522, /* 32672 ( 603) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
        3198, /* 32673 ( 603) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
      121458, /* 32674 ( 603) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  6]  1 */
    34146804, /* 32675 ( 603) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
    17140694, /* 32676 ( 603) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
    51021536, /* 32677 ( 603) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  0] -1 */
    17022434, /* 32678 ( 603) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  0]  1 */
    34028544, /* 32679 ( 603) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    51152754, /* 32680 ( 603) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  6] -1 */
    51034818, /* 32681 ( 603) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  0] -1 */
       16484, /* 32682 ( 604) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34146644, /* 32683 ( 604) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    17140530, /* 32684 ( 604) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  6]  1 */
        3362, /* 32685 ( 604) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
       16320, /* 32686 ( 604) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    34133682, /* 32687 ( 604) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
    17127408, /* 32688 ( 604) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  6]  1 */
    34133522, /* 32689 ( 604) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    51034658, /* 32690 ( 604) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  0] -1 */
    17127572, /* 32691 ( 604) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
        3198, /* 32692 ( 604) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    34146804, /* 32693 ( 604) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
    51021696, /* 32694 ( 604) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  0] -1 */
    17140694, /* 32695 ( 604) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
    51021536, /* 32696 ( 604) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  0] -1 */
    51034818, /* 32697 ( 604) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  0] -1 */
       16484, /* 32698 ( 605) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34146644, /* 32699 ( 605) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    34015586, /* 32700 ( 605) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    34015422, /* 32701 ( 605) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    17009472, /* 32702 ( 605) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  0]  1 */
    17140530, /* 32703 ( 605) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  6]  1 */
    51139632, /* 32704 ( 605) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  6] -1 */
    17009312, /* 32705 ( 605) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  0]  1 */
    51139796, /* 32706 ( 605) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
       16320, /* 32707 ( 605) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    51034658, /* 32708 ( 605) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  0] -1 */
      121458, /* 32709 ( 605) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  6]  1 */
      121298, /* 32710 ( 605) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6]  1 */
    34146804, /* 32711 ( 605) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
    17140694, /* 32712 ( 605) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
    51034818, /* 32713 ( 605) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  0] -1 */
       16484, /* 32714 ( 606) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    17140530, /* 32715 ( 606) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  6]  1 */
       16320, /* 32716 ( 606) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    17127408, /* 32717 ( 606) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  6]  1 */
    35563820, /* 32718 ( 606) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
        3198, /* 32719 ( 606) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
      121458, /* 32720 ( 606) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  6]  1 */
    52451834, /* 32721 ( 606) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
    52570094, /* 32722 ( 606) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
      134420, /* 32723 ( 606) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6]  1 */
    35445884, /* 32724 ( 606) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  0] -1 */
    35432762, /* 32725 ( 606) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  0] -1 */
    52556972, /* 32726 ( 606) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    17140694, /* 32727 ( 606) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
    17009312, /* 32728 ( 606) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  0]  1 */
    17022594, /* 32729 ( 606) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  0]  1 */
    17127572, /* 32730 ( 606) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
    35445720, /* 32731 ( 606) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  0] -1 */
    52569930, /* 32732 ( 606) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    35550698, /* 32733 ( 606) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
    35563980, /* 32734 ( 606) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6] -1 */
    52556808, /* 32735 ( 606) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    52438712, /* 32736 ( 606) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
    17009472, /* 32737 ( 606) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  0]  1 */
    52451994, /* 32738 ( 606) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
        3362, /* 32739 ( 606) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    52438872, /* 32740 ( 606) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
    35432598, /* 32741 ( 606) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  0] -1 */
      121298, /* 32742 ( 606) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6]  1 */
    35550858, /* 32743 ( 606) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6] -1 */
      134580, /* 32744 ( 606) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  6]  1 */
    17022434, /* 32745 ( 606) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  0]  1 */
       16484, /* 32746 ( 607) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    17140530, /* 32747 ( 607) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  6]  1 */
       16320, /* 32748 ( 607) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    17127408, /* 32749 ( 607) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  6]  1 */
    34146642, /* 32750 ( 607) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
        3198, /* 32751 ( 607) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
      121458, /* 32752 ( 607) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  6]  1 */
    34133520, /* 32753 ( 607) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
    51139634, /* 32754 ( 607) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
    51152916, /* 32755 ( 607) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6] -1 */
    51034820, /* 32756 ( 607) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  0] -1 */
      134420, /* 32757 ( 607) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6]  1 */
    51021698, /* 32758 ( 607) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  0] -1 */
    34015424, /* 32759 ( 607) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    17140694, /* 32760 ( 607) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
    51139794, /* 32761 ( 607) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6] -1 */
    34015584, /* 32762 ( 607) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    34028706, /* 32763 ( 607) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    17009312, /* 32764 ( 607) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  0]  1 */
    51034656, /* 32765 ( 607) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  0] -1 */
    17022594, /* 32766 ( 607) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  0]  1 */
    34028546, /* 32767 ( 607) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    51152756, /* 32768 ( 607) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
    17127572, /* 32769 ( 607) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
    51021534, /* 32770 ( 607) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  0] -1 */
    34146806, /* 32771 ( 607) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    17009472, /* 32772 ( 607) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  0]  1 */
        3362, /* 32773 ( 607) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34133684, /* 32774 ( 607) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
      121298, /* 32775 ( 607) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6]  1 */
      134580, /* 32776 ( 607) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  6]  1 */
    17022434, /* 32777 ( 607) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  0]  1 */
       16484, /* 32778 ( 608) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    17140530, /* 32779 ( 608) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  6]  1 */
       16320, /* 32780 ( 608) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    17127408, /* 32781 ( 608) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  6]  1 */
        3198, /* 32782 ( 608) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
      121458, /* 32783 ( 608) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  6]  1 */
    52451832, /* 32784 ( 608) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
    52556810, /* 32785 ( 608) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    52438710, /* 32786 ( 608) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
    35563818, /* 32787 ( 608) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  6] -1 */
    35550696, /* 32788 ( 608) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  6] -1 */
      134420, /* 32789 ( 608) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6]  1 */
    35445882, /* 32790 ( 608) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  0] -1 */
    52570092, /* 32791 ( 608) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    35432600, /* 32792 ( 608) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  0] -1 */
    17140694, /* 32793 ( 608) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
    35432760, /* 32794 ( 608) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  0] -1 */
    52556970, /* 32795 ( 608) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    17009312, /* 32796 ( 608) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  0]  1 */
    17022594, /* 32797 ( 608) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  0]  1 */
    35563982, /* 32798 ( 608) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
    17127572, /* 32799 ( 608) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
    52451996, /* 32800 ( 608) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
    35445722, /* 32801 ( 608) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  0] -1 */
    52569932, /* 32802 ( 608) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    17009472, /* 32803 ( 608) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  0]  1 */
        3362, /* 32804 ( 608) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    35550860, /* 32805 ( 608) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
    52438874, /* 32806 ( 608) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
      121298, /* 32807 ( 608) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6]  1 */
      134580, /* 32808 ( 608) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  6]  1 */
    17022434, /* 32809 ( 608) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  0]  1 */
       16484, /* 32810 ( 609) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
       16320, /* 32811 ( 609) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
        3360, /* 32812 ( 609) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    18426488, /* 32813 ( 609) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
     1551756, /* 32814 ( 609) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
    18426648, /* 32815 ( 609) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
    17127408, /* 32816 ( 609) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  6]  1 */
     1538636, /* 32817 ( 609) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
    17127572, /* 32818 ( 609) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
     1551596, /* 32819 ( 609) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
     1538472, /* 32820 ( 609) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
        3200, /* 32821 ( 609) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    18439772, /* 32822 ( 609) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    17140532, /* 32823 ( 609) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
    18439608, /* 32824 ( 609) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
    17140692, /* 32825 ( 609) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6]  1 */
       16484, /* 32826 ( 610) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    35563980, /* 32827 ( 610) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6] -1 */
    17127408, /* 32828 ( 610) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  6]  1 */
     1538636, /* 32829 ( 610) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
    52451996, /* 32830 ( 610) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
     1538472, /* 32831 ( 610) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
        3200, /* 32832 ( 610) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    52451832, /* 32833 ( 610) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
    52438872, /* 32834 ( 610) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
    34028544, /* 32835 ( 610) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    17127572, /* 32836 ( 610) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
     1551756, /* 32837 ( 610) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
    35563820, /* 32838 ( 610) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
    51152756, /* 32839 ( 610) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
    34015584, /* 32840 ( 610) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    52438712, /* 32841 ( 610) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
    18439772, /* 32842 ( 610) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    34028708, /* 32843 ( 610) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    18439608, /* 32844 ( 610) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
    18426648, /* 32845 ( 610) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
       16320, /* 32846 ( 610) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    51152916, /* 32847 ( 610) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6] -1 */
     1551596, /* 32848 ( 610) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
    17140532, /* 32849 ( 610) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
    35550696, /* 32850 ( 610) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  6] -1 */
    18426488, /* 32851 ( 610) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
        3360, /* 32852 ( 610) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    51139632, /* 32853 ( 610) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  6] -1 */
    35550860, /* 32854 ( 610) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
    34015424, /* 32855 ( 610) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    51139796, /* 32856 ( 610) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
    17140692, /* 32857 ( 610) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6]  1 */
       16484, /* 32858 ( 611) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
       16320, /* 32859 ( 611) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    35550696, /* 32860 ( 611) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  6] -1 */
    51139632, /* 32861 ( 611) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  6] -1 */
    35550860, /* 32862 ( 611) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
     1551756, /* 32863 ( 611) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
    34015424, /* 32864 ( 611) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
     1551596, /* 32865 ( 611) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
    51139796, /* 32866 ( 611) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
    52438872, /* 32867 ( 611) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
    34015584, /* 32868 ( 611) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    52438712, /* 32869 ( 611) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
    18439772, /* 32870 ( 611) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    17140532, /* 32871 ( 611) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
    18439608, /* 32872 ( 611) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
    17140692, /* 32873 ( 611) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6]  1 */
       16484, /* 32874 ( 612) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    35563980, /* 32875 ( 612) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6] -1 */
    35550696, /* 32876 ( 612) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  6] -1 */
    18426488, /* 32877 ( 612) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    51139632, /* 32878 ( 612) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  6] -1 */
    51152916, /* 32879 ( 612) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6] -1 */
     1538636, /* 32880 ( 612) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
     1551596, /* 32881 ( 612) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
        3200, /* 32882 ( 612) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    52451832, /* 32883 ( 612) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
    52438872, /* 32884 ( 612) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
    34015584, /* 32885 ( 612) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    18439772, /* 32886 ( 612) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    17140532, /* 32887 ( 612) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
    34028544, /* 32888 ( 612) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    17127572, /* 32889 ( 612) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
       16484, /* 32890 ( 613) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    18426488, /* 32891 ( 613) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    35550860, /* 32892 ( 613) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
     1551756, /* 32893 ( 613) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
    35563820, /* 32894 ( 613) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
    51152756, /* 32895 ( 613) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
    17127408, /* 32896 ( 613) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  6]  1 */
    51139796, /* 32897 ( 613) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
     1538472, /* 32898 ( 613) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
        3200, /* 32899 ( 613) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    52451832, /* 32900 ( 613) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
    52438872, /* 32901 ( 613) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
    34015584, /* 32902 ( 613) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    18439772, /* 32903 ( 613) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    17140692, /* 32904 ( 613) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6]  1 */
    34028544, /* 32905 ( 613) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
       16484, /* 32906 ( 614) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    35563980, /* 32907 ( 614) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6] -1 */
       16320, /* 32908 ( 614) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    35563820, /* 32909 ( 614) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
    51152756, /* 32910 ( 614) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
    17127408, /* 32911 ( 614) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  6]  1 */
    34015424, /* 32912 ( 614) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    51152916, /* 32913 ( 614) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6] -1 */
     1538636, /* 32914 ( 614) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
     1538472, /* 32915 ( 614) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
    52438872, /* 32916 ( 614) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
    34015584, /* 32917 ( 614) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    52438712, /* 32918 ( 614) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
    18439772, /* 32919 ( 614) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    18439608, /* 32920 ( 614) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
    17127572, /* 32921 ( 614) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
       16484, /* 32922 ( 615) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    35563980, /* 32923 ( 615) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6] -1 */
       16320, /* 32924 ( 615) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    35550696, /* 32925 ( 615) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  6] -1 */
    18426488, /* 32926 ( 615) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    51139632, /* 32927 ( 615) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  6] -1 */
        3360, /* 32928 ( 615) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    35550860, /* 32929 ( 615) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
    18426648, /* 32930 ( 615) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
    35563820, /* 32931 ( 615) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
    51152756, /* 32932 ( 615) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
    51152916, /* 32933 ( 615) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6] -1 */
    51139796, /* 32934 ( 615) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
        3200, /* 32935 ( 615) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    18439772, /* 32936 ( 615) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    18439608, /* 32937 ( 615) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
       16484, /* 32938 ( 616) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    17127408, /* 32939 ( 616) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  6]  1 */
    35445882, /* 32940 ( 616) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  0] -1 */
     1538636, /* 32941 ( 616) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
    34146642, /* 32942 ( 616) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
     1538472, /* 32943 ( 616) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
        3200, /* 32944 ( 616) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    51034818, /* 32945 ( 616) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  0] -1 */
    52556970, /* 32946 ( 616) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    52570094, /* 32947 ( 616) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    17127572, /* 32948 ( 616) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
    51034658, /* 32949 ( 616) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  0] -1 */
    51021698, /* 32950 ( 616) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  0] -1 */
     1551756, /* 32951 ( 616) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
    34133682, /* 32952 ( 616) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
    34146806, /* 32953 ( 616) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    18439772, /* 32954 ( 616) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    35445722, /* 32955 ( 616) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  0] -1 */
    18439608, /* 32956 ( 616) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
    18426648, /* 32957 ( 616) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
       16320, /* 32958 ( 616) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    52569930, /* 32959 ( 616) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
     1551596, /* 32960 ( 616) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
    17140532, /* 32961 ( 616) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
    51021534, /* 32962 ( 616) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  0] -1 */
        3360, /* 32963 ( 616) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    18426488, /* 32964 ( 616) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    52556810, /* 32965 ( 616) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    35432598, /* 32966 ( 616) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  0] -1 */
    35432762, /* 32967 ( 616) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  0] -1 */
    34133522, /* 32968 ( 616) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    17140692, /* 32969 ( 616) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6]  1 */
       16484, /* 32970 ( 617) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    17127408, /* 32971 ( 617) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  6]  1 */
     1538636, /* 32972 ( 617) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
     1538472, /* 32973 ( 617) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
        3200, /* 32974 ( 617) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34133520, /* 32975 ( 617) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
    17127572, /* 32976 ( 617) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
    51034820, /* 32977 ( 617) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  0] -1 */
     1551756, /* 32978 ( 617) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
    34133684, /* 32979 ( 617) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    52556972, /* 32980 ( 617) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    18439772, /* 32981 ( 617) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    35432600, /* 32982 ( 617) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  0] -1 */
    51021536, /* 32983 ( 617) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  0] -1 */
    18439608, /* 32984 ( 617) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
    18426648, /* 32985 ( 617) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
       16320, /* 32986 ( 617) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    34146804, /* 32987 ( 617) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
    52570092, /* 32988 ( 617) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    52556808, /* 32989 ( 617) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    35445884, /* 32990 ( 617) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  0] -1 */
    35445720, /* 32991 ( 617) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  0] -1 */
    51034656, /* 32992 ( 617) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  0] -1 */
     1551596, /* 32993 ( 617) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
    17140532, /* 32994 ( 617) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
    35432760, /* 32995 ( 617) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  0] -1 */
    34146644, /* 32996 ( 617) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    51021696, /* 32997 ( 617) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  0] -1 */
        3360, /* 32998 ( 617) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    18426488, /* 32999 ( 617) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    52569932, /* 33000 ( 617) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    17140692, /* 33001 ( 617) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6]  1 */
       16484, /* 33002 ( 618) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    17127408, /* 33003 ( 618) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  6]  1 */
     1538636, /* 33004 ( 618) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
     1538472, /* 33005 ( 618) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
        3200, /* 33006 ( 618) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    51139794, /* 33007 ( 618) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6] -1 */
    52438710, /* 33008 ( 618) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
    17127572, /* 33009 ( 618) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
    52451834, /* 33010 ( 618) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
    34015422, /* 33011 ( 618) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
     1551756, /* 33012 ( 618) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
    52438874, /* 33013 ( 618) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
    18439772, /* 33014 ( 618) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    18439608, /* 33015 ( 618) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
    18426648, /* 33016 ( 618) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
    34015586, /* 33017 ( 618) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
       16320, /* 33018 ( 618) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    51139634, /* 33019 ( 618) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
    35550698, /* 33020 ( 618) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
    35550858, /* 33021 ( 618) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6] -1 */
    35563982, /* 33022 ( 618) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
    34028546, /* 33023 ( 618) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    51152918, /* 33024 ( 618) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
     1551596, /* 33025 ( 618) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
    52451994, /* 33026 ( 618) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
    17140532, /* 33027 ( 618) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
    34028706, /* 33028 ( 618) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    35563818, /* 33029 ( 618) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  6] -1 */
    51152754, /* 33030 ( 618) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  6] -1 */
        3360, /* 33031 ( 618) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    18426488, /* 33032 ( 618) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    17140692, /* 33033 ( 618) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6]  1 */
       16484, /* 33034 ( 609) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
     1551594, /* 33035 ( 609) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
      121458, /* 33036 ( 609) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  6]  1 */
    17009312, /* 33037 ( 609) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  0]  1 */
     1433658, /* 33038 ( 609) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  0]  1 */
    18544746, /* 33039 ( 609) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
    18426486, /* 33040 ( 609) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
     1538636, /* 33041 ( 609) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
    17127572, /* 33042 ( 609) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
      134420, /* 33043 ( 609) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6]  1 */
        3198, /* 33044 ( 609) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
     1420376, /* 33045 ( 609) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  0]  1 */
    18439772, /* 33046 ( 609) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    18557708, /* 33047 ( 609) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    17140530, /* 33048 ( 609) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  6]  1 */
    17022594, /* 33049 ( 609) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  0]  1 */
       16484, /* 33050 ( 610) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    35445882, /* 33051 ( 610) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  0] -1 */
    18426486, /* 33052 ( 610) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
     1538636, /* 33053 ( 610) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
    52451996, /* 33054 ( 610) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
        3198, /* 33055 ( 610) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
     1420376, /* 33056 ( 610) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  0]  1 */
    51152754, /* 33057 ( 610) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  6] -1 */
    52556970, /* 33058 ( 610) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    35563818, /* 33059 ( 610) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  6] -1 */
    17127572, /* 33060 ( 610) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
     1433658, /* 33061 ( 610) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  0]  1 */
    34146644, /* 33062 ( 610) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    52569932, /* 33063 ( 610) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    34133682, /* 33064 ( 610) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
    51021536, /* 33065 ( 610) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  0] -1 */
    18439772, /* 33066 ( 610) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    34028708, /* 33067 ( 610) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    17140530, /* 33068 ( 610) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  6]  1 */
    18544746, /* 33069 ( 610) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
     1551594, /* 33070 ( 610) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
    51034818, /* 33071 ( 610) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  0] -1 */
      134420, /* 33072 ( 610) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6]  1 */
    18557708, /* 33073 ( 610) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    34015422, /* 33074 ( 610) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    17009312, /* 33075 ( 610) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  0]  1 */
      121458, /* 33076 ( 610) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  6]  1 */
    52438710, /* 33077 ( 610) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
    35550860, /* 33078 ( 610) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
    35432600, /* 33079 ( 610) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  0] -1 */
    51139796, /* 33080 ( 610) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
    17022594, /* 33081 ( 610) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  0]  1 */
       16484, /* 33082 ( 611) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
     1551594, /* 33083 ( 611) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
    34015422, /* 33084 ( 611) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    52438710, /* 33085 ( 611) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
    35550860, /* 33086 ( 611) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
     1433658, /* 33087 ( 611) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  0]  1 */
    35432600, /* 33088 ( 611) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  0] -1 */
      134420, /* 33089 ( 611) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6]  1 */
    51139796, /* 33090 ( 611) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
    52556970, /* 33091 ( 611) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    34133682, /* 33092 ( 611) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
    51021536, /* 33093 ( 611) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  0] -1 */
    18439772, /* 33094 ( 611) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    18557708, /* 33095 ( 611) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    17140530, /* 33096 ( 611) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  6]  1 */
    17022594, /* 33097 ( 611) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  0]  1 */
       16484, /* 33098 ( 612) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    35445882, /* 33099 ( 612) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  0] -1 */
    34015422, /* 33100 ( 612) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    17009312, /* 33101 ( 612) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  0]  1 */
    52438710, /* 33102 ( 612) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
    51034818, /* 33103 ( 612) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  0] -1 */
     1538636, /* 33104 ( 612) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
      134420, /* 33105 ( 612) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6]  1 */
     1420376, /* 33106 ( 612) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  0]  1 */
    51152754, /* 33107 ( 612) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  6] -1 */
    52556970, /* 33108 ( 612) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    34133682, /* 33109 ( 612) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
    18439772, /* 33110 ( 612) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    18557708, /* 33111 ( 612) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    35563818, /* 33112 ( 612) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  6] -1 */
    17127572, /* 33113 ( 612) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
       16484, /* 33114 ( 613) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    17009312, /* 33115 ( 613) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  0]  1 */
    35550860, /* 33116 ( 613) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
     1433658, /* 33117 ( 613) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  0]  1 */
    34146644, /* 33118 ( 613) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    52569932, /* 33119 ( 613) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    18426486, /* 33120 ( 613) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
    51139796, /* 33121 ( 613) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
        3198, /* 33122 ( 613) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
     1420376, /* 33123 ( 613) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  0]  1 */
    51152754, /* 33124 ( 613) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  6] -1 */
    52556970, /* 33125 ( 613) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    34133682, /* 33126 ( 613) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
    18439772, /* 33127 ( 613) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    17022594, /* 33128 ( 613) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  0]  1 */
    35563818, /* 33129 ( 613) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  6] -1 */
       16484, /* 33130 ( 614) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    35445882, /* 33131 ( 614) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  0] -1 */
     1551594, /* 33132 ( 614) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
    34146644, /* 33133 ( 614) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    52569932, /* 33134 ( 614) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    18426486, /* 33135 ( 614) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
    35432600, /* 33136 ( 614) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  0] -1 */
    51034818, /* 33137 ( 614) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  0] -1 */
     1538636, /* 33138 ( 614) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
        3198, /* 33139 ( 614) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    52556970, /* 33140 ( 614) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    34133682, /* 33141 ( 614) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
    51021536, /* 33142 ( 614) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  0] -1 */
    18439772, /* 33143 ( 614) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    17140530, /* 33144 ( 614) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  6]  1 */
    17127572, /* 33145 ( 614) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
       16484, /* 33146 ( 615) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    35445882, /* 33147 ( 615) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  0] -1 */
     1551594, /* 33148 ( 615) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
    34015422, /* 33149 ( 615) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    17009312, /* 33150 ( 615) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  0]  1 */
    52438710, /* 33151 ( 615) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
      121458, /* 33152 ( 615) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  6]  1 */
    35550860, /* 33153 ( 615) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
    18544746, /* 33154 ( 615) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
    34146644, /* 33155 ( 615) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    52569932, /* 33156 ( 615) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    51034818, /* 33157 ( 615) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  0] -1 */
    51139796, /* 33158 ( 615) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
     1420376, /* 33159 ( 615) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  0]  1 */
    18439772, /* 33160 ( 615) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    17140530, /* 33161 ( 615) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  6]  1 */
       16484, /* 33162 ( 616) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    18426486, /* 33163 ( 616) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
    35563980, /* 33164 ( 616) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6] -1 */
     1538636, /* 33165 ( 616) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
    35445720, /* 33166 ( 616) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  0] -1 */
        3198, /* 33167 ( 616) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
     1420376, /* 33168 ( 616) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  0]  1 */
    51152916, /* 33169 ( 616) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6] -1 */
    52438872, /* 33170 ( 616) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
    52570094, /* 33171 ( 616) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    17127572, /* 33172 ( 616) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
    52451834, /* 33173 ( 616) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
    51021698, /* 33174 ( 616) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  0] -1 */
     1433658, /* 33175 ( 616) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  0]  1 */
    34015584, /* 33176 ( 616) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    34146806, /* 33177 ( 616) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    18439772, /* 33178 ( 616) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    34028546, /* 33179 ( 616) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    17140530, /* 33180 ( 616) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  6]  1 */
    18544746, /* 33181 ( 616) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
     1551594, /* 33182 ( 616) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
    51034656, /* 33183 ( 616) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  0] -1 */
      134420, /* 33184 ( 616) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6]  1 */
    18557708, /* 33185 ( 616) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    52556808, /* 33186 ( 616) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
      121458, /* 33187 ( 616) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  6]  1 */
    17009312, /* 33188 ( 616) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  0]  1 */
    51139634, /* 33189 ( 616) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
    34133520, /* 33190 ( 616) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
    35432762, /* 33191 ( 616) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  0] -1 */
    35550698, /* 33192 ( 616) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
    17022594, /* 33193 ( 616) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  0]  1 */
       16484, /* 33194 ( 617) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    18426486, /* 33195 ( 617) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
     1538636, /* 33196 ( 617) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
        3198, /* 33197 ( 617) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
     1420376, /* 33198 ( 617) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  0]  1 */
    35432598, /* 33199 ( 617) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  0] -1 */
    17127572, /* 33200 ( 617) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
    51034820, /* 33201 ( 617) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  0] -1 */
     1433658, /* 33202 ( 617) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  0]  1 */
    34133684, /* 33203 ( 617) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    52556972, /* 33204 ( 617) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    18439772, /* 33205 ( 617) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    34015424, /* 33206 ( 617) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    52438712, /* 33207 ( 617) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
    17140530, /* 33208 ( 617) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  6]  1 */
    18544746, /* 33209 ( 617) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
     1551594, /* 33210 ( 617) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
    34028706, /* 33211 ( 617) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    52451994, /* 33212 ( 617) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
    51021534, /* 33213 ( 617) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  0] -1 */
    35445884, /* 33214 ( 617) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  0] -1 */
    34146642, /* 33215 ( 617) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
    52569930, /* 33216 ( 617) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
      134420, /* 33217 ( 617) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6]  1 */
    18557708, /* 33218 ( 617) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    35550858, /* 33219 ( 617) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6] -1 */
    35563820, /* 33220 ( 617) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
    51139794, /* 33221 ( 617) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6] -1 */
      121458, /* 33222 ( 617) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  6]  1 */
    17009312, /* 33223 ( 617) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  0]  1 */
    51152756, /* 33224 ( 617) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
    17022594, /* 33225 ( 617) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  0]  1 */
       16484, /* 33226 ( 618) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    18426486, /* 33227 ( 618) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
     1538636, /* 33228 ( 618) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
        3198, /* 33229 ( 618) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
     1420376, /* 33230 ( 618) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  0]  1 */
    51021696, /* 33231 ( 618) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  0] -1 */
    51139632, /* 33232 ( 618) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  6] -1 */
    17127572, /* 33233 ( 618) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
    51034658, /* 33234 ( 618) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  0] -1 */
    35550696, /* 33235 ( 618) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  6] -1 */
     1433658, /* 33236 ( 618) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  0]  1 */
    52438874, /* 33237 ( 618) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
    18439772, /* 33238 ( 618) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    17140530, /* 33239 ( 618) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  6]  1 */
    18544746, /* 33240 ( 618) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
    34015586, /* 33241 ( 618) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
     1551594, /* 33242 ( 618) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
    52556810, /* 33243 ( 618) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    34133522, /* 33244 ( 618) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    35432760, /* 33245 ( 618) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  0] -1 */
    35563982, /* 33246 ( 618) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
    35445722, /* 33247 ( 618) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  0] -1 */
    51152918, /* 33248 ( 618) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
      134420, /* 33249 ( 618) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6]  1 */
    52570092, /* 33250 ( 618) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    18557708, /* 33251 ( 618) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    34146804, /* 33252 ( 618) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
    34028544, /* 33253 ( 618) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    52451832, /* 33254 ( 618) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
      121458, /* 33255 ( 618) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  6]  1 */
    17009312, /* 33256 ( 618) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  0]  1 */
    17022594, /* 33257 ( 618) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  0]  1 */
       16484, /* 33258 ( 609) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
        3360, /* 33259 ( 609) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
       16320, /* 33260 ( 609) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    18426488, /* 33261 ( 609) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    17140692, /* 33262 ( 609) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6]  1 */
    18439608, /* 33263 ( 609) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
     1538472, /* 33264 ( 609) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
    17140532, /* 33265 ( 609) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
     1551596, /* 33266 ( 609) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
    17127572, /* 33267 ( 609) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
    17127408, /* 33268 ( 609) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  6]  1 */
        3200, /* 33269 ( 609) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    18439772, /* 33270 ( 609) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
     1538636, /* 33271 ( 609) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
    18426648, /* 33272 ( 609) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
     1551756, /* 33273 ( 609) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
       16484, /* 33274 ( 610) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    51152916, /* 33275 ( 610) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6] -1 */
     1538472, /* 33276 ( 610) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
    17140532, /* 33277 ( 610) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
    52451996, /* 33278 ( 610) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
    17127408, /* 33279 ( 610) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  6]  1 */
        3200, /* 33280 ( 610) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    52438872, /* 33281 ( 610) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
    52451832, /* 33282 ( 610) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
    34015584, /* 33283 ( 610) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
     1551596, /* 33284 ( 610) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
    17140692, /* 33285 ( 610) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6]  1 */
    51139796, /* 33286 ( 610) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
    35550860, /* 33287 ( 610) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
    34028544, /* 33288 ( 610) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    52438712, /* 33289 ( 610) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
    18439772, /* 33290 ( 610) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    34028708, /* 33291 ( 610) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    18426648, /* 33292 ( 610) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
    18439608, /* 33293 ( 610) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
        3360, /* 33294 ( 610) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    35563980, /* 33295 ( 610) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6] -1 */
    17127572, /* 33296 ( 610) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
     1538636, /* 33297 ( 610) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
    51139632, /* 33298 ( 610) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  6] -1 */
    18426488, /* 33299 ( 610) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
       16320, /* 33300 ( 610) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    35550696, /* 33301 ( 610) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  6] -1 */
    51152756, /* 33302 ( 610) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
    34015424, /* 33303 ( 610) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    35563820, /* 33304 ( 610) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
     1551756, /* 33305 ( 610) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
       16484, /* 33306 ( 611) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
        3360, /* 33307 ( 611) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    51139632, /* 33308 ( 611) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  6] -1 */
    35550696, /* 33309 ( 611) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  6] -1 */
    51152756, /* 33310 ( 611) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
    17140692, /* 33311 ( 611) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6]  1 */
    34015424, /* 33312 ( 611) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    17127572, /* 33313 ( 611) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
    35563820, /* 33314 ( 611) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
    52451832, /* 33315 ( 611) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
    34028544, /* 33316 ( 611) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    52438712, /* 33317 ( 611) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
    18439772, /* 33318 ( 611) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
     1538636, /* 33319 ( 611) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
    18426648, /* 33320 ( 611) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
     1551756, /* 33321 ( 611) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
       16484, /* 33322 ( 612) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    51152916, /* 33323 ( 612) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6] -1 */
    51139632, /* 33324 ( 612) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  6] -1 */
    18426488, /* 33325 ( 612) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    35550696, /* 33326 ( 612) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  6] -1 */
    35563980, /* 33327 ( 612) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6] -1 */
    17140532, /* 33328 ( 612) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
    17127572, /* 33329 ( 612) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
        3200, /* 33330 ( 612) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    52438872, /* 33331 ( 612) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
    52451832, /* 33332 ( 612) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
    34028544, /* 33333 ( 612) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    18439772, /* 33334 ( 612) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
     1538636, /* 33335 ( 612) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
    34015584, /* 33336 ( 612) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
     1551596, /* 33337 ( 612) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
       16484, /* 33338 ( 613) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    18426488, /* 33339 ( 613) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    51152756, /* 33340 ( 613) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
    17140692, /* 33341 ( 613) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6]  1 */
    51139796, /* 33342 ( 613) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
    35550860, /* 33343 ( 613) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
     1538472, /* 33344 ( 613) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
    35563820, /* 33345 ( 613) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
    17127408, /* 33346 ( 613) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  6]  1 */
        3200, /* 33347 ( 613) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    52438872, /* 33348 ( 613) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
    52451832, /* 33349 ( 613) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
    34028544, /* 33350 ( 613) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    18439772, /* 33351 ( 613) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
     1551756, /* 33352 ( 613) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
    34015584, /* 33353 ( 613) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
       16484, /* 33354 ( 614) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    51152916, /* 33355 ( 614) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6] -1 */
        3360, /* 33356 ( 614) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    51139796, /* 33357 ( 614) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
    35550860, /* 33358 ( 614) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
     1538472, /* 33359 ( 614) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
    34015424, /* 33360 ( 614) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    35563980, /* 33361 ( 614) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6] -1 */
    17140532, /* 33362 ( 614) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
    17127408, /* 33363 ( 614) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  6]  1 */
    52451832, /* 33364 ( 614) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
    34028544, /* 33365 ( 614) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    52438712, /* 33366 ( 614) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
    18439772, /* 33367 ( 614) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    18426648, /* 33368 ( 614) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
     1551596, /* 33369 ( 614) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
       16484, /* 33370 ( 615) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    51152916, /* 33371 ( 615) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6] -1 */
        3360, /* 33372 ( 615) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    51139632, /* 33373 ( 615) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  6] -1 */
    18426488, /* 33374 ( 615) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    35550696, /* 33375 ( 615) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  6] -1 */
       16320, /* 33376 ( 615) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    51152756, /* 33377 ( 615) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
    18439608, /* 33378 ( 615) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
    51139796, /* 33379 ( 615) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
    35550860, /* 33380 ( 615) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
    35563980, /* 33381 ( 615) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6] -1 */
    35563820, /* 33382 ( 615) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
        3200, /* 33383 ( 615) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    18439772, /* 33384 ( 615) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    18426648, /* 33385 ( 615) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
       16484, /* 33386 ( 616) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
     1538472, /* 33387 ( 616) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
    51034818, /* 33388 ( 616) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  0] -1 */
    17140532, /* 33389 ( 616) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
    34133682, /* 33390 ( 616) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
    17127408, /* 33391 ( 616) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  6]  1 */
        3200, /* 33392 ( 616) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    35445882, /* 33393 ( 616) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  0] -1 */
    52569930, /* 33394 ( 616) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    52570094, /* 33395 ( 616) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
     1551596, /* 33396 ( 616) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
    35432762, /* 33397 ( 616) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  0] -1 */
    35445722, /* 33398 ( 616) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  0] -1 */
    17140692, /* 33399 ( 616) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6]  1 */
    34146642, /* 33400 ( 616) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
    34146806, /* 33401 ( 616) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    18439772, /* 33402 ( 616) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    51021698, /* 33403 ( 616) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  0] -1 */
    18426648, /* 33404 ( 616) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
    18439608, /* 33405 ( 616) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
        3360, /* 33406 ( 616) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    52556970, /* 33407 ( 616) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    17127572, /* 33408 ( 616) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
     1538636, /* 33409 ( 616) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
    35432598, /* 33410 ( 616) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  0] -1 */
       16320, /* 33411 ( 616) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    18426488, /* 33412 ( 616) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    52556810, /* 33413 ( 616) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    51021534, /* 33414 ( 616) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  0] -1 */
    51034658, /* 33415 ( 616) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  0] -1 */
    34133522, /* 33416 ( 616) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
     1551756, /* 33417 ( 616) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
       16484, /* 33418 ( 617) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
     1538472, /* 33419 ( 617) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
    17140532, /* 33420 ( 617) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
    17127408, /* 33421 ( 617) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  6]  1 */
        3200, /* 33422 ( 617) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34133520, /* 33423 ( 617) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
     1551596, /* 33424 ( 617) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
    35445884, /* 33425 ( 617) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  0] -1 */
    17140692, /* 33426 ( 617) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6]  1 */
    34146644, /* 33427 ( 617) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    52569932, /* 33428 ( 617) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    18439772, /* 33429 ( 617) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    51021536, /* 33430 ( 617) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  0] -1 */
    35432600, /* 33431 ( 617) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  0] -1 */
    18426648, /* 33432 ( 617) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
    18439608, /* 33433 ( 617) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
        3360, /* 33434 ( 617) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    34146804, /* 33435 ( 617) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
    52570092, /* 33436 ( 617) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    52556808, /* 33437 ( 617) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    51034820, /* 33438 ( 617) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  0] -1 */
    51021696, /* 33439 ( 617) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  0] -1 */
    35432760, /* 33440 ( 617) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  0] -1 */
    17127572, /* 33441 ( 617) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
     1538636, /* 33442 ( 617) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
    51034656, /* 33443 ( 617) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  0] -1 */
    34133684, /* 33444 ( 617) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    35445720, /* 33445 ( 617) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  0] -1 */
       16320, /* 33446 ( 617) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    18426488, /* 33447 ( 617) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    52556972, /* 33448 ( 617) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
     1551756, /* 33449 ( 617) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
       16484, /* 33450 ( 618) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
     1538472, /* 33451 ( 618) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
    17140532, /* 33452 ( 618) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
    17127408, /* 33453 ( 618) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  6]  1 */
        3200, /* 33454 ( 618) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    35563818, /* 33455 ( 618) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  6] -1 */
    52438710, /* 33456 ( 618) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
     1551596, /* 33457 ( 618) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
    52438874, /* 33458 ( 618) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
    34015422, /* 33459 ( 618) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    17140692, /* 33460 ( 618) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6]  1 */
    52451834, /* 33461 ( 618) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
    18439772, /* 33462 ( 618) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    18426648, /* 33463 ( 618) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
    18439608, /* 33464 ( 618) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
    34028546, /* 33465 ( 618) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
        3360, /* 33466 ( 618) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    35550698, /* 33467 ( 618) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
    51139634, /* 33468 ( 618) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
    51152754, /* 33469 ( 618) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  6] -1 */
    51152918, /* 33470 ( 618) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
    34015586, /* 33471 ( 618) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    35563982, /* 33472 ( 618) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
    17127572, /* 33473 ( 618) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
    52451994, /* 33474 ( 618) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
     1538636, /* 33475 ( 618) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
    34028706, /* 33476 ( 618) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    51139794, /* 33477 ( 618) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6] -1 */
    35550858, /* 33478 ( 618) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6] -1 */
       16320, /* 33479 ( 618) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    18426488, /* 33480 ( 618) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
     1551756, /* 33481 ( 618) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
       16484, /* 33482 ( 609) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    17127570, /* 33483 ( 609) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6]  1 */
      134418, /* 33484 ( 609) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  6]  1 */
     1420376, /* 33485 ( 609) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  0]  1 */
    17022594, /* 33486 ( 609) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  0]  1 */
    18557706, /* 33487 ( 609) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
    18426486, /* 33488 ( 609) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
    17140532, /* 33489 ( 609) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
     1551596, /* 33490 ( 609) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
      121460, /* 33491 ( 609) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6]  1 */
        3198, /* 33492 ( 609) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    17009312, /* 33493 ( 609) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  0]  1 */
    18439772, /* 33494 ( 609) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    18544748, /* 33495 ( 609) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
     1538634, /* 33496 ( 609) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
     1433658, /* 33497 ( 609) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  0]  1 */
       16484, /* 33498 ( 610) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    51034818, /* 33499 ( 610) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  0] -1 */
    18426486, /* 33500 ( 610) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
    17140532, /* 33501 ( 610) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
    52451996, /* 33502 ( 610) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
        3198, /* 33503 ( 610) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    17009312, /* 33504 ( 610) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  0]  1 */
    35550858, /* 33505 ( 610) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6] -1 */
    52569930, /* 33506 ( 610) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    51139794, /* 33507 ( 610) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6] -1 */
     1551596, /* 33508 ( 610) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
    17022594, /* 33509 ( 610) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  0]  1 */
    34133684, /* 33510 ( 610) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    52556972, /* 33511 ( 610) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    34146642, /* 33512 ( 610) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
    35432600, /* 33513 ( 610) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  0] -1 */
    18439772, /* 33514 ( 610) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    34028708, /* 33515 ( 610) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
     1538634, /* 33516 ( 610) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
    18557706, /* 33517 ( 610) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
    17127570, /* 33518 ( 610) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6]  1 */
    35445882, /* 33519 ( 610) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  0] -1 */
      121460, /* 33520 ( 610) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6]  1 */
    18544748, /* 33521 ( 610) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    34015422, /* 33522 ( 610) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
     1420376, /* 33523 ( 610) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  0]  1 */
      134418, /* 33524 ( 610) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  6]  1 */
    52438710, /* 33525 ( 610) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
    51152756, /* 33526 ( 610) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
    51021536, /* 33527 ( 610) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  0] -1 */
    35563820, /* 33528 ( 610) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
     1433658, /* 33529 ( 610) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  0]  1 */
       16484, /* 33530 ( 611) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    17127570, /* 33531 ( 611) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6]  1 */
    34015422, /* 33532 ( 611) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    52438710, /* 33533 ( 611) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
    51152756, /* 33534 ( 611) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
    17022594, /* 33535 ( 611) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  0]  1 */
    51021536, /* 33536 ( 611) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  0] -1 */
      121460, /* 33537 ( 611) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6]  1 */
    35563820, /* 33538 ( 611) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
    52569930, /* 33539 ( 611) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    34146642, /* 33540 ( 611) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
    35432600, /* 33541 ( 611) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  0] -1 */
    18439772, /* 33542 ( 611) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    18544748, /* 33543 ( 611) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
     1538634, /* 33544 ( 611) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
     1433658, /* 33545 ( 611) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  0]  1 */
       16484, /* 33546 ( 612) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    51034818, /* 33547 ( 612) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  0] -1 */
    34015422, /* 33548 ( 612) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
     1420376, /* 33549 ( 612) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  0]  1 */
    52438710, /* 33550 ( 612) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
    35445882, /* 33551 ( 612) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  0] -1 */
    17140532, /* 33552 ( 612) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
      121460, /* 33553 ( 612) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6]  1 */
    17009312, /* 33554 ( 612) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  0]  1 */
    35550858, /* 33555 ( 612) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6] -1 */
    52569930, /* 33556 ( 612) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    34146642, /* 33557 ( 612) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
    18439772, /* 33558 ( 612) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    18544748, /* 33559 ( 612) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    51139794, /* 33560 ( 612) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6] -1 */
     1551596, /* 33561 ( 612) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
       16484, /* 33562 ( 613) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
     1420376, /* 33563 ( 613) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  0]  1 */
    51152756, /* 33564 ( 613) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
    17022594, /* 33565 ( 613) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  0]  1 */
    34133684, /* 33566 ( 613) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    52556972, /* 33567 ( 613) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    18426486, /* 33568 ( 613) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
    35563820, /* 33569 ( 613) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
        3198, /* 33570 ( 613) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    17009312, /* 33571 ( 613) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  0]  1 */
    35550858, /* 33572 ( 613) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6] -1 */
    52569930, /* 33573 ( 613) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    34146642, /* 33574 ( 613) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
    18439772, /* 33575 ( 613) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
     1433658, /* 33576 ( 613) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  0]  1 */
    51139794, /* 33577 ( 613) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6] -1 */
       16484, /* 33578 ( 614) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    51034818, /* 33579 ( 614) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  0] -1 */
    17127570, /* 33580 ( 614) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6]  1 */
    34133684, /* 33581 ( 614) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    52556972, /* 33582 ( 614) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    18426486, /* 33583 ( 614) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
    51021536, /* 33584 ( 614) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  0] -1 */
    35445882, /* 33585 ( 614) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  0] -1 */
    17140532, /* 33586 ( 614) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
        3198, /* 33587 ( 614) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    52569930, /* 33588 ( 614) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    34146642, /* 33589 ( 614) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
    35432600, /* 33590 ( 614) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  0] -1 */
    18439772, /* 33591 ( 614) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
     1538634, /* 33592 ( 614) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
     1551596, /* 33593 ( 614) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
       16484, /* 33594 ( 615) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    51034818, /* 33595 ( 615) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  0] -1 */
    17127570, /* 33596 ( 615) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6]  1 */
    34015422, /* 33597 ( 615) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
     1420376, /* 33598 ( 615) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  0]  1 */
    52438710, /* 33599 ( 615) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
      134418, /* 33600 ( 615) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  6]  1 */
    51152756, /* 33601 ( 615) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
    18557706, /* 33602 ( 615) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
    34133684, /* 33603 ( 615) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    52556972, /* 33604 ( 615) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    35445882, /* 33605 ( 615) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  0] -1 */
    35563820, /* 33606 ( 615) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
    17009312, /* 33607 ( 615) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  0]  1 */
    18439772, /* 33608 ( 615) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
     1538634, /* 33609 ( 615) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
       16484, /* 33610 ( 616) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    18426486, /* 33611 ( 616) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
    51152916, /* 33612 ( 616) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6] -1 */
    17140532, /* 33613 ( 616) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
    51021696, /* 33614 ( 616) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  0] -1 */
        3198, /* 33615 ( 616) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    17009312, /* 33616 ( 616) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  0]  1 */
    35563980, /* 33617 ( 616) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6] -1 */
    52451832, /* 33618 ( 616) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
    52570094, /* 33619 ( 616) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
     1551596, /* 33620 ( 616) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
    52438874, /* 33621 ( 616) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
    35445722, /* 33622 ( 616) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  0] -1 */
    17022594, /* 33623 ( 616) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  0]  1 */
    34028544, /* 33624 ( 616) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    34146806, /* 33625 ( 616) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    18439772, /* 33626 ( 616) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    34015586, /* 33627 ( 616) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
     1538634, /* 33628 ( 616) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
    18557706, /* 33629 ( 616) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
    17127570, /* 33630 ( 616) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6]  1 */
    35432760, /* 33631 ( 616) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  0] -1 */
      121460, /* 33632 ( 616) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6]  1 */
    18544748, /* 33633 ( 616) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    52556808, /* 33634 ( 616) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
      134418, /* 33635 ( 616) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  6]  1 */
     1420376, /* 33636 ( 616) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  0]  1 */
    35550698, /* 33637 ( 616) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
    34133520, /* 33638 ( 616) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
    51034658, /* 33639 ( 616) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  0] -1 */
    51139634, /* 33640 ( 616) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
     1433658, /* 33641 ( 616) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  0]  1 */
       16484, /* 33642 ( 617) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    18426486, /* 33643 ( 617) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
    17140532, /* 33644 ( 617) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
        3198, /* 33645 ( 617) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    17009312, /* 33646 ( 617) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  0]  1 */
    51021534, /* 33647 ( 617) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  0] -1 */
     1551596, /* 33648 ( 617) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
    35445884, /* 33649 ( 617) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  0] -1 */
    17022594, /* 33650 ( 617) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  0]  1 */
    34146644, /* 33651 ( 617) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    52569932, /* 33652 ( 617) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    18439772, /* 33653 ( 617) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    34015424, /* 33654 ( 617) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    52438712, /* 33655 ( 617) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
     1538634, /* 33656 ( 617) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
    18557706, /* 33657 ( 617) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
    17127570, /* 33658 ( 617) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6]  1 */
    34028706, /* 33659 ( 617) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    52451994, /* 33660 ( 617) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
    35432598, /* 33661 ( 617) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  0] -1 */
    51034820, /* 33662 ( 617) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  0] -1 */
    34133682, /* 33663 ( 617) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
    52556970, /* 33664 ( 617) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
      121460, /* 33665 ( 617) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6]  1 */
    18544748, /* 33666 ( 617) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    51152754, /* 33667 ( 617) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  6] -1 */
    51139796, /* 33668 ( 617) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
    35563818, /* 33669 ( 617) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  6] -1 */
      134418, /* 33670 ( 617) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  6]  1 */
     1420376, /* 33671 ( 617) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  0]  1 */
    35550860, /* 33672 ( 617) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
     1433658, /* 33673 ( 617) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  0]  1 */
       16484, /* 33674 ( 618) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    18426486, /* 33675 ( 618) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
    17140532, /* 33676 ( 618) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
        3198, /* 33677 ( 618) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    17009312, /* 33678 ( 618) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  0]  1 */
    35445720, /* 33679 ( 618) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  0] -1 */
    35550696, /* 33680 ( 618) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  6] -1 */
     1551596, /* 33681 ( 618) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
    35432762, /* 33682 ( 618) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  0] -1 */
    51139632, /* 33683 ( 618) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  6] -1 */
    17022594, /* 33684 ( 618) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  0]  1 */
    52451834, /* 33685 ( 618) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
    18439772, /* 33686 ( 618) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
     1538634, /* 33687 ( 618) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
    18557706, /* 33688 ( 618) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
    34028546, /* 33689 ( 618) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    17127570, /* 33690 ( 618) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6]  1 */
    52556810, /* 33691 ( 618) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    34133522, /* 33692 ( 618) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    51034656, /* 33693 ( 618) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  0] -1 */
    51152918, /* 33694 ( 618) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
    51021698, /* 33695 ( 618) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  0] -1 */
    35563982, /* 33696 ( 618) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
      121460, /* 33697 ( 618) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6]  1 */
    52570092, /* 33698 ( 618) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    18544748, /* 33699 ( 618) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    34146804, /* 33700 ( 618) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
    34015584, /* 33701 ( 618) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    52438872, /* 33702 ( 618) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
      134418, /* 33703 ( 618) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  6]  1 */
     1420376, /* 33704 ( 618) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  0]  1 */
     1433658, /* 33705 ( 618) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  0]  1 */
       16484, /* 33706 ( 609) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
        3360, /* 33707 ( 609) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
        3200, /* 33708 ( 609) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
     1551594, /* 33709 ( 609) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
    17127572, /* 33710 ( 609) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
     1538474, /* 33711 ( 609) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
    18426486, /* 33712 ( 609) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
    17140532, /* 33713 ( 609) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
    18439610, /* 33714 ( 609) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    17140692, /* 33715 ( 609) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6]  1 */
    17127408, /* 33716 ( 609) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  6]  1 */
       16320, /* 33717 ( 609) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
     1551758, /* 33718 ( 609) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
    18439770, /* 33719 ( 609) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
     1538634, /* 33720 ( 609) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
    18426650, /* 33721 ( 609) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
       16484, /* 33722 ( 610) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    51139796, /* 33723 ( 610) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
    18426486, /* 33724 ( 610) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
    17140532, /* 33725 ( 610) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
    35563982, /* 33726 ( 610) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
    17127408, /* 33727 ( 610) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  6]  1 */
       16320, /* 33728 ( 610) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    35550858, /* 33729 ( 610) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6] -1 */
    35550698, /* 33730 ( 610) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
    34015584, /* 33731 ( 610) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    18439610, /* 33732 ( 610) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    17127572, /* 33733 ( 610) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
    51152916, /* 33734 ( 610) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6] -1 */
    52451994, /* 33735 ( 610) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
    34015424, /* 33736 ( 610) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    35563818, /* 33737 ( 610) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  6] -1 */
     1551758, /* 33738 ( 610) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
    34028708, /* 33739 ( 610) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
     1538634, /* 33740 ( 610) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
     1538474, /* 33741 ( 610) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
        3360, /* 33742 ( 610) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    52438874, /* 33743 ( 610) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
    17140692, /* 33744 ( 610) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6]  1 */
    18439770, /* 33745 ( 610) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
    51139632, /* 33746 ( 610) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  6] -1 */
     1551594, /* 33747 ( 610) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
        3200, /* 33748 ( 610) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    52438710, /* 33749 ( 610) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
    51152756, /* 33750 ( 610) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
    34028544, /* 33751 ( 610) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    52451834, /* 33752 ( 610) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
    18426650, /* 33753 ( 610) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
       16484, /* 33754 ( 611) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
        3360, /* 33755 ( 611) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    51139632, /* 33756 ( 611) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  6] -1 */
    52438710, /* 33757 ( 611) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
    51152756, /* 33758 ( 611) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
    17127572, /* 33759 ( 611) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
    34028544, /* 33760 ( 611) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    17140692, /* 33761 ( 611) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6]  1 */
    52451834, /* 33762 ( 611) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
    35550698, /* 33763 ( 611) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
    34015424, /* 33764 ( 611) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    35563818, /* 33765 ( 611) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  6] -1 */
     1551758, /* 33766 ( 611) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
    18439770, /* 33767 ( 611) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
     1538634, /* 33768 ( 611) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
    18426650, /* 33769 ( 611) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
       16484, /* 33770 ( 612) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    51139796, /* 33771 ( 612) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
    51139632, /* 33772 ( 612) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  6] -1 */
     1551594, /* 33773 ( 612) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
    52438710, /* 33774 ( 612) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
    52438874, /* 33775 ( 612) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
    17140532, /* 33776 ( 612) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
    17140692, /* 33777 ( 612) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6]  1 */
       16320, /* 33778 ( 612) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    35550858, /* 33779 ( 612) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6] -1 */
    35550698, /* 33780 ( 612) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
    34015424, /* 33781 ( 612) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
     1551758, /* 33782 ( 612) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
    18439770, /* 33783 ( 612) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
    34015584, /* 33784 ( 612) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    18439610, /* 33785 ( 612) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
       16484, /* 33786 ( 613) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
     1551594, /* 33787 ( 613) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
    51152756, /* 33788 ( 613) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
    17127572, /* 33789 ( 613) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
    51152916, /* 33790 ( 613) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6] -1 */
    52451994, /* 33791 ( 613) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
    18426486, /* 33792 ( 613) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
    52451834, /* 33793 ( 613) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
    17127408, /* 33794 ( 613) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  6]  1 */
       16320, /* 33795 ( 613) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    35550858, /* 33796 ( 613) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6] -1 */
    35550698, /* 33797 ( 613) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
    34015424, /* 33798 ( 613) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
     1551758, /* 33799 ( 613) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
    18426650, /* 33800 ( 613) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    34015584, /* 33801 ( 613) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
       16484, /* 33802 ( 614) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    51139796, /* 33803 ( 614) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
        3360, /* 33804 ( 614) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    51152916, /* 33805 ( 614) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6] -1 */
    52451994, /* 33806 ( 614) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
    18426486, /* 33807 ( 614) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
    34028544, /* 33808 ( 614) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    52438874, /* 33809 ( 614) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
    17140532, /* 33810 ( 614) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
    17127408, /* 33811 ( 614) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  6]  1 */
    35550698, /* 33812 ( 614) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
    34015424, /* 33813 ( 614) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    35563818, /* 33814 ( 614) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  6] -1 */
     1551758, /* 33815 ( 614) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
     1538634, /* 33816 ( 614) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
    18439610, /* 33817 ( 614) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
       16484, /* 33818 ( 615) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    51139796, /* 33819 ( 615) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
        3360, /* 33820 ( 615) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    51139632, /* 33821 ( 615) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  6] -1 */
     1551594, /* 33822 ( 615) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
    52438710, /* 33823 ( 615) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
        3200, /* 33824 ( 615) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    51152756, /* 33825 ( 615) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
     1538474, /* 33826 ( 615) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
    51152916, /* 33827 ( 615) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6] -1 */
    52451994, /* 33828 ( 615) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
    52438874, /* 33829 ( 615) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
    52451834, /* 33830 ( 615) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
       16320, /* 33831 ( 615) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
     1551758, /* 33832 ( 615) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
     1538634, /* 33833 ( 615) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
       16484, /* 33834 ( 616) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    18426486, /* 33835 ( 616) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
    34133684, /* 33836 ( 616) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    17140532, /* 33837 ( 616) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
    51021696, /* 33838 ( 616) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  0] -1 */
    17127408, /* 33839 ( 616) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  6]  1 */
       16320, /* 33840 ( 616) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    35432762, /* 33841 ( 616) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  0] -1 */
    52556810, /* 33842 ( 616) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    52570094, /* 33843 ( 616) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    18439610, /* 33844 ( 616) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    35445882, /* 33845 ( 616) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  0] -1 */
    35445722, /* 33846 ( 616) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  0] -1 */
    17127572, /* 33847 ( 616) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
    51021536, /* 33848 ( 616) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  0] -1 */
    51034820, /* 33849 ( 616) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  0] -1 */
     1551758, /* 33850 ( 616) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
    34146804, /* 33851 ( 616) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
     1538634, /* 33852 ( 616) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
     1538474, /* 33853 ( 616) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
        3360, /* 33854 ( 616) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    52556970, /* 33855 ( 616) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    17140692, /* 33856 ( 616) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6]  1 */
    18439770, /* 33857 ( 616) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
    35432598, /* 33858 ( 616) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  0] -1 */
        3200, /* 33859 ( 616) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
     1551594, /* 33860 ( 616) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
    52569930, /* 33861 ( 616) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    34133520, /* 33862 ( 616) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
    34146644, /* 33863 ( 616) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    51034656, /* 33864 ( 616) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  0] -1 */
    18426650, /* 33865 ( 616) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
       16484, /* 33866 ( 617) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    18426486, /* 33867 ( 617) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
    17140532, /* 33868 ( 617) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
    17127408, /* 33869 ( 617) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  6]  1 */
       16320, /* 33870 ( 617) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    51021534, /* 33871 ( 617) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  0] -1 */
    18439610, /* 33872 ( 617) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    35445884, /* 33873 ( 617) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  0] -1 */
    17127572, /* 33874 ( 617) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
    51034658, /* 33875 ( 617) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  0] -1 */
    52569932, /* 33876 ( 617) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
     1551758, /* 33877 ( 617) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
    34146642, /* 33878 ( 617) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
    35445720, /* 33879 ( 617) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  0] -1 */
     1538634, /* 33880 ( 617) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
     1538474, /* 33881 ( 617) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
        3360, /* 33882 ( 617) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    51021698, /* 33883 ( 617) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  0] -1 */
    52556972, /* 33884 ( 617) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    52556808, /* 33885 ( 617) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    34146806, /* 33886 ( 617) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    34133682, /* 33887 ( 617) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
    35432760, /* 33888 ( 617) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  0] -1 */
    17140692, /* 33889 ( 617) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6]  1 */
    18439770, /* 33890 ( 617) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
    34133522, /* 33891 ( 617) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    51034818, /* 33892 ( 617) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  0] -1 */
    35432600, /* 33893 ( 617) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  0] -1 */
        3200, /* 33894 ( 617) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
     1551594, /* 33895 ( 617) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
    52570092, /* 33896 ( 617) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    18426650, /* 33897 ( 617) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
       16484, /* 33898 ( 618) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    18426486, /* 33899 ( 618) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
    17140532, /* 33900 ( 618) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
    17127408, /* 33901 ( 618) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  6]  1 */
       16320, /* 33902 ( 618) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    52438712, /* 33903 ( 618) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
    35550696, /* 33904 ( 618) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  6] -1 */
    18439610, /* 33905 ( 618) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    35563980, /* 33906 ( 618) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6] -1 */
    34015422, /* 33907 ( 618) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    17127572, /* 33908 ( 618) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
    35563820, /* 33909 ( 618) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
     1551758, /* 33910 ( 618) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
     1538634, /* 33911 ( 618) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
     1538474, /* 33912 ( 618) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
    34028546, /* 33913 ( 618) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
        3360, /* 33914 ( 618) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    52451832, /* 33915 ( 618) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
    51152754, /* 33916 ( 618) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  6] -1 */
    51139634, /* 33917 ( 618) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
    51152918, /* 33918 ( 618) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
    34028706, /* 33919 ( 618) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    52451996, /* 33920 ( 618) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
    17140692, /* 33921 ( 618) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6]  1 */
    35550860, /* 33922 ( 618) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
    18439770, /* 33923 ( 618) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
    34015586, /* 33924 ( 618) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    51139794, /* 33925 ( 618) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6] -1 */
    52438872, /* 33926 ( 618) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
        3200, /* 33927 ( 618) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
     1551594, /* 33928 ( 618) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
    18426650, /* 33929 ( 618) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
       16484, /* 33930 ( 609) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    17127570, /* 33931 ( 609) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6]  1 */
    17009312, /* 33932 ( 609) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  0]  1 */
     1433496, /* 33933 ( 609) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  0]  1 */
      121460, /* 33934 ( 609) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6]  1 */
    18544586, /* 33935 ( 609) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
     1538472, /* 33936 ( 609) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
    17140532, /* 33937 ( 609) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
    18439610, /* 33938 ( 609) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    17022594, /* 33939 ( 609) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  0]  1 */
        3198, /* 33940 ( 609) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
      134418, /* 33941 ( 609) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  6]  1 */
     1551758, /* 33942 ( 609) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
    18557868, /* 33943 ( 609) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
    18426648, /* 33944 ( 609) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
     1420538, /* 33945 ( 609) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  0]  1 */
       16484, /* 33946 ( 610) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34133684, /* 33947 ( 610) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
     1538472, /* 33948 ( 610) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
    17140532, /* 33949 ( 610) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
    35563982, /* 33950 ( 610) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
        3198, /* 33951 ( 610) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
      134418, /* 33952 ( 610) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  6]  1 */
    52438872, /* 33953 ( 610) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
    52556810, /* 33954 ( 610) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    51139794, /* 33955 ( 610) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6] -1 */
    18439610, /* 33956 ( 610) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
      121460, /* 33957 ( 610) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6]  1 */
    51034818, /* 33958 ( 610) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  0] -1 */
    52570092, /* 33959 ( 610) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    51021536, /* 33960 ( 610) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  0] -1 */
    35445720, /* 33961 ( 610) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  0] -1 */
     1551758, /* 33962 ( 610) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
    34028708, /* 33963 ( 610) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    18426648, /* 33964 ( 610) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
    18544586, /* 33965 ( 610) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    17127570, /* 33966 ( 610) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6]  1 */
    35432762, /* 33967 ( 610) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  0] -1 */
    17022594, /* 33968 ( 610) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  0]  1 */
    18557868, /* 33969 ( 610) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
    34015422, /* 33970 ( 610) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
     1433496, /* 33971 ( 610) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  0]  1 */
    17009312, /* 33972 ( 610) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  0]  1 */
    35550696, /* 33973 ( 610) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  6] -1 */
    51152756, /* 33974 ( 610) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
    34146642, /* 33975 ( 610) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
    52451834, /* 33976 ( 610) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
     1420538, /* 33977 ( 610) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  0]  1 */
       16484, /* 33978 ( 611) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    17127570, /* 33979 ( 611) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6]  1 */
    34015422, /* 33980 ( 611) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    35550696, /* 33981 ( 611) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  6] -1 */
    51152756, /* 33982 ( 611) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
      121460, /* 33983 ( 611) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6]  1 */
    34146642, /* 33984 ( 611) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
    17022594, /* 33985 ( 611) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  0]  1 */
    52451834, /* 33986 ( 611) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
    52556810, /* 33987 ( 611) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    51021536, /* 33988 ( 611) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  0] -1 */
    35445720, /* 33989 ( 611) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  0] -1 */
     1551758, /* 33990 ( 611) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
    18557868, /* 33991 ( 611) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
    18426648, /* 33992 ( 611) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
     1420538, /* 33993 ( 611) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  0]  1 */
       16484, /* 33994 ( 612) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34133684, /* 33995 ( 612) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    34015422, /* 33996 ( 612) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
     1433496, /* 33997 ( 612) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  0]  1 */
    35550696, /* 33998 ( 612) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  6] -1 */
    35432762, /* 33999 ( 612) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  0] -1 */
    17140532, /* 34000 ( 612) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
    17022594, /* 34001 ( 612) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  0]  1 */
      134418, /* 34002 ( 612) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  6]  1 */
    52438872, /* 34003 ( 612) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
    52556810, /* 34004 ( 612) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    51021536, /* 34005 ( 612) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  0] -1 */
     1551758, /* 34006 ( 612) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
    18557868, /* 34007 ( 612) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
    51139794, /* 34008 ( 612) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6] -1 */
    18439610, /* 34009 ( 612) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
       16484, /* 34010 ( 613) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
     1433496, /* 34011 ( 613) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  0]  1 */
    51152756, /* 34012 ( 613) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
      121460, /* 34013 ( 613) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6]  1 */
    51034818, /* 34014 ( 613) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  0] -1 */
    52570092, /* 34015 ( 613) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
     1538472, /* 34016 ( 613) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
    52451834, /* 34017 ( 613) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
        3198, /* 34018 ( 613) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
      134418, /* 34019 ( 613) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  6]  1 */
    52438872, /* 34020 ( 613) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
    52556810, /* 34021 ( 613) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    51021536, /* 34022 ( 613) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  0] -1 */
     1551758, /* 34023 ( 613) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
     1420538, /* 34024 ( 613) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  0]  1 */
    51139794, /* 34025 ( 613) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6] -1 */
       16484, /* 34026 ( 614) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34133684, /* 34027 ( 614) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    17127570, /* 34028 ( 614) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6]  1 */
    51034818, /* 34029 ( 614) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  0] -1 */
    52570092, /* 34030 ( 614) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
     1538472, /* 34031 ( 614) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
    34146642, /* 34032 ( 614) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
    35432762, /* 34033 ( 614) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  0] -1 */
    17140532, /* 34034 ( 614) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
        3198, /* 34035 ( 614) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    52556810, /* 34036 ( 614) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    51021536, /* 34037 ( 614) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  0] -1 */
    35445720, /* 34038 ( 614) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  0] -1 */
     1551758, /* 34039 ( 614) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
    18426648, /* 34040 ( 614) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
    18439610, /* 34041 ( 614) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
       16484, /* 34042 ( 615) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34133684, /* 34043 ( 615) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    17127570, /* 34044 ( 615) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6]  1 */
    34015422, /* 34045 ( 615) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
     1433496, /* 34046 ( 615) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  0]  1 */
    35550696, /* 34047 ( 615) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  6] -1 */
    17009312, /* 34048 ( 615) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  0]  1 */
    51152756, /* 34049 ( 615) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
    18544586, /* 34050 ( 615) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    51034818, /* 34051 ( 615) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  0] -1 */
    52570092, /* 34052 ( 615) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    35432762, /* 34053 ( 615) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  0] -1 */
    52451834, /* 34054 ( 615) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
      134418, /* 34055 ( 615) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  6]  1 */
     1551758, /* 34056 ( 615) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
    18426648, /* 34057 ( 615) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
       16484, /* 34058 ( 616) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
     1538472, /* 34059 ( 616) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
    51139796, /* 34060 ( 616) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
    17140532, /* 34061 ( 616) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
    34133682, /* 34062 ( 616) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
        3198, /* 34063 ( 616) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
      134418, /* 34064 ( 616) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  6]  1 */
    52438874, /* 34065 ( 616) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
    35550698, /* 34066 ( 616) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
    52570094, /* 34067 ( 616) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    18439610, /* 34068 ( 616) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    35563980, /* 34069 ( 616) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6] -1 */
    35445722, /* 34070 ( 616) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  0] -1 */
      121460, /* 34071 ( 616) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6]  1 */
    34015424, /* 34072 ( 616) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    51034820, /* 34073 ( 616) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  0] -1 */
     1551758, /* 34074 ( 616) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
    34028706, /* 34075 ( 616) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    18426648, /* 34076 ( 616) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
    18544586, /* 34077 ( 616) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    17127570, /* 34078 ( 616) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6]  1 */
    35432760, /* 34079 ( 616) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  0] -1 */
    17022594, /* 34080 ( 616) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  0]  1 */
    18557868, /* 34081 ( 616) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
    52556808, /* 34082 ( 616) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    17009312, /* 34083 ( 616) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  0]  1 */
     1433496, /* 34084 ( 616) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  0]  1 */
    52451832, /* 34085 ( 616) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
    51021534, /* 34086 ( 616) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  0] -1 */
    34146644, /* 34087 ( 616) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    51152754, /* 34088 ( 616) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  6] -1 */
     1420538, /* 34089 ( 616) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  0]  1 */
       16484, /* 34090 ( 617) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
     1538472, /* 34091 ( 617) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
    17140532, /* 34092 ( 617) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
        3198, /* 34093 ( 617) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
      134418, /* 34094 ( 617) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  6]  1 */
    34133520, /* 34095 ( 617) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
    18439610, /* 34096 ( 617) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    35445884, /* 34097 ( 617) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  0] -1 */
      121460, /* 34098 ( 617) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6]  1 */
    51034658, /* 34099 ( 617) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  0] -1 */
    52569932, /* 34100 ( 617) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
     1551758, /* 34101 ( 617) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
    34028544, /* 34102 ( 617) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    35563818, /* 34103 ( 617) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  6] -1 */
    18426648, /* 34104 ( 617) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
    18544586, /* 34105 ( 617) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    17127570, /* 34106 ( 617) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6]  1 */
    34015586, /* 34107 ( 617) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    35550860, /* 34108 ( 617) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
    35432598, /* 34109 ( 617) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  0] -1 */
    34146806, /* 34110 ( 617) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    51021696, /* 34111 ( 617) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  0] -1 */
    52556970, /* 34112 ( 617) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    17022594, /* 34113 ( 617) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  0]  1 */
    18557868, /* 34114 ( 617) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
    51139634, /* 34115 ( 617) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
    51152916, /* 34116 ( 617) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6] -1 */
    52438712, /* 34117 ( 617) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
    17009312, /* 34118 ( 617) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  0]  1 */
     1433496, /* 34119 ( 617) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  0]  1 */
    52451994, /* 34120 ( 617) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
     1420538, /* 34121 ( 617) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  0]  1 */
       16484, /* 34122 ( 618) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
     1538472, /* 34123 ( 618) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
    17140532, /* 34124 ( 618) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
        3198, /* 34125 ( 618) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
      134418, /* 34126 ( 618) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  6]  1 */
    35432600, /* 34127 ( 618) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  0] -1 */
    52438710, /* 34128 ( 618) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
    18439610, /* 34129 ( 618) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    35445882, /* 34130 ( 618) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  0] -1 */
    51139632, /* 34131 ( 618) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  6] -1 */
      121460, /* 34132 ( 618) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6]  1 */
    35563820, /* 34133 ( 618) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
     1551758, /* 34134 ( 618) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
    18426648, /* 34135 ( 618) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
    18544586, /* 34136 ( 618) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    34028546, /* 34137 ( 618) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    17127570, /* 34138 ( 618) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6]  1 */
    52569930, /* 34139 ( 618) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    51034656, /* 34140 ( 618) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  0] -1 */
    34133522, /* 34141 ( 618) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    51152918, /* 34142 ( 618) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
    34146804, /* 34143 ( 618) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
    52451996, /* 34144 ( 618) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
    17022594, /* 34145 ( 618) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  0]  1 */
    52556972, /* 34146 ( 618) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    18557868, /* 34147 ( 618) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
    51021698, /* 34148 ( 618) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  0] -1 */
    34015584, /* 34149 ( 618) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    35550858, /* 34150 ( 618) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6] -1 */
    17009312, /* 34151 ( 618) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  0]  1 */
     1433496, /* 34152 ( 618) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  0]  1 */
     1420538, /* 34153 ( 618) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  0]  1 */
       16484, /* 34154 ( 609) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
        3200, /* 34155 ( 609) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
        3360, /* 34156 ( 609) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
     1551594, /* 34157 ( 609) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
    18426650, /* 34158 ( 609) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
     1538634, /* 34159 ( 609) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
    17127408, /* 34160 ( 609) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  6]  1 */
    18439770, /* 34161 ( 609) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
    17140692, /* 34162 ( 609) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6]  1 */
    18439610, /* 34163 ( 609) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    18426486, /* 34164 ( 609) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
       16320, /* 34165 ( 609) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
     1551758, /* 34166 ( 609) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
    17140532, /* 34167 ( 609) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
     1538474, /* 34168 ( 609) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
    17127572, /* 34169 ( 609) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
       16484, /* 34170 ( 610) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    52438874, /* 34171 ( 610) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
    17127408, /* 34172 ( 610) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  6]  1 */
    18439770, /* 34173 ( 610) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
    35563982, /* 34174 ( 610) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
    18426486, /* 34175 ( 610) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
       16320, /* 34176 ( 610) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    35550698, /* 34177 ( 610) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
    35550858, /* 34178 ( 610) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6] -1 */
    34015424, /* 34179 ( 610) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    17140692, /* 34180 ( 610) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6]  1 */
    18426650, /* 34181 ( 610) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    52451834, /* 34182 ( 610) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
    51152756, /* 34183 ( 610) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
    34015584, /* 34184 ( 610) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    35563818, /* 34185 ( 610) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  6] -1 */
     1551758, /* 34186 ( 610) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
    34028708, /* 34187 ( 610) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
     1538474, /* 34188 ( 610) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
     1538634, /* 34189 ( 610) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
        3200, /* 34190 ( 610) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    51139796, /* 34191 ( 610) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
    18439610, /* 34192 ( 610) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    17140532, /* 34193 ( 610) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
    52438710, /* 34194 ( 610) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
     1551594, /* 34195 ( 610) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
        3360, /* 34196 ( 610) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    51139632, /* 34197 ( 610) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  6] -1 */
    52451994, /* 34198 ( 610) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
    34028544, /* 34199 ( 610) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    51152916, /* 34200 ( 610) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6] -1 */
    17127572, /* 34201 ( 610) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
       16484, /* 34202 ( 611) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
        3200, /* 34203 ( 611) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    52438710, /* 34204 ( 611) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
    51139632, /* 34205 ( 611) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  6] -1 */
    52451994, /* 34206 ( 611) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
    18426650, /* 34207 ( 611) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    34028544, /* 34208 ( 611) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    18439610, /* 34209 ( 611) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    51152916, /* 34210 ( 611) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6] -1 */
    35550858, /* 34211 ( 611) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6] -1 */
    34015584, /* 34212 ( 611) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    35563818, /* 34213 ( 611) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  6] -1 */
     1551758, /* 34214 ( 611) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
    17140532, /* 34215 ( 611) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
     1538474, /* 34216 ( 611) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
    17127572, /* 34217 ( 611) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
       16484, /* 34218 ( 612) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    52438874, /* 34219 ( 612) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
    52438710, /* 34220 ( 612) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
     1551594, /* 34221 ( 612) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
    51139632, /* 34222 ( 612) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  6] -1 */
    51139796, /* 34223 ( 612) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
    18439770, /* 34224 ( 612) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
    18439610, /* 34225 ( 612) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
       16320, /* 34226 ( 612) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    35550698, /* 34227 ( 612) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
    35550858, /* 34228 ( 612) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6] -1 */
    34015584, /* 34229 ( 612) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
     1551758, /* 34230 ( 612) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
    17140532, /* 34231 ( 612) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
    34015424, /* 34232 ( 612) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    17140692, /* 34233 ( 612) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6]  1 */
       16484, /* 34234 ( 613) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
     1551594, /* 34235 ( 613) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
    52451994, /* 34236 ( 613) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
    18426650, /* 34237 ( 613) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    52451834, /* 34238 ( 613) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
    51152756, /* 34239 ( 613) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
    17127408, /* 34240 ( 613) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  6]  1 */
    51152916, /* 34241 ( 613) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6] -1 */
    18426486, /* 34242 ( 613) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
       16320, /* 34243 ( 613) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    35550698, /* 34244 ( 613) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
    35550858, /* 34245 ( 613) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6] -1 */
    34015584, /* 34246 ( 613) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
     1551758, /* 34247 ( 613) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
    17127572, /* 34248 ( 613) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
    34015424, /* 34249 ( 613) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
       16484, /* 34250 ( 614) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    52438874, /* 34251 ( 614) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
        3200, /* 34252 ( 614) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    52451834, /* 34253 ( 614) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
    51152756, /* 34254 ( 614) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
    17127408, /* 34255 ( 614) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  6]  1 */
    34028544, /* 34256 ( 614) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    51139796, /* 34257 ( 614) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
    18439770, /* 34258 ( 614) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
    18426486, /* 34259 ( 614) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
    35550858, /* 34260 ( 614) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6] -1 */
    34015584, /* 34261 ( 614) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    35563818, /* 34262 ( 614) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  6] -1 */
     1551758, /* 34263 ( 614) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
     1538474, /* 34264 ( 614) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
    17140692, /* 34265 ( 614) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6]  1 */
       16484, /* 34266 ( 615) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    52438874, /* 34267 ( 615) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
        3200, /* 34268 ( 615) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    52438710, /* 34269 ( 615) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
     1551594, /* 34270 ( 615) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
    51139632, /* 34271 ( 615) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  6] -1 */
        3360, /* 34272 ( 615) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    52451994, /* 34273 ( 615) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
     1538634, /* 34274 ( 615) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
    52451834, /* 34275 ( 615) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
    51152756, /* 34276 ( 615) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
    51139796, /* 34277 ( 615) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
    51152916, /* 34278 ( 615) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6] -1 */
       16320, /* 34279 ( 615) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
     1551758, /* 34280 ( 615) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
     1538474, /* 34281 ( 615) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
       16484, /* 34282 ( 616) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    17127408, /* 34283 ( 616) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  6]  1 */
    35432762, /* 34284 ( 616) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  0] -1 */
    18439770, /* 34285 ( 616) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
    51021536, /* 34286 ( 616) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  0] -1 */
    18426486, /* 34287 ( 616) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
       16320, /* 34288 ( 616) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    34133684, /* 34289 ( 616) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    52556970, /* 34290 ( 616) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    52570094, /* 34291 ( 616) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    17140692, /* 34292 ( 616) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6]  1 */
    34146644, /* 34293 ( 616) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    34146804, /* 34294 ( 616) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
    18426650, /* 34295 ( 616) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    51021696, /* 34296 ( 616) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  0] -1 */
    51034820, /* 34297 ( 616) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  0] -1 */
     1551758, /* 34298 ( 616) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
    35445722, /* 34299 ( 616) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  0] -1 */
     1538474, /* 34300 ( 616) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
     1538634, /* 34301 ( 616) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
        3200, /* 34302 ( 616) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    52556810, /* 34303 ( 616) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    18439610, /* 34304 ( 616) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    17140532, /* 34305 ( 616) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
    34133520, /* 34306 ( 616) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
        3360, /* 34307 ( 616) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
     1551594, /* 34308 ( 616) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
    52569930, /* 34309 ( 616) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    35432598, /* 34310 ( 616) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  0] -1 */
    35445882, /* 34311 ( 616) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  0] -1 */
    51034656, /* 34312 ( 616) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  0] -1 */
    17127572, /* 34313 ( 616) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
       16484, /* 34314 ( 617) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    17127408, /* 34315 ( 617) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  6]  1 */
    18439770, /* 34316 ( 617) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
    18426486, /* 34317 ( 617) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
       16320, /* 34318 ( 617) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    51021534, /* 34319 ( 617) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  0] -1 */
    17140692, /* 34320 ( 617) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6]  1 */
    34146806, /* 34321 ( 617) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    18426650, /* 34322 ( 617) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    51034818, /* 34323 ( 617) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  0] -1 */
    52570092, /* 34324 ( 617) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
     1551758, /* 34325 ( 617) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
    35445720, /* 34326 ( 617) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  0] -1 */
    34146642, /* 34327 ( 617) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
     1538474, /* 34328 ( 617) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
     1538634, /* 34329 ( 617) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
        3200, /* 34330 ( 617) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    51021698, /* 34331 ( 617) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  0] -1 */
    52556972, /* 34332 ( 617) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    52556808, /* 34333 ( 617) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    35445884, /* 34334 ( 617) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  0] -1 */
    35432600, /* 34335 ( 617) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  0] -1 */
    34133522, /* 34336 ( 617) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    18439610, /* 34337 ( 617) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    17140532, /* 34338 ( 617) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
    35432760, /* 34339 ( 617) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  0] -1 */
    51034658, /* 34340 ( 617) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  0] -1 */
    34133682, /* 34341 ( 617) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
        3360, /* 34342 ( 617) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
     1551594, /* 34343 ( 617) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
    52569932, /* 34344 ( 617) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    17127572, /* 34345 ( 617) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
       16484, /* 34346 ( 618) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    17127408, /* 34347 ( 618) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  6]  1 */
    18439770, /* 34348 ( 618) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
    18426486, /* 34349 ( 618) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
       16320, /* 34350 ( 618) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    51139794, /* 34351 ( 618) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6] -1 */
    35550696, /* 34352 ( 618) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  6] -1 */
    17140692, /* 34353 ( 618) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6]  1 */
    35563820, /* 34354 ( 618) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
    34015422, /* 34355 ( 618) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    18426650, /* 34356 ( 618) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    35563980, /* 34357 ( 618) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6] -1 */
     1551758, /* 34358 ( 618) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
     1538474, /* 34359 ( 618) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
     1538634, /* 34360 ( 618) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
    34028706, /* 34361 ( 618) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
        3200, /* 34362 ( 618) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    51152754, /* 34363 ( 618) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  6] -1 */
    52451832, /* 34364 ( 618) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
    52438872, /* 34365 ( 618) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
    52451996, /* 34366 ( 618) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
    34028546, /* 34367 ( 618) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    51152918, /* 34368 ( 618) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
    18439610, /* 34369 ( 618) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    35550860, /* 34370 ( 618) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
    17140532, /* 34371 ( 618) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
    34015586, /* 34372 ( 618) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    52438712, /* 34373 ( 618) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
    51139634, /* 34374 ( 618) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
        3360, /* 34375 ( 618) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
     1551594, /* 34376 ( 618) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
    17127572, /* 34377 ( 618) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
       16484, /* 34378 ( 609) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    18426488, /* 34379 ( 609) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    17009472, /* 34380 ( 609) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  0]  1 */
      134418, /* 34381 ( 609) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  6]  1 */
     1420538, /* 34382 ( 609) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  0]  1 */
    18544746, /* 34383 ( 609) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
     1538472, /* 34384 ( 609) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
    18439770, /* 34385 ( 609) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
    17140692, /* 34386 ( 609) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6]  1 */
    17022434, /* 34387 ( 609) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  0]  1 */
        3198, /* 34388 ( 609) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
     1433496, /* 34389 ( 609) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  0]  1 */
     1551758, /* 34390 ( 609) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
    18557708, /* 34391 ( 609) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    17127410, /* 34392 ( 609) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
      121460, /* 34393 ( 609) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6]  1 */
       16484, /* 34394 ( 610) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    35432762, /* 34395 ( 610) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  0] -1 */
     1538472, /* 34396 ( 610) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
    18439770, /* 34397 ( 610) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
    35563982, /* 34398 ( 610) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
        3198, /* 34399 ( 610) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
     1433496, /* 34400 ( 610) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  0]  1 */
    51139634, /* 34401 ( 610) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
    52556970, /* 34402 ( 610) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    52438712, /* 34403 ( 610) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
    17140692, /* 34404 ( 610) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6]  1 */
     1420538, /* 34405 ( 610) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  0]  1 */
    51034658, /* 34406 ( 610) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  0] -1 */
    52569932, /* 34407 ( 610) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    51021696, /* 34408 ( 610) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  0] -1 */
    34146642, /* 34409 ( 610) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
     1551758, /* 34410 ( 610) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
    34028708, /* 34411 ( 610) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    17127410, /* 34412 ( 610) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
    18544746, /* 34413 ( 610) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
    18426488, /* 34414 ( 610) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    34133684, /* 34415 ( 610) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    17022434, /* 34416 ( 610) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  0]  1 */
    18557708, /* 34417 ( 610) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    34015422, /* 34418 ( 610) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
      134418, /* 34419 ( 610) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  6]  1 */
    17009472, /* 34420 ( 610) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  0]  1 */
    35550696, /* 34421 ( 610) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  6] -1 */
    52451994, /* 34422 ( 610) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
    35445720, /* 34423 ( 610) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  0] -1 */
    51152916, /* 34424 ( 610) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6] -1 */
      121460, /* 34425 ( 610) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6]  1 */
       16484, /* 34426 ( 611) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    18426488, /* 34427 ( 611) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    34015422, /* 34428 ( 611) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    35550696, /* 34429 ( 611) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  6] -1 */
    52451994, /* 34430 ( 611) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
     1420538, /* 34431 ( 611) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  0]  1 */
    35445720, /* 34432 ( 611) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  0] -1 */
    17022434, /* 34433 ( 611) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  0]  1 */
    51152916, /* 34434 ( 611) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6] -1 */
    52556970, /* 34435 ( 611) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    51021696, /* 34436 ( 611) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  0] -1 */
    34146642, /* 34437 ( 611) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
     1551758, /* 34438 ( 611) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
    18557708, /* 34439 ( 611) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    17127410, /* 34440 ( 611) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
      121460, /* 34441 ( 611) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6]  1 */
       16484, /* 34442 ( 612) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    35432762, /* 34443 ( 612) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  0] -1 */
    34015422, /* 34444 ( 612) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
      134418, /* 34445 ( 612) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  6]  1 */
    35550696, /* 34446 ( 612) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  6] -1 */
    34133684, /* 34447 ( 612) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    18439770, /* 34448 ( 612) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
    17022434, /* 34449 ( 612) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  0]  1 */
     1433496, /* 34450 ( 612) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  0]  1 */
    51139634, /* 34451 ( 612) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
    52556970, /* 34452 ( 612) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    51021696, /* 34453 ( 612) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  0] -1 */
     1551758, /* 34454 ( 612) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
    18557708, /* 34455 ( 612) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    52438712, /* 34456 ( 612) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
    17140692, /* 34457 ( 612) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6]  1 */
       16484, /* 34458 ( 613) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
      134418, /* 34459 ( 613) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  6]  1 */
    52451994, /* 34460 ( 613) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
     1420538, /* 34461 ( 613) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  0]  1 */
    51034658, /* 34462 ( 613) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  0] -1 */
    52569932, /* 34463 ( 613) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
     1538472, /* 34464 ( 613) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
    51152916, /* 34465 ( 613) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6] -1 */
        3198, /* 34466 ( 613) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
     1433496, /* 34467 ( 613) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  0]  1 */
    51139634, /* 34468 ( 613) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
    52556970, /* 34469 ( 613) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    51021696, /* 34470 ( 613) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  0] -1 */
     1551758, /* 34471 ( 613) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
      121460, /* 34472 ( 613) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6]  1 */
    52438712, /* 34473 ( 613) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
       16484, /* 34474 ( 614) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    35432762, /* 34475 ( 614) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  0] -1 */
    18426488, /* 34476 ( 614) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    51034658, /* 34477 ( 614) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  0] -1 */
    52569932, /* 34478 ( 614) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
     1538472, /* 34479 ( 614) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
    35445720, /* 34480 ( 614) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  0] -1 */
    34133684, /* 34481 ( 614) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    18439770, /* 34482 ( 614) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
        3198, /* 34483 ( 614) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    52556970, /* 34484 ( 614) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    51021696, /* 34485 ( 614) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  0] -1 */
    34146642, /* 34486 ( 614) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
     1551758, /* 34487 ( 614) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
    17127410, /* 34488 ( 614) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
    17140692, /* 34489 ( 614) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6]  1 */
       16484, /* 34490 ( 615) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    35432762, /* 34491 ( 615) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  0] -1 */
    18426488, /* 34492 ( 615) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    34015422, /* 34493 ( 615) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
      134418, /* 34494 ( 615) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  6]  1 */
    35550696, /* 34495 ( 615) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  6] -1 */
    17009472, /* 34496 ( 615) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  0]  1 */
    52451994, /* 34497 ( 615) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
    18544746, /* 34498 ( 615) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
    51034658, /* 34499 ( 615) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  0] -1 */
    52569932, /* 34500 ( 615) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    34133684, /* 34501 ( 615) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    51152916, /* 34502 ( 615) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6] -1 */
     1433496, /* 34503 ( 615) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  0]  1 */
     1551758, /* 34504 ( 615) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
    17127410, /* 34505 ( 615) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
       16484, /* 34506 ( 616) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
     1538472, /* 34507 ( 616) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
    52438874, /* 34508 ( 616) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
    18439770, /* 34509 ( 616) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
    35432600, /* 34510 ( 616) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  0] -1 */
        3198, /* 34511 ( 616) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
     1433496, /* 34512 ( 616) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  0]  1 */
    51139796, /* 34513 ( 616) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
    35550858, /* 34514 ( 616) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6] -1 */
    52570094, /* 34515 ( 616) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    17140692, /* 34516 ( 616) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6]  1 */
    35563820, /* 34517 ( 616) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
    34146804, /* 34518 ( 616) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
     1420538, /* 34519 ( 616) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  0]  1 */
    34015584, /* 34520 ( 616) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    51034820, /* 34521 ( 616) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  0] -1 */
     1551758, /* 34522 ( 616) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
    34028546, /* 34523 ( 616) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    17127410, /* 34524 ( 616) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
    18544746, /* 34525 ( 616) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
    18426488, /* 34526 ( 616) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    34133522, /* 34527 ( 616) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    17022434, /* 34528 ( 616) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  0]  1 */
    18557708, /* 34529 ( 616) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    52556808, /* 34530 ( 616) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    17009472, /* 34531 ( 616) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  0]  1 */
      134418, /* 34532 ( 616) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  6]  1 */
    51152754, /* 34533 ( 616) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  6] -1 */
    51021534, /* 34534 ( 616) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  0] -1 */
    35445882, /* 34535 ( 616) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  0] -1 */
    52451832, /* 34536 ( 616) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
      121460, /* 34537 ( 616) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6]  1 */
       16484, /* 34538 ( 617) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
     1538472, /* 34539 ( 617) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
    18439770, /* 34540 ( 617) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
        3198, /* 34541 ( 617) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
     1433496, /* 34542 ( 617) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  0]  1 */
    35432598, /* 34543 ( 617) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  0] -1 */
    17140692, /* 34544 ( 617) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6]  1 */
    34146806, /* 34545 ( 617) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
     1420538, /* 34546 ( 617) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  0]  1 */
    51034818, /* 34547 ( 617) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  0] -1 */
    52570092, /* 34548 ( 617) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
     1551758, /* 34549 ( 617) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
    34028544, /* 34550 ( 617) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    35563818, /* 34551 ( 617) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  6] -1 */
    17127410, /* 34552 ( 617) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
    18544746, /* 34553 ( 617) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
    18426488, /* 34554 ( 617) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    34015586, /* 34555 ( 617) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    35550860, /* 34556 ( 617) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
    34133520, /* 34557 ( 617) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
    35445884, /* 34558 ( 617) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  0] -1 */
    51021536, /* 34559 ( 617) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  0] -1 */
    52556810, /* 34560 ( 617) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    17022434, /* 34561 ( 617) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  0]  1 */
    18557708, /* 34562 ( 617) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    52438872, /* 34563 ( 617) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
    52451834, /* 34564 ( 617) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
    51139794, /* 34565 ( 617) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6] -1 */
    17009472, /* 34566 ( 617) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  0]  1 */
      134418, /* 34567 ( 617) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  6]  1 */
    51152756, /* 34568 ( 617) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
      121460, /* 34569 ( 617) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6]  1 */
       16484, /* 34570 ( 618) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
     1538472, /* 34571 ( 618) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
    18439770, /* 34572 ( 618) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
        3198, /* 34573 ( 618) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
     1433496, /* 34574 ( 618) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  0]  1 */
    34133682, /* 34575 ( 618) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
    51139632, /* 34576 ( 618) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  6] -1 */
    17140692, /* 34577 ( 618) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6]  1 */
    34146644, /* 34578 ( 618) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    52438710, /* 34579 ( 618) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
     1420538, /* 34580 ( 618) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  0]  1 */
    35563980, /* 34581 ( 618) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6] -1 */
     1551758, /* 34582 ( 618) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
    17127410, /* 34583 ( 618) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
    18544746, /* 34584 ( 618) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
    34028706, /* 34585 ( 618) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    18426488, /* 34586 ( 618) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    52569930, /* 34587 ( 618) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    51034656, /* 34588 ( 618) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  0] -1 */
    35432760, /* 34589 ( 618) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  0] -1 */
    52451996, /* 34590 ( 618) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
    35445722, /* 34591 ( 618) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  0] -1 */
    51152918, /* 34592 ( 618) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
    17022434, /* 34593 ( 618) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  0]  1 */
    52556972, /* 34594 ( 618) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    18557708, /* 34595 ( 618) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    51021698, /* 34596 ( 618) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  0] -1 */
    34015424, /* 34597 ( 618) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    35550698, /* 34598 ( 618) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
    17009472, /* 34599 ( 618) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  0]  1 */
      134418, /* 34600 ( 618) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  6]  1 */
      121460, /* 34601 ( 618) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6]  1 */
       16484, /* 34602 ( 609) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
        3200, /* 34603 ( 609) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
       16320, /* 34604 ( 609) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    17127570, /* 34605 ( 609) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6]  1 */
    18439610, /* 34606 ( 609) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    17140530, /* 34607 ( 609) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  6]  1 */
     1538472, /* 34608 ( 609) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
    18439770, /* 34609 ( 609) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
     1551756, /* 34610 ( 609) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
    18426650, /* 34611 ( 609) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    18426486, /* 34612 ( 609) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
        3360, /* 34613 ( 609) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    17140694, /* 34614 ( 609) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
     1538636, /* 34615 ( 609) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
    17127410, /* 34616 ( 609) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
     1551596, /* 34617 ( 609) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
       16484, /* 34618 ( 610) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    52451834, /* 34619 ( 610) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
     1538472, /* 34620 ( 610) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
    18439770, /* 34621 ( 610) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
    51152918, /* 34622 ( 610) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
    18426486, /* 34623 ( 610) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
        3360, /* 34624 ( 610) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    51139634, /* 34625 ( 610) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
    51152754, /* 34626 ( 610) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  6] -1 */
    34015424, /* 34627 ( 610) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
     1551756, /* 34628 ( 610) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
    18439610, /* 34629 ( 610) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    52438874, /* 34630 ( 610) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
    35550860, /* 34631 ( 610) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
    34028544, /* 34632 ( 610) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    51139794, /* 34633 ( 610) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6] -1 */
    17140694, /* 34634 ( 610) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
    34028708, /* 34635 ( 610) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    17127410, /* 34636 ( 610) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
    17140530, /* 34637 ( 610) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  6]  1 */
        3200, /* 34638 ( 610) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    35563820, /* 34639 ( 610) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
    18426650, /* 34640 ( 610) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
     1538636, /* 34641 ( 610) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
    52438710, /* 34642 ( 610) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
    17127570, /* 34643 ( 610) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6]  1 */
       16320, /* 34644 ( 610) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    35550696, /* 34645 ( 610) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  6] -1 */
    52451994, /* 34646 ( 610) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
    34015584, /* 34647 ( 610) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    35563980, /* 34648 ( 610) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6] -1 */
     1551596, /* 34649 ( 610) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
       16484, /* 34650 ( 611) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
        3200, /* 34651 ( 611) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    52438710, /* 34652 ( 611) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
    35550696, /* 34653 ( 611) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  6] -1 */
    52451994, /* 34654 ( 611) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
    18439610, /* 34655 ( 611) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    34015584, /* 34656 ( 611) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    18426650, /* 34657 ( 611) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    35563980, /* 34658 ( 611) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6] -1 */
    51152754, /* 34659 ( 611) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  6] -1 */
    34028544, /* 34660 ( 611) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    51139794, /* 34661 ( 611) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6] -1 */
    17140694, /* 34662 ( 611) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
     1538636, /* 34663 ( 611) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
    17127410, /* 34664 ( 611) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
     1551596, /* 34665 ( 611) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
       16484, /* 34666 ( 612) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    52451834, /* 34667 ( 612) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
    52438710, /* 34668 ( 612) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
    17127570, /* 34669 ( 612) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6]  1 */
    35550696, /* 34670 ( 612) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  6] -1 */
    35563820, /* 34671 ( 612) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
    18439770, /* 34672 ( 612) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
    18426650, /* 34673 ( 612) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
        3360, /* 34674 ( 612) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    51139634, /* 34675 ( 612) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
    51152754, /* 34676 ( 612) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  6] -1 */
    34028544, /* 34677 ( 612) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    17140694, /* 34678 ( 612) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
     1538636, /* 34679 ( 612) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
    34015424, /* 34680 ( 612) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
     1551756, /* 34681 ( 612) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
       16484, /* 34682 ( 613) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    17127570, /* 34683 ( 613) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6]  1 */
    52451994, /* 34684 ( 613) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
    18439610, /* 34685 ( 613) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    52438874, /* 34686 ( 613) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
    35550860, /* 34687 ( 613) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
     1538472, /* 34688 ( 613) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
    35563980, /* 34689 ( 613) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6] -1 */
    18426486, /* 34690 ( 613) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
        3360, /* 34691 ( 613) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    51139634, /* 34692 ( 613) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
    51152754, /* 34693 ( 613) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  6] -1 */
    34028544, /* 34694 ( 613) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    17140694, /* 34695 ( 613) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
     1551596, /* 34696 ( 613) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
    34015424, /* 34697 ( 613) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
       16484, /* 34698 ( 614) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    52451834, /* 34699 ( 614) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
        3200, /* 34700 ( 614) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    52438874, /* 34701 ( 614) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
    35550860, /* 34702 ( 614) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
     1538472, /* 34703 ( 614) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
    34015584, /* 34704 ( 614) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    35563820, /* 34705 ( 614) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
    18439770, /* 34706 ( 614) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
    18426486, /* 34707 ( 614) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
    51152754, /* 34708 ( 614) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  6] -1 */
    34028544, /* 34709 ( 614) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    51139794, /* 34710 ( 614) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6] -1 */
    17140694, /* 34711 ( 614) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
    17127410, /* 34712 ( 614) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
     1551756, /* 34713 ( 614) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
       16484, /* 34714 ( 615) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    52451834, /* 34715 ( 615) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
        3200, /* 34716 ( 615) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    52438710, /* 34717 ( 615) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
    17127570, /* 34718 ( 615) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6]  1 */
    35550696, /* 34719 ( 615) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  6] -1 */
       16320, /* 34720 ( 615) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    52451994, /* 34721 ( 615) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
    17140530, /* 34722 ( 615) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  6]  1 */
    52438874, /* 34723 ( 615) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
    35550860, /* 34724 ( 615) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
    35563820, /* 34725 ( 615) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
    35563980, /* 34726 ( 615) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6] -1 */
        3360, /* 34727 ( 615) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    17140694, /* 34728 ( 615) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
    17127410, /* 34729 ( 615) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
       16484, /* 34730 ( 616) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
     1538472, /* 34731 ( 616) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
    51034658, /* 34732 ( 616) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  0] -1 */
    18439770, /* 34733 ( 616) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
    35432600, /* 34734 ( 616) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  0] -1 */
    18426486, /* 34735 ( 616) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
        3360, /* 34736 ( 616) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    34146644, /* 34737 ( 616) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    52569930, /* 34738 ( 616) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    52570094, /* 34739 ( 616) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
     1551756, /* 34740 ( 616) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
    34133684, /* 34741 ( 616) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    34146804, /* 34742 ( 616) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
    18439610, /* 34743 ( 616) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    35445720, /* 34744 ( 616) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  0] -1 */
    35445884, /* 34745 ( 616) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  0] -1 */
    17140694, /* 34746 ( 616) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
    51021698, /* 34747 ( 616) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  0] -1 */
    17127410, /* 34748 ( 616) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
    17140530, /* 34749 ( 616) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  6]  1 */
        3200, /* 34750 ( 616) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    52556810, /* 34751 ( 616) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    18426650, /* 34752 ( 616) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
     1538636, /* 34753 ( 616) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
    34133520, /* 34754 ( 616) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
       16320, /* 34755 ( 616) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    17127570, /* 34756 ( 616) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6]  1 */
    52556970, /* 34757 ( 616) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    51021534, /* 34758 ( 616) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  0] -1 */
    51034818, /* 34759 ( 616) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  0] -1 */
    35432760, /* 34760 ( 616) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  0] -1 */
     1551596, /* 34761 ( 616) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
       16484, /* 34762 ( 617) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
     1538472, /* 34763 ( 617) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
    18439770, /* 34764 ( 617) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
    18426486, /* 34765 ( 617) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
        3360, /* 34766 ( 617) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    35432598, /* 34767 ( 617) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  0] -1 */
     1551756, /* 34768 ( 617) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
    34146806, /* 34769 ( 617) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    18439610, /* 34770 ( 617) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    35445882, /* 34771 ( 617) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  0] -1 */
    52570092, /* 34772 ( 617) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    17140694, /* 34773 ( 617) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
    51021696, /* 34774 ( 617) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  0] -1 */
    34133682, /* 34775 ( 617) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
    17127410, /* 34776 ( 617) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
    17140530, /* 34777 ( 617) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  6]  1 */
        3200, /* 34778 ( 617) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    35445722, /* 34779 ( 617) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  0] -1 */
    52569932, /* 34780 ( 617) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    52556808, /* 34781 ( 617) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    51034820, /* 34782 ( 617) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  0] -1 */
    51021536, /* 34783 ( 617) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  0] -1 */
    34133522, /* 34784 ( 617) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    18426650, /* 34785 ( 617) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
     1538636, /* 34786 ( 617) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
    51034656, /* 34787 ( 617) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  0] -1 */
    35432762, /* 34788 ( 617) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  0] -1 */
    34146642, /* 34789 ( 617) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
       16320, /* 34790 ( 617) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    17127570, /* 34791 ( 617) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6]  1 */
    52556972, /* 34792 ( 617) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
     1551596, /* 34793 ( 617) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
       16484, /* 34794 ( 618) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
     1538472, /* 34795 ( 618) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
    18439770, /* 34796 ( 618) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
    18426486, /* 34797 ( 618) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
        3360, /* 34798 ( 618) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    35563818, /* 34799 ( 618) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  6] -1 */
    51139632, /* 34800 ( 618) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  6] -1 */
     1551756, /* 34801 ( 618) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
    51139796, /* 34802 ( 618) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
    34015422, /* 34803 ( 618) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    18439610, /* 34804 ( 618) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    51152916, /* 34805 ( 618) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6] -1 */
    17140694, /* 34806 ( 618) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
    17127410, /* 34807 ( 618) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
    17140530, /* 34808 ( 618) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  6]  1 */
    34028706, /* 34809 ( 618) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
        3200, /* 34810 ( 618) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    35550858, /* 34811 ( 618) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6] -1 */
    52438872, /* 34812 ( 618) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
    52451832, /* 34813 ( 618) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
    52451996, /* 34814 ( 618) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
    34015586, /* 34815 ( 618) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    35563982, /* 34816 ( 618) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
    18426650, /* 34817 ( 618) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    51152756, /* 34818 ( 618) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
     1538636, /* 34819 ( 618) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
    34028546, /* 34820 ( 618) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    52438712, /* 34821 ( 618) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
    35550698, /* 34822 ( 618) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
       16320, /* 34823 ( 618) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    17127570, /* 34824 ( 618) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6]  1 */
     1551596, /* 34825 ( 618) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
       16484, /* 34826 ( 609) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    18426488, /* 34827 ( 609) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
     1433496, /* 34828 ( 609) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  0]  1 */
      121458, /* 34829 ( 609) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  6]  1 */
    17022434, /* 34830 ( 609) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  0]  1 */
    18557706, /* 34831 ( 609) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
    17127408, /* 34832 ( 609) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  6]  1 */
    18439770, /* 34833 ( 609) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
     1551756, /* 34834 ( 609) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
     1420538, /* 34835 ( 609) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  0]  1 */
        3198, /* 34836 ( 609) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    17009472, /* 34837 ( 609) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  0]  1 */
    17140694, /* 34838 ( 609) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
    18544748, /* 34839 ( 609) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
     1538474, /* 34840 ( 609) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
      134420, /* 34841 ( 609) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6]  1 */
       16484, /* 34842 ( 610) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    51034658, /* 34843 ( 610) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  0] -1 */
    17127408, /* 34844 ( 610) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  6]  1 */
    18439770, /* 34845 ( 610) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
    51152918, /* 34846 ( 610) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
        3198, /* 34847 ( 610) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    17009472, /* 34848 ( 610) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  0]  1 */
    35550698, /* 34849 ( 610) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
    52569930, /* 34850 ( 610) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    52438712, /* 34851 ( 610) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
     1551756, /* 34852 ( 610) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
    17022434, /* 34853 ( 610) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  0]  1 */
    35432762, /* 34854 ( 610) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  0] -1 */
    52556972, /* 34855 ( 610) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    35445720, /* 34856 ( 610) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  0] -1 */
    34133682, /* 34857 ( 610) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
    17140694, /* 34858 ( 610) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
    34028708, /* 34859 ( 610) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
     1538474, /* 34860 ( 610) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
    18557706, /* 34861 ( 610) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
    18426488, /* 34862 ( 610) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    34146644, /* 34863 ( 610) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
     1420538, /* 34864 ( 610) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  0]  1 */
    18544748, /* 34865 ( 610) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    34015422, /* 34866 ( 610) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
      121458, /* 34867 ( 610) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  6]  1 */
     1433496, /* 34868 ( 610) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  0]  1 */
    51139632, /* 34869 ( 610) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  6] -1 */
    52451994, /* 34870 ( 610) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
    51021696, /* 34871 ( 610) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  0] -1 */
    35563980, /* 34872 ( 610) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6] -1 */
      134420, /* 34873 ( 610) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6]  1 */
       16484, /* 34874 ( 611) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    18426488, /* 34875 ( 611) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    34015422, /* 34876 ( 611) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    51139632, /* 34877 ( 611) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  6] -1 */
    52451994, /* 34878 ( 611) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
    17022434, /* 34879 ( 611) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  0]  1 */
    51021696, /* 34880 ( 611) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  0] -1 */
     1420538, /* 34881 ( 611) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  0]  1 */
    35563980, /* 34882 ( 611) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6] -1 */
    52569930, /* 34883 ( 611) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    35445720, /* 34884 ( 611) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  0] -1 */
    34133682, /* 34885 ( 611) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
    17140694, /* 34886 ( 611) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
    18544748, /* 34887 ( 611) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
     1538474, /* 34888 ( 611) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
      134420, /* 34889 ( 611) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6]  1 */
       16484, /* 34890 ( 612) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    51034658, /* 34891 ( 612) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  0] -1 */
    34015422, /* 34892 ( 612) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
      121458, /* 34893 ( 612) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  6]  1 */
    51139632, /* 34894 ( 612) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  6] -1 */
    34146644, /* 34895 ( 612) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    18439770, /* 34896 ( 612) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
     1420538, /* 34897 ( 612) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  0]  1 */
    17009472, /* 34898 ( 612) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  0]  1 */
    35550698, /* 34899 ( 612) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
    52569930, /* 34900 ( 612) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    35445720, /* 34901 ( 612) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  0] -1 */
    17140694, /* 34902 ( 612) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
    18544748, /* 34903 ( 612) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    52438712, /* 34904 ( 612) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
     1551756, /* 34905 ( 612) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
       16484, /* 34906 ( 613) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
      121458, /* 34907 ( 613) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  6]  1 */
    52451994, /* 34908 ( 613) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
    17022434, /* 34909 ( 613) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  0]  1 */
    35432762, /* 34910 ( 613) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  0] -1 */
    52556972, /* 34911 ( 613) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    17127408, /* 34912 ( 613) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  6]  1 */
    35563980, /* 34913 ( 613) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6] -1 */
        3198, /* 34914 ( 613) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    17009472, /* 34915 ( 613) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  0]  1 */
    35550698, /* 34916 ( 613) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
    52569930, /* 34917 ( 613) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    35445720, /* 34918 ( 613) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  0] -1 */
    17140694, /* 34919 ( 613) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
      134420, /* 34920 ( 613) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6]  1 */
    52438712, /* 34921 ( 613) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
       16484, /* 34922 ( 614) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    51034658, /* 34923 ( 614) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  0] -1 */
    18426488, /* 34924 ( 614) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    35432762, /* 34925 ( 614) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  0] -1 */
    52556972, /* 34926 ( 614) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    17127408, /* 34927 ( 614) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  6]  1 */
    51021696, /* 34928 ( 614) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  0] -1 */
    34146644, /* 34929 ( 614) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    18439770, /* 34930 ( 614) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
        3198, /* 34931 ( 614) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    52569930, /* 34932 ( 614) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    35445720, /* 34933 ( 614) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  0] -1 */
    34133682, /* 34934 ( 614) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
    17140694, /* 34935 ( 614) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
     1538474, /* 34936 ( 614) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
     1551756, /* 34937 ( 614) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
       16484, /* 34938 ( 615) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    51034658, /* 34939 ( 615) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  0] -1 */
    18426488, /* 34940 ( 615) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    34015422, /* 34941 ( 615) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
      121458, /* 34942 ( 615) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  6]  1 */
    51139632, /* 34943 ( 615) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  6] -1 */
     1433496, /* 34944 ( 615) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  0]  1 */
    52451994, /* 34945 ( 615) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
    18557706, /* 34946 ( 615) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
    35432762, /* 34947 ( 615) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  0] -1 */
    52556972, /* 34948 ( 615) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    34146644, /* 34949 ( 615) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    35563980, /* 34950 ( 615) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6] -1 */
    17009472, /* 34951 ( 615) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  0]  1 */
    17140694, /* 34952 ( 615) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
     1538474, /* 34953 ( 615) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
       16484, /* 34954 ( 616) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    17127408, /* 34955 ( 616) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  6]  1 */
    52451834, /* 34956 ( 616) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
    18439770, /* 34957 ( 616) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
    51021536, /* 34958 ( 616) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  0] -1 */
        3198, /* 34959 ( 616) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    17009472, /* 34960 ( 616) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  0]  1 */
    35563820, /* 34961 ( 616) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
    51152754, /* 34962 ( 616) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  6] -1 */
    52570094, /* 34963 ( 616) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
     1551756, /* 34964 ( 616) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
    51139796, /* 34965 ( 616) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
    34146804, /* 34966 ( 616) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
    17022434, /* 34967 ( 616) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  0]  1 */
    34028544, /* 34968 ( 616) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    35445884, /* 34969 ( 616) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  0] -1 */
    17140694, /* 34970 ( 616) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
    34015586, /* 34971 ( 616) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
     1538474, /* 34972 ( 616) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
    18557706, /* 34973 ( 616) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
    18426488, /* 34974 ( 616) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    34133522, /* 34975 ( 616) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
     1420538, /* 34976 ( 616) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  0]  1 */
    18544748, /* 34977 ( 616) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    52556808, /* 34978 ( 616) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
     1433496, /* 34979 ( 616) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  0]  1 */
      121458, /* 34980 ( 616) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  6]  1 */
    35550858, /* 34981 ( 616) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6] -1 */
    35432598, /* 34982 ( 616) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  0] -1 */
    51034818, /* 34983 ( 616) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  0] -1 */
    52438872, /* 34984 ( 616) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
      134420, /* 34985 ( 616) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6]  1 */
       16484, /* 34986 ( 617) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    17127408, /* 34987 ( 617) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  6]  1 */
    18439770, /* 34988 ( 617) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
        3198, /* 34989 ( 617) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    17009472, /* 34990 ( 617) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  0]  1 */
    51021534, /* 34991 ( 617) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  0] -1 */
     1551756, /* 34992 ( 617) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
    34146806, /* 34993 ( 617) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    17022434, /* 34994 ( 617) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  0]  1 */
    35445882, /* 34995 ( 617) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  0] -1 */
    52570092, /* 34996 ( 617) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    17140694, /* 34997 ( 617) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
    34015584, /* 34998 ( 617) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    51139794, /* 34999 ( 617) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6] -1 */
     1538474, /* 35000 ( 617) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
    18557706, /* 35001 ( 617) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
    18426488, /* 35002 ( 617) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    34028546, /* 35003 ( 617) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    51152756, /* 35004 ( 617) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
    34133520, /* 35005 ( 617) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
    51034820, /* 35006 ( 617) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  0] -1 */
    35432600, /* 35007 ( 617) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  0] -1 */
    52556810, /* 35008 ( 617) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
     1420538, /* 35009 ( 617) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  0]  1 */
    18544748, /* 35010 ( 617) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    52451832, /* 35011 ( 617) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
    52438874, /* 35012 ( 617) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
    35563818, /* 35013 ( 617) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  6] -1 */
     1433496, /* 35014 ( 617) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  0]  1 */
      121458, /* 35015 ( 617) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  6]  1 */
    35550860, /* 35016 ( 617) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
      134420, /* 35017 ( 617) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6]  1 */
       16484, /* 35018 ( 618) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    17127408, /* 35019 ( 618) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  6]  1 */
    18439770, /* 35020 ( 618) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
        3198, /* 35021 ( 618) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    17009472, /* 35022 ( 618) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  0]  1 */
    34146642, /* 35023 ( 618) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
    35550696, /* 35024 ( 618) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  6] -1 */
     1551756, /* 35025 ( 618) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
    34133684, /* 35026 ( 618) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    52438710, /* 35027 ( 618) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
    17022434, /* 35028 ( 618) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  0]  1 */
    51152916, /* 35029 ( 618) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6] -1 */
    17140694, /* 35030 ( 618) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
     1538474, /* 35031 ( 618) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
    18557706, /* 35032 ( 618) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
    34028706, /* 35033 ( 618) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    18426488, /* 35034 ( 618) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    52556970, /* 35035 ( 618) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    35432760, /* 35036 ( 618) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  0] -1 */
    51034656, /* 35037 ( 618) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  0] -1 */
    52451996, /* 35038 ( 618) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
    51021698, /* 35039 ( 618) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  0] -1 */
    35563982, /* 35040 ( 618) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
     1420538, /* 35041 ( 618) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  0]  1 */
    52569932, /* 35042 ( 618) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    18544748, /* 35043 ( 618) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    35445722, /* 35044 ( 618) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  0] -1 */
    34015424, /* 35045 ( 618) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    51139634, /* 35046 ( 618) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
     1433496, /* 35047 ( 618) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  0]  1 */
      121458, /* 35048 ( 618) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  6]  1 */
      134420, /* 35049 ( 618) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6]  1 */
       16484, /* 35050 ( 609) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
       16320, /* 35051 ( 609) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
        3200, /* 35052 ( 609) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    17127570, /* 35053 ( 609) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6]  1 */
     1551596, /* 35054 ( 609) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
    17127410, /* 35055 ( 609) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
    18426486, /* 35056 ( 609) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
     1538636, /* 35057 ( 609) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
    18426650, /* 35058 ( 609) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
     1551756, /* 35059 ( 609) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
     1538472, /* 35060 ( 609) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
        3360, /* 35061 ( 609) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    17140694, /* 35062 ( 609) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
    18439770, /* 35063 ( 609) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
    17140530, /* 35064 ( 609) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  6]  1 */
    18439610, /* 35065 ( 609) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
       16484, /* 35066 ( 610) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    35563820, /* 35067 ( 610) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
    18426486, /* 35068 ( 610) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
     1538636, /* 35069 ( 610) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
    51152918, /* 35070 ( 610) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
     1538472, /* 35071 ( 610) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
        3360, /* 35072 ( 610) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    51152754, /* 35073 ( 610) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  6] -1 */
    51139634, /* 35074 ( 610) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
    34028544, /* 35075 ( 610) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    18426650, /* 35076 ( 610) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
     1551596, /* 35077 ( 610) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
    35563980, /* 35078 ( 610) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6] -1 */
    52451994, /* 35079 ( 610) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
    34015424, /* 35080 ( 610) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    51139794, /* 35081 ( 610) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6] -1 */
    17140694, /* 35082 ( 610) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
    34028708, /* 35083 ( 610) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    17140530, /* 35084 ( 610) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  6]  1 */
    17127410, /* 35085 ( 610) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
       16320, /* 35086 ( 610) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    52451834, /* 35087 ( 610) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
     1551756, /* 35088 ( 610) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
    18439770, /* 35089 ( 610) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
    35550696, /* 35090 ( 610) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  6] -1 */
    17127570, /* 35091 ( 610) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6]  1 */
        3200, /* 35092 ( 610) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    52438710, /* 35093 ( 610) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
    35550860, /* 35094 ( 610) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
    34015584, /* 35095 ( 610) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    52438874, /* 35096 ( 610) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
    18439610, /* 35097 ( 610) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
       16484, /* 35098 ( 611) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
       16320, /* 35099 ( 611) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    35550696, /* 35100 ( 611) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  6] -1 */
    52438710, /* 35101 ( 611) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
    35550860, /* 35102 ( 611) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
     1551596, /* 35103 ( 611) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
    34015584, /* 35104 ( 611) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
     1551756, /* 35105 ( 611) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
    52438874, /* 35106 ( 611) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
    51139634, /* 35107 ( 611) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
    34015424, /* 35108 ( 611) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    51139794, /* 35109 ( 611) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6] -1 */
    17140694, /* 35110 ( 611) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
    18439770, /* 35111 ( 611) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
    17140530, /* 35112 ( 611) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  6]  1 */
    18439610, /* 35113 ( 611) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
       16484, /* 35114 ( 612) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    35563820, /* 35115 ( 612) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
    35550696, /* 35116 ( 612) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  6] -1 */
    17127570, /* 35117 ( 612) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6]  1 */
    52438710, /* 35118 ( 612) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
    52451834, /* 35119 ( 612) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
     1538636, /* 35120 ( 612) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
     1551756, /* 35121 ( 612) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
        3360, /* 35122 ( 612) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    51152754, /* 35123 ( 612) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  6] -1 */
    51139634, /* 35124 ( 612) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
    34015424, /* 35125 ( 612) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    17140694, /* 35126 ( 612) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
    18439770, /* 35127 ( 612) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
    34028544, /* 35128 ( 612) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    18426650, /* 35129 ( 612) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
       16484, /* 35130 ( 613) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    17127570, /* 35131 ( 613) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6]  1 */
    35550860, /* 35132 ( 613) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
     1551596, /* 35133 ( 613) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
    35563980, /* 35134 ( 613) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6] -1 */
    52451994, /* 35135 ( 613) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
    18426486, /* 35136 ( 613) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
    52438874, /* 35137 ( 613) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
     1538472, /* 35138 ( 613) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
        3360, /* 35139 ( 613) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    51152754, /* 35140 ( 613) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  6] -1 */
    51139634, /* 35141 ( 613) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
    34015424, /* 35142 ( 613) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    17140694, /* 35143 ( 613) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
    18439610, /* 35144 ( 613) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    34028544, /* 35145 ( 613) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
       16484, /* 35146 ( 614) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    35563820, /* 35147 ( 614) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
       16320, /* 35148 ( 614) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    35563980, /* 35149 ( 614) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6] -1 */
    52451994, /* 35150 ( 614) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
    18426486, /* 35151 ( 614) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
    34015584, /* 35152 ( 614) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    52451834, /* 35153 ( 614) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
     1538636, /* 35154 ( 614) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
     1538472, /* 35155 ( 614) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
    51139634, /* 35156 ( 614) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
    34015424, /* 35157 ( 614) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    51139794, /* 35158 ( 614) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6] -1 */
    17140694, /* 35159 ( 614) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
    17140530, /* 35160 ( 614) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  6]  1 */
    18426650, /* 35161 ( 614) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
       16484, /* 35162 ( 615) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    35563820, /* 35163 ( 615) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
       16320, /* 35164 ( 615) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    35550696, /* 35165 ( 615) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  6] -1 */
    17127570, /* 35166 ( 615) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6]  1 */
    52438710, /* 35167 ( 615) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
        3200, /* 35168 ( 615) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    35550860, /* 35169 ( 615) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
    17127410, /* 35170 ( 615) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
    35563980, /* 35171 ( 615) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6] -1 */
    52451994, /* 35172 ( 615) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
    52451834, /* 35173 ( 615) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
    52438874, /* 35174 ( 615) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
        3360, /* 35175 ( 615) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    17140694, /* 35176 ( 615) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
    17140530, /* 35177 ( 615) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  6]  1 */
       16484, /* 35178 ( 616) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    18426486, /* 35179 ( 616) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
    34146644, /* 35180 ( 616) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
     1538636, /* 35181 ( 616) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
    35445720, /* 35182 ( 616) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  0] -1 */
     1538472, /* 35183 ( 616) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
        3360, /* 35184 ( 616) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    51034658, /* 35185 ( 616) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  0] -1 */
    52556810, /* 35186 ( 616) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    52570094, /* 35187 ( 616) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    18426650, /* 35188 ( 616) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    51034818, /* 35189 ( 616) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  0] -1 */
    51021698, /* 35190 ( 616) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  0] -1 */
     1551596, /* 35191 ( 616) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
    35432600, /* 35192 ( 616) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  0] -1 */
    35445884, /* 35193 ( 616) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  0] -1 */
    17140694, /* 35194 ( 616) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
    34146804, /* 35195 ( 616) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
    17140530, /* 35196 ( 616) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  6]  1 */
    17127410, /* 35197 ( 616) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
       16320, /* 35198 ( 616) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    52569930, /* 35199 ( 616) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
     1551756, /* 35200 ( 616) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
    18439770, /* 35201 ( 616) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
    51021534, /* 35202 ( 616) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  0] -1 */
        3200, /* 35203 ( 616) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    17127570, /* 35204 ( 616) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6]  1 */
    52556970, /* 35205 ( 616) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    34133520, /* 35206 ( 616) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
    34133684, /* 35207 ( 616) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    35432760, /* 35208 ( 616) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  0] -1 */
    18439610, /* 35209 ( 616) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
       16484, /* 35210 ( 617) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    18426486, /* 35211 ( 617) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
     1538636, /* 35212 ( 617) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
     1538472, /* 35213 ( 617) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
        3360, /* 35214 ( 617) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    35432598, /* 35215 ( 617) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  0] -1 */
    18426650, /* 35216 ( 617) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    51034820, /* 35217 ( 617) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  0] -1 */
     1551596, /* 35218 ( 617) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
    35432762, /* 35219 ( 617) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  0] -1 */
    52556972, /* 35220 ( 617) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    17140694, /* 35221 ( 617) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
    34133682, /* 35222 ( 617) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
    51021696, /* 35223 ( 617) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  0] -1 */
    17140530, /* 35224 ( 617) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  6]  1 */
    17127410, /* 35225 ( 617) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
       16320, /* 35226 ( 617) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    35445722, /* 35227 ( 617) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  0] -1 */
    52569932, /* 35228 ( 617) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    52556808, /* 35229 ( 617) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    34146806, /* 35230 ( 617) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    34146642, /* 35231 ( 617) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
    51034656, /* 35232 ( 617) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  0] -1 */
     1551756, /* 35233 ( 617) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
    18439770, /* 35234 ( 617) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
    34133522, /* 35235 ( 617) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    35445882, /* 35236 ( 617) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  0] -1 */
    51021536, /* 35237 ( 617) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  0] -1 */
        3200, /* 35238 ( 617) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    17127570, /* 35239 ( 617) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6]  1 */
    52570092, /* 35240 ( 617) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    18439610, /* 35241 ( 617) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
       16484, /* 35242 ( 618) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    18426486, /* 35243 ( 618) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
     1538636, /* 35244 ( 618) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
     1538472, /* 35245 ( 618) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
        3360, /* 35246 ( 618) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    52438712, /* 35247 ( 618) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
    51139632, /* 35248 ( 618) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  6] -1 */
    18426650, /* 35249 ( 618) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    51152916, /* 35250 ( 618) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6] -1 */
    34015422, /* 35251 ( 618) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
     1551596, /* 35252 ( 618) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
    51139796, /* 35253 ( 618) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
    17140694, /* 35254 ( 618) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
    17140530, /* 35255 ( 618) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  6]  1 */
    17127410, /* 35256 ( 618) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
    34015586, /* 35257 ( 618) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
       16320, /* 35258 ( 618) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    52438872, /* 35259 ( 618) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
    35550858, /* 35260 ( 618) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6] -1 */
    35550698, /* 35261 ( 618) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
    35563982, /* 35262 ( 618) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
    34028706, /* 35263 ( 618) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    52451996, /* 35264 ( 618) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
     1551756, /* 35265 ( 618) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
    51152756, /* 35266 ( 618) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
    18439770, /* 35267 ( 618) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
    34028546, /* 35268 ( 618) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    35563818, /* 35269 ( 618) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  6] -1 */
    52451832, /* 35270 ( 618) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
        3200, /* 35271 ( 618) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    17127570, /* 35272 ( 618) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6]  1 */
    18439610, /* 35273 ( 618) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
       16484, /* 35274 ( 609) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
     1551594, /* 35275 ( 609) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
     1420376, /* 35276 ( 609) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  0]  1 */
    17009472, /* 35277 ( 609) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  0]  1 */
      134420, /* 35278 ( 609) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6]  1 */
    18544586, /* 35279 ( 609) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    17127408, /* 35280 ( 609) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  6]  1 */
     1538636, /* 35281 ( 609) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
    18426650, /* 35282 ( 609) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
     1433658, /* 35283 ( 609) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  0]  1 */
        3198, /* 35284 ( 609) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
      121458, /* 35285 ( 609) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  6]  1 */
    17140694, /* 35286 ( 609) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
    18557868, /* 35287 ( 609) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
    18439608, /* 35288 ( 609) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
    17022434, /* 35289 ( 609) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  0]  1 */
       16484, /* 35290 ( 610) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34146644, /* 35291 ( 610) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    17127408, /* 35292 ( 610) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  6]  1 */
     1538636, /* 35293 ( 610) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
    51152918, /* 35294 ( 610) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
        3198, /* 35295 ( 610) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
      121458, /* 35296 ( 610) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  6]  1 */
    52451832, /* 35297 ( 610) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
    52556810, /* 35298 ( 610) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    35563818, /* 35299 ( 610) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  6] -1 */
    18426650, /* 35300 ( 610) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
      134420, /* 35301 ( 610) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6]  1 */
    35445882, /* 35302 ( 610) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  0] -1 */
    52570092, /* 35303 ( 610) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    35432600, /* 35304 ( 610) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  0] -1 */
    51021696, /* 35305 ( 610) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  0] -1 */
    17140694, /* 35306 ( 610) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
    34028708, /* 35307 ( 610) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    18439608, /* 35308 ( 610) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
    18544586, /* 35309 ( 610) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
     1551594, /* 35310 ( 610) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
    51034658, /* 35311 ( 610) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  0] -1 */
     1433658, /* 35312 ( 610) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  0]  1 */
    18557868, /* 35313 ( 610) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
    34015422, /* 35314 ( 610) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    17009472, /* 35315 ( 610) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  0]  1 */
     1420376, /* 35316 ( 610) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  0]  1 */
    51139632, /* 35317 ( 610) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  6] -1 */
    35550860, /* 35318 ( 610) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
    34133682, /* 35319 ( 610) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
    52438874, /* 35320 ( 610) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
    17022434, /* 35321 ( 610) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  0]  1 */
       16484, /* 35322 ( 611) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
     1551594, /* 35323 ( 611) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
    34015422, /* 35324 ( 611) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    51139632, /* 35325 ( 611) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  6] -1 */
    35550860, /* 35326 ( 611) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
      134420, /* 35327 ( 611) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6]  1 */
    34133682, /* 35328 ( 611) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
     1433658, /* 35329 ( 611) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  0]  1 */
    52438874, /* 35330 ( 611) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
    52556810, /* 35331 ( 611) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    35432600, /* 35332 ( 611) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  0] -1 */
    51021696, /* 35333 ( 611) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  0] -1 */
    17140694, /* 35334 ( 611) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
    18557868, /* 35335 ( 611) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
    18439608, /* 35336 ( 611) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
    17022434, /* 35337 ( 611) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  0]  1 */
       16484, /* 35338 ( 612) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34146644, /* 35339 ( 612) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    34015422, /* 35340 ( 612) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    17009472, /* 35341 ( 612) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  0]  1 */
    51139632, /* 35342 ( 612) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  6] -1 */
    51034658, /* 35343 ( 612) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  0] -1 */
     1538636, /* 35344 ( 612) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
     1433658, /* 35345 ( 612) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  0]  1 */
      121458, /* 35346 ( 612) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  6]  1 */
    52451832, /* 35347 ( 612) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
    52556810, /* 35348 ( 612) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    35432600, /* 35349 ( 612) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  0] -1 */
    17140694, /* 35350 ( 612) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
    18557868, /* 35351 ( 612) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
    35563818, /* 35352 ( 612) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  6] -1 */
    18426650, /* 35353 ( 612) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
       16484, /* 35354 ( 613) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    17009472, /* 35355 ( 613) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  0]  1 */
    35550860, /* 35356 ( 613) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
      134420, /* 35357 ( 613) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6]  1 */
    35445882, /* 35358 ( 613) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  0] -1 */
    52570092, /* 35359 ( 613) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    17127408, /* 35360 ( 613) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  6]  1 */
    52438874, /* 35361 ( 613) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
        3198, /* 35362 ( 613) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
      121458, /* 35363 ( 613) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  6]  1 */
    52451832, /* 35364 ( 613) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
    52556810, /* 35365 ( 613) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    35432600, /* 35366 ( 613) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  0] -1 */
    17140694, /* 35367 ( 613) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
    17022434, /* 35368 ( 613) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  0]  1 */
    35563818, /* 35369 ( 613) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  6] -1 */
       16484, /* 35370 ( 614) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34146644, /* 35371 ( 614) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
     1551594, /* 35372 ( 614) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
    35445882, /* 35373 ( 614) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  0] -1 */
    52570092, /* 35374 ( 614) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    17127408, /* 35375 ( 614) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  6]  1 */
    34133682, /* 35376 ( 614) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
    51034658, /* 35377 ( 614) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  0] -1 */
     1538636, /* 35378 ( 614) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
        3198, /* 35379 ( 614) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    52556810, /* 35380 ( 614) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    35432600, /* 35381 ( 614) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  0] -1 */
    51021696, /* 35382 ( 614) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  0] -1 */
    17140694, /* 35383 ( 614) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
    18439608, /* 35384 ( 614) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
    18426650, /* 35385 ( 614) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
       16484, /* 35386 ( 615) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34146644, /* 35387 ( 615) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
     1551594, /* 35388 ( 615) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
    34015422, /* 35389 ( 615) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    17009472, /* 35390 ( 615) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  0]  1 */
    51139632, /* 35391 ( 615) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  6] -1 */
     1420376, /* 35392 ( 615) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  0]  1 */
    35550860, /* 35393 ( 615) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
    18544586, /* 35394 ( 615) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    35445882, /* 35395 ( 615) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  0] -1 */
    52570092, /* 35396 ( 615) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    51034658, /* 35397 ( 615) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  0] -1 */
    52438874, /* 35398 ( 615) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
      121458, /* 35399 ( 615) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  6]  1 */
    17140694, /* 35400 ( 615) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
    18439608, /* 35401 ( 615) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
       16484, /* 35402 ( 616) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    17127408, /* 35403 ( 616) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  6]  1 */
    35563820, /* 35404 ( 616) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
     1538636, /* 35405 ( 616) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
    34146642, /* 35406 ( 616) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
        3198, /* 35407 ( 616) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
      121458, /* 35408 ( 616) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  6]  1 */
    52451834, /* 35409 ( 616) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
    51139634, /* 35410 ( 616) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
    52570094, /* 35411 ( 616) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    18426650, /* 35412 ( 616) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    51152916, /* 35413 ( 616) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6] -1 */
    51021698, /* 35414 ( 616) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  0] -1 */
      134420, /* 35415 ( 616) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6]  1 */
    34015424, /* 35416 ( 616) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    35445884, /* 35417 ( 616) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  0] -1 */
    17140694, /* 35418 ( 616) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
    34028706, /* 35419 ( 616) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    18439608, /* 35420 ( 616) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
    18544586, /* 35421 ( 616) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
     1551594, /* 35422 ( 616) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
    51034656, /* 35423 ( 616) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  0] -1 */
     1433658, /* 35424 ( 616) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  0]  1 */
    18557868, /* 35425 ( 616) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
    52556808, /* 35426 ( 616) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
     1420376, /* 35427 ( 616) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  0]  1 */
    17009472, /* 35428 ( 616) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  0]  1 */
    52438872, /* 35429 ( 616) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
    35432598, /* 35430 ( 616) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  0] -1 */
    34133684, /* 35431 ( 616) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    35550858, /* 35432 ( 616) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6] -1 */
    17022434, /* 35433 ( 616) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  0]  1 */
       16484, /* 35434 ( 617) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    17127408, /* 35435 ( 617) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  6]  1 */
     1538636, /* 35436 ( 617) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
        3198, /* 35437 ( 617) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
      121458, /* 35438 ( 617) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  6]  1 */
    34133520, /* 35439 ( 617) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
    18426650, /* 35440 ( 617) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    51034820, /* 35441 ( 617) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  0] -1 */
      134420, /* 35442 ( 617) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6]  1 */
    35432762, /* 35443 ( 617) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  0] -1 */
    52556972, /* 35444 ( 617) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    17140694, /* 35445 ( 617) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
    34015584, /* 35446 ( 617) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    51139794, /* 35447 ( 617) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6] -1 */
    18439608, /* 35448 ( 617) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
    18544586, /* 35449 ( 617) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
     1551594, /* 35450 ( 617) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
    34028546, /* 35451 ( 617) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    51152756, /* 35452 ( 617) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
    51021534, /* 35453 ( 617) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  0] -1 */
    34146806, /* 35454 ( 617) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    35445720, /* 35455 ( 617) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  0] -1 */
    52569930, /* 35456 ( 617) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
     1433658, /* 35457 ( 617) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  0]  1 */
    18557868, /* 35458 ( 617) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
    35550698, /* 35459 ( 617) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
    35563980, /* 35460 ( 617) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6] -1 */
    52438712, /* 35461 ( 617) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
     1420376, /* 35462 ( 617) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  0]  1 */
    17009472, /* 35463 ( 617) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  0]  1 */
    52451994, /* 35464 ( 617) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
    17022434, /* 35465 ( 617) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  0]  1 */
       16484, /* 35466 ( 618) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    17127408, /* 35467 ( 618) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  6]  1 */
     1538636, /* 35468 ( 618) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
        3198, /* 35469 ( 618) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
      121458, /* 35470 ( 618) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  6]  1 */
    51021536, /* 35471 ( 618) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  0] -1 */
    52438710, /* 35472 ( 618) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
    18426650, /* 35473 ( 618) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    51034818, /* 35474 ( 618) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  0] -1 */
    35550696, /* 35475 ( 618) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  6] -1 */
      134420, /* 35476 ( 618) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6]  1 */
    51139796, /* 35477 ( 618) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
    17140694, /* 35478 ( 618) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
    18439608, /* 35479 ( 618) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
    18544586, /* 35480 ( 618) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    34015586, /* 35481 ( 618) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
     1551594, /* 35482 ( 618) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
    52556970, /* 35483 ( 618) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    35432760, /* 35484 ( 618) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  0] -1 */
    34133522, /* 35485 ( 618) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    35563982, /* 35486 ( 618) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
    34146804, /* 35487 ( 618) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
    52451996, /* 35488 ( 618) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
     1433658, /* 35489 ( 618) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  0]  1 */
    52569932, /* 35490 ( 618) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    18557868, /* 35491 ( 618) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
    35445722, /* 35492 ( 618) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  0] -1 */
    34028544, /* 35493 ( 618) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    51152754, /* 35494 ( 618) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  6] -1 */
     1420376, /* 35495 ( 618) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  0]  1 */
    17009472, /* 35496 ( 618) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  0]  1 */
    17022434, /* 35497 ( 618) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  0]  1 */
       16484, /* 35498 ( 619) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    18439608, /* 35499 ( 619) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
    17140694, /* 35500 ( 619) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
    17127570, /* 35501 ( 619) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6]  1 */
       16320, /* 35502 ( 619) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    18426486, /* 35503 ( 619) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
     1551596, /* 35504 ( 619) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
     1538636, /* 35505 ( 619) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
        3198, /* 35506 ( 619) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    17127410, /* 35507 ( 619) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
    17140532, /* 35508 ( 619) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
    17127572, /* 35509 ( 619) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
     1538474, /* 35510 ( 619) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
     1551756, /* 35511 ( 619) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
    18439772, /* 35512 ( 619) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    17140530, /* 35513 ( 619) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  6]  1 */
    18426648, /* 35514 ( 619) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
    17127408, /* 35515 ( 619) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  6]  1 */
     1551594, /* 35516 ( 619) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
    17140692, /* 35517 ( 619) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6]  1 */
    18439610, /* 35518 ( 619) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
     1538472, /* 35519 ( 619) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
    18426650, /* 35520 ( 619) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
        3360, /* 35521 ( 619) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
       16322, /* 35522 ( 619) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    18426488, /* 35523 ( 619) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
        3200, /* 35524 ( 619) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
        3362, /* 35525 ( 619) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
     1551758, /* 35526 ( 619) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
    18439770, /* 35527 ( 619) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
       16482, /* 35528 ( 619) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
     1538634, /* 35529 ( 619) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
       16484, /* 35530 ( 620) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    18439608, /* 35531 ( 620) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
    17140694, /* 35532 ( 620) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
    17127570, /* 35533 ( 620) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6]  1 */
       16320, /* 35534 ( 620) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    18426486, /* 35535 ( 620) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
     1551596, /* 35536 ( 620) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
    35563980, /* 35537 ( 620) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6] -1 */
     1538636, /* 35538 ( 620) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
    52451996, /* 35539 ( 620) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
        3198, /* 35540 ( 620) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    51152754, /* 35541 ( 620) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  6] -1 */
    17127410, /* 35542 ( 620) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
    17140532, /* 35543 ( 620) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
    51152916, /* 35544 ( 620) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6] -1 */
    52438872, /* 35545 ( 620) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
    51139632, /* 35546 ( 620) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  6] -1 */
    35563818, /* 35547 ( 620) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  6] -1 */
    17127572, /* 35548 ( 620) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
    52451834, /* 35549 ( 620) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
    35550696, /* 35550 ( 620) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  6] -1 */
     1538474, /* 35551 ( 620) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
    52438874, /* 35552 ( 620) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
    34015584, /* 35553 ( 620) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
     1551756, /* 35554 ( 620) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
    18439772, /* 35555 ( 620) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    34015424, /* 35556 ( 620) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    34028708, /* 35557 ( 620) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    17140530, /* 35558 ( 620) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  6]  1 */
    52438712, /* 35559 ( 620) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
    34028546, /* 35560 ( 620) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    18426648, /* 35561 ( 620) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
    17127408, /* 35562 ( 620) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  6]  1 */
     1551594, /* 35563 ( 620) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
    17140692, /* 35564 ( 620) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6]  1 */
    34015586, /* 35565 ( 620) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    18439610, /* 35566 ( 620) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
     1538472, /* 35567 ( 620) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
    34028706, /* 35568 ( 620) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    35563982, /* 35569 ( 620) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
    52451994, /* 35570 ( 620) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
    18426650, /* 35571 ( 620) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    51152918, /* 35572 ( 620) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
        3360, /* 35573 ( 620) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    35550858, /* 35574 ( 620) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6] -1 */
    34028544, /* 35575 ( 620) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    52451832, /* 35576 ( 620) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
       16322, /* 35577 ( 620) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    18426488, /* 35578 ( 620) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    51139794, /* 35579 ( 620) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6] -1 */
    35563820, /* 35580 ( 620) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
    34015422, /* 35581 ( 620) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    52438710, /* 35582 ( 620) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
        3200, /* 35583 ( 620) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    51152756, /* 35584 ( 620) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
        3362, /* 35585 ( 620) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    35550860, /* 35586 ( 620) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
    51139634, /* 35587 ( 620) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
    51139796, /* 35588 ( 620) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
     1551758, /* 35589 ( 620) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
    35550698, /* 35590 ( 620) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
    18439770, /* 35591 ( 620) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
       16482, /* 35592 ( 620) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
     1538634, /* 35593 ( 620) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
       16484, /* 35594 ( 621) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    18439608, /* 35595 ( 621) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
    17140694, /* 35596 ( 621) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
       16320, /* 35597 ( 621) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
     1551596, /* 35598 ( 621) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
    17140532, /* 35599 ( 621) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
    52438872, /* 35600 ( 621) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
    51139632, /* 35601 ( 621) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  6] -1 */
    35550696, /* 35602 ( 621) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  6] -1 */
    52438874, /* 35603 ( 621) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
    34015584, /* 35604 ( 621) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
     1551756, /* 35605 ( 621) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
    18439772, /* 35606 ( 621) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    52438712, /* 35607 ( 621) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
    34015424, /* 35608 ( 621) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    17140530, /* 35609 ( 621) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  6]  1 */
    34015586, /* 35610 ( 621) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
     1551594, /* 35611 ( 621) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
    17140692, /* 35612 ( 621) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6]  1 */
    18439610, /* 35613 ( 621) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    35550858, /* 35614 ( 621) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6] -1 */
       16322, /* 35615 ( 621) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    51139794, /* 35616 ( 621) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6] -1 */
    34015422, /* 35617 ( 621) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    52438710, /* 35618 ( 621) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
    35550860, /* 35619 ( 621) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
    51139634, /* 35620 ( 621) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
    51139796, /* 35621 ( 621) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
     1551758, /* 35622 ( 621) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
    35550698, /* 35623 ( 621) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
    18439770, /* 35624 ( 621) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
       16482, /* 35625 ( 621) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
       16484, /* 35626 ( 622) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    17140694, /* 35627 ( 622) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
    18426486, /* 35628 ( 622) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
        3198, /* 35629 ( 622) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    51152754, /* 35630 ( 622) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  6] -1 */
    17127410, /* 35631 ( 622) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
    52438872, /* 35632 ( 622) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
    35563818, /* 35633 ( 622) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  6] -1 */
    52451834, /* 35634 ( 622) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
     1538474, /* 35635 ( 622) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
    52438874, /* 35636 ( 622) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
    34015584, /* 35637 ( 622) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
     1551756, /* 35638 ( 622) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
    18439772, /* 35639 ( 622) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    34028546, /* 35640 ( 622) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    34015586, /* 35641 ( 622) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    17127408, /* 35642 ( 622) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  6]  1 */
    17140692, /* 35643 ( 622) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6]  1 */
     1538472, /* 35644 ( 622) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
    35550858, /* 35645 ( 622) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6] -1 */
    34028544, /* 35646 ( 622) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    52451832, /* 35647 ( 622) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
    35563820, /* 35648 ( 622) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
    18426488, /* 35649 ( 622) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    51139794, /* 35650 ( 622) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6] -1 */
        3200, /* 35651 ( 622) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    51152756, /* 35652 ( 622) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
    35550860, /* 35653 ( 622) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
    51139796, /* 35654 ( 622) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
     1551758, /* 35655 ( 622) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
    18439770, /* 35656 ( 622) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
       16482, /* 35657 ( 622) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
       16484, /* 35658 ( 623) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    18439608, /* 35659 ( 623) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
    17140694, /* 35660 ( 623) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
    17127570, /* 35661 ( 623) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6]  1 */
       16320, /* 35662 ( 623) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    35563980, /* 35663 ( 623) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6] -1 */
    17127410, /* 35664 ( 623) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
    51152916, /* 35665 ( 623) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6] -1 */
    51139632, /* 35666 ( 623) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  6] -1 */
    52451834, /* 35667 ( 623) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
    35550696, /* 35668 ( 623) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  6] -1 */
     1538474, /* 35669 ( 623) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
    52438874, /* 35670 ( 623) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
    18439772, /* 35671 ( 623) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    34028546, /* 35672 ( 623) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    17140530, /* 35673 ( 623) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  6]  1 */
    34015586, /* 35674 ( 623) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    18426648, /* 35675 ( 623) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
     1551594, /* 35676 ( 623) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
    34028706, /* 35677 ( 623) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    52451994, /* 35678 ( 623) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
        3360, /* 35679 ( 623) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    35563820, /* 35680 ( 623) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
    18426488, /* 35681 ( 623) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    34015422, /* 35682 ( 623) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    52438710, /* 35683 ( 623) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
        3200, /* 35684 ( 623) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    51152756, /* 35685 ( 623) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
    35550860, /* 35686 ( 623) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
    51139796, /* 35687 ( 623) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
     1551758, /* 35688 ( 623) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
     1538634, /* 35689 ( 623) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
       16484, /* 35690 ( 624) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    35445882, /* 35691 ( 624) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  0] -1 */
    18439608, /* 35692 ( 624) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
    17140694, /* 35693 ( 624) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
    17127570, /* 35694 ( 624) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6]  1 */
       16320, /* 35695 ( 624) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    18426486, /* 35696 ( 624) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
     1551596, /* 35697 ( 624) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
     1538636, /* 35698 ( 624) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
    35445720, /* 35699 ( 624) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  0] -1 */
        3198, /* 35700 ( 624) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    52556970, /* 35701 ( 624) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    17127410, /* 35702 ( 624) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
    17140532, /* 35703 ( 624) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
    35432598, /* 35704 ( 624) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  0] -1 */
    51021696, /* 35705 ( 624) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  0] -1 */
    52570094, /* 35706 ( 624) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    17127572, /* 35707 ( 624) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
    51034658, /* 35708 ( 624) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  0] -1 */
     1538474, /* 35709 ( 624) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
    51034820, /* 35710 ( 624) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  0] -1 */
    51021698, /* 35711 ( 624) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  0] -1 */
    34146644, /* 35712 ( 624) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    52569932, /* 35713 ( 624) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    34146806, /* 35714 ( 624) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
     1551756, /* 35715 ( 624) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
    52556972, /* 35716 ( 624) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    51021536, /* 35717 ( 624) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  0] -1 */
    18439772, /* 35718 ( 624) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    34133684, /* 35719 ( 624) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    34133682, /* 35720 ( 624) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
    17140530, /* 35721 ( 624) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  6]  1 */
    18426648, /* 35722 ( 624) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
    17127408, /* 35723 ( 624) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  6]  1 */
     1551594, /* 35724 ( 624) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
    52556810, /* 35725 ( 624) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    17140692, /* 35726 ( 624) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6]  1 */
    34133522, /* 35727 ( 624) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    18439610, /* 35728 ( 624) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
     1538472, /* 35729 ( 624) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
    51034656, /* 35730 ( 624) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  0] -1 */
    51034818, /* 35731 ( 624) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  0] -1 */
    35432760, /* 35732 ( 624) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  0] -1 */
    18426650, /* 35733 ( 624) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    51021534, /* 35734 ( 624) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  0] -1 */
    35445722, /* 35735 ( 624) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  0] -1 */
    35445884, /* 35736 ( 624) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  0] -1 */
    34146642, /* 35737 ( 624) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
    52569930, /* 35738 ( 624) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
        3360, /* 35739 ( 624) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    52570092, /* 35740 ( 624) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    34146804, /* 35741 ( 624) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
    52556808, /* 35742 ( 624) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    18426488, /* 35743 ( 624) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
       16322, /* 35744 ( 624) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
        3200, /* 35745 ( 624) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
        3362, /* 35746 ( 624) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    35432600, /* 35747 ( 624) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  0] -1 */
    35432762, /* 35748 ( 624) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  0] -1 */
    34133520, /* 35749 ( 624) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
     1551758, /* 35750 ( 624) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
    18439770, /* 35751 ( 624) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
       16482, /* 35752 ( 624) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
     1538634, /* 35753 ( 624) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
       16484, /* 35754 ( 625) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    17127570, /* 35755 ( 625) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6]  1 */
    17140694, /* 35756 ( 625) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
        3200, /* 35757 ( 625) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    18439608, /* 35758 ( 625) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
    27697179, /* 35759 ( 625) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 9,  9,  3]  1 */
     1538474, /* 35760 ( 625) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
     1551594, /* 35761 ( 625) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
     9273891, /* 35762 ( 625) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 3,  3,  3]  1 */
        3360, /* 35763 ( 625) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    17140530, /* 35764 ( 625) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  6]  1 */
    26411225, /* 35765 ( 625) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 9,  3,  9]  1 */
     1538634, /* 35766 ( 625) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
       16320, /* 35767 ( 625) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    27710303, /* 35768 ( 625) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 9,  9,  3]  1 */
    18426648, /* 35769 ( 625) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
     9287015, /* 35770 ( 625) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 3,  3,  3]  1 */
    26411385, /* 35771 ( 625) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 9,  3,  9]  1 */
    10822289, /* 35772 ( 625) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 3,  9,  9]  1 */
    27710463, /* 35773 ( 625) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 9,  9,  3]  1 */
    18439772, /* 35774 ( 625) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    26398101, /* 35775 ( 625) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 9,  3,  9]  1 */
    17127410, /* 35776 ( 625) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
    18426488, /* 35777 ( 625) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    10809165, /* 35778 ( 625) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 3,  9,  9]  1 */
     9287175, /* 35779 ( 625) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 3,  3,  3]  1 */
    26398265, /* 35780 ( 625) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 9,  3,  9]  1 */
    10822449, /* 35781 ( 625) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 3,  9,  9]  1 */
    27697343, /* 35782 ( 625) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 9,  9,  3]  1 */
     9274055, /* 35783 ( 625) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 3,  3,  3]  1 */
     1551758, /* 35784 ( 625) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
    10809329, /* 35785 ( 625) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 3,  9,  9]  1 */
       16484, /* 35786 ( 626) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    61722687, /* 35787 ( 626) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 9,  9,  3] -1 */
    44834513, /* 35788 ( 626) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 3,  9,  9] -1 */
    17127570, /* 35789 ( 626) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6]  1 */
    17140694, /* 35790 ( 626) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
        3200, /* 35791 ( 626) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    18439608, /* 35792 ( 626) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
    27697179, /* 35793 ( 626) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 9,  9,  3]  1 */
     1538474, /* 35794 ( 626) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
     1551594, /* 35795 ( 626) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
     9273891, /* 35796 ( 626) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 3,  3,  3]  1 */
    52451996, /* 35797 ( 626) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
    17140530, /* 35798 ( 626) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  6]  1 */
        3360, /* 35799 ( 626) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    51139634, /* 35800 ( 626) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
    26411225, /* 35801 ( 626) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 9,  3,  9]  1 */
     1538634, /* 35802 ( 626) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
    60410325, /* 35803 ( 626) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 9,  3,  9] -1 */
       16320, /* 35804 ( 626) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    27710303, /* 35805 ( 626) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 9,  9,  3]  1 */
    52438712, /* 35806 ( 626) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
    44821389, /* 35807 ( 626) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 3,  9,  9] -1 */
    18426648, /* 35808 ( 626) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
     9287015, /* 35809 ( 626) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 3,  3,  3]  1 */
    26411385, /* 35810 ( 626) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 9,  3,  9]  1 */
    10822289, /* 35811 ( 626) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 3,  9,  9]  1 */
    27710463, /* 35812 ( 626) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 9,  9,  3]  1 */
    61722527, /* 35813 ( 626) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 9,  9,  3] -1 */
    18439772, /* 35814 ( 626) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    43299399, /* 35815 ( 626) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 3,  3,  3] -1 */
    34028708, /* 35816 ( 626) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    26398101, /* 35817 ( 626) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 9,  3,  9]  1 */
    60410489, /* 35818 ( 626) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 9,  3,  9] -1 */
    17127410, /* 35819 ( 626) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
    44834673, /* 35820 ( 626) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 3,  9,  9] -1 */
    43286279, /* 35821 ( 626) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 3,  3,  3] -1 */
    18426488, /* 35822 ( 626) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    10809165, /* 35823 ( 626) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 3,  9,  9]  1 */
    61709567, /* 35824 ( 626) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 9,  9,  3] -1 */
    35563982, /* 35825 ( 626) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
    52438872, /* 35826 ( 626) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
    44821553, /* 35827 ( 626) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 3,  9,  9] -1 */
    51152918, /* 35828 ( 626) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
    34015424, /* 35829 ( 626) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    51139794, /* 35830 ( 626) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6] -1 */
     9287175, /* 35831 ( 626) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 3,  3,  3]  1 */
    34015584, /* 35832 ( 626) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    43286115, /* 35833 ( 626) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 3,  3,  3] -1 */
    52451832, /* 35834 ( 626) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
    61709403, /* 35835 ( 626) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 9,  9,  3] -1 */
    51152754, /* 35836 ( 626) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  6] -1 */
    35550698, /* 35837 ( 626) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
    35563818, /* 35838 ( 626) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  6] -1 */
    26398265, /* 35839 ( 626) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 9,  3,  9]  1 */
    10822449, /* 35840 ( 626) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 3,  9,  9]  1 */
    35550858, /* 35841 ( 626) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6] -1 */
    60423449, /* 35842 ( 626) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 9,  3,  9] -1 */
    27697343, /* 35843 ( 626) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 9,  9,  3]  1 */
    43299239, /* 35844 ( 626) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 3,  3,  3] -1 */
     9274055, /* 35845 ( 626) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 3,  3,  3]  1 */
     1551758, /* 35846 ( 626) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
    34028544, /* 35847 ( 626) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    10809329, /* 35848 ( 626) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 3,  9,  9]  1 */
    60423609, /* 35849 ( 626) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 9,  3,  9] -1 */
       16484, /* 35850 ( 627) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    17140694, /* 35851 ( 627) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
    18439608, /* 35852 ( 627) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
     1551594, /* 35853 ( 627) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
    17140530, /* 35854 ( 627) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  6]  1 */
    51139634, /* 35855 ( 627) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
    26411225, /* 35856 ( 627) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 9,  3,  9]  1 */
    60410325, /* 35857 ( 627) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 9,  3,  9] -1 */
       16320, /* 35858 ( 627) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    27710303, /* 35859 ( 627) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 9,  9,  3]  1 */
    52438712, /* 35860 ( 627) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
    44821389, /* 35861 ( 627) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 3,  9,  9] -1 */
     9287015, /* 35862 ( 627) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 3,  3,  3]  1 */
    26411385, /* 35863 ( 627) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 9,  3,  9]  1 */
    10822289, /* 35864 ( 627) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 3,  9,  9]  1 */
    27710463, /* 35865 ( 627) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 9,  9,  3]  1 */
    18439772, /* 35866 ( 627) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    60410489, /* 35867 ( 627) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 9,  3,  9] -1 */
    43286279, /* 35868 ( 627) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 3,  3,  3] -1 */
    61709567, /* 35869 ( 627) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 9,  9,  3] -1 */
    44821553, /* 35870 ( 627) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 3,  9,  9] -1 */
    34015424, /* 35871 ( 627) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    51139794, /* 35872 ( 627) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6] -1 */
     9287175, /* 35873 ( 627) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 3,  3,  3]  1 */
    34015584, /* 35874 ( 627) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    43286115, /* 35875 ( 627) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 3,  3,  3] -1 */
    61709403, /* 35876 ( 627) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 9,  9,  3] -1 */
    35550698, /* 35877 ( 627) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
    35550858, /* 35878 ( 627) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6] -1 */
    10822449, /* 35879 ( 627) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 3,  9,  9]  1 */
     1551758, /* 35880 ( 627) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
    52438872, /* 35881 ( 627) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
       16484, /* 35882 ( 628) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    44834513, /* 35883 ( 628) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 3,  9,  9] -1 */
    17140694, /* 35884 ( 628) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
        3200, /* 35885 ( 628) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    27697179, /* 35886 ( 628) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 9,  9,  3]  1 */
     1538474, /* 35887 ( 628) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
     9273891, /* 35888 ( 628) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 3,  3,  3]  1 */
    26411385, /* 35889 ( 628) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 9,  3,  9]  1 */
    27710463, /* 35890 ( 628) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 9,  9,  3]  1 */
    61722527, /* 35891 ( 628) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 9,  9,  3] -1 */
    18439772, /* 35892 ( 628) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    26398101, /* 35893 ( 628) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 9,  3,  9]  1 */
    60410489, /* 35894 ( 628) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 9,  3,  9] -1 */
    17127410, /* 35895 ( 628) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
    43286279, /* 35896 ( 628) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 3,  3,  3] -1 */
    18426488, /* 35897 ( 628) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    10809165, /* 35898 ( 628) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 3,  9,  9]  1 */
    61709567, /* 35899 ( 628) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 9,  9,  3] -1 */
    44821553, /* 35900 ( 628) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 3,  9,  9] -1 */
    51139794, /* 35901 ( 628) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6] -1 */
     9287175, /* 35902 ( 628) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 3,  3,  3]  1 */
    34015584, /* 35903 ( 628) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    52451832, /* 35904 ( 628) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
    51152754, /* 35905 ( 628) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  6] -1 */
    35563818, /* 35906 ( 628) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  6] -1 */
    35550858, /* 35907 ( 628) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6] -1 */
    10822449, /* 35908 ( 628) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 3,  9,  9]  1 */
    60423449, /* 35909 ( 628) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 9,  3,  9] -1 */
    43299239, /* 35910 ( 628) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 3,  3,  3] -1 */
     1551758, /* 35911 ( 628) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
    34028544, /* 35912 ( 628) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    52438872, /* 35913 ( 628) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
       16484, /* 35914 ( 629) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    61722687, /* 35915 ( 629) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 9,  9,  3] -1 */
    44834513, /* 35916 ( 629) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 3,  9,  9] -1 */
    17127570, /* 35917 ( 629) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6]  1 */
    17140694, /* 35918 ( 629) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
        3200, /* 35919 ( 629) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    18439608, /* 35920 ( 629) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
     1538474, /* 35921 ( 629) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
     1551594, /* 35922 ( 629) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
        3360, /* 35923 ( 629) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    17140530, /* 35924 ( 629) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  6]  1 */
     1538634, /* 35925 ( 629) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
    60410325, /* 35926 ( 629) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 9,  3,  9] -1 */
       16320, /* 35927 ( 629) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    18426648, /* 35928 ( 629) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
    44821389, /* 35929 ( 629) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 3,  9,  9] -1 */
    43299399, /* 35930 ( 629) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 3,  3,  3] -1 */
    18439772, /* 35931 ( 629) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    60410489, /* 35932 ( 629) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 9,  3,  9] -1 */
    17127410, /* 35933 ( 629) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
    44834673, /* 35934 ( 629) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 3,  9,  9] -1 */
    43286279, /* 35935 ( 629) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 3,  3,  3] -1 */
    18426488, /* 35936 ( 629) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    61709567, /* 35937 ( 629) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 9,  9,  3] -1 */
    44821553, /* 35938 ( 629) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 3,  9,  9] -1 */
    43286115, /* 35939 ( 629) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 3,  3,  3] -1 */
    61709403, /* 35940 ( 629) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 9,  9,  3] -1 */
    60423449, /* 35941 ( 629) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 9,  3,  9] -1 */
    43299239, /* 35942 ( 629) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 3,  3,  3] -1 */
     1551758, /* 35943 ( 629) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
    61722527, /* 35944 ( 629) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 9,  9,  3] -1 */
    60423609, /* 35945 ( 629) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 9,  3,  9] -1 */
       16484, /* 35946 ( 630) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    17127570, /* 35947 ( 630) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6]  1 */
    17140694, /* 35948 ( 630) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
        3200, /* 35949 ( 630) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    18439608, /* 35950 ( 630) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
    27697179, /* 35951 ( 630) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 9,  9,  3]  1 */
     1538474, /* 35952 ( 630) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
     1551594, /* 35953 ( 630) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
     9273891, /* 35954 ( 630) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 3,  3,  3]  1 */
        3360, /* 35955 ( 630) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    17140530, /* 35956 ( 630) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  6]  1 */
    26411225, /* 35957 ( 630) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 9,  3,  9]  1 */
    44703291, /* 35958 ( 630) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 3,  9,  3] -1 */
     1538634, /* 35959 ( 630) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
    52570094, /* 35960 ( 630) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    52556810, /* 35961 ( 630) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
       16320, /* 35962 ( 630) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    27710303, /* 35963 ( 630) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 9,  9,  3]  1 */
    18426648, /* 35964 ( 630) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
     9287015, /* 35965 ( 630) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 3,  3,  3]  1 */
    26411385, /* 35966 ( 630) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 9,  3,  9]  1 */
    51034820, /* 35967 ( 630) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  0] -1 */
    10822289, /* 35968 ( 630) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 3,  9,  9]  1 */
    27710463, /* 35969 ( 630) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 9,  9,  3]  1 */
    43417497, /* 35970 ( 630) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 3,  3,  9] -1 */
    34146806, /* 35971 ( 630) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    18439772, /* 35972 ( 630) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    26398101, /* 35973 ( 630) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 9,  3,  9]  1 */
    17127410, /* 35974 ( 630) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
    60292391, /* 35975 ( 630) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 9,  3,  3] -1 */
    18426488, /* 35976 ( 630) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    10809165, /* 35977 ( 630) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 3,  9,  9]  1 */
    44703455, /* 35978 ( 630) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 3,  9,  3] -1 */
    51021536, /* 35979 ( 630) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  0] -1 */
    34133522, /* 35980 ( 630) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    60292227, /* 35981 ( 630) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 9,  3,  3] -1 */
    43404377, /* 35982 ( 630) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 3,  3,  9] -1 */
    35445884, /* 35983 ( 630) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  0] -1 */
    61827665, /* 35984 ( 630) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 9,  9,  9] -1 */
    34133682, /* 35985 ( 630) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
    35432600, /* 35986 ( 630) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  0] -1 */
    61827501, /* 35987 ( 630) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 9,  9,  9] -1 */
     9287175, /* 35988 ( 630) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 3,  3,  3]  1 */
    35432760, /* 35989 ( 630) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  0] -1 */
    44716575, /* 35990 ( 630) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 3,  9,  3] -1 */
    60305351, /* 35991 ( 630) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 9,  3,  3] -1 */
    51021696, /* 35992 ( 630) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  0] -1 */
    26398265, /* 35993 ( 630) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 9,  3,  9]  1 */
    61840625, /* 35994 ( 630) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 9,  9,  9] -1 */
    52569930, /* 35995 ( 630) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    10822449, /* 35996 ( 630) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 3,  9,  9]  1 */
    34146642, /* 35997 ( 630) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
    43417337, /* 35998 ( 630) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 3,  3,  9] -1 */
    43404213, /* 35999 ( 630) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 3,  3,  9] -1 */
    52556970, /* 36000 ( 630) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    27697343, /* 36001 ( 630) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 9,  9,  3]  1 */
    60305511, /* 36002 ( 630) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 9,  3,  3] -1 */
     9274055, /* 36003 ( 630) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 3,  3,  3]  1 */
     1551758, /* 36004 ( 630) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
    35445720, /* 36005 ( 630) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  0] -1 */
    51034656, /* 36006 ( 630) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  0] -1 */
    44716415, /* 36007 ( 630) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 3,  9,  3] -1 */
    61840785, /* 36008 ( 630) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 9,  9,  9] -1 */
    10809329, /* 36009 ( 630) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 3,  9,  9]  1 */
       16484, /* 36010 ( 625) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
     8565465, /* 36011 ( 625) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 3,  0,  3]  1 */
    17140694, /* 36012 ( 625) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
    27638132, /* 36013 ( 625) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 9,  9,  0]  1 */
    17908167, /* 36014 ( 625) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  3,  9]  1 */
    18426486, /* 36015 ( 625) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
    26339054, /* 36016 ( 625) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 9,  3,  6]  1 */
      783957, /* 36017 ( 625) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  3,  3]  1 */
        3198, /* 36018 ( 625) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    25689675, /* 36019 ( 625) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 9,  0,  9]  1 */
    19207245, /* 36020 ( 625) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  9,  3]  1 */
    25702637, /* 36021 ( 625) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 9,  0,  9]  1 */
    26988753, /* 36022 ( 625) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 9,  6,  3]  1 */
     2319231, /* 36023 ( 625) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  9,  9]  1 */
    27001715, /* 36024 ( 625) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 9,  6,  3]  1 */
    10100739, /* 36025 ( 625) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 3,  6,  9]  1 */
     8578427, /* 36026 ( 625) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 3,  0,  3]  1 */
    26352336, /* 36027 ( 625) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 9,  3,  6]  1 */
    10113701, /* 36028 ( 625) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 3,  6,  9]  1 */
    27651414, /* 36029 ( 625) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 9,  9,  0]  1 */
    18439772, /* 36030 ( 625) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    17127408, /* 36031 ( 625) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  6]  1 */
    10750118, /* 36032 ( 625) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 3,  9,  6]  1 */
     9214844, /* 36033 ( 625) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 3,  3,  0]  1 */
     1538472, /* 36034 ( 625) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
     9228126, /* 36035 ( 625) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 3,  3,  0]  1 */
    17895209, /* 36036 ( 625) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  3,  9]  1 */
    10763400, /* 36037 ( 625) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 3,  9,  6]  1 */
    19194287, /* 36038 ( 625) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  9,  3]  1 */
      770999, /* 36039 ( 625) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  3,  3]  1 */
     1551758, /* 36040 ( 625) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
     2306273, /* 36041 ( 625) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  9,  9]  1 */
       16484, /* 36042 ( 626) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    61663638, /* 36043 ( 626) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 9,  9,  0] -1 */
    44125925, /* 36044 ( 626) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 3,  6,  9] -1 */
     8565465, /* 36045 ( 626) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 3,  0,  3]  1 */
    17140694, /* 36046 ( 626) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
    27638132, /* 36047 ( 626) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 9,  9,  0]  1 */
    17908167, /* 36048 ( 626) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  3,  9]  1 */
    18426486, /* 36049 ( 626) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
    26339054, /* 36050 ( 626) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 9,  3,  6]  1 */
      783957, /* 36051 ( 626) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  3,  3]  1 */
        3198, /* 36052 ( 626) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    52451996, /* 36053 ( 626) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
    19207245, /* 36054 ( 626) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  9,  3]  1 */
    25689675, /* 36055 ( 626) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 9,  0,  9]  1 */
    44762342, /* 36056 ( 626) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 3,  9,  6] -1 */
    25702637, /* 36057 ( 626) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 9,  0,  9]  1 */
    26988753, /* 36058 ( 626) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 9,  6,  3]  1 */
    51139632, /* 36059 ( 626) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  6] -1 */
     2319231, /* 36060 ( 626) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  9,  9]  1 */
    27001715, /* 36061 ( 626) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 9,  6,  3]  1 */
    43227068, /* 36062 ( 626) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 3,  3,  0] -1 */
    35550696, /* 36063 ( 626) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  6] -1 */
    10100739, /* 36064 ( 626) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 3,  6,  9]  1 */
     8578427, /* 36065 ( 626) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 3,  0,  3]  1 */
    26352336, /* 36066 ( 626) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 9,  3,  6]  1 */
    10113701, /* 36067 ( 626) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 3,  6,  9]  1 */
    27651414, /* 36068 ( 626) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 9,  9,  0]  1 */
    61013939, /* 36069 ( 626) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 9,  6,  3] -1 */
    18439772, /* 36070 ( 626) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    43240350, /* 36071 ( 626) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 3,  3,  0] -1 */
    34028708, /* 36072 ( 626) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    17127408, /* 36073 ( 626) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  6]  1 */
    51907433, /* 36074 ( 626) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  3,  9] -1 */
    10750118, /* 36075 ( 626) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 3,  9,  6]  1 */
    44775624, /* 36076 ( 626) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 3,  9,  6] -1 */
    34783223, /* 36077 ( 626) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  3,  3] -1 */
     9214844, /* 36078 ( 626) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 3,  3,  0]  1 */
     1538472, /* 36079 ( 626) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
    53206511, /* 36080 ( 626) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  9,  3] -1 */
    35563982, /* 36081 ( 626) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
    44112963, /* 36082 ( 626) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 3,  6,  9] -1 */
    36318497, /* 36083 ( 626) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  9,  9] -1 */
    51152918, /* 36084 ( 626) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
    61650356, /* 36085 ( 626) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 9,  9,  0] -1 */
    42577689, /* 36086 ( 626) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 3,  0,  3] -1 */
     9228126, /* 36087 ( 626) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 3,  3,  0]  1 */
    59701899, /* 36088 ( 626) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 9,  0,  9] -1 */
    34015422, /* 36089 ( 626) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    51920391, /* 36090 ( 626) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  3,  9] -1 */
    52438710, /* 36091 ( 626) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
    53219469, /* 36092 ( 626) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  9,  3] -1 */
    60351278, /* 36093 ( 626) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 9,  3,  6] -1 */
    34796181, /* 36094 ( 626) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  3,  3] -1 */
    17895209, /* 36095 ( 626) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  3,  9]  1 */
    10763400, /* 36096 ( 626) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 3,  9,  6]  1 */
    61000977, /* 36097 ( 626) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 9,  6,  3] -1 */
    59714861, /* 36098 ( 626) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 9,  0,  9] -1 */
    19194287, /* 36099 ( 626) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  9,  3]  1 */
    42590651, /* 36100 ( 626) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 3,  0,  3] -1 */
      770999, /* 36101 ( 626) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  3,  3]  1 */
     1551758, /* 36102 ( 626) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
    36331455, /* 36103 ( 626) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  9,  9] -1 */
     2306273, /* 36104 ( 626) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  9,  9]  1 */
    60364560, /* 36105 ( 626) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 9,  3,  6] -1 */
       16484, /* 36106 ( 627) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    17140694, /* 36107 ( 627) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
    17908167, /* 36108 ( 627) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  3,  9]  1 */
      783957, /* 36109 ( 627) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  3,  3]  1 */
    19207245, /* 36110 ( 627) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  9,  3]  1 */
    44762342, /* 36111 ( 627) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 3,  9,  6] -1 */
    25702637, /* 36112 ( 627) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 9,  0,  9]  1 */
    51139632, /* 36113 ( 627) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  6] -1 */
     2319231, /* 36114 ( 627) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  9,  9]  1 */
    27001715, /* 36115 ( 627) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 9,  6,  3]  1 */
    43227068, /* 36116 ( 627) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 3,  3,  0] -1 */
    35550696, /* 36117 ( 627) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  6] -1 */
     8578427, /* 36118 ( 627) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 3,  0,  3]  1 */
    26352336, /* 36119 ( 627) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 9,  3,  6]  1 */
    10113701, /* 36120 ( 627) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 3,  6,  9]  1 */
    27651414, /* 36121 ( 627) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 9,  9,  0]  1 */
    18439772, /* 36122 ( 627) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    51907433, /* 36123 ( 627) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  3,  9] -1 */
    34783223, /* 36124 ( 627) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  3,  3] -1 */
    53206511, /* 36125 ( 627) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  9,  3] -1 */
    36318497, /* 36126 ( 627) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  9,  9] -1 */
    61650356, /* 36127 ( 627) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 9,  9,  0] -1 */
    42577689, /* 36128 ( 627) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 3,  0,  3] -1 */
     9228126, /* 36129 ( 627) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 3,  3,  0]  1 */
    59701899, /* 36130 ( 627) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 9,  0,  9] -1 */
    34015422, /* 36131 ( 627) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    52438710, /* 36132 ( 627) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
    60351278, /* 36133 ( 627) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 9,  3,  6] -1 */
    61000977, /* 36134 ( 627) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 9,  6,  3] -1 */
    10763400, /* 36135 ( 627) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 3,  9,  6]  1 */
     1551758, /* 36136 ( 627) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
    44112963, /* 36137 ( 627) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 3,  6,  9] -1 */
       16484, /* 36138 ( 628) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    44125925, /* 36139 ( 628) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 3,  6,  9] -1 */
    17140694, /* 36140 ( 628) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
    27638132, /* 36141 ( 628) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 9,  9,  0]  1 */
    18426486, /* 36142 ( 628) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
    26339054, /* 36143 ( 628) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 9,  3,  6]  1 */
        3198, /* 36144 ( 628) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    26352336, /* 36145 ( 628) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 9,  3,  6]  1 */
    27651414, /* 36146 ( 628) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 9,  9,  0]  1 */
    61013939, /* 36147 ( 628) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 9,  6,  3] -1 */
    18439772, /* 36148 ( 628) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    17127408, /* 36149 ( 628) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  6]  1 */
    51907433, /* 36150 ( 628) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  3,  9] -1 */
    10750118, /* 36151 ( 628) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 3,  9,  6]  1 */
    34783223, /* 36152 ( 628) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  3,  3] -1 */
     9214844, /* 36153 ( 628) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 3,  3,  0]  1 */
     1538472, /* 36154 ( 628) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
    53206511, /* 36155 ( 628) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  9,  3] -1 */
    36318497, /* 36156 ( 628) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  9,  9] -1 */
    42577689, /* 36157 ( 628) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 3,  0,  3] -1 */
     9228126, /* 36158 ( 628) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 3,  3,  0]  1 */
    59701899, /* 36159 ( 628) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 9,  0,  9] -1 */
    51920391, /* 36160 ( 628) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  3,  9] -1 */
    53219469, /* 36161 ( 628) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  9,  3] -1 */
    34796181, /* 36162 ( 628) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  3,  3] -1 */
    61000977, /* 36163 ( 628) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 9,  6,  3] -1 */
    10763400, /* 36164 ( 628) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 3,  9,  6]  1 */
    59714861, /* 36165 ( 628) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 9,  0,  9] -1 */
    42590651, /* 36166 ( 628) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 3,  0,  3] -1 */
     1551758, /* 36167 ( 628) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
    36331455, /* 36168 ( 628) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  9,  9] -1 */
    44112963, /* 36169 ( 628) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 3,  6,  9] -1 */
       16484, /* 36170 ( 629) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    61663638, /* 36171 ( 629) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 9,  9,  0] -1 */
    44125925, /* 36172 ( 629) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 3,  6,  9] -1 */
     8565465, /* 36173 ( 629) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 3,  0,  3]  1 */
    17140694, /* 36174 ( 629) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
    27638132, /* 36175 ( 629) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 9,  9,  0]  1 */
    17908167, /* 36176 ( 629) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  3,  9]  1 */
    26339054, /* 36177 ( 629) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 9,  3,  6]  1 */
      783957, /* 36178 ( 629) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  3,  3]  1 */
    25689675, /* 36179 ( 629) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 9,  0,  9]  1 */
    19207245, /* 36180 ( 629) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  9,  3]  1 */
    26988753, /* 36181 ( 629) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 9,  6,  3]  1 */
    51139632, /* 36182 ( 629) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  6] -1 */
     2319231, /* 36183 ( 629) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  9,  9]  1 */
    10100739, /* 36184 ( 629) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 3,  6,  9]  1 */
    35550696, /* 36185 ( 629) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  6] -1 */
    43240350, /* 36186 ( 629) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 3,  3,  0] -1 */
    18439772, /* 36187 ( 629) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    51907433, /* 36188 ( 629) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  3,  9] -1 */
    10750118, /* 36189 ( 629) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 3,  9,  6]  1 */
    44775624, /* 36190 ( 629) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 3,  9,  6] -1 */
    34783223, /* 36191 ( 629) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  3,  3] -1 */
     9214844, /* 36192 ( 629) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 3,  3,  0]  1 */
    53206511, /* 36193 ( 629) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  9,  3] -1 */
    36318497, /* 36194 ( 629) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  9,  9] -1 */
    34015422, /* 36195 ( 629) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    52438710, /* 36196 ( 629) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
    59714861, /* 36197 ( 629) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 9,  0,  9] -1 */
    42590651, /* 36198 ( 629) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 3,  0,  3] -1 */
     1551758, /* 36199 ( 629) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
    61013939, /* 36200 ( 629) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 9,  6,  3] -1 */
    60364560, /* 36201 ( 629) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 9,  3,  6] -1 */
       16484, /* 36202 ( 630) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
     8565465, /* 36203 ( 630) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 3,  0,  3]  1 */
    17140694, /* 36204 ( 630) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
    27638132, /* 36205 ( 630) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 9,  9,  0]  1 */
    17908167, /* 36206 ( 630) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  3,  9]  1 */
    18426486, /* 36207 ( 630) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
    26339054, /* 36208 ( 630) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 9,  3,  6]  1 */
      783957, /* 36209 ( 630) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  3,  3]  1 */
        3198, /* 36210 ( 630) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    25689675, /* 36211 ( 630) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 9,  0,  9]  1 */
    19207245, /* 36212 ( 630) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  9,  3]  1 */
    25702637, /* 36213 ( 630) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 9,  0,  9]  1 */
    35432598, /* 36214 ( 630) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  0] -1 */
    26988753, /* 36215 ( 630) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 9,  6,  3]  1 */
    52570094, /* 36216 ( 630) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    43345166, /* 36217 ( 630) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 3,  3,  6] -1 */
     2319231, /* 36218 ( 630) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  9,  9]  1 */
    27001715, /* 36219 ( 630) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 9,  6,  3]  1 */
    10100739, /* 36220 ( 630) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 3,  6,  9]  1 */
     8578427, /* 36221 ( 630) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 3,  0,  3]  1 */
    26352336, /* 36222 ( 630) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 9,  3,  6]  1 */
    51034820, /* 36223 ( 630) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  0] -1 */
    10113701, /* 36224 ( 630) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 3,  6,  9]  1 */
    27651414, /* 36225 ( 630) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 9,  9,  0]  1 */
    43358448, /* 36226 ( 630) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 3,  3,  6] -1 */
    34146806, /* 36227 ( 630) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    18439772, /* 36228 ( 630) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    17127408, /* 36229 ( 630) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  6]  1 */
    10750118, /* 36230 ( 630) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 3,  9,  6]  1 */
    51789335, /* 36231 ( 630) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  3,  3] -1 */
     9214844, /* 36232 ( 630) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 3,  3,  0]  1 */
     1538472, /* 36233 ( 630) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
    36200399, /* 36234 ( 630) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  9,  3] -1 */
    44644244, /* 36235 ( 630) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 3,  9,  0] -1 */
    61768454, /* 36236 ( 630) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 9,  9,  6] -1 */
    51021534, /* 36237 ( 630) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  0] -1 */
    34901321, /* 36238 ( 630) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  3,  9] -1 */
    35445884, /* 36239 ( 630) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  0] -1 */
    53324609, /* 36240 ( 630) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  9,  9] -1 */
    59583801, /* 36241 ( 630) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 9,  0,  3] -1 */
    60233180, /* 36242 ( 630) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 9,  3,  0] -1 */
    52556808, /* 36243 ( 630) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
     9228126, /* 36244 ( 630) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 3,  3,  0]  1 */
    61119075, /* 36245 ( 630) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 9,  6,  9] -1 */
    44657526, /* 36246 ( 630) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 3,  9,  0] -1 */
    59596763, /* 36247 ( 630) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 9,  0,  3] -1 */
    42695787, /* 36248 ( 630) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 3,  0,  9] -1 */
    17895209, /* 36249 ( 630) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  3,  9]  1 */
    61132037, /* 36250 ( 630) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 9,  6,  9] -1 */
    51802293, /* 36251 ( 630) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  3,  3] -1 */
    10763400, /* 36252 ( 630) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 3,  9,  6]  1 */
    36213357, /* 36253 ( 630) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  9,  3] -1 */
    42708749, /* 36254 ( 630) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 3,  0,  9] -1 */
    34133520, /* 36255 ( 630) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
    43994865, /* 36256 ( 630) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 3,  6,  3] -1 */
    19194287, /* 36257 ( 630) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  9,  3]  1 */
    60246462, /* 36258 ( 630) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 9,  3,  0] -1 */
      770999, /* 36259 ( 630) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  3,  3]  1 */
     1551758, /* 36260 ( 630) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
    34914279, /* 36261 ( 630) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  3,  9] -1 */
    53337567, /* 36262 ( 630) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  9,  9] -1 */
    44007827, /* 36263 ( 630) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 3,  6,  3] -1 */
    61781736, /* 36264 ( 630) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 9,  9,  6] -1 */
     2306273, /* 36265 ( 630) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  9,  9]  1 */
       16484, /* 36266 ( 631) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    18557868, /* 36267 ( 631) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
    18557870, /* 36268 ( 631) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
        3200, /* 36269 ( 631) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    18544584, /* 36270 ( 631) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
        3362, /* 36271 ( 631) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
       16322, /* 36272 ( 631) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
       16320, /* 36273 ( 631) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
        3198, /* 36274 ( 631) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    18544586, /* 36275 ( 631) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    18544748, /* 36276 ( 631) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    18557708, /* 36277 ( 631) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
        3360, /* 36278 ( 631) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    18544746, /* 36279 ( 631) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
       16482, /* 36280 ( 631) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    18557706, /* 36281 ( 631) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
       16484, /* 36282 ( 632) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    18557868, /* 36283 ( 632) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
    18544584, /* 36284 ( 632) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
       16320, /* 36285 ( 632) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
        3198, /* 36286 ( 632) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    52556970, /* 36287 ( 632) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    52570094, /* 36288 ( 632) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    34015584, /* 36289 ( 632) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    52569932, /* 36290 ( 632) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    52556972, /* 36291 ( 632) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    34015424, /* 36292 ( 632) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    34028546, /* 36293 ( 632) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    34028708, /* 36294 ( 632) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    18544746, /* 36295 ( 632) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
    34015586, /* 36296 ( 632) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    18557870, /* 36297 ( 632) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    52556810, /* 36298 ( 632) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    34028706, /* 36299 ( 632) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    52569930, /* 36300 ( 632) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
        3360, /* 36301 ( 632) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    18557708, /* 36302 ( 632) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    52570092, /* 36303 ( 632) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    18544748, /* 36304 ( 632) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    34028544, /* 36305 ( 632) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    52556808, /* 36306 ( 632) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
       16322, /* 36307 ( 632) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34015422, /* 36308 ( 632) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
        3200, /* 36309 ( 632) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
        3362, /* 36310 ( 632) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    18544586, /* 36311 ( 632) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
       16482, /* 36312 ( 632) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    18557706, /* 36313 ( 632) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
       16484, /* 36314 ( 633) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34015586, /* 36315 ( 633) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    18557870, /* 36316 ( 633) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    34015422, /* 36317 ( 633) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    52556810, /* 36318 ( 633) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    18557868, /* 36319 ( 633) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
       16322, /* 36320 ( 633) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
       16320, /* 36321 ( 633) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    34015584, /* 36322 ( 633) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    52556808, /* 36323 ( 633) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    52556970, /* 36324 ( 633) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    52556972, /* 36325 ( 633) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    34015424, /* 36326 ( 633) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    18557708, /* 36327 ( 633) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
       16482, /* 36328 ( 633) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    18557706, /* 36329 ( 633) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
       16484, /* 36330 ( 634) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34015586, /* 36331 ( 634) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    18557870, /* 36332 ( 634) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    18557868, /* 36333 ( 634) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
    34028546, /* 36334 ( 634) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
        3200, /* 36335 ( 634) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    18544584, /* 36336 ( 634) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
    34015584, /* 36337 ( 634) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    52569932, /* 36338 ( 634) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
        3198, /* 36339 ( 634) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    18544586, /* 36340 ( 634) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    52556970, /* 36341 ( 634) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    52556972, /* 36342 ( 634) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    52569930, /* 36343 ( 634) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
       16482, /* 36344 ( 634) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    34028544, /* 36345 ( 634) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
       16484, /* 36346 ( 635) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34015586, /* 36347 ( 635) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    18557870, /* 36348 ( 635) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    34015422, /* 36349 ( 635) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
        3200, /* 36350 ( 635) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
       16320, /* 36351 ( 635) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    52569932, /* 36352 ( 635) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    34028706, /* 36353 ( 635) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    18544586, /* 36354 ( 635) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    52556808, /* 36355 ( 635) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    52556972, /* 36356 ( 635) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    34028546, /* 36357 ( 635) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
        3360, /* 36358 ( 635) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    52570092, /* 36359 ( 635) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    18544746, /* 36360 ( 635) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
    18557706, /* 36361 ( 635) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
       16484, /* 36362 ( 636) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    18557868, /* 36363 ( 636) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
    18544584, /* 36364 ( 636) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
       16320, /* 36365 ( 636) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    52451996, /* 36366 ( 636) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
        3198, /* 36367 ( 636) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    52438872, /* 36368 ( 636) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
    52451834, /* 36369 ( 636) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
    52438874, /* 36370 ( 636) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
    34146644, /* 36371 ( 636) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    34146806, /* 36372 ( 636) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    34133684, /* 36373 ( 636) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    34133682, /* 36374 ( 636) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
    52438712, /* 36375 ( 636) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
    18544746, /* 36376 ( 636) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
    18557870, /* 36377 ( 636) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    34133522, /* 36378 ( 636) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    52451994, /* 36379 ( 636) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
    34146642, /* 36380 ( 636) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
        3360, /* 36381 ( 636) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    34146804, /* 36382 ( 636) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
    18557708, /* 36383 ( 636) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    18544748, /* 36384 ( 636) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    52451832, /* 36385 ( 636) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
       16322, /* 36386 ( 636) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    52438710, /* 36387 ( 636) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
        3200, /* 36388 ( 636) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
        3362, /* 36389 ( 636) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34133520, /* 36390 ( 636) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
    18544586, /* 36391 ( 636) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
       16482, /* 36392 ( 636) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    18557706, /* 36393 ( 636) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
       16484, /* 36394 ( 637) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
      121460, /* 36395 ( 637) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6]  1 */
    18557870, /* 36396 ( 637) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
      121458, /* 36397 ( 637) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  6]  1 */
      134418, /* 36398 ( 637) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  6]  1 */
        3200, /* 36399 ( 637) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    18544584, /* 36400 ( 637) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
    18439608, /* 36401 ( 637) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
    18557868, /* 36402 ( 637) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
    18426648, /* 36403 ( 637) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
    18439610, /* 36404 ( 637) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    18426650, /* 36405 ( 637) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
        3198, /* 36406 ( 637) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    18544586, /* 36407 ( 637) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
      134420, /* 36408 ( 637) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6]  1 */
       16482, /* 36409 ( 637) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
       16484, /* 36410 ( 638) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    18557868, /* 36411 ( 638) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
      134418, /* 36412 ( 638) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  6]  1 */
    18544584, /* 36413 ( 638) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
    18439608, /* 36414 ( 638) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
        3198, /* 36415 ( 638) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    52438872, /* 36416 ( 638) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
    52570094, /* 36417 ( 638) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    52451834, /* 36418 ( 638) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
    52438874, /* 36419 ( 638) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
    34146644, /* 36420 ( 638) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    34133684, /* 36421 ( 638) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    34133682, /* 36422 ( 638) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
    34015424, /* 36423 ( 638) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    34028708, /* 36424 ( 638) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    18426648, /* 36425 ( 638) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
    18557870, /* 36426 ( 638) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    52556810, /* 36427 ( 638) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    18439610, /* 36428 ( 638) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    34028706, /* 36429 ( 638) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    18426650, /* 36430 ( 638) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    34146642, /* 36431 ( 638) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
      134420, /* 36432 ( 638) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6]  1 */
    52570092, /* 36433 ( 638) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    52451832, /* 36434 ( 638) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
    52556808, /* 36435 ( 638) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
      121460, /* 36436 ( 638) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6]  1 */
    34015422, /* 36437 ( 638) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
      121458, /* 36438 ( 638) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  6]  1 */
        3200, /* 36439 ( 638) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    18544586, /* 36440 ( 638) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
       16482, /* 36441 ( 638) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
       16484, /* 36442 ( 639) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    18557868, /* 36443 ( 639) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
    18557870, /* 36444 ( 639) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    34015422, /* 36445 ( 639) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
      134418, /* 36446 ( 639) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  6]  1 */
    52556810, /* 36447 ( 639) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    18439608, /* 36448 ( 639) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
    18439610, /* 36449 ( 639) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    52438874, /* 36450 ( 639) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
      134420, /* 36451 ( 639) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6]  1 */
    34133684, /* 36452 ( 639) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    34133682, /* 36453 ( 639) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
    34015424, /* 36454 ( 639) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    52438872, /* 36455 ( 639) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
       16482, /* 36456 ( 639) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    52556808, /* 36457 ( 639) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
       16484, /* 36458 ( 640) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
      121460, /* 36459 ( 640) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6]  1 */
    18557870, /* 36460 ( 640) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    34015422, /* 36461 ( 640) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
        3200, /* 36462 ( 640) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    18439610, /* 36463 ( 640) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    34028706, /* 36464 ( 640) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    18426650, /* 36465 ( 640) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    18544586, /* 36466 ( 640) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    52570092, /* 36467 ( 640) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    34133682, /* 36468 ( 640) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
    34146642, /* 36469 ( 640) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
      134420, /* 36470 ( 640) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6]  1 */
    52438872, /* 36471 ( 640) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
    52451832, /* 36472 ( 640) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
    52556808, /* 36473 ( 640) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
       16484, /* 36474 ( 641) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    52451834, /* 36475 ( 641) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
    18557868, /* 36476 ( 641) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
    18557870, /* 36477 ( 641) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
        3200, /* 36478 ( 641) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    18544584, /* 36479 ( 641) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
    52438874, /* 36480 ( 641) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
    34146644, /* 36481 ( 641) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
        3198, /* 36482 ( 641) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    18544586, /* 36483 ( 641) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    34133684, /* 36484 ( 641) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    34133682, /* 36485 ( 641) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
    34146642, /* 36486 ( 641) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
    52438872, /* 36487 ( 641) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
       16482, /* 36488 ( 641) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    52451832, /* 36489 ( 641) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
       16484, /* 36490 ( 642) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    52451834, /* 36491 ( 642) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
      121460, /* 36492 ( 642) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6]  1 */
    18557870, /* 36493 ( 642) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    52556810, /* 36494 ( 642) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
      134418, /* 36495 ( 642) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  6]  1 */
    18544584, /* 36496 ( 642) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
    18439608, /* 36497 ( 642) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
    34146644, /* 36498 ( 642) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    34028706, /* 36499 ( 642) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    52438872, /* 36500 ( 642) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
    18426650, /* 36501 ( 642) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
        3198, /* 36502 ( 642) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    34133682, /* 36503 ( 642) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
    34015424, /* 36504 ( 642) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    52570092, /* 36505 ( 642) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
       16484, /* 36506 ( 643) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    52451834, /* 36507 ( 643) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
    18426648, /* 36508 ( 643) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
    18557870, /* 36509 ( 643) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    34015422, /* 36510 ( 643) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
      134418, /* 36511 ( 643) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  6]  1 */
        3200, /* 36512 ( 643) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    18439608, /* 36513 ( 643) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
      121458, /* 36514 ( 643) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  6]  1 */
    52438874, /* 36515 ( 643) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
    34146644, /* 36516 ( 643) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    34028706, /* 36517 ( 643) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    18544586, /* 36518 ( 643) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    34133684, /* 36519 ( 643) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    52570092, /* 36520 ( 643) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    52556808, /* 36521 ( 643) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
       16484, /* 36522 ( 644) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    18557868, /* 36523 ( 644) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
      134418, /* 36524 ( 644) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  6]  1 */
    18544584, /* 36525 ( 644) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
    18439608, /* 36526 ( 644) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
    52451996, /* 36527 ( 644) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
        3198, /* 36528 ( 644) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    52556970, /* 36529 ( 644) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    34015584, /* 36530 ( 644) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    52569932, /* 36531 ( 644) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    34146806, /* 36532 ( 644) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    52556972, /* 36533 ( 644) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    34028546, /* 36534 ( 644) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    52438712, /* 36535 ( 644) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
    18426648, /* 36536 ( 644) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
    34015586, /* 36537 ( 644) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    18557870, /* 36538 ( 644) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    34133522, /* 36539 ( 644) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    18439610, /* 36540 ( 644) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    52451994, /* 36541 ( 644) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
    18426650, /* 36542 ( 644) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    52569930, /* 36543 ( 644) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
      134420, /* 36544 ( 644) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6]  1 */
    34146804, /* 36545 ( 644) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
    34028544, /* 36546 ( 644) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
      121460, /* 36547 ( 644) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6]  1 */
      121458, /* 36548 ( 644) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  6]  1 */
    52438710, /* 36549 ( 644) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
        3200, /* 36550 ( 644) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34133520, /* 36551 ( 644) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
    18544586, /* 36552 ( 644) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
       16482, /* 36553 ( 644) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
       16484, /* 36554 ( 645) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    18557868, /* 36555 ( 645) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
    35445882, /* 36556 ( 645) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  0] -1 */
      134418, /* 36557 ( 645) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  6]  1 */
    18544584, /* 36558 ( 645) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
    18439608, /* 36559 ( 645) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
        3198, /* 36560 ( 645) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    51152916, /* 36561 ( 645) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6] -1 */
    35432598, /* 36562 ( 645) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  0] -1 */
    51021696, /* 36563 ( 645) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  0] -1 */
    51139632, /* 36564 ( 645) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  6] -1 */
    35563818, /* 36565 ( 645) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  6] -1 */
    51034658, /* 36566 ( 645) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  0] -1 */
    51021698, /* 36567 ( 645) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  0] -1 */
    18426648, /* 36568 ( 645) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
    18557870, /* 36569 ( 645) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    18439610, /* 36570 ( 645) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    51034656, /* 36571 ( 645) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  0] -1 */
    18426650, /* 36572 ( 645) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    35445884, /* 36573 ( 645) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  0] -1 */
    51152918, /* 36574 ( 645) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
      134420, /* 36575 ( 645) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6]  1 */
    35550858, /* 36576 ( 645) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6] -1 */
    35563820, /* 36577 ( 645) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
      121460, /* 36578 ( 645) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6]  1 */
      121458, /* 36579 ( 645) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  6]  1 */
        3200, /* 36580 ( 645) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    35550860, /* 36581 ( 645) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
    35432600, /* 36582 ( 645) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  0] -1 */
    51139634, /* 36583 ( 645) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
    18544586, /* 36584 ( 645) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
       16482, /* 36585 ( 645) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
       16484, /* 36586 ( 637) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    17022434, /* 36587 ( 637) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  0]  1 */
    18557870, /* 36588 ( 637) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    17009312, /* 36589 ( 637) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  0]  1 */
    17009472, /* 36590 ( 637) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  0]  1 */
       16320, /* 36591 ( 637) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    18544584, /* 36592 ( 637) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
     1538634, /* 36593 ( 637) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
    18544748, /* 36594 ( 637) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
     1538474, /* 36595 ( 637) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
     1551756, /* 36596 ( 637) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
     1551596, /* 36597 ( 637) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
        3198, /* 36598 ( 637) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    18557706, /* 36599 ( 637) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
    17022594, /* 36600 ( 637) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  0]  1 */
        3362, /* 36601 ( 637) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
       16484, /* 36602 ( 638) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    18544748, /* 36603 ( 638) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    17009472, /* 36604 ( 638) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  0]  1 */
    18544584, /* 36605 ( 638) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
     1538634, /* 36606 ( 638) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
        3198, /* 36607 ( 638) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    35550698, /* 36608 ( 638) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
    52570094, /* 36609 ( 638) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    35563980, /* 36610 ( 638) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6] -1 */
    35563820, /* 36611 ( 638) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
    51034818, /* 36612 ( 638) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  0] -1 */
    51034658, /* 36613 ( 638) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  0] -1 */
    51021536, /* 36614 ( 638) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  0] -1 */
    34028544, /* 36615 ( 638) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    34028708, /* 36616 ( 638) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
     1538474, /* 36617 ( 638) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
    18557870, /* 36618 ( 638) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    52569930, /* 36619 ( 638) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
     1551756, /* 36620 ( 638) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
    34015586, /* 36621 ( 638) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
     1551596, /* 36622 ( 638) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
    51021696, /* 36623 ( 638) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  0] -1 */
    17022594, /* 36624 ( 638) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  0]  1 */
    52556972, /* 36625 ( 638) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    35550858, /* 36626 ( 638) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6] -1 */
    52556808, /* 36627 ( 638) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    17022434, /* 36628 ( 638) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  0]  1 */
    34015422, /* 36629 ( 638) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    17009312, /* 36630 ( 638) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  0]  1 */
       16320, /* 36631 ( 638) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    18557706, /* 36632 ( 638) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
        3362, /* 36633 ( 638) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
       16484, /* 36634 ( 639) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    18544748, /* 36635 ( 639) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    18557870, /* 36636 ( 639) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    34015422, /* 36637 ( 639) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    17009472, /* 36638 ( 639) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  0]  1 */
    52569930, /* 36639 ( 639) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
     1538634, /* 36640 ( 639) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
     1551756, /* 36641 ( 639) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
    35563820, /* 36642 ( 639) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
    17022594, /* 36643 ( 639) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  0]  1 */
    51034658, /* 36644 ( 639) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  0] -1 */
    51021536, /* 36645 ( 639) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  0] -1 */
    34028544, /* 36646 ( 639) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    35550698, /* 36647 ( 639) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
        3362, /* 36648 ( 639) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    52556808, /* 36649 ( 639) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
       16484, /* 36650 ( 640) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    17022434, /* 36651 ( 640) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  0]  1 */
    18557870, /* 36652 ( 640) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    34015422, /* 36653 ( 640) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
       16320, /* 36654 ( 640) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
     1551756, /* 36655 ( 640) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
    34015586, /* 36656 ( 640) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
     1551596, /* 36657 ( 640) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
    18557706, /* 36658 ( 640) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
    52556972, /* 36659 ( 640) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    51021536, /* 36660 ( 640) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  0] -1 */
    51021696, /* 36661 ( 640) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  0] -1 */
    17022594, /* 36662 ( 640) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  0]  1 */
    35550698, /* 36663 ( 640) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
    35550858, /* 36664 ( 640) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6] -1 */
    52556808, /* 36665 ( 640) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
       16484, /* 36666 ( 641) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    35563980, /* 36667 ( 641) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6] -1 */
    18544748, /* 36668 ( 641) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    18557870, /* 36669 ( 641) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
       16320, /* 36670 ( 641) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    18544584, /* 36671 ( 641) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
    35563820, /* 36672 ( 641) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
    51034818, /* 36673 ( 641) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  0] -1 */
        3198, /* 36674 ( 641) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    18557706, /* 36675 ( 641) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
    51034658, /* 36676 ( 641) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  0] -1 */
    51021536, /* 36677 ( 641) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  0] -1 */
    51021696, /* 36678 ( 641) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  0] -1 */
    35550698, /* 36679 ( 641) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
        3362, /* 36680 ( 641) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    35550858, /* 36681 ( 641) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6] -1 */
       16484, /* 36682 ( 642) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    35563980, /* 36683 ( 642) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6] -1 */
    17022434, /* 36684 ( 642) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  0]  1 */
    18557870, /* 36685 ( 642) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    52569930, /* 36686 ( 642) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    17009472, /* 36687 ( 642) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  0]  1 */
    18544584, /* 36688 ( 642) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
     1538634, /* 36689 ( 642) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
    51034818, /* 36690 ( 642) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  0] -1 */
    34015586, /* 36691 ( 642) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    35550698, /* 36692 ( 642) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
     1551596, /* 36693 ( 642) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
        3198, /* 36694 ( 642) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    51021536, /* 36695 ( 642) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  0] -1 */
    34028544, /* 36696 ( 642) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    52556972, /* 36697 ( 642) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
       16484, /* 36698 ( 643) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    35563980, /* 36699 ( 643) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6] -1 */
     1538474, /* 36700 ( 643) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
    18557870, /* 36701 ( 643) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    34015422, /* 36702 ( 643) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    17009472, /* 36703 ( 643) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  0]  1 */
       16320, /* 36704 ( 643) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
     1538634, /* 36705 ( 643) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
    17009312, /* 36706 ( 643) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  0]  1 */
    35563820, /* 36707 ( 643) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
    51034818, /* 36708 ( 643) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  0] -1 */
    34015586, /* 36709 ( 643) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    18557706, /* 36710 ( 643) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
    51034658, /* 36711 ( 643) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  0] -1 */
    52556972, /* 36712 ( 643) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    52556808, /* 36713 ( 643) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
       16484, /* 36714 ( 644) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    18544748, /* 36715 ( 644) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    17009472, /* 36716 ( 644) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  0]  1 */
    18544584, /* 36717 ( 644) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
     1538634, /* 36718 ( 644) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
    35563982, /* 36719 ( 644) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
        3198, /* 36720 ( 644) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    52556810, /* 36721 ( 644) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    34015424, /* 36722 ( 644) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    52570092, /* 36723 ( 644) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    51034820, /* 36724 ( 644) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  0] -1 */
    52569932, /* 36725 ( 644) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    34028706, /* 36726 ( 644) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    35563818, /* 36727 ( 644) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  6] -1 */
     1538474, /* 36728 ( 644) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
    34028546, /* 36729 ( 644) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    18557870, /* 36730 ( 644) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    51034656, /* 36731 ( 644) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  0] -1 */
     1551756, /* 36732 ( 644) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
    35550860, /* 36733 ( 644) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
     1551596, /* 36734 ( 644) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
    52556970, /* 36735 ( 644) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    17022594, /* 36736 ( 644) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  0]  1 */
    51021698, /* 36737 ( 644) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  0] -1 */
    34015584, /* 36738 ( 644) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    17022434, /* 36739 ( 644) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  0]  1 */
    17009312, /* 36740 ( 644) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  0]  1 */
    35550696, /* 36741 ( 644) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  6] -1 */
       16320, /* 36742 ( 644) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    51021534, /* 36743 ( 644) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  0] -1 */
    18557706, /* 36744 ( 644) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
        3362, /* 36745 ( 644) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
       16484, /* 36746 ( 645) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    18544748, /* 36747 ( 645) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    34133684, /* 36748 ( 645) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    17009472, /* 36749 ( 645) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  0]  1 */
    18544584, /* 36750 ( 645) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
     1538634, /* 36751 ( 645) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
        3198, /* 36752 ( 645) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    52438874, /* 36753 ( 645) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
    34133520, /* 36754 ( 645) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
    35432600, /* 36755 ( 645) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  0] -1 */
    52438710, /* 36756 ( 645) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
    51139794, /* 36757 ( 645) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6] -1 */
    35445882, /* 36758 ( 645) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  0] -1 */
    35445722, /* 36759 ( 645) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  0] -1 */
     1538474, /* 36760 ( 645) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
    18557870, /* 36761 ( 645) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
     1551756, /* 36762 ( 645) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
    35432760, /* 36763 ( 645) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  0] -1 */
     1551596, /* 36764 ( 645) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
    34146806, /* 36765 ( 645) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    52451996, /* 36766 ( 645) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
    17022594, /* 36767 ( 645) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  0]  1 */
    51139634, /* 36768 ( 645) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
    51152916, /* 36769 ( 645) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6] -1 */
    17022434, /* 36770 ( 645) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  0]  1 */
    17009312, /* 36771 ( 645) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  0]  1 */
       16320, /* 36772 ( 645) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    51152756, /* 36773 ( 645) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
    34146642, /* 36774 ( 645) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
    52451832, /* 36775 ( 645) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
    18557706, /* 36776 ( 645) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
        3362, /* 36777 ( 645) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
       16484, /* 36778 ( 637) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
     1433658, /* 36779 ( 637) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  0]  1 */
    18557870, /* 36780 ( 637) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
     1433496, /* 36781 ( 637) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  0]  1 */
     1420376, /* 36782 ( 637) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  0]  1 */
        3360, /* 36783 ( 637) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    18544584, /* 36784 ( 637) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
    17127410, /* 36785 ( 637) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
    18557708, /* 36786 ( 637) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    17140530, /* 36787 ( 637) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  6]  1 */
    17127572, /* 36788 ( 637) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
    17140692, /* 36789 ( 637) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6]  1 */
        3198, /* 36790 ( 637) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    18544746, /* 36791 ( 637) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
     1420538, /* 36792 ( 637) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  0]  1 */
       16322, /* 36793 ( 637) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
       16484, /* 36794 ( 638) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    18557708, /* 36795 ( 638) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
     1420376, /* 36796 ( 638) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  0]  1 */
    18544584, /* 36797 ( 638) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
    17127410, /* 36798 ( 638) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
        3198, /* 36799 ( 638) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    51152754, /* 36800 ( 638) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  6] -1 */
    52570094, /* 36801 ( 638) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    51139796, /* 36802 ( 638) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
    51152916, /* 36803 ( 638) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6] -1 */
    35432762, /* 36804 ( 638) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  0] -1 */
    35445882, /* 36805 ( 638) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  0] -1 */
    35445720, /* 36806 ( 638) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  0] -1 */
    34015584, /* 36807 ( 638) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    34028708, /* 36808 ( 638) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    17140530, /* 36809 ( 638) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  6]  1 */
    18557870, /* 36810 ( 638) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    52556970, /* 36811 ( 638) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    17127572, /* 36812 ( 638) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
    34028546, /* 36813 ( 638) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    17140692, /* 36814 ( 638) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6]  1 */
    35432600, /* 36815 ( 638) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  0] -1 */
     1420538, /* 36816 ( 638) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  0]  1 */
    52569932, /* 36817 ( 638) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    51139634, /* 36818 ( 638) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
    52556808, /* 36819 ( 638) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
     1433658, /* 36820 ( 638) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  0]  1 */
    34015422, /* 36821 ( 638) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
     1433496, /* 36822 ( 638) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  0]  1 */
        3360, /* 36823 ( 638) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    18544746, /* 36824 ( 638) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
       16322, /* 36825 ( 638) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
       16484, /* 36826 ( 639) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    18557708, /* 36827 ( 639) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    18557870, /* 36828 ( 639) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    34015422, /* 36829 ( 639) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
     1420376, /* 36830 ( 639) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  0]  1 */
    52556970, /* 36831 ( 639) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    17127410, /* 36832 ( 639) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
    17127572, /* 36833 ( 639) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
    51152916, /* 36834 ( 639) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6] -1 */
     1420538, /* 36835 ( 639) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  0]  1 */
    35445882, /* 36836 ( 639) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  0] -1 */
    35445720, /* 36837 ( 639) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  0] -1 */
    34015584, /* 36838 ( 639) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    51152754, /* 36839 ( 639) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  6] -1 */
       16322, /* 36840 ( 639) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    52556808, /* 36841 ( 639) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
       16484, /* 36842 ( 640) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
     1433658, /* 36843 ( 640) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  0]  1 */
    18557870, /* 36844 ( 640) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    34015422, /* 36845 ( 640) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
        3360, /* 36846 ( 640) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    17127572, /* 36847 ( 640) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
    34028546, /* 36848 ( 640) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    17140692, /* 36849 ( 640) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6]  1 */
    18544746, /* 36850 ( 640) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
    52569932, /* 36851 ( 640) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    35445720, /* 36852 ( 640) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  0] -1 */
    35432600, /* 36853 ( 640) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  0] -1 */
     1420538, /* 36854 ( 640) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  0]  1 */
    51152754, /* 36855 ( 640) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  6] -1 */
    51139634, /* 36856 ( 640) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
    52556808, /* 36857 ( 640) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
       16484, /* 36858 ( 641) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    51139796, /* 36859 ( 641) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
    18557708, /* 36860 ( 641) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    18557870, /* 36861 ( 641) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
        3360, /* 36862 ( 641) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    18544584, /* 36863 ( 641) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
    51152916, /* 36864 ( 641) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6] -1 */
    35432762, /* 36865 ( 641) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  0] -1 */
        3198, /* 36866 ( 641) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    18544746, /* 36867 ( 641) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
    35445882, /* 36868 ( 641) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  0] -1 */
    35445720, /* 36869 ( 641) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  0] -1 */
    35432600, /* 36870 ( 641) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  0] -1 */
    51152754, /* 36871 ( 641) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  6] -1 */
       16322, /* 36872 ( 641) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    51139634, /* 36873 ( 641) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
       16484, /* 36874 ( 642) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    51139796, /* 36875 ( 642) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
     1433658, /* 36876 ( 642) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  0]  1 */
    18557870, /* 36877 ( 642) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    52556970, /* 36878 ( 642) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
     1420376, /* 36879 ( 642) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  0]  1 */
    18544584, /* 36880 ( 642) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
    17127410, /* 36881 ( 642) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
    35432762, /* 36882 ( 642) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  0] -1 */
    34028546, /* 36883 ( 642) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    51152754, /* 36884 ( 642) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  6] -1 */
    17140692, /* 36885 ( 642) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6]  1 */
        3198, /* 36886 ( 642) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    35445720, /* 36887 ( 642) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  0] -1 */
    34015584, /* 36888 ( 642) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    52569932, /* 36889 ( 642) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
       16484, /* 36890 ( 643) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    51139796, /* 36891 ( 643) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
    17140530, /* 36892 ( 643) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  6]  1 */
    18557870, /* 36893 ( 643) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    34015422, /* 36894 ( 643) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
     1420376, /* 36895 ( 643) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  0]  1 */
        3360, /* 36896 ( 643) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    17127410, /* 36897 ( 643) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
     1433496, /* 36898 ( 643) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  0]  1 */
    51152916, /* 36899 ( 643) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6] -1 */
    35432762, /* 36900 ( 643) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  0] -1 */
    34028546, /* 36901 ( 643) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    18544746, /* 36902 ( 643) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
    35445882, /* 36903 ( 643) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  0] -1 */
    52569932, /* 36904 ( 643) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    52556808, /* 36905 ( 643) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
       16484, /* 36906 ( 644) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    18557708, /* 36907 ( 644) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
     1420376, /* 36908 ( 644) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  0]  1 */
    18544584, /* 36909 ( 644) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
    17127410, /* 36910 ( 644) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
    51152918, /* 36911 ( 644) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
        3198, /* 36912 ( 644) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    52569930, /* 36913 ( 644) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    34028544, /* 36914 ( 644) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    52556972, /* 36915 ( 644) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    35445884, /* 36916 ( 644) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  0] -1 */
    52570092, /* 36917 ( 644) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    34015586, /* 36918 ( 644) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    51139794, /* 36919 ( 644) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6] -1 */
    17140530, /* 36920 ( 644) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  6]  1 */
    34028706, /* 36921 ( 644) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    18557870, /* 36922 ( 644) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    35432760, /* 36923 ( 644) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  0] -1 */
    17127572, /* 36924 ( 644) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
    51152756, /* 36925 ( 644) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
    17140692, /* 36926 ( 644) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6]  1 */
    52556810, /* 36927 ( 644) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
     1420538, /* 36928 ( 644) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  0]  1 */
    35445722, /* 36929 ( 644) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  0] -1 */
    34015424, /* 36930 ( 644) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
     1433658, /* 36931 ( 644) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  0]  1 */
     1433496, /* 36932 ( 644) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  0]  1 */
    51139632, /* 36933 ( 644) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  6] -1 */
        3360, /* 36934 ( 644) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    35432598, /* 36935 ( 644) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  0] -1 */
    18544746, /* 36936 ( 644) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
       16322, /* 36937 ( 644) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
       16484, /* 36938 ( 645) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    18557708, /* 36939 ( 645) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    51034658, /* 36940 ( 645) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  0] -1 */
     1420376, /* 36941 ( 645) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  0]  1 */
    18544584, /* 36942 ( 645) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
    17127410, /* 36943 ( 645) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
        3198, /* 36944 ( 645) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    35563820, /* 36945 ( 645) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
    51021534, /* 36946 ( 645) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  0] -1 */
    34146642, /* 36947 ( 645) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
    35550696, /* 36948 ( 645) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  6] -1 */
    52438712, /* 36949 ( 645) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
    34133684, /* 36950 ( 645) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    34146804, /* 36951 ( 645) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
    17140530, /* 36952 ( 645) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  6]  1 */
    18557870, /* 36953 ( 645) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    17127572, /* 36954 ( 645) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
    34133522, /* 36955 ( 645) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    17140692, /* 36956 ( 645) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6]  1 */
    51034820, /* 36957 ( 645) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  0] -1 */
    35563982, /* 36958 ( 645) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
     1420538, /* 36959 ( 645) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  0]  1 */
    52451832, /* 36960 ( 645) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
    52438874, /* 36961 ( 645) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
     1433658, /* 36962 ( 645) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  0]  1 */
     1433496, /* 36963 ( 645) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  0]  1 */
        3360, /* 36964 ( 645) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    52451994, /* 36965 ( 645) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
    51021696, /* 36966 ( 645) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  0] -1 */
    35550858, /* 36967 ( 645) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6] -1 */
    18544746, /* 36968 ( 645) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
       16322, /* 36969 ( 645) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
       16484, /* 36970 ( 646) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
      121460, /* 36971 ( 646) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6]  1 */
    18557870, /* 36972 ( 646) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    17140692, /* 36973 ( 646) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6]  1 */
      134418, /* 36974 ( 646) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  6]  1 */
    18544584, /* 36975 ( 646) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
    18439608, /* 36976 ( 646) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
    17009472, /* 36977 ( 646) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  0]  1 */
     1433658, /* 36978 ( 646) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  0]  1 */
     1551596, /* 36979 ( 646) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
    17022434, /* 36980 ( 646) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  0]  1 */
    18426650, /* 36981 ( 646) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
        3198, /* 36982 ( 646) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
     1420376, /* 36983 ( 646) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  0]  1 */
    17127410, /* 36984 ( 646) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
     1538634, /* 36985 ( 646) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
       16484, /* 36986 ( 647) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    35445882, /* 36987 ( 647) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  0] -1 */
      134418, /* 36988 ( 647) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  6]  1 */
    18544584, /* 36989 ( 647) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
    18439608, /* 36990 ( 647) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
     1551596, /* 36991 ( 647) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
        3198, /* 36992 ( 647) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
     1420376, /* 36993 ( 647) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  0]  1 */
    17127410, /* 36994 ( 647) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
    51152916, /* 36995 ( 647) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6] -1 */
    51021696, /* 36996 ( 647) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  0] -1 */
    52570094, /* 36997 ( 647) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    51034658, /* 36998 ( 647) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  0] -1 */
     1433658, /* 36999 ( 647) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  0]  1 */
    52438874, /* 37000 ( 647) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
    34133684, /* 37001 ( 647) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    34028708, /* 37002 ( 647) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    18557870, /* 37003 ( 647) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    17140692, /* 37004 ( 647) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6]  1 */
    17009472, /* 37005 ( 647) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  0]  1 */
    17022434, /* 37006 ( 647) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  0]  1 */
    18426650, /* 37007 ( 647) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    34146642, /* 37008 ( 647) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
    35550858, /* 37009 ( 647) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6] -1 */
    52451832, /* 37010 ( 647) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
    52556808, /* 37011 ( 647) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    35563820, /* 37012 ( 647) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
      121460, /* 37013 ( 647) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6]  1 */
    34015422, /* 37014 ( 647) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    35432600, /* 37015 ( 647) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  0] -1 */
    51139634, /* 37016 ( 647) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
     1538634, /* 37017 ( 647) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
       16484, /* 37018 ( 648) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    18557870, /* 37019 ( 648) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    34015422, /* 37020 ( 648) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
      134418, /* 37021 ( 648) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  6]  1 */
    18439608, /* 37022 ( 648) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
    17140692, /* 37023 ( 648) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6]  1 */
     1433658, /* 37024 ( 648) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  0]  1 */
    52438874, /* 37025 ( 648) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
    35432600, /* 37026 ( 648) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  0] -1 */
     1551596, /* 37027 ( 648) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
    51139634, /* 37028 ( 648) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
    17022434, /* 37029 ( 648) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  0]  1 */
    34133684, /* 37030 ( 648) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    35550858, /* 37031 ( 648) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6] -1 */
    51021696, /* 37032 ( 648) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  0] -1 */
    52556808, /* 37033 ( 648) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
       16484, /* 37034 ( 649) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    18557870, /* 37035 ( 649) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    17140692, /* 37036 ( 649) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6]  1 */
    18544584, /* 37037 ( 649) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
     1433658, /* 37038 ( 649) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  0]  1 */
    52438874, /* 37039 ( 649) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
    35563820, /* 37040 ( 649) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
        3198, /* 37041 ( 649) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
     1420376, /* 37042 ( 649) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  0]  1 */
    34133684, /* 37043 ( 649) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    17127410, /* 37044 ( 649) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
    34146642, /* 37045 ( 649) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
    35550858, /* 37046 ( 649) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6] -1 */
    51021696, /* 37047 ( 649) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  0] -1 */
    52451832, /* 37048 ( 649) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
    51034658, /* 37049 ( 649) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  0] -1 */
       16484, /* 37050 ( 650) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    35445882, /* 37051 ( 650) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  0] -1 */
    18557870, /* 37052 ( 650) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    34015422, /* 37053 ( 650) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
      134418, /* 37054 ( 650) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  6]  1 */
    18439608, /* 37055 ( 650) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
    17009472, /* 37056 ( 650) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  0]  1 */
    52438874, /* 37057 ( 650) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
    51034658, /* 37058 ( 650) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  0] -1 */
     1538634, /* 37059 ( 650) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
     1420376, /* 37060 ( 650) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  0]  1 */
    34133684, /* 37061 ( 650) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    17127410, /* 37062 ( 650) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
    51152916, /* 37063 ( 650) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6] -1 */
    35563820, /* 37064 ( 650) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
    52556808, /* 37065 ( 650) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
       16484, /* 37066 ( 651) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
      134418, /* 37067 ( 651) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  6]  1 */
    18544584, /* 37068 ( 651) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
    18439608, /* 37069 ( 651) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
     1551596, /* 37070 ( 651) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
    35563980, /* 37071 ( 651) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6] -1 */
    52451996, /* 37072 ( 651) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
        3198, /* 37073 ( 651) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
     1420376, /* 37074 ( 651) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  0]  1 */
    17127410, /* 37075 ( 651) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
     1433658, /* 37076 ( 651) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  0]  1 */
    34146806, /* 37077 ( 651) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    52556972, /* 37078 ( 651) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    51021536, /* 37079 ( 651) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  0] -1 */
    34015586, /* 37080 ( 651) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    18557870, /* 37081 ( 651) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    17140692, /* 37082 ( 651) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6]  1 */
    17009472, /* 37083 ( 651) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  0]  1 */
    35432760, /* 37084 ( 651) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  0] -1 */
    17022434, /* 37085 ( 651) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  0]  1 */
    51034818, /* 37086 ( 651) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  0] -1 */
    18426650, /* 37087 ( 651) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    35445722, /* 37088 ( 651) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  0] -1 */
    52569930, /* 37089 ( 651) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    34028544, /* 37090 ( 651) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
      121460, /* 37091 ( 651) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6]  1 */
    51139794, /* 37092 ( 651) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6] -1 */
    52438710, /* 37093 ( 651) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
    51152756, /* 37094 ( 651) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
    34133520, /* 37095 ( 651) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
    35550698, /* 37096 ( 651) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
     1538634, /* 37097 ( 651) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
       16484, /* 37098 ( 646) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
      134420, /* 37099 ( 646) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6]  1 */
    18557870, /* 37100 ( 646) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
     1551756, /* 37101 ( 646) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
      121458, /* 37102 ( 646) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  6]  1 */
    18544584, /* 37103 ( 646) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
    18426648, /* 37104 ( 646) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
     1433496, /* 37105 ( 646) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  0]  1 */
    17022594, /* 37106 ( 646) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  0]  1 */
    17127572, /* 37107 ( 646) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
     1420538, /* 37108 ( 646) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  0]  1 */
    18439610, /* 37109 ( 646) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
        3198, /* 37110 ( 646) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    17009312, /* 37111 ( 646) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  0]  1 */
     1538474, /* 37112 ( 646) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
    17140530, /* 37113 ( 646) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  6]  1 */
       16484, /* 37114 ( 647) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    51034818, /* 37115 ( 647) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  0] -1 */
      121458, /* 37116 ( 647) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  6]  1 */
    18544584, /* 37117 ( 647) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
    18426648, /* 37118 ( 647) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
    17127572, /* 37119 ( 647) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
        3198, /* 37120 ( 647) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    17009312, /* 37121 ( 647) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  0]  1 */
     1538474, /* 37122 ( 647) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
    35563980, /* 37123 ( 647) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6] -1 */
    35445720, /* 37124 ( 647) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  0] -1 */
    52570094, /* 37125 ( 647) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    35432762, /* 37126 ( 647) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  0] -1 */
    17022594, /* 37127 ( 647) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  0]  1 */
    52451834, /* 37128 ( 647) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
    34146644, /* 37129 ( 647) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    34028708, /* 37130 ( 647) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    18557870, /* 37131 ( 647) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
     1551756, /* 37132 ( 647) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
     1433496, /* 37133 ( 647) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  0]  1 */
     1420538, /* 37134 ( 647) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  0]  1 */
    18439610, /* 37135 ( 647) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    34133682, /* 37136 ( 647) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
    51152754, /* 37137 ( 647) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  6] -1 */
    52438872, /* 37138 ( 647) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
    52556808, /* 37139 ( 647) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    51139796, /* 37140 ( 647) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
      134420, /* 37141 ( 647) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6]  1 */
    34015422, /* 37142 ( 647) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    51021536, /* 37143 ( 647) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  0] -1 */
    35550698, /* 37144 ( 647) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
    17140530, /* 37145 ( 647) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  6]  1 */
       16484, /* 37146 ( 648) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    18557870, /* 37147 ( 648) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    34015422, /* 37148 ( 648) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
      121458, /* 37149 ( 648) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  6]  1 */
    18426648, /* 37150 ( 648) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
     1551756, /* 37151 ( 648) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
    17022594, /* 37152 ( 648) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  0]  1 */
    52451834, /* 37153 ( 648) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
    51021536, /* 37154 ( 648) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  0] -1 */
    17127572, /* 37155 ( 648) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
    35550698, /* 37156 ( 648) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
     1420538, /* 37157 ( 648) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  0]  1 */
    34146644, /* 37158 ( 648) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    51152754, /* 37159 ( 648) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  6] -1 */
    35445720, /* 37160 ( 648) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  0] -1 */
    52556808, /* 37161 ( 648) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
       16484, /* 37162 ( 649) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    18557870, /* 37163 ( 649) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
     1551756, /* 37164 ( 649) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
    18544584, /* 37165 ( 649) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
    17022594, /* 37166 ( 649) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  0]  1 */
    52451834, /* 37167 ( 649) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
    51139796, /* 37168 ( 649) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
        3198, /* 37169 ( 649) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    17009312, /* 37170 ( 649) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  0]  1 */
    34146644, /* 37171 ( 649) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
     1538474, /* 37172 ( 649) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
    34133682, /* 37173 ( 649) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
    51152754, /* 37174 ( 649) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  6] -1 */
    35445720, /* 37175 ( 649) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  0] -1 */
    52438872, /* 37176 ( 649) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
    35432762, /* 37177 ( 649) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  0] -1 */
       16484, /* 37178 ( 650) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    51034818, /* 37179 ( 650) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  0] -1 */
    18557870, /* 37180 ( 650) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    34015422, /* 37181 ( 650) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
      121458, /* 37182 ( 650) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  6]  1 */
    18426648, /* 37183 ( 650) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
     1433496, /* 37184 ( 650) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  0]  1 */
    52451834, /* 37185 ( 650) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
    35432762, /* 37186 ( 650) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  0] -1 */
    17140530, /* 37187 ( 650) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  6]  1 */
    17009312, /* 37188 ( 650) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  0]  1 */
    34146644, /* 37189 ( 650) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
     1538474, /* 37190 ( 650) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
    35563980, /* 37191 ( 650) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6] -1 */
    51139796, /* 37192 ( 650) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
    52556808, /* 37193 ( 650) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
       16484, /* 37194 ( 651) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
      121458, /* 37195 ( 651) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  6]  1 */
    18544584, /* 37196 ( 651) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
    18426648, /* 37197 ( 651) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
    17127572, /* 37198 ( 651) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
    51152916, /* 37199 ( 651) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6] -1 */
    52451996, /* 37200 ( 651) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
        3198, /* 37201 ( 651) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    17009312, /* 37202 ( 651) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  0]  1 */
     1538474, /* 37203 ( 651) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
    17022594, /* 37204 ( 651) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  0]  1 */
    34146806, /* 37205 ( 651) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    52569932, /* 37206 ( 651) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    35432600, /* 37207 ( 651) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  0] -1 */
    34028546, /* 37208 ( 651) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    18557870, /* 37209 ( 651) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
     1551756, /* 37210 ( 651) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
     1433496, /* 37211 ( 651) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  0]  1 */
    51034656, /* 37212 ( 651) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  0] -1 */
     1420538, /* 37213 ( 651) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  0]  1 */
    35445882, /* 37214 ( 651) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  0] -1 */
    18439610, /* 37215 ( 651) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    51021698, /* 37216 ( 651) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  0] -1 */
    52556970, /* 37217 ( 651) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    34015584, /* 37218 ( 651) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
      134420, /* 37219 ( 651) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6]  1 */
    35563818, /* 37220 ( 651) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  6] -1 */
    52438710, /* 37221 ( 651) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
    35550860, /* 37222 ( 651) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
    34133520, /* 37223 ( 651) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
    51139634, /* 37224 ( 651) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
    17140530, /* 37225 ( 651) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  6]  1 */
       16484, /* 37226 ( 652) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    18557870, /* 37227 ( 652) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    17140692, /* 37228 ( 652) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6]  1 */
    18544584, /* 37229 ( 652) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
        3362, /* 37230 ( 652) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
     1433658, /* 37231 ( 652) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  0]  1 */
    17127570, /* 37232 ( 652) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6]  1 */
       16320, /* 37233 ( 652) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
        3198, /* 37234 ( 652) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
     1420376, /* 37235 ( 652) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  0]  1 */
     1420536, /* 37236 ( 652) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  0]  1 */
    17127410, /* 37237 ( 652) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
    17140532, /* 37238 ( 652) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
     1433498, /* 37239 ( 652) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  0]  1 */
    18544748, /* 37240 ( 652) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    18557706, /* 37241 ( 652) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
       16484, /* 37242 ( 653) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    35445882, /* 37243 ( 653) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  0] -1 */
    18544584, /* 37244 ( 653) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
    17127570, /* 37245 ( 653) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6]  1 */
       16320, /* 37246 ( 653) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
        3198, /* 37247 ( 653) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
     1420376, /* 37248 ( 653) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  0]  1 */
    17127410, /* 37249 ( 653) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
    17140532, /* 37250 ( 653) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
    51152916, /* 37251 ( 653) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6] -1 */
    52570094, /* 37252 ( 653) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
     1433658, /* 37253 ( 653) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  0]  1 */
    52556972, /* 37254 ( 653) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    34028708, /* 37255 ( 653) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    34015586, /* 37256 ( 653) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    18557870, /* 37257 ( 653) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    17140692, /* 37258 ( 653) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6]  1 */
    35432760, /* 37259 ( 653) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  0] -1 */
    35445722, /* 37260 ( 653) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  0] -1 */
    52569930, /* 37261 ( 653) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    18544748, /* 37262 ( 653) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    34028544, /* 37263 ( 653) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    52556808, /* 37264 ( 653) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    51139794, /* 37265 ( 653) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6] -1 */
    34015422, /* 37266 ( 653) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    51152756, /* 37267 ( 653) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
        3362, /* 37268 ( 653) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    35432600, /* 37269 ( 653) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  0] -1 */
    51139634, /* 37270 ( 653) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
     1420536, /* 37271 ( 653) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  0]  1 */
     1433498, /* 37272 ( 653) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  0]  1 */
    18557706, /* 37273 ( 653) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
       16484, /* 37274 ( 654) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34015586, /* 37275 ( 654) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    18557870, /* 37276 ( 654) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    34015422, /* 37277 ( 654) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    51139794, /* 37278 ( 654) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6] -1 */
    17140692, /* 37279 ( 654) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6]  1 */
     1433658, /* 37280 ( 654) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  0]  1 */
       16320, /* 37281 ( 654) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    35432600, /* 37282 ( 654) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  0] -1 */
    35432760, /* 37283 ( 654) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  0] -1 */
    51139634, /* 37284 ( 654) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
    52556808, /* 37285 ( 654) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    52556972, /* 37286 ( 654) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    17140532, /* 37287 ( 654) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
     1433498, /* 37288 ( 654) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  0]  1 */
    18557706, /* 37289 ( 654) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
       16484, /* 37290 ( 655) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    35445882, /* 37291 ( 655) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  0] -1 */
    18557870, /* 37292 ( 655) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    34015422, /* 37293 ( 655) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    51139794, /* 37294 ( 655) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6] -1 */
        3362, /* 37295 ( 655) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    35432760, /* 37296 ( 655) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  0] -1 */
     1420376, /* 37297 ( 655) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  0]  1 */
    17127410, /* 37298 ( 655) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
    51152916, /* 37299 ( 655) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6] -1 */
    17140532, /* 37300 ( 655) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
    52569930, /* 37301 ( 655) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
     1433498, /* 37302 ( 655) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  0]  1 */
    18544748, /* 37303 ( 655) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    34028544, /* 37304 ( 655) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    52556808, /* 37305 ( 655) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
       16484, /* 37306 ( 656) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34015586, /* 37307 ( 656) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    18557870, /* 37308 ( 656) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    17140692, /* 37309 ( 656) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6]  1 */
    51139794, /* 37310 ( 656) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6] -1 */
    18544584, /* 37311 ( 656) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
    51152756, /* 37312 ( 656) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
     1433658, /* 37313 ( 656) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  0]  1 */
    35432760, /* 37314 ( 656) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  0] -1 */
        3198, /* 37315 ( 656) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
     1420376, /* 37316 ( 656) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  0]  1 */
    35445722, /* 37317 ( 656) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  0] -1 */
    17127410, /* 37318 ( 656) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
    52556972, /* 37319 ( 656) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    52569930, /* 37320 ( 656) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    34028544, /* 37321 ( 656) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
       16484, /* 37322 ( 657) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    35445882, /* 37323 ( 657) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  0] -1 */
    18557870, /* 37324 ( 657) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    51139794, /* 37325 ( 657) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6] -1 */
    18544584, /* 37326 ( 657) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
    51152756, /* 37327 ( 657) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
        3362, /* 37328 ( 657) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
       16320, /* 37329 ( 657) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    35432600, /* 37330 ( 657) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  0] -1 */
    35432760, /* 37331 ( 657) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  0] -1 */
    51139634, /* 37332 ( 657) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
        3198, /* 37333 ( 657) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    35445722, /* 37334 ( 657) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  0] -1 */
    51152916, /* 37335 ( 657) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6] -1 */
    18544748, /* 37336 ( 657) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    18557706, /* 37337 ( 657) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
       16484, /* 37338 ( 658) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    35445882, /* 37339 ( 658) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  0] -1 */
    18557870, /* 37340 ( 658) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    34015422, /* 37341 ( 658) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    34015586, /* 37342 ( 658) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    51152756, /* 37343 ( 658) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
    17127570, /* 37344 ( 658) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6]  1 */
       16320, /* 37345 ( 658) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    52556808, /* 37346 ( 658) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
     1420376, /* 37347 ( 658) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  0]  1 */
     1420536, /* 37348 ( 658) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  0]  1 */
    17127410, /* 37349 ( 658) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
    51152916, /* 37350 ( 658) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6] -1 */
    52556972, /* 37351 ( 658) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    35445722, /* 37352 ( 658) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  0] -1 */
    18557706, /* 37353 ( 658) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
       16484, /* 37354 ( 659) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    18544584, /* 37355 ( 659) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
    17127570, /* 37356 ( 659) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6]  1 */
       16320, /* 37357 ( 659) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    35563980, /* 37358 ( 659) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6] -1 */
    52451996, /* 37359 ( 659) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
        3198, /* 37360 ( 659) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
     1420376, /* 37361 ( 659) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  0]  1 */
    17127410, /* 37362 ( 659) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
    17140532, /* 37363 ( 659) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
    51021696, /* 37364 ( 659) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  0] -1 */
    51034658, /* 37365 ( 659) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  0] -1 */
     1433658, /* 37366 ( 659) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  0]  1 */
    52438874, /* 37367 ( 659) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
    34146806, /* 37368 ( 659) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    34133684, /* 37369 ( 659) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    51021536, /* 37370 ( 659) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  0] -1 */
    18557870, /* 37371 ( 659) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    17140692, /* 37372 ( 659) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6]  1 */
    51034818, /* 37373 ( 659) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  0] -1 */
    34146642, /* 37374 ( 659) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
    35550858, /* 37375 ( 659) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6] -1 */
    18544748, /* 37376 ( 659) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    52451832, /* 37377 ( 659) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
    35563820, /* 37378 ( 659) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
    52438710, /* 37379 ( 659) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
        3362, /* 37380 ( 659) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34133520, /* 37381 ( 659) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
     1420536, /* 37382 ( 659) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  0]  1 */
    35550698, /* 37383 ( 659) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
     1433498, /* 37384 ( 659) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  0]  1 */
    18557706, /* 37385 ( 659) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
       16484, /* 37386 ( 660) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    18544584, /* 37387 ( 660) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
    17127570, /* 37388 ( 660) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6]  1 */
       16320, /* 37389 ( 660) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    35445720, /* 37390 ( 660) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  0] -1 */
        3198, /* 37391 ( 660) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
     1420376, /* 37392 ( 660) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  0]  1 */
    51152754, /* 37393 ( 660) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  6] -1 */
    17127410, /* 37394 ( 660) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
    17140532, /* 37395 ( 660) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
    52556970, /* 37396 ( 660) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    35432598, /* 37397 ( 660) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  0] -1 */
    51139632, /* 37398 ( 660) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  6] -1 */
     1433658, /* 37399 ( 660) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  0]  1 */
    34015584, /* 37400 ( 660) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    52569932, /* 37401 ( 660) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    34015424, /* 37402 ( 660) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    34028546, /* 37403 ( 660) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    18557870, /* 37404 ( 660) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    17140692, /* 37405 ( 660) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6]  1 */
    52556810, /* 37406 ( 660) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    34028706, /* 37407 ( 660) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    35445884, /* 37408 ( 660) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  0] -1 */
    51152918, /* 37409 ( 660) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
    52570092, /* 37410 ( 660) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    18544748, /* 37411 ( 660) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
        3362, /* 37412 ( 660) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    35432762, /* 37413 ( 660) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  0] -1 */
    51139796, /* 37414 ( 660) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
     1420536, /* 37415 ( 660) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  0]  1 */
     1433498, /* 37416 ( 660) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  0]  1 */
    18557706, /* 37417 ( 660) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
       16484, /* 37418 ( 652) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    18557870, /* 37419 ( 652) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
     1551756, /* 37420 ( 652) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
    18544584, /* 37421 ( 652) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
       16322, /* 37422 ( 652) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    17022594, /* 37423 ( 652) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  0]  1 */
     1551594, /* 37424 ( 652) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
        3360, /* 37425 ( 652) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
        3198, /* 37426 ( 652) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    17009312, /* 37427 ( 652) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  0]  1 */
    17022432, /* 37428 ( 652) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  0]  1 */
     1538474, /* 37429 ( 652) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
     1538636, /* 37430 ( 652) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
    17009474, /* 37431 ( 652) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  0]  1 */
    18557708, /* 37432 ( 652) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    18544746, /* 37433 ( 652) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
       16484, /* 37434 ( 653) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    51034818, /* 37435 ( 653) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  0] -1 */
    18544584, /* 37436 ( 653) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
     1551594, /* 37437 ( 653) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
        3360, /* 37438 ( 653) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
        3198, /* 37439 ( 653) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    17009312, /* 37440 ( 653) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  0]  1 */
     1538474, /* 37441 ( 653) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
     1538636, /* 37442 ( 653) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
    35563980, /* 37443 ( 653) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6] -1 */
    52570094, /* 37444 ( 653) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    17022594, /* 37445 ( 653) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  0]  1 */
    52569932, /* 37446 ( 653) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    34028708, /* 37447 ( 653) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    34028546, /* 37448 ( 653) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    18557870, /* 37449 ( 653) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
     1551756, /* 37450 ( 653) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
    51034656, /* 37451 ( 653) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  0] -1 */
    51021698, /* 37452 ( 653) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  0] -1 */
    52556970, /* 37453 ( 653) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    18557708, /* 37454 ( 653) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    34015584, /* 37455 ( 653) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    52556808, /* 37456 ( 653) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    35563818, /* 37457 ( 653) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  6] -1 */
    34015422, /* 37458 ( 653) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    35550860, /* 37459 ( 653) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
       16322, /* 37460 ( 653) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    51021536, /* 37461 ( 653) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  0] -1 */
    35550698, /* 37462 ( 653) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
    17022432, /* 37463 ( 653) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  0]  1 */
    17009474, /* 37464 ( 653) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  0]  1 */
    18544746, /* 37465 ( 653) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
       16484, /* 37466 ( 654) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34028546, /* 37467 ( 654) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    18557870, /* 37468 ( 654) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    34015422, /* 37469 ( 654) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    35563818, /* 37470 ( 654) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  6] -1 */
     1551756, /* 37471 ( 654) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
    17022594, /* 37472 ( 654) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  0]  1 */
        3360, /* 37473 ( 654) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    51021536, /* 37474 ( 654) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  0] -1 */
    51034656, /* 37475 ( 654) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  0] -1 */
    35550698, /* 37476 ( 654) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
    52556808, /* 37477 ( 654) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    52569932, /* 37478 ( 654) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
     1538636, /* 37479 ( 654) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
    17009474, /* 37480 ( 654) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  0]  1 */
    18544746, /* 37481 ( 654) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
       16484, /* 37482 ( 655) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    51034818, /* 37483 ( 655) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  0] -1 */
    18557870, /* 37484 ( 655) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    34015422, /* 37485 ( 655) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    35563818, /* 37486 ( 655) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  6] -1 */
       16322, /* 37487 ( 655) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    51034656, /* 37488 ( 655) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  0] -1 */
    17009312, /* 37489 ( 655) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  0]  1 */
     1538474, /* 37490 ( 655) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
    35563980, /* 37491 ( 655) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6] -1 */
     1538636, /* 37492 ( 655) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
    52556970, /* 37493 ( 655) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    17009474, /* 37494 ( 655) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  0]  1 */
    18557708, /* 37495 ( 655) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    34015584, /* 37496 ( 655) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    52556808, /* 37497 ( 655) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
       16484, /* 37498 ( 656) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34028546, /* 37499 ( 656) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    18557870, /* 37500 ( 656) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
     1551756, /* 37501 ( 656) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
    35563818, /* 37502 ( 656) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  6] -1 */
    18544584, /* 37503 ( 656) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
    35550860, /* 37504 ( 656) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
    17022594, /* 37505 ( 656) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  0]  1 */
    51034656, /* 37506 ( 656) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  0] -1 */
        3198, /* 37507 ( 656) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    17009312, /* 37508 ( 656) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  0]  1 */
    51021698, /* 37509 ( 656) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  0] -1 */
     1538474, /* 37510 ( 656) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
    52569932, /* 37511 ( 656) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    52556970, /* 37512 ( 656) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    34015584, /* 37513 ( 656) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
       16484, /* 37514 ( 657) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    51034818, /* 37515 ( 657) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  0] -1 */
    18557870, /* 37516 ( 657) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    35563818, /* 37517 ( 657) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  6] -1 */
    18544584, /* 37518 ( 657) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
    35550860, /* 37519 ( 657) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
       16322, /* 37520 ( 657) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
        3360, /* 37521 ( 657) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    51021536, /* 37522 ( 657) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  0] -1 */
    51034656, /* 37523 ( 657) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  0] -1 */
    35550698, /* 37524 ( 657) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
        3198, /* 37525 ( 657) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    51021698, /* 37526 ( 657) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  0] -1 */
    35563980, /* 37527 ( 657) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6] -1 */
    18557708, /* 37528 ( 657) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    18544746, /* 37529 ( 657) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
       16484, /* 37530 ( 658) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    51034818, /* 37531 ( 658) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  0] -1 */
    18557870, /* 37532 ( 658) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    34015422, /* 37533 ( 658) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    34028546, /* 37534 ( 658) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    35550860, /* 37535 ( 658) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
     1551594, /* 37536 ( 658) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
        3360, /* 37537 ( 658) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    52556808, /* 37538 ( 658) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    17009312, /* 37539 ( 658) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  0]  1 */
    17022432, /* 37540 ( 658) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  0]  1 */
     1538474, /* 37541 ( 658) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
    35563980, /* 37542 ( 658) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6] -1 */
    52569932, /* 37543 ( 658) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    51021698, /* 37544 ( 658) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  0] -1 */
    18544746, /* 37545 ( 658) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
       16484, /* 37546 ( 659) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    18544584, /* 37547 ( 659) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
     1551594, /* 37548 ( 659) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
        3360, /* 37549 ( 659) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    51152916, /* 37550 ( 659) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6] -1 */
    52451996, /* 37551 ( 659) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
        3198, /* 37552 ( 659) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    17009312, /* 37553 ( 659) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  0]  1 */
     1538474, /* 37554 ( 659) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
     1538636, /* 37555 ( 659) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
    35445720, /* 37556 ( 659) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  0] -1 */
    35432762, /* 37557 ( 659) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  0] -1 */
    17022594, /* 37558 ( 659) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  0]  1 */
    52451834, /* 37559 ( 659) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
    34146806, /* 37560 ( 659) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    34146644, /* 37561 ( 659) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    35432600, /* 37562 ( 659) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  0] -1 */
    18557870, /* 37563 ( 659) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
     1551756, /* 37564 ( 659) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
    35445882, /* 37565 ( 659) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  0] -1 */
    34133682, /* 37566 ( 659) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
    51152754, /* 37567 ( 659) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  6] -1 */
    18557708, /* 37568 ( 659) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    52438872, /* 37569 ( 659) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
    51139796, /* 37570 ( 659) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
    52438710, /* 37571 ( 659) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
       16322, /* 37572 ( 659) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34133520, /* 37573 ( 659) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
    17022432, /* 37574 ( 659) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  0]  1 */
    51139634, /* 37575 ( 659) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
    17009474, /* 37576 ( 659) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  0]  1 */
    18544746, /* 37577 ( 659) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
       16484, /* 37578 ( 660) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    18544584, /* 37579 ( 660) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
     1551594, /* 37580 ( 660) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
        3360, /* 37581 ( 660) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    51021696, /* 37582 ( 660) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  0] -1 */
        3198, /* 37583 ( 660) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    17009312, /* 37584 ( 660) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  0]  1 */
    35550858, /* 37585 ( 660) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6] -1 */
     1538474, /* 37586 ( 660) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
     1538636, /* 37587 ( 660) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
    52569930, /* 37588 ( 660) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    51021534, /* 37589 ( 660) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  0] -1 */
    35550696, /* 37590 ( 660) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  6] -1 */
    17022594, /* 37591 ( 660) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  0]  1 */
    34028544, /* 37592 ( 660) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    52556972, /* 37593 ( 660) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    34015424, /* 37594 ( 660) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    34015586, /* 37595 ( 660) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    18557870, /* 37596 ( 660) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
     1551756, /* 37597 ( 660) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
    52556810, /* 37598 ( 660) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    34028706, /* 37599 ( 660) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    51034820, /* 37600 ( 660) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  0] -1 */
    35563982, /* 37601 ( 660) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
    52570092, /* 37602 ( 660) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    18557708, /* 37603 ( 660) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
       16322, /* 37604 ( 660) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    51034658, /* 37605 ( 660) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  0] -1 */
    35563820, /* 37606 ( 660) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
    17022432, /* 37607 ( 660) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  0]  1 */
    17009474, /* 37608 ( 660) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  0]  1 */
    18544746, /* 37609 ( 660) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
       16484, /* 37610 ( 652) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    18557870, /* 37611 ( 652) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    18426650, /* 37612 ( 652) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    18544584, /* 37613 ( 652) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
       16322, /* 37614 ( 652) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
      121460, /* 37615 ( 652) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6]  1 */
    18426488, /* 37616 ( 652) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
        3360, /* 37617 ( 652) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
        3198, /* 37618 ( 652) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
      134418, /* 37619 ( 652) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  6]  1 */
      121298, /* 37620 ( 652) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6]  1 */
    18439608, /* 37621 ( 652) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
    18439770, /* 37622 ( 652) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
      134580, /* 37623 ( 652) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  6]  1 */
    18557708, /* 37624 ( 652) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    18544746, /* 37625 ( 652) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
       16484, /* 37626 ( 653) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34133684, /* 37627 ( 653) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    18544584, /* 37628 ( 653) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
    18426488, /* 37629 ( 653) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
        3360, /* 37630 ( 653) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
        3198, /* 37631 ( 653) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
      134418, /* 37632 ( 653) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  6]  1 */
    18439608, /* 37633 ( 653) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
    18439770, /* 37634 ( 653) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
    52438874, /* 37635 ( 653) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
    52570094, /* 37636 ( 653) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
      121460, /* 37637 ( 653) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6]  1 */
    52569932, /* 37638 ( 653) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    34028708, /* 37639 ( 653) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    34028546, /* 37640 ( 653) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    18557870, /* 37641 ( 653) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    18426650, /* 37642 ( 653) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    34133522, /* 37643 ( 653) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    34146804, /* 37644 ( 653) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
    52556970, /* 37645 ( 653) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    18557708, /* 37646 ( 653) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    34015584, /* 37647 ( 653) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    52556808, /* 37648 ( 653) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    52438712, /* 37649 ( 653) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
    34015422, /* 37650 ( 653) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    52451994, /* 37651 ( 653) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
       16322, /* 37652 ( 653) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34146642, /* 37653 ( 653) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
    52451832, /* 37654 ( 653) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
      121298, /* 37655 ( 653) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6]  1 */
      134580, /* 37656 ( 653) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  6]  1 */
    18544746, /* 37657 ( 653) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
       16484, /* 37658 ( 654) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34028546, /* 37659 ( 654) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    18557870, /* 37660 ( 654) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    34015422, /* 37661 ( 654) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    52438712, /* 37662 ( 654) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
    18426650, /* 37663 ( 654) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
      121460, /* 37664 ( 654) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6]  1 */
        3360, /* 37665 ( 654) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    34146642, /* 37666 ( 654) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
    34133522, /* 37667 ( 654) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    52451832, /* 37668 ( 654) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
    52556808, /* 37669 ( 654) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    52569932, /* 37670 ( 654) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    18439770, /* 37671 ( 654) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
      134580, /* 37672 ( 654) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  6]  1 */
    18544746, /* 37673 ( 654) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
       16484, /* 37674 ( 655) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34133684, /* 37675 ( 655) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    18557870, /* 37676 ( 655) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    34015422, /* 37677 ( 655) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    52438712, /* 37678 ( 655) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
       16322, /* 37679 ( 655) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34133522, /* 37680 ( 655) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
      134418, /* 37681 ( 655) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  6]  1 */
    18439608, /* 37682 ( 655) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
    52438874, /* 37683 ( 655) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
    18439770, /* 37684 ( 655) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
    52556970, /* 37685 ( 655) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
      134580, /* 37686 ( 655) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  6]  1 */
    18557708, /* 37687 ( 655) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    34015584, /* 37688 ( 655) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    52556808, /* 37689 ( 655) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
       16484, /* 37690 ( 656) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34028546, /* 37691 ( 656) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    18557870, /* 37692 ( 656) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    18426650, /* 37693 ( 656) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    52438712, /* 37694 ( 656) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
    18544584, /* 37695 ( 656) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
    52451994, /* 37696 ( 656) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
      121460, /* 37697 ( 656) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6]  1 */
    34133522, /* 37698 ( 656) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
        3198, /* 37699 ( 656) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
      134418, /* 37700 ( 656) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  6]  1 */
    34146804, /* 37701 ( 656) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
    18439608, /* 37702 ( 656) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
    52569932, /* 37703 ( 656) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    52556970, /* 37704 ( 656) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    34015584, /* 37705 ( 656) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
       16484, /* 37706 ( 657) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34133684, /* 37707 ( 657) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    18557870, /* 37708 ( 657) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    52438712, /* 37709 ( 657) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
    18544584, /* 37710 ( 657) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
    52451994, /* 37711 ( 657) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
       16322, /* 37712 ( 657) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
        3360, /* 37713 ( 657) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    34146642, /* 37714 ( 657) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
    34133522, /* 37715 ( 657) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    52451832, /* 37716 ( 657) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
        3198, /* 37717 ( 657) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    34146804, /* 37718 ( 657) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
    52438874, /* 37719 ( 657) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
    18557708, /* 37720 ( 657) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    18544746, /* 37721 ( 657) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
       16484, /* 37722 ( 658) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34133684, /* 37723 ( 658) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    18557870, /* 37724 ( 658) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    34015422, /* 37725 ( 658) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    34028546, /* 37726 ( 658) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    52451994, /* 37727 ( 658) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
    18426488, /* 37728 ( 658) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
        3360, /* 37729 ( 658) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    52556808, /* 37730 ( 658) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
      134418, /* 37731 ( 658) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  6]  1 */
      121298, /* 37732 ( 658) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6]  1 */
    18439608, /* 37733 ( 658) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
    52438874, /* 37734 ( 658) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
    52569932, /* 37735 ( 658) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    34146804, /* 37736 ( 658) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
    18544746, /* 37737 ( 658) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
       16484, /* 37738 ( 659) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    18544584, /* 37739 ( 659) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
    18426488, /* 37740 ( 659) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
        3360, /* 37741 ( 659) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    51139796, /* 37742 ( 659) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
    35563982, /* 37743 ( 659) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
        3198, /* 37744 ( 659) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
      134418, /* 37745 ( 659) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  6]  1 */
    18439608, /* 37746 ( 659) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
    18439770, /* 37747 ( 659) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
    35432600, /* 37748 ( 659) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  0] -1 */
    35445882, /* 37749 ( 659) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  0] -1 */
      121460, /* 37750 ( 659) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6]  1 */
    35563820, /* 37751 ( 659) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
    51034820, /* 37752 ( 659) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  0] -1 */
    51034658, /* 37753 ( 659) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  0] -1 */
    35445720, /* 37754 ( 659) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  0] -1 */
    18557870, /* 37755 ( 659) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    18426650, /* 37756 ( 659) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    35432762, /* 37757 ( 659) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  0] -1 */
    51021696, /* 37758 ( 659) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  0] -1 */
    51139634, /* 37759 ( 659) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
    18557708, /* 37760 ( 659) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    35550858, /* 37761 ( 659) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6] -1 */
    51152916, /* 37762 ( 659) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6] -1 */
    35550696, /* 37763 ( 659) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  6] -1 */
       16322, /* 37764 ( 659) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    51021534, /* 37765 ( 659) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  0] -1 */
      121298, /* 37766 ( 659) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6]  1 */
    51152754, /* 37767 ( 659) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  6] -1 */
      134580, /* 37768 ( 659) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  6]  1 */
    18544746, /* 37769 ( 659) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
       16484, /* 37770 ( 660) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    18544584, /* 37771 ( 660) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
    18426488, /* 37772 ( 660) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
        3360, /* 37773 ( 660) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    34133682, /* 37774 ( 660) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
        3198, /* 37775 ( 660) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
      134418, /* 37776 ( 660) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  6]  1 */
    52438872, /* 37777 ( 660) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
    18439608, /* 37778 ( 660) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
    18439770, /* 37779 ( 660) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
    52556810, /* 37780 ( 660) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    34133520, /* 37781 ( 660) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
    52438710, /* 37782 ( 660) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
      121460, /* 37783 ( 660) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6]  1 */
    34015424, /* 37784 ( 660) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    52570092, /* 37785 ( 660) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    34028544, /* 37786 ( 660) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    34028706, /* 37787 ( 660) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    18557870, /* 37788 ( 660) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    18426650, /* 37789 ( 660) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    52569930, /* 37790 ( 660) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    34015586, /* 37791 ( 660) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    34146806, /* 37792 ( 660) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    52451996, /* 37793 ( 660) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
    52556972, /* 37794 ( 660) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    18557708, /* 37795 ( 660) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
       16322, /* 37796 ( 660) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34146644, /* 37797 ( 660) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    52451834, /* 37798 ( 660) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
      121298, /* 37799 ( 660) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6]  1 */
      134580, /* 37800 ( 660) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  6]  1 */
    18544746, /* 37801 ( 660) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
       16484, /* 37802 ( 652) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    18557870, /* 37803 ( 652) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    17127572, /* 37804 ( 652) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
    18544584, /* 37805 ( 652) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
       16482, /* 37806 ( 652) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
     1420538, /* 37807 ( 652) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  0]  1 */
    17127570, /* 37808 ( 652) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6]  1 */
        3200, /* 37809 ( 652) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
        3198, /* 37810 ( 652) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
     1433496, /* 37811 ( 652) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  0]  1 */
     1420536, /* 37812 ( 652) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  0]  1 */
    17140530, /* 37813 ( 652) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  6]  1 */
    17140532, /* 37814 ( 652) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
     1433498, /* 37815 ( 652) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  0]  1 */
    18557868, /* 37816 ( 652) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
    18544586, /* 37817 ( 652) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
       16484, /* 37818 ( 653) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    35432762, /* 37819 ( 653) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  0] -1 */
    18544584, /* 37820 ( 653) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
    17127570, /* 37821 ( 653) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6]  1 */
        3200, /* 37822 ( 653) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
        3198, /* 37823 ( 653) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
     1433496, /* 37824 ( 653) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  0]  1 */
    17140530, /* 37825 ( 653) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  6]  1 */
    17140532, /* 37826 ( 653) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
    51139796, /* 37827 ( 653) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
    52570094, /* 37828 ( 653) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
     1420538, /* 37829 ( 653) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  0]  1 */
    52570092, /* 37830 ( 653) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    34028708, /* 37831 ( 653) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    34028706, /* 37832 ( 653) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    18557870, /* 37833 ( 653) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    17127572, /* 37834 ( 653) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
    35432760, /* 37835 ( 653) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  0] -1 */
    35445722, /* 37836 ( 653) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  0] -1 */
    52556810, /* 37837 ( 653) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    18557868, /* 37838 ( 653) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
    34015424, /* 37839 ( 653) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    52556808, /* 37840 ( 653) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    51139794, /* 37841 ( 653) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6] -1 */
    34015422, /* 37842 ( 653) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    51152756, /* 37843 ( 653) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
       16482, /* 37844 ( 653) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    35445720, /* 37845 ( 653) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  0] -1 */
    51152754, /* 37846 ( 653) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  6] -1 */
     1420536, /* 37847 ( 653) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  0]  1 */
     1433498, /* 37848 ( 653) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  0]  1 */
    18544586, /* 37849 ( 653) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
       16484, /* 37850 ( 654) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34028706, /* 37851 ( 654) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    18557870, /* 37852 ( 654) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    34015422, /* 37853 ( 654) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    51139794, /* 37854 ( 654) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6] -1 */
    17127572, /* 37855 ( 654) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
     1420538, /* 37856 ( 654) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  0]  1 */
        3200, /* 37857 ( 654) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    35445720, /* 37858 ( 654) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  0] -1 */
    35432760, /* 37859 ( 654) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  0] -1 */
    51152754, /* 37860 ( 654) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  6] -1 */
    52556808, /* 37861 ( 654) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    52570092, /* 37862 ( 654) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    17140532, /* 37863 ( 654) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
     1433498, /* 37864 ( 654) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  0]  1 */
    18544586, /* 37865 ( 654) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
       16484, /* 37866 ( 655) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    35432762, /* 37867 ( 655) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  0] -1 */
    18557870, /* 37868 ( 655) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    34015422, /* 37869 ( 655) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    51139794, /* 37870 ( 655) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6] -1 */
       16482, /* 37871 ( 655) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    35432760, /* 37872 ( 655) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  0] -1 */
     1433496, /* 37873 ( 655) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  0]  1 */
    17140530, /* 37874 ( 655) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  6]  1 */
    51139796, /* 37875 ( 655) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
    17140532, /* 37876 ( 655) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
    52556810, /* 37877 ( 655) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
     1433498, /* 37878 ( 655) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  0]  1 */
    18557868, /* 37879 ( 655) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
    34015424, /* 37880 ( 655) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    52556808, /* 37881 ( 655) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
       16484, /* 37882 ( 656) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34028706, /* 37883 ( 656) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    18557870, /* 37884 ( 656) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    17127572, /* 37885 ( 656) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
    51139794, /* 37886 ( 656) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6] -1 */
    18544584, /* 37887 ( 656) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
    51152756, /* 37888 ( 656) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
     1420538, /* 37889 ( 656) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  0]  1 */
    35432760, /* 37890 ( 656) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  0] -1 */
        3198, /* 37891 ( 656) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
     1433496, /* 37892 ( 656) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  0]  1 */
    35445722, /* 37893 ( 656) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  0] -1 */
    17140530, /* 37894 ( 656) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  6]  1 */
    52570092, /* 37895 ( 656) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    52556810, /* 37896 ( 656) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    34015424, /* 37897 ( 656) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
       16484, /* 37898 ( 657) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    35432762, /* 37899 ( 657) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  0] -1 */
    18557870, /* 37900 ( 657) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    51139794, /* 37901 ( 657) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6] -1 */
    18544584, /* 37902 ( 657) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
    51152756, /* 37903 ( 657) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
       16482, /* 37904 ( 657) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
        3200, /* 37905 ( 657) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    35445720, /* 37906 ( 657) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  0] -1 */
    35432760, /* 37907 ( 657) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  0] -1 */
    51152754, /* 37908 ( 657) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  6] -1 */
        3198, /* 37909 ( 657) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    35445722, /* 37910 ( 657) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  0] -1 */
    51139796, /* 37911 ( 657) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
    18557868, /* 37912 ( 657) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
    18544586, /* 37913 ( 657) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
       16484, /* 37914 ( 658) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    35432762, /* 37915 ( 658) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  0] -1 */
    18557870, /* 37916 ( 658) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    34015422, /* 37917 ( 658) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    34028706, /* 37918 ( 658) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    51152756, /* 37919 ( 658) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
    17127570, /* 37920 ( 658) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6]  1 */
        3200, /* 37921 ( 658) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    52556808, /* 37922 ( 658) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
     1433496, /* 37923 ( 658) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  0]  1 */
     1420536, /* 37924 ( 658) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  0]  1 */
    17140530, /* 37925 ( 658) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  6]  1 */
    51139796, /* 37926 ( 658) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
    52570092, /* 37927 ( 658) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    35445722, /* 37928 ( 658) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  0] -1 */
    18544586, /* 37929 ( 658) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
       16484, /* 37930 ( 659) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    18544584, /* 37931 ( 659) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
    17127570, /* 37932 ( 659) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6]  1 */
        3200, /* 37933 ( 659) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    52438874, /* 37934 ( 659) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
    35563982, /* 37935 ( 659) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
        3198, /* 37936 ( 659) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
     1433496, /* 37937 ( 659) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  0]  1 */
    17140530, /* 37938 ( 659) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  6]  1 */
    17140532, /* 37939 ( 659) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
    34133682, /* 37940 ( 659) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
    34146644, /* 37941 ( 659) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
     1420538, /* 37942 ( 659) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  0]  1 */
    35563980, /* 37943 ( 659) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6] -1 */
    51034820, /* 37944 ( 659) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  0] -1 */
    51034818, /* 37945 ( 659) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  0] -1 */
    34146642, /* 37946 ( 659) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
    18557870, /* 37947 ( 659) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    17127572, /* 37948 ( 659) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
    34133684, /* 37949 ( 659) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    51021536, /* 37950 ( 659) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  0] -1 */
    52438872, /* 37951 ( 659) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
    18557868, /* 37952 ( 659) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
    35550698, /* 37953 ( 659) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
    52451834, /* 37954 ( 659) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
    35550696, /* 37955 ( 659) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  6] -1 */
       16482, /* 37956 ( 659) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    51021534, /* 37957 ( 659) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  0] -1 */
     1420536, /* 37958 ( 659) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  0]  1 */
    52451832, /* 37959 ( 659) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
     1433498, /* 37960 ( 659) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  0]  1 */
    18544586, /* 37961 ( 659) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
       16484, /* 37962 ( 660) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    18544584, /* 37963 ( 660) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
    17127570, /* 37964 ( 660) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6]  1 */
        3200, /* 37965 ( 660) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    35432600, /* 37966 ( 660) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  0] -1 */
        3198, /* 37967 ( 660) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
     1433496, /* 37968 ( 660) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  0]  1 */
    51139634, /* 37969 ( 660) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
    17140530, /* 37970 ( 660) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  6]  1 */
    17140532, /* 37971 ( 660) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
    52556970, /* 37972 ( 660) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    35432598, /* 37973 ( 660) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  0] -1 */
    51139632, /* 37974 ( 660) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  6] -1 */
     1420538, /* 37975 ( 660) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  0]  1 */
    34015584, /* 37976 ( 660) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    52569932, /* 37977 ( 660) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    34028544, /* 37978 ( 660) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    34028546, /* 37979 ( 660) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    18557870, /* 37980 ( 660) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    17127572, /* 37981 ( 660) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
    52569930, /* 37982 ( 660) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    34015586, /* 37983 ( 660) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    35445884, /* 37984 ( 660) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  0] -1 */
    51152918, /* 37985 ( 660) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
    52556972, /* 37986 ( 660) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    18557868, /* 37987 ( 660) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
       16482, /* 37988 ( 660) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    35445882, /* 37989 ( 660) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  0] -1 */
    51152916, /* 37990 ( 660) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6] -1 */
     1420536, /* 37991 ( 660) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  0]  1 */
     1433498, /* 37992 ( 660) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  0]  1 */
    18544586, /* 37993 ( 660) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
       16484, /* 37994 ( 652) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    18557870, /* 37995 ( 652) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
     1551596, /* 37996 ( 652) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
    18544584, /* 37997 ( 652) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
       16482, /* 37998 ( 652) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    17022434, /* 37999 ( 652) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  0]  1 */
     1551594, /* 38000 ( 652) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
        3200, /* 38001 ( 652) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
        3198, /* 38002 ( 652) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    17009472, /* 38003 ( 652) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  0]  1 */
    17022432, /* 38004 ( 652) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  0]  1 */
     1538634, /* 38005 ( 652) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
     1538636, /* 38006 ( 652) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
    17009474, /* 38007 ( 652) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  0]  1 */
    18557868, /* 38008 ( 652) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
    18544586, /* 38009 ( 652) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
       16484, /* 38010 ( 653) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    51034658, /* 38011 ( 653) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  0] -1 */
    18544584, /* 38012 ( 653) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
     1551594, /* 38013 ( 653) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
        3200, /* 38014 ( 653) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
        3198, /* 38015 ( 653) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    17009472, /* 38016 ( 653) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  0]  1 */
     1538634, /* 38017 ( 653) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
     1538636, /* 38018 ( 653) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
    35563820, /* 38019 ( 653) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
    52570094, /* 38020 ( 653) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    17022434, /* 38021 ( 653) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  0]  1 */
    52570092, /* 38022 ( 653) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    34028708, /* 38023 ( 653) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    34028706, /* 38024 ( 653) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    18557870, /* 38025 ( 653) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
     1551596, /* 38026 ( 653) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
    51034656, /* 38027 ( 653) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  0] -1 */
    51021698, /* 38028 ( 653) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  0] -1 */
    52556810, /* 38029 ( 653) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    18557868, /* 38030 ( 653) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
    34015424, /* 38031 ( 653) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    52556808, /* 38032 ( 653) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    35563818, /* 38033 ( 653) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  6] -1 */
    34015422, /* 38034 ( 653) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    35550860, /* 38035 ( 653) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
       16482, /* 38036 ( 653) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    51021696, /* 38037 ( 653) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  0] -1 */
    35550858, /* 38038 ( 653) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6] -1 */
    17022432, /* 38039 ( 653) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  0]  1 */
    17009474, /* 38040 ( 653) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  0]  1 */
    18544586, /* 38041 ( 653) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
       16484, /* 38042 ( 654) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34028706, /* 38043 ( 654) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    18557870, /* 38044 ( 654) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    34015422, /* 38045 ( 654) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    35563818, /* 38046 ( 654) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  6] -1 */
     1551596, /* 38047 ( 654) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
    17022434, /* 38048 ( 654) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  0]  1 */
        3200, /* 38049 ( 654) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    51021696, /* 38050 ( 654) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  0] -1 */
    51034656, /* 38051 ( 654) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  0] -1 */
    35550858, /* 38052 ( 654) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6] -1 */
    52556808, /* 38053 ( 654) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    52570092, /* 38054 ( 654) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
     1538636, /* 38055 ( 654) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
    17009474, /* 38056 ( 654) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  0]  1 */
    18544586, /* 38057 ( 654) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
       16484, /* 38058 ( 655) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    51034658, /* 38059 ( 655) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  0] -1 */
    18557870, /* 38060 ( 655) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    34015422, /* 38061 ( 655) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    35563818, /* 38062 ( 655) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  6] -1 */
       16482, /* 38063 ( 655) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    51034656, /* 38064 ( 655) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  0] -1 */
    17009472, /* 38065 ( 655) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  0]  1 */
     1538634, /* 38066 ( 655) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
    35563820, /* 38067 ( 655) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
     1538636, /* 38068 ( 655) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
    52556810, /* 38069 ( 655) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    17009474, /* 38070 ( 655) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  0]  1 */
    18557868, /* 38071 ( 655) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
    34015424, /* 38072 ( 655) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    52556808, /* 38073 ( 655) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
       16484, /* 38074 ( 656) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34028706, /* 38075 ( 656) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    18557870, /* 38076 ( 656) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
     1551596, /* 38077 ( 656) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
    35563818, /* 38078 ( 656) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  6] -1 */
    18544584, /* 38079 ( 656) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
    35550860, /* 38080 ( 656) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
    17022434, /* 38081 ( 656) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  0]  1 */
    51034656, /* 38082 ( 656) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  0] -1 */
        3198, /* 38083 ( 656) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    17009472, /* 38084 ( 656) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  0]  1 */
    51021698, /* 38085 ( 656) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  0] -1 */
     1538634, /* 38086 ( 656) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
    52570092, /* 38087 ( 656) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    52556810, /* 38088 ( 656) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    34015424, /* 38089 ( 656) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
       16484, /* 38090 ( 657) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    51034658, /* 38091 ( 657) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  0] -1 */
    18557870, /* 38092 ( 657) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    35563818, /* 38093 ( 657) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  6] -1 */
    18544584, /* 38094 ( 657) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
    35550860, /* 38095 ( 657) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
       16482, /* 38096 ( 657) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
        3200, /* 38097 ( 657) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    51021696, /* 38098 ( 657) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  0] -1 */
    51034656, /* 38099 ( 657) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  0] -1 */
    35550858, /* 38100 ( 657) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6] -1 */
        3198, /* 38101 ( 657) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    51021698, /* 38102 ( 657) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  0] -1 */
    35563820, /* 38103 ( 657) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
    18557868, /* 38104 ( 657) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
    18544586, /* 38105 ( 657) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
       16484, /* 38106 ( 658) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    51034658, /* 38107 ( 658) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  0] -1 */
    18557870, /* 38108 ( 658) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    34015422, /* 38109 ( 658) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    34028706, /* 38110 ( 658) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    35550860, /* 38111 ( 658) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
     1551594, /* 38112 ( 658) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
        3200, /* 38113 ( 658) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    52556808, /* 38114 ( 658) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    17009472, /* 38115 ( 658) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  0]  1 */
    17022432, /* 38116 ( 658) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  0]  1 */
     1538634, /* 38117 ( 658) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
    35563820, /* 38118 ( 658) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
    52570092, /* 38119 ( 658) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    51021698, /* 38120 ( 658) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  0] -1 */
    18544586, /* 38121 ( 658) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
       16484, /* 38122 ( 659) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    18544584, /* 38123 ( 659) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
     1551594, /* 38124 ( 659) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
        3200, /* 38125 ( 659) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    52451834, /* 38126 ( 659) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
    51152918, /* 38127 ( 659) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
        3198, /* 38128 ( 659) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    17009472, /* 38129 ( 659) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  0]  1 */
     1538634, /* 38130 ( 659) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
     1538636, /* 38131 ( 659) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
    34146642, /* 38132 ( 659) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
    34133684, /* 38133 ( 659) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    17022434, /* 38134 ( 659) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  0]  1 */
    51152916, /* 38135 ( 659) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6] -1 */
    35445884, /* 38136 ( 659) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  0] -1 */
    35445882, /* 38137 ( 659) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  0] -1 */
    34133682, /* 38138 ( 659) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
    18557870, /* 38139 ( 659) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
     1551596, /* 38140 ( 659) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
    34146644, /* 38141 ( 659) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    35432600, /* 38142 ( 659) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  0] -1 */
    52451832, /* 38143 ( 659) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
    18557868, /* 38144 ( 659) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
    51139634, /* 38145 ( 659) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
    52438874, /* 38146 ( 659) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
    51139632, /* 38147 ( 659) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  6] -1 */
       16482, /* 38148 ( 659) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    35432598, /* 38149 ( 659) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  0] -1 */
    17022432, /* 38150 ( 659) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  0]  1 */
    52438872, /* 38151 ( 659) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
    17009474, /* 38152 ( 659) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  0]  1 */
    18544586, /* 38153 ( 659) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
       16484, /* 38154 ( 660) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    18544584, /* 38155 ( 660) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
     1551594, /* 38156 ( 660) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
        3200, /* 38157 ( 660) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    51021536, /* 38158 ( 660) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  0] -1 */
        3198, /* 38159 ( 660) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    17009472, /* 38160 ( 660) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  0]  1 */
    35550698, /* 38161 ( 660) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
     1538634, /* 38162 ( 660) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
     1538636, /* 38163 ( 660) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
    52569930, /* 38164 ( 660) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    51021534, /* 38165 ( 660) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  0] -1 */
    35550696, /* 38166 ( 660) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  6] -1 */
    17022434, /* 38167 ( 660) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  0]  1 */
    34028544, /* 38168 ( 660) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    52556972, /* 38169 ( 660) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    34015584, /* 38170 ( 660) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    34015586, /* 38171 ( 660) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    18557870, /* 38172 ( 660) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
     1551596, /* 38173 ( 660) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
    52556970, /* 38174 ( 660) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    34028546, /* 38175 ( 660) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    51034820, /* 38176 ( 660) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  0] -1 */
    35563982, /* 38177 ( 660) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
    52569932, /* 38178 ( 660) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    18557868, /* 38179 ( 660) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
       16482, /* 38180 ( 660) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    51034818, /* 38181 ( 660) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  0] -1 */
    35563980, /* 38182 ( 660) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6] -1 */
    17022432, /* 38183 ( 660) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  0]  1 */
    17009474, /* 38184 ( 660) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  0]  1 */
    18544586, /* 38185 ( 660) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
       16484, /* 38186 ( 652) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    18557870, /* 38187 ( 652) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    18439610, /* 38188 ( 652) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    18544584, /* 38189 ( 652) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
        3362, /* 38190 ( 652) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
      134420, /* 38191 ( 652) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6]  1 */
    18426488, /* 38192 ( 652) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
       16320, /* 38193 ( 652) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
        3198, /* 38194 ( 652) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
      121458, /* 38195 ( 652) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  6]  1 */
      121298, /* 38196 ( 652) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6]  1 */
    18426648, /* 38197 ( 652) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
    18439770, /* 38198 ( 652) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
      134580, /* 38199 ( 652) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  6]  1 */
    18544748, /* 38200 ( 652) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    18557706, /* 38201 ( 652) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
       16484, /* 38202 ( 653) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34146644, /* 38203 ( 653) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    18544584, /* 38204 ( 653) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
    18426488, /* 38205 ( 653) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
       16320, /* 38206 ( 653) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
        3198, /* 38207 ( 653) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
      121458, /* 38208 ( 653) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  6]  1 */
    18426648, /* 38209 ( 653) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
    18439770, /* 38210 ( 653) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
    52451834, /* 38211 ( 653) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
    52570094, /* 38212 ( 653) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
      134420, /* 38213 ( 653) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6]  1 */
    52556972, /* 38214 ( 653) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    34028708, /* 38215 ( 653) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    34015586, /* 38216 ( 653) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    18557870, /* 38217 ( 653) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    18439610, /* 38218 ( 653) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    34133522, /* 38219 ( 653) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    34146804, /* 38220 ( 653) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
    52569930, /* 38221 ( 653) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    18544748, /* 38222 ( 653) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    34028544, /* 38223 ( 653) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    52556808, /* 38224 ( 653) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    52438712, /* 38225 ( 653) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
    34015422, /* 38226 ( 653) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    52451994, /* 38227 ( 653) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
        3362, /* 38228 ( 653) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34133682, /* 38229 ( 653) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
    52438872, /* 38230 ( 653) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
      121298, /* 38231 ( 653) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6]  1 */
      134580, /* 38232 ( 653) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  6]  1 */
    18557706, /* 38233 ( 653) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
       16484, /* 38234 ( 654) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34015586, /* 38235 ( 654) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    18557870, /* 38236 ( 654) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    34015422, /* 38237 ( 654) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    52438712, /* 38238 ( 654) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
    18439610, /* 38239 ( 654) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
      134420, /* 38240 ( 654) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6]  1 */
       16320, /* 38241 ( 654) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    34133682, /* 38242 ( 654) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
    34133522, /* 38243 ( 654) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    52438872, /* 38244 ( 654) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
    52556808, /* 38245 ( 654) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    52556972, /* 38246 ( 654) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    18439770, /* 38247 ( 654) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
      134580, /* 38248 ( 654) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  6]  1 */
    18557706, /* 38249 ( 654) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
       16484, /* 38250 ( 655) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34146644, /* 38251 ( 655) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    18557870, /* 38252 ( 655) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    34015422, /* 38253 ( 655) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    52438712, /* 38254 ( 655) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
        3362, /* 38255 ( 655) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34133522, /* 38256 ( 655) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
      121458, /* 38257 ( 655) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  6]  1 */
    18426648, /* 38258 ( 655) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
    52451834, /* 38259 ( 655) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
    18439770, /* 38260 ( 655) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
    52569930, /* 38261 ( 655) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
      134580, /* 38262 ( 655) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  6]  1 */
    18544748, /* 38263 ( 655) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    34028544, /* 38264 ( 655) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    52556808, /* 38265 ( 655) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
       16484, /* 38266 ( 656) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34015586, /* 38267 ( 656) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    18557870, /* 38268 ( 656) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    18439610, /* 38269 ( 656) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    52438712, /* 38270 ( 656) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
    18544584, /* 38271 ( 656) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
    52451994, /* 38272 ( 656) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
      134420, /* 38273 ( 656) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6]  1 */
    34133522, /* 38274 ( 656) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
        3198, /* 38275 ( 656) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
      121458, /* 38276 ( 656) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  6]  1 */
    34146804, /* 38277 ( 656) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
    18426648, /* 38278 ( 656) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
    52556972, /* 38279 ( 656) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    52569930, /* 38280 ( 656) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    34028544, /* 38281 ( 656) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
       16484, /* 38282 ( 657) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34146644, /* 38283 ( 657) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    18557870, /* 38284 ( 657) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    52438712, /* 38285 ( 657) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
    18544584, /* 38286 ( 657) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
    52451994, /* 38287 ( 657) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
        3362, /* 38288 ( 657) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
       16320, /* 38289 ( 657) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    34133682, /* 38290 ( 657) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
    34133522, /* 38291 ( 657) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    52438872, /* 38292 ( 657) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
        3198, /* 38293 ( 657) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    34146804, /* 38294 ( 657) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
    52451834, /* 38295 ( 657) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
    18544748, /* 38296 ( 657) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    18557706, /* 38297 ( 657) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
       16484, /* 38298 ( 658) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34146644, /* 38299 ( 658) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    18557870, /* 38300 ( 658) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    34015422, /* 38301 ( 658) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    34015586, /* 38302 ( 658) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    52451994, /* 38303 ( 658) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
    18426488, /* 38304 ( 658) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
       16320, /* 38305 ( 658) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    52556808, /* 38306 ( 658) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
      121458, /* 38307 ( 658) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  6]  1 */
      121298, /* 38308 ( 658) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6]  1 */
    18426648, /* 38309 ( 658) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
    52451834, /* 38310 ( 658) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
    52556972, /* 38311 ( 658) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    34146804, /* 38312 ( 658) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
    18557706, /* 38313 ( 658) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
       16484, /* 38314 ( 659) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    18544584, /* 38315 ( 659) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
    18426488, /* 38316 ( 659) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
       16320, /* 38317 ( 659) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    35563820, /* 38318 ( 659) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
    51152918, /* 38319 ( 659) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
        3198, /* 38320 ( 659) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
      121458, /* 38321 ( 659) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  6]  1 */
    18426648, /* 38322 ( 659) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
    18439770, /* 38323 ( 659) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
    51021536, /* 38324 ( 659) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  0] -1 */
    51034818, /* 38325 ( 659) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  0] -1 */
      134420, /* 38326 ( 659) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6]  1 */
    51139796, /* 38327 ( 659) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
    35445884, /* 38328 ( 659) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  0] -1 */
    35432762, /* 38329 ( 659) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  0] -1 */
    51021696, /* 38330 ( 659) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  0] -1 */
    18557870, /* 38331 ( 659) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    18439610, /* 38332 ( 659) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    51034658, /* 38333 ( 659) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  0] -1 */
    35445720, /* 38334 ( 659) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  0] -1 */
    35550698, /* 38335 ( 659) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
    18544748, /* 38336 ( 659) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    51152754, /* 38337 ( 659) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  6] -1 */
    35563980, /* 38338 ( 659) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6] -1 */
    51139632, /* 38339 ( 659) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  6] -1 */
        3362, /* 38340 ( 659) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    35432598, /* 38341 ( 659) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  0] -1 */
      121298, /* 38342 ( 659) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6]  1 */
    35550858, /* 38343 ( 659) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6] -1 */
      134580, /* 38344 ( 659) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  6]  1 */
    18557706, /* 38345 ( 659) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
       16484, /* 38346 ( 660) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    18544584, /* 38347 ( 660) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
    18426488, /* 38348 ( 660) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
       16320, /* 38349 ( 660) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    34146642, /* 38350 ( 660) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
        3198, /* 38351 ( 660) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
      121458, /* 38352 ( 660) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  6]  1 */
    52451832, /* 38353 ( 660) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
    18426648, /* 38354 ( 660) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
    18439770, /* 38355 ( 660) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
    52556810, /* 38356 ( 660) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    34133520, /* 38357 ( 660) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
    52438710, /* 38358 ( 660) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
      134420, /* 38359 ( 660) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6]  1 */
    34015424, /* 38360 ( 660) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    52570092, /* 38361 ( 660) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    34015584, /* 38362 ( 660) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    34028706, /* 38363 ( 660) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    18557870, /* 38364 ( 660) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    18439610, /* 38365 ( 660) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    52556970, /* 38366 ( 660) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    34028546, /* 38367 ( 660) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    34146806, /* 38368 ( 660) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    52451996, /* 38369 ( 660) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
    52569932, /* 38370 ( 660) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    18544748, /* 38371 ( 660) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
        3362, /* 38372 ( 660) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34133684, /* 38373 ( 660) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    52438874, /* 38374 ( 660) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
      121298, /* 38375 ( 660) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6]  1 */
      134580, /* 38376 ( 660) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  6]  1 */
    18557706, /* 38377 ( 660) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
       16484, /* 38378 ( 661) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
        7898, /* 38379 ( 661) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 0,  0,  0]  1 */
       11786, /* 38380 ( 661) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  0]  1 */
        3200, /* 38381 ( 661) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
       16484, /* 38382 ( 662) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
        3200, /* 38383 ( 662) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34024010, /* 38384 ( 662) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  0] -1 */
        7898, /* 38385 ( 662) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34020122, /* 38386 ( 662) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 0,  0,  0] -1 */
       11786, /* 38387 ( 662) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34015424, /* 38388 ( 662) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    34028708, /* 38389 ( 662) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
       16484, /* 38390 ( 663) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34024010, /* 38391 ( 663) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    34020122, /* 38392 ( 663) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 0,  0,  0] -1 */
        3200, /* 38393 ( 663) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
       16484, /* 38394 ( 664) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34142108, /* 38395 ( 664) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    34133522, /* 38396 ( 664) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
        3200, /* 38397 ( 664) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34138220, /* 38398 ( 664) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    34146806, /* 38399 ( 664) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
       11786, /* 38400 ( 664) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  0]  1 */
        7898, /* 38401 ( 664) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 0,  0,  0]  1 */
       16484, /* 38402 ( 665) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
        3200, /* 38403 ( 665) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    52447298, /* 38404 ( 665) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 6,  6,  0] -1 */
    52451996, /* 38405 ( 665) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
       11786, /* 38406 ( 665) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    52438712, /* 38407 ( 665) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
        7898, /* 38408 ( 665) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    52443410, /* 38409 ( 665) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 6,  6,  0] -1 */
       16484, /* 38410 ( 666) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    52565396, /* 38411 ( 666) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    52556810, /* 38412 ( 666) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
        3200, /* 38413 ( 666) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    52561508, /* 38414 ( 666) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 6,  6,  6] -1 */
       11786, /* 38415 ( 666) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  0]  1 */
        7898, /* 38416 ( 666) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    52570094, /* 38417 ( 666) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
       16484, /* 38418 ( 667) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
      121298, /* 38419 ( 667) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6]  1 */
      188933, /* 38420 ( 667) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  9]  1 */
       66947, /* 38421 ( 667) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 0,  0,  3]  1 */
       16484, /* 38422 ( 668) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34133522, /* 38423 ( 668) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    34079171, /* 38424 ( 668) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 0,  0,  3] -1 */
      188933, /* 38425 ( 668) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  9]  1 */
    34201157, /* 38426 ( 668) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  9] -1 */
      121298, /* 38427 ( 668) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6]  1 */
       66947, /* 38428 ( 668) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 0,  0,  3]  1 */
    34028708, /* 38429 ( 668) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
       16484, /* 38430 ( 669) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
      121298, /* 38431 ( 669) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6]  1 */
    34079171, /* 38432 ( 669) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 0,  0,  3] -1 */
    34201157, /* 38433 ( 669) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  9] -1 */
       16484, /* 38434 ( 670) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34197269, /* 38435 ( 670) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 0,  0,  9] -1 */
      188933, /* 38436 ( 670) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  9]  1 */
      121298, /* 38437 ( 670) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6]  1 */
    34083059, /* 38438 ( 670) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  3] -1 */
    34146806, /* 38439 ( 670) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    34015424, /* 38440 ( 670) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
       66947, /* 38441 ( 670) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 0,  0,  3]  1 */
       16484, /* 38442 ( 671) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    52556810, /* 38443 ( 671) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
      188933, /* 38444 ( 671) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  9]  1 */
    52502459, /* 38445 ( 671) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 6,  6,  3] -1 */
    52624445, /* 38446 ( 671) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 6,  6,  9] -1 */
      121298, /* 38447 ( 671) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6]  1 */
    52451996, /* 38448 ( 671) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
       66947, /* 38449 ( 671) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 0,  0,  3]  1 */
       16484, /* 38450 ( 672) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    52506347, /* 38451 ( 672) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 6,  6,  3] -1 */
    52438712, /* 38452 ( 672) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
    52620557, /* 38453 ( 672) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 6,  6,  9] -1 */
      188933, /* 38454 ( 672) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  9]  1 */
      121298, /* 38455 ( 672) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6]  1 */
       66947, /* 38456 ( 672) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 0,  0,  3]  1 */
    52570094, /* 38457 ( 672) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
       16484, /* 38458 ( 673) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
      129884, /* 38459 ( 673) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  6]  1 */
      125996, /* 38460 ( 673) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 0,  0,  6]  1 */
        3200, /* 38461 ( 673) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
       16484, /* 38462 ( 674) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34142108, /* 38463 ( 674) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  6] -1 */
        3200, /* 38464 ( 674) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
      129884, /* 38465 ( 674) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  6]  1 */
    34138220, /* 38466 ( 674) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 0,  0,  6] -1 */
      125996, /* 38467 ( 674) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 0,  0,  6]  1 */
    34015424, /* 38468 ( 674) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    34028708, /* 38469 ( 674) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
       16484, /* 38470 ( 675) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34142108, /* 38471 ( 675) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    34138220, /* 38472 ( 675) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 0,  0,  6] -1 */
        3200, /* 38473 ( 675) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
       16484, /* 38474 ( 676) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34133522, /* 38475 ( 676) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
        3200, /* 38476 ( 676) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
      129884, /* 38477 ( 676) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  6]  1 */
    34024010, /* 38478 ( 676) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    34020122, /* 38479 ( 676) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    34146806, /* 38480 ( 676) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
      125996, /* 38481 ( 676) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 0,  0,  6]  1 */
       16484, /* 38482 ( 677) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    52565396, /* 38483 ( 677) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 6,  6,  6] -1 */
        3200, /* 38484 ( 677) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    52561508, /* 38485 ( 677) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 6,  6,  6] -1 */
      129884, /* 38486 ( 677) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  6]  1 */
    52451996, /* 38487 ( 677) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
      125996, /* 38488 ( 677) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 0,  0,  6]  1 */
    52438712, /* 38489 ( 677) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
       16484, /* 38490 ( 678) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    52556810, /* 38491 ( 678) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
        3200, /* 38492 ( 678) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
      129884, /* 38493 ( 678) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  6]  1 */
    52447298, /* 38494 ( 678) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 6,  6,  0] -1 */
      125996, /* 38495 ( 678) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 0,  0,  6]  1 */
    52570094, /* 38496 ( 678) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    52443410, /* 38497 ( 678) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 6,  6,  0] -1 */
       16484, /* 38498 ( 679) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
      121298, /* 38499 ( 679) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6]  1 */
      185045, /* 38500 ( 679) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 0,  0,  9]  1 */
       70835, /* 38501 ( 679) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  3]  1 */
       16484, /* 38502 ( 680) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34133522, /* 38503 ( 680) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    34197269, /* 38504 ( 680) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 0,  0,  9] -1 */
      185045, /* 38505 ( 680) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 0,  0,  9]  1 */
      121298, /* 38506 ( 680) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6]  1 */
    34083059, /* 38507 ( 680) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  3] -1 */
    34028708, /* 38508 ( 680) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
       70835, /* 38509 ( 680) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  3]  1 */
       16484, /* 38510 ( 681) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34083059, /* 38511 ( 681) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  3] -1 */
      121298, /* 38512 ( 681) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6]  1 */
    34197269, /* 38513 ( 681) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 0,  0,  9] -1 */
       16484, /* 38514 ( 682) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34079171, /* 38515 ( 682) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 0,  0,  3] -1 */
      185045, /* 38516 ( 682) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 0,  0,  9]  1 */
    34201157, /* 38517 ( 682) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  9] -1 */
      121298, /* 38518 ( 682) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6]  1 */
    34146806, /* 38519 ( 682) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    34015424, /* 38520 ( 682) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
       70835, /* 38521 ( 682) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  3]  1 */
       16484, /* 38522 ( 683) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    52506347, /* 38523 ( 683) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 6,  6,  3] -1 */
    52556810, /* 38524 ( 683) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    52620557, /* 38525 ( 683) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 6,  6,  9] -1 */
      185045, /* 38526 ( 683) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 0,  0,  9]  1 */
      121298, /* 38527 ( 683) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6]  1 */
    52451996, /* 38528 ( 683) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
       70835, /* 38529 ( 683) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  3]  1 */
       16484, /* 38530 ( 684) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
      185045, /* 38531 ( 684) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 0,  0,  9]  1 */
    52502459, /* 38532 ( 684) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 6,  6,  3] -1 */
    52624445, /* 38533 ( 684) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 6,  6,  9] -1 */
      121298, /* 38534 ( 684) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6]  1 */
    52438712, /* 38535 ( 684) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
    52570094, /* 38536 ( 684) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
       70835, /* 38537 ( 684) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  3]  1 */
       16484, /* 38538 ( 685) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    18557870, /* 38539 ( 685) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
        3200, /* 38540 ( 685) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    18553172, /* 38541 ( 685) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    18544586, /* 38542 ( 685) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    18549284, /* 38543 ( 685) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 6,  6,  6]  1 */
       11786, /* 38544 ( 685) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  0]  1 */
        7898, /* 38545 ( 685) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 0,  0,  0]  1 */
       16484, /* 38546 ( 686) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    52565396, /* 38547 ( 686) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    18557870, /* 38548 ( 686) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    52556810, /* 38549 ( 686) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
        3200, /* 38550 ( 686) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    52561508, /* 38551 ( 686) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    34024010, /* 38552 ( 686) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  0] -1 */
        7898, /* 38553 ( 686) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    18553172, /* 38554 ( 686) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    18544586, /* 38555 ( 686) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    34020122, /* 38556 ( 686) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    18549284, /* 38557 ( 686) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 6,  6,  6]  1 */
       11786, /* 38558 ( 686) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34015424, /* 38559 ( 686) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    34028708, /* 38560 ( 686) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    52570094, /* 38561 ( 686) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
       16484, /* 38562 ( 687) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    52565396, /* 38563 ( 687) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    18557870, /* 38564 ( 687) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
        3200, /* 38565 ( 687) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    52561508, /* 38566 ( 687) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    34024010, /* 38567 ( 687) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    18544586, /* 38568 ( 687) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    34020122, /* 38569 ( 687) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 0,  0,  0] -1 */
       16484, /* 38570 ( 688) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34142108, /* 38571 ( 688) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    18557870, /* 38572 ( 688) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    34133522, /* 38573 ( 688) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
        3200, /* 38574 ( 688) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    18553172, /* 38575 ( 688) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    34138220, /* 38576 ( 688) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    52447298, /* 38577 ( 688) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 6,  6,  0] -1 */
    52451996, /* 38578 ( 688) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
    18544586, /* 38579 ( 688) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    34146806, /* 38580 ( 688) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    18549284, /* 38581 ( 688) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 6,  6,  6]  1 */
       11786, /* 38582 ( 688) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    52438712, /* 38583 ( 688) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
        7898, /* 38584 ( 688) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    52443410, /* 38585 ( 688) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 6,  6,  0] -1 */
       16484, /* 38586 ( 689) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    18557870, /* 38587 ( 689) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
     1488011, /* 38588 ( 689) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 0,  6,  3]  1 */
        3200, /* 38589 ( 689) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    17191157, /* 38590 ( 689) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 6,  0,  9]  1 */
    18544586, /* 38591 ( 689) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
     1484123, /* 38592 ( 689) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 0,  6,  3]  1 */
    17195045, /* 38593 ( 689) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 6,  0,  9]  1 */
       16484, /* 38594 ( 690) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    18557870, /* 38595 ( 690) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    51203381, /* 38596 ( 690) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 6,  0,  9] -1 */
    52556810, /* 38597 ( 690) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
        3200, /* 38598 ( 690) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
     1488011, /* 38599 ( 690) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 0,  6,  3]  1 */
    51207269, /* 38600 ( 690) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 6,  0,  9] -1 */
    17191157, /* 38601 ( 690) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 6,  0,  9]  1 */
    35496347, /* 38602 ( 690) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 0,  6,  3] -1 */
    18544586, /* 38603 ( 690) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    35500235, /* 38604 ( 690) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 0,  6,  3] -1 */
     1484123, /* 38605 ( 690) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 0,  6,  3]  1 */
    17195045, /* 38606 ( 690) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 6,  0,  9]  1 */
    34028708, /* 38607 ( 690) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    52570094, /* 38608 ( 690) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    34015424, /* 38609 ( 690) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
       16484, /* 38610 ( 691) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    18557870, /* 38611 ( 691) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    51203381, /* 38612 ( 691) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 6,  0,  9] -1 */
        3200, /* 38613 ( 691) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    51207269, /* 38614 ( 691) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 6,  0,  9] -1 */
    35496347, /* 38615 ( 691) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 0,  6,  3] -1 */
    18544586, /* 38616 ( 691) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    35500235, /* 38617 ( 691) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 0,  6,  3] -1 */
       16484, /* 38618 ( 692) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    35618333, /* 38619 ( 692) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 0,  6,  9] -1 */
    18557870, /* 38620 ( 692) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    52438712, /* 38621 ( 692) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
     1488011, /* 38622 ( 692) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 0,  6,  3]  1 */
        3200, /* 38623 ( 692) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34133522, /* 38624 ( 692) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    17191157, /* 38625 ( 692) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 6,  0,  9]  1 */
    52451996, /* 38626 ( 692) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
    18544586, /* 38627 ( 692) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    34146806, /* 38628 ( 692) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
     1484123, /* 38629 ( 692) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 0,  6,  3]  1 */
    17195045, /* 38630 ( 692) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 6,  0,  9]  1 */
    51085283, /* 38631 ( 692) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 6,  0,  3] -1 */
    35614445, /* 38632 ( 692) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 0,  6,  9] -1 */
    51089171, /* 38633 ( 692) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 6,  0,  3] -1 */
       16484, /* 38634 ( 693) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
       11784, /* 38635 ( 693) [ 0,  1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  0]  1 */
        7896, /* 38636 ( 693) [ 0, -1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  0]  1 */
        3200, /* 38637 ( 693) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
       16484, /* 38638 ( 694) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34024008, /* 38639 ( 694) [ 0,  1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    34020120, /* 38640 ( 694) [ 0, -1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  0] -1 */
        3200, /* 38641 ( 694) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
       11784, /* 38642 ( 694) [ 0,  1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  0]  1 */
        7896, /* 38643 ( 694) [ 0, -1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    34015424, /* 38644 ( 694) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    34028708, /* 38645 ( 694) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
       16484, /* 38646 ( 695) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34024008, /* 38647 ( 695) [ 0,  1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    34020120, /* 38648 ( 695) [ 0, -1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  0] -1 */
        3200, /* 38649 ( 695) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
       16484, /* 38650 ( 696) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34133522, /* 38651 ( 696) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
        3200, /* 38652 ( 696) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
       11784, /* 38653 ( 696) [ 0,  1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  0]  1 */
        7896, /* 38654 ( 696) [ 0, -1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    34142106, /* 38655 ( 696) [ 0,  1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  6] -1 */
    34138218, /* 38656 ( 696) [ 0, -1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  6] -1 */
    34146806, /* 38657 ( 696) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
       16484, /* 38658 ( 697) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
        3200, /* 38659 ( 697) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
       11784, /* 38660 ( 697) [ 0,  1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  0]  1 */
        7896, /* 38661 ( 697) [ 0, -1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    52443408, /* 38662 ( 697) [ 0, -1,  0,  1,  0,  0,  0,  0, -1] [ 6,  6,  0] -1 */
    52451996, /* 38663 ( 697) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
    52438712, /* 38664 ( 697) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
    52447296, /* 38665 ( 697) [ 0,  1,  0, -1,  0,  0,  0,  0, -1] [ 6,  6,  0] -1 */
       16484, /* 38666 ( 698) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    52556810, /* 38667 ( 698) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
        3200, /* 38668 ( 698) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    52561506, /* 38669 ( 698) [ 0, -1,  0,  1,  0,  0,  0,  0, -1] [ 6,  6,  6] -1 */
       11784, /* 38670 ( 698) [ 0,  1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  0]  1 */
        7896, /* 38671 ( 698) [ 0, -1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    52565394, /* 38672 ( 698) [ 0,  1,  0, -1,  0,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    52570094, /* 38673 ( 698) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
       16484, /* 38674 ( 699) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    18557870, /* 38675 ( 699) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
        3200, /* 38676 ( 699) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
       11784, /* 38677 ( 699) [ 0,  1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  0]  1 */
        7896, /* 38678 ( 699) [ 0, -1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    18549282, /* 38679 ( 699) [ 0, -1,  0,  1,  0,  0,  0,  0, -1] [ 6,  6,  6]  1 */
    18544586, /* 38680 ( 699) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    18553170, /* 38681 ( 699) [ 0,  1,  0, -1,  0,  0,  0,  0, -1] [ 6,  6,  6]  1 */
       16484, /* 38682 ( 700) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34024008, /* 38683 ( 700) [ 0,  1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    18557870, /* 38684 ( 700) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    52556810, /* 38685 ( 700) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    34020120, /* 38686 ( 700) [ 0, -1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  0] -1 */
        3200, /* 38687 ( 700) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    52561506, /* 38688 ( 700) [ 0, -1,  0,  1,  0,  0,  0,  0, -1] [ 6,  6,  6] -1 */
       11784, /* 38689 ( 700) [ 0,  1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  0]  1 */
        7896, /* 38690 ( 700) [ 0, -1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    18549282, /* 38691 ( 700) [ 0, -1,  0,  1,  0,  0,  0,  0, -1] [ 6,  6,  6]  1 */
    18544586, /* 38692 ( 700) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    52565394, /* 38693 ( 700) [ 0,  1,  0, -1,  0,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    34015424, /* 38694 ( 700) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    34028708, /* 38695 ( 700) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    52570094, /* 38696 ( 700) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    18553170, /* 38697 ( 700) [ 0,  1,  0, -1,  0,  0,  0,  0, -1] [ 6,  6,  6]  1 */
       16484, /* 38698 ( 701) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34024008, /* 38699 ( 701) [ 0,  1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    18557870, /* 38700 ( 701) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    34020120, /* 38701 ( 701) [ 0, -1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  0] -1 */
        3200, /* 38702 ( 701) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    52561506, /* 38703 ( 701) [ 0, -1,  0,  1,  0,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    18544586, /* 38704 ( 701) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    52565394, /* 38705 ( 701) [ 0,  1,  0, -1,  0,  0,  0,  0, -1] [ 6,  6,  6] -1 */
       16484, /* 38706 ( 702) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    18557870, /* 38707 ( 702) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    34133522, /* 38708 ( 702) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
        3200, /* 38709 ( 702) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
       11784, /* 38710 ( 702) [ 0,  1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  0]  1 */
        7896, /* 38711 ( 702) [ 0, -1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    52443408, /* 38712 ( 702) [ 0, -1,  0,  1,  0,  0,  0,  0, -1] [ 6,  6,  0] -1 */
    34142106, /* 38713 ( 702) [ 0,  1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  6] -1 */
    18549282, /* 38714 ( 702) [ 0, -1,  0,  1,  0,  0,  0,  0, -1] [ 6,  6,  6]  1 */
    34138218, /* 38715 ( 702) [ 0, -1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  6] -1 */
    52451996, /* 38716 ( 702) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
    18544586, /* 38717 ( 702) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    34146806, /* 38718 ( 702) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    52438712, /* 38719 ( 702) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
    52447296, /* 38720 ( 702) [ 0,  1,  0, -1,  0,  0,  0,  0, -1] [ 6,  6,  0] -1 */
    18553170, /* 38721 ( 702) [ 0,  1,  0, -1,  0,  0,  0,  0, -1] [ 6,  6,  6]  1 */
       16484, /* 38722 ( 703) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
        3200, /* 38723 ( 703) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
       11784, /* 38724 ( 703) [ 0,  1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  0]  1 */
        7896, /* 38725 ( 703) [ 0, -1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  0]  1 */
        3198, /* 38726 ( 703) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
       11786, /* 38727 ( 703) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  0]  1 */
        7898, /* 38728 ( 703) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 0,  0,  0]  1 */
       16482, /* 38729 ( 703) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
       16484, /* 38730 ( 704) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34024008, /* 38731 ( 704) [ 0,  1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    34015422, /* 38732 ( 704) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    34020120, /* 38733 ( 704) [ 0, -1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  0] -1 */
        3200, /* 38734 ( 704) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34024010, /* 38735 ( 704) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  0] -1 */
       11784, /* 38736 ( 704) [ 0,  1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  0]  1 */
        7896, /* 38737 ( 704) [ 0, -1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    34028706, /* 38738 ( 704) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
        3198, /* 38739 ( 704) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    34020122, /* 38740 ( 704) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 0,  0,  0] -1 */
       11786, /* 38741 ( 704) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34028708, /* 38742 ( 704) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
        7898, /* 38743 ( 704) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 0,  0,  0]  1 */
       16482, /* 38744 ( 704) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    34015424, /* 38745 ( 704) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
       16484, /* 38746 ( 705) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34024008, /* 38747 ( 705) [ 0,  1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    34020120, /* 38748 ( 705) [ 0, -1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  0] -1 */
        3200, /* 38749 ( 705) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34024010, /* 38750 ( 705) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  0] -1 */
        3198, /* 38751 ( 705) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    34020122, /* 38752 ( 705) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 0,  0,  0] -1 */
       16482, /* 38753 ( 705) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
       16484, /* 38754 ( 706) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34024008, /* 38755 ( 706) [ 0,  1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    34015422, /* 38756 ( 706) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    34020120, /* 38757 ( 706) [ 0, -1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  0] -1 */
        3200, /* 38758 ( 706) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34028706, /* 38759 ( 706) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
       11786, /* 38760 ( 706) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  0]  1 */
        7898, /* 38761 ( 706) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 0,  0,  0]  1 */
       16484, /* 38762 ( 707) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34015422, /* 38763 ( 707) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
        3200, /* 38764 ( 707) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34024010, /* 38765 ( 707) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  0] -1 */
       11784, /* 38766 ( 707) [ 0,  1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  0]  1 */
        7896, /* 38767 ( 707) [ 0, -1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    34028706, /* 38768 ( 707) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    34020122, /* 38769 ( 707) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 0,  0,  0] -1 */
       16484, /* 38770 ( 708) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34142108, /* 38771 ( 708) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    34133522, /* 38772 ( 708) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
        3200, /* 38773 ( 708) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
       11784, /* 38774 ( 708) [ 0,  1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  0]  1 */
        7896, /* 38775 ( 708) [ 0, -1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    34138220, /* 38776 ( 708) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    34142106, /* 38777 ( 708) [ 0,  1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  6] -1 */
    34133520, /* 38778 ( 708) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
    34138218, /* 38779 ( 708) [ 0, -1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  6] -1 */
        3198, /* 38780 ( 708) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    34146806, /* 38781 ( 708) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
       11786, /* 38782 ( 708) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34146804, /* 38783 ( 708) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
        7898, /* 38784 ( 708) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 0,  0,  0]  1 */
       16482, /* 38785 ( 708) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
       16484, /* 38786 ( 709) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    52438710, /* 38787 ( 709) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
        3200, /* 38788 ( 709) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
       11784, /* 38789 ( 709) [ 0,  1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  0]  1 */
        7896, /* 38790 ( 709) [ 0, -1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  0]  1 */
       16482, /* 38791 ( 709) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    52443408, /* 38792 ( 709) [ 0, -1,  0,  1,  0,  0,  0,  0, -1] [ 6,  6,  0] -1 */
    52451994, /* 38793 ( 709) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
    52447298, /* 38794 ( 709) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 6,  6,  0] -1 */
    52451996, /* 38795 ( 709) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
        3198, /* 38796 ( 709) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
       11786, /* 38797 ( 709) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    52438712, /* 38798 ( 709) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
        7898, /* 38799 ( 709) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    52443410, /* 38800 ( 709) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 6,  6,  0] -1 */
    52447296, /* 38801 ( 709) [ 0,  1,  0, -1,  0,  0,  0,  0, -1] [ 6,  6,  0] -1 */
       16484, /* 38802 ( 710) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    52565396, /* 38803 ( 710) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    52556810, /* 38804 ( 710) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
        3200, /* 38805 ( 710) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    52561508, /* 38806 ( 710) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    52561506, /* 38807 ( 710) [ 0, -1,  0,  1,  0,  0,  0,  0, -1] [ 6,  6,  6] -1 */
       11784, /* 38808 ( 710) [ 0,  1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  0]  1 */
        7896, /* 38809 ( 710) [ 0, -1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  0]  1 */
       16482, /* 38810 ( 710) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
        3198, /* 38811 ( 710) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    52570092, /* 38812 ( 710) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    52565394, /* 38813 ( 710) [ 0,  1,  0, -1,  0,  0,  0,  0, -1] [ 6,  6,  6] -1 */
       11786, /* 38814 ( 710) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  0]  1 */
        7898, /* 38815 ( 710) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    52570094, /* 38816 ( 710) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    52556808, /* 38817 ( 710) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
       16484, /* 38818 ( 711) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
        3200, /* 38819 ( 711) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
      129884, /* 38820 ( 711) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  6]  1 */
        3198, /* 38821 ( 711) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
      129882, /* 38822 ( 711) [ 0,  1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  6]  1 */
      125996, /* 38823 ( 711) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 0,  0,  6]  1 */
      125994, /* 38824 ( 711) [ 0, -1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  6]  1 */
       16482, /* 38825 ( 711) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
       16484, /* 38826 ( 712) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34142108, /* 38827 ( 712) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    34015422, /* 38828 ( 712) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
        3200, /* 38829 ( 712) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
      129884, /* 38830 ( 712) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  6]  1 */
    34138220, /* 38831 ( 712) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    34142106, /* 38832 ( 712) [ 0,  1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  6] -1 */
    34028706, /* 38833 ( 712) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    34138218, /* 38834 ( 712) [ 0, -1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  6] -1 */
        3198, /* 38835 ( 712) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
      129882, /* 38836 ( 712) [ 0,  1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  6]  1 */
      125996, /* 38837 ( 712) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 0,  0,  6]  1 */
      125994, /* 38838 ( 712) [ 0, -1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  6]  1 */
    34015424, /* 38839 ( 712) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    34028708, /* 38840 ( 712) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
       16482, /* 38841 ( 712) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
       16484, /* 38842 ( 713) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34142108, /* 38843 ( 713) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  6] -1 */
        3200, /* 38844 ( 713) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34142106, /* 38845 ( 713) [ 0,  1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  6] -1 */
    34138220, /* 38846 ( 713) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    34138218, /* 38847 ( 713) [ 0, -1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  6] -1 */
        3198, /* 38848 ( 713) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
       16482, /* 38849 ( 713) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
       16484, /* 38850 ( 714) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34015422, /* 38851 ( 714) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
        3200, /* 38852 ( 714) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
      129884, /* 38853 ( 714) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  6]  1 */
    34142106, /* 38854 ( 714) [ 0,  1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  6] -1 */
    34028706, /* 38855 ( 714) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    34138218, /* 38856 ( 714) [ 0, -1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  6] -1 */
      125996, /* 38857 ( 714) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 0,  0,  6]  1 */
       16484, /* 38858 ( 715) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34142108, /* 38859 ( 715) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    34015422, /* 38860 ( 715) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
        3200, /* 38861 ( 715) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34138220, /* 38862 ( 715) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    34028706, /* 38863 ( 715) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
      129882, /* 38864 ( 715) [ 0,  1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  6]  1 */
      125994, /* 38865 ( 715) [ 0, -1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  6]  1 */
       16484, /* 38866 ( 716) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34024008, /* 38867 ( 716) [ 0,  1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    34133522, /* 38868 ( 716) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    34020120, /* 38869 ( 716) [ 0, -1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  0] -1 */
        3200, /* 38870 ( 716) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
      129884, /* 38871 ( 716) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  6]  1 */
    34024010, /* 38872 ( 716) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    34133520, /* 38873 ( 716) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
        3198, /* 38874 ( 716) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    34020122, /* 38875 ( 716) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 0,  0,  0] -1 */
      129882, /* 38876 ( 716) [ 0,  1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  6]  1 */
    34146806, /* 38877 ( 716) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
      125996, /* 38878 ( 716) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 0,  0,  6]  1 */
      125994, /* 38879 ( 716) [ 0, -1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  6]  1 */
    34146804, /* 38880 ( 716) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
       16482, /* 38881 ( 716) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
       16484, /* 38882 ( 717) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    52565396, /* 38883 ( 717) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    52438710, /* 38884 ( 717) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
        3200, /* 38885 ( 717) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    52561508, /* 38886 ( 717) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 6,  6,  6] -1 */
      129884, /* 38887 ( 717) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  6]  1 */
    52561506, /* 38888 ( 717) [ 0, -1,  0,  1,  0,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    52451994, /* 38889 ( 717) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
    52451996, /* 38890 ( 717) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
        3198, /* 38891 ( 717) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
      129882, /* 38892 ( 717) [ 0,  1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  6]  1 */
      125996, /* 38893 ( 717) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 0,  0,  6]  1 */
    52565394, /* 38894 ( 717) [ 0,  1,  0, -1,  0,  0,  0,  0, -1] [ 6,  6,  6] -1 */
      125994, /* 38895 ( 717) [ 0, -1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  6]  1 */
    52438712, /* 38896 ( 717) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
       16482, /* 38897 ( 717) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
       16484, /* 38898 ( 718) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    52556810, /* 38899 ( 718) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
        3200, /* 38900 ( 718) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    52447296, /* 38901 ( 718) [ 0,  1,  0, -1,  0,  0,  0,  0, -1] [ 6,  6,  0] -1 */
      129884, /* 38902 ( 718) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  6]  1 */
       16482, /* 38903 ( 718) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    52443408, /* 38904 ( 718) [ 0, -1,  0,  1,  0,  0,  0,  0, -1] [ 6,  6,  0] -1 */
    52447298, /* 38905 ( 718) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 6,  6,  0] -1 */
        3198, /* 38906 ( 718) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
      129882, /* 38907 ( 718) [ 0,  1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  6]  1 */
      125996, /* 38908 ( 718) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 0,  0,  6]  1 */
      125994, /* 38909 ( 718) [ 0, -1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  6]  1 */
    52570092, /* 38910 ( 718) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    52570094, /* 38911 ( 718) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    52443410, /* 38912 ( 718) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 6,  6,  0] -1 */
    52556808, /* 38913 ( 718) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
       16484, /* 38914 ( 719) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
        3200, /* 38915 ( 719) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    18435074, /* 38916 ( 719) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    18431186, /* 38917 ( 719) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 6,  6,  0]  1 */
        7896, /* 38918 ( 719) [ 0, -1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    18426486, /* 38919 ( 719) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
    18439770, /* 38920 ( 719) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
       11784, /* 38921 ( 719) [ 0,  1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  0]  1 */
       16484, /* 38922 ( 720) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
        3200, /* 38923 ( 720) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    52443410, /* 38924 ( 720) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 6,  6,  0] -1 */
    18435074, /* 38925 ( 720) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    52438710, /* 38926 ( 720) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
    18431186, /* 38927 ( 720) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    34024008, /* 38928 ( 720) [ 0,  1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  0] -1 */
        7896, /* 38929 ( 720) [ 0, -1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    52451994, /* 38930 ( 720) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
    18426486, /* 38931 ( 720) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
    18439770, /* 38932 ( 720) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
       11784, /* 38933 ( 720) [ 0,  1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    34015424, /* 38934 ( 720) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    34028708, /* 38935 ( 720) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    52447298, /* 38936 ( 720) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 6,  6,  0] -1 */
    34020120, /* 38937 ( 720) [ 0, -1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  0] -1 */
       16484, /* 38938 ( 721) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
        3200, /* 38939 ( 721) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    52443410, /* 38940 ( 721) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 6,  6,  0] -1 */
    34024008, /* 38941 ( 721) [ 0,  1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    18426486, /* 38942 ( 721) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
    18439770, /* 38943 ( 721) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
    52447298, /* 38944 ( 721) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 6,  6,  0] -1 */
    34020120, /* 38945 ( 721) [ 0, -1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  0] -1 */
       16484, /* 38946 ( 722) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
        3200, /* 38947 ( 722) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    18435074, /* 38948 ( 722) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    52438710, /* 38949 ( 722) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
    18431186, /* 38950 ( 722) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    34024008, /* 38951 ( 722) [ 0,  1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    52451994, /* 38952 ( 722) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
    34020120, /* 38953 ( 722) [ 0, -1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  0] -1 */
       16484, /* 38954 ( 723) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
        3200, /* 38955 ( 723) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    52443410, /* 38956 ( 723) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 6,  6,  0] -1 */
    52438710, /* 38957 ( 723) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
        7896, /* 38958 ( 723) [ 0, -1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    52451994, /* 38959 ( 723) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
       11784, /* 38960 ( 723) [ 0,  1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    52447298, /* 38961 ( 723) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 6,  6,  0] -1 */
       16484, /* 38962 ( 724) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
        3200, /* 38963 ( 724) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    18435074, /* 38964 ( 724) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    34142106, /* 38965 ( 724) [ 0,  1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  6] -1 */
    34133522, /* 38966 ( 724) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    18431186, /* 38967 ( 724) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    52561508, /* 38968 ( 724) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    34138218, /* 38969 ( 724) [ 0, -1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  6] -1 */
        7896, /* 38970 ( 724) [ 0, -1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    52556808, /* 38971 ( 724) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    18426486, /* 38972 ( 724) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
    34146806, /* 38973 ( 724) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    52565396, /* 38974 ( 724) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    18439770, /* 38975 ( 724) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
       11784, /* 38976 ( 724) [ 0,  1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    52570092, /* 38977 ( 724) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
       16484, /* 38978 ( 725) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
        3200, /* 38979 ( 725) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    18435074, /* 38980 ( 725) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    34015422, /* 38981 ( 725) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    34020122, /* 38982 ( 725) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    18431186, /* 38983 ( 725) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    34024010, /* 38984 ( 725) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    52443408, /* 38985 ( 725) [ 0, -1,  0,  1,  0,  0,  0,  0, -1] [ 6,  6,  0] -1 */
        7896, /* 38986 ( 725) [ 0, -1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    34028706, /* 38987 ( 725) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    52447296, /* 38988 ( 725) [ 0,  1,  0, -1,  0,  0,  0,  0, -1] [ 6,  6,  0] -1 */
    52451996, /* 38989 ( 725) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
    18426486, /* 38990 ( 725) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
    18439770, /* 38991 ( 725) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
       11784, /* 38992 ( 725) [ 0,  1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    52438712, /* 38993 ( 725) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
       16484, /* 38994 ( 726) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
        3200, /* 38995 ( 726) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    18435074, /* 38996 ( 726) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    52556810, /* 38997 ( 726) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    18431186, /* 38998 ( 726) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 6,  6,  0]  1 */
        7896, /* 38999 ( 726) [ 0, -1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    18426486, /* 39000 ( 726) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
    52561506, /* 39001 ( 726) [ 0, -1,  0,  1,  0,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    52565394, /* 39002 ( 726) [ 0,  1,  0, -1,  0,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    18439770, /* 39003 ( 726) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
       11784, /* 39004 ( 726) [ 0,  1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    34146804, /* 39005 ( 726) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
    34138220, /* 39006 ( 726) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    52570094, /* 39007 ( 726) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    34142108, /* 39008 ( 726) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    34133520, /* 39009 ( 726) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
       16484, /* 39010 ( 719) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    18426488, /* 39011 ( 719) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
     1428962, /* 39012 ( 719) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 0,  6,  0]  1 */
    17014010, /* 39013 ( 719) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 6,  0,  0]  1 */
     1425072, /* 39014 ( 719) [ 0, -1,  0,  1,  0,  0,  0,  0, -1] [ 0,  6,  0]  1 */
        3198, /* 39015 ( 719) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    18439770, /* 39016 ( 719) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
    17017896, /* 39017 ( 719) [ 0,  1,  0, -1,  0,  0,  0,  0, -1] [ 6,  0,  0]  1 */
       16484, /* 39018 ( 720) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    18426488, /* 39019 ( 720) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    51026234, /* 39020 ( 720) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 6,  0,  0] -1 */
     1428962, /* 39021 ( 720) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 0,  6,  0]  1 */
    34015422, /* 39022 ( 720) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    17014010, /* 39023 ( 720) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 6,  0,  0]  1 */
    51030120, /* 39024 ( 720) [ 0,  1,  0, -1,  0,  0,  0,  0, -1] [ 6,  0,  0] -1 */
     1425072, /* 39025 ( 720) [ 0, -1,  0,  1,  0,  0,  0,  0, -1] [ 0,  6,  0]  1 */
    52451994, /* 39026 ( 720) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
        3198, /* 39027 ( 720) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    18439770, /* 39028 ( 720) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
    17017896, /* 39029 ( 720) [ 0,  1,  0, -1,  0,  0,  0,  0, -1] [ 6,  0,  0]  1 */
    52438712, /* 39030 ( 720) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
    34028708, /* 39031 ( 720) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    35441186, /* 39032 ( 720) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 0,  6,  0] -1 */
    35437296, /* 39033 ( 720) [ 0, -1,  0,  1,  0,  0,  0,  0, -1] [ 0,  6,  0] -1 */
       16484, /* 39034 ( 721) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    18426488, /* 39035 ( 721) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    51026234, /* 39036 ( 721) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 6,  0,  0] -1 */
    51030120, /* 39037 ( 721) [ 0,  1,  0, -1,  0,  0,  0,  0, -1] [ 6,  0,  0] -1 */
        3198, /* 39038 ( 721) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    18439770, /* 39039 ( 721) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
    35441186, /* 39040 ( 721) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 0,  6,  0] -1 */
    35437296, /* 39041 ( 721) [ 0, -1,  0,  1,  0,  0,  0,  0, -1] [ 0,  6,  0] -1 */
       16484, /* 39042 ( 722) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    18426488, /* 39043 ( 722) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
     1428962, /* 39044 ( 722) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 0,  6,  0]  1 */
    34015422, /* 39045 ( 722) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    17014010, /* 39046 ( 722) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 6,  0,  0]  1 */
    51030120, /* 39047 ( 722) [ 0,  1,  0, -1,  0,  0,  0,  0, -1] [ 6,  0,  0] -1 */
    52451994, /* 39048 ( 722) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
    35437296, /* 39049 ( 722) [ 0, -1,  0,  1,  0,  0,  0,  0, -1] [ 0,  6,  0] -1 */
       16484, /* 39050 ( 723) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    18426488, /* 39051 ( 723) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    51026234, /* 39052 ( 723) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 6,  0,  0] -1 */
    34015422, /* 39053 ( 723) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
     1425072, /* 39054 ( 723) [ 0, -1,  0,  1,  0,  0,  0,  0, -1] [ 0,  6,  0]  1 */
    52451994, /* 39055 ( 723) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
    17017896, /* 39056 ( 723) [ 0,  1,  0, -1,  0,  0,  0,  0, -1] [ 6,  0,  0]  1 */
    35441186, /* 39057 ( 723) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 0,  6,  0] -1 */
       16484, /* 39058 ( 724) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    18426488, /* 39059 ( 724) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
     1428962, /* 39060 ( 724) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 0,  6,  0]  1 */
    51148218, /* 39061 ( 724) [ 0,  1,  0, -1,  0,  0,  0,  0, -1] [ 6,  0,  6] -1 */
    52556810, /* 39062 ( 724) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    17014010, /* 39063 ( 724) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 6,  0,  0]  1 */
    51144332, /* 39064 ( 724) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 6,  0,  6] -1 */
    35555394, /* 39065 ( 724) [ 0, -1,  0,  1,  0,  0,  0,  0, -1] [ 0,  6,  6] -1 */
     1425072, /* 39066 ( 724) [ 0, -1,  0,  1,  0,  0,  0,  0, -1] [ 0,  6,  0]  1 */
    34133520, /* 39067 ( 724) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
        3198, /* 39068 ( 724) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    34146806, /* 39069 ( 724) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    35559284, /* 39070 ( 724) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 0,  6,  6] -1 */
    18439770, /* 39071 ( 724) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
    17017896, /* 39072 ( 724) [ 0,  1,  0, -1,  0,  0,  0,  0, -1] [ 6,  0,  0]  1 */
    52570092, /* 39073 ( 724) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
       16484, /* 39074 ( 725) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    18426488, /* 39075 ( 725) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
     1428962, /* 39076 ( 725) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 0,  6,  0]  1 */
    52438710, /* 39077 ( 725) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
    35437298, /* 39078 ( 725) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 0,  6,  0] -1 */
    17014010, /* 39079 ( 725) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 6,  0,  0]  1 */
    51030122, /* 39080 ( 725) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 6,  0,  0] -1 */
    51026232, /* 39081 ( 725) [ 0, -1,  0,  1,  0,  0,  0,  0, -1] [ 6,  0,  0] -1 */
     1425072, /* 39082 ( 725) [ 0, -1,  0,  1,  0,  0,  0,  0, -1] [ 0,  6,  0]  1 */
    34028706, /* 39083 ( 725) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    35441184, /* 39084 ( 725) [ 0,  1,  0, -1,  0,  0,  0,  0, -1] [ 0,  6,  0] -1 */
    52451996, /* 39085 ( 725) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
        3198, /* 39086 ( 725) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    18439770, /* 39087 ( 725) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
    17017896, /* 39088 ( 725) [ 0,  1,  0, -1,  0,  0,  0,  0, -1] [ 6,  0,  0]  1 */
    34015424, /* 39089 ( 725) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
       16484, /* 39090 ( 726) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    18426488, /* 39091 ( 726) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
     1428962, /* 39092 ( 726) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 0,  6,  0]  1 */
    34133522, /* 39093 ( 726) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    17014010, /* 39094 ( 726) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 6,  0,  0]  1 */
     1425072, /* 39095 ( 726) [ 0, -1,  0,  1,  0,  0,  0,  0, -1] [ 0,  6,  0]  1 */
        3198, /* 39096 ( 726) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    51144330, /* 39097 ( 726) [ 0, -1,  0,  1,  0,  0,  0,  0, -1] [ 6,  0,  6] -1 */
    35559282, /* 39098 ( 726) [ 0,  1,  0, -1,  0,  0,  0,  0, -1] [ 0,  6,  6] -1 */
    18439770, /* 39099 ( 726) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
    17017896, /* 39100 ( 726) [ 0,  1,  0, -1,  0,  0,  0,  0, -1] [ 6,  0,  0]  1 */
    34146804, /* 39101 ( 726) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
    35555396, /* 39102 ( 726) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 0,  6,  6] -1 */
    52570094, /* 39103 ( 726) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    51148220, /* 39104 ( 726) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 6,  0,  6] -1 */
    52556808, /* 39105 ( 726) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
       16484, /* 39106 ( 727) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
        3200, /* 39107 ( 727) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
        7896, /* 39108 ( 727) [ 0, -1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    18553172, /* 39109 ( 727) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    18549284, /* 39110 ( 727) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 6,  6,  6]  1 */
       11784, /* 39111 ( 727) [ 0,  1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    18544584, /* 39112 ( 727) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
    18557868, /* 39113 ( 727) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
       16484, /* 39114 ( 728) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
        3200, /* 39115 ( 728) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
        7896, /* 39116 ( 728) [ 0, -1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    52556808, /* 39117 ( 728) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    18553172, /* 39118 ( 728) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    18549284, /* 39119 ( 728) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 6,  6,  6]  1 */
       11784, /* 39120 ( 728) [ 0,  1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    52570092, /* 39121 ( 728) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    18544584, /* 39122 ( 728) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
    34020120, /* 39123 ( 728) [ 0, -1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    52561508, /* 39124 ( 728) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    18557868, /* 39125 ( 728) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
    34024008, /* 39126 ( 728) [ 0,  1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    34015424, /* 39127 ( 728) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    34028708, /* 39128 ( 728) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    52565396, /* 39129 ( 728) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 6,  6,  6] -1 */
       16484, /* 39130 ( 729) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
        3200, /* 39131 ( 729) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    18544584, /* 39132 ( 729) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
    34020120, /* 39133 ( 729) [ 0, -1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    34024008, /* 39134 ( 729) [ 0,  1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    18557868, /* 39135 ( 729) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
    52561508, /* 39136 ( 729) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    52565396, /* 39137 ( 729) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 6,  6,  6] -1 */
       16484, /* 39138 ( 730) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
        3200, /* 39139 ( 730) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    52556808, /* 39140 ( 730) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    18553172, /* 39141 ( 730) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    18549284, /* 39142 ( 730) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    52570092, /* 39143 ( 730) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    34020120, /* 39144 ( 730) [ 0, -1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    34024008, /* 39145 ( 730) [ 0,  1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  0] -1 */
       16484, /* 39146 ( 731) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
        3200, /* 39147 ( 731) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
        7896, /* 39148 ( 731) [ 0, -1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    52556808, /* 39149 ( 731) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
       11784, /* 39150 ( 731) [ 0,  1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    52570092, /* 39151 ( 731) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    52561508, /* 39152 ( 731) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    52565396, /* 39153 ( 731) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 6,  6,  6] -1 */
       16484, /* 39154 ( 732) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
        3200, /* 39155 ( 732) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
        7896, /* 39156 ( 732) [ 0, -1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    34133522, /* 39157 ( 732) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    18553172, /* 39158 ( 732) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    52443410, /* 39159 ( 732) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 6,  6,  0] -1 */
    18549284, /* 39160 ( 732) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 6,  6,  6]  1 */
       11784, /* 39161 ( 732) [ 0,  1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    52447298, /* 39162 ( 732) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 6,  6,  0] -1 */
    34138218, /* 39163 ( 732) [ 0, -1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  6] -1 */
    52438710, /* 39164 ( 732) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
    34142106, /* 39165 ( 732) [ 0,  1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  6] -1 */
    18544584, /* 39166 ( 732) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
    34146806, /* 39167 ( 732) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    18557868, /* 39168 ( 732) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
    52451994, /* 39169 ( 732) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
       16484, /* 39170 ( 733) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
        3200, /* 39171 ( 733) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
        7896, /* 39172 ( 733) [ 0, -1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    52447296, /* 39173 ( 733) [ 0,  1,  0, -1,  0,  0,  0,  0, -1] [ 6,  6,  0] -1 */
    34133520, /* 39174 ( 733) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
    18553172, /* 39175 ( 733) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    18549284, /* 39176 ( 733) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 6,  6,  6]  1 */
       11784, /* 39177 ( 733) [ 0,  1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    34138220, /* 39178 ( 733) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    52443408, /* 39179 ( 733) [ 0, -1,  0,  1,  0,  0,  0,  0, -1] [ 6,  6,  0] -1 */
    34146804, /* 39180 ( 733) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
    52451996, /* 39181 ( 733) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
    18544584, /* 39182 ( 733) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
    34142108, /* 39183 ( 733) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    18557868, /* 39184 ( 733) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
    52438712, /* 39185 ( 733) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
       16484, /* 39186 ( 734) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
        3200, /* 39187 ( 734) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34020122, /* 39188 ( 734) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    52556810, /* 39189 ( 734) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
        7896, /* 39190 ( 734) [ 0, -1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    18553172, /* 39191 ( 734) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    52561506, /* 39192 ( 734) [ 0, -1,  0,  1,  0,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    18549284, /* 39193 ( 734) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 6,  6,  6]  1 */
       11784, /* 39194 ( 734) [ 0,  1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    52565394, /* 39195 ( 734) [ 0,  1,  0, -1,  0,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    18544584, /* 39196 ( 734) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
    18557868, /* 39197 ( 734) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
    34028706, /* 39198 ( 734) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    34024010, /* 39199 ( 734) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    52570094, /* 39200 ( 734) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    34015422, /* 39201 ( 734) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
       16484, /* 39202 ( 727) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    18426488, /* 39203 ( 727) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    17132106, /* 39204 ( 727) [ 0, -1,  0,  1,  0,  0,  0,  0, -1] [ 6,  0,  6]  1 */
    17135996, /* 39205 ( 727) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 6,  0,  6]  1 */
     1543172, /* 39206 ( 727) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 0,  6,  6]  1 */
     1547058, /* 39207 ( 727) [ 0,  1,  0, -1,  0,  0,  0,  0, -1] [ 0,  6,  6]  1 */
        3198, /* 39208 ( 727) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    18439770, /* 39209 ( 727) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
       16484, /* 39210 ( 728) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    18426488, /* 39211 ( 728) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    17132106, /* 39212 ( 728) [ 0, -1,  0,  1,  0,  0,  0,  0, -1] [ 6,  0,  6]  1 */
    34015422, /* 39213 ( 728) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    17135996, /* 39214 ( 728) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 6,  0,  6]  1 */
     1543172, /* 39215 ( 728) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 0,  6,  6]  1 */
     1547058, /* 39216 ( 728) [ 0,  1,  0, -1,  0,  0,  0,  0, -1] [ 0,  6,  6]  1 */
    52451994, /* 39217 ( 728) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
        3198, /* 39218 ( 728) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    51144330, /* 39219 ( 728) [ 0, -1,  0,  1,  0,  0,  0,  0, -1] [ 6,  0,  6] -1 */
    35555396, /* 39220 ( 728) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 0,  6,  6] -1 */
    18439770, /* 39221 ( 728) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
    35559282, /* 39222 ( 728) [ 0,  1,  0, -1,  0,  0,  0,  0, -1] [ 0,  6,  6] -1 */
    52438712, /* 39223 ( 728) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
    34028708, /* 39224 ( 728) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    51148220, /* 39225 ( 728) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 6,  0,  6] -1 */
       16484, /* 39226 ( 729) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    18426488, /* 39227 ( 729) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
        3198, /* 39228 ( 729) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    51144330, /* 39229 ( 729) [ 0, -1,  0,  1,  0,  0,  0,  0, -1] [ 6,  0,  6] -1 */
    35559282, /* 39230 ( 729) [ 0,  1,  0, -1,  0,  0,  0,  0, -1] [ 0,  6,  6] -1 */
    18439770, /* 39231 ( 729) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
    35555396, /* 39232 ( 729) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 0,  6,  6] -1 */
    51148220, /* 39233 ( 729) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 6,  0,  6] -1 */
       16484, /* 39234 ( 730) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    18426488, /* 39235 ( 730) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    34015422, /* 39236 ( 730) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    17135996, /* 39237 ( 730) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 6,  0,  6]  1 */
     1543172, /* 39238 ( 730) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 0,  6,  6]  1 */
    52451994, /* 39239 ( 730) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
    51144330, /* 39240 ( 730) [ 0, -1,  0,  1,  0,  0,  0,  0, -1] [ 6,  0,  6] -1 */
    35559282, /* 39241 ( 730) [ 0,  1,  0, -1,  0,  0,  0,  0, -1] [ 0,  6,  6] -1 */
       16484, /* 39242 ( 731) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    18426488, /* 39243 ( 731) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    17132106, /* 39244 ( 731) [ 0, -1,  0,  1,  0,  0,  0,  0, -1] [ 6,  0,  6]  1 */
    34015422, /* 39245 ( 731) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
     1547058, /* 39246 ( 731) [ 0,  1,  0, -1,  0,  0,  0,  0, -1] [ 0,  6,  6]  1 */
    52451994, /* 39247 ( 731) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
    35555396, /* 39248 ( 731) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 0,  6,  6] -1 */
    51148220, /* 39249 ( 731) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 6,  0,  6] -1 */
       16484, /* 39250 ( 732) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    18426488, /* 39251 ( 732) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    17132106, /* 39252 ( 732) [ 0, -1,  0,  1,  0,  0,  0,  0, -1] [ 6,  0,  6]  1 */
    52556810, /* 39253 ( 732) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    17135996, /* 39254 ( 732) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 6,  0,  6]  1 */
    35437298, /* 39255 ( 732) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 0,  6,  0] -1 */
     1543172, /* 39256 ( 732) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 0,  6,  6]  1 */
     1547058, /* 39257 ( 732) [ 0,  1,  0, -1,  0,  0,  0,  0, -1] [ 0,  6,  6]  1 */
    51030122, /* 39258 ( 732) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 6,  0,  0] -1 */
    51026232, /* 39259 ( 732) [ 0, -1,  0,  1,  0,  0,  0,  0, -1] [ 6,  0,  0] -1 */
    34133520, /* 39260 ( 732) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
    35441184, /* 39261 ( 732) [ 0,  1,  0, -1,  0,  0,  0,  0, -1] [ 0,  6,  0] -1 */
        3198, /* 39262 ( 732) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    34146806, /* 39263 ( 732) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    18439770, /* 39264 ( 732) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
    52570092, /* 39265 ( 732) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
       16484, /* 39266 ( 733) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    18426488, /* 39267 ( 733) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    17132106, /* 39268 ( 733) [ 0, -1,  0,  1,  0,  0,  0,  0, -1] [ 6,  0,  6]  1 */
    51148218, /* 39269 ( 733) [ 0,  1,  0, -1,  0,  0,  0,  0, -1] [ 6,  0,  6] -1 */
    52438710, /* 39270 ( 733) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
    17135996, /* 39271 ( 733) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 6,  0,  6]  1 */
     1543172, /* 39272 ( 733) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 0,  6,  6]  1 */
     1547058, /* 39273 ( 733) [ 0,  1,  0, -1,  0,  0,  0,  0, -1] [ 0,  6,  6]  1 */
    51144332, /* 39274 ( 733) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 6,  0,  6] -1 */
    35555394, /* 39275 ( 733) [ 0, -1,  0,  1,  0,  0,  0,  0, -1] [ 0,  6,  6] -1 */
    34028706, /* 39276 ( 733) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    52451996, /* 39277 ( 733) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
        3198, /* 39278 ( 733) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    35559284, /* 39279 ( 733) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 0,  6,  6] -1 */
    18439770, /* 39280 ( 733) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
    34015424, /* 39281 ( 733) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
       16484, /* 39282 ( 734) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    18426488, /* 39283 ( 734) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    51026234, /* 39284 ( 734) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 6,  0,  0] -1 */
    34133522, /* 39285 ( 734) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    17132106, /* 39286 ( 734) [ 0, -1,  0,  1,  0,  0,  0,  0, -1] [ 6,  0,  6]  1 */
    17135996, /* 39287 ( 734) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 6,  0,  6]  1 */
    35437296, /* 39288 ( 734) [ 0, -1,  0,  1,  0,  0,  0,  0, -1] [ 0,  6,  0] -1 */
     1543172, /* 39289 ( 734) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 0,  6,  6]  1 */
     1547058, /* 39290 ( 734) [ 0,  1,  0, -1,  0,  0,  0,  0, -1] [ 0,  6,  6]  1 */
    51030120, /* 39291 ( 734) [ 0,  1,  0, -1,  0,  0,  0,  0, -1] [ 6,  0,  0] -1 */
        3198, /* 39292 ( 734) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    18439770, /* 39293 ( 734) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
    34146804, /* 39294 ( 734) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
    35441186, /* 39295 ( 734) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 0,  6,  0] -1 */
    52570094, /* 39296 ( 734) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    52556808, /* 39297 ( 734) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
       16484, /* 39298 ( 735) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    18557868, /* 39299 ( 735) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
    18557870, /* 39300 ( 735) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    18544584, /* 39301 ( 735) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
        3200, /* 39302 ( 735) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
       11784, /* 39303 ( 735) [ 0,  1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    18553172, /* 39304 ( 735) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 6,  6,  6]  1 */
        7896, /* 39305 ( 735) [ 0, -1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    18549282, /* 39306 ( 735) [ 0, -1,  0,  1,  0,  0,  0,  0, -1] [ 6,  6,  6]  1 */
        3198, /* 39307 ( 735) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    18544586, /* 39308 ( 735) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    18549284, /* 39309 ( 735) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 6,  6,  6]  1 */
       11786, /* 39310 ( 735) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  0]  1 */
        7898, /* 39311 ( 735) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 0,  0,  0]  1 */
       16482, /* 39312 ( 735) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    18553170, /* 39313 ( 735) [ 0,  1,  0, -1,  0,  0,  0,  0, -1] [ 6,  6,  6]  1 */
       16484, /* 39314 ( 736) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    18557868, /* 39315 ( 736) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
    18544584, /* 39316 ( 736) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
    52561506, /* 39317 ( 736) [ 0, -1,  0,  1,  0,  0,  0,  0, -1] [ 6,  6,  6] -1 */
        3198, /* 39318 ( 736) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    52565394, /* 39319 ( 736) [ 0,  1,  0, -1,  0,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    52570094, /* 39320 ( 736) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    34024008, /* 39321 ( 736) [ 0,  1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    52565396, /* 39322 ( 736) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    34020120, /* 39323 ( 736) [ 0, -1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    52561508, /* 39324 ( 736) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    34024010, /* 39325 ( 736) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    18549282, /* 39326 ( 736) [ 0, -1,  0,  1,  0,  0,  0,  0, -1] [ 6,  6,  6]  1 */
    34020122, /* 39327 ( 736) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    34015424, /* 39328 ( 736) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    34028708, /* 39329 ( 736) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    18553170, /* 39330 ( 736) [ 0,  1,  0, -1,  0,  0,  0,  0, -1] [ 6,  6,  6]  1 */
    18557870, /* 39331 ( 736) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    52556810, /* 39332 ( 736) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
       11784, /* 39333 ( 736) [ 0,  1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    18553172, /* 39334 ( 736) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 6,  6,  6]  1 */
        7896, /* 39335 ( 736) [ 0, -1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    34028706, /* 39336 ( 736) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    18549284, /* 39337 ( 736) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 6,  6,  6]  1 */
       11786, /* 39338 ( 736) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  0]  1 */
        7898, /* 39339 ( 736) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    52570092, /* 39340 ( 736) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    52556808, /* 39341 ( 736) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    34015422, /* 39342 ( 736) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
        3200, /* 39343 ( 736) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    18544586, /* 39344 ( 736) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
       16482, /* 39345 ( 736) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
       16484, /* 39346 ( 737) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34024008, /* 39347 ( 737) [ 0,  1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    18557870, /* 39348 ( 737) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    18557868, /* 39349 ( 737) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
    52565396, /* 39350 ( 737) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    18544584, /* 39351 ( 737) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
    52561508, /* 39352 ( 737) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 6,  6,  6] -1 */
        3200, /* 39353 ( 737) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34024010, /* 39354 ( 737) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    34020120, /* 39355 ( 737) [ 0, -1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    52561506, /* 39356 ( 737) [ 0, -1,  0,  1,  0,  0,  0,  0, -1] [ 6,  6,  6] -1 */
        3198, /* 39357 ( 737) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    34020122, /* 39358 ( 737) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    18544586, /* 39359 ( 737) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    52565394, /* 39360 ( 737) [ 0,  1,  0, -1,  0,  0,  0,  0, -1] [ 6,  6,  6] -1 */
       16482, /* 39361 ( 737) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
       16484, /* 39362 ( 738) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34024008, /* 39363 ( 738) [ 0,  1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    18557870, /* 39364 ( 738) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    34015422, /* 39365 ( 738) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    34020120, /* 39366 ( 738) [ 0, -1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  0] -1 */
        3200, /* 39367 ( 738) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    52561506, /* 39368 ( 738) [ 0, -1,  0,  1,  0,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    18553172, /* 39369 ( 738) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    34028706, /* 39370 ( 738) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    18544586, /* 39371 ( 738) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    18549284, /* 39372 ( 738) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    52565394, /* 39373 ( 738) [ 0,  1,  0, -1,  0,  0,  0,  0, -1] [ 6,  6,  6] -1 */
       11786, /* 39374 ( 738) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    52570092, /* 39375 ( 738) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
        7898, /* 39376 ( 738) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    52556808, /* 39377 ( 738) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
       16484, /* 39378 ( 739) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    52565396, /* 39379 ( 739) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    18557870, /* 39380 ( 739) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    34015422, /* 39381 ( 739) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
        3200, /* 39382 ( 739) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    52561508, /* 39383 ( 739) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    34024010, /* 39384 ( 739) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  0] -1 */
       11784, /* 39385 ( 739) [ 0,  1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  0]  1 */
        7896, /* 39386 ( 739) [ 0, -1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    18549282, /* 39387 ( 739) [ 0, -1,  0,  1,  0,  0,  0,  0, -1] [ 6,  6,  6]  1 */
    34028706, /* 39388 ( 739) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    18544586, /* 39389 ( 739) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    34020122, /* 39390 ( 739) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    52570092, /* 39391 ( 739) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    18553170, /* 39392 ( 739) [ 0,  1,  0, -1,  0,  0,  0,  0, -1] [ 6,  6,  6]  1 */
    52556808, /* 39393 ( 739) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
       16484, /* 39394 ( 740) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    18557868, /* 39395 ( 740) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
    18544584, /* 39396 ( 740) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
    52443408, /* 39397 ( 740) [ 0, -1,  0,  1,  0,  0,  0,  0, -1] [ 6,  6,  0] -1 */
    52447298, /* 39398 ( 740) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 6,  6,  0] -1 */
    52451996, /* 39399 ( 740) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
        3198, /* 39400 ( 740) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    52443410, /* 39401 ( 740) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 6,  6,  0] -1 */
    52447296, /* 39402 ( 740) [ 0,  1,  0, -1,  0,  0,  0,  0, -1] [ 6,  6,  0] -1 */
    34142108, /* 39403 ( 740) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    34138220, /* 39404 ( 740) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    34142106, /* 39405 ( 740) [ 0,  1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  6] -1 */
    18549282, /* 39406 ( 740) [ 0, -1,  0,  1,  0,  0,  0,  0, -1] [ 6,  6,  6]  1 */
    34138218, /* 39407 ( 740) [ 0, -1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  6] -1 */
    34146806, /* 39408 ( 740) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    52438712, /* 39409 ( 740) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
    18553170, /* 39410 ( 740) [ 0,  1,  0, -1,  0,  0,  0,  0, -1] [ 6,  6,  6]  1 */
    18557870, /* 39411 ( 740) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    34133522, /* 39412 ( 740) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
       11784, /* 39413 ( 740) [ 0,  1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    18553172, /* 39414 ( 740) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 6,  6,  6]  1 */
        7896, /* 39415 ( 740) [ 0, -1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    52451994, /* 39416 ( 740) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
    18549284, /* 39417 ( 740) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 6,  6,  6]  1 */
       11786, /* 39418 ( 740) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34146804, /* 39419 ( 740) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
        7898, /* 39420 ( 740) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    52438710, /* 39421 ( 740) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
        3200, /* 39422 ( 740) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34133520, /* 39423 ( 740) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
    18544586, /* 39424 ( 740) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
       16482, /* 39425 ( 740) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
       16484, /* 39426 ( 741) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
       11784, /* 39427 ( 741) [ 0,  1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    18557870, /* 39428 ( 741) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    17199741, /* 39429 ( 741) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  9]  1 */
     1488011, /* 39430 ( 741) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 0,  6,  3]  1 */
    17186457, /* 39431 ( 741) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  9]  1 */
    18553170, /* 39432 ( 741) [ 0,  1,  0, -1,  0,  0,  0,  0, -1] [ 6,  6,  6]  1 */
     1492707, /* 39433 ( 741) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  3]  1 */
     1479423, /* 39434 ( 741) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  3]  1 */
        3200, /* 39435 ( 741) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    18544586, /* 39436 ( 741) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
        7896, /* 39437 ( 741) [ 0, -1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  0]  1 */
     1484123, /* 39438 ( 741) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 0,  6,  3]  1 */
    17191157, /* 39439 ( 741) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 6,  0,  9]  1 */
    17195045, /* 39440 ( 741) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 6,  0,  9]  1 */
    18549282, /* 39441 ( 741) [ 0, -1,  0,  1,  0,  0,  0,  0, -1] [ 6,  6,  6]  1 */
       16484, /* 39442 ( 742) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    35504931, /* 39443 ( 742) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  3] -1 */
    17186457, /* 39444 ( 742) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  9]  1 */
    52561506, /* 39445 ( 742) [ 0, -1,  0,  1,  0,  0,  0,  0, -1] [ 6,  6,  6] -1 */
     1479423, /* 39446 ( 742) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  3]  1 */
        3200, /* 39447 ( 742) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    18544586, /* 39448 ( 742) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    51211965, /* 39449 ( 742) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  9] -1 */
        7896, /* 39450 ( 742) [ 0, -1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    52565394, /* 39451 ( 742) [ 0,  1,  0, -1,  0,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    34024008, /* 39452 ( 742) [ 0,  1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    52570094, /* 39453 ( 742) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    17195045, /* 39454 ( 742) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 6,  0,  9]  1 */
    35500235, /* 39455 ( 742) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 0,  6,  3] -1 */
     1492707, /* 39456 ( 742) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  3]  1 */
    35496347, /* 39457 ( 742) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 0,  6,  3] -1 */
    51203381, /* 39458 ( 742) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 6,  0,  9] -1 */
    34028708, /* 39459 ( 742) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    18549282, /* 39460 ( 742) [ 0, -1,  0,  1,  0,  0,  0,  0, -1] [ 6,  6,  6]  1 */
       11784, /* 39461 ( 742) [ 0,  1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    18557870, /* 39462 ( 742) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    17199741, /* 39463 ( 742) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  9]  1 */
     1488011, /* 39464 ( 742) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 0,  6,  3]  1 */
    18553170, /* 39465 ( 742) [ 0,  1,  0, -1,  0,  0,  0,  0, -1] [ 6,  6,  6]  1 */
     1484123, /* 39466 ( 742) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 0,  6,  3]  1 */
    17191157, /* 39467 ( 742) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 6,  0,  9]  1 */
    51198681, /* 39468 ( 742) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  9] -1 */
    35491647, /* 39469 ( 742) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  3] -1 */
    34020120, /* 39470 ( 742) [ 0, -1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    34015424, /* 39471 ( 742) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    52556810, /* 39472 ( 742) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    51207269, /* 39473 ( 742) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 6,  0,  9] -1 */
       16484, /* 39474 ( 743) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    18557870, /* 39475 ( 743) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    17199741, /* 39476 ( 743) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  9]  1 */
    17186457, /* 39477 ( 743) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  9]  1 */
     1492707, /* 39478 ( 743) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  3]  1 */
    35496347, /* 39479 ( 743) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 0,  6,  3] -1 */
    34020120, /* 39480 ( 743) [ 0, -1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    51203381, /* 39481 ( 743) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 6,  0,  9] -1 */
    52561506, /* 39482 ( 743) [ 0, -1,  0,  1,  0,  0,  0,  0, -1] [ 6,  6,  6] -1 */
     1479423, /* 39483 ( 743) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  3]  1 */
        3200, /* 39484 ( 743) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    18544586, /* 39485 ( 743) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    51207269, /* 39486 ( 743) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 6,  0,  9] -1 */
    52565394, /* 39487 ( 743) [ 0,  1,  0, -1,  0,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    34024008, /* 39488 ( 743) [ 0,  1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    35500235, /* 39489 ( 743) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 0,  6,  3] -1 */
       16484, /* 39490 ( 744) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    35504931, /* 39491 ( 744) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  3] -1 */
    18557870, /* 39492 ( 744) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    35491647, /* 39493 ( 744) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  3] -1 */
     1488011, /* 39494 ( 744) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 0,  6,  3]  1 */
    34020120, /* 39495 ( 744) [ 0, -1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    52561506, /* 39496 ( 744) [ 0, -1,  0,  1,  0,  0,  0,  0, -1] [ 6,  6,  6] -1 */
        3200, /* 39497 ( 744) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    18544586, /* 39498 ( 744) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    51211965, /* 39499 ( 744) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  9] -1 */
     1484123, /* 39500 ( 744) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 0,  6,  3]  1 */
    52565394, /* 39501 ( 744) [ 0,  1,  0, -1,  0,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    17191157, /* 39502 ( 744) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 6,  0,  9]  1 */
    34024008, /* 39503 ( 744) [ 0,  1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    17195045, /* 39504 ( 744) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 6,  0,  9]  1 */
    51198681, /* 39505 ( 744) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  9] -1 */
       16484, /* 39506 ( 745) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
       11784, /* 39507 ( 745) [ 0,  1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    18557870, /* 39508 ( 745) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    35491647, /* 39509 ( 745) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  3] -1 */
    35504931, /* 39510 ( 745) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  3] -1 */
    18553170, /* 39511 ( 745) [ 0,  1,  0, -1,  0,  0,  0,  0, -1] [ 6,  6,  6]  1 */
    35496347, /* 39512 ( 745) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 0,  6,  3] -1 */
    51203381, /* 39513 ( 745) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 6,  0,  9] -1 */
        3200, /* 39514 ( 745) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    18544586, /* 39515 ( 745) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    51207269, /* 39516 ( 745) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 6,  0,  9] -1 */
    51211965, /* 39517 ( 745) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  9] -1 */
        7896, /* 39518 ( 745) [ 0, -1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    35500235, /* 39519 ( 745) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 0,  6,  3] -1 */
    18549282, /* 39520 ( 745) [ 0, -1,  0,  1,  0,  0,  0,  0, -1] [ 6,  6,  6]  1 */
    51198681, /* 39521 ( 745) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  9] -1 */
       16484, /* 39522 ( 746) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    17186457, /* 39523 ( 746) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  9]  1 */
    35623029, /* 39524 ( 746) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  9] -1 */
    34142106, /* 39525 ( 746) [ 0,  1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  6] -1 */
    52451996, /* 39526 ( 746) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
     1479423, /* 39527 ( 746) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  3]  1 */
        3200, /* 39528 ( 746) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    18544586, /* 39529 ( 746) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
        7896, /* 39530 ( 746) [ 0, -1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    17195045, /* 39531 ( 746) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 6,  0,  9]  1 */
    51085283, /* 39532 ( 746) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 6,  0,  3] -1 */
    35614445, /* 39533 ( 746) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 0,  6,  9] -1 */
    52447296, /* 39534 ( 746) [ 0,  1,  0, -1,  0,  0,  0,  0, -1] [ 6,  6,  0] -1 */
     1492707, /* 39535 ( 746) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  3]  1 */
    34146806, /* 39536 ( 746) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    52438712, /* 39537 ( 746) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
    18549282, /* 39538 ( 746) [ 0, -1,  0,  1,  0,  0,  0,  0, -1] [ 6,  6,  6]  1 */
       11784, /* 39539 ( 746) [ 0,  1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    18557870, /* 39540 ( 746) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    17199741, /* 39541 ( 746) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  9]  1 */
     1488011, /* 39542 ( 746) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 0,  6,  3]  1 */
    18553170, /* 39543 ( 746) [ 0,  1,  0, -1,  0,  0,  0,  0, -1] [ 6,  6,  6]  1 */
    51093867, /* 39544 ( 746) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  3] -1 */
     1484123, /* 39545 ( 746) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 0,  6,  3]  1 */
    52443408, /* 39546 ( 746) [ 0, -1,  0,  1,  0,  0,  0,  0, -1] [ 6,  6,  0] -1 */
    17191157, /* 39547 ( 746) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 6,  0,  9]  1 */
    34138218, /* 39548 ( 746) [ 0, -1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  6] -1 */
    51089171, /* 39549 ( 746) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 6,  0,  3] -1 */
    51080583, /* 39550 ( 746) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  3] -1 */
    35609745, /* 39551 ( 746) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  9] -1 */
    35618333, /* 39552 ( 746) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 0,  6,  9] -1 */
    34133522, /* 39553 ( 746) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
       16484, /* 39554 ( 741) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    10817751, /* 39555 ( 741) [ 0,  1,  0, -1,  0,  0,  0,  0, -1] [ 3,  9,  9]  1 */
    18557870, /* 39556 ( 741) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    17140692, /* 39557 ( 741) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6]  1 */
     9282479, /* 39558 ( 741) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 3,  3,  3]  1 */
    18544584, /* 39559 ( 741) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
    26288589, /* 39560 ( 741) [ 0,  1,  0, -1,  0,  0,  0,  0, -1] [ 9,  3,  3]  1 */
     1433658, /* 39561 ( 741) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  0]  1 */
        3198, /* 39562 ( 741) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
     1420376, /* 39563 ( 741) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  0]  1 */
    17127410, /* 39564 ( 741) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
    27819975, /* 39565 ( 741) [ 0, -1,  0,  1,  0,  0,  0,  0, -1] [ 9,  9,  9]  1 */
    26284703, /* 39566 ( 741) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 9,  3,  3]  1 */
    10813865, /* 39567 ( 741) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 3,  9,  9]  1 */
    27823865, /* 39568 ( 741) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 9,  9,  9]  1 */
     9278589, /* 39569 ( 741) [ 0, -1,  0,  1,  0,  0,  0,  0, -1] [ 3,  3,  3]  1 */
       16484, /* 39570 ( 742) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    35445882, /* 39571 ( 742) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  0] -1 */
    18544584, /* 39572 ( 742) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
    43290813, /* 39573 ( 742) [ 0, -1,  0,  1,  0,  0,  0,  0, -1] [ 3,  3,  3] -1 */
        3198, /* 39574 ( 742) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
     1420376, /* 39575 ( 742) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  0]  1 */
    17127410, /* 39576 ( 742) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
    51152916, /* 39577 ( 742) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6] -1 */
    27819975, /* 39578 ( 742) [ 0, -1,  0,  1,  0,  0,  0,  0, -1] [ 9,  9,  9]  1 */
    60300813, /* 39579 ( 742) [ 0,  1,  0, -1,  0,  0,  0,  0, -1] [ 9,  3,  3] -1 */
    44829975, /* 39580 ( 742) [ 0,  1,  0, -1,  0,  0,  0,  0, -1] [ 3,  9,  9] -1 */
    52570094, /* 39581 ( 742) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    27823865, /* 39582 ( 742) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 9,  9,  9]  1 */
    43294703, /* 39583 ( 742) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 3,  3,  3] -1 */
     1433658, /* 39584 ( 742) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  0]  1 */
    60296927, /* 39585 ( 742) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 9,  3,  3] -1 */
    44826089, /* 39586 ( 742) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 3,  9,  9] -1 */
    34028708, /* 39587 ( 742) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
     9278589, /* 39588 ( 742) [ 0, -1,  0,  1,  0,  0,  0,  0, -1] [ 3,  3,  3]  1 */
    10817751, /* 39589 ( 742) [ 0,  1,  0, -1,  0,  0,  0,  0, -1] [ 3,  9,  9]  1 */
    18557870, /* 39590 ( 742) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    17140692, /* 39591 ( 742) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6]  1 */
     9282479, /* 39592 ( 742) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 3,  3,  3]  1 */
    26288589, /* 39593 ( 742) [ 0,  1,  0, -1,  0,  0,  0,  0, -1] [ 9,  3,  3]  1 */
    26284703, /* 39594 ( 742) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 9,  3,  3]  1 */
    10813865, /* 39595 ( 742) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 3,  9,  9]  1 */
    52556808, /* 39596 ( 742) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    34015422, /* 39597 ( 742) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    61832199, /* 39598 ( 742) [ 0, -1,  0,  1,  0,  0,  0,  0, -1] [ 9,  9,  9] -1 */
    35432600, /* 39599 ( 742) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  0] -1 */
    51139634, /* 39600 ( 742) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
    61836089, /* 39601 ( 742) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 9,  9,  9] -1 */
       16484, /* 39602 ( 743) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    18557870, /* 39603 ( 743) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    17140692, /* 39604 ( 743) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6]  1 */
    18544584, /* 39605 ( 743) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
     1433658, /* 39606 ( 743) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  0]  1 */
    60296927, /* 39607 ( 743) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 9,  3,  3] -1 */
    61832199, /* 39608 ( 743) [ 0, -1,  0,  1,  0,  0,  0,  0, -1] [ 9,  9,  9] -1 */
    44826089, /* 39609 ( 743) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 3,  9,  9] -1 */
    43290813, /* 39610 ( 743) [ 0, -1,  0,  1,  0,  0,  0,  0, -1] [ 3,  3,  3] -1 */
        3198, /* 39611 ( 743) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
     1420376, /* 39612 ( 743) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  0]  1 */
    17127410, /* 39613 ( 743) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
    61836089, /* 39614 ( 743) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 9,  9,  9] -1 */
    60300813, /* 39615 ( 743) [ 0,  1,  0, -1,  0,  0,  0,  0, -1] [ 9,  3,  3] -1 */
    44829975, /* 39616 ( 743) [ 0,  1,  0, -1,  0,  0,  0,  0, -1] [ 3,  9,  9] -1 */
    43294703, /* 39617 ( 743) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 3,  3,  3] -1 */
       16484, /* 39618 ( 744) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    35445882, /* 39619 ( 744) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  0] -1 */
    18557870, /* 39620 ( 744) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    34015422, /* 39621 ( 744) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
     9282479, /* 39622 ( 744) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 3,  3,  3]  1 */
    61832199, /* 39623 ( 744) [ 0, -1,  0,  1,  0,  0,  0,  0, -1] [ 9,  9,  9] -1 */
    43290813, /* 39624 ( 744) [ 0, -1,  0,  1,  0,  0,  0,  0, -1] [ 3,  3,  3] -1 */
     1420376, /* 39625 ( 744) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  0]  1 */
    17127410, /* 39626 ( 744) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
    51152916, /* 39627 ( 744) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6] -1 */
    26284703, /* 39628 ( 744) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 9,  3,  3]  1 */
    60300813, /* 39629 ( 744) [ 0,  1,  0, -1,  0,  0,  0,  0, -1] [ 9,  3,  3] -1 */
    10813865, /* 39630 ( 744) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 3,  9,  9]  1 */
    44829975, /* 39631 ( 744) [ 0,  1,  0, -1,  0,  0,  0,  0, -1] [ 3,  9,  9] -1 */
    27823865, /* 39632 ( 744) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 9,  9,  9]  1 */
    52556808, /* 39633 ( 744) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
       16484, /* 39634 ( 745) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    10817751, /* 39635 ( 745) [ 0,  1,  0, -1,  0,  0,  0,  0, -1] [ 3,  9,  9]  1 */
    18557870, /* 39636 ( 745) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    34015422, /* 39637 ( 745) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    35445882, /* 39638 ( 745) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  0] -1 */
    26288589, /* 39639 ( 745) [ 0,  1,  0, -1,  0,  0,  0,  0, -1] [ 9,  3,  3]  1 */
    60296927, /* 39640 ( 745) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 9,  3,  3] -1 */
    44826089, /* 39641 ( 745) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 3,  9,  9] -1 */
     1420376, /* 39642 ( 745) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  0]  1 */
    17127410, /* 39643 ( 745) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
    61836089, /* 39644 ( 745) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 9,  9,  9] -1 */
    51152916, /* 39645 ( 745) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6] -1 */
    27819975, /* 39646 ( 745) [ 0, -1,  0,  1,  0,  0,  0,  0, -1] [ 9,  9,  9]  1 */
    43294703, /* 39647 ( 745) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 3,  3,  3] -1 */
     9278589, /* 39648 ( 745) [ 0, -1,  0,  1,  0,  0,  0,  0, -1] [ 3,  3,  3]  1 */
    52556808, /* 39649 ( 745) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
       16484, /* 39650 ( 746) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    18544584, /* 39651 ( 746) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
    35563980, /* 39652 ( 746) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6] -1 */
    44711877, /* 39653 ( 746) [ 0,  1,  0, -1,  0,  0,  0,  0, -1] [ 3,  9,  3] -1 */
    52451996, /* 39654 ( 746) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
        3198, /* 39655 ( 746) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
     1420376, /* 39656 ( 746) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  0]  1 */
    17127410, /* 39657 ( 746) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
    27819975, /* 39658 ( 746) [ 0, -1,  0,  1,  0,  0,  0,  0, -1] [ 9,  9,  9]  1 */
    27823865, /* 39659 ( 746) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 9,  9,  9]  1 */
    44707991, /* 39660 ( 746) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 3,  9,  3] -1 */
    60415025, /* 39661 ( 746) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 9,  3,  9] -1 */
    60418911, /* 39662 ( 746) [ 0,  1,  0, -1,  0,  0,  0,  0, -1] [ 9,  3,  9] -1 */
     1433658, /* 39663 ( 746) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  0]  1 */
    34146806, /* 39664 ( 746) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    51021536, /* 39665 ( 746) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  0] -1 */
     9278589, /* 39666 ( 746) [ 0, -1,  0,  1,  0,  0,  0,  0, -1] [ 3,  3,  3]  1 */
    10817751, /* 39667 ( 746) [ 0,  1,  0, -1,  0,  0,  0,  0, -1] [ 3,  9,  9]  1 */
    18557870, /* 39668 ( 746) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    17140692, /* 39669 ( 746) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6]  1 */
     9282479, /* 39670 ( 746) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 3,  3,  3]  1 */
    26288589, /* 39671 ( 746) [ 0,  1,  0, -1,  0,  0,  0,  0, -1] [ 9,  3,  3]  1 */
    51034818, /* 39672 ( 746) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  0] -1 */
    26284703, /* 39673 ( 746) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 9,  3,  3]  1 */
    43408911, /* 39674 ( 746) [ 0, -1,  0,  1,  0,  0,  0,  0, -1] [ 3,  3,  9] -1 */
    10813865, /* 39675 ( 746) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 3,  9,  9]  1 */
    61714101, /* 39676 ( 746) [ 0, -1,  0,  1,  0,  0,  0,  0, -1] [ 9,  9,  3] -1 */
    61717991, /* 39677 ( 746) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 9,  9,  3] -1 */
    52438710, /* 39678 ( 746) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
    34133520, /* 39679 ( 746) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
    43412801, /* 39680 ( 746) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 3,  3,  9] -1 */
    35550698, /* 39681 ( 746) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
       16484, /* 39682 ( 747) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
        3200, /* 39683 ( 747) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
       16320, /* 39684 ( 747) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
        7410, /* 39685 ( 747) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  0]  1 */
       12270, /* 39686 ( 747) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  0]  1 */
       11786, /* 39687 ( 747) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  0]  1 */
        3360, /* 39688 ( 747) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
        7898, /* 39689 ( 747) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 0,  0,  0]  1 */
       16484, /* 39690 ( 748) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
        3200, /* 39691 ( 748) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34019634, /* 39692 ( 748) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    34024494, /* 39693 ( 748) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  0] -1 */
        7898, /* 39694 ( 748) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34024010, /* 39695 ( 748) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  0] -1 */
       16320, /* 39696 ( 748) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    34015584, /* 39697 ( 748) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
        7410, /* 39698 ( 748) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  0]  1 */
       12270, /* 39699 ( 748) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    34020122, /* 39700 ( 748) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 0,  0,  0] -1 */
       11786, /* 39701 ( 748) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34015424, /* 39702 ( 748) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
        3360, /* 39703 ( 748) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    34028708, /* 39704 ( 748) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    34028544, /* 39705 ( 748) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
       16484, /* 39706 ( 749) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
        3200, /* 39707 ( 749) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34019634, /* 39708 ( 749) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    34024494, /* 39709 ( 749) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    34024010, /* 39710 ( 749) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  0] -1 */
       16320, /* 39711 ( 749) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    34020122, /* 39712 ( 749) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 0,  0,  0] -1 */
        3360, /* 39713 ( 749) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
       16484, /* 39714 ( 750) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
        3200, /* 39715 ( 750) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34019634, /* 39716 ( 750) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    34024494, /* 39717 ( 750) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    34015584, /* 39718 ( 750) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
       11786, /* 39719 ( 750) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  0]  1 */
        7898, /* 39720 ( 750) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34028544, /* 39721 ( 750) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
       16484, /* 39722 ( 751) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
        3200, /* 39723 ( 751) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34024010, /* 39724 ( 751) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    34015584, /* 39725 ( 751) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
        7410, /* 39726 ( 751) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  0]  1 */
       12270, /* 39727 ( 751) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    34020122, /* 39728 ( 751) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    34028544, /* 39729 ( 751) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
       16484, /* 39730 ( 752) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34142592, /* 39731 ( 752) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  6] -1 */
    34133522, /* 39732 ( 752) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    34137732, /* 39733 ( 752) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  6] -1 */
    34142108, /* 39734 ( 752) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  6] -1 */
        3200, /* 39735 ( 752) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
       16320, /* 39736 ( 752) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    34138220, /* 39737 ( 752) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 0,  0,  6] -1 */
        7410, /* 39738 ( 752) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  0]  1 */
       12270, /* 39739 ( 752) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    34146806, /* 39740 ( 752) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
       11786, /* 39741 ( 752) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34146642, /* 39742 ( 752) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
    34133682, /* 39743 ( 752) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
        3360, /* 39744 ( 752) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
        7898, /* 39745 ( 752) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 0,  0,  0]  1 */
       16484, /* 39746 ( 753) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    52442922, /* 39747 ( 753) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 6,  6,  0] -1 */
    52438712, /* 39748 ( 753) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
        3200, /* 39749 ( 753) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
       16320, /* 39750 ( 753) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
        7410, /* 39751 ( 753) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  0]  1 */
       12270, /* 39752 ( 753) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    52447298, /* 39753 ( 753) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 6,  6,  0] -1 */
    52451996, /* 39754 ( 753) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
    52447782, /* 39755 ( 753) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 6,  6,  0] -1 */
    52438872, /* 39756 ( 753) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
       11786, /* 39757 ( 753) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  0]  1 */
        3360, /* 39758 ( 753) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
        7898, /* 39759 ( 753) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    52443410, /* 39760 ( 753) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 6,  6,  0] -1 */
    52451832, /* 39761 ( 753) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
       16484, /* 39762 ( 754) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    52565396, /* 39763 ( 754) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    52556810, /* 39764 ( 754) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
        3200, /* 39765 ( 754) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    52561508, /* 39766 ( 754) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 6,  6,  6] -1 */
       16320, /* 39767 ( 754) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    52565880, /* 39768 ( 754) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 6,  6,  6] -1 */
        7410, /* 39769 ( 754) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  0]  1 */
       12270, /* 39770 ( 754) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    52556970, /* 39771 ( 754) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
       11786, /* 39772 ( 754) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    52569930, /* 39773 ( 754) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
        3360, /* 39774 ( 754) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
        7898, /* 39775 ( 754) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    52561020, /* 39776 ( 754) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    52570094, /* 39777 ( 754) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
       16484, /* 39778 ( 755) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    18426648, /* 39779 ( 755) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
    18439608, /* 39780 ( 755) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
        3200, /* 39781 ( 755) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    18431186, /* 39782 ( 755) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 6,  6,  0]  1 */
        7410, /* 39783 ( 755) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  0]  1 */
       12270, /* 39784 ( 755) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    18435074, /* 39785 ( 755) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 6,  6,  0]  1 */
       16484, /* 39786 ( 756) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    18426648, /* 39787 ( 756) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
    18439608, /* 39788 ( 756) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
        3200, /* 39789 ( 756) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34019634, /* 39790 ( 756) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    34024494, /* 39791 ( 756) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    18431186, /* 39792 ( 756) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 6,  6,  0]  1 */
        7410, /* 39793 ( 756) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  0]  1 */
       12270, /* 39794 ( 756) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    52447298, /* 39795 ( 756) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 6,  6,  0] -1 */
    52438872, /* 39796 ( 756) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
    18435074, /* 39797 ( 756) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    34015424, /* 39798 ( 756) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    34028708, /* 39799 ( 756) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    52443410, /* 39800 ( 756) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 6,  6,  0] -1 */
    52451832, /* 39801 ( 756) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
       16484, /* 39802 ( 757) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    18426648, /* 39803 ( 757) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
    18439608, /* 39804 ( 757) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
        3200, /* 39805 ( 757) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34019634, /* 39806 ( 757) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    34024494, /* 39807 ( 757) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    52447298, /* 39808 ( 757) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 6,  6,  0] -1 */
    52443410, /* 39809 ( 757) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 6,  6,  0] -1 */
       16484, /* 39810 ( 758) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
        3200, /* 39811 ( 758) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34019634, /* 39812 ( 758) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    34024494, /* 39813 ( 758) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    18431186, /* 39814 ( 758) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    18435074, /* 39815 ( 758) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    52438872, /* 39816 ( 758) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
    52451832, /* 39817 ( 758) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
       16484, /* 39818 ( 759) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
        3200, /* 39819 ( 759) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
        7410, /* 39820 ( 759) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  0]  1 */
       12270, /* 39821 ( 759) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    52447298, /* 39822 ( 759) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 6,  6,  0] -1 */
    52438872, /* 39823 ( 759) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
    52443410, /* 39824 ( 759) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 6,  6,  0] -1 */
    52451832, /* 39825 ( 759) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
       16484, /* 39826 ( 760) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    18426648, /* 39827 ( 760) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
    34133522, /* 39828 ( 760) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    34142592, /* 39829 ( 760) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  6] -1 */
    18439608, /* 39830 ( 760) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
        3200, /* 39831 ( 760) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    52561508, /* 39832 ( 760) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    34137732, /* 39833 ( 760) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  6] -1 */
    52565396, /* 39834 ( 760) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    18431186, /* 39835 ( 760) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 6,  6,  0]  1 */
        7410, /* 39836 ( 760) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  0]  1 */
       12270, /* 39837 ( 760) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    34146806, /* 39838 ( 760) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    52556970, /* 39839 ( 760) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    52569930, /* 39840 ( 760) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    18435074, /* 39841 ( 760) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 6,  6,  0]  1 */
       16484, /* 39842 ( 761) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    18426648, /* 39843 ( 761) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
    52442922, /* 39844 ( 761) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 6,  6,  0] -1 */
    18439608, /* 39845 ( 761) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
        3200, /* 39846 ( 761) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34024010, /* 39847 ( 761) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    18431186, /* 39848 ( 761) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    34015584, /* 39849 ( 761) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
        7410, /* 39850 ( 761) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  0]  1 */
       12270, /* 39851 ( 761) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    52451996, /* 39852 ( 761) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
    52447782, /* 39853 ( 761) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 6,  6,  0] -1 */
    34020122, /* 39854 ( 761) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    52438712, /* 39855 ( 761) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
    34028544, /* 39856 ( 761) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    18435074, /* 39857 ( 761) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 6,  6,  0]  1 */
       16484, /* 39858 ( 762) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    18426648, /* 39859 ( 762) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
    34142108, /* 39860 ( 762) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    52556810, /* 39861 ( 762) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    18439608, /* 39862 ( 762) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
        3200, /* 39863 ( 762) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    18431186, /* 39864 ( 762) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    52565880, /* 39865 ( 762) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    34138220, /* 39866 ( 762) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 0,  0,  6] -1 */
        7410, /* 39867 ( 762) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  0]  1 */
       12270, /* 39868 ( 762) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    34133682, /* 39869 ( 762) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
    34146642, /* 39870 ( 762) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
    52561020, /* 39871 ( 762) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    52570094, /* 39872 ( 762) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    18435074, /* 39873 ( 762) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 6,  6,  0]  1 */
       16484, /* 39874 ( 763) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
      134418, /* 39875 ( 763) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  6]  1 */
      189417, /* 39876 ( 763) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  9]  1 */
        3360, /* 39877 ( 763) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
      188933, /* 39878 ( 763) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  9]  1 */
       66459, /* 39879 ( 763) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  3]  1 */
      121298, /* 39880 ( 763) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6]  1 */
       66947, /* 39881 ( 763) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 0,  0,  3]  1 */
       16484, /* 39882 ( 764) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34201641, /* 39883 ( 764) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  9] -1 */
    34133522, /* 39884 ( 764) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
      134418, /* 39885 ( 764) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  6]  1 */
      189417, /* 39886 ( 764) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  9]  1 */
        3360, /* 39887 ( 764) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    34079171, /* 39888 ( 764) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 0,  0,  3] -1 */
      188933, /* 39889 ( 764) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  9]  1 */
       66459, /* 39890 ( 764) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  3]  1 */
    34201157, /* 39891 ( 764) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  9] -1 */
    34015584, /* 39892 ( 764) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
      121298, /* 39893 ( 764) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6]  1 */
    34146642, /* 39894 ( 764) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
       66947, /* 39895 ( 764) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 0,  0,  3]  1 */
    34028708, /* 39896 ( 764) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    34078683, /* 39897 ( 764) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  3] -1 */
       16484, /* 39898 ( 765) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
      134418, /* 39899 ( 765) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  6]  1 */
    34079171, /* 39900 ( 765) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 0,  0,  3] -1 */
    34201157, /* 39901 ( 765) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  9] -1 */
      121298, /* 39902 ( 765) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6]  1 */
        3360, /* 39903 ( 765) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    34201641, /* 39904 ( 765) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  9] -1 */
    34078683, /* 39905 ( 765) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  3] -1 */
       16484, /* 39906 ( 766) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
      188933, /* 39907 ( 766) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  9]  1 */
    34015584, /* 39908 ( 766) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
      121298, /* 39909 ( 766) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6]  1 */
    34146642, /* 39910 ( 766) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
       66947, /* 39911 ( 766) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 0,  0,  3]  1 */
    34201641, /* 39912 ( 766) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  9] -1 */
    34078683, /* 39913 ( 766) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  3] -1 */
       16484, /* 39914 ( 767) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
      189417, /* 39915 ( 767) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  9]  1 */
    34079171, /* 39916 ( 767) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 0,  0,  3] -1 */
    34201157, /* 39917 ( 767) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  9] -1 */
       66459, /* 39918 ( 767) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  3]  1 */
    34015584, /* 39919 ( 767) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
      121298, /* 39920 ( 767) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6]  1 */
    34146642, /* 39921 ( 767) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
       16484, /* 39922 ( 768) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34083543, /* 39923 ( 768) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  3] -1 */
      134418, /* 39924 ( 768) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  6]  1 */
    34197269, /* 39925 ( 768) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 0,  0,  9] -1 */
      189417, /* 39926 ( 768) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  9]  1 */
        3360, /* 39927 ( 768) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    34196781, /* 39928 ( 768) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  9] -1 */
      188933, /* 39929 ( 768) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  9]  1 */
       66459, /* 39930 ( 768) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  3]  1 */
      121298, /* 39931 ( 768) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6]  1 */
    34083059, /* 39932 ( 768) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  3] -1 */
    34146806, /* 39933 ( 768) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    34133682, /* 39934 ( 768) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
    34015424, /* 39935 ( 768) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
       66947, /* 39936 ( 768) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 0,  0,  3]  1 */
    34028544, /* 39937 ( 768) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
       16484, /* 39938 ( 769) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    52501971, /* 39939 ( 769) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 6,  6,  3] -1 */
    52556810, /* 39940 ( 769) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
      134418, /* 39941 ( 769) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  6]  1 */
      189417, /* 39942 ( 769) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  9]  1 */
        3360, /* 39943 ( 769) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
      188933, /* 39944 ( 769) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  9]  1 */
    52502459, /* 39945 ( 769) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 6,  6,  3] -1 */
       66459, /* 39946 ( 769) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  3]  1 */
    52624445, /* 39947 ( 769) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 6,  6,  9] -1 */
      121298, /* 39948 ( 769) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6]  1 */
    52451996, /* 39949 ( 769) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
    52569930, /* 39950 ( 769) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
       66947, /* 39951 ( 769) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 0,  0,  3]  1 */
    52438872, /* 39952 ( 769) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
    52624929, /* 39953 ( 769) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 6,  6,  9] -1 */
       16484, /* 39954 ( 770) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    52506347, /* 39955 ( 770) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 6,  6,  3] -1 */
    52438712, /* 39956 ( 770) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
      134418, /* 39957 ( 770) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  6]  1 */
    52620557, /* 39958 ( 770) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 6,  6,  9] -1 */
      189417, /* 39959 ( 770) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  9]  1 */
        3360, /* 39960 ( 770) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
      188933, /* 39961 ( 770) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  9]  1 */
       66459, /* 39962 ( 770) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  3]  1 */
    52506831, /* 39963 ( 770) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 6,  6,  3] -1 */
      121298, /* 39964 ( 770) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6]  1 */
    52556970, /* 39965 ( 770) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
       66947, /* 39966 ( 770) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 0,  0,  3]  1 */
    52620069, /* 39967 ( 770) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 6,  6,  9] -1 */
    52570094, /* 39968 ( 770) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    52451832, /* 39969 ( 770) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
       16484, /* 39970 ( 771) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
      125508, /* 39971 ( 771) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  6]  1 */
       12270, /* 39972 ( 771) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  0]  1 */
      121298, /* 39973 ( 771) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6]  1 */
    18485697, /* 39974 ( 771) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  3]  1 */
    18490235, /* 39975 ( 771) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 6,  6,  3]  1 */
    18612221, /* 39976 ( 771) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 6,  6,  9]  1 */
    18616755, /* 39977 ( 771) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  9]  1 */
       16484, /* 39978 ( 772) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34137732, /* 39979 ( 772) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  6] -1 */
    34133522, /* 39980 ( 772) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    52497921, /* 39981 ( 772) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  3] -1 */
      125508, /* 39982 ( 772) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  6]  1 */
    34024494, /* 39983 ( 772) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    52502459, /* 39984 ( 772) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 6,  6,  3] -1 */
    52624445, /* 39985 ( 772) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 6,  6,  9] -1 */
       12270, /* 39986 ( 772) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    52628979, /* 39987 ( 772) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  9] -1 */
      121298, /* 39988 ( 772) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6]  1 */
    18612221, /* 39989 ( 772) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 6,  6,  9]  1 */
    18490235, /* 39990 ( 772) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 6,  6,  3]  1 */
    18485697, /* 39991 ( 772) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  3]  1 */
    34028708, /* 39992 ( 772) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    18616755, /* 39993 ( 772) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  9]  1 */
       16484, /* 39994 ( 773) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34137732, /* 39995 ( 773) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  6] -1 */
    34024494, /* 39996 ( 773) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    52502459, /* 39997 ( 773) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 6,  6,  3] -1 */
    52624445, /* 39998 ( 773) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 6,  6,  9] -1 */
      121298, /* 39999 ( 773) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6]  1 */
    18485697, /* 40000 ( 773) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  3]  1 */
    18616755, /* 40001 ( 773) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  9]  1 */
       16484, /* 40002 ( 774) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34137732, /* 40003 ( 774) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  6] -1 */
    52497921, /* 40004 ( 774) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  3] -1 */
    34024494, /* 40005 ( 774) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    52628979, /* 40006 ( 774) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  9] -1 */
      121298, /* 40007 ( 774) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6]  1 */
    18490235, /* 40008 ( 774) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 6,  6,  3]  1 */
    18612221, /* 40009 ( 774) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 6,  6,  9]  1 */
       16484, /* 40010 ( 775) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    52497921, /* 40011 ( 775) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  3] -1 */
      125508, /* 40012 ( 775) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  6]  1 */
    52502459, /* 40013 ( 775) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 6,  6,  3] -1 */
    52624445, /* 40014 ( 775) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 6,  6,  9] -1 */
       12270, /* 40015 ( 775) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    52628979, /* 40016 ( 775) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  9] -1 */
      121298, /* 40017 ( 775) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6]  1 */
       16484, /* 40018 ( 776) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34142592, /* 40019 ( 776) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  6] -1 */
    52506347, /* 40020 ( 776) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 6,  6,  3] -1 */
    52620557, /* 40021 ( 776) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 6,  6,  9] -1 */
    34019634, /* 40022 ( 776) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  0] -1 */
      125508, /* 40023 ( 776) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  6]  1 */
       12270, /* 40024 ( 776) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    52616019, /* 40025 ( 776) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  9] -1 */
      121298, /* 40026 ( 776) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6]  1 */
    18485697, /* 40027 ( 776) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  3]  1 */
    18490235, /* 40028 ( 776) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 6,  6,  3]  1 */
    34146806, /* 40029 ( 776) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    52510881, /* 40030 ( 776) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  3] -1 */
    34015424, /* 40031 ( 776) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    18612221, /* 40032 ( 776) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 6,  6,  9]  1 */
    18616755, /* 40033 ( 776) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  9]  1 */
       16484, /* 40034 ( 777) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    52556810, /* 40035 ( 777) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    34205691, /* 40036 ( 777) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  9] -1 */
      125508, /* 40037 ( 777) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  6]  1 */
    34074633, /* 40038 ( 777) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  3] -1 */
    34079171, /* 40039 ( 777) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 0,  0,  3] -1 */
    34201157, /* 40040 ( 777) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  9] -1 */
       12270, /* 40041 ( 777) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  0]  1 */
      121298, /* 40042 ( 777) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6]  1 */
    52451996, /* 40043 ( 777) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
    18490235, /* 40044 ( 777) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 6,  6,  3]  1 */
    18485697, /* 40045 ( 777) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  3]  1 */
    52447782, /* 40046 ( 777) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 6,  6,  0] -1 */
    18612221, /* 40047 ( 777) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 6,  6,  9]  1 */
    52561020, /* 40048 ( 777) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    18616755, /* 40049 ( 777) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  9]  1 */
       16484, /* 40050 ( 778) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34087593, /* 40051 ( 778) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  3] -1 */
    52442922, /* 40052 ( 778) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 6,  6,  0] -1 */
    34197269, /* 40053 ( 778) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 0,  0,  9] -1 */
      125508, /* 40054 ( 778) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  6]  1 */
    52565880, /* 40055 ( 778) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 6,  6,  6] -1 */
       12270, /* 40056 ( 778) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  0]  1 */
      121298, /* 40057 ( 778) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6]  1 */
    18485697, /* 40058 ( 778) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  3]  1 */
    18490235, /* 40059 ( 778) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 6,  6,  3]  1 */
    34192731, /* 40060 ( 778) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  9] -1 */
    34083059, /* 40061 ( 778) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  3] -1 */
    52438712, /* 40062 ( 778) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
    18612221, /* 40063 ( 778) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 6,  6,  9]  1 */
    52570094, /* 40064 ( 778) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    18616755, /* 40065 ( 778) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  9]  1 */
       16484, /* 40066 ( 779) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
        3200, /* 40067 ( 779) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
      125508, /* 40068 ( 779) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  6]  1 */
      130368, /* 40069 ( 779) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  6]  1 */
      129884, /* 40070 ( 779) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  6]  1 */
       16320, /* 40071 ( 779) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
      125996, /* 40072 ( 779) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 0,  0,  6]  1 */
        3360, /* 40073 ( 779) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
       16484, /* 40074 ( 780) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34142592, /* 40075 ( 780) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  6] -1 */
    34137732, /* 40076 ( 780) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  6] -1 */
    34142108, /* 40077 ( 780) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  6] -1 */
        3200, /* 40078 ( 780) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
      125508, /* 40079 ( 780) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  6]  1 */
      130368, /* 40080 ( 780) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  6]  1 */
      129884, /* 40081 ( 780) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  6]  1 */
       16320, /* 40082 ( 780) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    34015584, /* 40083 ( 780) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    34138220, /* 40084 ( 780) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 0,  0,  6] -1 */
      125996, /* 40085 ( 780) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 0,  0,  6]  1 */
    34015424, /* 40086 ( 780) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
        3360, /* 40087 ( 780) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    34028708, /* 40088 ( 780) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    34028544, /* 40089 ( 780) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
       16484, /* 40090 ( 781) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34142592, /* 40091 ( 781) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  6] -1 */
    34137732, /* 40092 ( 781) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  6] -1 */
    34142108, /* 40093 ( 781) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  6] -1 */
        3200, /* 40094 ( 781) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
       16320, /* 40095 ( 781) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    34138220, /* 40096 ( 781) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 0,  0,  6] -1 */
        3360, /* 40097 ( 781) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
       16484, /* 40098 ( 782) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34142592, /* 40099 ( 782) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  6] -1 */
    34137732, /* 40100 ( 782) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  6] -1 */
        3200, /* 40101 ( 782) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
      129884, /* 40102 ( 782) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  6]  1 */
    34015584, /* 40103 ( 782) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
      125996, /* 40104 ( 782) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 0,  0,  6]  1 */
    34028544, /* 40105 ( 782) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
       16484, /* 40106 ( 783) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34142108, /* 40107 ( 783) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  6] -1 */
        3200, /* 40108 ( 783) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
      125508, /* 40109 ( 783) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  6]  1 */
      130368, /* 40110 ( 783) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  6]  1 */
    34015584, /* 40111 ( 783) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    34138220, /* 40112 ( 783) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    34028544, /* 40113 ( 783) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
       16484, /* 40114 ( 784) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34133522, /* 40115 ( 784) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
        3200, /* 40116 ( 784) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34019634, /* 40117 ( 784) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  0] -1 */
      125508, /* 40118 ( 784) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  6]  1 */
      130368, /* 40119 ( 784) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  6]  1 */
      129884, /* 40120 ( 784) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  6]  1 */
       16320, /* 40121 ( 784) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    34024494, /* 40122 ( 784) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    34024010, /* 40123 ( 784) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    34020122, /* 40124 ( 784) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    34146806, /* 40125 ( 784) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
      125996, /* 40126 ( 784) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 0,  0,  6]  1 */
    34133682, /* 40127 ( 784) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
    34146642, /* 40128 ( 784) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
        3360, /* 40129 ( 784) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
       16484, /* 40130 ( 785) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    52565396, /* 40131 ( 785) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    52438712, /* 40132 ( 785) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
        3200, /* 40133 ( 785) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    52561508, /* 40134 ( 785) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 6,  6,  6] -1 */
      125508, /* 40135 ( 785) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  6]  1 */
      130368, /* 40136 ( 785) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  6]  1 */
      129884, /* 40137 ( 785) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  6]  1 */
       16320, /* 40138 ( 785) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    52451996, /* 40139 ( 785) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
      125996, /* 40140 ( 785) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 0,  0,  6]  1 */
        3360, /* 40141 ( 785) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    52438872, /* 40142 ( 785) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
    52561020, /* 40143 ( 785) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    52565880, /* 40144 ( 785) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    52451832, /* 40145 ( 785) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
       16484, /* 40146 ( 786) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    52442922, /* 40147 ( 786) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 6,  6,  0] -1 */
    52556810, /* 40148 ( 786) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
        3200, /* 40149 ( 786) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
      125508, /* 40150 ( 786) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  6]  1 */
      130368, /* 40151 ( 786) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  6]  1 */
      129884, /* 40152 ( 786) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  6]  1 */
       16320, /* 40153 ( 786) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    52447298, /* 40154 ( 786) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 6,  6,  0] -1 */
    52447782, /* 40155 ( 786) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 6,  6,  0] -1 */
      125996, /* 40156 ( 786) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 0,  0,  6]  1 */
    52556970, /* 40157 ( 786) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    52569930, /* 40158 ( 786) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
        3360, /* 40159 ( 786) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    52570094, /* 40160 ( 786) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    52443410, /* 40161 ( 786) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 6,  6,  0] -1 */
       16484, /* 40162 ( 787) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
        3200, /* 40163 ( 787) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    18553172, /* 40164 ( 787) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 6,  6,  6]  1 */
        7410, /* 40165 ( 787) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  0]  1 */
       12270, /* 40166 ( 787) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    18549284, /* 40167 ( 787) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    18544746, /* 40168 ( 787) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
    18557706, /* 40169 ( 787) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
       16484, /* 40170 ( 788) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    52565396, /* 40171 ( 788) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 6,  6,  6] -1 */
        3200, /* 40172 ( 788) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    52561508, /* 40173 ( 788) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    34024494, /* 40174 ( 788) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    18553172, /* 40175 ( 788) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    34019634, /* 40176 ( 788) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  0] -1 */
        7410, /* 40177 ( 788) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  0]  1 */
       12270, /* 40178 ( 788) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    52556970, /* 40179 ( 788) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    18549284, /* 40180 ( 788) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    52569930, /* 40181 ( 788) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    34028708, /* 40182 ( 788) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    18544746, /* 40183 ( 788) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
    34015424, /* 40184 ( 788) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    18557706, /* 40185 ( 788) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
       16484, /* 40186 ( 789) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    52565396, /* 40187 ( 789) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 6,  6,  6] -1 */
        3200, /* 40188 ( 789) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    52561508, /* 40189 ( 789) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    34024494, /* 40190 ( 789) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    34019634, /* 40191 ( 789) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    18544746, /* 40192 ( 789) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
    18557706, /* 40193 ( 789) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
       16484, /* 40194 ( 790) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
        3200, /* 40195 ( 790) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34019634, /* 40196 ( 790) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    34024494, /* 40197 ( 790) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    18553172, /* 40198 ( 790) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    52556970, /* 40199 ( 790) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    18549284, /* 40200 ( 790) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    52569930, /* 40201 ( 790) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
       16484, /* 40202 ( 791) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    52565396, /* 40203 ( 791) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 6,  6,  6] -1 */
        3200, /* 40204 ( 791) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    52561508, /* 40205 ( 791) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 6,  6,  6] -1 */
        7410, /* 40206 ( 791) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  0]  1 */
       12270, /* 40207 ( 791) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    52556970, /* 40208 ( 791) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    52569930, /* 40209 ( 791) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
       16484, /* 40210 ( 792) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34142592, /* 40211 ( 792) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  6] -1 */
    34133522, /* 40212 ( 792) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    34137732, /* 40213 ( 792) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  6] -1 */
        3200, /* 40214 ( 792) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    18553172, /* 40215 ( 792) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 6,  6,  6]  1 */
        7410, /* 40216 ( 792) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  0]  1 */
       12270, /* 40217 ( 792) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    52447298, /* 40218 ( 792) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 6,  6,  0] -1 */
    34146806, /* 40219 ( 792) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    18549284, /* 40220 ( 792) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    52438872, /* 40221 ( 792) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
    18544746, /* 40222 ( 792) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
    52443410, /* 40223 ( 792) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 6,  6,  0] -1 */
    52451832, /* 40224 ( 792) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
    18557706, /* 40225 ( 792) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
       16484, /* 40226 ( 793) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    52442922, /* 40227 ( 793) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 6,  6,  0] -1 */
    34142108, /* 40228 ( 793) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  6] -1 */
        3200, /* 40229 ( 793) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    18553172, /* 40230 ( 793) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    34138220, /* 40231 ( 793) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 0,  0,  6] -1 */
        7410, /* 40232 ( 793) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  0]  1 */
       12270, /* 40233 ( 793) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    52451996, /* 40234 ( 793) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
    52447782, /* 40235 ( 793) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 6,  6,  0] -1 */
    18549284, /* 40236 ( 793) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    34133682, /* 40237 ( 793) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
    34146642, /* 40238 ( 793) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
    52438712, /* 40239 ( 793) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
    18544746, /* 40240 ( 793) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
    18557706, /* 40241 ( 793) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
       16484, /* 40242 ( 794) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    52556810, /* 40243 ( 794) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
        3200, /* 40244 ( 794) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34024010, /* 40245 ( 794) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    18553172, /* 40246 ( 794) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    52565880, /* 40247 ( 794) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    34015584, /* 40248 ( 794) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
        7410, /* 40249 ( 794) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  0]  1 */
       12270, /* 40250 ( 794) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    52561020, /* 40251 ( 794) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    34020122, /* 40252 ( 794) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    18549284, /* 40253 ( 794) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    18544746, /* 40254 ( 794) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
    52570094, /* 40255 ( 794) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    34028544, /* 40256 ( 794) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    18557706, /* 40257 ( 794) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
       16484, /* 40258 ( 795) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
      134418, /* 40259 ( 795) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  6]  1 */
      185045, /* 40260 ( 795) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 0,  0,  9]  1 */
       71319, /* 40261 ( 795) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  3]  1 */
      121298, /* 40262 ( 795) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6]  1 */
      184557, /* 40263 ( 795) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  9]  1 */
        3360, /* 40264 ( 795) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
       70835, /* 40265 ( 795) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  3]  1 */
       16484, /* 40266 ( 796) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34083543, /* 40267 ( 796) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  3] -1 */
    34133522, /* 40268 ( 796) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
      134418, /* 40269 ( 796) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  6]  1 */
    34197269, /* 40270 ( 796) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 0,  0,  9] -1 */
    34196781, /* 40271 ( 796) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  9] -1 */
    34015584, /* 40272 ( 796) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
      185045, /* 40273 ( 796) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 0,  0,  9]  1 */
       71319, /* 40274 ( 796) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  3]  1 */
      121298, /* 40275 ( 796) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6]  1 */
    34083059, /* 40276 ( 796) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  3] -1 */
    34146642, /* 40277 ( 796) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
      184557, /* 40278 ( 796) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  9]  1 */
        3360, /* 40279 ( 796) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    34028708, /* 40280 ( 796) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
       70835, /* 40281 ( 796) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  3]  1 */
       16484, /* 40282 ( 797) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34083543, /* 40283 ( 797) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  3] -1 */
      134418, /* 40284 ( 797) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  6]  1 */
    34197269, /* 40285 ( 797) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 0,  0,  9] -1 */
    34196781, /* 40286 ( 797) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  9] -1 */
      121298, /* 40287 ( 797) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6]  1 */
    34083059, /* 40288 ( 797) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  3] -1 */
        3360, /* 40289 ( 797) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
       16484, /* 40290 ( 798) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34083543, /* 40291 ( 798) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  3] -1 */
    34196781, /* 40292 ( 798) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  9] -1 */
    34015584, /* 40293 ( 798) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
      185045, /* 40294 ( 798) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 0,  0,  9]  1 */
      121298, /* 40295 ( 798) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6]  1 */
    34146642, /* 40296 ( 798) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
       70835, /* 40297 ( 798) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  3]  1 */
       16484, /* 40298 ( 799) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34197269, /* 40299 ( 799) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 0,  0,  9] -1 */
    34015584, /* 40300 ( 799) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
       71319, /* 40301 ( 799) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  3]  1 */
      121298, /* 40302 ( 799) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6]  1 */
    34083059, /* 40303 ( 799) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  3] -1 */
    34146642, /* 40304 ( 799) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
      184557, /* 40305 ( 799) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  9]  1 */
       16484, /* 40306 ( 800) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34078683, /* 40307 ( 800) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  3] -1 */
      134418, /* 40308 ( 800) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  6]  1 */
    34079171, /* 40309 ( 800) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 0,  0,  3] -1 */
      185045, /* 40310 ( 800) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 0,  0,  9]  1 */
    34201157, /* 40311 ( 800) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  9] -1 */
       71319, /* 40312 ( 800) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  3]  1 */
      121298, /* 40313 ( 800) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6]  1 */
    34146806, /* 40314 ( 800) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    34133682, /* 40315 ( 800) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
      184557, /* 40316 ( 800) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  9]  1 */
        3360, /* 40317 ( 800) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    34201641, /* 40318 ( 800) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  9] -1 */
    34028544, /* 40319 ( 800) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    34015424, /* 40320 ( 800) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
       70835, /* 40321 ( 800) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  3]  1 */
       16484, /* 40322 ( 801) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    52506347, /* 40323 ( 801) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 6,  6,  3] -1 */
    52556810, /* 40324 ( 801) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
      134418, /* 40325 ( 801) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  6]  1 */
    52620557, /* 40326 ( 801) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 6,  6,  9] -1 */
        3360, /* 40327 ( 801) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
      185045, /* 40328 ( 801) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 0,  0,  9]  1 */
       71319, /* 40329 ( 801) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  3]  1 */
    52438872, /* 40330 ( 801) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
    52506831, /* 40331 ( 801) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 6,  6,  3] -1 */
      121298, /* 40332 ( 801) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6]  1 */
    52451996, /* 40333 ( 801) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
      184557, /* 40334 ( 801) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  9]  1 */
       70835, /* 40335 ( 801) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  3]  1 */
    52620069, /* 40336 ( 801) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 6,  6,  9] -1 */
    52569930, /* 40337 ( 801) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
       16484, /* 40338 ( 802) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    52501971, /* 40339 ( 802) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 6,  6,  3] -1 */
    52438712, /* 40340 ( 802) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
      134418, /* 40341 ( 802) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  6]  1 */
      185045, /* 40342 ( 802) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 0,  0,  9]  1 */
    52502459, /* 40343 ( 802) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 6,  6,  3] -1 */
       71319, /* 40344 ( 802) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  3]  1 */
    52624445, /* 40345 ( 802) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 6,  6,  9] -1 */
      121298, /* 40346 ( 802) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6]  1 */
    52556970, /* 40347 ( 802) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
      184557, /* 40348 ( 802) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  9]  1 */
        3360, /* 40349 ( 802) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    52624929, /* 40350 ( 802) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 6,  6,  9] -1 */
    52570094, /* 40351 ( 802) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    52451832, /* 40352 ( 802) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
       70835, /* 40353 ( 802) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  3]  1 */
       16484, /* 40354 ( 803) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    18498657, /* 40355 ( 803) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  3]  1 */
      125508, /* 40356 ( 803) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  6]  1 */
    18494123, /* 40357 ( 803) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 6,  6,  3]  1 */
    18608333, /* 40358 ( 803) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 6,  6,  9]  1 */
       12270, /* 40359 ( 803) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  0]  1 */
      121298, /* 40360 ( 803) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6]  1 */
    18603795, /* 40361 ( 803) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  9]  1 */
       16484, /* 40362 ( 804) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34137732, /* 40363 ( 804) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  6] -1 */
    34133522, /* 40364 ( 804) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    18498657, /* 40365 ( 804) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  3]  1 */
    52506347, /* 40366 ( 804) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 6,  6,  3] -1 */
    52620557, /* 40367 ( 804) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 6,  6,  9] -1 */
      125508, /* 40368 ( 804) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  6]  1 */
    18494123, /* 40369 ( 804) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 6,  6,  3]  1 */
    34024494, /* 40370 ( 804) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    18608333, /* 40371 ( 804) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 6,  6,  9]  1 */
       12270, /* 40372 ( 804) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    52616019, /* 40373 ( 804) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  9] -1 */
      121298, /* 40374 ( 804) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6]  1 */
    52510881, /* 40375 ( 804) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  3] -1 */
    34028708, /* 40376 ( 804) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    18603795, /* 40377 ( 804) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  9]  1 */
       16484, /* 40378 ( 805) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34137732, /* 40379 ( 805) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  6] -1 */
    52506347, /* 40380 ( 805) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 6,  6,  3] -1 */
    18498657, /* 40381 ( 805) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  3]  1 */
    52620557, /* 40382 ( 805) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 6,  6,  9] -1 */
    34024494, /* 40383 ( 805) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  0] -1 */
      121298, /* 40384 ( 805) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6]  1 */
    18603795, /* 40385 ( 805) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  9]  1 */
       16484, /* 40386 ( 806) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34137732, /* 40387 ( 806) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  6] -1 */
    34024494, /* 40388 ( 806) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    18494123, /* 40389 ( 806) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 6,  6,  3]  1 */
    18608333, /* 40390 ( 806) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 6,  6,  9]  1 */
    52616019, /* 40391 ( 806) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  9] -1 */
      121298, /* 40392 ( 806) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6]  1 */
    52510881, /* 40393 ( 806) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  3] -1 */
       16484, /* 40394 ( 807) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    52506347, /* 40395 ( 807) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 6,  6,  3] -1 */
    52620557, /* 40396 ( 807) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 6,  6,  9] -1 */
      125508, /* 40397 ( 807) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  6]  1 */
       12270, /* 40398 ( 807) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    52616019, /* 40399 ( 807) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  9] -1 */
      121298, /* 40400 ( 807) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6]  1 */
    52510881, /* 40401 ( 807) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  3] -1 */
       16484, /* 40402 ( 808) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34142592, /* 40403 ( 808) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  6] -1 */
    18498657, /* 40404 ( 808) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  3]  1 */
    52497921, /* 40405 ( 808) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  3] -1 */
    34019634, /* 40406 ( 808) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  0] -1 */
      125508, /* 40407 ( 808) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  6]  1 */
    18494123, /* 40408 ( 808) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 6,  6,  3]  1 */
    52502459, /* 40409 ( 808) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 6,  6,  3] -1 */
    18608333, /* 40410 ( 808) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 6,  6,  9]  1 */
    52624445, /* 40411 ( 808) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 6,  6,  9] -1 */
       12270, /* 40412 ( 808) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    52628979, /* 40413 ( 808) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  9] -1 */
      121298, /* 40414 ( 808) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6]  1 */
    34146806, /* 40415 ( 808) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    34015424, /* 40416 ( 808) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    18603795, /* 40417 ( 808) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  9]  1 */
       16484, /* 40418 ( 809) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    18498657, /* 40419 ( 809) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  3]  1 */
    34197269, /* 40420 ( 809) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 0,  0,  9] -1 */
    52556810, /* 40421 ( 809) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
      125508, /* 40422 ( 809) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  6]  1 */
    18494123, /* 40423 ( 809) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 6,  6,  3]  1 */
    18608333, /* 40424 ( 809) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 6,  6,  9]  1 */
       12270, /* 40425 ( 809) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  0]  1 */
      121298, /* 40426 ( 809) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6]  1 */
    52451996, /* 40427 ( 809) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
    52447782, /* 40428 ( 809) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 6,  6,  0] -1 */
    34192731, /* 40429 ( 809) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  9] -1 */
    34083059, /* 40430 ( 809) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  3] -1 */
    52561020, /* 40431 ( 809) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    34087593, /* 40432 ( 809) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  3] -1 */
    18603795, /* 40433 ( 809) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  9]  1 */
       16484, /* 40434 ( 810) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    52442922, /* 40435 ( 810) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 6,  6,  0] -1 */
    18498657, /* 40436 ( 810) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  3]  1 */
    34205691, /* 40437 ( 810) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  9] -1 */
      125508, /* 40438 ( 810) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  6]  1 */
    18494123, /* 40439 ( 810) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 6,  6,  3]  1 */
    34074633, /* 40440 ( 810) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  3] -1 */
    34079171, /* 40441 ( 810) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 0,  0,  3] -1 */
    52565880, /* 40442 ( 810) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    18608333, /* 40443 ( 810) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 6,  6,  9]  1 */
    34201157, /* 40444 ( 810) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  9] -1 */
       12270, /* 40445 ( 810) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  0]  1 */
      121298, /* 40446 ( 810) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6]  1 */
    52438712, /* 40447 ( 810) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
    52570094, /* 40448 ( 810) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    18603795, /* 40449 ( 810) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  9]  1 */
       16484, /* 40450 ( 811) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    18557870, /* 40451 ( 811) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
        3200, /* 40452 ( 811) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    18548796, /* 40453 ( 811) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 6,  6,  6]  1 */
    18553656, /* 40454 ( 811) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 6,  6,  6]  1 */
       16320, /* 40455 ( 811) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    18553172, /* 40456 ( 811) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 6,  6,  6]  1 */
        7410, /* 40457 ( 811) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  0]  1 */
       12270, /* 40458 ( 811) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    18544586, /* 40459 ( 811) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    18549284, /* 40460 ( 811) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 6,  6,  6]  1 */
       11786, /* 40461 ( 811) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  0]  1 */
        3360, /* 40462 ( 811) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
        7898, /* 40463 ( 811) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    18544746, /* 40464 ( 811) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
    18557706, /* 40465 ( 811) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
       16484, /* 40466 ( 812) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34019634, /* 40467 ( 812) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    18553656, /* 40468 ( 812) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 6,  6,  6]  1 */
       16320, /* 40469 ( 812) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
       12270, /* 40470 ( 812) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    52556970, /* 40471 ( 812) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    52570094, /* 40472 ( 812) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    52565396, /* 40473 ( 812) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    52561508, /* 40474 ( 812) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    34024010, /* 40475 ( 812) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    18548796, /* 40476 ( 812) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 6,  6,  6]  1 */
    34015584, /* 40477 ( 812) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
        7410, /* 40478 ( 812) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    34020122, /* 40479 ( 812) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    34015424, /* 40480 ( 812) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    34028708, /* 40481 ( 812) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    18544746, /* 40482 ( 812) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
    18557870, /* 40483 ( 812) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    52556810, /* 40484 ( 812) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    18553172, /* 40485 ( 812) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    18549284, /* 40486 ( 812) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 6,  6,  6]  1 */
       11786, /* 40487 ( 812) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    52569930, /* 40488 ( 812) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
        3360, /* 40489 ( 812) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
        7898, /* 40490 ( 812) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    52565880, /* 40491 ( 812) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    34028544, /* 40492 ( 812) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
        3200, /* 40493 ( 812) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34024494, /* 40494 ( 812) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    18544586, /* 40495 ( 812) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    52561020, /* 40496 ( 812) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    18557706, /* 40497 ( 812) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
       16484, /* 40498 ( 813) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    52565396, /* 40499 ( 813) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    18557870, /* 40500 ( 813) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
        3200, /* 40501 ( 813) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    52561508, /* 40502 ( 813) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    34024494, /* 40503 ( 813) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    34019634, /* 40504 ( 813) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    34024010, /* 40505 ( 813) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  0] -1 */
       16320, /* 40506 ( 813) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    18544746, /* 40507 ( 813) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
    18544586, /* 40508 ( 813) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    34020122, /* 40509 ( 813) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 0,  0,  0] -1 */
        3360, /* 40510 ( 813) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    52561020, /* 40511 ( 813) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    52565880, /* 40512 ( 813) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    18557706, /* 40513 ( 813) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
       16484, /* 40514 ( 814) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    18557870, /* 40515 ( 814) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
        3200, /* 40516 ( 814) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34019634, /* 40517 ( 814) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    34024494, /* 40518 ( 814) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    18553172, /* 40519 ( 814) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    34015584, /* 40520 ( 814) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    18544586, /* 40521 ( 814) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    52556970, /* 40522 ( 814) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    18549284, /* 40523 ( 814) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 6,  6,  6]  1 */
       11786, /* 40524 ( 814) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    52569930, /* 40525 ( 814) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
        7898, /* 40526 ( 814) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    52561020, /* 40527 ( 814) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    52565880, /* 40528 ( 814) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    34028544, /* 40529 ( 814) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
       16484, /* 40530 ( 815) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    52565396, /* 40531 ( 815) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    18557870, /* 40532 ( 815) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
        3200, /* 40533 ( 815) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    52561508, /* 40534 ( 815) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    34024010, /* 40535 ( 815) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    18548796, /* 40536 ( 815) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 6,  6,  6]  1 */
    18553656, /* 40537 ( 815) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 6,  6,  6]  1 */
    34015584, /* 40538 ( 815) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
        7410, /* 40539 ( 815) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  0]  1 */
       12270, /* 40540 ( 815) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    18544586, /* 40541 ( 815) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    34020122, /* 40542 ( 815) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    52556970, /* 40543 ( 815) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    52569930, /* 40544 ( 815) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    34028544, /* 40545 ( 815) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
       16484, /* 40546 ( 816) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34137732, /* 40547 ( 816) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  6] -1 */
    52442922, /* 40548 ( 816) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 6,  6,  0] -1 */
    18553656, /* 40549 ( 816) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 6,  6,  6]  1 */
       16320, /* 40550 ( 816) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
       12270, /* 40551 ( 816) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    52447298, /* 40552 ( 816) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 6,  6,  0] -1 */
    52451996, /* 40553 ( 816) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
    52438872, /* 40554 ( 816) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
    52443410, /* 40555 ( 816) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 6,  6,  0] -1 */
    34142108, /* 40556 ( 816) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    18548796, /* 40557 ( 816) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 6,  6,  6]  1 */
    34138220, /* 40558 ( 816) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 0,  0,  6] -1 */
        7410, /* 40559 ( 816) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    34146806, /* 40560 ( 816) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    34133682, /* 40561 ( 816) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
    52438712, /* 40562 ( 816) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
    18544746, /* 40563 ( 816) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
    18557870, /* 40564 ( 816) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    34133522, /* 40565 ( 816) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    18553172, /* 40566 ( 816) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    52447782, /* 40567 ( 816) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 6,  6,  0] -1 */
    18549284, /* 40568 ( 816) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 6,  6,  6]  1 */
       11786, /* 40569 ( 816) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34146642, /* 40570 ( 816) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
        3360, /* 40571 ( 816) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
        7898, /* 40572 ( 816) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    52451832, /* 40573 ( 816) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
    34142592, /* 40574 ( 816) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  6] -1 */
        3200, /* 40575 ( 816) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    18544586, /* 40576 ( 816) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    18557706, /* 40577 ( 816) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
       16484, /* 40578 ( 817) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    18557870, /* 40579 ( 817) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
     1488011, /* 40580 ( 817) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 0,  6,  3]  1 */
        3200, /* 40581 ( 817) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
     1479585, /* 40582 ( 817) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  3]  1 */
     1492545, /* 40583 ( 817) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  3]  1 */
    18548796, /* 40584 ( 817) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 6,  6,  6]  1 */
    18553656, /* 40585 ( 817) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 6,  6,  6]  1 */
    17191157, /* 40586 ( 817) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 6,  0,  9]  1 */
    17186619, /* 40587 ( 817) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  9]  1 */
        7410, /* 40588 ( 817) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  0]  1 */
       12270, /* 40589 ( 817) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    18544586, /* 40590 ( 817) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
     1484123, /* 40591 ( 817) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 0,  6,  3]  1 */
    17195045, /* 40592 ( 817) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 6,  0,  9]  1 */
    17199579, /* 40593 ( 817) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  9]  1 */
       16484, /* 40594 ( 818) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    51203381, /* 40595 ( 818) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 6,  0,  9] -1 */
    34019634, /* 40596 ( 818) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    18553656, /* 40597 ( 818) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 6,  6,  6]  1 */
    51207269, /* 40598 ( 818) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 6,  0,  9] -1 */
       12270, /* 40599 ( 818) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  0]  1 */
     1484123, /* 40600 ( 818) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 0,  6,  3]  1 */
    35504769, /* 40601 ( 818) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  3] -1 */
    52570094, /* 40602 ( 818) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
     1488011, /* 40603 ( 818) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 0,  6,  3]  1 */
     1479585, /* 40604 ( 818) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  3]  1 */
    18548796, /* 40605 ( 818) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 6,  6,  6]  1 */
    17186619, /* 40606 ( 818) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  9]  1 */
    17191157, /* 40607 ( 818) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 6,  0,  9]  1 */
        7410, /* 40608 ( 818) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    51211803, /* 40609 ( 818) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  9] -1 */
    17195045, /* 40610 ( 818) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 6,  0,  9]  1 */
    34015424, /* 40611 ( 818) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    34028708, /* 40612 ( 818) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    18557870, /* 40613 ( 818) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    52556810, /* 40614 ( 818) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
     1492545, /* 40615 ( 818) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  3]  1 */
    17199579, /* 40616 ( 818) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  9]  1 */
    52565880, /* 40617 ( 818) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 6,  6,  6] -1 */
        3200, /* 40618 ( 818) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34024494, /* 40619 ( 818) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    35496347, /* 40620 ( 818) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 0,  6,  3] -1 */
    18544586, /* 40621 ( 818) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    35500235, /* 40622 ( 818) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 0,  6,  3] -1 */
    35491809, /* 40623 ( 818) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  3] -1 */
    52561020, /* 40624 ( 818) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    51198843, /* 40625 ( 818) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  9] -1 */
       16484, /* 40626 ( 819) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    18557870, /* 40627 ( 819) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    51203381, /* 40628 ( 819) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 6,  0,  9] -1 */
        3200, /* 40629 ( 819) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34019634, /* 40630 ( 819) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  0] -1 */
     1492545, /* 40631 ( 819) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  3]  1 */
    34024494, /* 40632 ( 819) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    51207269, /* 40633 ( 819) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 6,  0,  9] -1 */
    52565880, /* 40634 ( 819) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    17186619, /* 40635 ( 819) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  9]  1 */
     1479585, /* 40636 ( 819) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  3]  1 */
    35496347, /* 40637 ( 819) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 0,  6,  3] -1 */
    18544586, /* 40638 ( 819) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    35500235, /* 40639 ( 819) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 0,  6,  3] -1 */
    52561020, /* 40640 ( 819) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    17199579, /* 40641 ( 819) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  9]  1 */
       16484, /* 40642 ( 820) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    18557870, /* 40643 ( 820) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
     1488011, /* 40644 ( 820) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 0,  6,  3]  1 */
        3200, /* 40645 ( 820) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34019634, /* 40646 ( 820) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    34024494, /* 40647 ( 820) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    17191157, /* 40648 ( 820) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 6,  0,  9]  1 */
    51211803, /* 40649 ( 820) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  9] -1 */
    51198843, /* 40650 ( 820) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  9] -1 */
    18544586, /* 40651 ( 820) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
     1484123, /* 40652 ( 820) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 0,  6,  3]  1 */
    17195045, /* 40653 ( 820) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 6,  0,  9]  1 */
    35491809, /* 40654 ( 820) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  3] -1 */
    35504769, /* 40655 ( 820) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  3] -1 */
    52561020, /* 40656 ( 820) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    52565880, /* 40657 ( 820) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 6,  6,  6] -1 */
       16484, /* 40658 ( 821) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    18557870, /* 40659 ( 821) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    51203381, /* 40660 ( 821) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 6,  0,  9] -1 */
        3200, /* 40661 ( 821) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    18548796, /* 40662 ( 821) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 6,  6,  6]  1 */
    18553656, /* 40663 ( 821) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 6,  6,  6]  1 */
    51207269, /* 40664 ( 821) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 6,  0,  9] -1 */
    51211803, /* 40665 ( 821) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  9] -1 */
        7410, /* 40666 ( 821) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    35496347, /* 40667 ( 821) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 0,  6,  3] -1 */
       12270, /* 40668 ( 821) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    18544586, /* 40669 ( 821) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    35500235, /* 40670 ( 821) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 0,  6,  3] -1 */
    35491809, /* 40671 ( 821) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  3] -1 */
    35504769, /* 40672 ( 821) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  3] -1 */
    51198843, /* 40673 ( 821) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  9] -1 */
       16484, /* 40674 ( 822) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34137732, /* 40675 ( 822) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  6] -1 */
    52442922, /* 40676 ( 822) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 6,  6,  0] -1 */
    35618333, /* 40677 ( 822) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 0,  6,  9] -1 */
    18553656, /* 40678 ( 822) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 6,  6,  6]  1 */
       12270, /* 40679 ( 822) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    52451996, /* 40680 ( 822) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
     1484123, /* 40681 ( 822) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 0,  6,  3]  1 */
    51093705, /* 40682 ( 822) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  3] -1 */
     1488011, /* 40683 ( 822) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 0,  6,  3]  1 */
    35622867, /* 40684 ( 822) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  9] -1 */
     1479585, /* 40685 ( 822) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  3]  1 */
    18548796, /* 40686 ( 822) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 6,  6,  6]  1 */
    17186619, /* 40687 ( 822) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  9]  1 */
    17191157, /* 40688 ( 822) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 6,  0,  9]  1 */
        7410, /* 40689 ( 822) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    34146806, /* 40690 ( 822) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    17195045, /* 40691 ( 822) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 6,  0,  9]  1 */
    52438712, /* 40692 ( 822) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
    18557870, /* 40693 ( 822) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    34133522, /* 40694 ( 822) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
     1492545, /* 40695 ( 822) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  3]  1 */
    52447782, /* 40696 ( 822) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 6,  6,  0] -1 */
    17199579, /* 40697 ( 822) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  9]  1 */
    34142592, /* 40698 ( 822) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  6] -1 */
        3200, /* 40699 ( 822) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    51080745, /* 40700 ( 822) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  3] -1 */
    18544586, /* 40701 ( 822) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    35609907, /* 40702 ( 822) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  9] -1 */
    51085283, /* 40703 ( 822) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 6,  0,  3] -1 */
    35614445, /* 40704 ( 822) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 0,  6,  9] -1 */
    51089171, /* 40705 ( 822) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 6,  0,  3] -1 */
       16484, /* 40706 ( 823) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
        3200, /* 40707 ( 823) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
        3362, /* 40708 ( 823) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
       12272, /* 40709 ( 823) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 0,  0,  0]  1 */
        7412, /* 40710 ( 823) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  0]  1 */
       11786, /* 40711 ( 823) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  0]  1 */
        7898, /* 40712 ( 823) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 0,  0,  0]  1 */
       16322, /* 40713 ( 823) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
       16484, /* 40714 ( 824) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34015586, /* 40715 ( 824) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    34028546, /* 40716 ( 824) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
        3200, /* 40717 ( 824) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
        3362, /* 40718 ( 824) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34019636, /* 40719 ( 824) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  0] -1 */
       12272, /* 40720 ( 824) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34024010, /* 40721 ( 824) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  0] -1 */
        7412, /* 40722 ( 824) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34020122, /* 40723 ( 824) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 0,  0,  0] -1 */
       11786, /* 40724 ( 824) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34028708, /* 40725 ( 824) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
        7898, /* 40726 ( 824) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34024496, /* 40727 ( 824) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    34015424, /* 40728 ( 824) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
       16322, /* 40729 ( 824) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
       16484, /* 40730 ( 825) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34015586, /* 40731 ( 825) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
        3200, /* 40732 ( 825) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34024010, /* 40733 ( 825) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  0] -1 */
       12272, /* 40734 ( 825) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 0,  0,  0]  1 */
        7412, /* 40735 ( 825) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34020122, /* 40736 ( 825) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    34028546, /* 40737 ( 825) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
       16484, /* 40738 ( 826) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
        3200, /* 40739 ( 826) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
        3362, /* 40740 ( 826) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34019636, /* 40741 ( 826) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    34024010, /* 40742 ( 826) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    34020122, /* 40743 ( 826) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    34024496, /* 40744 ( 826) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 0,  0,  0] -1 */
       16322, /* 40745 ( 826) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
       16484, /* 40746 ( 827) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34015586, /* 40747 ( 827) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
        3200, /* 40748 ( 827) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34019636, /* 40749 ( 827) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  0] -1 */
       11786, /* 40750 ( 827) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34028546, /* 40751 ( 827) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
        7898, /* 40752 ( 827) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34024496, /* 40753 ( 827) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 0,  0,  0] -1 */
       16484, /* 40754 ( 828) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34142108, /* 40755 ( 828) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    34133522, /* 40756 ( 828) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
        3200, /* 40757 ( 828) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34142594, /* 40758 ( 828) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 0,  0,  6] -1 */
        3362, /* 40759 ( 828) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
       12272, /* 40760 ( 828) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34146644, /* 40761 ( 828) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    34138220, /* 40762 ( 828) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 0,  0,  6] -1 */
        7412, /* 40763 ( 828) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34146806, /* 40764 ( 828) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    34133684, /* 40765 ( 828) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
       11786, /* 40766 ( 828) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34137734, /* 40767 ( 828) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  6] -1 */
        7898, /* 40768 ( 828) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 0,  0,  0]  1 */
       16322, /* 40769 ( 828) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
       16484, /* 40770 ( 829) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    52451834, /* 40771 ( 829) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
        3200, /* 40772 ( 829) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
        3362, /* 40773 ( 829) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
       12272, /* 40774 ( 829) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    52438874, /* 40775 ( 829) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
    52442924, /* 40776 ( 829) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 6,  6,  0] -1 */
        7412, /* 40777 ( 829) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    52451996, /* 40778 ( 829) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
    52447298, /* 40779 ( 829) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 6,  6,  0] -1 */
       11786, /* 40780 ( 829) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    52438712, /* 40781 ( 829) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
        7898, /* 40782 ( 829) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    52443410, /* 40783 ( 829) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 6,  6,  0] -1 */
    52447784, /* 40784 ( 829) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 6,  6,  0] -1 */
       16322, /* 40785 ( 829) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
       16484, /* 40786 ( 830) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    52565396, /* 40787 ( 830) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    52556810, /* 40788 ( 830) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    52565882, /* 40789 ( 830) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 6,  6,  6] -1 */
        3200, /* 40790 ( 830) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    52561508, /* 40791 ( 830) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 6,  6,  6] -1 */
        3362, /* 40792 ( 830) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
       12272, /* 40793 ( 830) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    52569932, /* 40794 ( 830) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
        7412, /* 40795 ( 830) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    52556972, /* 40796 ( 830) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
       11786, /* 40797 ( 830) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    52561022, /* 40798 ( 830) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 6,  6,  6] -1 */
        7898, /* 40799 ( 830) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    52570094, /* 40800 ( 830) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
       16322, /* 40801 ( 830) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
       16484, /* 40802 ( 831) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    18435560, /* 40803 ( 831) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 6,  6,  0]  1 */
        3200, /* 40804 ( 831) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    18439610, /* 40805 ( 831) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    18426650, /* 40806 ( 831) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    18430700, /* 40807 ( 831) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 6,  6,  0]  1 */
       11786, /* 40808 ( 831) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  0]  1 */
        7898, /* 40809 ( 831) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 0,  0,  0]  1 */
       16484, /* 40810 ( 832) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    52451834, /* 40811 ( 832) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
    18435560, /* 40812 ( 832) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 6,  6,  0]  1 */
        3200, /* 40813 ( 832) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    18439610, /* 40814 ( 832) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    34024010, /* 40815 ( 832) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    52438874, /* 40816 ( 832) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
    52442924, /* 40817 ( 832) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 6,  6,  0] -1 */
    18426650, /* 40818 ( 832) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    18430700, /* 40819 ( 832) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    34020122, /* 40820 ( 832) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 0,  0,  0] -1 */
       11786, /* 40821 ( 832) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34028708, /* 40822 ( 832) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
        7898, /* 40823 ( 832) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    52447784, /* 40824 ( 832) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 6,  6,  0] -1 */
    34015424, /* 40825 ( 832) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
       16484, /* 40826 ( 833) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    52451834, /* 40827 ( 833) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
    18435560, /* 40828 ( 833) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 6,  6,  0]  1 */
        3200, /* 40829 ( 833) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34024010, /* 40830 ( 833) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    52438874, /* 40831 ( 833) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
    18430700, /* 40832 ( 833) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    34020122, /* 40833 ( 833) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 0,  0,  0] -1 */
       16484, /* 40834 ( 834) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
        3200, /* 40835 ( 834) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    18439610, /* 40836 ( 834) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    34024010, /* 40837 ( 834) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    52442924, /* 40838 ( 834) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 6,  6,  0] -1 */
    18426650, /* 40839 ( 834) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    34020122, /* 40840 ( 834) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    52447784, /* 40841 ( 834) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 6,  6,  0] -1 */
       16484, /* 40842 ( 835) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    52451834, /* 40843 ( 835) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
        3200, /* 40844 ( 835) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    52438874, /* 40845 ( 835) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
    52442924, /* 40846 ( 835) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 6,  6,  0] -1 */
       11786, /* 40847 ( 835) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  0]  1 */
        7898, /* 40848 ( 835) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    52447784, /* 40849 ( 835) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 6,  6,  0] -1 */
       16484, /* 40850 ( 836) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34142108, /* 40851 ( 836) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    34133522, /* 40852 ( 836) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    18435560, /* 40853 ( 836) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    52565882, /* 40854 ( 836) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 6,  6,  6] -1 */
        3200, /* 40855 ( 836) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    18439610, /* 40856 ( 836) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    52569932, /* 40857 ( 836) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    34138220, /* 40858 ( 836) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    18426650, /* 40859 ( 836) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    18430700, /* 40860 ( 836) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    34146806, /* 40861 ( 836) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    52556972, /* 40862 ( 836) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
       11786, /* 40863 ( 836) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    52561022, /* 40864 ( 836) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 6,  6,  6] -1 */
        7898, /* 40865 ( 836) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 0,  0,  0]  1 */
       16484, /* 40866 ( 837) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34015586, /* 40867 ( 837) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    18435560, /* 40868 ( 837) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 6,  6,  0]  1 */
        3200, /* 40869 ( 837) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    18439610, /* 40870 ( 837) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    34019636, /* 40871 ( 837) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    34024496, /* 40872 ( 837) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    52447298, /* 40873 ( 837) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 6,  6,  0] -1 */
    18426650, /* 40874 ( 837) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    52451996, /* 40875 ( 837) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
    18430700, /* 40876 ( 837) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 6,  6,  0]  1 */
       11786, /* 40877 ( 837) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34028546, /* 40878 ( 837) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    52438712, /* 40879 ( 837) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
        7898, /* 40880 ( 837) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    52443410, /* 40881 ( 837) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 6,  6,  0] -1 */
       16484, /* 40882 ( 838) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    52565396, /* 40883 ( 838) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    18435560, /* 40884 ( 838) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    52556810, /* 40885 ( 838) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
        3200, /* 40886 ( 838) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    52561508, /* 40887 ( 838) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    18439610, /* 40888 ( 838) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    34142594, /* 40889 ( 838) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    34146644, /* 40890 ( 838) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    18426650, /* 40891 ( 838) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    18430700, /* 40892 ( 838) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    34133684, /* 40893 ( 838) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    34137734, /* 40894 ( 838) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  6] -1 */
       11786, /* 40895 ( 838) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  0]  1 */
        7898, /* 40896 ( 838) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    52570094, /* 40897 ( 838) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
       16484, /* 40898 ( 839) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
      121460, /* 40899 ( 839) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6]  1 */
        3200, /* 40900 ( 839) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
      129884, /* 40901 ( 839) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  6]  1 */
       12272, /* 40902 ( 839) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 0,  0,  0]  1 */
        7412, /* 40903 ( 839) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  0]  1 */
      125996, /* 40904 ( 839) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 0,  0,  6]  1 */
      134420, /* 40905 ( 839) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6]  1 */
       16484, /* 40906 ( 840) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
      121460, /* 40907 ( 840) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6]  1 */
    34142108, /* 40908 ( 840) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  6] -1 */
        3200, /* 40909 ( 840) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
      129884, /* 40910 ( 840) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  6]  1 */
    34019636, /* 40911 ( 840) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  0] -1 */
       12272, /* 40912 ( 840) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34146644, /* 40913 ( 840) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    34138220, /* 40914 ( 840) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 0,  0,  6] -1 */
        7412, /* 40915 ( 840) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  0]  1 */
      125996, /* 40916 ( 840) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 0,  0,  6]  1 */
    34133684, /* 40917 ( 840) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
      134420, /* 40918 ( 840) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6]  1 */
    34028708, /* 40919 ( 840) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    34024496, /* 40920 ( 840) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    34015424, /* 40921 ( 840) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
       16484, /* 40922 ( 841) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34142108, /* 40923 ( 841) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  6] -1 */
        3200, /* 40924 ( 841) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
       12272, /* 40925 ( 841) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34146644, /* 40926 ( 841) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    34138220, /* 40927 ( 841) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 0,  0,  6] -1 */
        7412, /* 40928 ( 841) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34133684, /* 40929 ( 841) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
       16484, /* 40930 ( 842) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
      121460, /* 40931 ( 842) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6]  1 */
    34142108, /* 40932 ( 842) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  6] -1 */
        3200, /* 40933 ( 842) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34019636, /* 40934 ( 842) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    34138220, /* 40935 ( 842) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 0,  0,  6] -1 */
      134420, /* 40936 ( 842) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6]  1 */
    34024496, /* 40937 ( 842) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 0,  0,  0] -1 */
       16484, /* 40938 ( 843) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
        3200, /* 40939 ( 843) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
      129884, /* 40940 ( 843) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  6]  1 */
    34019636, /* 40941 ( 843) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    34146644, /* 40942 ( 843) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
      125996, /* 40943 ( 843) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 0,  0,  6]  1 */
    34133684, /* 40944 ( 843) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    34024496, /* 40945 ( 843) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 0,  0,  0] -1 */
       16484, /* 40946 ( 844) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
      121460, /* 40947 ( 844) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6]  1 */
    34015586, /* 40948 ( 844) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    34133522, /* 40949 ( 844) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    34028546, /* 40950 ( 844) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
        3200, /* 40951 ( 844) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34142594, /* 40952 ( 844) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 0,  0,  6] -1 */
      129884, /* 40953 ( 844) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  6]  1 */
    34024010, /* 40954 ( 844) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  0] -1 */
       12272, /* 40955 ( 844) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 0,  0,  0]  1 */
        7412, /* 40956 ( 844) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34020122, /* 40957 ( 844) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    34146806, /* 40958 ( 844) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
      125996, /* 40959 ( 844) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 0,  0,  6]  1 */
    34137734, /* 40960 ( 844) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  6] -1 */
      134420, /* 40961 ( 844) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6]  1 */
       16484, /* 40962 ( 845) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
      121460, /* 40963 ( 845) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6]  1 */
    52565396, /* 40964 ( 845) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 6,  6,  6] -1 */
        3200, /* 40965 ( 845) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    52561508, /* 40966 ( 845) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 6,  6,  6] -1 */
      129884, /* 40967 ( 845) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  6]  1 */
       12272, /* 40968 ( 845) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    52442924, /* 40969 ( 845) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 6,  6,  0] -1 */
    52569932, /* 40970 ( 845) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
        7412, /* 40971 ( 845) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    52451996, /* 40972 ( 845) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
      125996, /* 40973 ( 845) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 0,  0,  6]  1 */
    52556972, /* 40974 ( 845) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
      134420, /* 40975 ( 845) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6]  1 */
    52438712, /* 40976 ( 845) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
    52447784, /* 40977 ( 845) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 6,  6,  0] -1 */
       16484, /* 40978 ( 846) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    52451834, /* 40979 ( 846) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
      121460, /* 40980 ( 846) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6]  1 */
    52556810, /* 40981 ( 846) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
        3200, /* 40982 ( 846) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
      129884, /* 40983 ( 846) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  6]  1 */
       12272, /* 40984 ( 846) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    52438874, /* 40985 ( 846) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
        7412, /* 40986 ( 846) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    52447298, /* 40987 ( 846) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 6,  6,  0] -1 */
      125996, /* 40988 ( 846) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 0,  0,  6]  1 */
    52561022, /* 40989 ( 846) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    52565882, /* 40990 ( 846) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 6,  6,  6] -1 */
      134420, /* 40991 ( 846) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6]  1 */
    52570094, /* 40992 ( 846) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    52443410, /* 40993 ( 846) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 6,  6,  0] -1 */
       16484, /* 40994 ( 847) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
        3200, /* 40995 ( 847) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    18553172, /* 40996 ( 847) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 6,  6,  6]  1 */
       12272, /* 40997 ( 847) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 0,  0,  0]  1 */
        7412, /* 40998 ( 847) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    18549284, /* 40999 ( 847) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    18557708, /* 41000 ( 847) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    18544748, /* 41001 ( 847) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
       16484, /* 41002 ( 848) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    52565396, /* 41003 ( 848) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 6,  6,  6] -1 */
        3200, /* 41004 ( 848) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    52561508, /* 41005 ( 848) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    18553172, /* 41006 ( 848) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 6,  6,  6]  1 */
       12272, /* 41007 ( 848) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34019636, /* 41008 ( 848) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    52569932, /* 41009 ( 848) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    34024496, /* 41010 ( 848) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 0,  0,  0] -1 */
        7412, /* 41011 ( 848) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    18549284, /* 41012 ( 848) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    52556972, /* 41013 ( 848) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    34015424, /* 41014 ( 848) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    18557708, /* 41015 ( 848) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    34028708, /* 41016 ( 848) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    18544748, /* 41017 ( 848) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
       16484, /* 41018 ( 849) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    52565396, /* 41019 ( 849) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 6,  6,  6] -1 */
        3200, /* 41020 ( 849) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    52561508, /* 41021 ( 849) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 6,  6,  6] -1 */
       12272, /* 41022 ( 849) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    52569932, /* 41023 ( 849) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
        7412, /* 41024 ( 849) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    52556972, /* 41025 ( 849) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
       16484, /* 41026 ( 850) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    52565396, /* 41027 ( 850) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 6,  6,  6] -1 */
        3200, /* 41028 ( 850) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    52561508, /* 41029 ( 850) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    34019636, /* 41030 ( 850) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    34024496, /* 41031 ( 850) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    18557708, /* 41032 ( 850) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    18544748, /* 41033 ( 850) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
       16484, /* 41034 ( 851) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
        3200, /* 41035 ( 851) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34019636, /* 41036 ( 851) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    18553172, /* 41037 ( 851) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    52569932, /* 41038 ( 851) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    52556972, /* 41039 ( 851) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    18549284, /* 41040 ( 851) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    34024496, /* 41041 ( 851) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 0,  0,  0] -1 */
       16484, /* 41042 ( 852) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    52451834, /* 41043 ( 852) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
    34133522, /* 41044 ( 852) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
        3200, /* 41045 ( 852) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34142594, /* 41046 ( 852) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    18553172, /* 41047 ( 852) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 6,  6,  6]  1 */
       12272, /* 41048 ( 852) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    52438874, /* 41049 ( 852) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
        7412, /* 41050 ( 852) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    52447298, /* 41051 ( 852) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 6,  6,  0] -1 */
    34146806, /* 41052 ( 852) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    18549284, /* 41053 ( 852) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    34137734, /* 41054 ( 852) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    18557708, /* 41055 ( 852) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    18544748, /* 41056 ( 852) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    52443410, /* 41057 ( 852) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 6,  6,  0] -1 */
       16484, /* 41058 ( 853) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34142108, /* 41059 ( 853) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    52438712, /* 41060 ( 853) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
        3200, /* 41061 ( 853) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    18553172, /* 41062 ( 853) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 6,  6,  6]  1 */
       12272, /* 41063 ( 853) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    52442924, /* 41064 ( 853) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 6,  6,  0] -1 */
    34146644, /* 41065 ( 853) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    34138220, /* 41066 ( 853) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 0,  0,  6] -1 */
        7412, /* 41067 ( 853) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    52451996, /* 41068 ( 853) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
    34133684, /* 41069 ( 853) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    18549284, /* 41070 ( 853) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    18557708, /* 41071 ( 853) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    18544748, /* 41072 ( 853) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    52447784, /* 41073 ( 853) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 6,  6,  0] -1 */
       16484, /* 41074 ( 854) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34015586, /* 41075 ( 854) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    52556810, /* 41076 ( 854) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
        3200, /* 41077 ( 854) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34024010, /* 41078 ( 854) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    18553172, /* 41079 ( 854) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 6,  6,  6]  1 */
       12272, /* 41080 ( 854) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 0,  0,  0]  1 */
        7412, /* 41081 ( 854) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34020122, /* 41082 ( 854) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    18557708, /* 41083 ( 854) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    18549284, /* 41084 ( 854) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    52561022, /* 41085 ( 854) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    52565882, /* 41086 ( 854) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    34028546, /* 41087 ( 854) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    52570094, /* 41088 ( 854) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    18544748, /* 41089 ( 854) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
       16484, /* 41090 ( 855) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
      121460, /* 41091 ( 855) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6]  1 */
        3200, /* 41092 ( 855) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
      130370, /* 41093 ( 855) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 0,  0,  6]  1 */
       11786, /* 41094 ( 855) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  0]  1 */
      134420, /* 41095 ( 855) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6]  1 */
        7898, /* 41096 ( 855) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 0,  0,  0]  1 */
      125510, /* 41097 ( 855) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  6]  1 */
       16484, /* 41098 ( 856) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
      121460, /* 41099 ( 856) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6]  1 */
        3200, /* 41100 ( 856) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34142594, /* 41101 ( 856) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    34024010, /* 41102 ( 856) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  0] -1 */
        7898, /* 41103 ( 856) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34146644, /* 41104 ( 856) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    34020122, /* 41105 ( 856) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    34133684, /* 41106 ( 856) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
      130370, /* 41107 ( 856) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 0,  0,  6]  1 */
       11786, /* 41108 ( 856) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34137734, /* 41109 ( 856) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  6] -1 */
      134420, /* 41110 ( 856) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6]  1 */
    34028708, /* 41111 ( 856) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
      125510, /* 41112 ( 856) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  6]  1 */
    34015424, /* 41113 ( 856) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
       16484, /* 41114 ( 857) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
        3200, /* 41115 ( 857) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34024010, /* 41116 ( 857) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    34146644, /* 41117 ( 857) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    34020122, /* 41118 ( 857) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    34133684, /* 41119 ( 857) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
      130370, /* 41120 ( 857) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 0,  0,  6]  1 */
      125510, /* 41121 ( 857) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  6]  1 */
       16484, /* 41122 ( 858) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
      121460, /* 41123 ( 858) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6]  1 */
        3200, /* 41124 ( 858) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34142594, /* 41125 ( 858) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    34024010, /* 41126 ( 858) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    34020122, /* 41127 ( 858) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    34137734, /* 41128 ( 858) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  6] -1 */
      134420, /* 41129 ( 858) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6]  1 */
       16484, /* 41130 ( 859) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
        3200, /* 41131 ( 859) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34142594, /* 41132 ( 859) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    34146644, /* 41133 ( 859) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    34133684, /* 41134 ( 859) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    34137734, /* 41135 ( 859) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  6] -1 */
       11786, /* 41136 ( 859) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  0]  1 */
        7898, /* 41137 ( 859) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 0,  0,  0]  1 */
       16484, /* 41138 ( 860) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
      121460, /* 41139 ( 860) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6]  1 */
    34015586, /* 41140 ( 860) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    34133522, /* 41141 ( 860) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    34142108, /* 41142 ( 860) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  6] -1 */
        3200, /* 41143 ( 860) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34028546, /* 41144 ( 860) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    34019636, /* 41145 ( 860) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    34138220, /* 41146 ( 860) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    34146806, /* 41147 ( 860) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
      130370, /* 41148 ( 860) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 0,  0,  6]  1 */
       11786, /* 41149 ( 860) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  0]  1 */
      134420, /* 41150 ( 860) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6]  1 */
        7898, /* 41151 ( 860) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 0,  0,  0]  1 */
      125510, /* 41152 ( 860) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  6]  1 */
    34024496, /* 41153 ( 860) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 0,  0,  0] -1 */
       16484, /* 41154 ( 861) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
      121460, /* 41155 ( 861) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6]  1 */
    52565882, /* 41156 ( 861) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 6,  6,  6] -1 */
        3200, /* 41157 ( 861) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    52569932, /* 41158 ( 861) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    52447298, /* 41159 ( 861) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 6,  6,  0] -1 */
    52451996, /* 41160 ( 861) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
      130370, /* 41161 ( 861) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 0,  0,  6]  1 */
    52556972, /* 41162 ( 861) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
       11786, /* 41163 ( 861) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  0]  1 */
      134420, /* 41164 ( 861) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6]  1 */
    52438712, /* 41165 ( 861) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
        7898, /* 41166 ( 861) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 0,  0,  0]  1 */
      125510, /* 41167 ( 861) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  6]  1 */
    52443410, /* 41168 ( 861) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 6,  6,  0] -1 */
    52561022, /* 41169 ( 861) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 6,  6,  6] -1 */
       16484, /* 41170 ( 862) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    52451834, /* 41171 ( 862) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
      121460, /* 41172 ( 862) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6]  1 */
    52565396, /* 41173 ( 862) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    52556810, /* 41174 ( 862) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
        3200, /* 41175 ( 862) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    52561508, /* 41176 ( 862) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    52438874, /* 41177 ( 862) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
    52442924, /* 41178 ( 862) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 6,  6,  0] -1 */
      130370, /* 41179 ( 862) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 0,  0,  6]  1 */
       11786, /* 41180 ( 862) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  0]  1 */
      134420, /* 41181 ( 862) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6]  1 */
        7898, /* 41182 ( 862) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 0,  0,  0]  1 */
      125510, /* 41183 ( 862) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  6]  1 */
    52570094, /* 41184 ( 862) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    52447784, /* 41185 ( 862) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 6,  6,  0] -1 */
       16484, /* 41186 ( 863) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
        3200, /* 41187 ( 863) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    18548798, /* 41188 ( 863) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 6,  6,  6]  1 */
       11786, /* 41189 ( 863) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    18557708, /* 41190 ( 863) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
        7898, /* 41191 ( 863) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    18544748, /* 41192 ( 863) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    18553658, /* 41193 ( 863) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 6,  6,  6]  1 */
       16484, /* 41194 ( 864) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    52565882, /* 41195 ( 864) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 6,  6,  6] -1 */
        3200, /* 41196 ( 864) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34024010, /* 41197 ( 864) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  0] -1 */
        7898, /* 41198 ( 864) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    52569932, /* 41199 ( 864) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    34020122, /* 41200 ( 864) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    18548798, /* 41201 ( 864) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    52556972, /* 41202 ( 864) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
       11786, /* 41203 ( 864) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    52561022, /* 41204 ( 864) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    34015424, /* 41205 ( 864) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    18557708, /* 41206 ( 864) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    34028708, /* 41207 ( 864) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    18544748, /* 41208 ( 864) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    18553658, /* 41209 ( 864) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 6,  6,  6]  1 */
       16484, /* 41210 ( 865) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
        3200, /* 41211 ( 865) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34024010, /* 41212 ( 865) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    52569932, /* 41213 ( 865) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    34020122, /* 41214 ( 865) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    52556972, /* 41215 ( 865) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    18548798, /* 41216 ( 865) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    18553658, /* 41217 ( 865) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 6,  6,  6]  1 */
       16484, /* 41218 ( 866) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
        3200, /* 41219 ( 866) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34024010, /* 41220 ( 866) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    34020122, /* 41221 ( 866) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    52561022, /* 41222 ( 866) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    52565882, /* 41223 ( 866) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    18557708, /* 41224 ( 866) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    18544748, /* 41225 ( 866) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
       16484, /* 41226 ( 867) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
        3200, /* 41227 ( 867) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    52569932, /* 41228 ( 867) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    52561022, /* 41229 ( 867) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    52556972, /* 41230 ( 867) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    52565882, /* 41231 ( 867) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 6,  6,  6] -1 */
       11786, /* 41232 ( 867) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  0]  1 */
        7898, /* 41233 ( 867) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 0,  0,  0]  1 */
       16484, /* 41234 ( 868) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    52451834, /* 41235 ( 868) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
    34142108, /* 41236 ( 868) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    34133522, /* 41237 ( 868) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
        3200, /* 41238 ( 868) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    52438874, /* 41239 ( 868) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
    52442924, /* 41240 ( 868) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 6,  6,  0] -1 */
    34138220, /* 41241 ( 868) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    34146806, /* 41242 ( 868) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    18548798, /* 41243 ( 868) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 6,  6,  6]  1 */
       11786, /* 41244 ( 868) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    18557708, /* 41245 ( 868) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
        7898, /* 41246 ( 868) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    18544748, /* 41247 ( 868) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    52447784, /* 41248 ( 868) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 6,  6,  0] -1 */
    18553658, /* 41249 ( 868) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 6,  6,  6]  1 */
       16484, /* 41250 ( 869) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    52438712, /* 41251 ( 869) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
        3200, /* 41252 ( 869) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34142594, /* 41253 ( 869) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    34146644, /* 41254 ( 869) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    52447298, /* 41255 ( 869) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 6,  6,  0] -1 */
    52451996, /* 41256 ( 869) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
    18548798, /* 41257 ( 869) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    34133684, /* 41258 ( 869) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
       11786, /* 41259 ( 869) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34137734, /* 41260 ( 869) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    18557708, /* 41261 ( 869) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
        7898, /* 41262 ( 869) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    18544748, /* 41263 ( 869) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    52443410, /* 41264 ( 869) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 6,  6,  0] -1 */
    18553658, /* 41265 ( 869) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 6,  6,  6]  1 */
       16484, /* 41266 ( 870) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34015586, /* 41267 ( 870) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    52565396, /* 41268 ( 870) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    52556810, /* 41269 ( 870) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
        3200, /* 41270 ( 870) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    52561508, /* 41271 ( 870) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    34019636, /* 41272 ( 870) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    34024496, /* 41273 ( 870) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    18548798, /* 41274 ( 870) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    18557708, /* 41275 ( 870) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
       11786, /* 41276 ( 870) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34028546, /* 41277 ( 870) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    52570094, /* 41278 ( 870) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
        7898, /* 41279 ( 870) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    18544748, /* 41280 ( 870) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    18553658, /* 41281 ( 870) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 6,  6,  6]  1 */
       16484, /* 41282 ( 871) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
        3200, /* 41283 ( 871) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
        3362, /* 41284 ( 871) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
      129884, /* 41285 ( 871) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  6]  1 */
      125996, /* 41286 ( 871) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 0,  0,  6]  1 */
      130370, /* 41287 ( 871) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 0,  0,  6]  1 */
      125510, /* 41288 ( 871) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  6]  1 */
       16322, /* 41289 ( 871) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
       16484, /* 41290 ( 872) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34015586, /* 41291 ( 872) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    34142108, /* 41292 ( 872) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    34028546, /* 41293 ( 872) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
        3200, /* 41294 ( 872) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34142594, /* 41295 ( 872) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 0,  0,  6] -1 */
        3362, /* 41296 ( 872) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
      129884, /* 41297 ( 872) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  6]  1 */
    34138220, /* 41298 ( 872) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 0,  0,  6] -1 */
      125996, /* 41299 ( 872) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 0,  0,  6]  1 */
      130370, /* 41300 ( 872) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 0,  0,  6]  1 */
    34137734, /* 41301 ( 872) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    34015424, /* 41302 ( 872) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    34028708, /* 41303 ( 872) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
      125510, /* 41304 ( 872) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  6]  1 */
       16322, /* 41305 ( 872) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
       16484, /* 41306 ( 873) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34015586, /* 41307 ( 873) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    34142108, /* 41308 ( 873) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  6] -1 */
        3200, /* 41309 ( 873) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34138220, /* 41310 ( 873) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 0,  0,  6] -1 */
      130370, /* 41311 ( 873) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 0,  0,  6]  1 */
    34028546, /* 41312 ( 873) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
      125510, /* 41313 ( 873) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  6]  1 */
       16484, /* 41314 ( 874) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34142108, /* 41315 ( 874) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  6] -1 */
        3200, /* 41316 ( 874) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34142594, /* 41317 ( 874) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 0,  0,  6] -1 */
        3362, /* 41318 ( 874) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34138220, /* 41319 ( 874) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    34137734, /* 41320 ( 874) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  6] -1 */
       16322, /* 41321 ( 874) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
       16484, /* 41322 ( 875) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34015586, /* 41323 ( 875) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
        3200, /* 41324 ( 875) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34142594, /* 41325 ( 875) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 0,  0,  6] -1 */
      129884, /* 41326 ( 875) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  6]  1 */
      125996, /* 41327 ( 875) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 0,  0,  6]  1 */
    34137734, /* 41328 ( 875) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    34028546, /* 41329 ( 875) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
       16484, /* 41330 ( 876) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34133522, /* 41331 ( 876) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
        3200, /* 41332 ( 876) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
        3362, /* 41333 ( 876) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
      129884, /* 41334 ( 876) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  6]  1 */
    34019636, /* 41335 ( 876) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    34024010, /* 41336 ( 876) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    34146644, /* 41337 ( 876) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    34020122, /* 41338 ( 876) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    34146806, /* 41339 ( 876) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
      125996, /* 41340 ( 876) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 0,  0,  6]  1 */
      130370, /* 41341 ( 876) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 0,  0,  6]  1 */
    34133684, /* 41342 ( 876) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
      125510, /* 41343 ( 876) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  6]  1 */
    34024496, /* 41344 ( 876) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 0,  0,  0] -1 */
       16322, /* 41345 ( 876) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
       16484, /* 41346 ( 877) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    52451834, /* 41347 ( 877) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
    52565396, /* 41348 ( 877) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 6,  6,  6] -1 */
        3200, /* 41349 ( 877) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    52561508, /* 41350 ( 877) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 6,  6,  6] -1 */
        3362, /* 41351 ( 877) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
      129884, /* 41352 ( 877) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  6]  1 */
    52438874, /* 41353 ( 877) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
    52451996, /* 41354 ( 877) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
      125996, /* 41355 ( 877) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 0,  0,  6]  1 */
      130370, /* 41356 ( 877) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 0,  0,  6]  1 */
    52561022, /* 41357 ( 877) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    52565882, /* 41358 ( 877) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    52438712, /* 41359 ( 877) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
      125510, /* 41360 ( 877) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  6]  1 */
       16322, /* 41361 ( 877) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
       16484, /* 41362 ( 878) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    52556810, /* 41363 ( 878) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
        3200, /* 41364 ( 878) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
        3362, /* 41365 ( 878) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
      129884, /* 41366 ( 878) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  6]  1 */
    52442924, /* 41367 ( 878) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 6,  6,  0] -1 */
    52569932, /* 41368 ( 878) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    52447298, /* 41369 ( 878) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 6,  6,  0] -1 */
    52447784, /* 41370 ( 878) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 6,  6,  0] -1 */
      125996, /* 41371 ( 878) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 0,  0,  6]  1 */
      130370, /* 41372 ( 878) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 0,  0,  6]  1 */
    52556972, /* 41373 ( 878) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
      125510, /* 41374 ( 878) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  6]  1 */
    52570094, /* 41375 ( 878) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    52443410, /* 41376 ( 878) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 6,  6,  0] -1 */
       16322, /* 41377 ( 878) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
       16484, /* 41378 ( 879) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
        3200, /* 41379 ( 879) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    18439610, /* 41380 ( 879) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
      129884, /* 41381 ( 879) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  6]  1 */
    18426650, /* 41382 ( 879) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
      125996, /* 41383 ( 879) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 0,  0,  6]  1 */
    18548798, /* 41384 ( 879) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    18553658, /* 41385 ( 879) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 6,  6,  6]  1 */
       16484, /* 41386 ( 880) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    52451834, /* 41387 ( 880) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
    34142108, /* 41388 ( 880) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  6] -1 */
        3200, /* 41389 ( 880) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    18439610, /* 41390 ( 880) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
      129884, /* 41391 ( 880) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  6]  1 */
    52438874, /* 41392 ( 880) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
    34138220, /* 41393 ( 880) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    18426650, /* 41394 ( 880) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
      125996, /* 41395 ( 880) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 0,  0,  6]  1 */
    52561022, /* 41396 ( 880) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    52565882, /* 41397 ( 880) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    34015424, /* 41398 ( 880) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    34028708, /* 41399 ( 880) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    18548798, /* 41400 ( 880) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    18553658, /* 41401 ( 880) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 6,  6,  6]  1 */
       16484, /* 41402 ( 881) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    52451834, /* 41403 ( 881) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
    34142108, /* 41404 ( 881) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  6] -1 */
        3200, /* 41405 ( 881) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    52438874, /* 41406 ( 881) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
    34138220, /* 41407 ( 881) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    18548798, /* 41408 ( 881) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    18553658, /* 41409 ( 881) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 6,  6,  6]  1 */
       16484, /* 41410 ( 882) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34142108, /* 41411 ( 882) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  6] -1 */
        3200, /* 41412 ( 882) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    18439610, /* 41413 ( 882) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    34138220, /* 41414 ( 882) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    18426650, /* 41415 ( 882) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    52561022, /* 41416 ( 882) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    52565882, /* 41417 ( 882) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 6,  6,  6] -1 */
       16484, /* 41418 ( 883) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    52451834, /* 41419 ( 883) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
        3200, /* 41420 ( 883) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
      129884, /* 41421 ( 883) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  6]  1 */
    52438874, /* 41422 ( 883) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
      125996, /* 41423 ( 883) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 0,  0,  6]  1 */
    52561022, /* 41424 ( 883) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    52565882, /* 41425 ( 883) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 6,  6,  6] -1 */
       16484, /* 41426 ( 884) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34133522, /* 41427 ( 884) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
        3200, /* 41428 ( 884) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    18439610, /* 41429 ( 884) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
      129884, /* 41430 ( 884) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  6]  1 */
    34024010, /* 41431 ( 884) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    52442924, /* 41432 ( 884) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 6,  6,  0] -1 */
    52569932, /* 41433 ( 884) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    18426650, /* 41434 ( 884) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    34020122, /* 41435 ( 884) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    34146806, /* 41436 ( 884) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
      125996, /* 41437 ( 884) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 0,  0,  6]  1 */
    52556972, /* 41438 ( 884) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    18548798, /* 41439 ( 884) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    52447784, /* 41440 ( 884) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 6,  6,  0] -1 */
    18553658, /* 41441 ( 884) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 6,  6,  6]  1 */
       16484, /* 41442 ( 885) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34015586, /* 41443 ( 885) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    52565396, /* 41444 ( 885) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 6,  6,  6] -1 */
        3200, /* 41445 ( 885) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    52561508, /* 41446 ( 885) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 6,  6,  6] -1 */
      129884, /* 41447 ( 885) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  6]  1 */
    18439610, /* 41448 ( 885) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    34142594, /* 41449 ( 885) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    18426650, /* 41450 ( 885) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    52451996, /* 41451 ( 885) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
      125996, /* 41452 ( 885) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 0,  0,  6]  1 */
    34137734, /* 41453 ( 885) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    34028546, /* 41454 ( 885) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    52438712, /* 41455 ( 885) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
    18548798, /* 41456 ( 885) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    18553658, /* 41457 ( 885) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 6,  6,  6]  1 */
       16484, /* 41458 ( 886) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    52556810, /* 41459 ( 886) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
        3200, /* 41460 ( 886) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    18439610, /* 41461 ( 886) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
      129884, /* 41462 ( 886) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  6]  1 */
    34019636, /* 41463 ( 886) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    34146644, /* 41464 ( 886) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    34024496, /* 41465 ( 886) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    52447298, /* 41466 ( 886) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 6,  6,  0] -1 */
    18426650, /* 41467 ( 886) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
      125996, /* 41468 ( 886) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 0,  0,  6]  1 */
    18548798, /* 41469 ( 886) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    34133684, /* 41470 ( 886) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    52570094, /* 41471 ( 886) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    52443410, /* 41472 ( 886) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 6,  6,  0] -1 */
    18553658, /* 41473 ( 886) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 6,  6,  6]  1 */
       16484, /* 41474 ( 887) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    18557870, /* 41475 ( 887) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
        3200, /* 41476 ( 887) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
        3362, /* 41477 ( 887) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    18553172, /* 41478 ( 887) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 6,  6,  6]  1 */
       12272, /* 41479 ( 887) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 0,  0,  0]  1 */
        7412, /* 41480 ( 887) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    18544586, /* 41481 ( 887) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    18548798, /* 41482 ( 887) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    18549284, /* 41483 ( 887) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 6,  6,  6]  1 */
       11786, /* 41484 ( 887) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    18557708, /* 41485 ( 887) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
        7898, /* 41486 ( 887) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    18544748, /* 41487 ( 887) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    18553658, /* 41488 ( 887) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 6,  6,  6]  1 */
       16322, /* 41489 ( 887) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
       16484, /* 41490 ( 888) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    52570094, /* 41491 ( 888) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    52565396, /* 41492 ( 888) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    52561508, /* 41493 ( 888) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    34024010, /* 41494 ( 888) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    52569932, /* 41495 ( 888) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    34020122, /* 41496 ( 888) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    52556972, /* 41497 ( 888) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    52565882, /* 41498 ( 888) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    34015424, /* 41499 ( 888) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    34028546, /* 41500 ( 888) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    34028708, /* 41501 ( 888) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    34024496, /* 41502 ( 888) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    34015586, /* 41503 ( 888) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    18557870, /* 41504 ( 888) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    52556810, /* 41505 ( 888) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    34019636, /* 41506 ( 888) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    18553172, /* 41507 ( 888) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    18549284, /* 41508 ( 888) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 6,  6,  6]  1 */
       11786, /* 41509 ( 888) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    52561022, /* 41510 ( 888) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    18557708, /* 41511 ( 888) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
        7898, /* 41512 ( 888) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    18544748, /* 41513 ( 888) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    18553658, /* 41514 ( 888) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 6,  6,  6]  1 */
       16322, /* 41515 ( 888) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
        3200, /* 41516 ( 888) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
        3362, /* 41517 ( 888) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
       12272, /* 41518 ( 888) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 0,  0,  0]  1 */
        7412, /* 41519 ( 888) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    18544586, /* 41520 ( 888) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    18548798, /* 41521 ( 888) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 6,  6,  6]  1 */
       16484, /* 41522 ( 889) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34015586, /* 41523 ( 889) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    18557870, /* 41524 ( 889) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    52565396, /* 41525 ( 889) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 6,  6,  6] -1 */
        3200, /* 41526 ( 889) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    52561508, /* 41527 ( 889) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    34024010, /* 41528 ( 889) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  0] -1 */
       12272, /* 41529 ( 889) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    52569932, /* 41530 ( 889) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
        7412, /* 41531 ( 889) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    18544586, /* 41532 ( 889) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    34020122, /* 41533 ( 889) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    52556972, /* 41534 ( 889) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    34028546, /* 41535 ( 889) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    18548798, /* 41536 ( 889) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    18553658, /* 41537 ( 889) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 6,  6,  6]  1 */
       16484, /* 41538 ( 890) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    52565396, /* 41539 ( 890) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    18557870, /* 41540 ( 890) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
        3200, /* 41541 ( 890) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    52561508, /* 41542 ( 890) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 6,  6,  6] -1 */
        3362, /* 41543 ( 890) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34019636, /* 41544 ( 890) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    34024010, /* 41545 ( 890) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    34024496, /* 41546 ( 890) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    18544586, /* 41547 ( 890) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    34020122, /* 41548 ( 890) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    52561022, /* 41549 ( 890) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    52565882, /* 41550 ( 890) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    18557708, /* 41551 ( 890) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    18544748, /* 41552 ( 890) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
       16322, /* 41553 ( 890) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
       16484, /* 41554 ( 891) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34015586, /* 41555 ( 891) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    18557870, /* 41556 ( 891) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    34028546, /* 41557 ( 891) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    52565882, /* 41558 ( 891) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 6,  6,  6] -1 */
        3200, /* 41559 ( 891) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34019636, /* 41560 ( 891) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    18553172, /* 41561 ( 891) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    52569932, /* 41562 ( 891) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    18544586, /* 41563 ( 891) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    18549284, /* 41564 ( 891) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    52556972, /* 41565 ( 891) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    52561022, /* 41566 ( 891) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 6,  6,  6] -1 */
       11786, /* 41567 ( 891) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  0]  1 */
        7898, /* 41568 ( 891) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34024496, /* 41569 ( 891) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 0,  0,  0] -1 */
       16484, /* 41570 ( 892) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    52447298, /* 41571 ( 892) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 6,  6,  0] -1 */
    52451996, /* 41572 ( 892) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
    52443410, /* 41573 ( 892) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 6,  6,  0] -1 */
    52451834, /* 41574 ( 892) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
    34142108, /* 41575 ( 892) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    52438874, /* 41576 ( 892) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
    34146644, /* 41577 ( 892) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    34138220, /* 41578 ( 892) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    34146806, /* 41579 ( 892) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    34133684, /* 41580 ( 892) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    52438712, /* 41581 ( 892) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
    52447784, /* 41582 ( 892) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 6,  6,  0] -1 */
    18557870, /* 41583 ( 892) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    34133522, /* 41584 ( 892) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    34142594, /* 41585 ( 892) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    18553172, /* 41586 ( 892) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    52442924, /* 41587 ( 892) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 6,  6,  0] -1 */
    34137734, /* 41588 ( 892) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    18549284, /* 41589 ( 892) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 6,  6,  6]  1 */
       11786, /* 41590 ( 892) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    18557708, /* 41591 ( 892) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
        7898, /* 41592 ( 892) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    18544748, /* 41593 ( 892) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    18553658, /* 41594 ( 892) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 6,  6,  6]  1 */
       16322, /* 41595 ( 892) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
        3200, /* 41596 ( 892) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
        3362, /* 41597 ( 892) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
       12272, /* 41598 ( 892) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 0,  0,  0]  1 */
        7412, /* 41599 ( 892) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    18544586, /* 41600 ( 892) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    18548798, /* 41601 ( 892) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 6,  6,  6]  1 */
       16484, /* 41602 ( 893) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
      121460, /* 41603 ( 893) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6]  1 */
    18557870, /* 41604 ( 893) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    18435560, /* 41605 ( 893) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 6,  6,  0]  1 */
        3200, /* 41606 ( 893) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    18439610, /* 41607 ( 893) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    18553172, /* 41608 ( 893) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    18426650, /* 41609 ( 893) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    18544586, /* 41610 ( 893) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    18430700, /* 41611 ( 893) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    18549284, /* 41612 ( 893) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 6,  6,  6]  1 */
      130370, /* 41613 ( 893) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 0,  0,  6]  1 */
       11786, /* 41614 ( 893) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  0]  1 */
      134420, /* 41615 ( 893) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6]  1 */
        7898, /* 41616 ( 893) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 0,  0,  0]  1 */
      125510, /* 41617 ( 893) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  6]  1 */
       16484, /* 41618 ( 894) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    52570094, /* 41619 ( 894) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    52451834, /* 41620 ( 894) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
    52565396, /* 41621 ( 894) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    52561508, /* 41622 ( 894) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    34024010, /* 41623 ( 894) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    52438874, /* 41624 ( 894) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
    34146644, /* 41625 ( 894) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    34020122, /* 41626 ( 894) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    34133684, /* 41627 ( 894) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    34015424, /* 41628 ( 894) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    34028708, /* 41629 ( 894) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    52447784, /* 41630 ( 894) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 6,  6,  0] -1 */
    18557870, /* 41631 ( 894) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    52556810, /* 41632 ( 894) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    34142594, /* 41633 ( 894) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    18439610, /* 41634 ( 894) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    18553172, /* 41635 ( 894) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    52442924, /* 41636 ( 894) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 6,  6,  0] -1 */
    18426650, /* 41637 ( 894) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    34137734, /* 41638 ( 894) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    18549284, /* 41639 ( 894) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 6,  6,  6]  1 */
       11786, /* 41640 ( 894) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  0]  1 */
      134420, /* 41641 ( 894) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6]  1 */
        7898, /* 41642 ( 894) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 0,  0,  0]  1 */
      121460, /* 41643 ( 894) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6]  1 */
    18435560, /* 41644 ( 894) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 6,  6,  0]  1 */
        3200, /* 41645 ( 894) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    18430700, /* 41646 ( 894) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    18544586, /* 41647 ( 894) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
      130370, /* 41648 ( 894) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 0,  0,  6]  1 */
      125510, /* 41649 ( 894) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  6]  1 */
       16484, /* 41650 ( 895) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    52451834, /* 41651 ( 895) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
    52565396, /* 41652 ( 895) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    18557870, /* 41653 ( 895) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    18435560, /* 41654 ( 895) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 6,  6,  0]  1 */
        3200, /* 41655 ( 895) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    52561508, /* 41656 ( 895) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    34024010, /* 41657 ( 895) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    52438874, /* 41658 ( 895) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
    34146644, /* 41659 ( 895) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    18430700, /* 41660 ( 895) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    18544586, /* 41661 ( 895) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    34020122, /* 41662 ( 895) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    34133684, /* 41663 ( 895) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
      130370, /* 41664 ( 895) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 0,  0,  6]  1 */
      125510, /* 41665 ( 895) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  6]  1 */
       16484, /* 41666 ( 896) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
      121460, /* 41667 ( 896) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6]  1 */
    18557870, /* 41668 ( 896) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    52565396, /* 41669 ( 896) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 6,  6,  6] -1 */
        3200, /* 41670 ( 896) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    52561508, /* 41671 ( 896) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    34142594, /* 41672 ( 896) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    34024010, /* 41673 ( 896) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    52442924, /* 41674 ( 896) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 6,  6,  0] -1 */
    18439610, /* 41675 ( 896) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    18426650, /* 41676 ( 896) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    18544586, /* 41677 ( 896) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    34020122, /* 41678 ( 896) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    34137734, /* 41679 ( 896) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  6] -1 */
      134420, /* 41680 ( 896) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6]  1 */
    52447784, /* 41681 ( 896) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 6,  6,  0] -1 */
       16484, /* 41682 ( 897) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    52451834, /* 41683 ( 897) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
    18557870, /* 41684 ( 897) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
        3200, /* 41685 ( 897) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34142594, /* 41686 ( 897) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    18553172, /* 41687 ( 897) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    52438874, /* 41688 ( 897) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
    52442924, /* 41689 ( 897) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 6,  6,  0] -1 */
    34146644, /* 41690 ( 897) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    18544586, /* 41691 ( 897) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    34133684, /* 41692 ( 897) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    18549284, /* 41693 ( 897) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    34137734, /* 41694 ( 897) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  6] -1 */
       11786, /* 41695 ( 897) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  0]  1 */
        7898, /* 41696 ( 897) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    52447784, /* 41697 ( 897) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 6,  6,  0] -1 */
       16484, /* 41698 ( 898) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    52447298, /* 41699 ( 898) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 6,  6,  0] -1 */
    52451996, /* 41700 ( 898) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
    52443410, /* 41701 ( 898) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 6,  6,  0] -1 */
    34142108, /* 41702 ( 898) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    52569932, /* 41703 ( 898) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    34138220, /* 41704 ( 898) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    34146806, /* 41705 ( 898) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    52556972, /* 41706 ( 898) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    52565882, /* 41707 ( 898) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    34028546, /* 41708 ( 898) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    52438712, /* 41709 ( 898) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
    34024496, /* 41710 ( 898) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    34015586, /* 41711 ( 898) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    18557870, /* 41712 ( 898) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    34133522, /* 41713 ( 898) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    18439610, /* 41714 ( 898) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    34019636, /* 41715 ( 898) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    18553172, /* 41716 ( 898) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    18426650, /* 41717 ( 898) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    18549284, /* 41718 ( 898) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 6,  6,  6]  1 */
       11786, /* 41719 ( 898) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    52561022, /* 41720 ( 898) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 6,  6,  6] -1 */
      134420, /* 41721 ( 898) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6]  1 */
        7898, /* 41722 ( 898) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 0,  0,  0]  1 */
      121460, /* 41723 ( 898) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6]  1 */
    18435560, /* 41724 ( 898) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 6,  6,  0]  1 */
        3200, /* 41725 ( 898) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    18430700, /* 41726 ( 898) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    18544586, /* 41727 ( 898) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
      130370, /* 41728 ( 898) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 0,  0,  6]  1 */
      125510, /* 41729 ( 898) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  6]  1 */
       16484, /* 41730 ( 899) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    18557870, /* 41731 ( 899) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
     1488011, /* 41732 ( 899) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 0,  6,  3]  1 */
     1483637, /* 41733 ( 899) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 0,  6,  3]  1 */
     1488497, /* 41734 ( 899) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 0,  6,  3]  1 */
        3362, /* 41735 ( 899) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
        3200, /* 41736 ( 899) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    17191157, /* 41737 ( 899) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 6,  0,  9]  1 */
    18544586, /* 41738 ( 899) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
     1484123, /* 41739 ( 899) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 0,  6,  3]  1 */
    17195045, /* 41740 ( 899) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 6,  0,  9]  1 */
    18557708, /* 41741 ( 899) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    17190671, /* 41742 ( 899) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 6,  0,  9]  1 */
    17195531, /* 41743 ( 899) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 6,  0,  9]  1 */
    18544748, /* 41744 ( 899) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
       16322, /* 41745 ( 899) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
       16484, /* 41746 ( 900) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    51203381, /* 41747 ( 900) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 6,  0,  9] -1 */
    51207269, /* 41748 ( 900) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 6,  0,  9] -1 */
    51207755, /* 41749 ( 900) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 6,  0,  9] -1 */
     1484123, /* 41750 ( 900) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 0,  6,  3]  1 */
    52570094, /* 41751 ( 900) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
     1488011, /* 41752 ( 900) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 0,  6,  3]  1 */
     1488497, /* 41753 ( 900) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 0,  6,  3]  1 */
    35495861, /* 41754 ( 900) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 0,  6,  3] -1 */
    17191157, /* 41755 ( 900) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 6,  0,  9]  1 */
    51202895, /* 41756 ( 900) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 6,  0,  9] -1 */
    52569932, /* 41757 ( 900) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    52556972, /* 41758 ( 900) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    17195045, /* 41759 ( 900) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 6,  0,  9]  1 */
    34015424, /* 41760 ( 900) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    34028708, /* 41761 ( 900) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    17195531, /* 41762 ( 900) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 6,  0,  9]  1 */
    34028546, /* 41763 ( 900) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    34015586, /* 41764 ( 900) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    18557870, /* 41765 ( 900) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    52556810, /* 41766 ( 900) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
     1483637, /* 41767 ( 900) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 0,  6,  3]  1 */
    18557708, /* 41768 ( 900) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    17190671, /* 41769 ( 900) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 6,  0,  9]  1 */
    18544748, /* 41770 ( 900) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
       16322, /* 41771 ( 900) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
        3200, /* 41772 ( 900) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
        3362, /* 41773 ( 900) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    35496347, /* 41774 ( 900) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 0,  6,  3] -1 */
    18544586, /* 41775 ( 900) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    35500235, /* 41776 ( 900) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 0,  6,  3] -1 */
    35500721, /* 41777 ( 900) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 0,  6,  3] -1 */
       16484, /* 41778 ( 901) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34015586, /* 41779 ( 901) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    18557870, /* 41780 ( 901) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    51203381, /* 41781 ( 901) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 6,  0,  9] -1 */
        3200, /* 41782 ( 901) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
     1488497, /* 41783 ( 901) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 0,  6,  3]  1 */
    51207269, /* 41784 ( 901) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 6,  0,  9] -1 */
    52569932, /* 41785 ( 901) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    35496347, /* 41786 ( 901) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 0,  6,  3] -1 */
    18544586, /* 41787 ( 901) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    52556972, /* 41788 ( 901) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    35500235, /* 41789 ( 901) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 0,  6,  3] -1 */
     1483637, /* 41790 ( 901) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 0,  6,  3]  1 */
    34028546, /* 41791 ( 901) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    17190671, /* 41792 ( 901) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 6,  0,  9]  1 */
    17195531, /* 41793 ( 901) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 6,  0,  9]  1 */
       16484, /* 41794 ( 902) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    18557870, /* 41795 ( 902) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    51203381, /* 41796 ( 902) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 6,  0,  9] -1 */
        3200, /* 41797 ( 902) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
        3362, /* 41798 ( 902) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    35495861, /* 41799 ( 902) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 0,  6,  3] -1 */
    51207269, /* 41800 ( 902) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 6,  0,  9] -1 */
    51202895, /* 41801 ( 902) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 6,  0,  9] -1 */
    51207755, /* 41802 ( 902) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 6,  0,  9] -1 */
    35496347, /* 41803 ( 902) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 0,  6,  3] -1 */
    18544586, /* 41804 ( 902) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    18557708, /* 41805 ( 902) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    35500235, /* 41806 ( 902) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 0,  6,  3] -1 */
    35500721, /* 41807 ( 902) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 0,  6,  3] -1 */
    18544748, /* 41808 ( 902) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
       16322, /* 41809 ( 902) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
       16484, /* 41810 ( 903) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34015586, /* 41811 ( 903) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    18557870, /* 41812 ( 903) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
     1488011, /* 41813 ( 903) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 0,  6,  3]  1 */
    34028546, /* 41814 ( 903) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
        3200, /* 41815 ( 903) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    35495861, /* 41816 ( 903) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 0,  6,  3] -1 */
    17191157, /* 41817 ( 903) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 6,  0,  9]  1 */
    51202895, /* 41818 ( 903) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 6,  0,  9] -1 */
    51207755, /* 41819 ( 903) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 6,  0,  9] -1 */
    52569932, /* 41820 ( 903) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    18544586, /* 41821 ( 903) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    52556972, /* 41822 ( 903) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
     1484123, /* 41823 ( 903) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 0,  6,  3]  1 */
    17195045, /* 41824 ( 903) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 6,  0,  9]  1 */
    35500721, /* 41825 ( 903) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 0,  6,  3] -1 */
       16484, /* 41826 ( 904) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    35618333, /* 41827 ( 904) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 0,  6,  9] -1 */
    51089657, /* 41828 ( 904) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 6,  0,  3] -1 */
    35618819, /* 41829 ( 904) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 0,  6,  9] -1 */
    52451996, /* 41830 ( 904) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
     1484123, /* 41831 ( 904) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 0,  6,  3]  1 */
    52451834, /* 41832 ( 904) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
    35613959, /* 41833 ( 904) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 0,  6,  9] -1 */
     1488011, /* 41834 ( 904) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 0,  6,  3]  1 */
     1488497, /* 41835 ( 904) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 0,  6,  3]  1 */
    52438874, /* 41836 ( 904) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
    17191157, /* 41837 ( 904) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 6,  0,  9]  1 */
    34146644, /* 41838 ( 904) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    51084797, /* 41839 ( 904) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 6,  0,  3] -1 */
    34146806, /* 41840 ( 904) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    34133684, /* 41841 ( 904) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    17195045, /* 41842 ( 904) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 6,  0,  9]  1 */
    52438712, /* 41843 ( 904) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
    17195531, /* 41844 ( 904) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 6,  0,  9]  1 */
    18557870, /* 41845 ( 904) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    34133522, /* 41846 ( 904) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
     1483637, /* 41847 ( 904) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 0,  6,  3]  1 */
    18557708, /* 41848 ( 904) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    17190671, /* 41849 ( 904) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 6,  0,  9]  1 */
    18544748, /* 41850 ( 904) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
       16322, /* 41851 ( 904) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
        3200, /* 41852 ( 904) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
        3362, /* 41853 ( 904) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    18544586, /* 41854 ( 904) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    51085283, /* 41855 ( 904) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 6,  0,  3] -1 */
    35614445, /* 41856 ( 904) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 0,  6,  9] -1 */
    51089171, /* 41857 ( 904) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 6,  0,  3] -1 */
       16484, /* 41858 ( 905) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    17072573, /* 41859 ( 905) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 6,  0,  3]  1 */
      121460, /* 41860 ( 905) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6]  1 */
    18557870, /* 41861 ( 905) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
     1488011, /* 41862 ( 905) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 0,  6,  3]  1 */
        3200, /* 41863 ( 905) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    18439610, /* 41864 ( 905) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
     1601735, /* 41865 ( 905) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 0,  6,  9]  1 */
    17191157, /* 41866 ( 905) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 6,  0,  9]  1 */
      134420, /* 41867 ( 905) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6]  1 */
    17077433, /* 41868 ( 905) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 6,  0,  3]  1 */
    18426650, /* 41869 ( 905) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    18544586, /* 41870 ( 905) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
     1606595, /* 41871 ( 905) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 0,  6,  9]  1 */
     1484123, /* 41872 ( 905) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 0,  6,  3]  1 */
    17195045, /* 41873 ( 905) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 6,  0,  9]  1 */
       16484, /* 41874 ( 906) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    51089657, /* 41875 ( 906) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 6,  0,  3] -1 */
    51203381, /* 41876 ( 906) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 6,  0,  9] -1 */
    35618819, /* 41877 ( 906) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 0,  6,  9] -1 */
    51207269, /* 41878 ( 906) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 6,  0,  9] -1 */
     1484123, /* 41879 ( 906) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 0,  6,  3]  1 */
    52570094, /* 41880 ( 906) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    52451834, /* 41881 ( 906) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
    35613959, /* 41882 ( 906) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 0,  6,  9] -1 */
     1488011, /* 41883 ( 906) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 0,  6,  3]  1 */
    52438874, /* 41884 ( 906) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
    17191157, /* 41885 ( 906) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 6,  0,  9]  1 */
    34146644, /* 41886 ( 906) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    17077433, /* 41887 ( 906) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 6,  0,  3]  1 */
     1606595, /* 41888 ( 906) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 0,  6,  9]  1 */
    51084797, /* 41889 ( 906) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 6,  0,  3] -1 */
    34133684, /* 41890 ( 906) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    17195045, /* 41891 ( 906) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 6,  0,  9]  1 */
    34015424, /* 41892 ( 906) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    34028708, /* 41893 ( 906) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    18557870, /* 41894 ( 906) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    52556810, /* 41895 ( 906) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    18439610, /* 41896 ( 906) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
     1601735, /* 41897 ( 906) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 0,  6,  9]  1 */
    18426650, /* 41898 ( 906) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
      134420, /* 41899 ( 906) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6]  1 */
    17072573, /* 41900 ( 906) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 6,  0,  3]  1 */
      121460, /* 41901 ( 906) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6]  1 */
        3200, /* 41902 ( 906) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    35496347, /* 41903 ( 906) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 0,  6,  3] -1 */
    18544586, /* 41904 ( 906) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    35500235, /* 41905 ( 906) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 0,  6,  3] -1 */
       16484, /* 41906 ( 907) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    17072573, /* 41907 ( 907) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 6,  0,  3]  1 */
    52451834, /* 41908 ( 907) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
    18557870, /* 41909 ( 907) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    51203381, /* 41910 ( 907) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 6,  0,  9] -1 */
        3200, /* 41911 ( 907) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    52438874, /* 41912 ( 907) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
     1601735, /* 41913 ( 907) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 0,  6,  9]  1 */
    51207269, /* 41914 ( 907) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 6,  0,  9] -1 */
    34146644, /* 41915 ( 907) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    35496347, /* 41916 ( 907) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 0,  6,  3] -1 */
    17077433, /* 41917 ( 907) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 6,  0,  3]  1 */
    18544586, /* 41918 ( 907) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
     1606595, /* 41919 ( 907) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 0,  6,  9]  1 */
    34133684, /* 41920 ( 907) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    35500235, /* 41921 ( 907) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 0,  6,  3] -1 */
       16484, /* 41922 ( 908) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
      121460, /* 41923 ( 908) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6]  1 */
    18557870, /* 41924 ( 908) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    51203381, /* 41925 ( 908) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 6,  0,  9] -1 */
    35613959, /* 41926 ( 908) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 0,  6,  9] -1 */
    35618819, /* 41927 ( 908) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 0,  6,  9] -1 */
        3200, /* 41928 ( 908) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    51089657, /* 41929 ( 908) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 6,  0,  3] -1 */
    18439610, /* 41930 ( 908) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    51207269, /* 41931 ( 908) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 6,  0,  9] -1 */
    35496347, /* 41932 ( 908) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 0,  6,  3] -1 */
    18426650, /* 41933 ( 908) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    18544586, /* 41934 ( 908) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    51084797, /* 41935 ( 908) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 6,  0,  3] -1 */
    35500235, /* 41936 ( 908) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 0,  6,  3] -1 */
      134420, /* 41937 ( 908) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6]  1 */
       16484, /* 41938 ( 909) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    52451834, /* 41939 ( 909) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
    51089657, /* 41940 ( 909) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 6,  0,  3] -1 */
    18557870, /* 41941 ( 909) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    35613959, /* 41942 ( 909) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 0,  6,  9] -1 */
    35618819, /* 41943 ( 909) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 0,  6,  9] -1 */
        3200, /* 41944 ( 909) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
     1488011, /* 41945 ( 909) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 0,  6,  3]  1 */
    52438874, /* 41946 ( 909) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
    17191157, /* 41947 ( 909) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 6,  0,  9]  1 */
    34146644, /* 41948 ( 909) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    18544586, /* 41949 ( 909) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    51084797, /* 41950 ( 909) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 6,  0,  3] -1 */
    34133684, /* 41951 ( 909) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
     1484123, /* 41952 ( 909) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 0,  6,  3]  1 */
    17195045, /* 41953 ( 909) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 6,  0,  9]  1 */
       16484, /* 41954 ( 910) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    35618333, /* 41955 ( 910) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 0,  6,  9] -1 */
    51207755, /* 41956 ( 910) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 6,  0,  9] -1 */
    52451996, /* 41957 ( 910) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
     1484123, /* 41958 ( 910) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 0,  6,  3]  1 */
     1488011, /* 41959 ( 910) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 0,  6,  3]  1 */
    35495861, /* 41960 ( 910) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 0,  6,  3] -1 */
    17191157, /* 41961 ( 910) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 6,  0,  9]  1 */
    51202895, /* 41962 ( 910) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 6,  0,  9] -1 */
    52569932, /* 41963 ( 910) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    17077433, /* 41964 ( 910) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 6,  0,  3]  1 */
     1606595, /* 41965 ( 910) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 0,  6,  9]  1 */
    34146806, /* 41966 ( 910) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    52556972, /* 41967 ( 910) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    17195045, /* 41968 ( 910) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 6,  0,  9]  1 */
    52438712, /* 41969 ( 910) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
    34028546, /* 41970 ( 910) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    34015586, /* 41971 ( 910) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    18557870, /* 41972 ( 910) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    34133522, /* 41973 ( 910) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    18439610, /* 41974 ( 910) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
     1601735, /* 41975 ( 910) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 0,  6,  9]  1 */
    18426650, /* 41976 ( 910) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
      134420, /* 41977 ( 910) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6]  1 */
    17072573, /* 41978 ( 910) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 6,  0,  3]  1 */
      121460, /* 41979 ( 910) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6]  1 */
    35500721, /* 41980 ( 910) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 0,  6,  3] -1 */
        3200, /* 41981 ( 910) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    18544586, /* 41982 ( 910) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    51085283, /* 41983 ( 910) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 6,  0,  3] -1 */
    35614445, /* 41984 ( 910) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 0,  6,  9] -1 */
    51089171, /* 41985 ( 910) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 6,  0,  3] -1 */
       16484, /* 41986 ( 911) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
        3200, /* 41987 ( 911) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
       11784, /* 41988 ( 911) [ 0,  1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  0]  1 */
       12272, /* 41989 ( 911) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 0,  0,  0]  1 */
       16320, /* 41990 ( 911) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
        7896, /* 41991 ( 911) [ 0, -1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  0]  1 */
        7412, /* 41992 ( 911) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  0]  1 */
        3360, /* 41993 ( 911) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
       16484, /* 41994 ( 912) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34024008, /* 41995 ( 912) [ 0,  1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    34020120, /* 41996 ( 912) [ 0, -1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  0] -1 */
        3200, /* 41997 ( 912) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
       11784, /* 41998 ( 912) [ 0,  1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  0]  1 */
       12272, /* 41999 ( 912) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 0,  0,  0]  1 */
       16320, /* 42000 ( 912) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
        7896, /* 42001 ( 912) [ 0, -1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    34019636, /* 42002 ( 912) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    34015584, /* 42003 ( 912) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
        7412, /* 42004 ( 912) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34015424, /* 42005 ( 912) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
        3360, /* 42006 ( 912) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    34028708, /* 42007 ( 912) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    34024496, /* 42008 ( 912) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    34028544, /* 42009 ( 912) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
       16484, /* 42010 ( 913) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34024008, /* 42011 ( 913) [ 0,  1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    34020120, /* 42012 ( 913) [ 0, -1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  0] -1 */
        3200, /* 42013 ( 913) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
       12272, /* 42014 ( 913) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34015584, /* 42015 ( 913) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
        7412, /* 42016 ( 913) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34028544, /* 42017 ( 913) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
       16484, /* 42018 ( 914) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34024008, /* 42019 ( 914) [ 0,  1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    34020120, /* 42020 ( 914) [ 0, -1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  0] -1 */
        3200, /* 42021 ( 914) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34019636, /* 42022 ( 914) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  0] -1 */
       16320, /* 42023 ( 914) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
        3360, /* 42024 ( 914) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    34024496, /* 42025 ( 914) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 0,  0,  0] -1 */
       16484, /* 42026 ( 915) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
        3200, /* 42027 ( 915) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
       11784, /* 42028 ( 915) [ 0,  1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    34019636, /* 42029 ( 915) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  0] -1 */
        7896, /* 42030 ( 915) [ 0, -1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    34015584, /* 42031 ( 915) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    34024496, /* 42032 ( 915) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    34028544, /* 42033 ( 915) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
       16484, /* 42034 ( 916) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34133522, /* 42035 ( 916) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
        3200, /* 42036 ( 916) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34142594, /* 42037 ( 916) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 0,  0,  6] -1 */
       11784, /* 42038 ( 916) [ 0,  1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  0]  1 */
       12272, /* 42039 ( 916) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 0,  0,  0]  1 */
       16320, /* 42040 ( 916) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
        7896, /* 42041 ( 916) [ 0, -1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    34142106, /* 42042 ( 916) [ 0,  1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  6] -1 */
    34138218, /* 42043 ( 916) [ 0, -1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  6] -1 */
        7412, /* 42044 ( 916) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34146806, /* 42045 ( 916) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    34137734, /* 42046 ( 916) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    34133682, /* 42047 ( 916) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
    34146642, /* 42048 ( 916) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
        3360, /* 42049 ( 916) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
       16484, /* 42050 ( 917) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    52438712, /* 42051 ( 917) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
        3200, /* 42052 ( 917) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
       11784, /* 42053 ( 917) [ 0,  1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  0]  1 */
       12272, /* 42054 ( 917) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 0,  0,  0]  1 */
       16320, /* 42055 ( 917) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
        7896, /* 42056 ( 917) [ 0, -1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    52442924, /* 42057 ( 917) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 6,  6,  0] -1 */
    52443408, /* 42058 ( 917) [ 0, -1,  0,  1,  0,  0,  0,  0, -1] [ 6,  6,  0] -1 */
        7412, /* 42059 ( 917) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    52451996, /* 42060 ( 917) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
        3360, /* 42061 ( 917) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    52438872, /* 42062 ( 917) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
    52447296, /* 42063 ( 917) [ 0,  1,  0, -1,  0,  0,  0,  0, -1] [ 6,  6,  0] -1 */
    52447784, /* 42064 ( 917) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 6,  6,  0] -1 */
    52451832, /* 42065 ( 917) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
       16484, /* 42066 ( 918) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    52556810, /* 42067 ( 918) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
        3200, /* 42068 ( 918) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    52561506, /* 42069 ( 918) [ 0, -1,  0,  1,  0,  0,  0,  0, -1] [ 6,  6,  6] -1 */
       11784, /* 42070 ( 918) [ 0,  1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  0]  1 */
       12272, /* 42071 ( 918) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 0,  0,  0]  1 */
       16320, /* 42072 ( 918) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
        7896, /* 42073 ( 918) [ 0, -1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  0]  1 */
        7412, /* 42074 ( 918) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    52556970, /* 42075 ( 918) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    52561022, /* 42076 ( 918) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    52565394, /* 42077 ( 918) [ 0,  1,  0, -1,  0,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    52565882, /* 42078 ( 918) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    52569930, /* 42079 ( 918) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
        3360, /* 42080 ( 918) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    52570094, /* 42081 ( 918) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
       16484, /* 42082 ( 919) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
      121458, /* 42083 ( 919) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  6]  1 */
      134418, /* 42084 ( 919) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  6]  1 */
        3200, /* 42085 ( 919) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
       11784, /* 42086 ( 919) [ 0,  1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  0]  1 */
        7896, /* 42087 ( 919) [ 0, -1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  0]  1 */
      130370, /* 42088 ( 919) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 0,  0,  6]  1 */
      125510, /* 42089 ( 919) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  6]  1 */
       16484, /* 42090 ( 920) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34024008, /* 42091 ( 920) [ 0,  1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  0] -1 */
      121458, /* 42092 ( 920) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  6]  1 */
      134418, /* 42093 ( 920) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  6]  1 */
        3200, /* 42094 ( 920) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34142594, /* 42095 ( 920) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    34020120, /* 42096 ( 920) [ 0, -1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  0] -1 */
       11784, /* 42097 ( 920) [ 0,  1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  0]  1 */
        7896, /* 42098 ( 920) [ 0, -1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    34137734, /* 42099 ( 920) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  6] -1 */
      130370, /* 42100 ( 920) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 0,  0,  6]  1 */
    34133682, /* 42101 ( 920) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
    34146642, /* 42102 ( 920) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
    34015424, /* 42103 ( 920) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    34028708, /* 42104 ( 920) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
      125510, /* 42105 ( 920) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  6]  1 */
       16484, /* 42106 ( 921) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34024008, /* 42107 ( 921) [ 0,  1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    34020120, /* 42108 ( 921) [ 0, -1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  0] -1 */
        3200, /* 42109 ( 921) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
      130370, /* 42110 ( 921) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 0,  0,  6]  1 */
    34133682, /* 42111 ( 921) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
    34146642, /* 42112 ( 921) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
      125510, /* 42113 ( 921) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  6]  1 */
       16484, /* 42114 ( 922) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34024008, /* 42115 ( 922) [ 0,  1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    34020120, /* 42116 ( 922) [ 0, -1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  0] -1 */
      134418, /* 42117 ( 922) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  6]  1 */
        3200, /* 42118 ( 922) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34142594, /* 42119 ( 922) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 0,  0,  6] -1 */
      121458, /* 42120 ( 922) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  6]  1 */
    34137734, /* 42121 ( 922) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  6] -1 */
       16484, /* 42122 ( 923) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
        3200, /* 42123 ( 923) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34142594, /* 42124 ( 923) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 0,  0,  6] -1 */
       11784, /* 42125 ( 923) [ 0,  1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  0]  1 */
        7896, /* 42126 ( 923) [ 0, -1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    34137734, /* 42127 ( 923) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    34133682, /* 42128 ( 923) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
    34146642, /* 42129 ( 923) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
       16484, /* 42130 ( 924) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34133522, /* 42131 ( 924) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
      121458, /* 42132 ( 924) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  6]  1 */
      134418, /* 42133 ( 924) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  6]  1 */
        3200, /* 42134 ( 924) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
       11784, /* 42135 ( 924) [ 0,  1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    34019636, /* 42136 ( 924) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  0] -1 */
        7896, /* 42137 ( 924) [ 0, -1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    34015584, /* 42138 ( 924) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    34142106, /* 42139 ( 924) [ 0,  1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  6] -1 */
    34138218, /* 42140 ( 924) [ 0, -1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  6] -1 */
    34146806, /* 42141 ( 924) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
      130370, /* 42142 ( 924) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 0,  0,  6]  1 */
      125510, /* 42143 ( 924) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  6]  1 */
    34024496, /* 42144 ( 924) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    34028544, /* 42145 ( 924) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
       16484, /* 42146 ( 925) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
      121458, /* 42147 ( 925) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  6]  1 */
      134418, /* 42148 ( 925) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  6]  1 */
        3200, /* 42149 ( 925) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
       11784, /* 42150 ( 925) [ 0,  1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  0]  1 */
        7896, /* 42151 ( 925) [ 0, -1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    52443408, /* 42152 ( 925) [ 0, -1,  0,  1,  0,  0,  0,  0, -1] [ 6,  6,  0] -1 */
    52451996, /* 42153 ( 925) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
    52556970, /* 42154 ( 925) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
      130370, /* 42155 ( 925) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 0,  0,  6]  1 */
    52561022, /* 42156 ( 925) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    52565882, /* 42157 ( 925) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    52569930, /* 42158 ( 925) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    52438712, /* 42159 ( 925) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
      125510, /* 42160 ( 925) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  6]  1 */
    52447296, /* 42161 ( 925) [ 0,  1,  0, -1,  0,  0,  0,  0, -1] [ 6,  6,  0] -1 */
       16484, /* 42162 ( 926) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
      121458, /* 42163 ( 926) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  6]  1 */
      134418, /* 42164 ( 926) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  6]  1 */
        3200, /* 42165 ( 926) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    52556810, /* 42166 ( 926) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    52561506, /* 42167 ( 926) [ 0, -1,  0,  1,  0,  0,  0,  0, -1] [ 6,  6,  6] -1 */
       11784, /* 42168 ( 926) [ 0,  1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    52442924, /* 42169 ( 926) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 6,  6,  0] -1 */
        7896, /* 42170 ( 926) [ 0, -1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  0]  1 */
      130370, /* 42171 ( 926) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 0,  0,  6]  1 */
    52565394, /* 42172 ( 926) [ 0,  1,  0, -1,  0,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    52438872, /* 42173 ( 926) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
      125510, /* 42174 ( 926) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  6]  1 */
    52570094, /* 42175 ( 926) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    52447784, /* 42176 ( 926) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 6,  6,  0] -1 */
    52451832, /* 42177 ( 926) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
       16484, /* 42178 ( 927) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    18426648, /* 42179 ( 927) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
    18435560, /* 42180 ( 927) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    18439608, /* 42181 ( 927) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
        3200, /* 42182 ( 927) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
       11784, /* 42183 ( 927) [ 0,  1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  0]  1 */
        7896, /* 42184 ( 927) [ 0, -1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    18430700, /* 42185 ( 927) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 6,  6,  0]  1 */
       16484, /* 42186 ( 928) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34024008, /* 42187 ( 928) [ 0,  1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    18426648, /* 42188 ( 928) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
    18435560, /* 42189 ( 928) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    18439608, /* 42190 ( 928) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
        3200, /* 42191 ( 928) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34020120, /* 42192 ( 928) [ 0, -1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  0] -1 */
       11784, /* 42193 ( 928) [ 0,  1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    52442924, /* 42194 ( 928) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 6,  6,  0] -1 */
        7896, /* 42195 ( 928) [ 0, -1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    52438872, /* 42196 ( 928) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
    18430700, /* 42197 ( 928) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    34015424, /* 42198 ( 928) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    34028708, /* 42199 ( 928) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    52447784, /* 42200 ( 928) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 6,  6,  0] -1 */
    52451832, /* 42201 ( 928) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
       16484, /* 42202 ( 929) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34024008, /* 42203 ( 929) [ 0,  1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    18435560, /* 42204 ( 929) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    34020120, /* 42205 ( 929) [ 0, -1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  0] -1 */
        3200, /* 42206 ( 929) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    18430700, /* 42207 ( 929) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    52438872, /* 42208 ( 929) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
    52451832, /* 42209 ( 929) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
       16484, /* 42210 ( 930) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34024008, /* 42211 ( 930) [ 0,  1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    18426648, /* 42212 ( 930) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
    34020120, /* 42213 ( 930) [ 0, -1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    18439608, /* 42214 ( 930) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
        3200, /* 42215 ( 930) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    52442924, /* 42216 ( 930) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 6,  6,  0] -1 */
    52447784, /* 42217 ( 930) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 6,  6,  0] -1 */
       16484, /* 42218 ( 931) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
        3200, /* 42219 ( 931) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
       11784, /* 42220 ( 931) [ 0,  1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    52442924, /* 42221 ( 931) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 6,  6,  0] -1 */
        7896, /* 42222 ( 931) [ 0, -1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    52438872, /* 42223 ( 931) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
    52447784, /* 42224 ( 931) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 6,  6,  0] -1 */
    52451832, /* 42225 ( 931) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
       16484, /* 42226 ( 932) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    18426648, /* 42227 ( 932) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
    34133522, /* 42228 ( 932) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    18435560, /* 42229 ( 932) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    18439608, /* 42230 ( 932) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
        3200, /* 42231 ( 932) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
       11784, /* 42232 ( 932) [ 0,  1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  0]  1 */
        7896, /* 42233 ( 932) [ 0, -1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    34142106, /* 42234 ( 932) [ 0,  1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  6] -1 */
    34138218, /* 42235 ( 932) [ 0, -1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  6] -1 */
    18430700, /* 42236 ( 932) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    34146806, /* 42237 ( 932) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    52561022, /* 42238 ( 932) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    52556970, /* 42239 ( 932) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    52565882, /* 42240 ( 932) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    52569930, /* 42241 ( 932) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
       16484, /* 42242 ( 933) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    18426648, /* 42243 ( 933) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
    18435560, /* 42244 ( 933) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    18439608, /* 42245 ( 933) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
        3200, /* 42246 ( 933) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
       11784, /* 42247 ( 933) [ 0,  1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    34019636, /* 42248 ( 933) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  0] -1 */
        7896, /* 42249 ( 933) [ 0, -1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    52443408, /* 42250 ( 933) [ 0, -1,  0,  1,  0,  0,  0,  0, -1] [ 6,  6,  0] -1 */
    34015584, /* 42251 ( 933) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    34024496, /* 42252 ( 933) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    52451996, /* 42253 ( 933) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
    18430700, /* 42254 ( 933) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    52438712, /* 42255 ( 933) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
    52447296, /* 42256 ( 933) [ 0,  1,  0, -1,  0,  0,  0,  0, -1] [ 6,  6,  0] -1 */
    34028544, /* 42257 ( 933) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
       16484, /* 42258 ( 934) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    18426648, /* 42259 ( 934) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
    18435560, /* 42260 ( 934) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    18439608, /* 42261 ( 934) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
        3200, /* 42262 ( 934) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    52556810, /* 42263 ( 934) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    34142594, /* 42264 ( 934) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 0,  0,  6] -1 */
       11784, /* 42265 ( 934) [ 0,  1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    52561506, /* 42266 ( 934) [ 0, -1,  0,  1,  0,  0,  0,  0, -1] [ 6,  6,  6] -1 */
        7896, /* 42267 ( 934) [ 0, -1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    18430700, /* 42268 ( 934) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    34137734, /* 42269 ( 934) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    52565394, /* 42270 ( 934) [ 0,  1,  0, -1,  0,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    34146642, /* 42271 ( 934) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
    34133682, /* 42272 ( 934) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
    52570094, /* 42273 ( 934) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
       16484, /* 42274 ( 935) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
        3200, /* 42275 ( 935) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
       11784, /* 42276 ( 935) [ 0,  1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  0]  1 */
        7896, /* 42277 ( 935) [ 0, -1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    18544746, /* 42278 ( 935) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
    18548798, /* 42279 ( 935) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    18553658, /* 42280 ( 935) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    18557706, /* 42281 ( 935) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
       16484, /* 42282 ( 936) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34024008, /* 42283 ( 936) [ 0,  1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    34015424, /* 42284 ( 936) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    34020120, /* 42285 ( 936) [ 0, -1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  0] -1 */
        3200, /* 42286 ( 936) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
       11784, /* 42287 ( 936) [ 0,  1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  0]  1 */
        7896, /* 42288 ( 936) [ 0, -1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    52556970, /* 42289 ( 936) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    52561022, /* 42290 ( 936) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    52565882, /* 42291 ( 936) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    52569930, /* 42292 ( 936) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    34028708, /* 42293 ( 936) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    18544746, /* 42294 ( 936) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
    18548798, /* 42295 ( 936) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    18553658, /* 42296 ( 936) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    18557706, /* 42297 ( 936) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
       16484, /* 42298 ( 937) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34024008, /* 42299 ( 937) [ 0,  1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    34020120, /* 42300 ( 937) [ 0, -1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  0] -1 */
        3200, /* 42301 ( 937) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    52556970, /* 42302 ( 937) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    52569930, /* 42303 ( 937) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    18548798, /* 42304 ( 937) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    18553658, /* 42305 ( 937) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 6,  6,  6]  1 */
       16484, /* 42306 ( 938) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34024008, /* 42307 ( 938) [ 0,  1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    34020120, /* 42308 ( 938) [ 0, -1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  0] -1 */
        3200, /* 42309 ( 938) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    52561022, /* 42310 ( 938) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    52565882, /* 42311 ( 938) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    18544746, /* 42312 ( 938) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
    18557706, /* 42313 ( 938) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
       16484, /* 42314 ( 939) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
        3200, /* 42315 ( 939) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
       11784, /* 42316 ( 939) [ 0,  1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  0]  1 */
        7896, /* 42317 ( 939) [ 0, -1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    52556970, /* 42318 ( 939) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    52561022, /* 42319 ( 939) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    52565882, /* 42320 ( 939) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    52569930, /* 42321 ( 939) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
       16484, /* 42322 ( 940) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34133522, /* 42323 ( 940) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
        3200, /* 42324 ( 940) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
       11784, /* 42325 ( 940) [ 0,  1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    52442924, /* 42326 ( 940) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 6,  6,  0] -1 */
        7896, /* 42327 ( 940) [ 0, -1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    34142106, /* 42328 ( 940) [ 0,  1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  6] -1 */
    52451832, /* 42329 ( 940) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
    34138218, /* 42330 ( 940) [ 0, -1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  6] -1 */
    34146806, /* 42331 ( 940) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    52438872, /* 42332 ( 940) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
    18544746, /* 42333 ( 940) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
    18548798, /* 42334 ( 940) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    52447784, /* 42335 ( 940) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 6,  6,  0] -1 */
    18553658, /* 42336 ( 940) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    18557706, /* 42337 ( 940) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
       16484, /* 42338 ( 941) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
        3200, /* 42339 ( 941) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34142594, /* 42340 ( 941) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 0,  0,  6] -1 */
       11784, /* 42341 ( 941) [ 0,  1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  0]  1 */
        7896, /* 42342 ( 941) [ 0, -1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    52443408, /* 42343 ( 941) [ 0, -1,  0,  1,  0,  0,  0,  0, -1] [ 6,  6,  0] -1 */
    52451996, /* 42344 ( 941) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
    34137734, /* 42345 ( 941) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    34133682, /* 42346 ( 941) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
    34146642, /* 42347 ( 941) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
    52438712, /* 42348 ( 941) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
    18544746, /* 42349 ( 941) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
    18548798, /* 42350 ( 941) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    52447296, /* 42351 ( 941) [ 0,  1,  0, -1,  0,  0,  0,  0, -1] [ 6,  6,  0] -1 */
    18553658, /* 42352 ( 941) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    18557706, /* 42353 ( 941) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
       16484, /* 42354 ( 942) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    52556810, /* 42355 ( 942) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
        3200, /* 42356 ( 942) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    52561506, /* 42357 ( 942) [ 0, -1,  0,  1,  0,  0,  0,  0, -1] [ 6,  6,  6] -1 */
       11784, /* 42358 ( 942) [ 0,  1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    34019636, /* 42359 ( 942) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  0] -1 */
        7896, /* 42360 ( 942) [ 0, -1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    34015584, /* 42361 ( 942) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    34024496, /* 42362 ( 942) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    18548798, /* 42363 ( 942) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    52565394, /* 42364 ( 942) [ 0,  1,  0, -1,  0,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    18544746, /* 42365 ( 942) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
    52570094, /* 42366 ( 942) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    34028544, /* 42367 ( 942) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    18553658, /* 42368 ( 942) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    18557706, /* 42369 ( 942) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
       16484, /* 42370 ( 943) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
        3200, /* 42371 ( 943) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
        3362, /* 42372 ( 943) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
       11784, /* 42373 ( 943) [ 0,  1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  0]  1 */
        7896, /* 42374 ( 943) [ 0, -1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  0]  1 */
        7410, /* 42375 ( 943) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  0]  1 */
       12270, /* 42376 ( 943) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  0]  1 */
       16322, /* 42377 ( 943) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
       16484, /* 42378 ( 944) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34024008, /* 42379 ( 944) [ 0,  1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    34015586, /* 42380 ( 944) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    34020120, /* 42381 ( 944) [ 0, -1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    34028546, /* 42382 ( 944) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
        3200, /* 42383 ( 944) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34019634, /* 42384 ( 944) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  0] -1 */
        3362, /* 42385 ( 944) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
       11784, /* 42386 ( 944) [ 0,  1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    34024494, /* 42387 ( 944) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  0] -1 */
        7896, /* 42388 ( 944) [ 0, -1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  0]  1 */
        7410, /* 42389 ( 944) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  0]  1 */
       12270, /* 42390 ( 944) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    34015424, /* 42391 ( 944) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    34028708, /* 42392 ( 944) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
       16322, /* 42393 ( 944) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
       16484, /* 42394 ( 945) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34024008, /* 42395 ( 945) [ 0,  1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    34015586, /* 42396 ( 945) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    34020120, /* 42397 ( 945) [ 0, -1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  0] -1 */
        3200, /* 42398 ( 945) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
        7410, /* 42399 ( 945) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  0]  1 */
       12270, /* 42400 ( 945) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    34028546, /* 42401 ( 945) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
       16484, /* 42402 ( 946) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34024008, /* 42403 ( 946) [ 0,  1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    34020120, /* 42404 ( 946) [ 0, -1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  0] -1 */
        3200, /* 42405 ( 946) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34019634, /* 42406 ( 946) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  0] -1 */
        3362, /* 42407 ( 946) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34024494, /* 42408 ( 946) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  0] -1 */
       16322, /* 42409 ( 946) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
       16484, /* 42410 ( 947) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34015586, /* 42411 ( 947) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
        3200, /* 42412 ( 947) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34019634, /* 42413 ( 947) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    34024494, /* 42414 ( 947) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  0] -1 */
       11784, /* 42415 ( 947) [ 0,  1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  0]  1 */
        7896, /* 42416 ( 947) [ 0, -1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    34028546, /* 42417 ( 947) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
       16484, /* 42418 ( 948) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34142592, /* 42419 ( 948) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  6] -1 */
    34133522, /* 42420 ( 948) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    34137732, /* 42421 ( 948) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  6] -1 */
        3200, /* 42422 ( 948) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
        3362, /* 42423 ( 948) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
       11784, /* 42424 ( 948) [ 0,  1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    34146644, /* 42425 ( 948) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
        7896, /* 42426 ( 948) [ 0, -1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    34142106, /* 42427 ( 948) [ 0,  1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  6] -1 */
        7410, /* 42428 ( 948) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  0]  1 */
       12270, /* 42429 ( 948) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    34138218, /* 42430 ( 948) [ 0, -1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  6] -1 */
    34146806, /* 42431 ( 948) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    34133684, /* 42432 ( 948) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
       16322, /* 42433 ( 948) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
       16484, /* 42434 ( 949) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    52451834, /* 42435 ( 949) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
    52442922, /* 42436 ( 949) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 6,  6,  0] -1 */
        3200, /* 42437 ( 949) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
        3362, /* 42438 ( 949) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
       11784, /* 42439 ( 949) [ 0,  1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    52438874, /* 42440 ( 949) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
        7896, /* 42441 ( 949) [ 0, -1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    52443408, /* 42442 ( 949) [ 0, -1,  0,  1,  0,  0,  0,  0, -1] [ 6,  6,  0] -1 */
        7410, /* 42443 ( 949) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  0]  1 */
       12270, /* 42444 ( 949) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    52451996, /* 42445 ( 949) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
    52447782, /* 42446 ( 949) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 6,  6,  0] -1 */
    52438712, /* 42447 ( 949) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
    52447296, /* 42448 ( 949) [ 0,  1,  0, -1,  0,  0,  0,  0, -1] [ 6,  6,  0] -1 */
       16322, /* 42449 ( 949) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
       16484, /* 42450 ( 950) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    52556810, /* 42451 ( 950) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
        3200, /* 42452 ( 950) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    52561506, /* 42453 ( 950) [ 0, -1,  0,  1,  0,  0,  0,  0, -1] [ 6,  6,  6] -1 */
        3362, /* 42454 ( 950) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
       11784, /* 42455 ( 950) [ 0,  1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  0]  1 */
        7896, /* 42456 ( 950) [ 0, -1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    52565880, /* 42457 ( 950) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    52569932, /* 42458 ( 950) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
        7410, /* 42459 ( 950) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  0]  1 */
       12270, /* 42460 ( 950) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    52556972, /* 42461 ( 950) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    52565394, /* 42462 ( 950) [ 0,  1,  0, -1,  0,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    52561020, /* 42463 ( 950) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    52570094, /* 42464 ( 950) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
       16322, /* 42465 ( 950) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
       16484, /* 42466 ( 951) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
      121460, /* 42467 ( 951) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6]  1 */
        3200, /* 42468 ( 951) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
      125508, /* 42469 ( 951) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  6]  1 */
       11784, /* 42470 ( 951) [ 0,  1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  0]  1 */
      130368, /* 42471 ( 951) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  6]  1 */
        7896, /* 42472 ( 951) [ 0, -1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  0]  1 */
      134420, /* 42473 ( 951) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6]  1 */
       16484, /* 42474 ( 952) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
      121460, /* 42475 ( 952) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6]  1 */
    34024008, /* 42476 ( 952) [ 0,  1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    34142592, /* 42477 ( 952) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  6] -1 */
    34137732, /* 42478 ( 952) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  6] -1 */
        3200, /* 42479 ( 952) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34020120, /* 42480 ( 952) [ 0, -1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  0] -1 */
      125508, /* 42481 ( 952) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  6]  1 */
       11784, /* 42482 ( 952) [ 0,  1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  0]  1 */
      130368, /* 42483 ( 952) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  6]  1 */
        7896, /* 42484 ( 952) [ 0, -1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    34146644, /* 42485 ( 952) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    34133684, /* 42486 ( 952) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
      134420, /* 42487 ( 952) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6]  1 */
    34028708, /* 42488 ( 952) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    34015424, /* 42489 ( 952) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
       16484, /* 42490 ( 953) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34024008, /* 42491 ( 953) [ 0,  1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    34020120, /* 42492 ( 953) [ 0, -1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  0] -1 */
        3200, /* 42493 ( 953) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
      125508, /* 42494 ( 953) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  6]  1 */
      130368, /* 42495 ( 953) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  6]  1 */
    34146644, /* 42496 ( 953) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    34133684, /* 42497 ( 953) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
       16484, /* 42498 ( 954) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34142592, /* 42499 ( 954) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  6] -1 */
    34024008, /* 42500 ( 954) [ 0,  1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  0] -1 */
      121460, /* 42501 ( 954) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6]  1 */
    34137732, /* 42502 ( 954) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  6] -1 */
        3200, /* 42503 ( 954) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34020120, /* 42504 ( 954) [ 0, -1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  0] -1 */
      134420, /* 42505 ( 954) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6]  1 */
       16484, /* 42506 ( 955) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34142592, /* 42507 ( 955) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  6] -1 */
    34137732, /* 42508 ( 955) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  6] -1 */
        3200, /* 42509 ( 955) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
       11784, /* 42510 ( 955) [ 0,  1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    34146644, /* 42511 ( 955) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
        7896, /* 42512 ( 955) [ 0, -1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    34133684, /* 42513 ( 955) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
       16484, /* 42514 ( 956) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
      121460, /* 42515 ( 956) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6]  1 */
    34015586, /* 42516 ( 956) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    34133522, /* 42517 ( 956) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    34028546, /* 42518 ( 956) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
        3200, /* 42519 ( 956) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34019634, /* 42520 ( 956) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  0] -1 */
      125508, /* 42521 ( 956) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  6]  1 */
       11784, /* 42522 ( 956) [ 0,  1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  0]  1 */
      130368, /* 42523 ( 956) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  6]  1 */
        7896, /* 42524 ( 956) [ 0, -1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    34024494, /* 42525 ( 956) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    34142106, /* 42526 ( 956) [ 0,  1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  6] -1 */
    34138218, /* 42527 ( 956) [ 0, -1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  6] -1 */
    34146806, /* 42528 ( 956) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
      134420, /* 42529 ( 956) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6]  1 */
       16484, /* 42530 ( 957) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
      121460, /* 42531 ( 957) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6]  1 */
        3200, /* 42532 ( 957) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
      125508, /* 42533 ( 957) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  6]  1 */
       11784, /* 42534 ( 957) [ 0,  1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  0]  1 */
      130368, /* 42535 ( 957) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  6]  1 */
        7896, /* 42536 ( 957) [ 0, -1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    52565880, /* 42537 ( 957) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    52443408, /* 42538 ( 957) [ 0, -1,  0,  1,  0,  0,  0,  0, -1] [ 6,  6,  0] -1 */
    52569932, /* 42539 ( 957) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    52451996, /* 42540 ( 957) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
    52556972, /* 42541 ( 957) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
      134420, /* 42542 ( 957) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6]  1 */
    52438712, /* 42543 ( 957) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
    52561020, /* 42544 ( 957) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    52447296, /* 42545 ( 957) [ 0,  1,  0, -1,  0,  0,  0,  0, -1] [ 6,  6,  0] -1 */
       16484, /* 42546 ( 958) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    52451834, /* 42547 ( 958) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
      121460, /* 42548 ( 958) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6]  1 */
    52442922, /* 42549 ( 958) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 6,  6,  0] -1 */
    52556810, /* 42550 ( 958) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
        3200, /* 42551 ( 958) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    52561506, /* 42552 ( 958) [ 0, -1,  0,  1,  0,  0,  0,  0, -1] [ 6,  6,  6] -1 */
      125508, /* 42553 ( 958) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  6]  1 */
       11784, /* 42554 ( 958) [ 0,  1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  0]  1 */
      130368, /* 42555 ( 958) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  6]  1 */
    52438874, /* 42556 ( 958) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
        7896, /* 42557 ( 958) [ 0, -1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    52447782, /* 42558 ( 958) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 6,  6,  0] -1 */
    52565394, /* 42559 ( 958) [ 0,  1,  0, -1,  0,  0,  0,  0, -1] [ 6,  6,  6] -1 */
      134420, /* 42560 ( 958) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6]  1 */
    52570094, /* 42561 ( 958) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
       16484, /* 42562 ( 959) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
        3200, /* 42563 ( 959) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    18439610, /* 42564 ( 959) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
       11784, /* 42565 ( 959) [ 0,  1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  0]  1 */
        7896, /* 42566 ( 959) [ 0, -1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    18430698, /* 42567 ( 959) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 6,  6,  0]  1 */
    18426650, /* 42568 ( 959) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    18435558, /* 42569 ( 959) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 6,  6,  0]  1 */
       16484, /* 42570 ( 960) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    52451834, /* 42571 ( 960) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
    34024008, /* 42572 ( 960) [ 0,  1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    52442922, /* 42573 ( 960) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 6,  6,  0] -1 */
    34020120, /* 42574 ( 960) [ 0, -1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  0] -1 */
        3200, /* 42575 ( 960) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    18439610, /* 42576 ( 960) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
       11784, /* 42577 ( 960) [ 0,  1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    52438874, /* 42578 ( 960) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
        7896, /* 42579 ( 960) [ 0, -1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    18430698, /* 42580 ( 960) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 6,  6,  0]  1 */
    18426650, /* 42581 ( 960) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    52447782, /* 42582 ( 960) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 6,  6,  0] -1 */
    34015424, /* 42583 ( 960) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    34028708, /* 42584 ( 960) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    18435558, /* 42585 ( 960) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 6,  6,  0]  1 */
       16484, /* 42586 ( 961) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    52451834, /* 42587 ( 961) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
    34024008, /* 42588 ( 961) [ 0,  1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    34020120, /* 42589 ( 961) [ 0, -1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  0] -1 */
        3200, /* 42590 ( 961) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    52438874, /* 42591 ( 961) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
    18430698, /* 42592 ( 961) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 6,  6,  0]  1 */
    18435558, /* 42593 ( 961) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 6,  6,  0]  1 */
       16484, /* 42594 ( 962) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34024008, /* 42595 ( 962) [ 0,  1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    52442922, /* 42596 ( 962) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 6,  6,  0] -1 */
    34020120, /* 42597 ( 962) [ 0, -1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  0] -1 */
        3200, /* 42598 ( 962) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    18439610, /* 42599 ( 962) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    18426650, /* 42600 ( 962) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    52447782, /* 42601 ( 962) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 6,  6,  0] -1 */
       16484, /* 42602 ( 963) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    52451834, /* 42603 ( 963) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
    52442922, /* 42604 ( 963) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 6,  6,  0] -1 */
        3200, /* 42605 ( 963) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
       11784, /* 42606 ( 963) [ 0,  1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    52438874, /* 42607 ( 963) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
        7896, /* 42608 ( 963) [ 0, -1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    52447782, /* 42609 ( 963) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 6,  6,  0] -1 */
       16484, /* 42610 ( 964) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34133522, /* 42611 ( 964) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
        3200, /* 42612 ( 964) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    18439610, /* 42613 ( 964) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
       11784, /* 42614 ( 964) [ 0,  1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  0]  1 */
        7896, /* 42615 ( 964) [ 0, -1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    52569932, /* 42616 ( 964) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    34142106, /* 42617 ( 964) [ 0,  1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  6] -1 */
    18430698, /* 42618 ( 964) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 6,  6,  0]  1 */
    34138218, /* 42619 ( 964) [ 0, -1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  6] -1 */
    18426650, /* 42620 ( 964) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    34146806, /* 42621 ( 964) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    52556972, /* 42622 ( 964) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    52561020, /* 42623 ( 964) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    52565880, /* 42624 ( 964) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    18435558, /* 42625 ( 964) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 6,  6,  0]  1 */
       16484, /* 42626 ( 965) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34015586, /* 42627 ( 965) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
        3200, /* 42628 ( 965) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    18439610, /* 42629 ( 965) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    34024494, /* 42630 ( 965) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  0] -1 */
       11784, /* 42631 ( 965) [ 0,  1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    34019634, /* 42632 ( 965) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  0] -1 */
        7896, /* 42633 ( 965) [ 0, -1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    52443408, /* 42634 ( 965) [ 0, -1,  0,  1,  0,  0,  0,  0, -1] [ 6,  6,  0] -1 */
    18430698, /* 42635 ( 965) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 6,  6,  0]  1 */
    18426650, /* 42636 ( 965) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    52451996, /* 42637 ( 965) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
    34028546, /* 42638 ( 965) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    52438712, /* 42639 ( 965) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
    52447296, /* 42640 ( 965) [ 0,  1,  0, -1,  0,  0,  0,  0, -1] [ 6,  6,  0] -1 */
    18435558, /* 42641 ( 965) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 6,  6,  0]  1 */
       16484, /* 42642 ( 966) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34142592, /* 42643 ( 966) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  6] -1 */
    34137732, /* 42644 ( 966) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  6] -1 */
    52556810, /* 42645 ( 966) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
        3200, /* 42646 ( 966) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    18439610, /* 42647 ( 966) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    52561506, /* 42648 ( 966) [ 0, -1,  0,  1,  0,  0,  0,  0, -1] [ 6,  6,  6] -1 */
       11784, /* 42649 ( 966) [ 0,  1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    34146644, /* 42650 ( 966) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
        7896, /* 42651 ( 966) [ 0, -1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    18430698, /* 42652 ( 966) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 6,  6,  0]  1 */
    18426650, /* 42653 ( 966) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    34133684, /* 42654 ( 966) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    52565394, /* 42655 ( 966) [ 0,  1,  0, -1,  0,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    52570094, /* 42656 ( 966) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    18435558, /* 42657 ( 966) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 6,  6,  0]  1 */
       16484, /* 42658 ( 967) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
        3200, /* 42659 ( 967) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
       11784, /* 42660 ( 967) [ 0,  1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    18553656, /* 42661 ( 967) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 6,  6,  6]  1 */
    18548796, /* 42662 ( 967) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 6,  6,  6]  1 */
        7896, /* 42663 ( 967) [ 0, -1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    18557708, /* 42664 ( 967) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    18544748, /* 42665 ( 967) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
       16484, /* 42666 ( 968) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34024008, /* 42667 ( 968) [ 0,  1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    34020120, /* 42668 ( 968) [ 0, -1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  0] -1 */
        3200, /* 42669 ( 968) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
       11784, /* 42670 ( 968) [ 0,  1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    18553656, /* 42671 ( 968) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 6,  6,  6]  1 */
    18548796, /* 42672 ( 968) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 6,  6,  6]  1 */
        7896, /* 42673 ( 968) [ 0, -1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    52565880, /* 42674 ( 968) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    52569932, /* 42675 ( 968) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    52556972, /* 42676 ( 968) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    34015424, /* 42677 ( 968) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    18557708, /* 42678 ( 968) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    34028708, /* 42679 ( 968) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    52561020, /* 42680 ( 968) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    18544748, /* 42681 ( 968) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
       16484, /* 42682 ( 969) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34024008, /* 42683 ( 969) [ 0,  1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    34020120, /* 42684 ( 969) [ 0, -1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  0] -1 */
        3200, /* 42685 ( 969) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    18548796, /* 42686 ( 969) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 6,  6,  6]  1 */
    18553656, /* 42687 ( 969) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 6,  6,  6]  1 */
    52569932, /* 42688 ( 969) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    52556972, /* 42689 ( 969) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
       16484, /* 42690 ( 970) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34024008, /* 42691 ( 970) [ 0,  1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    34020120, /* 42692 ( 970) [ 0, -1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  0] -1 */
        3200, /* 42693 ( 970) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    18544748, /* 42694 ( 970) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    18557708, /* 42695 ( 970) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    52561020, /* 42696 ( 970) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    52565880, /* 42697 ( 970) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 6,  6,  6] -1 */
       16484, /* 42698 ( 971) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
        3200, /* 42699 ( 971) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
       11784, /* 42700 ( 971) [ 0,  1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  0]  1 */
        7896, /* 42701 ( 971) [ 0, -1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    52569932, /* 42702 ( 971) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    52556972, /* 42703 ( 971) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    52561020, /* 42704 ( 971) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    52565880, /* 42705 ( 971) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 6,  6,  6] -1 */
       16484, /* 42706 ( 972) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    52451834, /* 42707 ( 972) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
    52442922, /* 42708 ( 972) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 6,  6,  0] -1 */
    34133522, /* 42709 ( 972) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
        3200, /* 42710 ( 972) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
       11784, /* 42711 ( 972) [ 0,  1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    18553656, /* 42712 ( 972) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 6,  6,  6]  1 */
    18548796, /* 42713 ( 972) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 6,  6,  6]  1 */
    52438874, /* 42714 ( 972) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
    34142106, /* 42715 ( 972) [ 0,  1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  6] -1 */
        7896, /* 42716 ( 972) [ 0, -1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    34138218, /* 42717 ( 972) [ 0, -1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  6] -1 */
    52447782, /* 42718 ( 972) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 6,  6,  0] -1 */
    34146806, /* 42719 ( 972) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    18557708, /* 42720 ( 972) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    18544748, /* 42721 ( 972) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
       16484, /* 42722 ( 973) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34142592, /* 42723 ( 973) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  6] -1 */
    52438712, /* 42724 ( 973) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
    34137732, /* 42725 ( 973) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  6] -1 */
        3200, /* 42726 ( 973) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
       11784, /* 42727 ( 973) [ 0,  1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    18553656, /* 42728 ( 973) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 6,  6,  6]  1 */
    18548796, /* 42729 ( 973) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 6,  6,  6]  1 */
        7896, /* 42730 ( 973) [ 0, -1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    52443408, /* 42731 ( 973) [ 0, -1,  0,  1,  0,  0,  0,  0, -1] [ 6,  6,  0] -1 */
    34146644, /* 42732 ( 973) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    52451996, /* 42733 ( 973) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
    34133684, /* 42734 ( 973) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    18557708, /* 42735 ( 973) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    18544748, /* 42736 ( 973) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    52447296, /* 42737 ( 973) [ 0,  1,  0, -1,  0,  0,  0,  0, -1] [ 6,  6,  0] -1 */
       16484, /* 42738 ( 974) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34015586, /* 42739 ( 974) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    52556810, /* 42740 ( 974) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
        3200, /* 42741 ( 974) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34019634, /* 42742 ( 974) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    34024494, /* 42743 ( 974) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  0] -1 */
       11784, /* 42744 ( 974) [ 0,  1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    18553656, /* 42745 ( 974) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 6,  6,  6]  1 */
    18548796, /* 42746 ( 974) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 6,  6,  6]  1 */
        7896, /* 42747 ( 974) [ 0, -1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    52561506, /* 42748 ( 974) [ 0, -1,  0,  1,  0,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    18557708, /* 42749 ( 974) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    52565394, /* 42750 ( 974) [ 0,  1,  0, -1,  0,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    34028546, /* 42751 ( 974) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    52570094, /* 42752 ( 974) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    18544748, /* 42753 ( 974) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
       16484, /* 42754 ( 975) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    18557870, /* 42755 ( 975) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
        3200, /* 42756 ( 975) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
        3362, /* 42757 ( 975) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
       11784, /* 42758 ( 975) [ 0,  1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    18553656, /* 42759 ( 975) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 6,  6,  6]  1 */
    18548796, /* 42760 ( 975) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 6,  6,  6]  1 */
        7896, /* 42761 ( 975) [ 0, -1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    18549282, /* 42762 ( 975) [ 0, -1,  0,  1,  0,  0,  0,  0, -1] [ 6,  6,  6]  1 */
        7410, /* 42763 ( 975) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  0]  1 */
       12270, /* 42764 ( 975) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    18544586, /* 42765 ( 975) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    18557708, /* 42766 ( 975) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    18544748, /* 42767 ( 975) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    18553170, /* 42768 ( 975) [ 0,  1,  0, -1,  0,  0,  0,  0, -1] [ 6,  6,  6]  1 */
       16322, /* 42769 ( 975) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
       16484, /* 42770 ( 976) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    52561506, /* 42771 ( 976) [ 0, -1,  0,  1,  0,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    34019634, /* 42772 ( 976) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    18553656, /* 42773 ( 976) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 6,  6,  6]  1 */
       12270, /* 42774 ( 976) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    52565394, /* 42775 ( 976) [ 0,  1,  0, -1,  0,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    52570094, /* 42776 ( 976) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    34024008, /* 42777 ( 976) [ 0,  1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    34020120, /* 42778 ( 976) [ 0, -1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    18548796, /* 42779 ( 976) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 6,  6,  6]  1 */
    52569932, /* 42780 ( 976) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    18549282, /* 42781 ( 976) [ 0, -1,  0,  1,  0,  0,  0,  0, -1] [ 6,  6,  6]  1 */
        7410, /* 42782 ( 976) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    52556972, /* 42783 ( 976) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    34015424, /* 42784 ( 976) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    34028546, /* 42785 ( 976) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    34028708, /* 42786 ( 976) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    18553170, /* 42787 ( 976) [ 0,  1,  0, -1,  0,  0,  0,  0, -1] [ 6,  6,  6]  1 */
    34015586, /* 42788 ( 976) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    18557870, /* 42789 ( 976) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    52556810, /* 42790 ( 976) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
       11784, /* 42791 ( 976) [ 0,  1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  0]  1 */
        7896, /* 42792 ( 976) [ 0, -1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    18557708, /* 42793 ( 976) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    18544748, /* 42794 ( 976) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    52565880, /* 42795 ( 976) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 6,  6,  6] -1 */
       16322, /* 42796 ( 976) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
        3200, /* 42797 ( 976) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
        3362, /* 42798 ( 976) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34024494, /* 42799 ( 976) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    18544586, /* 42800 ( 976) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    52561020, /* 42801 ( 976) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 6,  6,  6] -1 */
       16484, /* 42802 ( 977) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34024008, /* 42803 ( 977) [ 0,  1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    18557870, /* 42804 ( 977) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    34015586, /* 42805 ( 977) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    34020120, /* 42806 ( 977) [ 0, -1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  0] -1 */
        3200, /* 42807 ( 977) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    52561506, /* 42808 ( 977) [ 0, -1,  0,  1,  0,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    18548796, /* 42809 ( 977) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 6,  6,  6]  1 */
    18553656, /* 42810 ( 977) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 6,  6,  6]  1 */
    52569932, /* 42811 ( 977) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
        7410, /* 42812 ( 977) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  0]  1 */
       12270, /* 42813 ( 977) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    18544586, /* 42814 ( 977) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    52556972, /* 42815 ( 977) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    52565394, /* 42816 ( 977) [ 0,  1,  0, -1,  0,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    34028546, /* 42817 ( 977) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
       16484, /* 42818 ( 978) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34024008, /* 42819 ( 978) [ 0,  1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    18557870, /* 42820 ( 978) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    34020120, /* 42821 ( 978) [ 0, -1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  0] -1 */
        3200, /* 42822 ( 978) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34019634, /* 42823 ( 978) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  0] -1 */
        3362, /* 42824 ( 978) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34024494, /* 42825 ( 978) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    52561506, /* 42826 ( 978) [ 0, -1,  0,  1,  0,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    52565880, /* 42827 ( 978) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    18544586, /* 42828 ( 978) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    52565394, /* 42829 ( 978) [ 0,  1,  0, -1,  0,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    18557708, /* 42830 ( 978) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    52561020, /* 42831 ( 978) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    18544748, /* 42832 ( 978) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
       16322, /* 42833 ( 978) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
       16484, /* 42834 ( 979) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34015586, /* 42835 ( 979) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    18557870, /* 42836 ( 979) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
        3200, /* 42837 ( 979) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34019634, /* 42838 ( 979) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    34024494, /* 42839 ( 979) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  0] -1 */
       11784, /* 42840 ( 979) [ 0,  1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  0]  1 */
        7896, /* 42841 ( 979) [ 0, -1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    52569932, /* 42842 ( 979) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    18549282, /* 42843 ( 979) [ 0, -1,  0,  1,  0,  0,  0,  0, -1] [ 6,  6,  6]  1 */
    18544586, /* 42844 ( 979) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    52556972, /* 42845 ( 979) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    34028546, /* 42846 ( 979) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    52561020, /* 42847 ( 979) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    52565880, /* 42848 ( 979) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    18553170, /* 42849 ( 979) [ 0,  1,  0, -1,  0,  0,  0,  0, -1] [ 6,  6,  6]  1 */
       16484, /* 42850 ( 980) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34137732, /* 42851 ( 980) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  6] -1 */
    52442922, /* 42852 ( 980) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 6,  6,  0] -1 */
    18553656, /* 42853 ( 980) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 6,  6,  6]  1 */
    52443408, /* 42854 ( 980) [ 0, -1,  0,  1,  0,  0,  0,  0, -1] [ 6,  6,  0] -1 */
       12270, /* 42855 ( 980) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    52451996, /* 42856 ( 980) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
    52447296, /* 42857 ( 980) [ 0,  1,  0, -1,  0,  0,  0,  0, -1] [ 6,  6,  0] -1 */
    52451834, /* 42858 ( 980) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
    18548796, /* 42859 ( 980) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 6,  6,  6]  1 */
    52438874, /* 42860 ( 980) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
    34146644, /* 42861 ( 980) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    34142106, /* 42862 ( 980) [ 0,  1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  6] -1 */
        7410, /* 42863 ( 980) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    18549282, /* 42864 ( 980) [ 0, -1,  0,  1,  0,  0,  0,  0, -1] [ 6,  6,  6]  1 */
    34138218, /* 42865 ( 980) [ 0, -1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  6] -1 */
    34146806, /* 42866 ( 980) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    34133684, /* 42867 ( 980) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    52438712, /* 42868 ( 980) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
    18553170, /* 42869 ( 980) [ 0,  1,  0, -1,  0,  0,  0,  0, -1] [ 6,  6,  6]  1 */
    18557870, /* 42870 ( 980) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    34133522, /* 42871 ( 980) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
       11784, /* 42872 ( 980) [ 0,  1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  0]  1 */
        7896, /* 42873 ( 980) [ 0, -1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    52447782, /* 42874 ( 980) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 6,  6,  0] -1 */
    18557708, /* 42875 ( 980) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    18544748, /* 42876 ( 980) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
       16322, /* 42877 ( 980) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34142592, /* 42878 ( 980) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  6] -1 */
        3200, /* 42879 ( 980) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
        3362, /* 42880 ( 980) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    18544586, /* 42881 ( 980) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
       16484, /* 42882 ( 981) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
      121460, /* 42883 ( 981) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6]  1 */
    18557870, /* 42884 ( 981) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
        3200, /* 42885 ( 981) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    18439610, /* 42886 ( 981) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
      125508, /* 42887 ( 981) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  6]  1 */
       11784, /* 42888 ( 981) [ 0,  1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  0]  1 */
      130368, /* 42889 ( 981) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  6]  1 */
        7896, /* 42890 ( 981) [ 0, -1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    18549282, /* 42891 ( 981) [ 0, -1,  0,  1,  0,  0,  0,  0, -1] [ 6,  6,  6]  1 */
    18430698, /* 42892 ( 981) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 6,  6,  0]  1 */
    18426650, /* 42893 ( 981) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    18544586, /* 42894 ( 981) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
      134420, /* 42895 ( 981) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6]  1 */
    18553170, /* 42896 ( 981) [ 0,  1,  0, -1,  0,  0,  0,  0, -1] [ 6,  6,  6]  1 */
    18435558, /* 42897 ( 981) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 6,  6,  0]  1 */
       16484, /* 42898 ( 982) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34137732, /* 42899 ( 982) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  6] -1 */
    52442922, /* 42900 ( 982) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 6,  6,  0] -1 */
    52561506, /* 42901 ( 982) [ 0, -1,  0,  1,  0,  0,  0,  0, -1] [ 6,  6,  6] -1 */
      130368, /* 42902 ( 982) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  6]  1 */
    52565394, /* 42903 ( 982) [ 0,  1,  0, -1,  0,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    52570094, /* 42904 ( 982) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    52451834, /* 42905 ( 982) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
    34024008, /* 42906 ( 982) [ 0,  1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    34020120, /* 42907 ( 982) [ 0, -1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  0] -1 */
      125508, /* 42908 ( 982) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  6]  1 */
    52438874, /* 42909 ( 982) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
    34146644, /* 42910 ( 982) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    18549282, /* 42911 ( 982) [ 0, -1,  0,  1,  0,  0,  0,  0, -1] [ 6,  6,  6]  1 */
    18430698, /* 42912 ( 982) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 6,  6,  0]  1 */
    34133684, /* 42913 ( 982) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    34015424, /* 42914 ( 982) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    34028708, /* 42915 ( 982) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    18553170, /* 42916 ( 982) [ 0,  1,  0, -1,  0,  0,  0,  0, -1] [ 6,  6,  6]  1 */
    18557870, /* 42917 ( 982) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    52556810, /* 42918 ( 982) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    18439610, /* 42919 ( 982) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
       11784, /* 42920 ( 982) [ 0,  1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  0]  1 */
        7896, /* 42921 ( 982) [ 0, -1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    18426650, /* 42922 ( 982) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    52447782, /* 42923 ( 982) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 6,  6,  0] -1 */
      134420, /* 42924 ( 982) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6]  1 */
      121460, /* 42925 ( 982) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6]  1 */
    34142592, /* 42926 ( 982) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  6] -1 */
        3200, /* 42927 ( 982) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    18544586, /* 42928 ( 982) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    18435558, /* 42929 ( 982) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 6,  6,  0]  1 */
       16484, /* 42930 ( 983) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    52451834, /* 42931 ( 983) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
    34024008, /* 42932 ( 983) [ 0,  1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    18557870, /* 42933 ( 983) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    34020120, /* 42934 ( 983) [ 0, -1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  0] -1 */
        3200, /* 42935 ( 983) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    52561506, /* 42936 ( 983) [ 0, -1,  0,  1,  0,  0,  0,  0, -1] [ 6,  6,  6] -1 */
      125508, /* 42937 ( 983) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  6]  1 */
      130368, /* 42938 ( 983) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  6]  1 */
    52438874, /* 42939 ( 983) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
    34146644, /* 42940 ( 983) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    18430698, /* 42941 ( 983) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 6,  6,  0]  1 */
    18544586, /* 42942 ( 983) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    34133684, /* 42943 ( 983) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    52565394, /* 42944 ( 983) [ 0,  1,  0, -1,  0,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    18435558, /* 42945 ( 983) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 6,  6,  0]  1 */
       16484, /* 42946 ( 984) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34024008, /* 42947 ( 984) [ 0,  1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    18557870, /* 42948 ( 984) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
      121460, /* 42949 ( 984) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6]  1 */
    34142592, /* 42950 ( 984) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  6] -1 */
        3200, /* 42951 ( 984) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34137732, /* 42952 ( 984) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  6] -1 */
    52442922, /* 42953 ( 984) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 6,  6,  0] -1 */
    34020120, /* 42954 ( 984) [ 0, -1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    52561506, /* 42955 ( 984) [ 0, -1,  0,  1,  0,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    18439610, /* 42956 ( 984) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    18426650, /* 42957 ( 984) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    18544586, /* 42958 ( 984) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    52447782, /* 42959 ( 984) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 6,  6,  0] -1 */
    52565394, /* 42960 ( 984) [ 0,  1,  0, -1,  0,  0,  0,  0, -1] [ 6,  6,  6] -1 */
      134420, /* 42961 ( 984) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6]  1 */
       16484, /* 42962 ( 985) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    52451834, /* 42963 ( 985) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
    34142592, /* 42964 ( 985) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  6] -1 */
    18557870, /* 42965 ( 985) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    34137732, /* 42966 ( 985) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  6] -1 */
    52442922, /* 42967 ( 985) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 6,  6,  0] -1 */
        3200, /* 42968 ( 985) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
       11784, /* 42969 ( 985) [ 0,  1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    52438874, /* 42970 ( 985) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
        7896, /* 42971 ( 985) [ 0, -1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    34146644, /* 42972 ( 985) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    18549282, /* 42973 ( 985) [ 0, -1,  0,  1,  0,  0,  0,  0, -1] [ 6,  6,  6]  1 */
    52447782, /* 42974 ( 985) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 6,  6,  0] -1 */
    18544586, /* 42975 ( 985) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    34133684, /* 42976 ( 985) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    18553170, /* 42977 ( 985) [ 0,  1,  0, -1,  0,  0,  0,  0, -1] [ 6,  6,  6]  1 */
       16484, /* 42978 ( 986) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34019634, /* 42979 ( 986) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  0] -1 */
      130368, /* 42980 ( 986) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  6]  1 */
    52443408, /* 42981 ( 986) [ 0, -1,  0,  1,  0,  0,  0,  0, -1] [ 6,  6,  0] -1 */
    52451996, /* 42982 ( 986) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
    52447296, /* 42983 ( 986) [ 0,  1,  0, -1,  0,  0,  0,  0, -1] [ 6,  6,  0] -1 */
      125508, /* 42984 ( 986) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  6]  1 */
    52569932, /* 42985 ( 986) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    34142106, /* 42986 ( 986) [ 0,  1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  6] -1 */
    18549282, /* 42987 ( 986) [ 0, -1,  0,  1,  0,  0,  0,  0, -1] [ 6,  6,  6]  1 */
    18430698, /* 42988 ( 986) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 6,  6,  0]  1 */
    34138218, /* 42989 ( 986) [ 0, -1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  6] -1 */
    34146806, /* 42990 ( 986) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    52556972, /* 42991 ( 986) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    34028546, /* 42992 ( 986) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    52438712, /* 42993 ( 986) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
    18553170, /* 42994 ( 986) [ 0,  1,  0, -1,  0,  0,  0,  0, -1] [ 6,  6,  6]  1 */
    34015586, /* 42995 ( 986) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    18557870, /* 42996 ( 986) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    34133522, /* 42997 ( 986) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    18439610, /* 42998 ( 986) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
       11784, /* 42999 ( 986) [ 0,  1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  0]  1 */
        7896, /* 43000 ( 986) [ 0, -1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    18426650, /* 43001 ( 986) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
      134420, /* 43002 ( 986) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6]  1 */
    52565880, /* 43003 ( 986) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 6,  6,  6] -1 */
      121460, /* 43004 ( 986) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6]  1 */
        3200, /* 43005 ( 986) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34024494, /* 43006 ( 986) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    18544586, /* 43007 ( 986) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    52561020, /* 43008 ( 986) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    18435558, /* 43009 ( 986) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 6,  6,  0]  1 */
       16484, /* 43010 ( 987) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    18557870, /* 43011 ( 987) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
        3200, /* 43012 ( 987) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
       11784, /* 43013 ( 987) [ 0,  1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  0]  1 */
       12272, /* 43014 ( 987) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 0,  0,  0]  1 */
       16320, /* 43015 ( 987) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
        7896, /* 43016 ( 987) [ 0, -1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    18549282, /* 43017 ( 987) [ 0, -1,  0,  1,  0,  0,  0,  0, -1] [ 6,  6,  6]  1 */
        7412, /* 43018 ( 987) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    18544586, /* 43019 ( 987) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
        3360, /* 43020 ( 987) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    18544746, /* 43021 ( 987) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
    18548798, /* 43022 ( 987) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    18553170, /* 43023 ( 987) [ 0,  1,  0, -1,  0,  0,  0,  0, -1] [ 6,  6,  6]  1 */
    18553658, /* 43024 ( 987) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    18557706, /* 43025 ( 987) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
       16484, /* 43026 ( 988) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    52561506, /* 43027 ( 988) [ 0, -1,  0,  1,  0,  0,  0,  0, -1] [ 6,  6,  6] -1 */
       16320, /* 43028 ( 988) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    52556970, /* 43029 ( 988) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    52565394, /* 43030 ( 988) [ 0,  1,  0, -1,  0,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    52570094, /* 43031 ( 988) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    34024008, /* 43032 ( 988) [ 0,  1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    34020120, /* 43033 ( 988) [ 0, -1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    34015584, /* 43034 ( 988) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    18549282, /* 43035 ( 988) [ 0, -1,  0,  1,  0,  0,  0,  0, -1] [ 6,  6,  6]  1 */
    52565882, /* 43036 ( 988) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    34015424, /* 43037 ( 988) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    34028708, /* 43038 ( 988) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    18544746, /* 43039 ( 988) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
    34024496, /* 43040 ( 988) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    18553170, /* 43041 ( 988) [ 0,  1,  0, -1,  0,  0,  0,  0, -1] [ 6,  6,  6]  1 */
    18557870, /* 43042 ( 988) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    52556810, /* 43043 ( 988) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
       11784, /* 43044 ( 988) [ 0,  1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    34019636, /* 43045 ( 988) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  0] -1 */
        7896, /* 43046 ( 988) [ 0, -1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    52561022, /* 43047 ( 988) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    52569930, /* 43048 ( 988) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
        3360, /* 43049 ( 988) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    34028544, /* 43050 ( 988) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    18553658, /* 43051 ( 988) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 6,  6,  6]  1 */
        3200, /* 43052 ( 988) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
       12272, /* 43053 ( 988) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 0,  0,  0]  1 */
        7412, /* 43054 ( 988) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    18544586, /* 43055 ( 988) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    18548798, /* 43056 ( 988) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    18557706, /* 43057 ( 988) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
       16484, /* 43058 ( 989) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34024008, /* 43059 ( 989) [ 0,  1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    18557870, /* 43060 ( 989) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    34020120, /* 43061 ( 989) [ 0, -1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  0] -1 */
        3200, /* 43062 ( 989) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    52561506, /* 43063 ( 989) [ 0, -1,  0,  1,  0,  0,  0,  0, -1] [ 6,  6,  6] -1 */
       12272, /* 43064 ( 989) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34015584, /* 43065 ( 989) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
        7412, /* 43066 ( 989) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    18544586, /* 43067 ( 989) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    52556970, /* 43068 ( 989) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    52565394, /* 43069 ( 989) [ 0,  1,  0, -1,  0,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    52569930, /* 43070 ( 989) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    18548798, /* 43071 ( 989) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    34028544, /* 43072 ( 989) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    18553658, /* 43073 ( 989) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 6,  6,  6]  1 */
       16484, /* 43074 ( 990) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34024008, /* 43075 ( 990) [ 0,  1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    18557870, /* 43076 ( 990) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    34020120, /* 43077 ( 990) [ 0, -1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  0] -1 */
        3200, /* 43078 ( 990) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    52561506, /* 43079 ( 990) [ 0, -1,  0,  1,  0,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    34019636, /* 43080 ( 990) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  0] -1 */
       16320, /* 43081 ( 990) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    18544586, /* 43082 ( 990) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    52561022, /* 43083 ( 990) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    52565394, /* 43084 ( 990) [ 0,  1,  0, -1,  0,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    52565882, /* 43085 ( 990) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 6,  6,  6] -1 */
        3360, /* 43086 ( 990) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    18544746, /* 43087 ( 990) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
    34024496, /* 43088 ( 990) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    18557706, /* 43089 ( 990) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
       16484, /* 43090 ( 991) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    18557870, /* 43091 ( 991) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    52565882, /* 43092 ( 991) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 6,  6,  6] -1 */
        3200, /* 43093 ( 991) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
       11784, /* 43094 ( 991) [ 0,  1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    34019636, /* 43095 ( 991) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  0] -1 */
        7896, /* 43096 ( 991) [ 0, -1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    34015584, /* 43097 ( 991) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    18549282, /* 43098 ( 991) [ 0, -1,  0,  1,  0,  0,  0,  0, -1] [ 6,  6,  6]  1 */
    18544586, /* 43099 ( 991) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    52556970, /* 43100 ( 991) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    52561022, /* 43101 ( 991) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    18553170, /* 43102 ( 991) [ 0,  1,  0, -1,  0,  0,  0,  0, -1] [ 6,  6,  6]  1 */
    52569930, /* 43103 ( 991) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    34024496, /* 43104 ( 991) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    34028544, /* 43105 ( 991) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
       16484, /* 43106 ( 992) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
       16320, /* 43107 ( 992) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    52443408, /* 43108 ( 992) [ 0, -1,  0,  1,  0,  0,  0,  0, -1] [ 6,  6,  0] -1 */
    52451996, /* 43109 ( 992) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
    52438872, /* 43110 ( 992) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
    52447296, /* 43111 ( 992) [ 0,  1,  0, -1,  0,  0,  0,  0, -1] [ 6,  6,  0] -1 */
    34142106, /* 43112 ( 992) [ 0,  1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  6] -1 */
    18549282, /* 43113 ( 992) [ 0, -1,  0,  1,  0,  0,  0,  0, -1] [ 6,  6,  6]  1 */
    34138218, /* 43114 ( 992) [ 0, -1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  6] -1 */
    34146806, /* 43115 ( 992) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    34133682, /* 43116 ( 992) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
    52438712, /* 43117 ( 992) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
    18544746, /* 43118 ( 992) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
    18553170, /* 43119 ( 992) [ 0,  1,  0, -1,  0,  0,  0,  0, -1] [ 6,  6,  6]  1 */
    52447784, /* 43120 ( 992) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 6,  6,  0] -1 */
    18557870, /* 43121 ( 992) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    34133522, /* 43122 ( 992) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    34142594, /* 43123 ( 992) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 0,  0,  6] -1 */
       11784, /* 43124 ( 992) [ 0,  1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    52442924, /* 43125 ( 992) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 6,  6,  0] -1 */
        7896, /* 43126 ( 992) [ 0, -1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    34137734, /* 43127 ( 992) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    34146642, /* 43128 ( 992) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
        3360, /* 43129 ( 992) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    52451832, /* 43130 ( 992) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
    18553658, /* 43131 ( 992) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 6,  6,  6]  1 */
        3200, /* 43132 ( 992) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
       12272, /* 43133 ( 992) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 0,  0,  0]  1 */
        7412, /* 43134 ( 992) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    18544586, /* 43135 ( 992) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    18548798, /* 43136 ( 992) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    18557706, /* 43137 ( 992) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
       16484, /* 43138 ( 993) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    18557870, /* 43139 ( 993) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
        3200, /* 43140 ( 993) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
     1488497, /* 43141 ( 993) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 0,  6,  3]  1 */
     1492545, /* 43142 ( 993) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  3]  1 */
       11784, /* 43143 ( 993) [ 0,  1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  0]  1 */
     1479585, /* 43144 ( 993) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  3]  1 */
        7896, /* 43145 ( 993) [ 0, -1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    17186619, /* 43146 ( 993) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  9]  1 */
    18549282, /* 43147 ( 993) [ 0, -1,  0,  1,  0,  0,  0,  0, -1] [ 6,  6,  6]  1 */
    18544586, /* 43148 ( 993) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
     1483637, /* 43149 ( 993) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 0,  6,  3]  1 */
    17190671, /* 43150 ( 993) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 6,  0,  9]  1 */
    17195531, /* 43151 ( 993) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 6,  0,  9]  1 */
    17199579, /* 43152 ( 993) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  9]  1 */
    18553170, /* 43153 ( 993) [ 0,  1,  0, -1,  0,  0,  0,  0, -1] [ 6,  6,  6]  1 */
       16484, /* 43154 ( 994) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    52561506, /* 43155 ( 994) [ 0, -1,  0,  1,  0,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    51207755, /* 43156 ( 994) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 6,  0,  9] -1 */
    52565394, /* 43157 ( 994) [ 0,  1,  0, -1,  0,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    35504769, /* 43158 ( 994) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  3] -1 */
    52570094, /* 43159 ( 994) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    34024008, /* 43160 ( 994) [ 0,  1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    34020120, /* 43161 ( 994) [ 0, -1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  0] -1 */
     1488497, /* 43162 ( 994) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 0,  6,  3]  1 */
     1479585, /* 43163 ( 994) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  3]  1 */
    35495861, /* 43164 ( 994) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 0,  6,  3] -1 */
    17186619, /* 43165 ( 994) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  9]  1 */
    51202895, /* 43166 ( 994) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 6,  0,  9] -1 */
    18549282, /* 43167 ( 994) [ 0, -1,  0,  1,  0,  0,  0,  0, -1] [ 6,  6,  6]  1 */
    51211803, /* 43168 ( 994) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  9] -1 */
    34015424, /* 43169 ( 994) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    34028708, /* 43170 ( 994) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    17195531, /* 43171 ( 994) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 6,  0,  9]  1 */
    18553170, /* 43172 ( 994) [ 0,  1,  0, -1,  0,  0,  0,  0, -1] [ 6,  6,  6]  1 */
    18557870, /* 43173 ( 994) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    52556810, /* 43174 ( 994) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
     1492545, /* 43175 ( 994) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  3]  1 */
       11784, /* 43176 ( 994) [ 0,  1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  0]  1 */
        7896, /* 43177 ( 994) [ 0, -1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  0]  1 */
     1483637, /* 43178 ( 994) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 0,  6,  3]  1 */
    17190671, /* 43179 ( 994) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 6,  0,  9]  1 */
    17199579, /* 43180 ( 994) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  9]  1 */
        3200, /* 43181 ( 994) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    35491809, /* 43182 ( 994) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  3] -1 */
    18544586, /* 43183 ( 994) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    35500721, /* 43184 ( 994) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 0,  6,  3] -1 */
    51198843, /* 43185 ( 994) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  9] -1 */
       16484, /* 43186 ( 995) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34024008, /* 43187 ( 995) [ 0,  1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    18557870, /* 43188 ( 995) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    34020120, /* 43189 ( 995) [ 0, -1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  0] -1 */
        3200, /* 43190 ( 995) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
     1488497, /* 43191 ( 995) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 0,  6,  3]  1 */
    52561506, /* 43192 ( 995) [ 0, -1,  0,  1,  0,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    17190671, /* 43193 ( 995) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 6,  0,  9]  1 */
    51211803, /* 43194 ( 995) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  9] -1 */
    18544586, /* 43195 ( 995) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    52565394, /* 43196 ( 995) [ 0,  1,  0, -1,  0,  0,  0,  0, -1] [ 6,  6,  6] -1 */
     1483637, /* 43197 ( 995) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 0,  6,  3]  1 */
    35491809, /* 43198 ( 995) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  3] -1 */
    35504769, /* 43199 ( 995) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  3] -1 */
    17195531, /* 43200 ( 995) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 6,  0,  9]  1 */
    51198843, /* 43201 ( 995) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  9] -1 */
       16484, /* 43202 ( 996) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34024008, /* 43203 ( 996) [ 0,  1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    18557870, /* 43204 ( 996) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    34020120, /* 43205 ( 996) [ 0, -1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  0] -1 */
        3200, /* 43206 ( 996) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
     1479585, /* 43207 ( 996) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  3]  1 */
     1492545, /* 43208 ( 996) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  3]  1 */
    35495861, /* 43209 ( 996) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 0,  6,  3] -1 */
    52561506, /* 43210 ( 996) [ 0, -1,  0,  1,  0,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    17186619, /* 43211 ( 996) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  9]  1 */
    51202895, /* 43212 ( 996) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 6,  0,  9] -1 */
    51207755, /* 43213 ( 996) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 6,  0,  9] -1 */
    18544586, /* 43214 ( 996) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    52565394, /* 43215 ( 996) [ 0,  1,  0, -1,  0,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    35500721, /* 43216 ( 996) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 0,  6,  3] -1 */
    17199579, /* 43217 ( 996) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  9]  1 */
       16484, /* 43218 ( 997) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    18557870, /* 43219 ( 997) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
        3200, /* 43220 ( 997) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
       11784, /* 43221 ( 997) [ 0,  1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    35495861, /* 43222 ( 997) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 0,  6,  3] -1 */
        7896, /* 43223 ( 997) [ 0, -1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    51202895, /* 43224 ( 997) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 6,  0,  9] -1 */
    51207755, /* 43225 ( 997) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 6,  0,  9] -1 */
    51211803, /* 43226 ( 997) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  9] -1 */
    35491809, /* 43227 ( 997) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  3] -1 */
    18549282, /* 43228 ( 997) [ 0, -1,  0,  1,  0,  0,  0,  0, -1] [ 6,  6,  6]  1 */
    18544586, /* 43229 ( 997) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    35500721, /* 43230 ( 997) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 0,  6,  3] -1 */
    35504769, /* 43231 ( 997) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  3] -1 */
    51198843, /* 43232 ( 997) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  9] -1 */
    18553170, /* 43233 ( 997) [ 0,  1,  0, -1,  0,  0,  0,  0, -1] [ 6,  6,  6]  1 */
       16484, /* 43234 ( 998) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    51089657, /* 43235 ( 998) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 6,  0,  3] -1 */
    35618819, /* 43236 ( 998) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 0,  6,  9] -1 */
    52443408, /* 43237 ( 998) [ 0, -1,  0,  1,  0,  0,  0,  0, -1] [ 6,  6,  0] -1 */
    52451996, /* 43238 ( 998) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
    52447296, /* 43239 ( 998) [ 0,  1,  0, -1,  0,  0,  0,  0, -1] [ 6,  6,  0] -1 */
    51093705, /* 43240 ( 998) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  3] -1 */
    35613959, /* 43241 ( 998) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 0,  6,  9] -1 */
    35622867, /* 43242 ( 998) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  9] -1 */
     1488497, /* 43243 ( 998) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 0,  6,  3]  1 */
     1479585, /* 43244 ( 998) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  3]  1 */
    17186619, /* 43245 ( 998) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  9]  1 */
    34142106, /* 43246 ( 998) [ 0,  1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  6] -1 */
    18549282, /* 43247 ( 998) [ 0, -1,  0,  1,  0,  0,  0,  0, -1] [ 6,  6,  6]  1 */
    34138218, /* 43248 ( 998) [ 0, -1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  6] -1 */
    51084797, /* 43249 ( 998) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 6,  0,  3] -1 */
    34146806, /* 43250 ( 998) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    52438712, /* 43251 ( 998) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
    17195531, /* 43252 ( 998) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 6,  0,  9]  1 */
    18553170, /* 43253 ( 998) [ 0,  1,  0, -1,  0,  0,  0,  0, -1] [ 6,  6,  6]  1 */
    18557870, /* 43254 ( 998) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    34133522, /* 43255 ( 998) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
     1492545, /* 43256 ( 998) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  3]  1 */
       11784, /* 43257 ( 998) [ 0,  1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  0]  1 */
        7896, /* 43258 ( 998) [ 0, -1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  0]  1 */
     1483637, /* 43259 ( 998) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 0,  6,  3]  1 */
    17190671, /* 43260 ( 998) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 6,  0,  9]  1 */
    17199579, /* 43261 ( 998) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  9]  1 */
        3200, /* 43262 ( 998) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    51080745, /* 43263 ( 998) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  3] -1 */
    18544586, /* 43264 ( 998) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    35609907, /* 43265 ( 998) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  9] -1 */
       16484, /* 43266 ( 999) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
        3200, /* 43267 ( 999) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
        3362, /* 43268 ( 999) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
       11784, /* 43269 ( 999) [ 0,  1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  0]  1 */
       12272, /* 43270 ( 999) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 0,  0,  0]  1 */
       16320, /* 43271 ( 999) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
        7896, /* 43272 ( 999) [ 0, -1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  0]  1 */
        7410, /* 43273 ( 999) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  0]  1 */
       12270, /* 43274 ( 999) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  0]  1 */
        7412, /* 43275 ( 999) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  0]  1 */
        3198, /* 43276 ( 999) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
       11786, /* 43277 ( 999) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  0]  1 */
        3360, /* 43278 ( 999) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
        7898, /* 43279 ( 999) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 0,  0,  0]  1 */
       16482, /* 43280 ( 999) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
       16322, /* 43281 ( 999) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
       16484, /* 43282 (1000) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34019634, /* 43283 (1000) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  0] -1 */
       16320, /* 43284 (1000) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
       12270, /* 43285 (1000) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  0]  1 */
        3198, /* 43286 (1000) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    34024008, /* 43287 (1000) [ 0,  1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    34020120, /* 43288 (1000) [ 0, -1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    34024010, /* 43289 (1000) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    34015584, /* 43290 (1000) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
        7410, /* 43291 (1000) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    34020122, /* 43292 (1000) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    34015424, /* 43293 (1000) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    34028546, /* 43294 (1000) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    34028708, /* 43295 (1000) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    34024496, /* 43296 (1000) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    34015586, /* 43297 (1000) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
       11784, /* 43298 (1000) [ 0,  1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    34019636, /* 43299 (1000) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  0] -1 */
        7896, /* 43300 (1000) [ 0, -1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    34028706, /* 43301 (1000) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
       11786, /* 43302 (1000) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  0]  1 */
        3360, /* 43303 (1000) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
        7898, /* 43304 (1000) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34028544, /* 43305 (1000) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
       16322, /* 43306 (1000) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34015422, /* 43307 (1000) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
        3200, /* 43308 (1000) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
        3362, /* 43309 (1000) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34024494, /* 43310 (1000) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  0] -1 */
       12272, /* 43311 (1000) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 0,  0,  0]  1 */
        7412, /* 43312 (1000) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  0]  1 */
       16482, /* 43313 (1000) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
       16484, /* 43314 (1001) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34024008, /* 43315 (1001) [ 0,  1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    34015422, /* 43316 (1001) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    34020120, /* 43317 (1001) [ 0, -1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  0] -1 */
        3200, /* 43318 (1001) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34019634, /* 43319 (1001) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    34024494, /* 43320 (1001) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  0] -1 */
        3362, /* 43321 (1001) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
       12272, /* 43322 (1001) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34015584, /* 43323 (1001) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    34028706, /* 43324 (1001) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
        7412, /* 43325 (1001) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  0]  1 */
       11786, /* 43326 (1001) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  0]  1 */
        7898, /* 43327 (1001) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34028544, /* 43328 (1001) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
       16322, /* 43329 (1001) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
       16484, /* 43330 (1002) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34024008, /* 43331 (1002) [ 0,  1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    34015586, /* 43332 (1002) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    34020120, /* 43333 (1002) [ 0, -1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  0] -1 */
        3200, /* 43334 (1002) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34024010, /* 43335 (1002) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  0] -1 */
       12272, /* 43336 (1002) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34015584, /* 43337 (1002) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
        7410, /* 43338 (1002) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  0]  1 */
       12270, /* 43339 (1002) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  0]  1 */
        7412, /* 43340 (1002) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  0]  1 */
        3198, /* 43341 (1002) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    34020122, /* 43342 (1002) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    34028546, /* 43343 (1002) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
       16482, /* 43344 (1002) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    34028544, /* 43345 (1002) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
       16484, /* 43346 (1003) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34024008, /* 43347 (1003) [ 0,  1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    34020120, /* 43348 (1003) [ 0, -1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  0] -1 */
        3200, /* 43349 (1003) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34019634, /* 43350 (1003) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  0] -1 */
        3362, /* 43351 (1003) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34024494, /* 43352 (1003) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    34019636, /* 43353 (1003) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  0] -1 */
       16320, /* 43354 (1003) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    34024010, /* 43355 (1003) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    34024496, /* 43356 (1003) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 0,  0,  0] -1 */
        3198, /* 43357 (1003) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    34020122, /* 43358 (1003) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 0,  0,  0] -1 */
        3360, /* 43359 (1003) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
       16482, /* 43360 (1003) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
       16322, /* 43361 (1003) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
       16484, /* 43362 (1004) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34015586, /* 43363 (1004) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    34015422, /* 43364 (1004) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
        3200, /* 43365 (1004) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34019634, /* 43366 (1004) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    34024494, /* 43367 (1004) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  0] -1 */
       11784, /* 43368 (1004) [ 0,  1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    34024010, /* 43369 (1004) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  0] -1 */
       16320, /* 43370 (1004) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
       12272, /* 43371 (1004) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 0,  0,  0]  1 */
        7896, /* 43372 (1004) [ 0, -1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    34028706, /* 43373 (1004) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
        7412, /* 43374 (1004) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34020122, /* 43375 (1004) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    34028546, /* 43376 (1004) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
        3360, /* 43377 (1004) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
       16484, /* 43378 (1005) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34015586, /* 43379 (1005) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
        3200, /* 43380 (1005) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34019634, /* 43381 (1005) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    34024494, /* 43382 (1005) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  0] -1 */
       11784, /* 43383 (1005) [ 0,  1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    34019636, /* 43384 (1005) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    34015584, /* 43385 (1005) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
        7896, /* 43386 (1005) [ 0, -1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    34024496, /* 43387 (1005) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 0,  0,  0] -1 */
        3198, /* 43388 (1005) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
       11786, /* 43389 (1005) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34028546, /* 43390 (1005) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
        7898, /* 43391 (1005) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 0,  0,  0]  1 */
       16482, /* 43392 (1005) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    34028544, /* 43393 (1005) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
       16484, /* 43394 (1006) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34015422, /* 43395 (1006) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
        3200, /* 43396 (1006) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
        3362, /* 43397 (1006) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
       11784, /* 43398 (1006) [ 0,  1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    34024010, /* 43399 (1006) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    34015584, /* 43400 (1006) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    34019636, /* 43401 (1006) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  0] -1 */
        7896, /* 43402 (1006) [ 0, -1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  0]  1 */
        7410, /* 43403 (1006) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  0]  1 */
       12270, /* 43404 (1006) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    34028706, /* 43405 (1006) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    34020122, /* 43406 (1006) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    34024496, /* 43407 (1006) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    34028544, /* 43408 (1006) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
       16322, /* 43409 (1006) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
       16484, /* 43410 (1007) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34024008, /* 43411 (1007) [ 0,  1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    34015586, /* 43412 (1007) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    34015422, /* 43413 (1007) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    34020120, /* 43414 (1007) [ 0, -1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  0] -1 */
        3200, /* 43415 (1007) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34019636, /* 43416 (1007) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  0] -1 */
       16320, /* 43417 (1007) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
        7410, /* 43418 (1007) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  0]  1 */
       12270, /* 43419 (1007) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    34028706, /* 43420 (1007) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
       11786, /* 43421 (1007) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34028546, /* 43422 (1007) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
        3360, /* 43423 (1007) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
        7898, /* 43424 (1007) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34024496, /* 43425 (1007) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 0,  0,  0] -1 */
       16484, /* 43426 (1008) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34137732, /* 43427 (1008) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  6] -1 */
       16320, /* 43428 (1008) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
       12270, /* 43429 (1008) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  0]  1 */
        3198, /* 43430 (1008) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    34142108, /* 43431 (1008) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    34146644, /* 43432 (1008) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    34138220, /* 43433 (1008) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 0,  0,  6] -1 */
        7410, /* 43434 (1008) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    34142106, /* 43435 (1008) [ 0,  1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  6] -1 */
    34138218, /* 43436 (1008) [ 0, -1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  6] -1 */
    34146806, /* 43437 (1008) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    34133684, /* 43438 (1008) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    34133682, /* 43439 (1008) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
    34133522, /* 43440 (1008) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    34142594, /* 43441 (1008) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 0,  0,  6] -1 */
       11784, /* 43442 (1008) [ 0,  1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  0]  1 */
        7896, /* 43443 (1008) [ 0, -1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    34137734, /* 43444 (1008) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  6] -1 */
       11786, /* 43445 (1008) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34146642, /* 43446 (1008) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
        3360, /* 43447 (1008) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
        7898, /* 43448 (1008) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34146804, /* 43449 (1008) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
       16322, /* 43450 (1008) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34142592, /* 43451 (1008) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  6] -1 */
        3200, /* 43452 (1008) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
        3362, /* 43453 (1008) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
       12272, /* 43454 (1008) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34133520, /* 43455 (1008) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
        7412, /* 43456 (1008) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  0]  1 */
       16482, /* 43457 (1008) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
       16484, /* 43458 (1009) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    52442922, /* 43459 (1009) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 6,  6,  0] -1 */
       16320, /* 43460 (1009) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    52443408, /* 43461 (1009) [ 0, -1,  0,  1,  0,  0,  0,  0, -1] [ 6,  6,  0] -1 */
       12270, /* 43462 (1009) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    52447298, /* 43463 (1009) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 6,  6,  0] -1 */
    52451996, /* 43464 (1009) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
        3198, /* 43465 (1009) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    52438872, /* 43466 (1009) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
    52443410, /* 43467 (1009) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 6,  6,  0] -1 */
    52447296, /* 43468 (1009) [ 0,  1,  0, -1,  0,  0,  0,  0, -1] [ 6,  6,  0] -1 */
    52451834, /* 43469 (1009) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
    52438874, /* 43470 (1009) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
        7410, /* 43471 (1009) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    52438712, /* 43472 (1009) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
    52447784, /* 43473 (1009) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 6,  6,  0] -1 */
       11784, /* 43474 (1009) [ 0,  1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    52442924, /* 43475 (1009) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 6,  6,  0] -1 */
        7896, /* 43476 (1009) [ 0, -1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    52451994, /* 43477 (1009) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
    52447782, /* 43478 (1009) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 6,  6,  0] -1 */
       11786, /* 43479 (1009) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  0]  1 */
        3360, /* 43480 (1009) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
        7898, /* 43481 (1009) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    52451832, /* 43482 (1009) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
       16322, /* 43483 (1009) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    52438710, /* 43484 (1009) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
        3200, /* 43485 (1009) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
        3362, /* 43486 (1009) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
       12272, /* 43487 (1009) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 0,  0,  0]  1 */
        7412, /* 43488 (1009) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  0]  1 */
       16482, /* 43489 (1009) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
       16484, /* 43490 (1010) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    52561506, /* 43491 (1010) [ 0, -1,  0,  1,  0,  0,  0,  0, -1] [ 6,  6,  6] -1 */
       16320, /* 43492 (1010) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
       12270, /* 43493 (1010) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  0]  1 */
        3198, /* 43494 (1010) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    52556970, /* 43495 (1010) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    52565394, /* 43496 (1010) [ 0,  1,  0, -1,  0,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    52570094, /* 43497 (1010) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    52565396, /* 43498 (1010) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    52561508, /* 43499 (1010) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    52569932, /* 43500 (1010) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
        7410, /* 43501 (1010) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    52556972, /* 43502 (1010) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    52565882, /* 43503 (1010) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    52556810, /* 43504 (1010) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
       11784, /* 43505 (1010) [ 0,  1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  0]  1 */
        7896, /* 43506 (1010) [ 0, -1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    52561022, /* 43507 (1010) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 6,  6,  6] -1 */
       11786, /* 43508 (1010) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    52569930, /* 43509 (1010) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
        3360, /* 43510 (1010) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
        7898, /* 43511 (1010) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    52570092, /* 43512 (1010) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    52565880, /* 43513 (1010) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    52556808, /* 43514 (1010) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
       16322, /* 43515 (1010) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
        3200, /* 43516 (1010) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
        3362, /* 43517 (1010) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
       12272, /* 43518 (1010) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 0,  0,  0]  1 */
        7412, /* 43519 (1010) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    52561020, /* 43520 (1010) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 6,  6,  6] -1 */
       16482, /* 43521 (1010) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
       16484, /* 43522 (1011) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
      121460, /* 43523 (1011) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6]  1 */
      121458, /* 43524 (1011) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  6]  1 */
      134418, /* 43525 (1011) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  6]  1 */
        3200, /* 43526 (1011) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
      125508, /* 43527 (1011) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  6]  1 */
       11784, /* 43528 (1011) [ 0,  1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  0]  1 */
      130368, /* 43529 (1011) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  6]  1 */
        7896, /* 43530 (1011) [ 0, -1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  0]  1 */
        3198, /* 43531 (1011) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
      130370, /* 43532 (1011) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 0,  0,  6]  1 */
       11786, /* 43533 (1011) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  0]  1 */
      134420, /* 43534 (1011) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6]  1 */
        7898, /* 43535 (1011) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 0,  0,  0]  1 */
      125510, /* 43536 (1011) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  6]  1 */
       16482, /* 43537 (1011) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
       16484, /* 43538 (1012) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34137732, /* 43539 (1012) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  6] -1 */
      134418, /* 43540 (1012) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  6]  1 */
      130368, /* 43541 (1012) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  6]  1 */
        3198, /* 43542 (1012) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    34024008, /* 43543 (1012) [ 0,  1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    34020120, /* 43544 (1012) [ 0, -1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  0] -1 */
      125508, /* 43545 (1012) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  6]  1 */
    34024010, /* 43546 (1012) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    34146644, /* 43547 (1012) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    34020122, /* 43548 (1012) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    34133684, /* 43549 (1012) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    34133682, /* 43550 (1012) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
    34015424, /* 43551 (1012) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    34028708, /* 43552 (1012) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    34142594, /* 43553 (1012) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 0,  0,  6] -1 */
       11784, /* 43554 (1012) [ 0,  1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  0]  1 */
        7896, /* 43555 (1012) [ 0, -1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    34028706, /* 43556 (1012) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    34137734, /* 43557 (1012) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  6] -1 */
       11786, /* 43558 (1012) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34146642, /* 43559 (1012) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
      134420, /* 43560 (1012) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6]  1 */
        7898, /* 43561 (1012) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 0,  0,  0]  1 */
      121460, /* 43562 (1012) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6]  1 */
    34142592, /* 43563 (1012) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  6] -1 */
    34015422, /* 43564 (1012) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
      121458, /* 43565 (1012) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  6]  1 */
        3200, /* 43566 (1012) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
      130370, /* 43567 (1012) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 0,  0,  6]  1 */
      125510, /* 43568 (1012) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  6]  1 */
       16482, /* 43569 (1012) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
       16484, /* 43570 (1013) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34142592, /* 43571 (1013) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  6] -1 */
    34024008, /* 43572 (1013) [ 0,  1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    34015422, /* 43573 (1013) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    34137732, /* 43574 (1013) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  6] -1 */
        3200, /* 43575 (1013) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
      121460, /* 43576 (1013) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6]  1 */
    34020120, /* 43577 (1013) [ 0, -1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    34028706, /* 43578 (1013) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
      134420, /* 43579 (1013) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6]  1 */
      130370, /* 43580 (1013) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 0,  0,  6]  1 */
       11786, /* 43581 (1013) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34146642, /* 43582 (1013) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
    34133682, /* 43583 (1013) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
        7898, /* 43584 (1013) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 0,  0,  0]  1 */
      125510, /* 43585 (1013) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  6]  1 */
       16484, /* 43586 (1014) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34024008, /* 43587 (1014) [ 0,  1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    34020120, /* 43588 (1014) [ 0, -1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  0] -1 */
        3200, /* 43589 (1014) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
      125508, /* 43590 (1014) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  6]  1 */
      130368, /* 43591 (1014) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  6]  1 */
    34024010, /* 43592 (1014) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    34146644, /* 43593 (1014) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
        3198, /* 43594 (1014) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    34020122, /* 43595 (1014) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    34133684, /* 43596 (1014) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
      130370, /* 43597 (1014) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 0,  0,  6]  1 */
    34133682, /* 43598 (1014) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
    34146642, /* 43599 (1014) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
      125510, /* 43600 (1014) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  6]  1 */
       16482, /* 43601 (1014) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
       16484, /* 43602 (1015) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34024008, /* 43603 (1015) [ 0,  1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  0] -1 */
      121460, /* 43604 (1015) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6]  1 */
    34142592, /* 43605 (1015) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  6] -1 */
      134418, /* 43606 (1015) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  6]  1 */
        3200, /* 43607 (1015) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34137732, /* 43608 (1015) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  6] -1 */
    34142594, /* 43609 (1015) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    34024010, /* 43610 (1015) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  0] -1 */
      121458, /* 43611 (1015) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  6]  1 */
    34020120, /* 43612 (1015) [ 0, -1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  0] -1 */
        3198, /* 43613 (1015) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    34020122, /* 43614 (1015) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    34137734, /* 43615 (1015) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  6] -1 */
      134420, /* 43616 (1015) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6]  1 */
       16482, /* 43617 (1015) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
       16484, /* 43618 (1016) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34142592, /* 43619 (1016) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  6] -1 */
    34137732, /* 43620 (1016) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  6] -1 */
    34015422, /* 43621 (1016) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
      134418, /* 43622 (1016) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  6]  1 */
        3200, /* 43623 (1016) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
      121458, /* 43624 (1016) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  6]  1 */
    34024010, /* 43625 (1016) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  0] -1 */
       11784, /* 43626 (1016) [ 0,  1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    34146644, /* 43627 (1016) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
        7896, /* 43628 (1016) [ 0, -1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    34028706, /* 43629 (1016) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    34020122, /* 43630 (1016) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    34133684, /* 43631 (1016) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
      130370, /* 43632 (1016) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 0,  0,  6]  1 */
      125510, /* 43633 (1016) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  6]  1 */
       16484, /* 43634 (1017) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34142592, /* 43635 (1017) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  6] -1 */
    34137732, /* 43636 (1017) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  6] -1 */
        3200, /* 43637 (1017) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34142594, /* 43638 (1017) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 0,  0,  6] -1 */
       11784, /* 43639 (1017) [ 0,  1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    34146644, /* 43640 (1017) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
        7896, /* 43641 (1017) [ 0, -1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  0]  1 */
        3198, /* 43642 (1017) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    34133684, /* 43643 (1017) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    34137734, /* 43644 (1017) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  6] -1 */
       11786, /* 43645 (1017) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34146642, /* 43646 (1017) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
    34133682, /* 43647 (1017) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
        7898, /* 43648 (1017) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 0,  0,  0]  1 */
       16482, /* 43649 (1017) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
       16484, /* 43650 (1018) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
      121460, /* 43651 (1018) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6]  1 */
    34015422, /* 43652 (1018) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
        3200, /* 43653 (1018) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34142594, /* 43654 (1018) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 0,  0,  6] -1 */
      125508, /* 43655 (1018) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  6]  1 */
      130368, /* 43656 (1018) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  6]  1 */
       11784, /* 43657 (1018) [ 0,  1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    34024010, /* 43658 (1018) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  0] -1 */
        7896, /* 43659 (1018) [ 0, -1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    34028706, /* 43660 (1018) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    34020122, /* 43661 (1018) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    34137734, /* 43662 (1018) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    34133682, /* 43663 (1018) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
    34146642, /* 43664 (1018) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
      134420, /* 43665 (1018) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6]  1 */
       16484, /* 43666 (1019) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34024008, /* 43667 (1019) [ 0,  1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    34015422, /* 43668 (1019) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
      134418, /* 43669 (1019) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  6]  1 */
        3200, /* 43670 (1019) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
      121458, /* 43671 (1019) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  6]  1 */
      125508, /* 43672 (1019) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  6]  1 */
      130368, /* 43673 (1019) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  6]  1 */
    34142594, /* 43674 (1019) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    34020120, /* 43675 (1019) [ 0, -1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    34146644, /* 43676 (1019) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    34028706, /* 43677 (1019) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    34133684, /* 43678 (1019) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    34137734, /* 43679 (1019) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  6] -1 */
       11786, /* 43680 (1019) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  0]  1 */
        7898, /* 43681 (1019) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 0,  0,  0]  1 */
       16484, /* 43682 (1020) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
      134418, /* 43683 (1020) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  6]  1 */
    34019634, /* 43684 (1020) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  0] -1 */
      130368, /* 43685 (1020) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  6]  1 */
        3198, /* 43686 (1020) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    34142108, /* 43687 (1020) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  6] -1 */
      125508, /* 43688 (1020) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  6]  1 */
    34015584, /* 43689 (1020) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    34138220, /* 43690 (1020) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    34142106, /* 43691 (1020) [ 0,  1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  6] -1 */
    34138218, /* 43692 (1020) [ 0, -1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  6] -1 */
    34146806, /* 43693 (1020) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    34028546, /* 43694 (1020) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    34024496, /* 43695 (1020) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    34015586, /* 43696 (1020) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    34133522, /* 43697 (1020) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
       11784, /* 43698 (1020) [ 0,  1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    34019636, /* 43699 (1020) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  0] -1 */
        7896, /* 43700 (1020) [ 0, -1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  0]  1 */
       11786, /* 43701 (1020) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  0]  1 */
      134420, /* 43702 (1020) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6]  1 */
    34146804, /* 43703 (1020) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
        7898, /* 43704 (1020) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34028544, /* 43705 (1020) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
      121460, /* 43706 (1020) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6]  1 */
      121458, /* 43707 (1020) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  6]  1 */
        3200, /* 43708 (1020) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34024494, /* 43709 (1020) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    34133520, /* 43710 (1020) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
      130370, /* 43711 (1020) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 0,  0,  6]  1 */
      125510, /* 43712 (1020) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  6]  1 */
       16482, /* 43713 (1020) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
       16484, /* 43714 (1021) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
      134418, /* 43715 (1021) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  6]  1 */
      130368, /* 43716 (1021) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  6]  1 */
    52443408, /* 43717 (1021) [ 0, -1,  0,  1,  0,  0,  0,  0, -1] [ 6,  6,  0] -1 */
    52447298, /* 43718 (1021) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 6,  6,  0] -1 */
    52451996, /* 43719 (1021) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
        3198, /* 43720 (1021) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    52556970, /* 43721 (1021) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    52443410, /* 43722 (1021) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 6,  6,  0] -1 */
    52447296, /* 43723 (1021) [ 0,  1,  0, -1,  0,  0,  0,  0, -1] [ 6,  6,  0] -1 */
    52561020, /* 43724 (1021) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 6,  6,  6] -1 */
      125508, /* 43725 (1021) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  6]  1 */
    52569932, /* 43726 (1021) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    52556972, /* 43727 (1021) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    52565882, /* 43728 (1021) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    52438712, /* 43729 (1021) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
       11784, /* 43730 (1021) [ 0,  1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  0]  1 */
        7896, /* 43731 (1021) [ 0, -1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    52451994, /* 43732 (1021) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
    52561022, /* 43733 (1021) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 6,  6,  6] -1 */
       11786, /* 43734 (1021) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    52569930, /* 43735 (1021) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
      134420, /* 43736 (1021) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6]  1 */
        7898, /* 43737 (1021) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    52565880, /* 43738 (1021) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 6,  6,  6] -1 */
      121460, /* 43739 (1021) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6]  1 */
      121458, /* 43740 (1021) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  6]  1 */
    52438710, /* 43741 (1021) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
        3200, /* 43742 (1021) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
      130370, /* 43743 (1021) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 0,  0,  6]  1 */
      125510, /* 43744 (1021) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  6]  1 */
       16482, /* 43745 (1021) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
       16484, /* 43746 (1022) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    52442922, /* 43747 (1022) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 6,  6,  0] -1 */
      134418, /* 43748 (1022) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  6]  1 */
    52561506, /* 43749 (1022) [ 0, -1,  0,  1,  0,  0,  0,  0, -1] [ 6,  6,  6] -1 */
      130368, /* 43750 (1022) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  6]  1 */
        3198, /* 43751 (1022) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    52565394, /* 43752 (1022) [ 0,  1,  0, -1,  0,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    52438872, /* 43753 (1022) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
    52570094, /* 43754 (1022) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    52451834, /* 43755 (1022) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
    52565396, /* 43756 (1022) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    52561508, /* 43757 (1022) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 6,  6,  6] -1 */
      125508, /* 43758 (1022) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  6]  1 */
    52438874, /* 43759 (1022) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
    52447784, /* 43760 (1022) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 6,  6,  0] -1 */
    52556810, /* 43761 (1022) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
       11784, /* 43762 (1022) [ 0,  1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    52442924, /* 43763 (1022) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 6,  6,  0] -1 */
        7896, /* 43764 (1022) [ 0, -1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    52447782, /* 43765 (1022) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 6,  6,  0] -1 */
       11786, /* 43766 (1022) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  0]  1 */
      134420, /* 43767 (1022) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6]  1 */
        7898, /* 43768 (1022) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    52570092, /* 43769 (1022) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    52451832, /* 43770 (1022) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
    52556808, /* 43771 (1022) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
      121460, /* 43772 (1022) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6]  1 */
      121458, /* 43773 (1022) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  6]  1 */
        3200, /* 43774 (1022) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
      130370, /* 43775 (1022) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 0,  0,  6]  1 */
      125510, /* 43776 (1022) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  6]  1 */
       16482, /* 43777 (1022) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
       16484, /* 43778 (1023) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
        3200, /* 43779 (1023) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
       11786, /* 43780 (1023) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    18435560, /* 43781 (1023) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 6,  6,  0]  1 */
        3360, /* 43782 (1023) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
        7898, /* 43783 (1023) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    18431184, /* 43784 (1023) [ 0, -1,  0,  1,  0,  0,  0,  0, -1] [ 6,  6,  0]  1 */
    18439610, /* 43785 (1023) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
       12270, /* 43786 (1023) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  0]  1 */
        7410, /* 43787 (1023) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    18430700, /* 43788 (1023) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    18426486, /* 43789 (1023) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
    18439770, /* 43790 (1023) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
    18435072, /* 43791 (1023) [ 0,  1,  0, -1,  0,  0,  0,  0, -1] [ 6,  6,  0]  1 */
       16320, /* 43792 (1023) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    18426650, /* 43793 (1023) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
       16484, /* 43794 (1024) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34019634, /* 43795 (1024) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  0] -1 */
       11786, /* 43796 (1024) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    52447296, /* 43797 (1024) [ 0,  1,  0, -1,  0,  0,  0,  0, -1] [ 6,  6,  0] -1 */
       12270, /* 43798 (1024) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    34028544, /* 43799 (1024) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    18426486, /* 43800 (1024) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
    34015584, /* 43801 (1024) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    18426650, /* 43802 (1024) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    52451834, /* 43803 (1024) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
    34020122, /* 43804 (1024) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 0,  0,  0] -1 */
        7410, /* 43805 (1024) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    18435072, /* 43806 (1024) [ 0,  1,  0, -1,  0,  0,  0,  0, -1] [ 6,  6,  0]  1 */
       16320, /* 43807 (1024) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    34015424, /* 43808 (1024) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    34028708, /* 43809 (1024) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    52447784, /* 43810 (1024) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 6,  6,  0] -1 */
    52443408, /* 43811 (1024) [ 0, -1,  0,  1,  0,  0,  0,  0, -1] [ 6,  6,  0] -1 */
        3360, /* 43812 (1024) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
        7898, /* 43813 (1024) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    52442924, /* 43814 (1024) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 6,  6,  0] -1 */
    18439610, /* 43815 (1024) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    52451994, /* 43816 (1024) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
    34024010, /* 43817 (1024) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  0] -1 */
        3200, /* 43818 (1024) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    52438710, /* 43819 (1024) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
    18435560, /* 43820 (1024) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    34024494, /* 43821 (1024) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    18431184, /* 43822 (1024) [ 0, -1,  0,  1,  0,  0,  0,  0, -1] [ 6,  6,  0]  1 */
    52438874, /* 43823 (1024) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
    18430700, /* 43824 (1024) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    18439770, /* 43825 (1024) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
       16484, /* 43826 (1025) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
        3200, /* 43827 (1025) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34019634, /* 43828 (1025) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  0] -1 */
       11786, /* 43829 (1025) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    52438710, /* 43830 (1025) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
    18435560, /* 43831 (1025) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 6,  6,  0]  1 */
        7898, /* 43832 (1025) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34024494, /* 43833 (1025) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    52447296, /* 43834 (1025) [ 0,  1,  0, -1,  0,  0,  0,  0, -1] [ 6,  6,  0] -1 */
    18439610, /* 43835 (1025) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    52451994, /* 43836 (1025) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
    18430700, /* 43837 (1025) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    34028544, /* 43838 (1025) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    34015584, /* 43839 (1025) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    18426650, /* 43840 (1025) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    52443408, /* 43841 (1025) [ 0, -1,  0,  1,  0,  0,  0,  0, -1] [ 6,  6,  0] -1 */
       16484, /* 43842 (1026) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
        3200, /* 43843 (1026) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34020122, /* 43844 (1026) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    18435560, /* 43845 (1026) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    52447296, /* 43846 (1026) [ 0,  1,  0, -1,  0,  0,  0,  0, -1] [ 6,  6,  0] -1 */
    52451834, /* 43847 (1026) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
    52438874, /* 43848 (1026) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
       12270, /* 43849 (1026) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  0]  1 */
        7410, /* 43850 (1026) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    34028544, /* 43851 (1026) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    18426486, /* 43852 (1026) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
    18430700, /* 43853 (1026) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    18439770, /* 43854 (1026) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
    34015584, /* 43855 (1026) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    34024010, /* 43856 (1026) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    52443408, /* 43857 (1026) [ 0, -1,  0,  1,  0,  0,  0,  0, -1] [ 6,  6,  0] -1 */
       16484, /* 43858 (1027) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
        3200, /* 43859 (1027) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34020122, /* 43860 (1027) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    34019634, /* 43861 (1027) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  0] -1 */
        3360, /* 43862 (1027) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    34024494, /* 43863 (1027) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    52447296, /* 43864 (1027) [ 0,  1,  0, -1,  0,  0,  0,  0, -1] [ 6,  6,  0] -1 */
    52442924, /* 43865 (1027) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 6,  6,  0] -1 */
    18439610, /* 43866 (1027) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    18426486, /* 43867 (1027) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
    18439770, /* 43868 (1027) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
       16320, /* 43869 (1027) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    34024010, /* 43870 (1027) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    18426650, /* 43871 (1027) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    52447784, /* 43872 (1027) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 6,  6,  0] -1 */
    52443408, /* 43873 (1027) [ 0, -1,  0,  1,  0,  0,  0,  0, -1] [ 6,  6,  0] -1 */
       16484, /* 43874 (1028) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
        3200, /* 43875 (1028) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34020122, /* 43876 (1028) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    34019634, /* 43877 (1028) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    52438710, /* 43878 (1028) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
    18435560, /* 43879 (1028) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 6,  6,  0]  1 */
        3360, /* 43880 (1028) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    34024494, /* 43881 (1028) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    18431184, /* 43882 (1028) [ 0, -1,  0,  1,  0,  0,  0,  0, -1] [ 6,  6,  0]  1 */
    52438874, /* 43883 (1028) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
    52451994, /* 43884 (1028) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
    18430700, /* 43885 (1028) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    18435072, /* 43886 (1028) [ 0,  1,  0, -1,  0,  0,  0,  0, -1] [ 6,  6,  0]  1 */
       16320, /* 43887 (1028) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    34024010, /* 43888 (1028) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    52451834, /* 43889 (1028) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
       16484, /* 43890 (1029) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
        3200, /* 43891 (1029) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34019634, /* 43892 (1029) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  0] -1 */
       11786, /* 43893 (1029) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  0]  1 */
        7898, /* 43894 (1029) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34024494, /* 43895 (1029) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    52442924, /* 43896 (1029) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 6,  6,  0] -1 */
    18431184, /* 43897 (1029) [ 0, -1,  0,  1,  0,  0,  0,  0, -1] [ 6,  6,  0]  1 */
    52438874, /* 43898 (1029) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
    34028544, /* 43899 (1029) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    18426486, /* 43900 (1029) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
    18439770, /* 43901 (1029) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
    18435072, /* 43902 (1029) [ 0,  1,  0, -1,  0,  0,  0,  0, -1] [ 6,  6,  0]  1 */
    34015584, /* 43903 (1029) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    52447784, /* 43904 (1029) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 6,  6,  0] -1 */
    52451834, /* 43905 (1029) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
       16484, /* 43906 (1030) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
        3200, /* 43907 (1030) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34020122, /* 43908 (1030) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    52438710, /* 43909 (1030) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
    52442924, /* 43910 (1030) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 6,  6,  0] -1 */
    18431184, /* 43911 (1030) [ 0, -1,  0,  1,  0,  0,  0,  0, -1] [ 6,  6,  0]  1 */
    18439610, /* 43912 (1030) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
       12270, /* 43913 (1030) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  0]  1 */
        7410, /* 43914 (1030) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    34028544, /* 43915 (1030) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    52451994, /* 43916 (1030) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
    18435072, /* 43917 (1030) [ 0,  1,  0, -1,  0,  0,  0,  0, -1] [ 6,  6,  0]  1 */
    34015584, /* 43918 (1030) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    34024010, /* 43919 (1030) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    18426650, /* 43920 (1030) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    52447784, /* 43921 (1030) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 6,  6,  0] -1 */
       16484, /* 43922 (1031) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
        3200, /* 43923 (1031) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
       11786, /* 43924 (1031) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    52438710, /* 43925 (1031) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
        3360, /* 43926 (1031) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
        7898, /* 43927 (1031) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    52447296, /* 43928 (1031) [ 0,  1,  0, -1,  0,  0,  0,  0, -1] [ 6,  6,  0] -1 */
    52442924, /* 43929 (1031) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 6,  6,  0] -1 */
    52451834, /* 43930 (1031) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
    52438874, /* 43931 (1031) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
       12270, /* 43932 (1031) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  0]  1 */
        7410, /* 43933 (1031) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    52451994, /* 43934 (1031) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
       16320, /* 43935 (1031) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    52447784, /* 43936 (1031) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 6,  6,  0] -1 */
    52443408, /* 43937 (1031) [ 0, -1,  0,  1,  0,  0,  0,  0, -1] [ 6,  6,  0] -1 */
       16484, /* 43938 (1032) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
       11786, /* 43939 (1032) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  0]  1 */
       12270, /* 43940 (1032) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    18426486, /* 43941 (1032) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
    34146642, /* 43942 (1032) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
    18426650, /* 43943 (1032) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
        7410, /* 43944 (1032) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    34146806, /* 43945 (1032) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    18435072, /* 43946 (1032) [ 0,  1,  0, -1,  0,  0,  0,  0, -1] [ 6,  6,  0]  1 */
       16320, /* 43947 (1032) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    52565882, /* 43948 (1032) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    34133522, /* 43949 (1032) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
        3360, /* 43950 (1032) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
        7898, /* 43951 (1032) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    52561506, /* 43952 (1032) [ 0, -1,  0,  1,  0,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    18439610, /* 43953 (1032) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    52561022, /* 43954 (1032) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    34142108, /* 43955 (1032) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    52570092, /* 43956 (1032) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
        3200, /* 43957 (1032) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34142592, /* 43958 (1032) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  6] -1 */
    52565394, /* 43959 (1032) [ 0,  1,  0, -1,  0,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    18435560, /* 43960 (1032) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    34133682, /* 43961 (1032) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
    52569932, /* 43962 (1032) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    52556972, /* 43963 (1032) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    34138220, /* 43964 (1032) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    18431184, /* 43965 (1032) [ 0, -1,  0,  1,  0,  0,  0,  0, -1] [ 6,  6,  0]  1 */
    52556808, /* 43966 (1032) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    18430700, /* 43967 (1032) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    18439770, /* 43968 (1032) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
    34137732, /* 43969 (1032) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  6] -1 */
       16484, /* 43970 (1033) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
       11786, /* 43971 (1033) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    52442922, /* 43972 (1033) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 6,  6,  0] -1 */
    34020120, /* 43973 (1033) [ 0, -1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  0] -1 */
       12270, /* 43974 (1033) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    52451996, /* 43975 (1033) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
    18426486, /* 43976 (1033) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
    18426650, /* 43977 (1033) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    52447298, /* 43978 (1033) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 6,  6,  0] -1 */
    34015586, /* 43979 (1033) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
        7410, /* 43980 (1033) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    18435072, /* 43981 (1033) [ 0,  1,  0, -1,  0,  0,  0,  0, -1] [ 6,  6,  0]  1 */
       16320, /* 43982 (1033) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    52438712, /* 43983 (1033) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
    34024496, /* 43984 (1033) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 0,  0,  0] -1 */
        3360, /* 43985 (1033) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
        7898, /* 43986 (1033) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34019636, /* 43987 (1033) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    52451832, /* 43988 (1033) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
    18439610, /* 43989 (1033) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    34028706, /* 43990 (1033) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    34024008, /* 43991 (1033) [ 0,  1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    52438872, /* 43992 (1033) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
    52447782, /* 43993 (1033) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 6,  6,  0] -1 */
    34028546, /* 43994 (1033) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
        3200, /* 43995 (1033) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    18435560, /* 43996 (1033) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    34015422, /* 43997 (1033) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    52443410, /* 43998 (1033) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 6,  6,  0] -1 */
    18431184, /* 43999 (1033) [ 0, -1,  0,  1,  0,  0,  0,  0, -1] [ 6,  6,  0]  1 */
    18430700, /* 44000 (1033) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    18439770, /* 44001 (1033) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
       16484, /* 44002 (1034) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    52561020, /* 44003 (1034) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 6,  6,  6] -1 */
       11786, /* 44004 (1034) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  0]  1 */
       12270, /* 44005 (1034) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    18426486, /* 44006 (1034) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
    52569930, /* 44007 (1034) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    18426650, /* 44008 (1034) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    52570094, /* 44009 (1034) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
        7410, /* 44010 (1034) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    18435072, /* 44011 (1034) [ 0,  1,  0, -1,  0,  0,  0,  0, -1] [ 6,  6,  0]  1 */
       16320, /* 44012 (1034) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    52556810, /* 44013 (1034) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
        3360, /* 44014 (1034) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
        7898, /* 44015 (1034) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34142594, /* 44016 (1034) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    18439610, /* 44017 (1034) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    34138218, /* 44018 (1034) [ 0, -1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  6] -1 */
    34137734, /* 44019 (1034) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    52556970, /* 44020 (1034) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    34146804, /* 44021 (1034) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
    34142106, /* 44022 (1034) [ 0,  1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  6] -1 */
    52561508, /* 44023 (1034) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    52565880, /* 44024 (1034) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    52565396, /* 44025 (1034) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    34133520, /* 44026 (1034) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
        3200, /* 44027 (1034) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34146644, /* 44028 (1034) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    18435560, /* 44029 (1034) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    18431184, /* 44030 (1034) [ 0, -1,  0,  1,  0,  0,  0,  0, -1] [ 6,  6,  0]  1 */
    18430700, /* 44031 (1034) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    34133684, /* 44032 (1034) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    18439770, /* 44033 (1034) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
       16484, /* 44034 (1023) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    18426488, /* 44035 (1023) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
     1428962, /* 44036 (1023) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 0,  6,  0]  1 */
    18435560, /* 44037 (1023) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    17009472, /* 44038 (1023) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  0]  1 */
    17014010, /* 44039 (1023) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 6,  0,  0]  1 */
     1425072, /* 44040 (1023) [ 0, -1,  0,  1,  0,  0,  0,  0, -1] [ 0,  6,  0]  1 */
    17022434, /* 44041 (1023) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  0]  1 */
       12270, /* 44042 (1023) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    18430698, /* 44043 (1023) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 6,  6,  0]  1 */
        7412, /* 44044 (1023) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  0]  1 */
        3198, /* 44045 (1023) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    18439770, /* 44046 (1023) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
    17017896, /* 44047 (1023) [ 0,  1,  0, -1,  0,  0,  0,  0, -1] [ 6,  0,  0]  1 */
     1433496, /* 44048 (1023) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  0]  1 */
     1420538, /* 44049 (1023) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  0]  1 */
       16484, /* 44050 (1024) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    52442922, /* 44051 (1024) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 6,  6,  0] -1 */
     1428962, /* 44052 (1024) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 0,  6,  0]  1 */
    51030120, /* 44053 (1024) [ 0,  1,  0, -1,  0,  0,  0,  0, -1] [ 6,  0,  0] -1 */
       12270, /* 44054 (1024) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    35445720, /* 44055 (1024) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  0] -1 */
        3198, /* 44056 (1024) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    51021696, /* 44057 (1024) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  0] -1 */
     1420538, /* 44058 (1024) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  0]  1 */
    51034658, /* 44059 (1024) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  0] -1 */
    51026234, /* 44060 (1024) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 6,  0,  0] -1 */
    18430698, /* 44061 (1024) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 6,  6,  0]  1 */
    17017896, /* 44062 (1024) [ 0,  1,  0, -1,  0,  0,  0,  0, -1] [ 6,  0,  0]  1 */
     1433496, /* 44063 (1024) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  0]  1 */
    52438712, /* 44064 (1024) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
    34028708, /* 44065 (1024) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    52447784, /* 44066 (1024) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 6,  6,  0] -1 */
    35437296, /* 44067 (1024) [ 0, -1,  0,  1,  0,  0,  0,  0, -1] [ 0,  6,  0] -1 */
    17009472, /* 44068 (1024) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  0]  1 */
    17014010, /* 44069 (1024) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 6,  0,  0]  1 */
    34019636, /* 44070 (1024) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    17022434, /* 44071 (1024) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  0]  1 */
    52451994, /* 44072 (1024) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
    35441186, /* 44073 (1024) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 0,  6,  0] -1 */
    18426488, /* 44074 (1024) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    34015422, /* 44075 (1024) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    18435560, /* 44076 (1024) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    34024494, /* 44077 (1024) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  0] -1 */
     1425072, /* 44078 (1024) [ 0, -1,  0,  1,  0,  0,  0,  0, -1] [ 0,  6,  0]  1 */
    35432762, /* 44079 (1024) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  0] -1 */
        7412, /* 44080 (1024) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    18439770, /* 44081 (1024) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
       16484, /* 44082 (1025) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    18426488, /* 44083 (1025) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    52442922, /* 44084 (1025) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 6,  6,  0] -1 */
     1428962, /* 44085 (1025) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 0,  6,  0]  1 */
    34015422, /* 44086 (1025) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    18435560, /* 44087 (1025) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    17014010, /* 44088 (1025) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 6,  0,  0]  1 */
    34024494, /* 44089 (1025) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    51030120, /* 44090 (1025) [ 0,  1,  0, -1,  0,  0,  0,  0, -1] [ 6,  0,  0] -1 */
    17022434, /* 44091 (1025) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  0]  1 */
    52451994, /* 44092 (1025) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
        7412, /* 44093 (1025) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    35445720, /* 44094 (1025) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  0] -1 */
    51021696, /* 44095 (1025) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  0] -1 */
     1420538, /* 44096 (1025) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  0]  1 */
    35437296, /* 44097 (1025) [ 0, -1,  0,  1,  0,  0,  0,  0, -1] [ 0,  6,  0] -1 */
       16484, /* 44098 (1026) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    18426488, /* 44099 (1026) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    51026234, /* 44100 (1026) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 6,  0,  0] -1 */
    18435560, /* 44101 (1026) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    51030120, /* 44102 (1026) [ 0,  1,  0, -1,  0,  0,  0,  0, -1] [ 6,  0,  0] -1 */
    51034658, /* 44103 (1026) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  0] -1 */
    35432762, /* 44104 (1026) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  0] -1 */
       12270, /* 44105 (1026) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    18430698, /* 44106 (1026) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 6,  6,  0]  1 */
    35445720, /* 44107 (1026) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  0] -1 */
        3198, /* 44108 (1026) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
        7412, /* 44109 (1026) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    18439770, /* 44110 (1026) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
    51021696, /* 44111 (1026) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  0] -1 */
    35441186, /* 44112 (1026) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 0,  6,  0] -1 */
    35437296, /* 44113 (1026) [ 0, -1,  0,  1,  0,  0,  0,  0, -1] [ 0,  6,  0] -1 */
       16484, /* 44114 (1027) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    18426488, /* 44115 (1027) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    51026234, /* 44116 (1027) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 6,  0,  0] -1 */
    52442922, /* 44117 (1027) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 6,  6,  0] -1 */
    17009472, /* 44118 (1027) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  0]  1 */
    34024494, /* 44119 (1027) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    51030120, /* 44120 (1027) [ 0,  1,  0, -1,  0,  0,  0,  0, -1] [ 6,  0,  0] -1 */
    34019636, /* 44121 (1027) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    17022434, /* 44122 (1027) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  0]  1 */
        3198, /* 44123 (1027) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    18439770, /* 44124 (1027) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
     1433496, /* 44125 (1027) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  0]  1 */
    35441186, /* 44126 (1027) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 0,  6,  0] -1 */
     1420538, /* 44127 (1027) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  0]  1 */
    52447784, /* 44128 (1027) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 6,  6,  0] -1 */
    35437296, /* 44129 (1027) [ 0, -1,  0,  1,  0,  0,  0,  0, -1] [ 0,  6,  0] -1 */
       16484, /* 44130 (1028) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    18426488, /* 44131 (1028) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    51026234, /* 44132 (1028) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 6,  0,  0] -1 */
    52442922, /* 44133 (1028) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 6,  6,  0] -1 */
    34015422, /* 44134 (1028) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    18435560, /* 44135 (1028) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    17009472, /* 44136 (1028) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  0]  1 */
    34024494, /* 44137 (1028) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  0] -1 */
     1425072, /* 44138 (1028) [ 0, -1,  0,  1,  0,  0,  0,  0, -1] [ 0,  6,  0]  1 */
    35432762, /* 44139 (1028) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  0] -1 */
    52451994, /* 44140 (1028) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
        7412, /* 44141 (1028) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    17017896, /* 44142 (1028) [ 0,  1,  0, -1,  0,  0,  0,  0, -1] [ 6,  0,  0]  1 */
     1433496, /* 44143 (1028) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  0]  1 */
    35441186, /* 44144 (1028) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 0,  6,  0] -1 */
    51034658, /* 44145 (1028) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  0] -1 */
       16484, /* 44146 (1029) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    18426488, /* 44147 (1029) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    52442922, /* 44148 (1029) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 6,  6,  0] -1 */
     1428962, /* 44149 (1029) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 0,  6,  0]  1 */
    17014010, /* 44150 (1029) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 6,  0,  0]  1 */
    34024494, /* 44151 (1029) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    34019636, /* 44152 (1029) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  0] -1 */
     1425072, /* 44153 (1029) [ 0, -1,  0,  1,  0,  0,  0,  0, -1] [ 0,  6,  0]  1 */
    35432762, /* 44154 (1029) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  0] -1 */
    35445720, /* 44155 (1029) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  0] -1 */
        3198, /* 44156 (1029) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    18439770, /* 44157 (1029) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
    17017896, /* 44158 (1029) [ 0,  1,  0, -1,  0,  0,  0,  0, -1] [ 6,  0,  0]  1 */
    51021696, /* 44159 (1029) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  0] -1 */
    52447784, /* 44160 (1029) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 6,  6,  0] -1 */
    51034658, /* 44161 (1029) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  0] -1 */
       16484, /* 44162 (1030) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    18426488, /* 44163 (1030) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    51026234, /* 44164 (1030) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 6,  0,  0] -1 */
    34015422, /* 44165 (1030) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    34019636, /* 44166 (1030) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  0] -1 */
     1425072, /* 44167 (1030) [ 0, -1,  0,  1,  0,  0,  0,  0, -1] [ 0,  6,  0]  1 */
    17022434, /* 44168 (1030) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  0]  1 */
       12270, /* 44169 (1030) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    18430698, /* 44170 (1030) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 6,  6,  0]  1 */
    35445720, /* 44171 (1030) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  0] -1 */
    52451994, /* 44172 (1030) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
    17017896, /* 44173 (1030) [ 0,  1,  0, -1,  0,  0,  0,  0, -1] [ 6,  0,  0]  1 */
    51021696, /* 44174 (1030) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  0] -1 */
    35441186, /* 44175 (1030) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 0,  6,  0] -1 */
     1420538, /* 44176 (1030) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  0]  1 */
    52447784, /* 44177 (1030) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 6,  6,  0] -1 */
       16484, /* 44178 (1031) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    18426488, /* 44179 (1031) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
     1428962, /* 44180 (1031) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 0,  6,  0]  1 */
    34015422, /* 44181 (1031) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    17009472, /* 44182 (1031) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  0]  1 */
    17014010, /* 44183 (1031) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 6,  0,  0]  1 */
    51030120, /* 44184 (1031) [ 0,  1,  0, -1,  0,  0,  0,  0, -1] [ 6,  0,  0] -1 */
    34019636, /* 44185 (1031) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    51034658, /* 44186 (1031) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  0] -1 */
    35432762, /* 44187 (1031) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  0] -1 */
       12270, /* 44188 (1031) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    18430698, /* 44189 (1031) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 6,  6,  0]  1 */
    52451994, /* 44190 (1031) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
     1433496, /* 44191 (1031) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  0]  1 */
    52447784, /* 44192 (1031) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 6,  6,  0] -1 */
    35437296, /* 44193 (1031) [ 0, -1,  0,  1,  0,  0,  0,  0, -1] [ 0,  6,  0] -1 */
       16484, /* 44194 (1032) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
     1428962, /* 44195 (1032) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 0,  6,  0]  1 */
       12270, /* 44196 (1032) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  0]  1 */
        3198, /* 44197 (1032) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    35563818, /* 44198 (1032) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  6] -1 */
     1420538, /* 44199 (1032) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  0]  1 */
    18430698, /* 44200 (1032) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 6,  6,  0]  1 */
    34146806, /* 44201 (1032) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    17017896, /* 44202 (1032) [ 0,  1,  0, -1,  0,  0,  0,  0, -1] [ 6,  0,  0]  1 */
     1433496, /* 44203 (1032) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  0]  1 */
    52565882, /* 44204 (1032) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    52556810, /* 44205 (1032) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    17009472, /* 44206 (1032) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  0]  1 */
    17014010, /* 44207 (1032) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 6,  0,  0]  1 */
    35555394, /* 44208 (1032) [ 0, -1,  0,  1,  0,  0,  0,  0, -1] [ 0,  6,  6] -1 */
    17022434, /* 44209 (1032) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  0]  1 */
    34137734, /* 44210 (1032) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    35559284, /* 44211 (1032) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 0,  6,  6] -1 */
    52570092, /* 44212 (1032) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    18426488, /* 44213 (1032) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    34142592, /* 44214 (1032) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  6] -1 */
    51148218, /* 44215 (1032) [ 0,  1,  0, -1,  0,  0,  0,  0, -1] [ 6,  0,  6] -1 */
    18435560, /* 44216 (1032) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    51139794, /* 44217 (1032) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6] -1 */
    51152756, /* 44218 (1032) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
    35550860, /* 44219 (1032) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
    51144332, /* 44220 (1032) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 6,  0,  6] -1 */
     1425072, /* 44221 (1032) [ 0, -1,  0,  1,  0,  0,  0,  0, -1] [ 0,  6,  0]  1 */
    34133520, /* 44222 (1032) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
        7412, /* 44223 (1032) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    18439770, /* 44224 (1032) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
    52561020, /* 44225 (1032) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 6,  6,  6] -1 */
       16484, /* 44226 (1033) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
     1428962, /* 44227 (1033) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 0,  6,  0]  1 */
    34019634, /* 44228 (1033) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    51026232, /* 44229 (1033) [ 0, -1,  0,  1,  0,  0,  0,  0, -1] [ 6,  0,  0] -1 */
       12270, /* 44230 (1033) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    52451996, /* 44231 (1033) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
        3198, /* 44232 (1033) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
     1420538, /* 44233 (1033) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  0]  1 */
    51030122, /* 44234 (1033) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 6,  0,  0] -1 */
    51021698, /* 44235 (1033) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  0] -1 */
    18430698, /* 44236 (1033) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 6,  6,  0]  1 */
    17017896, /* 44237 (1033) [ 0,  1,  0, -1,  0,  0,  0,  0, -1] [ 6,  0,  0]  1 */
     1433496, /* 44238 (1033) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  0]  1 */
    34015424, /* 44239 (1033) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    34024496, /* 44240 (1033) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    17009472, /* 44241 (1033) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  0]  1 */
    17014010, /* 44242 (1033) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 6,  0,  0]  1 */
    52442924, /* 44243 (1033) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 6,  6,  0] -1 */
    51034656, /* 44244 (1033) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  0] -1 */
    17022434, /* 44245 (1033) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  0]  1 */
    34028706, /* 44246 (1033) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    35441184, /* 44247 (1033) [ 0,  1,  0, -1,  0,  0,  0,  0, -1] [ 0,  6,  0] -1 */
    35432760, /* 44248 (1033) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  0] -1 */
    52447782, /* 44249 (1033) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 6,  6,  0] -1 */
    35445722, /* 44250 (1033) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  0] -1 */
    18426488, /* 44251 (1033) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    18435560, /* 44252 (1033) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    52438710, /* 44253 (1033) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
    35437298, /* 44254 (1033) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 0,  6,  0] -1 */
     1425072, /* 44255 (1033) [ 0, -1,  0,  1,  0,  0,  0,  0, -1] [ 0,  6,  0]  1 */
        7412, /* 44256 (1033) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    18439770, /* 44257 (1033) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
       16484, /* 44258 (1034) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34137732, /* 44259 (1034) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  6] -1 */
     1428962, /* 44260 (1034) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 0,  6,  0]  1 */
       12270, /* 44261 (1034) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  0]  1 */
        3198, /* 44262 (1034) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    51152754, /* 44263 (1034) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  6] -1 */
     1420538, /* 44264 (1034) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  0]  1 */
    52570094, /* 44265 (1034) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    18430698, /* 44266 (1034) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 6,  6,  0]  1 */
    17017896, /* 44267 (1034) [ 0,  1,  0, -1,  0,  0,  0,  0, -1] [ 6,  0,  0]  1 */
     1433496, /* 44268 (1034) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  0]  1 */
    34133522, /* 44269 (1034) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    17009472, /* 44270 (1034) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  0]  1 */
    17014010, /* 44271 (1034) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 6,  0,  0]  1 */
    34142594, /* 44272 (1034) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    17022434, /* 44273 (1034) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  0]  1 */
    51144330, /* 44274 (1034) [ 0, -1,  0,  1,  0,  0,  0,  0, -1] [ 6,  0,  6] -1 */
    52561022, /* 44275 (1034) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    35550858, /* 44276 (1034) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6] -1 */
    34146804, /* 44277 (1034) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
    35559282, /* 44278 (1034) [ 0,  1,  0, -1,  0,  0,  0,  0, -1] [ 0,  6,  6] -1 */
    35555396, /* 44279 (1034) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 0,  6,  6] -1 */
    52565880, /* 44280 (1034) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    51148220, /* 44281 (1034) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 6,  0,  6] -1 */
    52556808, /* 44282 (1034) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    18426488, /* 44283 (1034) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    35563820, /* 44284 (1034) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
    18435560, /* 44285 (1034) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 6,  6,  0]  1 */
     1425072, /* 44286 (1034) [ 0, -1,  0,  1,  0,  0,  0,  0, -1] [ 0,  6,  0]  1 */
        7412, /* 44287 (1034) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    51139796, /* 44288 (1034) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
    18439770, /* 44289 (1034) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
       16484, /* 44290 (1035) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
        3200, /* 44291 (1035) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
       11786, /* 44292 (1035) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  0]  1 */
       16320, /* 44293 (1035) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
        7898, /* 44294 (1035) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 0,  0,  0]  1 */
       12270, /* 44295 (1035) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  0]  1 */
        7410, /* 44296 (1035) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  0]  1 */
        3360, /* 44297 (1035) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    18549282, /* 44298 (1035) [ 0, -1,  0,  1,  0,  0,  0,  0, -1] [ 6,  6,  6]  1 */
    18544748, /* 44299 (1035) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    18544584, /* 44300 (1035) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
    18557708, /* 44301 (1035) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    18557868, /* 44302 (1035) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
    18553170, /* 44303 (1035) [ 0,  1,  0, -1,  0,  0,  0,  0, -1] [ 6,  6,  6]  1 */
    18548798, /* 44304 (1035) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    18553658, /* 44305 (1035) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 6,  6,  6]  1 */
       16484, /* 44306 (1036) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
       11786, /* 44307 (1036) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  0]  1 */
        3360, /* 44308 (1036) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
       12270, /* 44309 (1036) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    52565394, /* 44310 (1036) [ 0,  1,  0, -1,  0,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    18544748, /* 44311 (1036) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    18544584, /* 44312 (1036) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
    18557708, /* 44313 (1036) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    34028544, /* 44314 (1036) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    34019634, /* 44315 (1036) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    34020122, /* 44316 (1036) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 0,  0,  0] -1 */
        7410, /* 44317 (1036) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    18553170, /* 44318 (1036) [ 0,  1,  0, -1,  0,  0,  0,  0, -1] [ 6,  6,  6]  1 */
    52565882, /* 44319 (1036) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    34015424, /* 44320 (1036) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    34028708, /* 44321 (1036) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    52561506, /* 44322 (1036) [ 0, -1,  0,  1,  0,  0,  0,  0, -1] [ 6,  6,  6] -1 */
       16320, /* 44323 (1036) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
        7898, /* 44324 (1036) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    52570092, /* 44325 (1036) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    52561022, /* 44326 (1036) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    34024010, /* 44327 (1036) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    18553658, /* 44328 (1036) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 6,  6,  6]  1 */
        3200, /* 44329 (1036) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34024494, /* 44330 (1036) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    34015584, /* 44331 (1036) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    52556808, /* 44332 (1036) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    52569932, /* 44333 (1036) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    52556972, /* 44334 (1036) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    18549282, /* 44335 (1036) [ 0, -1,  0,  1,  0,  0,  0,  0, -1] [ 6,  6,  6]  1 */
    18557868, /* 44336 (1036) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
    18548798, /* 44337 (1036) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 6,  6,  6]  1 */
       16484, /* 44338 (1037) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
        3200, /* 44339 (1037) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34024494, /* 44340 (1037) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  0] -1 */
       11786, /* 44341 (1037) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    52556808, /* 44342 (1037) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    34015584, /* 44343 (1037) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
        7898, /* 44344 (1037) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    52565394, /* 44345 (1037) [ 0,  1,  0, -1,  0,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    18544748, /* 44346 (1037) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    52570092, /* 44347 (1037) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    18548798, /* 44348 (1037) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    18557708, /* 44349 (1037) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    34019634, /* 44350 (1037) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    34028544, /* 44351 (1037) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    18553658, /* 44352 (1037) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    52561506, /* 44353 (1037) [ 0, -1,  0,  1,  0,  0,  0,  0, -1] [ 6,  6,  6] -1 */
       16484, /* 44354 (1038) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
        3200, /* 44355 (1038) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34020122, /* 44356 (1038) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    34015584, /* 44357 (1038) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    52569932, /* 44358 (1038) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    52556972, /* 44359 (1038) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    52565394, /* 44360 (1038) [ 0,  1,  0, -1,  0,  0,  0,  0, -1] [ 6,  6,  6] -1 */
       12270, /* 44361 (1038) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  0]  1 */
        7410, /* 44362 (1038) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    18544584, /* 44363 (1038) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
    34024010, /* 44364 (1038) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    18557868, /* 44365 (1038) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
    18548798, /* 44366 (1038) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    34028544, /* 44367 (1038) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    18553658, /* 44368 (1038) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    52561506, /* 44369 (1038) [ 0, -1,  0,  1,  0,  0,  0,  0, -1] [ 6,  6,  6] -1 */
       16484, /* 44370 (1039) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
        3200, /* 44371 (1039) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34020122, /* 44372 (1039) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 0,  0,  0] -1 */
       16320, /* 44373 (1039) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    34024494, /* 44374 (1039) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  0] -1 */
        3360, /* 44375 (1039) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    52565394, /* 44376 (1039) [ 0,  1,  0, -1,  0,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    18544748, /* 44377 (1039) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    18544584, /* 44378 (1039) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
    34024010, /* 44379 (1039) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    52561022, /* 44380 (1039) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    18557708, /* 44381 (1039) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    18557868, /* 44382 (1039) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
    52565882, /* 44383 (1039) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    34019634, /* 44384 (1039) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    52561506, /* 44385 (1039) [ 0, -1,  0,  1,  0,  0,  0,  0, -1] [ 6,  6,  6] -1 */
       16484, /* 44386 (1040) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
        3200, /* 44387 (1040) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34020122, /* 44388 (1040) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 0,  0,  0] -1 */
       16320, /* 44389 (1040) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    52556808, /* 44390 (1040) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    34024494, /* 44391 (1040) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    52569932, /* 44392 (1040) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    52556972, /* 44393 (1040) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
        3360, /* 44394 (1040) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    18549282, /* 44395 (1040) [ 0, -1,  0,  1,  0,  0,  0,  0, -1] [ 6,  6,  6]  1 */
    52570092, /* 44396 (1040) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    18548798, /* 44397 (1040) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    34024010, /* 44398 (1040) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    18553170, /* 44399 (1040) [ 0,  1,  0, -1,  0,  0,  0,  0, -1] [ 6,  6,  6]  1 */
    34019634, /* 44400 (1040) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    18553658, /* 44401 (1040) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 6,  6,  6]  1 */
       16484, /* 44402 (1041) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
        3200, /* 44403 (1041) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34024494, /* 44404 (1041) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  0] -1 */
       11786, /* 44405 (1041) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34015584, /* 44406 (1041) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    52565882, /* 44407 (1041) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    52569932, /* 44408 (1041) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
        7898, /* 44409 (1041) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    52556972, /* 44410 (1041) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    18549282, /* 44411 (1041) [ 0, -1,  0,  1,  0,  0,  0,  0, -1] [ 6,  6,  6]  1 */
    18544584, /* 44412 (1041) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
    52561022, /* 44413 (1041) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    18557868, /* 44414 (1041) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
    18553170, /* 44415 (1041) [ 0,  1,  0, -1,  0,  0,  0,  0, -1] [ 6,  6,  6]  1 */
    34019634, /* 44416 (1041) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    34028544, /* 44417 (1041) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
       16484, /* 44418 (1042) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
        3200, /* 44419 (1042) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34020122, /* 44420 (1042) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    34015584, /* 44421 (1042) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    52556808, /* 44422 (1042) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    52565882, /* 44423 (1042) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 6,  6,  6] -1 */
       12270, /* 44424 (1042) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  0]  1 */
        7410, /* 44425 (1042) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    18549282, /* 44426 (1042) [ 0, -1,  0,  1,  0,  0,  0,  0, -1] [ 6,  6,  6]  1 */
    18544748, /* 44427 (1042) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    52570092, /* 44428 (1042) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    52561022, /* 44429 (1042) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    18557708, /* 44430 (1042) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    18553170, /* 44431 (1042) [ 0,  1,  0, -1,  0,  0,  0,  0, -1] [ 6,  6,  6]  1 */
    34024010, /* 44432 (1042) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    34028544, /* 44433 (1042) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
       16484, /* 44434 (1043) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
        3200, /* 44435 (1043) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
       11786, /* 44436 (1043) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  0]  1 */
       16320, /* 44437 (1043) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    52556808, /* 44438 (1043) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    52569932, /* 44439 (1043) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
        7898, /* 44440 (1043) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 0,  0,  0]  1 */
       12270, /* 44441 (1043) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    52565394, /* 44442 (1043) [ 0,  1,  0, -1,  0,  0,  0,  0, -1] [ 6,  6,  6] -1 */
        7410, /* 44443 (1043) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    52556972, /* 44444 (1043) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
        3360, /* 44445 (1043) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    52570092, /* 44446 (1043) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    52561022, /* 44447 (1043) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    52565882, /* 44448 (1043) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    52561506, /* 44449 (1043) [ 0, -1,  0,  1,  0,  0,  0,  0, -1] [ 6,  6,  6] -1 */
       16484, /* 44450 (1044) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34137732, /* 44451 (1044) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  6] -1 */
       11786, /* 44452 (1044) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  0]  1 */
        3360, /* 44453 (1044) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
       12270, /* 44454 (1044) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    18544748, /* 44455 (1044) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    34146642, /* 44456 (1044) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
    18544584, /* 44457 (1044) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
    18557708, /* 44458 (1044) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    34133682, /* 44459 (1044) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
    52451834, /* 44460 (1044) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
        7410, /* 44461 (1044) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    34146806, /* 44462 (1044) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    18553170, /* 44463 (1044) [ 0,  1,  0, -1,  0,  0,  0,  0, -1] [ 6,  6,  6]  1 */
    52447784, /* 44464 (1044) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 6,  6,  0] -1 */
       16320, /* 44465 (1044) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    34133522, /* 44466 (1044) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
        7898, /* 44467 (1044) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    52442924, /* 44468 (1044) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 6,  6,  0] -1 */
    52443408, /* 44469 (1044) [ 0, -1,  0,  1,  0,  0,  0,  0, -1] [ 6,  6,  0] -1 */
    34142108, /* 44470 (1044) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    52451994, /* 44471 (1044) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
    18553658, /* 44472 (1044) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 6,  6,  6]  1 */
        3200, /* 44473 (1044) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    52447296, /* 44474 (1044) [ 0,  1,  0, -1,  0,  0,  0,  0, -1] [ 6,  6,  0] -1 */
    34142592, /* 44475 (1044) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  6] -1 */
    34138220, /* 44476 (1044) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    18549282, /* 44477 (1044) [ 0, -1,  0,  1,  0,  0,  0,  0, -1] [ 6,  6,  6]  1 */
    52438874, /* 44478 (1044) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
    52438710, /* 44479 (1044) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
    18557868, /* 44480 (1044) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
    18548798, /* 44481 (1044) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 6,  6,  6]  1 */
       16484, /* 44482 (1045) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    52442922, /* 44483 (1045) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 6,  6,  0] -1 */
       11786, /* 44484 (1045) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  0]  1 */
        3360, /* 44485 (1045) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
       12270, /* 44486 (1045) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    34138218, /* 44487 (1045) [ 0, -1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  6] -1 */
    18544748, /* 44488 (1045) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    52451996, /* 44489 (1045) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
    18544584, /* 44490 (1045) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
    52451832, /* 44491 (1045) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
    18557708, /* 44492 (1045) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    52447298, /* 44493 (1045) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 6,  6,  0] -1 */
        7410, /* 44494 (1045) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    18553170, /* 44495 (1045) [ 0,  1,  0, -1,  0,  0,  0,  0, -1] [ 6,  6,  6]  1 */
    52438712, /* 44496 (1045) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
       16320, /* 44497 (1045) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    34142594, /* 44498 (1045) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 0,  0,  6] -1 */
        7898, /* 44499 (1045) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34146804, /* 44500 (1045) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
    34142106, /* 44501 (1045) [ 0,  1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  6] -1 */
    34137734, /* 44502 (1045) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    52438872, /* 44503 (1045) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
    52447782, /* 44504 (1045) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 6,  6,  0] -1 */
    18553658, /* 44505 (1045) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    34146644, /* 44506 (1045) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
        3200, /* 44507 (1045) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34133520, /* 44508 (1045) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
    52443410, /* 44509 (1045) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 6,  6,  0] -1 */
    18549282, /* 44510 (1045) [ 0, -1,  0,  1,  0,  0,  0,  0, -1] [ 6,  6,  6]  1 */
    34133684, /* 44511 (1045) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    18557868, /* 44512 (1045) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
    18548798, /* 44513 (1045) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 6,  6,  6]  1 */
       16484, /* 44514 (1046) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
       11786, /* 44515 (1046) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    52561020, /* 44516 (1046) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 6,  6,  6] -1 */
        3360, /* 44517 (1046) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
       12270, /* 44518 (1046) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    18544748, /* 44519 (1046) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    18544584, /* 44520 (1046) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
    18557708, /* 44521 (1046) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    52570094, /* 44522 (1046) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    34015586, /* 44523 (1046) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
        7410, /* 44524 (1046) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    18553170, /* 44525 (1046) [ 0,  1,  0, -1,  0,  0,  0,  0, -1] [ 6,  6,  6]  1 */
    34024496, /* 44526 (1046) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 0,  0,  0] -1 */
       16320, /* 44527 (1046) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    52556810, /* 44528 (1046) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
        7898, /* 44529 (1046) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34019636, /* 44530 (1046) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    52569930, /* 44531 (1046) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    52556970, /* 44532 (1046) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    52565880, /* 44533 (1046) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    34020120, /* 44534 (1046) [ 0, -1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    34028546, /* 44535 (1046) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    34028706, /* 44536 (1046) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    34024008, /* 44537 (1046) [ 0,  1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    52561508, /* 44538 (1046) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    18553658, /* 44539 (1046) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    34015422, /* 44540 (1046) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
        3200, /* 44541 (1046) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    52565396, /* 44542 (1046) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    18549282, /* 44543 (1046) [ 0, -1,  0,  1,  0,  0,  0,  0, -1] [ 6,  6,  6]  1 */
    18557868, /* 44544 (1046) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
    18548798, /* 44545 (1046) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 6,  6,  6]  1 */
       16484, /* 44546 (1035) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    18426488, /* 44547 (1035) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
     1428962, /* 44548 (1035) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 0,  6,  0]  1 */
     1551594, /* 44549 (1035) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
    17014010, /* 44550 (1035) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 6,  0,  0]  1 */
      130368, /* 44551 (1035) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  6]  1 */
    18548796, /* 44552 (1035) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 6,  6,  6]  1 */
    17127570, /* 44553 (1035) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6]  1 */
     1425072, /* 44554 (1035) [ 0, -1,  0,  1,  0,  0,  0,  0, -1] [ 0,  6,  0]  1 */
     1538636, /* 44555 (1035) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
        3198, /* 44556 (1035) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    17140532, /* 44557 (1035) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
    18439770, /* 44558 (1035) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
    17017896, /* 44559 (1035) [ 0,  1,  0, -1,  0,  0,  0,  0, -1] [ 6,  0,  0]  1 */
      125510, /* 44560 (1035) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  6]  1 */
    18553658, /* 44561 (1035) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 6,  6,  6]  1 */
       16484, /* 44562 (1036) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
     1428962, /* 44563 (1036) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 0,  6,  0]  1 */
    17127570, /* 44564 (1036) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6]  1 */
      130368, /* 44565 (1036) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  6]  1 */
    51030120, /* 44566 (1036) [ 0,  1,  0, -1,  0,  0,  0,  0, -1] [ 6,  0,  0] -1 */
     1538636, /* 44567 (1036) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
        3198, /* 44568 (1036) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    17140532, /* 44569 (1036) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
    35563818, /* 44570 (1036) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  6] -1 */
    52561020, /* 44571 (1036) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    51026234, /* 44572 (1036) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 6,  0,  0] -1 */
    18548796, /* 44573 (1036) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 6,  6,  6]  1 */
    17017896, /* 44574 (1036) [ 0,  1,  0, -1,  0,  0,  0,  0, -1] [ 6,  0,  0]  1 */
    52565882, /* 44575 (1036) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    52438712, /* 44576 (1036) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
    34028708, /* 44577 (1036) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    35437296, /* 44578 (1036) [ 0, -1,  0,  1,  0,  0,  0,  0, -1] [ 0,  6,  0] -1 */
     1551594, /* 44579 (1036) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
    17014010, /* 44580 (1036) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 6,  0,  0]  1 */
    52451994, /* 44581 (1036) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
    34137734, /* 44582 (1036) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    35441186, /* 44583 (1036) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 0,  6,  0] -1 */
    18553658, /* 44584 (1036) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    18426488, /* 44585 (1036) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    34142592, /* 44586 (1036) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  6] -1 */
    51139794, /* 44587 (1036) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6] -1 */
    34015422, /* 44588 (1036) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    51152756, /* 44589 (1036) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
    35550860, /* 44590 (1036) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
     1425072, /* 44591 (1036) [ 0, -1,  0,  1,  0,  0,  0,  0, -1] [ 0,  6,  0]  1 */
    18439770, /* 44592 (1036) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
      125510, /* 44593 (1036) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  6]  1 */
       16484, /* 44594 (1037) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    18426488, /* 44595 (1037) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    34142592, /* 44596 (1037) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  6] -1 */
     1428962, /* 44597 (1037) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 0,  6,  0]  1 */
    34015422, /* 44598 (1037) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    51139794, /* 44599 (1037) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6] -1 */
    17014010, /* 44600 (1037) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 6,  0,  0]  1 */
    51030120, /* 44601 (1037) [ 0,  1,  0, -1,  0,  0,  0,  0, -1] [ 6,  0,  0] -1 */
     1538636, /* 44602 (1037) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
    52451994, /* 44603 (1037) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
      125510, /* 44604 (1037) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  6]  1 */
    17140532, /* 44605 (1037) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
    52561020, /* 44606 (1037) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    35563818, /* 44607 (1037) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  6] -1 */
    18553658, /* 44608 (1037) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    35437296, /* 44609 (1037) [ 0, -1,  0,  1,  0,  0,  0,  0, -1] [ 0,  6,  0] -1 */
       16484, /* 44610 (1038) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    18426488, /* 44611 (1038) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    51026234, /* 44612 (1038) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 6,  0,  0] -1 */
    51139794, /* 44613 (1038) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6] -1 */
    51152756, /* 44614 (1038) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
    35550860, /* 44615 (1038) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
    51030120, /* 44616 (1038) [ 0,  1,  0, -1,  0,  0,  0,  0, -1] [ 6,  0,  0] -1 */
      130368, /* 44617 (1038) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  6]  1 */
    18548796, /* 44618 (1038) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 6,  6,  6]  1 */
        3198, /* 44619 (1038) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    35441186, /* 44620 (1038) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 0,  6,  0] -1 */
    18439770, /* 44621 (1038) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
      125510, /* 44622 (1038) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  6]  1 */
    35563818, /* 44623 (1038) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  6] -1 */
    18553658, /* 44624 (1038) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    35437296, /* 44625 (1038) [ 0, -1,  0,  1,  0,  0,  0,  0, -1] [ 0,  6,  0] -1 */
       16484, /* 44626 (1039) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    18426488, /* 44627 (1039) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    51026234, /* 44628 (1039) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 6,  0,  0] -1 */
     1551594, /* 44629 (1039) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
    34142592, /* 44630 (1039) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  6] -1 */
    17127570, /* 44631 (1039) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6]  1 */
    51030120, /* 44632 (1039) [ 0,  1,  0, -1,  0,  0,  0,  0, -1] [ 6,  0,  0] -1 */
     1538636, /* 44633 (1039) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
        3198, /* 44634 (1039) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    35441186, /* 44635 (1039) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 0,  6,  0] -1 */
    34137734, /* 44636 (1039) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    17140532, /* 44637 (1039) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
    18439770, /* 44638 (1039) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
    52565882, /* 44639 (1039) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    52561020, /* 44640 (1039) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    35437296, /* 44641 (1039) [ 0, -1,  0,  1,  0,  0,  0,  0, -1] [ 0,  6,  0] -1 */
       16484, /* 44642 (1040) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    18426488, /* 44643 (1040) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    51026234, /* 44644 (1040) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 6,  0,  0] -1 */
     1551594, /* 44645 (1040) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
    34015422, /* 44646 (1040) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    34142592, /* 44647 (1040) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  6] -1 */
    51152756, /* 44648 (1040) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
    35550860, /* 44649 (1040) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
    17127570, /* 44650 (1040) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6]  1 */
     1425072, /* 44651 (1040) [ 0, -1,  0,  1,  0,  0,  0,  0, -1] [ 0,  6,  0]  1 */
    52451994, /* 44652 (1040) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
      125510, /* 44653 (1040) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  6]  1 */
    35441186, /* 44654 (1040) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 0,  6,  0] -1 */
    17017896, /* 44655 (1040) [ 0,  1,  0, -1,  0,  0,  0,  0, -1] [ 6,  0,  0]  1 */
    52561020, /* 44656 (1040) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    18553658, /* 44657 (1040) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 6,  6,  6]  1 */
       16484, /* 44658 (1041) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    18426488, /* 44659 (1041) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    34142592, /* 44660 (1041) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  6] -1 */
     1428962, /* 44661 (1041) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 0,  6,  0]  1 */
    51139794, /* 44662 (1041) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6] -1 */
    52565882, /* 44663 (1041) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    51152756, /* 44664 (1041) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
    17014010, /* 44665 (1041) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 6,  0,  0]  1 */
    35550860, /* 44666 (1041) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
     1425072, /* 44667 (1041) [ 0, -1,  0,  1,  0,  0,  0,  0, -1] [ 0,  6,  0]  1 */
        3198, /* 44668 (1041) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    34137734, /* 44669 (1041) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    18439770, /* 44670 (1041) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
    17017896, /* 44671 (1041) [ 0,  1,  0, -1,  0,  0,  0,  0, -1] [ 6,  0,  0]  1 */
    52561020, /* 44672 (1041) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    35563818, /* 44673 (1041) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  6] -1 */
       16484, /* 44674 (1042) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    18426488, /* 44675 (1042) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    51026234, /* 44676 (1042) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 6,  0,  0] -1 */
    51139794, /* 44677 (1042) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6] -1 */
    34015422, /* 44678 (1042) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    52565882, /* 44679 (1042) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 6,  6,  6] -1 */
      130368, /* 44680 (1042) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  6]  1 */
    18548796, /* 44681 (1042) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 6,  6,  6]  1 */
     1425072, /* 44682 (1042) [ 0, -1,  0,  1,  0,  0,  0,  0, -1] [ 0,  6,  0]  1 */
     1538636, /* 44683 (1042) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
    52451994, /* 44684 (1042) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
    34137734, /* 44685 (1042) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    17140532, /* 44686 (1042) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
    17017896, /* 44687 (1042) [ 0,  1,  0, -1,  0,  0,  0,  0, -1] [ 6,  0,  0]  1 */
    35441186, /* 44688 (1042) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 0,  6,  0] -1 */
    35563818, /* 44689 (1042) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  6] -1 */
       16484, /* 44690 (1043) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    18426488, /* 44691 (1043) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
     1428962, /* 44692 (1043) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 0,  6,  0]  1 */
     1551594, /* 44693 (1043) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
    34015422, /* 44694 (1043) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    51152756, /* 44695 (1043) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
    17014010, /* 44696 (1043) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 6,  0,  0]  1 */
      130368, /* 44697 (1043) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  6]  1 */
    51030120, /* 44698 (1043) [ 0,  1,  0, -1,  0,  0,  0,  0, -1] [ 6,  0,  0] -1 */
    18548796, /* 44699 (1043) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 6,  6,  6]  1 */
    35550860, /* 44700 (1043) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
    17127570, /* 44701 (1043) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6]  1 */
    52451994, /* 44702 (1043) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
    34137734, /* 44703 (1043) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    52565882, /* 44704 (1043) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    35437296, /* 44705 (1043) [ 0, -1,  0,  1,  0,  0,  0,  0, -1] [ 0,  6,  0] -1 */
       16484, /* 44706 (1044) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    52442922, /* 44707 (1044) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 6,  6,  0] -1 */
     1428962, /* 44708 (1044) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 0,  6,  0]  1 */
    17127570, /* 44709 (1044) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6]  1 */
      130368, /* 44710 (1044) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  6]  1 */
     1538636, /* 44711 (1044) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
    35445720, /* 44712 (1044) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  0] -1 */
        3198, /* 44713 (1044) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    17140532, /* 44714 (1044) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
    51021696, /* 44715 (1044) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  0] -1 */
    51034658, /* 44716 (1044) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  0] -1 */
    18548796, /* 44717 (1044) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 6,  6,  6]  1 */
    34146806, /* 44718 (1044) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    17017896, /* 44719 (1044) [ 0,  1,  0, -1,  0,  0,  0,  0, -1] [ 6,  0,  0]  1 */
    52447784, /* 44720 (1044) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 6,  6,  0] -1 */
     1551594, /* 44721 (1044) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
    52556810, /* 44722 (1044) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    17014010, /* 44723 (1044) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 6,  0,  0]  1 */
    34019636, /* 44724 (1044) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    35555394, /* 44725 (1044) [ 0, -1,  0,  1,  0,  0,  0,  0, -1] [ 0,  6,  6] -1 */
    35559284, /* 44726 (1044) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 0,  6,  6] -1 */
    52570092, /* 44727 (1044) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    18553658, /* 44728 (1044) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    18426488, /* 44729 (1044) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    51148218, /* 44730 (1044) [ 0,  1,  0, -1,  0,  0,  0,  0, -1] [ 6,  0,  6] -1 */
    34024494, /* 44731 (1044) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    51144332, /* 44732 (1044) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 6,  0,  6] -1 */
     1425072, /* 44733 (1044) [ 0, -1,  0,  1,  0,  0,  0,  0, -1] [ 0,  6,  0]  1 */
    35432762, /* 44734 (1044) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  0] -1 */
    34133520, /* 44735 (1044) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
    18439770, /* 44736 (1044) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
      125510, /* 44737 (1044) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  6]  1 */
       16484, /* 44738 (1045) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34137732, /* 44739 (1045) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  6] -1 */
     1428962, /* 44740 (1045) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 0,  6,  0]  1 */
    17127570, /* 44741 (1045) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6]  1 */
      130368, /* 44742 (1045) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  6]  1 */
    51026232, /* 44743 (1045) [ 0, -1,  0,  1,  0,  0,  0,  0, -1] [ 6,  0,  0] -1 */
     1538636, /* 44744 (1045) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
    52451996, /* 44745 (1045) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
        3198, /* 44746 (1045) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    51152754, /* 44747 (1045) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  6] -1 */
    17140532, /* 44748 (1045) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
    51030122, /* 44749 (1045) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 6,  0,  0] -1 */
    18548796, /* 44750 (1045) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 6,  6,  6]  1 */
    17017896, /* 44751 (1045) [ 0,  1,  0, -1,  0,  0,  0,  0, -1] [ 6,  0,  0]  1 */
    34015424, /* 44752 (1045) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
     1551594, /* 44753 (1045) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
    34142594, /* 44754 (1045) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    17014010, /* 44755 (1045) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 6,  0,  0]  1 */
    34028706, /* 44756 (1045) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    35441184, /* 44757 (1045) [ 0,  1,  0, -1,  0,  0,  0,  0, -1] [ 0,  6,  0] -1 */
    52561022, /* 44758 (1045) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    35550858, /* 44759 (1045) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6] -1 */
    52565880, /* 44760 (1045) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    18553658, /* 44761 (1045) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    35563820, /* 44762 (1045) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
    18426488, /* 44763 (1045) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    52438710, /* 44764 (1045) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
    35437298, /* 44765 (1045) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 0,  6,  0] -1 */
     1425072, /* 44766 (1045) [ 0, -1,  0,  1,  0,  0,  0,  0, -1] [ 0,  6,  0]  1 */
    51139796, /* 44767 (1045) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
    18439770, /* 44768 (1045) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
      125510, /* 44769 (1045) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  6]  1 */
       16484, /* 44770 (1046) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
     1428962, /* 44771 (1046) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 0,  6,  0]  1 */
    34019634, /* 44772 (1046) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    17127570, /* 44773 (1046) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6]  1 */
      130368, /* 44774 (1046) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  6]  1 */
     1538636, /* 44775 (1046) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
        3198, /* 44776 (1046) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    17140532, /* 44777 (1046) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
    52570094, /* 44778 (1046) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    51021698, /* 44779 (1046) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  0] -1 */
    18548796, /* 44780 (1046) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 6,  6,  6]  1 */
    17017896, /* 44781 (1046) [ 0,  1,  0, -1,  0,  0,  0,  0, -1] [ 6,  0,  0]  1 */
    34024496, /* 44782 (1046) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 0,  0,  0] -1 */
     1551594, /* 44783 (1046) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
    34133522, /* 44784 (1046) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    17014010, /* 44785 (1046) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 6,  0,  0]  1 */
    52442924, /* 44786 (1046) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 6,  6,  0] -1 */
    51034656, /* 44787 (1046) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  0] -1 */
    35432760, /* 44788 (1046) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  0] -1 */
    52447782, /* 44789 (1046) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 6,  6,  0] -1 */
    51144330, /* 44790 (1046) [ 0, -1,  0,  1,  0,  0,  0,  0, -1] [ 6,  0,  6] -1 */
    35445722, /* 44791 (1046) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  0] -1 */
    34146804, /* 44792 (1046) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
    35559282, /* 44793 (1046) [ 0,  1,  0, -1,  0,  0,  0,  0, -1] [ 0,  6,  6] -1 */
    35555396, /* 44794 (1046) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 0,  6,  6] -1 */
    18553658, /* 44795 (1046) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    52556808, /* 44796 (1046) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    18426488, /* 44797 (1046) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    51148220, /* 44798 (1046) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 6,  0,  6] -1 */
     1425072, /* 44799 (1046) [ 0, -1,  0,  1,  0,  0,  0,  0, -1] [ 0,  6,  0]  1 */
    18439770, /* 44800 (1046) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
      125510, /* 44801 (1046) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  6]  1 */
       16484, /* 44802 (1047) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    18426648, /* 44803 (1047) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
    18435560, /* 44804 (1047) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    18439608, /* 44805 (1047) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
        3200, /* 44806 (1047) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    18439610, /* 44807 (1047) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
       11784, /* 44808 (1047) [ 0,  1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  0]  1 */
        7896, /* 44809 (1047) [ 0, -1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    18430698, /* 44810 (1047) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 6,  6,  0]  1 */
    18426650, /* 44811 (1047) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
        3198, /* 44812 (1047) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    18430700, /* 44813 (1047) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 6,  6,  0]  1 */
       11786, /* 44814 (1047) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  0]  1 */
        7898, /* 44815 (1047) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 0,  0,  0]  1 */
       16482, /* 44816 (1047) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    18435558, /* 44817 (1047) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 6,  6,  0]  1 */
       16484, /* 44818 (1048) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    52442922, /* 44819 (1048) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 6,  6,  0] -1 */
    18439608, /* 44820 (1048) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
        3198, /* 44821 (1048) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    52438872, /* 44822 (1048) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
    52451834, /* 44823 (1048) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
    34024008, /* 44824 (1048) [ 0,  1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    34020120, /* 44825 (1048) [ 0, -1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    34024010, /* 44826 (1048) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    52438874, /* 44827 (1048) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
    18430698, /* 44828 (1048) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 6,  6,  0]  1 */
    34020122, /* 44829 (1048) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    34015424, /* 44830 (1048) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    34028708, /* 44831 (1048) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    52447784, /* 44832 (1048) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 6,  6,  0] -1 */
    18426648, /* 44833 (1048) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
    18439610, /* 44834 (1048) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
       11784, /* 44835 (1048) [ 0,  1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    52442924, /* 44836 (1048) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 6,  6,  0] -1 */
        7896, /* 44837 (1048) [ 0, -1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    34028706, /* 44838 (1048) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    18426650, /* 44839 (1048) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    52447782, /* 44840 (1048) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 6,  6,  0] -1 */
       11786, /* 44841 (1048) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  0]  1 */
        7898, /* 44842 (1048) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    52451832, /* 44843 (1048) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
    34015422, /* 44844 (1048) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    18435560, /* 44845 (1048) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 6,  6,  0]  1 */
        3200, /* 44846 (1048) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    18430700, /* 44847 (1048) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 6,  6,  0]  1 */
       16482, /* 44848 (1048) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    18435558, /* 44849 (1048) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 6,  6,  0]  1 */
       16484, /* 44850 (1049) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34024008, /* 44851 (1049) [ 0,  1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    52442922, /* 44852 (1049) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 6,  6,  0] -1 */
    34015422, /* 44853 (1049) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    18435560, /* 44854 (1049) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 6,  6,  0]  1 */
        3200, /* 44855 (1049) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34020120, /* 44856 (1049) [ 0, -1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    18439610, /* 44857 (1049) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    34028706, /* 44858 (1049) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    52438872, /* 44859 (1049) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
    52447782, /* 44860 (1049) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 6,  6,  0] -1 */
    18426650, /* 44861 (1049) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    18430700, /* 44862 (1049) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 6,  6,  0]  1 */
       11786, /* 44863 (1049) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  0]  1 */
        7898, /* 44864 (1049) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    52451832, /* 44865 (1049) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
       16484, /* 44866 (1050) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    52451834, /* 44867 (1050) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
    34024008, /* 44868 (1050) [ 0,  1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    18435560, /* 44869 (1050) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    34020120, /* 44870 (1050) [ 0, -1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  0] -1 */
        3200, /* 44871 (1050) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34024010, /* 44872 (1050) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    52438874, /* 44873 (1050) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
    18430698, /* 44874 (1050) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 6,  6,  0]  1 */
    18430700, /* 44875 (1050) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 6,  6,  0]  1 */
        3198, /* 44876 (1050) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    34020122, /* 44877 (1050) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    52438872, /* 44878 (1050) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
       16482, /* 44879 (1050) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    52451832, /* 44880 (1050) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
    18435558, /* 44881 (1050) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 6,  6,  0]  1 */
       16484, /* 44882 (1051) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34024008, /* 44883 (1051) [ 0,  1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    52442922, /* 44884 (1051) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 6,  6,  0] -1 */
    18426648, /* 44885 (1051) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
    18439608, /* 44886 (1051) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
        3200, /* 44887 (1051) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34020120, /* 44888 (1051) [ 0, -1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    34024010, /* 44889 (1051) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    18439610, /* 44890 (1051) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    52442924, /* 44891 (1051) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 6,  6,  0] -1 */
    18426650, /* 44892 (1051) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
        3198, /* 44893 (1051) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    34020122, /* 44894 (1051) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    52447782, /* 44895 (1051) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 6,  6,  0] -1 */
       16482, /* 44896 (1051) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    52447784, /* 44897 (1051) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 6,  6,  0] -1 */
       16484, /* 44898 (1052) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    52451834, /* 44899 (1052) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
    52442922, /* 44900 (1052) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 6,  6,  0] -1 */
    18426648, /* 44901 (1052) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
    34015422, /* 44902 (1052) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    18439608, /* 44903 (1052) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
        3200, /* 44904 (1052) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    18435560, /* 44905 (1052) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    34024010, /* 44906 (1052) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  0] -1 */
       11784, /* 44907 (1052) [ 0,  1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    52438874, /* 44908 (1052) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
        7896, /* 44909 (1052) [ 0, -1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    34028706, /* 44910 (1052) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    52447782, /* 44911 (1052) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 6,  6,  0] -1 */
    18430700, /* 44912 (1052) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    34020122, /* 44913 (1052) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 0,  0,  0] -1 */
       16484, /* 44914 (1053) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    52451834, /* 44915 (1053) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
    52442922, /* 44916 (1053) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 6,  6,  0] -1 */
        3200, /* 44917 (1053) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
       11784, /* 44918 (1053) [ 0,  1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    52438874, /* 44919 (1053) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
    52442924, /* 44920 (1053) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 6,  6,  0] -1 */
        7896, /* 44921 (1053) [ 0, -1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    52438872, /* 44922 (1053) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
    52447782, /* 44923 (1053) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 6,  6,  0] -1 */
        3198, /* 44924 (1053) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
       11786, /* 44925 (1053) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  0]  1 */
        7898, /* 44926 (1053) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 0,  0,  0]  1 */
       16482, /* 44927 (1053) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    52447784, /* 44928 (1053) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 6,  6,  0] -1 */
    52451832, /* 44929 (1053) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
       16484, /* 44930 (1054) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34015422, /* 44931 (1054) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
        3200, /* 44932 (1054) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    18439610, /* 44933 (1054) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    34024010, /* 44934 (1054) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  0] -1 */
       11784, /* 44935 (1054) [ 0,  1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    52442924, /* 44936 (1054) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 6,  6,  0] -1 */
        7896, /* 44937 (1054) [ 0, -1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    34028706, /* 44938 (1054) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    18430698, /* 44939 (1054) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 6,  6,  0]  1 */
    18426650, /* 44940 (1054) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    34020122, /* 44941 (1054) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    52438872, /* 44942 (1054) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
    52447784, /* 44943 (1054) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 6,  6,  0] -1 */
    52451832, /* 44944 (1054) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
    18435558, /* 44945 (1054) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 6,  6,  0]  1 */
       16484, /* 44946 (1055) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    52451834, /* 44947 (1055) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
    34024008, /* 44948 (1055) [ 0,  1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    18426648, /* 44949 (1055) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
    34015422, /* 44950 (1055) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    18439608, /* 44951 (1055) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
        3200, /* 44952 (1055) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34020120, /* 44953 (1055) [ 0, -1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    52438874, /* 44954 (1055) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
    52442924, /* 44955 (1055) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 6,  6,  0] -1 */
    34028706, /* 44956 (1055) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    18430698, /* 44957 (1055) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 6,  6,  0]  1 */
       11786, /* 44958 (1055) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  0]  1 */
        7898, /* 44959 (1055) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    52447784, /* 44960 (1055) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 6,  6,  0] -1 */
    18435558, /* 44961 (1055) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 6,  6,  0]  1 */
       16484, /* 44962 (1056) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    18439608, /* 44963 (1056) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
        3198, /* 44964 (1056) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    52556970, /* 44965 (1056) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    34142108, /* 44966 (1056) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    52569932, /* 44967 (1056) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    34138220, /* 44968 (1056) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    34142106, /* 44969 (1056) [ 0,  1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  6] -1 */
    18430698, /* 44970 (1056) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 6,  6,  0]  1 */
    34138218, /* 44971 (1056) [ 0, -1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  6] -1 */
    34146806, /* 44972 (1056) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    52556972, /* 44973 (1056) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    52565882, /* 44974 (1056) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    18426648, /* 44975 (1056) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
    34133522, /* 44976 (1056) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    18439610, /* 44977 (1056) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
       11784, /* 44978 (1056) [ 0,  1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  0]  1 */
        7896, /* 44979 (1056) [ 0, -1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    18426650, /* 44980 (1056) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    52561022, /* 44981 (1056) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 6,  6,  6] -1 */
       11786, /* 44982 (1056) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    52569930, /* 44983 (1056) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    34146804, /* 44984 (1056) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
        7898, /* 44985 (1056) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    52565880, /* 44986 (1056) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    18435560, /* 44987 (1056) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 6,  6,  0]  1 */
        3200, /* 44988 (1056) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34133520, /* 44989 (1056) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
    18430700, /* 44990 (1056) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    52561020, /* 44991 (1056) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 6,  6,  6] -1 */
       16482, /* 44992 (1056) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    18435558, /* 44993 (1056) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 6,  6,  0]  1 */
       16484, /* 44994 (1057) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    18439608, /* 44995 (1057) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
    34019634, /* 44996 (1057) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    52443408, /* 44997 (1057) [ 0, -1,  0,  1,  0,  0,  0,  0, -1] [ 6,  6,  0] -1 */
    52447298, /* 44998 (1057) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 6,  6,  0] -1 */
    52451996, /* 44999 (1057) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
        3198, /* 45000 (1057) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    52447296, /* 45001 (1057) [ 0,  1,  0, -1,  0,  0,  0,  0, -1] [ 6,  6,  0] -1 */
    52443410, /* 45002 (1057) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 6,  6,  0] -1 */
    34015584, /* 45003 (1057) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    18430698, /* 45004 (1057) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 6,  6,  0]  1 */
    34028546, /* 45005 (1057) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    52438712, /* 45006 (1057) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
    34024496, /* 45007 (1057) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    34015586, /* 45008 (1057) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    18426648, /* 45009 (1057) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
    18439610, /* 45010 (1057) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
       11784, /* 45011 (1057) [ 0,  1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    34019636, /* 45012 (1057) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  0] -1 */
        7896, /* 45013 (1057) [ 0, -1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    52451994, /* 45014 (1057) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
    18426650, /* 45015 (1057) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
       11786, /* 45016 (1057) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  0]  1 */
        7898, /* 45017 (1057) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34028544, /* 45018 (1057) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    18435560, /* 45019 (1057) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    52438710, /* 45020 (1057) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
        3200, /* 45021 (1057) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34024494, /* 45022 (1057) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    18430700, /* 45023 (1057) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 6,  6,  0]  1 */
       16482, /* 45024 (1057) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    18435558, /* 45025 (1057) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 6,  6,  0]  1 */
       16484, /* 45026 (1058) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34137732, /* 45027 (1058) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  6] -1 */
    18439608, /* 45028 (1058) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
    52561506, /* 45029 (1058) [ 0, -1,  0,  1,  0,  0,  0,  0, -1] [ 6,  6,  6] -1 */
        3198, /* 45030 (1058) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    52565394, /* 45031 (1058) [ 0,  1,  0, -1,  0,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    52570094, /* 45032 (1058) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    52565396, /* 45033 (1058) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    52561508, /* 45034 (1058) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    34146644, /* 45035 (1058) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    18430698, /* 45036 (1058) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 6,  6,  0]  1 */
    34133684, /* 45037 (1058) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    34133682, /* 45038 (1058) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
    18426648, /* 45039 (1058) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
    52556810, /* 45040 (1058) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    18439610, /* 45041 (1058) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    34142594, /* 45042 (1058) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 0,  0,  6] -1 */
       11784, /* 45043 (1058) [ 0,  1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  0]  1 */
        7896, /* 45044 (1058) [ 0, -1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    18426650, /* 45045 (1058) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    34137734, /* 45046 (1058) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  6] -1 */
       11786, /* 45047 (1058) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34146642, /* 45048 (1058) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
        7898, /* 45049 (1058) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    52570092, /* 45050 (1058) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    52556808, /* 45051 (1058) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    34142592, /* 45052 (1058) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  6] -1 */
    18435560, /* 45053 (1058) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 6,  6,  0]  1 */
        3200, /* 45054 (1058) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    18430700, /* 45055 (1058) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 6,  6,  0]  1 */
       16482, /* 45056 (1058) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    18435558, /* 45057 (1058) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 6,  6,  0]  1 */
       16484, /* 45058 (1059) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
        3200, /* 45059 (1059) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
       11784, /* 45060 (1059) [ 0,  1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    18553656, /* 45061 (1059) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 6,  6,  6]  1 */
    18548796, /* 45062 (1059) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 6,  6,  6]  1 */
       16482, /* 45063 (1059) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
        7896, /* 45064 (1059) [ 0, -1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  0]  1 */
        3198, /* 45065 (1059) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    18548798, /* 45066 (1059) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 6,  6,  6]  1 */
       11786, /* 45067 (1059) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    18557708, /* 45068 (1059) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
        7898, /* 45069 (1059) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    18544746, /* 45070 (1059) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
    18544748, /* 45071 (1059) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    18553658, /* 45072 (1059) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    18557706, /* 45073 (1059) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
       16484, /* 45074 (1060) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    18553656, /* 45075 (1060) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 6,  6,  6]  1 */
        3198, /* 45076 (1060) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    52556970, /* 45077 (1060) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    34024008, /* 45078 (1060) [ 0,  1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    34020120, /* 45079 (1060) [ 0, -1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    34024010, /* 45080 (1060) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    18548796, /* 45081 (1060) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 6,  6,  6]  1 */
    52569932, /* 45082 (1060) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    34020122, /* 45083 (1060) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    52556972, /* 45084 (1060) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    52565882, /* 45085 (1060) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    34015424, /* 45086 (1060) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    34028708, /* 45087 (1060) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    18544746, /* 45088 (1060) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
       11784, /* 45089 (1060) [ 0,  1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  0]  1 */
        7896, /* 45090 (1060) [ 0, -1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    34028706, /* 45091 (1060) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    52561022, /* 45092 (1060) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 6,  6,  6] -1 */
       11786, /* 45093 (1060) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    52569930, /* 45094 (1060) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    18557708, /* 45095 (1060) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
        7898, /* 45096 (1060) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    18544748, /* 45097 (1060) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    52565880, /* 45098 (1060) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    18553658, /* 45099 (1060) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    34015422, /* 45100 (1060) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
        3200, /* 45101 (1060) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    18548798, /* 45102 (1060) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    52561020, /* 45103 (1060) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 6,  6,  6] -1 */
       16482, /* 45104 (1060) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    18557706, /* 45105 (1060) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
       16484, /* 45106 (1061) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34024008, /* 45107 (1061) [ 0,  1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    34015422, /* 45108 (1061) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    34020120, /* 45109 (1061) [ 0, -1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  0] -1 */
        3200, /* 45110 (1061) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34028706, /* 45111 (1061) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    18544748, /* 45112 (1061) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    52556970, /* 45113 (1061) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    18548798, /* 45114 (1061) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 6,  6,  6]  1 */
       11786, /* 45115 (1061) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    52569930, /* 45116 (1061) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    18557708, /* 45117 (1061) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
        7898, /* 45118 (1061) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    52561020, /* 45119 (1061) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    52565880, /* 45120 (1061) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    18553658, /* 45121 (1061) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 6,  6,  6]  1 */
       16484, /* 45122 (1062) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34024008, /* 45123 (1062) [ 0,  1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    34020120, /* 45124 (1062) [ 0, -1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  0] -1 */
        3200, /* 45125 (1062) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34024010, /* 45126 (1062) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    18548796, /* 45127 (1062) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 6,  6,  6]  1 */
    18553656, /* 45128 (1062) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 6,  6,  6]  1 */
    52569932, /* 45129 (1062) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
        3198, /* 45130 (1062) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    34020122, /* 45131 (1062) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    18548798, /* 45132 (1062) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    52556972, /* 45133 (1062) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    52556970, /* 45134 (1062) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    52569930, /* 45135 (1062) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
       16482, /* 45136 (1062) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    18553658, /* 45137 (1062) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 6,  6,  6]  1 */
       16484, /* 45138 (1063) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34024008, /* 45139 (1063) [ 0,  1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    34020120, /* 45140 (1063) [ 0, -1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  0] -1 */
        3200, /* 45141 (1063) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34024010, /* 45142 (1063) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    18544746, /* 45143 (1063) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
    52565880, /* 45144 (1063) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 6,  6,  6] -1 */
       16482, /* 45145 (1063) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
        3198, /* 45146 (1063) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    34020122, /* 45147 (1063) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    52561022, /* 45148 (1063) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    52565882, /* 45149 (1063) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    18557708, /* 45150 (1063) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    52561020, /* 45151 (1063) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    18544748, /* 45152 (1063) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    18557706, /* 45153 (1063) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
       16484, /* 45154 (1064) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34015422, /* 45155 (1064) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
        3200, /* 45156 (1064) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34024010, /* 45157 (1064) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  0] -1 */
       11784, /* 45158 (1064) [ 0,  1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    18544746, /* 45159 (1064) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
        7896, /* 45160 (1064) [ 0, -1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    52569932, /* 45161 (1064) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    34028706, /* 45162 (1064) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    34020122, /* 45163 (1064) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    18548798, /* 45164 (1064) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    52556972, /* 45165 (1064) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    52561020, /* 45166 (1064) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    52565880, /* 45167 (1064) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    18553658, /* 45168 (1064) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    18557706, /* 45169 (1064) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
       16484, /* 45170 (1065) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
        3200, /* 45171 (1065) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
       11784, /* 45172 (1065) [ 0,  1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  0]  1 */
        7896, /* 45173 (1065) [ 0, -1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  0]  1 */
       16482, /* 45174 (1065) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    52569932, /* 45175 (1065) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
        3198, /* 45176 (1065) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    52556970, /* 45177 (1065) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    52556972, /* 45178 (1065) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    52561022, /* 45179 (1065) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    52565882, /* 45180 (1065) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    52569930, /* 45181 (1065) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
       11786, /* 45182 (1065) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  0]  1 */
        7898, /* 45183 (1065) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    52561020, /* 45184 (1065) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    52565880, /* 45185 (1065) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 6,  6,  6] -1 */
       16484, /* 45186 (1066) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34015422, /* 45187 (1066) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
        3200, /* 45188 (1066) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34024010, /* 45189 (1066) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  0] -1 */
       11784, /* 45190 (1066) [ 0,  1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    18553656, /* 45191 (1066) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 6,  6,  6]  1 */
    18548796, /* 45192 (1066) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 6,  6,  6]  1 */
        7896, /* 45193 (1066) [ 0, -1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    34028706, /* 45194 (1066) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    34020122, /* 45195 (1066) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    52556970, /* 45196 (1066) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    52561022, /* 45197 (1066) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    52565882, /* 45198 (1066) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    52569930, /* 45199 (1066) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    18557708, /* 45200 (1066) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    18544748, /* 45201 (1066) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
       16484, /* 45202 (1067) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34024008, /* 45203 (1067) [ 0,  1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    34015422, /* 45204 (1067) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    52565882, /* 45205 (1067) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 6,  6,  6] -1 */
        3200, /* 45206 (1067) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34020120, /* 45207 (1067) [ 0, -1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    18548796, /* 45208 (1067) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 6,  6,  6]  1 */
    18553656, /* 45209 (1067) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 6,  6,  6]  1 */
    52569932, /* 45210 (1067) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    34028706, /* 45211 (1067) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    52556972, /* 45212 (1067) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
       11786, /* 45213 (1067) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    52561022, /* 45214 (1067) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 6,  6,  6] -1 */
        7898, /* 45215 (1067) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    18544746, /* 45216 (1067) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
    18557706, /* 45217 (1067) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
       16484, /* 45218 (1068) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    52442922, /* 45219 (1068) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 6,  6,  0] -1 */
    18553656, /* 45220 (1068) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 6,  6,  6]  1 */
        3198, /* 45221 (1068) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    52438872, /* 45222 (1068) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
    52451834, /* 45223 (1068) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
    34142108, /* 45224 (1068) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    18548796, /* 45225 (1068) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 6,  6,  6]  1 */
    52438874, /* 45226 (1068) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
    34138220, /* 45227 (1068) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    34142106, /* 45228 (1068) [ 0,  1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  6] -1 */
    34138218, /* 45229 (1068) [ 0, -1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  6] -1 */
    34146806, /* 45230 (1068) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    18544746, /* 45231 (1068) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
    52447784, /* 45232 (1068) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 6,  6,  0] -1 */
    34133522, /* 45233 (1068) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
       11784, /* 45234 (1068) [ 0,  1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    52442924, /* 45235 (1068) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 6,  6,  0] -1 */
        7896, /* 45236 (1068) [ 0, -1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    52447782, /* 45237 (1068) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 6,  6,  0] -1 */
       11786, /* 45238 (1068) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    18557708, /* 45239 (1068) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
        7898, /* 45240 (1068) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34146804, /* 45241 (1068) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
    18544748, /* 45242 (1068) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    18553658, /* 45243 (1068) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    52451832, /* 45244 (1068) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
        3200, /* 45245 (1068) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34133520, /* 45246 (1068) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
    18548798, /* 45247 (1068) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 6,  6,  6]  1 */
       16482, /* 45248 (1068) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    18557706, /* 45249 (1068) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
       16484, /* 45250 (1069) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34137732, /* 45251 (1069) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  6] -1 */
    18553656, /* 45252 (1069) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 6,  6,  6]  1 */
    52443408, /* 45253 (1069) [ 0, -1,  0,  1,  0,  0,  0,  0, -1] [ 6,  6,  0] -1 */
    52447298, /* 45254 (1069) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 6,  6,  0] -1 */
    52451996, /* 45255 (1069) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
        3198, /* 45256 (1069) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    52447296, /* 45257 (1069) [ 0,  1,  0, -1,  0,  0,  0,  0, -1] [ 6,  6,  0] -1 */
    52443410, /* 45258 (1069) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 6,  6,  0] -1 */
    18548796, /* 45259 (1069) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 6,  6,  6]  1 */
    34146644, /* 45260 (1069) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    34133684, /* 45261 (1069) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    34133682, /* 45262 (1069) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
    52438712, /* 45263 (1069) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
    18544746, /* 45264 (1069) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
    34142594, /* 45265 (1069) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 0,  0,  6] -1 */
       11784, /* 45266 (1069) [ 0,  1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  0]  1 */
        7896, /* 45267 (1069) [ 0, -1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    52451994, /* 45268 (1069) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
    34137734, /* 45269 (1069) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  6] -1 */
       11786, /* 45270 (1069) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34146642, /* 45271 (1069) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
    18557708, /* 45272 (1069) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
        7898, /* 45273 (1069) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    18544748, /* 45274 (1069) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    18553658, /* 45275 (1069) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    34142592, /* 45276 (1069) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  6] -1 */
    52438710, /* 45277 (1069) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
        3200, /* 45278 (1069) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    18548798, /* 45279 (1069) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 6,  6,  6]  1 */
       16482, /* 45280 (1069) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    18557706, /* 45281 (1069) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
       16484, /* 45282 (1070) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    52561506, /* 45283 (1070) [ 0, -1,  0,  1,  0,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    34019634, /* 45284 (1070) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    18553656, /* 45285 (1070) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 6,  6,  6]  1 */
        3198, /* 45286 (1070) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    52565394, /* 45287 (1070) [ 0,  1,  0, -1,  0,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    52570094, /* 45288 (1070) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    52565396, /* 45289 (1070) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    52561508, /* 45290 (1070) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    18548796, /* 45291 (1070) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 6,  6,  6]  1 */
    34015584, /* 45292 (1070) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    34028546, /* 45293 (1070) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    18544746, /* 45294 (1070) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
    34024496, /* 45295 (1070) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    34015586, /* 45296 (1070) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    52556810, /* 45297 (1070) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
       11784, /* 45298 (1070) [ 0,  1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    34019636, /* 45299 (1070) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  0] -1 */
        7896, /* 45300 (1070) [ 0, -1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  0]  1 */
       11786, /* 45301 (1070) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    18557708, /* 45302 (1070) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
        7898, /* 45303 (1070) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    52570092, /* 45304 (1070) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    18544748, /* 45305 (1070) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    34028544, /* 45306 (1070) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    18553658, /* 45307 (1070) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    52556808, /* 45308 (1070) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
        3200, /* 45309 (1070) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34024494, /* 45310 (1070) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    18548798, /* 45311 (1070) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 6,  6,  6]  1 */
       16482, /* 45312 (1070) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    18557706, /* 45313 (1070) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
       16484, /* 45314 (1071) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
        3200, /* 45315 (1071) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    18435074, /* 45316 (1071) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    18431186, /* 45317 (1071) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    18435560, /* 45318 (1071) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 6,  6,  0]  1 */
        7896, /* 45319 (1071) [ 0, -1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  0]  1 */
        7410, /* 45320 (1071) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    18430700, /* 45321 (1071) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    18426486, /* 45322 (1071) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
    18439608, /* 45323 (1071) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
    18426648, /* 45324 (1071) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
        3362, /* 45325 (1071) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
       11784, /* 45326 (1071) [ 0,  1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    18439770, /* 45327 (1071) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
       16322, /* 45328 (1071) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
       12270, /* 45329 (1071) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  0]  1 */
       16484, /* 45330 (1072) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    18435074, /* 45331 (1072) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    34019634, /* 45332 (1072) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    34024008, /* 45333 (1072) [ 0,  1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    18426486, /* 45334 (1072) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
    52443410, /* 45335 (1072) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 6,  6,  0] -1 */
    34015586, /* 45336 (1072) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
        7410, /* 45337 (1072) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  0]  1 */
       11784, /* 45338 (1072) [ 0,  1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    34015424, /* 45339 (1072) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    34028708, /* 45340 (1072) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    52447784, /* 45341 (1072) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 6,  6,  0] -1 */
    34020120, /* 45342 (1072) [ 0, -1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    18431186, /* 45343 (1072) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    52442924, /* 45344 (1072) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 6,  6,  0] -1 */
    52451832, /* 45345 (1072) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
    52438872, /* 45346 (1072) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
    52451994, /* 45347 (1072) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
    34024494, /* 45348 (1072) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    34028546, /* 45349 (1072) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
        3362, /* 45350 (1072) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    52447298, /* 45351 (1072) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 6,  6,  0] -1 */
        3200, /* 45352 (1072) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    52438710, /* 45353 (1072) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
    18435560, /* 45354 (1072) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 6,  6,  0]  1 */
        7896, /* 45355 (1072) [ 0, -1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    18430700, /* 45356 (1072) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    18439608, /* 45357 (1072) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
    18426648, /* 45358 (1072) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
    18439770, /* 45359 (1072) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
       16322, /* 45360 (1072) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
       12270, /* 45361 (1072) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  0]  1 */
       16484, /* 45362 (1073) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
        3200, /* 45363 (1073) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    18435074, /* 45364 (1073) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    52438710, /* 45365 (1073) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
    34019634, /* 45366 (1073) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    18431186, /* 45367 (1073) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    34024008, /* 45368 (1073) [ 0,  1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    18435560, /* 45369 (1073) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    52451832, /* 45370 (1073) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
    52438872, /* 45371 (1073) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
    52451994, /* 45372 (1073) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
    34024494, /* 45373 (1073) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    18430700, /* 45374 (1073) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 6,  6,  0]  1 */
        3362, /* 45375 (1073) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
       16322, /* 45376 (1073) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34020120, /* 45377 (1073) [ 0, -1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  0] -1 */
       16484, /* 45378 (1074) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
        3200, /* 45379 (1074) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    52443410, /* 45380 (1074) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 6,  6,  0] -1 */
    34015586, /* 45381 (1074) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    34024008, /* 45382 (1074) [ 0,  1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    18435560, /* 45383 (1074) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    52451832, /* 45384 (1074) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
    52438872, /* 45385 (1074) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
        7410, /* 45386 (1074) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    18430700, /* 45387 (1074) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    18426486, /* 45388 (1074) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
    34028546, /* 45389 (1074) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    18439770, /* 45390 (1074) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
    34020120, /* 45391 (1074) [ 0, -1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    52447298, /* 45392 (1074) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 6,  6,  0] -1 */
       12270, /* 45393 (1074) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  0]  1 */
       16484, /* 45394 (1075) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
        3200, /* 45395 (1075) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    52443410, /* 45396 (1075) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 6,  6,  0] -1 */
    34019634, /* 45397 (1075) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    34024008, /* 45398 (1075) [ 0,  1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    52442924, /* 45399 (1075) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 6,  6,  0] -1 */
    34024494, /* 45400 (1075) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    18426486, /* 45401 (1075) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
    18439608, /* 45402 (1075) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
    18426648, /* 45403 (1075) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
        3362, /* 45404 (1075) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    18439770, /* 45405 (1075) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
       16322, /* 45406 (1075) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    52447298, /* 45407 (1075) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 6,  6,  0] -1 */
    52447784, /* 45408 (1075) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 6,  6,  0] -1 */
    34020120, /* 45409 (1075) [ 0, -1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  0] -1 */
       16484, /* 45410 (1076) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
        3200, /* 45411 (1076) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    52443410, /* 45412 (1076) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 6,  6,  0] -1 */
    52438710, /* 45413 (1076) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
    34019634, /* 45414 (1076) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    34015586, /* 45415 (1076) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    18435560, /* 45416 (1076) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 6,  6,  0]  1 */
        7896, /* 45417 (1076) [ 0, -1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    52451994, /* 45418 (1076) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
    34024494, /* 45419 (1076) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    18439608, /* 45420 (1076) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
    18430700, /* 45421 (1076) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    18426648, /* 45422 (1076) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
    34028546, /* 45423 (1076) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
       11784, /* 45424 (1076) [ 0,  1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    52447298, /* 45425 (1076) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 6,  6,  0] -1 */
       16484, /* 45426 (1077) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
        3200, /* 45427 (1077) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    18435074, /* 45428 (1077) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    34019634, /* 45429 (1077) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    18431186, /* 45430 (1077) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    34015586, /* 45431 (1077) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    52442924, /* 45432 (1077) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 6,  6,  0] -1 */
    52451832, /* 45433 (1077) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
    52438872, /* 45434 (1077) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
        7896, /* 45435 (1077) [ 0, -1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    34024494, /* 45436 (1077) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    18426486, /* 45437 (1077) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
    34028546, /* 45438 (1077) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    18439770, /* 45439 (1077) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
       11784, /* 45440 (1077) [ 0,  1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    52447784, /* 45441 (1077) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 6,  6,  0] -1 */
       16484, /* 45442 (1078) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
        3200, /* 45443 (1078) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    52443410, /* 45444 (1078) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 6,  6,  0] -1 */
    52438710, /* 45445 (1078) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
    52442924, /* 45446 (1078) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 6,  6,  0] -1 */
    52451832, /* 45447 (1078) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
    52438872, /* 45448 (1078) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
        7410, /* 45449 (1078) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    52451994, /* 45450 (1078) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
        7896, /* 45451 (1078) [ 0, -1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  0]  1 */
        3362, /* 45452 (1078) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
       11784, /* 45453 (1078) [ 0,  1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  0]  1 */
       16322, /* 45454 (1078) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    52447298, /* 45455 (1078) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 6,  6,  0] -1 */
    52447784, /* 45456 (1078) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 6,  6,  0] -1 */
       12270, /* 45457 (1078) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  0]  1 */
       16484, /* 45458 (1079) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
        3200, /* 45459 (1079) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    18435074, /* 45460 (1079) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    52438710, /* 45461 (1079) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
    18431186, /* 45462 (1079) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    34024008, /* 45463 (1079) [ 0,  1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    34015586, /* 45464 (1079) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    52442924, /* 45465 (1079) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 6,  6,  0] -1 */
        7410, /* 45466 (1079) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    52451994, /* 45467 (1079) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
    18439608, /* 45468 (1079) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
    34028546, /* 45469 (1079) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    18426648, /* 45470 (1079) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
    34020120, /* 45471 (1079) [ 0, -1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    52447784, /* 45472 (1079) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 6,  6,  0] -1 */
       12270, /* 45473 (1079) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  0]  1 */
       16484, /* 45474 (1080) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34137732, /* 45475 (1080) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  6] -1 */
    18435074, /* 45476 (1080) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    18426486, /* 45477 (1080) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
    52569930, /* 45478 (1080) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
        7410, /* 45479 (1080) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    34146806, /* 45480 (1080) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
       11784, /* 45481 (1080) [ 0,  1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    34133522, /* 45482 (1080) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    52565882, /* 45483 (1080) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    18431186, /* 45484 (1080) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    34138218, /* 45485 (1080) [ 0, -1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  6] -1 */
    52561022, /* 45486 (1080) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 6,  6,  6] -1 */
        3362, /* 45487 (1080) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    52565396, /* 45488 (1080) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    52556970, /* 45489 (1080) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    52570092, /* 45490 (1080) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    34142592, /* 45491 (1080) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  6] -1 */
    34146644, /* 45492 (1080) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
        3200, /* 45493 (1080) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34142106, /* 45494 (1080) [ 0,  1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  6] -1 */
    52561508, /* 45495 (1080) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    18435560, /* 45496 (1080) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 6,  6,  0]  1 */
        7896, /* 45497 (1080) [ 0, -1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    52556808, /* 45498 (1080) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    18430700, /* 45499 (1080) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    18439608, /* 45500 (1080) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
    34133684, /* 45501 (1080) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    18426648, /* 45502 (1080) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
    18439770, /* 45503 (1080) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
       16322, /* 45504 (1080) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
       12270, /* 45505 (1080) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  0]  1 */
       16484, /* 45506 (1081) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    52442922, /* 45507 (1081) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 6,  6,  0] -1 */
    18435074, /* 45508 (1081) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    52443408, /* 45509 (1081) [ 0, -1,  0,  1,  0,  0,  0,  0, -1] [ 6,  6,  0] -1 */
    52451996, /* 45510 (1081) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
    18426486, /* 45511 (1081) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
    34028544, /* 45512 (1081) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    34015584, /* 45513 (1081) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    52451834, /* 45514 (1081) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
    34024010, /* 45515 (1081) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  0] -1 */
        7410, /* 45516 (1081) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  0]  1 */
       11784, /* 45517 (1081) [ 0,  1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    52438712, /* 45518 (1081) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
    34024496, /* 45519 (1081) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    18431186, /* 45520 (1081) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    34019636, /* 45521 (1081) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    34028706, /* 45522 (1081) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    52447296, /* 45523 (1081) [ 0,  1,  0, -1,  0,  0,  0,  0, -1] [ 6,  6,  0] -1 */
        3362, /* 45524 (1081) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
        3200, /* 45525 (1081) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34015422, /* 45526 (1081) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    34020122, /* 45527 (1081) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    52447782, /* 45528 (1081) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 6,  6,  0] -1 */
    18435560, /* 45529 (1081) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 6,  6,  0]  1 */
        7896, /* 45530 (1081) [ 0, -1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    52438874, /* 45531 (1081) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
    18430700, /* 45532 (1081) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    18439608, /* 45533 (1081) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
    18426648, /* 45534 (1081) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
    18439770, /* 45535 (1081) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
       16322, /* 45536 (1081) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
       12270, /* 45537 (1081) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  0]  1 */
       16484, /* 45538 (1082) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    18435074, /* 45539 (1082) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    18426486, /* 45540 (1082) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
    34146642, /* 45541 (1082) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
    52570094, /* 45542 (1082) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
        7410, /* 45543 (1082) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  0]  1 */
       11784, /* 45544 (1082) [ 0,  1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    34142594, /* 45545 (1082) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    52556810, /* 45546 (1082) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    18431186, /* 45547 (1082) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    52561506, /* 45548 (1082) [ 0, -1,  0,  1,  0,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    34137734, /* 45549 (1082) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  6] -1 */
        3362, /* 45550 (1082) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34146804, /* 45551 (1082) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
    52565394, /* 45552 (1082) [ 0,  1,  0, -1,  0,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    34138220, /* 45553 (1082) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    34142108, /* 45554 (1082) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    34133520, /* 45555 (1082) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
        3200, /* 45556 (1082) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    52565880, /* 45557 (1082) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    34133682, /* 45558 (1082) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
    52569932, /* 45559 (1082) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    52556972, /* 45560 (1082) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    18435560, /* 45561 (1082) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 6,  6,  0]  1 */
        7896, /* 45562 (1082) [ 0, -1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    18430700, /* 45563 (1082) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    18439608, /* 45564 (1082) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
    18426648, /* 45565 (1082) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
    18439770, /* 45566 (1082) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
       16322, /* 45567 (1082) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    52561020, /* 45568 (1082) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 6,  6,  6] -1 */
       12270, /* 45569 (1082) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  0]  1 */
       16484, /* 45570 (1071) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    18426488, /* 45571 (1071) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
     1428962, /* 45572 (1071) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 0,  6,  0]  1 */
    17014010, /* 45573 (1071) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 6,  0,  0]  1 */
       12272, /* 45574 (1071) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 0,  0,  0]  1 */
     1425072, /* 45575 (1071) [ 0, -1,  0,  1,  0,  0,  0,  0, -1] [ 0,  6,  0]  1 */
        7410, /* 45576 (1071) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    18430700, /* 45577 (1071) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 6,  6,  0]  1 */
        3198, /* 45578 (1071) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    17022432, /* 45579 (1071) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  0]  1 */
     1420536, /* 45580 (1071) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  0]  1 */
    17009474, /* 45581 (1071) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  0]  1 */
    17017896, /* 45582 (1071) [ 0,  1,  0, -1,  0,  0,  0,  0, -1] [ 6,  0,  0]  1 */
    18439770, /* 45583 (1071) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
     1433498, /* 45584 (1071) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  0]  1 */
    18435558, /* 45585 (1071) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 6,  6,  0]  1 */
       16484, /* 45586 (1072) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
     1428962, /* 45587 (1072) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 0,  6,  0]  1 */
    34019634, /* 45588 (1072) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    51030120, /* 45589 (1072) [ 0,  1,  0, -1,  0,  0,  0,  0, -1] [ 6,  0,  0] -1 */
        3198, /* 45590 (1072) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    51026234, /* 45591 (1072) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 6,  0,  0] -1 */
    51021698, /* 45592 (1072) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  0] -1 */
        7410, /* 45593 (1072) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    17017896, /* 45594 (1072) [ 0,  1,  0, -1,  0,  0,  0,  0, -1] [ 6,  0,  0]  1 */
    52438712, /* 45595 (1072) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
    34028708, /* 45596 (1072) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    34024496, /* 45597 (1072) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    35437296, /* 45598 (1072) [ 0, -1,  0,  1,  0,  0,  0,  0, -1] [ 0,  6,  0] -1 */
    17014010, /* 45599 (1072) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 6,  0,  0]  1 */
    52442924, /* 45600 (1072) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 6,  6,  0] -1 */
    51034656, /* 45601 (1072) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  0] -1 */
    35432760, /* 45602 (1072) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  0] -1 */
    52451994, /* 45603 (1072) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
    52447782, /* 45604 (1072) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 6,  6,  0] -1 */
    35445722, /* 45605 (1072) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  0] -1 */
    17009474, /* 45606 (1072) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  0]  1 */
    35441186, /* 45607 (1072) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 0,  6,  0] -1 */
    18426488, /* 45608 (1072) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    34015422, /* 45609 (1072) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
       12272, /* 45610 (1072) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 0,  0,  0]  1 */
     1425072, /* 45611 (1072) [ 0, -1,  0,  1,  0,  0,  0,  0, -1] [ 0,  6,  0]  1 */
    18430700, /* 45612 (1072) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    17022432, /* 45613 (1072) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  0]  1 */
     1420536, /* 45614 (1072) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  0]  1 */
    18439770, /* 45615 (1072) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
     1433498, /* 45616 (1072) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  0]  1 */
    18435558, /* 45617 (1072) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 6,  6,  0]  1 */
       16484, /* 45618 (1073) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    18426488, /* 45619 (1073) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
     1428962, /* 45620 (1073) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 0,  6,  0]  1 */
    34015422, /* 45621 (1073) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    34019634, /* 45622 (1073) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    17014010, /* 45623 (1073) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 6,  0,  0]  1 */
    51030120, /* 45624 (1073) [ 0,  1,  0, -1,  0,  0,  0,  0, -1] [ 6,  0,  0] -1 */
       12272, /* 45625 (1073) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    51034656, /* 45626 (1073) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  0] -1 */
    35432760, /* 45627 (1073) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  0] -1 */
    52451994, /* 45628 (1073) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
    52447782, /* 45629 (1073) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 6,  6,  0] -1 */
    18430700, /* 45630 (1073) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    17009474, /* 45631 (1073) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  0]  1 */
     1433498, /* 45632 (1073) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  0]  1 */
    35437296, /* 45633 (1073) [ 0, -1,  0,  1,  0,  0,  0,  0, -1] [ 0,  6,  0] -1 */
       16484, /* 45634 (1074) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    18426488, /* 45635 (1074) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    51026234, /* 45636 (1074) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 6,  0,  0] -1 */
    51021698, /* 45637 (1074) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  0] -1 */
    51030120, /* 45638 (1074) [ 0,  1,  0, -1,  0,  0,  0,  0, -1] [ 6,  0,  0] -1 */
       12272, /* 45639 (1074) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    51034656, /* 45640 (1074) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  0] -1 */
    35432760, /* 45641 (1074) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  0] -1 */
        7410, /* 45642 (1074) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    18430700, /* 45643 (1074) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 6,  6,  0]  1 */
        3198, /* 45644 (1074) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    35445722, /* 45645 (1074) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  0] -1 */
    18439770, /* 45646 (1074) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
    35437296, /* 45647 (1074) [ 0, -1,  0,  1,  0,  0,  0,  0, -1] [ 0,  6,  0] -1 */
    35441186, /* 45648 (1074) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 0,  6,  0] -1 */
    18435558, /* 45649 (1074) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 6,  6,  0]  1 */
       16484, /* 45650 (1075) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    18426488, /* 45651 (1075) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    51026234, /* 45652 (1075) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 6,  0,  0] -1 */
    34019634, /* 45653 (1075) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    51030120, /* 45654 (1075) [ 0,  1,  0, -1,  0,  0,  0,  0, -1] [ 6,  0,  0] -1 */
    52442924, /* 45655 (1075) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 6,  6,  0] -1 */
    52447782, /* 45656 (1075) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 6,  6,  0] -1 */
        3198, /* 45657 (1075) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    17022432, /* 45658 (1075) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  0]  1 */
     1420536, /* 45659 (1075) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  0]  1 */
    17009474, /* 45660 (1075) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  0]  1 */
    18439770, /* 45661 (1075) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
     1433498, /* 45662 (1075) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  0]  1 */
    35441186, /* 45663 (1075) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 0,  6,  0] -1 */
    34024496, /* 45664 (1075) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    35437296, /* 45665 (1075) [ 0, -1,  0,  1,  0,  0,  0,  0, -1] [ 0,  6,  0] -1 */
       16484, /* 45666 (1076) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    18426488, /* 45667 (1076) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    51026234, /* 45668 (1076) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 6,  0,  0] -1 */
    34015422, /* 45669 (1076) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    34019634, /* 45670 (1076) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    51021698, /* 45671 (1076) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  0] -1 */
       12272, /* 45672 (1076) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 0,  0,  0]  1 */
     1425072, /* 45673 (1076) [ 0, -1,  0,  1,  0,  0,  0,  0, -1] [ 0,  6,  0]  1 */
    52451994, /* 45674 (1076) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
    52447782, /* 45675 (1076) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 6,  6,  0] -1 */
    17022432, /* 45676 (1076) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  0]  1 */
    18430700, /* 45677 (1076) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 6,  6,  0]  1 */
     1420536, /* 45678 (1076) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  0]  1 */
    35445722, /* 45679 (1076) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  0] -1 */
    17017896, /* 45680 (1076) [ 0,  1,  0, -1,  0,  0,  0,  0, -1] [ 6,  0,  0]  1 */
    35441186, /* 45681 (1076) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 0,  6,  0] -1 */
       16484, /* 45682 (1077) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    18426488, /* 45683 (1077) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
     1428962, /* 45684 (1077) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 0,  6,  0]  1 */
    34019634, /* 45685 (1077) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    17014010, /* 45686 (1077) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 6,  0,  0]  1 */
    51021698, /* 45687 (1077) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  0] -1 */
    52442924, /* 45688 (1077) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 6,  6,  0] -1 */
    51034656, /* 45689 (1077) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  0] -1 */
    35432760, /* 45690 (1077) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  0] -1 */
     1425072, /* 45691 (1077) [ 0, -1,  0,  1,  0,  0,  0,  0, -1] [ 0,  6,  0]  1 */
    52447782, /* 45692 (1077) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 6,  6,  0] -1 */
        3198, /* 45693 (1077) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    35445722, /* 45694 (1077) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  0] -1 */
    18439770, /* 45695 (1077) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
    17017896, /* 45696 (1077) [ 0,  1,  0, -1,  0,  0,  0,  0, -1] [ 6,  0,  0]  1 */
    34024496, /* 45697 (1077) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 0,  0,  0] -1 */
       16484, /* 45698 (1078) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    18426488, /* 45699 (1078) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    51026234, /* 45700 (1078) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 6,  0,  0] -1 */
    34015422, /* 45701 (1078) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    52442924, /* 45702 (1078) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 6,  6,  0] -1 */
    51034656, /* 45703 (1078) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  0] -1 */
    35432760, /* 45704 (1078) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  0] -1 */
        7410, /* 45705 (1078) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    52451994, /* 45706 (1078) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
     1425072, /* 45707 (1078) [ 0, -1,  0,  1,  0,  0,  0,  0, -1] [ 0,  6,  0]  1 */
    17009474, /* 45708 (1078) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  0]  1 */
    17017896, /* 45709 (1078) [ 0,  1,  0, -1,  0,  0,  0,  0, -1] [ 6,  0,  0]  1 */
     1433498, /* 45710 (1078) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  0]  1 */
    35441186, /* 45711 (1078) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 0,  6,  0] -1 */
    34024496, /* 45712 (1078) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    18435558, /* 45713 (1078) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 6,  6,  0]  1 */
       16484, /* 45714 (1079) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    18426488, /* 45715 (1079) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
     1428962, /* 45716 (1079) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 0,  6,  0]  1 */
    34015422, /* 45717 (1079) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    17014010, /* 45718 (1079) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 6,  0,  0]  1 */
    51030120, /* 45719 (1079) [ 0,  1,  0, -1,  0,  0,  0,  0, -1] [ 6,  0,  0] -1 */
    51021698, /* 45720 (1079) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  0] -1 */
    52442924, /* 45721 (1079) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 6,  6,  0] -1 */
        7410, /* 45722 (1079) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    52451994, /* 45723 (1079) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
    17022432, /* 45724 (1079) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  0]  1 */
    35445722, /* 45725 (1079) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  0] -1 */
     1420536, /* 45726 (1079) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  0]  1 */
    35437296, /* 45727 (1079) [ 0, -1,  0,  1,  0,  0,  0,  0, -1] [ 0,  6,  0] -1 */
    34024496, /* 45728 (1079) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    18435558, /* 45729 (1079) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 6,  6,  0]  1 */
       16484, /* 45730 (1080) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34137732, /* 45731 (1080) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  6] -1 */
     1428962, /* 45732 (1080) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 0,  6,  0]  1 */
        3198, /* 45733 (1080) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    51152754, /* 45734 (1080) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  6] -1 */
        7410, /* 45735 (1080) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    34146806, /* 45736 (1080) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    17017896, /* 45737 (1080) [ 0,  1,  0, -1,  0,  0,  0,  0, -1] [ 6,  0,  0]  1 */
    52556810, /* 45738 (1080) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    34142594, /* 45739 (1080) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    17014010, /* 45740 (1080) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 6,  0,  0]  1 */
    35555394, /* 45741 (1080) [ 0, -1,  0,  1,  0,  0,  0,  0, -1] [ 0,  6,  6] -1 */
    52561022, /* 45742 (1080) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    17009474, /* 45743 (1080) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  0]  1 */
    35559284, /* 45744 (1080) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 0,  6,  6] -1 */
    35550858, /* 45745 (1080) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6] -1 */
    52570092, /* 45746 (1080) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    52565880, /* 45747 (1080) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    35563820, /* 45748 (1080) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
    18426488, /* 45749 (1080) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    51148218, /* 45750 (1080) [ 0,  1,  0, -1,  0,  0,  0,  0, -1] [ 6,  0,  6] -1 */
    51144332, /* 45751 (1080) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 6,  0,  6] -1 */
       12272, /* 45752 (1080) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 0,  0,  0]  1 */
     1425072, /* 45753 (1080) [ 0, -1,  0,  1,  0,  0,  0,  0, -1] [ 0,  6,  0]  1 */
    34133520, /* 45754 (1080) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
    18430700, /* 45755 (1080) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    17022432, /* 45756 (1080) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  0]  1 */
    51139796, /* 45757 (1080) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
     1420536, /* 45758 (1080) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  0]  1 */
    18439770, /* 45759 (1080) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
     1433498, /* 45760 (1080) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  0]  1 */
    18435558, /* 45761 (1080) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 6,  6,  0]  1 */
       16484, /* 45762 (1081) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    52442922, /* 45763 (1081) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 6,  6,  0] -1 */
     1428962, /* 45764 (1081) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 0,  6,  0]  1 */
    51026232, /* 45765 (1081) [ 0, -1,  0,  1,  0,  0,  0,  0, -1] [ 6,  0,  0] -1 */
    52451996, /* 45766 (1081) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
        3198, /* 45767 (1081) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    35445720, /* 45768 (1081) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  0] -1 */
    51021696, /* 45769 (1081) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  0] -1 */
    51034658, /* 45770 (1081) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  0] -1 */
    51030122, /* 45771 (1081) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 6,  0,  0] -1 */
        7410, /* 45772 (1081) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    17017896, /* 45773 (1081) [ 0,  1,  0, -1,  0,  0,  0,  0, -1] [ 6,  0,  0]  1 */
    34015424, /* 45774 (1081) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    52447784, /* 45775 (1081) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 6,  6,  0] -1 */
    17014010, /* 45776 (1081) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 6,  0,  0]  1 */
    34019636, /* 45777 (1081) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    34028706, /* 45778 (1081) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    35441184, /* 45779 (1081) [ 0,  1,  0, -1,  0,  0,  0,  0, -1] [ 0,  6,  0] -1 */
    17009474, /* 45780 (1081) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  0]  1 */
    18426488, /* 45781 (1081) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    52438710, /* 45782 (1081) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
    35437298, /* 45783 (1081) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 0,  6,  0] -1 */
    34024494, /* 45784 (1081) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  0] -1 */
       12272, /* 45785 (1081) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 0,  0,  0]  1 */
     1425072, /* 45786 (1081) [ 0, -1,  0,  1,  0,  0,  0,  0, -1] [ 0,  6,  0]  1 */
    35432762, /* 45787 (1081) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  0] -1 */
    18430700, /* 45788 (1081) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    17022432, /* 45789 (1081) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  0]  1 */
     1420536, /* 45790 (1081) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  0]  1 */
    18439770, /* 45791 (1081) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
     1433498, /* 45792 (1081) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  0]  1 */
    18435558, /* 45793 (1081) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 6,  6,  0]  1 */
       16484, /* 45794 (1082) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
     1428962, /* 45795 (1082) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 0,  6,  0]  1 */
        3198, /* 45796 (1082) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    35563818, /* 45797 (1082) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  6] -1 */
    52570094, /* 45798 (1082) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
        7410, /* 45799 (1082) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    17017896, /* 45800 (1082) [ 0,  1,  0, -1,  0,  0,  0,  0, -1] [ 6,  0,  0]  1 */
    52565882, /* 45801 (1082) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    34133522, /* 45802 (1082) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    17014010, /* 45803 (1082) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 6,  0,  0]  1 */
    51144330, /* 45804 (1082) [ 0, -1,  0,  1,  0,  0,  0,  0, -1] [ 6,  0,  6] -1 */
    34137734, /* 45805 (1082) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    17009474, /* 45806 (1082) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  0]  1 */
    34146804, /* 45807 (1082) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
    35559282, /* 45808 (1082) [ 0,  1,  0, -1,  0,  0,  0,  0, -1] [ 0,  6,  6] -1 */
    35555396, /* 45809 (1082) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 0,  6,  6] -1 */
    51148220, /* 45810 (1082) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 6,  0,  6] -1 */
    52556808, /* 45811 (1082) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    18426488, /* 45812 (1082) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    34142592, /* 45813 (1082) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  6] -1 */
    51139794, /* 45814 (1082) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6] -1 */
    51152756, /* 45815 (1082) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
    35550860, /* 45816 (1082) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
       12272, /* 45817 (1082) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 0,  0,  0]  1 */
     1425072, /* 45818 (1082) [ 0, -1,  0,  1,  0,  0,  0,  0, -1] [ 0,  6,  0]  1 */
    18430700, /* 45819 (1082) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    17022432, /* 45820 (1082) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  0]  1 */
     1420536, /* 45821 (1082) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  0]  1 */
    18439770, /* 45822 (1082) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
     1433498, /* 45823 (1082) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  0]  1 */
    52561020, /* 45824 (1082) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    18435558, /* 45825 (1082) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 6,  6,  0]  1 */
       16484, /* 45826 (1083) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
        3200, /* 45827 (1083) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    18435074, /* 45828 (1083) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    18431186, /* 45829 (1083) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 6,  6,  0]  1 */
      125508, /* 45830 (1083) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  6]  1 */
      130368, /* 45831 (1083) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  6]  1 */
      134420, /* 45832 (1083) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6]  1 */
        7896, /* 45833 (1083) [ 0, -1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    18544746, /* 45834 (1083) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
    18426486, /* 45835 (1083) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
    18553658, /* 45836 (1083) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    18439770, /* 45837 (1083) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
       11784, /* 45838 (1083) [ 0,  1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    18557706, /* 45839 (1083) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
    18548798, /* 45840 (1083) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 6,  6,  6]  1 */
      121460, /* 45841 (1083) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6]  1 */
       16484, /* 45842 (1084) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34137732, /* 45843 (1084) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  6] -1 */
    18435074, /* 45844 (1084) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    34024008, /* 45845 (1084) [ 0,  1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  0] -1 */
      130368, /* 45846 (1084) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  6]  1 */
      134420, /* 45847 (1084) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6]  1 */
    18426486, /* 45848 (1084) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
    52569930, /* 45849 (1084) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
      121460, /* 45850 (1084) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6]  1 */
    52443410, /* 45851 (1084) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 6,  6,  0] -1 */
      125508, /* 45852 (1084) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  6]  1 */
       11784, /* 45853 (1084) [ 0,  1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    34015424, /* 45854 (1084) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    34028708, /* 45855 (1084) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    18557706, /* 45856 (1084) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
    34020120, /* 45857 (1084) [ 0, -1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    52565882, /* 45858 (1084) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    18431186, /* 45859 (1084) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    52451994, /* 45860 (1084) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
    52561022, /* 45861 (1084) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    52556970, /* 45862 (1084) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    52447298, /* 45863 (1084) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 6,  6,  0] -1 */
    34142592, /* 45864 (1084) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  6] -1 */
    34146644, /* 45865 (1084) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
        3200, /* 45866 (1084) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    52438710, /* 45867 (1084) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
        7896, /* 45868 (1084) [ 0, -1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    34133684, /* 45869 (1084) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    18553658, /* 45870 (1084) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    18439770, /* 45871 (1084) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
    18548798, /* 45872 (1084) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    18544746, /* 45873 (1084) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
       16484, /* 45874 (1085) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
        3200, /* 45875 (1085) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34137732, /* 45876 (1085) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  6] -1 */
    18435074, /* 45877 (1085) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    52438710, /* 45878 (1085) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
    18431186, /* 45879 (1085) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    34024008, /* 45880 (1085) [ 0,  1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  0] -1 */
      134420, /* 45881 (1085) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6]  1 */
    52451994, /* 45882 (1085) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
    52569930, /* 45883 (1085) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    18548798, /* 45884 (1085) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    18553658, /* 45885 (1085) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    52556970, /* 45886 (1085) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    34020120, /* 45887 (1085) [ 0, -1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    34142592, /* 45888 (1085) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  6] -1 */
      121460, /* 45889 (1085) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6]  1 */
       16484, /* 45890 (1086) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
        3200, /* 45891 (1086) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    52443410, /* 45892 (1086) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 6,  6,  0] -1 */
      125508, /* 45893 (1086) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  6]  1 */
    34024008, /* 45894 (1086) [ 0,  1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  0] -1 */
      130368, /* 45895 (1086) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  6]  1 */
    34133684, /* 45896 (1086) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    18426486, /* 45897 (1086) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
    52569930, /* 45898 (1086) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    18553658, /* 45899 (1086) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    18439770, /* 45900 (1086) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
    52556970, /* 45901 (1086) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    52447298, /* 45902 (1086) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 6,  6,  0] -1 */
    18548798, /* 45903 (1086) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    34146644, /* 45904 (1086) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    34020120, /* 45905 (1086) [ 0, -1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  0] -1 */
       16484, /* 45906 (1087) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
        3200, /* 45907 (1087) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    52443410, /* 45908 (1087) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 6,  6,  0] -1 */
    34137732, /* 45909 (1087) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  6] -1 */
    52565882, /* 45910 (1087) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    34024008, /* 45911 (1087) [ 0,  1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  0] -1 */
      134420, /* 45912 (1087) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6]  1 */
    18544746, /* 45913 (1087) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
    18426486, /* 45914 (1087) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
    52447298, /* 45915 (1087) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 6,  6,  0] -1 */
    52561022, /* 45916 (1087) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    18439770, /* 45917 (1087) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
    34020120, /* 45918 (1087) [ 0, -1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    18557706, /* 45919 (1087) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
    34142592, /* 45920 (1087) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  6] -1 */
      121460, /* 45921 (1087) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6]  1 */
       16484, /* 45922 (1088) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
        3200, /* 45923 (1088) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    52443410, /* 45924 (1088) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 6,  6,  0] -1 */
    34137732, /* 45925 (1088) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  6] -1 */
    52438710, /* 45926 (1088) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
        7896, /* 45927 (1088) [ 0, -1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    52451994, /* 45928 (1088) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
    34133684, /* 45929 (1088) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    52447298, /* 45930 (1088) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 6,  6,  0] -1 */
    18548798, /* 45931 (1088) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    18553658, /* 45932 (1088) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 6,  6,  6]  1 */
       11784, /* 45933 (1088) [ 0,  1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    18557706, /* 45934 (1088) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
    34142592, /* 45935 (1088) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  6] -1 */
    34146644, /* 45936 (1088) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    18544746, /* 45937 (1088) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
       16484, /* 45938 (1089) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
        3200, /* 45939 (1089) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34137732, /* 45940 (1089) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  6] -1 */
    18435074, /* 45941 (1089) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    52565882, /* 45942 (1089) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    18431186, /* 45943 (1089) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 6,  6,  0]  1 */
        7896, /* 45944 (1089) [ 0, -1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    34133684, /* 45945 (1089) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    18426486, /* 45946 (1089) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
    52569930, /* 45947 (1089) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    52561022, /* 45948 (1089) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    18439770, /* 45949 (1089) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
       11784, /* 45950 (1089) [ 0,  1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    52556970, /* 45951 (1089) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    34142592, /* 45952 (1089) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  6] -1 */
    34146644, /* 45953 (1089) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
       16484, /* 45954 (1090) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
        3200, /* 45955 (1090) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    52443410, /* 45956 (1090) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 6,  6,  0] -1 */
    52438710, /* 45957 (1090) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
    52565882, /* 45958 (1090) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 6,  6,  6] -1 */
      125508, /* 45959 (1090) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  6]  1 */
      130368, /* 45960 (1090) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  6]  1 */
      134420, /* 45961 (1090) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6]  1 */
        7896, /* 45962 (1090) [ 0, -1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    52451994, /* 45963 (1090) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
    52569930, /* 45964 (1090) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    52561022, /* 45965 (1090) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 6,  6,  6] -1 */
       11784, /* 45966 (1090) [ 0,  1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    52556970, /* 45967 (1090) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    52447298, /* 45968 (1090) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 6,  6,  0] -1 */
      121460, /* 45969 (1090) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6]  1 */
       16484, /* 45970 (1091) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
        3200, /* 45971 (1091) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    18435074, /* 45972 (1091) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    52438710, /* 45973 (1091) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
    52565882, /* 45974 (1091) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    18431186, /* 45975 (1091) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    34024008, /* 45976 (1091) [ 0,  1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  0] -1 */
      130368, /* 45977 (1091) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  6]  1 */
      125508, /* 45978 (1091) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  6]  1 */
    52451994, /* 45979 (1091) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
    34133684, /* 45980 (1091) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    52561022, /* 45981 (1091) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    34020120, /* 45982 (1091) [ 0, -1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    18557706, /* 45983 (1091) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
    34146644, /* 45984 (1091) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    18544746, /* 45985 (1091) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
       16484, /* 45986 (1092) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    18435074, /* 45987 (1092) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    34019634, /* 45988 (1092) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  0] -1 */
      130368, /* 45989 (1092) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  6]  1 */
      134420, /* 45990 (1092) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6]  1 */
    18426486, /* 45991 (1092) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
      121460, /* 45992 (1092) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6]  1 */
      125508, /* 45993 (1092) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  6]  1 */
    34015586, /* 45994 (1092) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    34146806, /* 45995 (1092) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
       11784, /* 45996 (1092) [ 0,  1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    18557706, /* 45997 (1092) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
    52447784, /* 45998 (1092) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 6,  6,  0] -1 */
    34133522, /* 45999 (1092) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    18431186, /* 46000 (1092) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    52442924, /* 46001 (1092) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 6,  6,  0] -1 */
    52451832, /* 46002 (1092) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
    34138218, /* 46003 (1092) [ 0, -1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  6] -1 */
    52438872, /* 46004 (1092) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
    34024494, /* 46005 (1092) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    34028546, /* 46006 (1092) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    52565396, /* 46007 (1092) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    52570092, /* 46008 (1092) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
        3200, /* 46009 (1092) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34142106, /* 46010 (1092) [ 0,  1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  6] -1 */
    52561508, /* 46011 (1092) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 6,  6,  6] -1 */
        7896, /* 46012 (1092) [ 0, -1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    52556808, /* 46013 (1092) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    18553658, /* 46014 (1092) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    18439770, /* 46015 (1092) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
    18548798, /* 46016 (1092) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    18544746, /* 46017 (1092) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
       16484, /* 46018 (1093) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    18435074, /* 46019 (1093) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 6,  6,  0]  1 */
      130368, /* 46020 (1093) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  6]  1 */
    52443408, /* 46021 (1093) [ 0, -1,  0,  1,  0,  0,  0,  0, -1] [ 6,  6,  0] -1 */
      134420, /* 46022 (1093) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6]  1 */
    52451996, /* 46023 (1093) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
    18426486, /* 46024 (1093) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
    34146642, /* 46025 (1093) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
      121460, /* 46026 (1093) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6]  1 */
    34024010, /* 46027 (1093) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  0] -1 */
      125508, /* 46028 (1093) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  6]  1 */
       11784, /* 46029 (1093) [ 0,  1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    52438712, /* 46030 (1093) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
    34142594, /* 46031 (1093) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    18557706, /* 46032 (1093) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
    18431186, /* 46033 (1093) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    34028706, /* 46034 (1093) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    52447296, /* 46035 (1093) [ 0,  1,  0, -1,  0,  0,  0,  0, -1] [ 6,  6,  0] -1 */
    34137734, /* 46036 (1093) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  6] -1 */
        3200, /* 46037 (1093) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    52565880, /* 46038 (1093) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    34133682, /* 46039 (1093) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
    34015422, /* 46040 (1093) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    34020122, /* 46041 (1093) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    52556972, /* 46042 (1093) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    52569932, /* 46043 (1093) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
        7896, /* 46044 (1093) [ 0, -1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    18553658, /* 46045 (1093) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    18439770, /* 46046 (1093) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
    52561020, /* 46047 (1093) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    18548798, /* 46048 (1093) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    18544746, /* 46049 (1093) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
       16484, /* 46050 (1094) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    52442922, /* 46051 (1094) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 6,  6,  0] -1 */
    18435074, /* 46052 (1094) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 6,  6,  0]  1 */
      130368, /* 46053 (1094) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  6]  1 */
      134420, /* 46054 (1094) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6]  1 */
    34028544, /* 46055 (1094) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    18426486, /* 46056 (1094) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
    34015584, /* 46057 (1094) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    52570094, /* 46058 (1094) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
      121460, /* 46059 (1094) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6]  1 */
    52451834, /* 46060 (1094) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
      125508, /* 46061 (1094) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  6]  1 */
       11784, /* 46062 (1094) [ 0,  1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    18557706, /* 46063 (1094) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
    34024496, /* 46064 (1094) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    52556810, /* 46065 (1094) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    18431186, /* 46066 (1094) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    34019636, /* 46067 (1094) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    52561506, /* 46068 (1094) [ 0, -1,  0,  1,  0,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    34146804, /* 46069 (1094) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
    52565394, /* 46070 (1094) [ 0,  1,  0, -1,  0,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    34138220, /* 46071 (1094) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    34142108, /* 46072 (1094) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    34133520, /* 46073 (1094) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
        3200, /* 46074 (1094) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    52447782, /* 46075 (1094) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 6,  6,  0] -1 */
        7896, /* 46076 (1094) [ 0, -1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    52438874, /* 46077 (1094) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
    18553658, /* 46078 (1094) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    18439770, /* 46079 (1094) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
    18548798, /* 46080 (1094) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    18544746, /* 46081 (1094) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
       16484, /* 46082 (1083) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    18426488, /* 46083 (1083) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
     1428962, /* 46084 (1083) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 0,  6,  0]  1 */
    17014010, /* 46085 (1083) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 6,  0,  0]  1 */
      125508, /* 46086 (1083) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  6]  1 */
    18553656, /* 46087 (1083) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 6,  6,  6]  1 */
     1551596, /* 46088 (1083) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
     1425072, /* 46089 (1083) [ 0, -1,  0,  1,  0,  0,  0,  0, -1] [ 0,  6,  0]  1 */
     1538634, /* 46090 (1083) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
        3198, /* 46091 (1083) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
      130370, /* 46092 (1083) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 0,  0,  6]  1 */
    18439770, /* 46093 (1083) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
    17017896, /* 46094 (1083) [ 0,  1,  0, -1,  0,  0,  0,  0, -1] [ 6,  0,  0]  1 */
    17140530, /* 46095 (1083) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  6]  1 */
    18548798, /* 46096 (1083) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    17127572, /* 46097 (1083) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
       16484, /* 46098 (1084) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34137732, /* 46099 (1084) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  6] -1 */
     1428962, /* 46100 (1084) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 0,  6,  0]  1 */
    51030120, /* 46101 (1084) [ 0,  1,  0, -1,  0,  0,  0,  0, -1] [ 6,  0,  0] -1 */
    18553656, /* 46102 (1084) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 6,  6,  6]  1 */
     1551596, /* 46103 (1084) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
        3198, /* 46104 (1084) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    51152754, /* 46105 (1084) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  6] -1 */
    17127572, /* 46106 (1084) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
    51026234, /* 46107 (1084) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 6,  0,  0] -1 */
      125508, /* 46108 (1084) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  6]  1 */
    17017896, /* 46109 (1084) [ 0,  1,  0, -1,  0,  0,  0,  0, -1] [ 6,  0,  0]  1 */
    52438712, /* 46110 (1084) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
    34028708, /* 46111 (1084) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    17140530, /* 46112 (1084) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  6]  1 */
    35437296, /* 46113 (1084) [ 0, -1,  0,  1,  0,  0,  0,  0, -1] [ 0,  6,  0] -1 */
    34142594, /* 46114 (1084) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    17014010, /* 46115 (1084) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 6,  0,  0]  1 */
    52451994, /* 46116 (1084) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
    52561022, /* 46117 (1084) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    35550858, /* 46118 (1084) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6] -1 */
    35441186, /* 46119 (1084) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 0,  6,  0] -1 */
    52565880, /* 46120 (1084) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    35563820, /* 46121 (1084) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
    18426488, /* 46122 (1084) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    34015422, /* 46123 (1084) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
     1425072, /* 46124 (1084) [ 0, -1,  0,  1,  0,  0,  0,  0, -1] [ 0,  6,  0]  1 */
    51139796, /* 46125 (1084) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
      130370, /* 46126 (1084) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 0,  0,  6]  1 */
    18439770, /* 46127 (1084) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
    18548798, /* 46128 (1084) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 6,  6,  6]  1 */
     1538634, /* 46129 (1084) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
       16484, /* 46130 (1085) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    18426488, /* 46131 (1085) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    34137732, /* 46132 (1085) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  6] -1 */
     1428962, /* 46133 (1085) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 0,  6,  0]  1 */
    34015422, /* 46134 (1085) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    17014010, /* 46135 (1085) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 6,  0,  0]  1 */
    51030120, /* 46136 (1085) [ 0,  1,  0, -1,  0,  0,  0,  0, -1] [ 6,  0,  0] -1 */
     1551596, /* 46137 (1085) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
    52451994, /* 46138 (1085) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
    51152754, /* 46139 (1085) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  6] -1 */
    18548798, /* 46140 (1085) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 6,  6,  6]  1 */
      130370, /* 46141 (1085) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 0,  0,  6]  1 */
    35550858, /* 46142 (1085) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6] -1 */
    35437296, /* 46143 (1085) [ 0, -1,  0,  1,  0,  0,  0,  0, -1] [ 0,  6,  0] -1 */
    52565880, /* 46144 (1085) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    17127572, /* 46145 (1085) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
       16484, /* 46146 (1086) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    18426488, /* 46147 (1086) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    51026234, /* 46148 (1086) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 6,  0,  0] -1 */
      125508, /* 46149 (1086) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  6]  1 */
    51030120, /* 46150 (1086) [ 0,  1,  0, -1,  0,  0,  0,  0, -1] [ 6,  0,  0] -1 */
    18553656, /* 46151 (1086) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 6,  6,  6]  1 */
    51139796, /* 46152 (1086) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
        3198, /* 46153 (1086) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    51152754, /* 46154 (1086) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  6] -1 */
      130370, /* 46155 (1086) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 0,  0,  6]  1 */
    18439770, /* 46156 (1086) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
    35550858, /* 46157 (1086) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6] -1 */
    35441186, /* 46158 (1086) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 0,  6,  0] -1 */
    18548798, /* 46159 (1086) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    35563820, /* 46160 (1086) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
    35437296, /* 46161 (1086) [ 0, -1,  0,  1,  0,  0,  0,  0, -1] [ 0,  6,  0] -1 */
       16484, /* 46162 (1087) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    18426488, /* 46163 (1087) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    51026234, /* 46164 (1087) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 6,  0,  0] -1 */
    34137732, /* 46165 (1087) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  6] -1 */
    34142594, /* 46166 (1087) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    51030120, /* 46167 (1087) [ 0,  1,  0, -1,  0,  0,  0,  0, -1] [ 6,  0,  0] -1 */
     1551596, /* 46168 (1087) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
     1538634, /* 46169 (1087) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
        3198, /* 46170 (1087) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    35441186, /* 46171 (1087) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 0,  6,  0] -1 */
    52561022, /* 46172 (1087) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    18439770, /* 46173 (1087) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
    35437296, /* 46174 (1087) [ 0, -1,  0,  1,  0,  0,  0,  0, -1] [ 0,  6,  0] -1 */
    17140530, /* 46175 (1087) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  6]  1 */
    52565880, /* 46176 (1087) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    17127572, /* 46177 (1087) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
       16484, /* 46178 (1088) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    18426488, /* 46179 (1088) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    51026234, /* 46180 (1088) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 6,  0,  0] -1 */
    34137732, /* 46181 (1088) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  6] -1 */
    34015422, /* 46182 (1088) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
     1425072, /* 46183 (1088) [ 0, -1,  0,  1,  0,  0,  0,  0, -1] [ 0,  6,  0]  1 */
    52451994, /* 46184 (1088) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
    51139796, /* 46185 (1088) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
    35441186, /* 46186 (1088) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 0,  6,  0] -1 */
    18548798, /* 46187 (1088) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 6,  6,  6]  1 */
      130370, /* 46188 (1088) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 0,  0,  6]  1 */
    17017896, /* 46189 (1088) [ 0,  1,  0, -1,  0,  0,  0,  0, -1] [ 6,  0,  0]  1 */
    17140530, /* 46190 (1088) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  6]  1 */
    52565880, /* 46191 (1088) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    35563820, /* 46192 (1088) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
     1538634, /* 46193 (1088) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
       16484, /* 46194 (1089) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    18426488, /* 46195 (1089) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    34137732, /* 46196 (1089) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  6] -1 */
     1428962, /* 46197 (1089) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 0,  6,  0]  1 */
    34142594, /* 46198 (1089) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    17014010, /* 46199 (1089) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 6,  0,  0]  1 */
     1425072, /* 46200 (1089) [ 0, -1,  0,  1,  0,  0,  0,  0, -1] [ 0,  6,  0]  1 */
    51139796, /* 46201 (1089) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
        3198, /* 46202 (1089) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    51152754, /* 46203 (1089) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  6] -1 */
    52561022, /* 46204 (1089) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    18439770, /* 46205 (1089) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
    17017896, /* 46206 (1089) [ 0,  1,  0, -1,  0,  0,  0,  0, -1] [ 6,  0,  0]  1 */
    35550858, /* 46207 (1089) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6] -1 */
    52565880, /* 46208 (1089) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    35563820, /* 46209 (1089) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
       16484, /* 46210 (1090) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    18426488, /* 46211 (1090) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    51026234, /* 46212 (1090) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 6,  0,  0] -1 */
    34015422, /* 46213 (1090) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    34142594, /* 46214 (1090) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 0,  0,  6] -1 */
      125508, /* 46215 (1090) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  6]  1 */
    18553656, /* 46216 (1090) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 6,  6,  6]  1 */
     1551596, /* 46217 (1090) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
     1425072, /* 46218 (1090) [ 0, -1,  0,  1,  0,  0,  0,  0, -1] [ 0,  6,  0]  1 */
    52451994, /* 46219 (1090) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
    51152754, /* 46220 (1090) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  6] -1 */
    52561022, /* 46221 (1090) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    17017896, /* 46222 (1090) [ 0,  1,  0, -1,  0,  0,  0,  0, -1] [ 6,  0,  0]  1 */
    35550858, /* 46223 (1090) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6] -1 */
    35441186, /* 46224 (1090) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 0,  6,  0] -1 */
    17127572, /* 46225 (1090) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
       16484, /* 46226 (1091) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    18426488, /* 46227 (1091) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
     1428962, /* 46228 (1091) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 0,  6,  0]  1 */
    34015422, /* 46229 (1091) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    34142594, /* 46230 (1091) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    17014010, /* 46231 (1091) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 6,  0,  0]  1 */
    51030120, /* 46232 (1091) [ 0,  1,  0, -1,  0,  0,  0,  0, -1] [ 6,  0,  0] -1 */
    18553656, /* 46233 (1091) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 6,  6,  6]  1 */
      125508, /* 46234 (1091) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  6]  1 */
    52451994, /* 46235 (1091) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
    51139796, /* 46236 (1091) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
    52561022, /* 46237 (1091) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    35437296, /* 46238 (1091) [ 0, -1,  0,  1,  0,  0,  0,  0, -1] [ 0,  6,  0] -1 */
    17140530, /* 46239 (1091) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  6]  1 */
    35563820, /* 46240 (1091) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
     1538634, /* 46241 (1091) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
       16484, /* 46242 (1092) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
     1428962, /* 46243 (1092) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 0,  6,  0]  1 */
    34019634, /* 46244 (1092) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    18553656, /* 46245 (1092) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 6,  6,  6]  1 */
     1551596, /* 46246 (1092) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
        3198, /* 46247 (1092) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    17127572, /* 46248 (1092) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
      125508, /* 46249 (1092) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  6]  1 */
    51021698, /* 46250 (1092) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  0] -1 */
    34146806, /* 46251 (1092) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    17017896, /* 46252 (1092) [ 0,  1,  0, -1,  0,  0,  0,  0, -1] [ 6,  0,  0]  1 */
    17140530, /* 46253 (1092) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  6]  1 */
    34024496, /* 46254 (1092) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    52556810, /* 46255 (1092) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    17014010, /* 46256 (1092) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 6,  0,  0]  1 */
    52442924, /* 46257 (1092) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 6,  6,  0] -1 */
    51034656, /* 46258 (1092) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  0] -1 */
    35555394, /* 46259 (1092) [ 0, -1,  0,  1,  0,  0,  0,  0, -1] [ 0,  6,  6] -1 */
    35432760, /* 46260 (1092) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  0] -1 */
    52447782, /* 46261 (1092) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 6,  6,  0] -1 */
    35445722, /* 46262 (1092) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  0] -1 */
    35559284, /* 46263 (1092) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 0,  6,  6] -1 */
    52570092, /* 46264 (1092) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    18426488, /* 46265 (1092) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    51148218, /* 46266 (1092) [ 0,  1,  0, -1,  0,  0,  0,  0, -1] [ 6,  0,  6] -1 */
    51144332, /* 46267 (1092) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 6,  0,  6] -1 */
     1425072, /* 46268 (1092) [ 0, -1,  0,  1,  0,  0,  0,  0, -1] [ 0,  6,  0]  1 */
    34133520, /* 46269 (1092) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
      130370, /* 46270 (1092) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 0,  0,  6]  1 */
    18439770, /* 46271 (1092) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
    18548798, /* 46272 (1092) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 6,  6,  6]  1 */
     1538634, /* 46273 (1092) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
       16484, /* 46274 (1093) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
     1428962, /* 46275 (1093) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 0,  6,  0]  1 */
    18553656, /* 46276 (1093) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 6,  6,  6]  1 */
    51026232, /* 46277 (1093) [ 0, -1,  0,  1,  0,  0,  0,  0, -1] [ 6,  0,  0] -1 */
     1551596, /* 46278 (1093) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
    52451996, /* 46279 (1093) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
        3198, /* 46280 (1093) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    35563818, /* 46281 (1093) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  6] -1 */
    17127572, /* 46282 (1093) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
    51030122, /* 46283 (1093) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 6,  0,  0] -1 */
      125508, /* 46284 (1093) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  6]  1 */
    17017896, /* 46285 (1093) [ 0,  1,  0, -1,  0,  0,  0,  0, -1] [ 6,  0,  0]  1 */
    34015424, /* 46286 (1093) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    52565882, /* 46287 (1093) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    17140530, /* 46288 (1093) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  6]  1 */
    17014010, /* 46289 (1093) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 6,  0,  0]  1 */
    34028706, /* 46290 (1093) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    35441184, /* 46291 (1093) [ 0,  1,  0, -1,  0,  0,  0,  0, -1] [ 0,  6,  0] -1 */
    34137734, /* 46292 (1093) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    18426488, /* 46293 (1093) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    34142592, /* 46294 (1093) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  6] -1 */
    51139794, /* 46295 (1093) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6] -1 */
    52438710, /* 46296 (1093) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
    35437298, /* 46297 (1093) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 0,  6,  0] -1 */
    35550860, /* 46298 (1093) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
    51152756, /* 46299 (1093) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
     1425072, /* 46300 (1093) [ 0, -1,  0,  1,  0,  0,  0,  0, -1] [ 0,  6,  0]  1 */
      130370, /* 46301 (1093) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 0,  0,  6]  1 */
    18439770, /* 46302 (1093) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
    52561020, /* 46303 (1093) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    18548798, /* 46304 (1093) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 6,  6,  6]  1 */
     1538634, /* 46305 (1093) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
       16484, /* 46306 (1094) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    52442922, /* 46307 (1094) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 6,  6,  0] -1 */
     1428962, /* 46308 (1094) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 0,  6,  0]  1 */
    18553656, /* 46309 (1094) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 6,  6,  6]  1 */
     1551596, /* 46310 (1094) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
    35445720, /* 46311 (1094) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  0] -1 */
        3198, /* 46312 (1094) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    51021696, /* 46313 (1094) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  0] -1 */
    52570094, /* 46314 (1094) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    17127572, /* 46315 (1094) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
    51034658, /* 46316 (1094) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  0] -1 */
      125508, /* 46317 (1094) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  6]  1 */
    17017896, /* 46318 (1094) [ 0,  1,  0, -1,  0,  0,  0,  0, -1] [ 6,  0,  0]  1 */
    17140530, /* 46319 (1094) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  6]  1 */
    52447784, /* 46320 (1094) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 6,  6,  0] -1 */
    34133522, /* 46321 (1094) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    17014010, /* 46322 (1094) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 6,  0,  0]  1 */
    34019636, /* 46323 (1094) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    51144330, /* 46324 (1094) [ 0, -1,  0,  1,  0,  0,  0,  0, -1] [ 6,  0,  6] -1 */
    34146804, /* 46325 (1094) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
    35559282, /* 46326 (1094) [ 0,  1,  0, -1,  0,  0,  0,  0, -1] [ 0,  6,  6] -1 */
    35555396, /* 46327 (1094) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 0,  6,  6] -1 */
    51148220, /* 46328 (1094) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 6,  0,  6] -1 */
    52556808, /* 46329 (1094) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    18426488, /* 46330 (1094) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    34024494, /* 46331 (1094) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  0] -1 */
     1425072, /* 46332 (1094) [ 0, -1,  0,  1,  0,  0,  0,  0, -1] [ 0,  6,  0]  1 */
    35432762, /* 46333 (1094) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  0] -1 */
      130370, /* 46334 (1094) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 0,  0,  6]  1 */
    18439770, /* 46335 (1094) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
    18548798, /* 46336 (1094) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 6,  6,  6]  1 */
     1538634, /* 46337 (1094) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
       16484, /* 46338 (1095) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
        3200, /* 46339 (1095) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
        3362, /* 46340 (1095) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
      130368, /* 46341 (1095) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  6]  1 */
      125508, /* 46342 (1095) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  6]  1 */
       16320, /* 46343 (1095) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
      129884, /* 46344 (1095) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  6]  1 */
        3198, /* 46345 (1095) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
      129882, /* 46346 (1095) [ 0,  1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  6]  1 */
      125996, /* 46347 (1095) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 0,  0,  6]  1 */
      130370, /* 46348 (1095) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 0,  0,  6]  1 */
      125994, /* 46349 (1095) [ 0, -1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  6]  1 */
        3360, /* 46350 (1095) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
      125510, /* 46351 (1095) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  6]  1 */
       16482, /* 46352 (1095) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
       16322, /* 46353 (1095) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
       16484, /* 46354 (1096) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34137732, /* 46355 (1096) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  6] -1 */
      130368, /* 46356 (1096) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  6]  1 */
       16320, /* 46357 (1096) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
        3198, /* 46358 (1096) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    34142108, /* 46359 (1096) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  6] -1 */
      125508, /* 46360 (1096) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  6]  1 */
    34015584, /* 46361 (1096) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    34138220, /* 46362 (1096) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    34142106, /* 46363 (1096) [ 0,  1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  6] -1 */
    34138218, /* 46364 (1096) [ 0, -1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  6] -1 */
    34015424, /* 46365 (1096) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    34028546, /* 46366 (1096) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    34028708, /* 46367 (1096) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    34015586, /* 46368 (1096) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    34142594, /* 46369 (1096) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 0,  0,  6] -1 */
      129884, /* 46370 (1096) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  6]  1 */
    34028706, /* 46371 (1096) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
      125996, /* 46372 (1096) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 0,  0,  6]  1 */
      129882, /* 46373 (1096) [ 0,  1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  6]  1 */
      125994, /* 46374 (1096) [ 0, -1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  6]  1 */
    34137734, /* 46375 (1096) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  6] -1 */
        3360, /* 46376 (1096) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    34028544, /* 46377 (1096) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
       16322, /* 46378 (1096) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34142592, /* 46379 (1096) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  6] -1 */
    34015422, /* 46380 (1096) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
        3200, /* 46381 (1096) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
        3362, /* 46382 (1096) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
      130370, /* 46383 (1096) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 0,  0,  6]  1 */
      125510, /* 46384 (1096) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  6]  1 */
       16482, /* 46385 (1096) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
       16484, /* 46386 (1097) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34142592, /* 46387 (1097) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  6] -1 */
    34137732, /* 46388 (1097) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  6] -1 */
    34015422, /* 46389 (1097) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
        3200, /* 46390 (1097) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
        3362, /* 46391 (1097) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
      129884, /* 46392 (1097) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  6]  1 */
    34015584, /* 46393 (1097) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    34142106, /* 46394 (1097) [ 0,  1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  6] -1 */
    34028706, /* 46395 (1097) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    34138218, /* 46396 (1097) [ 0, -1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  6] -1 */
      125996, /* 46397 (1097) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 0,  0,  6]  1 */
      130370, /* 46398 (1097) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 0,  0,  6]  1 */
      125510, /* 46399 (1097) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  6]  1 */
    34028544, /* 46400 (1097) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
       16322, /* 46401 (1097) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
       16484, /* 46402 (1098) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34015586, /* 46403 (1098) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    34142108, /* 46404 (1098) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  6] -1 */
        3200, /* 46405 (1098) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
      125508, /* 46406 (1098) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  6]  1 */
      130368, /* 46407 (1098) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  6]  1 */
    34015584, /* 46408 (1098) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    34142106, /* 46409 (1098) [ 0,  1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  6] -1 */
    34138220, /* 46410 (1098) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    34138218, /* 46411 (1098) [ 0, -1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  6] -1 */
        3198, /* 46412 (1098) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
      130370, /* 46413 (1098) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 0,  0,  6]  1 */
    34028546, /* 46414 (1098) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
      125510, /* 46415 (1098) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  6]  1 */
       16482, /* 46416 (1098) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    34028544, /* 46417 (1098) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
       16484, /* 46418 (1099) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34142592, /* 46419 (1099) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  6] -1 */
    34137732, /* 46420 (1099) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  6] -1 */
    34142108, /* 46421 (1099) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  6] -1 */
        3200, /* 46422 (1099) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34142594, /* 46423 (1099) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 0,  0,  6] -1 */
        3362, /* 46424 (1099) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
       16320, /* 46425 (1099) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    34138220, /* 46426 (1099) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    34142106, /* 46427 (1099) [ 0,  1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  6] -1 */
    34138218, /* 46428 (1099) [ 0, -1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  6] -1 */
        3198, /* 46429 (1099) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    34137734, /* 46430 (1099) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  6] -1 */
        3360, /* 46431 (1099) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
       16482, /* 46432 (1099) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
       16322, /* 46433 (1099) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
       16484, /* 46434 (1100) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34142592, /* 46435 (1100) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  6] -1 */
    34137732, /* 46436 (1100) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  6] -1 */
    34015422, /* 46437 (1100) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    34015586, /* 46438 (1100) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
        3200, /* 46439 (1100) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34142108, /* 46440 (1100) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  6] -1 */
       16320, /* 46441 (1100) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    34138220, /* 46442 (1100) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    34028706, /* 46443 (1100) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
      129882, /* 46444 (1100) [ 0,  1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  6]  1 */
      130370, /* 46445 (1100) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 0,  0,  6]  1 */
      125994, /* 46446 (1100) [ 0, -1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  6]  1 */
    34028546, /* 46447 (1100) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
        3360, /* 46448 (1100) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
      125510, /* 46449 (1100) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  6]  1 */
       16484, /* 46450 (1101) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34015586, /* 46451 (1101) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    34142592, /* 46452 (1101) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  6] -1 */
    34137732, /* 46453 (1101) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  6] -1 */
        3200, /* 46454 (1101) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34142594, /* 46455 (1101) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 0,  0,  6] -1 */
      129884, /* 46456 (1101) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  6]  1 */
    34015584, /* 46457 (1101) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
        3198, /* 46458 (1101) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
      129882, /* 46459 (1101) [ 0,  1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  6]  1 */
      125996, /* 46460 (1101) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 0,  0,  6]  1 */
    34137734, /* 46461 (1101) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  6] -1 */
      125994, /* 46462 (1101) [ 0, -1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  6]  1 */
    34028546, /* 46463 (1101) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
       16482, /* 46464 (1101) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    34028544, /* 46465 (1101) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
       16484, /* 46466 (1102) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34142108, /* 46467 (1102) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    34015422, /* 46468 (1102) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
        3200, /* 46469 (1102) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34142594, /* 46470 (1102) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 0,  0,  6] -1 */
      125508, /* 46471 (1102) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  6]  1 */
      130368, /* 46472 (1102) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  6]  1 */
        3362, /* 46473 (1102) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34015584, /* 46474 (1102) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    34138220, /* 46475 (1102) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    34028706, /* 46476 (1102) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
      129882, /* 46477 (1102) [ 0,  1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  6]  1 */
    34137734, /* 46478 (1102) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  6] -1 */
      125994, /* 46479 (1102) [ 0, -1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  6]  1 */
    34028544, /* 46480 (1102) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
       16322, /* 46481 (1102) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
       16484, /* 46482 (1103) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34015586, /* 46483 (1103) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    34015422, /* 46484 (1103) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
        3200, /* 46485 (1103) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34142594, /* 46486 (1103) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 0,  0,  6] -1 */
      125508, /* 46487 (1103) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  6]  1 */
      130368, /* 46488 (1103) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  6]  1 */
      129884, /* 46489 (1103) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  6]  1 */
       16320, /* 46490 (1103) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    34142106, /* 46491 (1103) [ 0,  1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  6] -1 */
    34028706, /* 46492 (1103) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    34138218, /* 46493 (1103) [ 0, -1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  6] -1 */
      125996, /* 46494 (1103) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 0,  0,  6]  1 */
    34137734, /* 46495 (1103) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    34028546, /* 46496 (1103) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
        3360, /* 46497 (1103) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
       16484, /* 46498 (1104) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34019634, /* 46499 (1104) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  0] -1 */
      130368, /* 46500 (1104) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  6]  1 */
       16320, /* 46501 (1104) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
        3198, /* 46502 (1104) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    34024008, /* 46503 (1104) [ 0,  1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    34020120, /* 46504 (1104) [ 0, -1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  0] -1 */
      125508, /* 46505 (1104) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  6]  1 */
    34024010, /* 46506 (1104) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    34146644, /* 46507 (1104) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    34020122, /* 46508 (1104) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    34146806, /* 46509 (1104) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    34133684, /* 46510 (1104) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    34133682, /* 46511 (1104) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
    34024496, /* 46512 (1104) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    34133522, /* 46513 (1104) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
      129884, /* 46514 (1104) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  6]  1 */
    34019636, /* 46515 (1104) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  0] -1 */
      125996, /* 46516 (1104) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 0,  0,  6]  1 */
      129882, /* 46517 (1104) [ 0,  1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  6]  1 */
      125994, /* 46518 (1104) [ 0, -1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  6]  1 */
    34146642, /* 46519 (1104) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
        3360, /* 46520 (1104) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    34146804, /* 46521 (1104) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
       16322, /* 46522 (1104) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
        3200, /* 46523 (1104) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
        3362, /* 46524 (1104) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34024494, /* 46525 (1104) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    34133520, /* 46526 (1104) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
      130370, /* 46527 (1104) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 0,  0,  6]  1 */
      125510, /* 46528 (1104) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  6]  1 */
       16482, /* 46529 (1104) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
       16484, /* 46530 (1105) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    52561506, /* 46531 (1105) [ 0, -1,  0,  1,  0,  0,  0,  0, -1] [ 6,  6,  6] -1 */
      130368, /* 46532 (1105) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  6]  1 */
       16320, /* 46533 (1105) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    52451996, /* 46534 (1105) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
        3198, /* 46535 (1105) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    52565394, /* 46536 (1105) [ 0,  1,  0, -1,  0,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    52438872, /* 46537 (1105) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
    52561020, /* 46538 (1105) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    52451834, /* 46539 (1105) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
    52565396, /* 46540 (1105) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    52561508, /* 46541 (1105) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 6,  6,  6] -1 */
      125508, /* 46542 (1105) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  6]  1 */
    52438874, /* 46543 (1105) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
    52565882, /* 46544 (1105) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    52438712, /* 46545 (1105) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
      129884, /* 46546 (1105) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  6]  1 */
    52451994, /* 46547 (1105) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
      125996, /* 46548 (1105) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 0,  0,  6]  1 */
      129882, /* 46549 (1105) [ 0,  1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  6]  1 */
      125994, /* 46550 (1105) [ 0, -1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  6]  1 */
    52561022, /* 46551 (1105) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 6,  6,  6] -1 */
        3360, /* 46552 (1105) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    52565880, /* 46553 (1105) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    52451832, /* 46554 (1105) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
       16322, /* 46555 (1105) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    52438710, /* 46556 (1105) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
        3200, /* 46557 (1105) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
        3362, /* 46558 (1105) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
      130370, /* 46559 (1105) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 0,  0,  6]  1 */
      125510, /* 46560 (1105) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  6]  1 */
       16482, /* 46561 (1105) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
       16484, /* 46562 (1106) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    52442922, /* 46563 (1106) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 6,  6,  0] -1 */
      130368, /* 46564 (1106) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  6]  1 */
       16320, /* 46565 (1106) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    52443408, /* 46566 (1106) [ 0, -1,  0,  1,  0,  0,  0,  0, -1] [ 6,  6,  0] -1 */
    52447298, /* 46567 (1106) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 6,  6,  0] -1 */
        3198, /* 46568 (1106) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    52556970, /* 46569 (1106) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    52447296, /* 46570 (1106) [ 0,  1,  0, -1,  0,  0,  0,  0, -1] [ 6,  6,  0] -1 */
    52570094, /* 46571 (1106) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    52443410, /* 46572 (1106) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 6,  6,  0] -1 */
      125508, /* 46573 (1106) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  6]  1 */
    52569932, /* 46574 (1106) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    52556972, /* 46575 (1106) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    52447784, /* 46576 (1106) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 6,  6,  0] -1 */
    52556810, /* 46577 (1106) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
      129884, /* 46578 (1106) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  6]  1 */
    52442924, /* 46579 (1106) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 6,  6,  0] -1 */
    52447782, /* 46580 (1106) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 6,  6,  0] -1 */
      125996, /* 46581 (1106) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 0,  0,  6]  1 */
      129882, /* 46582 (1106) [ 0,  1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  6]  1 */
      125994, /* 46583 (1106) [ 0, -1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  6]  1 */
    52569930, /* 46584 (1106) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
        3360, /* 46585 (1106) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    52570092, /* 46586 (1106) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    52556808, /* 46587 (1106) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
       16322, /* 46588 (1106) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
        3200, /* 46589 (1106) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
        3362, /* 46590 (1106) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
      130370, /* 46591 (1106) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 0,  0,  6]  1 */
      125510, /* 46592 (1106) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  6]  1 */
       16482, /* 46593 (1106) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
       16484, /* 46594 (1107) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
      121460, /* 46595 (1107) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6]  1 */
      121458, /* 46596 (1107) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  6]  1 */
      134418, /* 46597 (1107) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  6]  1 */
        3200, /* 46598 (1107) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
      129884, /* 46599 (1107) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  6]  1 */
       12272, /* 46600 (1107) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 0,  0,  0]  1 */
        7410, /* 46601 (1107) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  0]  1 */
       12270, /* 46602 (1107) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  0]  1 */
        7412, /* 46603 (1107) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  0]  1 */
        3198, /* 46604 (1107) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
      129882, /* 46605 (1107) [ 0,  1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  6]  1 */
      125996, /* 46606 (1107) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 0,  0,  6]  1 */
      125994, /* 46607 (1107) [ 0, -1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  6]  1 */
      134420, /* 46608 (1107) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6]  1 */
       16482, /* 46609 (1107) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
       16484, /* 46610 (1108) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
      134418, /* 46611 (1108) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  6]  1 */
    34019634, /* 46612 (1108) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  0] -1 */
       12270, /* 46613 (1108) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  0]  1 */
        3198, /* 46614 (1108) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    34142108, /* 46615 (1108) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    34146644, /* 46616 (1108) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    34138220, /* 46617 (1108) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 0,  0,  6] -1 */
        7410, /* 46618 (1108) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    34142106, /* 46619 (1108) [ 0,  1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  6] -1 */
    34138218, /* 46620 (1108) [ 0, -1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  6] -1 */
    34133684, /* 46621 (1108) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    34133682, /* 46622 (1108) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
    34015424, /* 46623 (1108) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    34028708, /* 46624 (1108) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    34024496, /* 46625 (1108) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 0,  0,  0] -1 */
      129884, /* 46626 (1108) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  6]  1 */
    34019636, /* 46627 (1108) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    34028706, /* 46628 (1108) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
      125996, /* 46629 (1108) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 0,  0,  6]  1 */
      129882, /* 46630 (1108) [ 0,  1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  6]  1 */
      125994, /* 46631 (1108) [ 0, -1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  6]  1 */
    34146642, /* 46632 (1108) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
      134420, /* 46633 (1108) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6]  1 */
      121460, /* 46634 (1108) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6]  1 */
    34015422, /* 46635 (1108) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
      121458, /* 46636 (1108) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  6]  1 */
        3200, /* 46637 (1108) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34024494, /* 46638 (1108) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  0] -1 */
       12272, /* 46639 (1108) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 0,  0,  0]  1 */
        7412, /* 46640 (1108) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  0]  1 */
       16482, /* 46641 (1108) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
       16484, /* 46642 (1109) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
      121460, /* 46643 (1109) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6]  1 */
    34015422, /* 46644 (1109) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
        3200, /* 46645 (1109) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34019634, /* 46646 (1109) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    34024494, /* 46647 (1109) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  0] -1 */
      129884, /* 46648 (1109) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  6]  1 */
       12272, /* 46649 (1109) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34142106, /* 46650 (1109) [ 0,  1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  6] -1 */
    34028706, /* 46651 (1109) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    34138218, /* 46652 (1109) [ 0, -1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  6] -1 */
        7412, /* 46653 (1109) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  0]  1 */
      125996, /* 46654 (1109) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 0,  0,  6]  1 */
    34133682, /* 46655 (1109) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
    34146642, /* 46656 (1109) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
      134420, /* 46657 (1109) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6]  1 */
       16484, /* 46658 (1110) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34142108, /* 46659 (1110) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  6] -1 */
        3200, /* 46660 (1110) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
       12272, /* 46661 (1110) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34146644, /* 46662 (1110) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    34142106, /* 46663 (1110) [ 0,  1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  6] -1 */
    34138220, /* 46664 (1110) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 0,  0,  6] -1 */
       12270, /* 46665 (1110) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  0]  1 */
        7410, /* 46666 (1110) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  0]  1 */
        7412, /* 46667 (1110) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  0]  1 */
        3198, /* 46668 (1110) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    34138218, /* 46669 (1110) [ 0, -1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  6] -1 */
    34133684, /* 46670 (1110) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    34133682, /* 46671 (1110) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
    34146642, /* 46672 (1110) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
       16482, /* 46673 (1110) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
       16484, /* 46674 (1111) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
      121460, /* 46675 (1111) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6]  1 */
    34142108, /* 46676 (1111) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  6] -1 */
      121458, /* 46677 (1111) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  6]  1 */
      134418, /* 46678 (1111) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  6]  1 */
        3200, /* 46679 (1111) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34019634, /* 46680 (1111) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    34024494, /* 46681 (1111) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    34019636, /* 46682 (1111) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    34138220, /* 46683 (1111) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    34142106, /* 46684 (1111) [ 0,  1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  6] -1 */
    34024496, /* 46685 (1111) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    34138218, /* 46686 (1111) [ 0, -1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  6] -1 */
        3198, /* 46687 (1111) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
      134420, /* 46688 (1111) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6]  1 */
       16482, /* 46689 (1111) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
       16484, /* 46690 (1112) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34142108, /* 46691 (1112) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    34015422, /* 46692 (1112) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
      134418, /* 46693 (1112) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  6]  1 */
        3200, /* 46694 (1112) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34019634, /* 46695 (1112) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    34024494, /* 46696 (1112) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  0] -1 */
      121458, /* 46697 (1112) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  6]  1 */
       12272, /* 46698 (1112) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34146644, /* 46699 (1112) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    34138220, /* 46700 (1112) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    34028706, /* 46701 (1112) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
        7412, /* 46702 (1112) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  0]  1 */
      129882, /* 46703 (1112) [ 0,  1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  6]  1 */
    34133684, /* 46704 (1112) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
      125994, /* 46705 (1112) [ 0, -1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  6]  1 */
       16484, /* 46706 (1113) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
        3200, /* 46707 (1113) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34019634, /* 46708 (1113) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    34024494, /* 46709 (1113) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    34019636, /* 46710 (1113) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  0] -1 */
      129884, /* 46711 (1113) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  6]  1 */
    34146644, /* 46712 (1113) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    34024496, /* 46713 (1113) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 0,  0,  0] -1 */
        3198, /* 46714 (1113) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
      129882, /* 46715 (1113) [ 0,  1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  6]  1 */
      125996, /* 46716 (1113) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 0,  0,  6]  1 */
    34133684, /* 46717 (1113) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    34146642, /* 46718 (1113) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
    34133682, /* 46719 (1113) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
      125994, /* 46720 (1113) [ 0, -1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  6]  1 */
       16482, /* 46721 (1113) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
       16484, /* 46722 (1114) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
      121460, /* 46723 (1114) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6]  1 */
    34142108, /* 46724 (1114) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    34015422, /* 46725 (1114) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
        3200, /* 46726 (1114) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34019636, /* 46727 (1114) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    34138220, /* 46728 (1114) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 0,  0,  6] -1 */
        7410, /* 46729 (1114) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  0]  1 */
       12270, /* 46730 (1114) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    34028706, /* 46731 (1114) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
      134420, /* 46732 (1114) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6]  1 */
      129882, /* 46733 (1114) [ 0,  1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  6]  1 */
    34133682, /* 46734 (1114) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
    34146642, /* 46735 (1114) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
      125994, /* 46736 (1114) [ 0, -1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  6]  1 */
    34024496, /* 46737 (1114) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 0,  0,  0] -1 */
       16484, /* 46738 (1115) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34015422, /* 46739 (1115) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
      134418, /* 46740 (1115) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  6]  1 */
        3200, /* 46741 (1115) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
      121458, /* 46742 (1115) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  6]  1 */
      129884, /* 46743 (1115) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  6]  1 */
    34019636, /* 46744 (1115) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    34146644, /* 46745 (1115) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    34142106, /* 46746 (1115) [ 0,  1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  6] -1 */
        7410, /* 46747 (1115) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  0]  1 */
       12270, /* 46748 (1115) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    34028706, /* 46749 (1115) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    34138218, /* 46750 (1115) [ 0, -1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  6] -1 */
      125996, /* 46751 (1115) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 0,  0,  6]  1 */
    34133684, /* 46752 (1115) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    34024496, /* 46753 (1115) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 0,  0,  0] -1 */
       16484, /* 46754 (1116) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34137732, /* 46755 (1116) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  6] -1 */
      134418, /* 46756 (1116) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  6]  1 */
       12270, /* 46757 (1116) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  0]  1 */
        3198, /* 46758 (1116) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    34024008, /* 46759 (1116) [ 0,  1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    34020120, /* 46760 (1116) [ 0, -1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    34024010, /* 46761 (1116) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    34015584, /* 46762 (1116) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
        7410, /* 46763 (1116) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    34020122, /* 46764 (1116) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    34146806, /* 46765 (1116) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    34028546, /* 46766 (1116) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    34015586, /* 46767 (1116) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    34133522, /* 46768 (1116) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    34142594, /* 46769 (1116) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 0,  0,  6] -1 */
      129884, /* 46770 (1116) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  6]  1 */
      125996, /* 46771 (1116) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 0,  0,  6]  1 */
      129882, /* 46772 (1116) [ 0,  1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  6]  1 */
      125994, /* 46773 (1116) [ 0, -1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  6]  1 */
    34137734, /* 46774 (1116) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  6] -1 */
      134420, /* 46775 (1116) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6]  1 */
    34146804, /* 46776 (1116) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
    34028544, /* 46777 (1116) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
      121460, /* 46778 (1116) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6]  1 */
    34142592, /* 46779 (1116) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  6] -1 */
      121458, /* 46780 (1116) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  6]  1 */
        3200, /* 46781 (1116) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
       12272, /* 46782 (1116) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34133520, /* 46783 (1116) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
        7412, /* 46784 (1116) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  0]  1 */
       16482, /* 46785 (1116) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
       16484, /* 46786 (1117) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    52442922, /* 46787 (1117) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 6,  6,  0] -1 */
      134418, /* 46788 (1117) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  6]  1 */
    52561506, /* 46789 (1117) [ 0, -1,  0,  1,  0,  0,  0,  0, -1] [ 6,  6,  6] -1 */
       12270, /* 46790 (1117) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    52451996, /* 46791 (1117) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
        3198, /* 46792 (1117) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    52556970, /* 46793 (1117) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    52565394, /* 46794 (1117) [ 0,  1,  0, -1,  0,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    52565396, /* 46795 (1117) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    52561508, /* 46796 (1117) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    52569932, /* 46797 (1117) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
        7410, /* 46798 (1117) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    52556972, /* 46799 (1117) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    52438712, /* 46800 (1117) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
    52447784, /* 46801 (1117) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 6,  6,  0] -1 */
      129884, /* 46802 (1117) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  6]  1 */
    52442924, /* 46803 (1117) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 6,  6,  0] -1 */
    52451994, /* 46804 (1117) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
    52447782, /* 46805 (1117) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 6,  6,  0] -1 */
      125996, /* 46806 (1117) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 0,  0,  6]  1 */
      129882, /* 46807 (1117) [ 0,  1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  6]  1 */
      125994, /* 46808 (1117) [ 0, -1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  6]  1 */
    52569930, /* 46809 (1117) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
      134420, /* 46810 (1117) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6]  1 */
      121460, /* 46811 (1117) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6]  1 */
      121458, /* 46812 (1117) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  6]  1 */
    52438710, /* 46813 (1117) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
        3200, /* 46814 (1117) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
       12272, /* 46815 (1117) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 0,  0,  0]  1 */
        7412, /* 46816 (1117) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  0]  1 */
       16482, /* 46817 (1117) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
       16484, /* 46818 (1118) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
      134418, /* 46819 (1118) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  6]  1 */
    52443408, /* 46820 (1118) [ 0, -1,  0,  1,  0,  0,  0,  0, -1] [ 6,  6,  0] -1 */
       12270, /* 46821 (1118) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    52447298, /* 46822 (1118) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 6,  6,  0] -1 */
        3198, /* 46823 (1118) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    52438872, /* 46824 (1118) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
    52447296, /* 46825 (1118) [ 0,  1,  0, -1,  0,  0,  0,  0, -1] [ 6,  6,  0] -1 */
    52570094, /* 46826 (1118) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    52443410, /* 46827 (1118) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 6,  6,  0] -1 */
    52451834, /* 46828 (1118) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
    52438874, /* 46829 (1118) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
        7410, /* 46830 (1118) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    52565882, /* 46831 (1118) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    52556810, /* 46832 (1118) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
      129884, /* 46833 (1118) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  6]  1 */
      125996, /* 46834 (1118) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 0,  0,  6]  1 */
      129882, /* 46835 (1118) [ 0,  1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  6]  1 */
      125994, /* 46836 (1118) [ 0, -1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  6]  1 */
    52561022, /* 46837 (1118) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 6,  6,  6] -1 */
      134420, /* 46838 (1118) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6]  1 */
    52570092, /* 46839 (1118) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    52565880, /* 46840 (1118) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    52451832, /* 46841 (1118) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
    52556808, /* 46842 (1118) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
      121460, /* 46843 (1118) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6]  1 */
      121458, /* 46844 (1118) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  6]  1 */
        3200, /* 46845 (1118) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
       12272, /* 46846 (1118) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 0,  0,  0]  1 */
        7412, /* 46847 (1118) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    52561020, /* 46848 (1118) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 6,  6,  6] -1 */
       16482, /* 46849 (1118) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
       16484, /* 46850 (1119) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
        3200, /* 46851 (1119) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
      121458, /* 46852 (1119) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  6]  1 */
    18435558, /* 46853 (1119) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 6,  6,  0]  1 */
    18430698, /* 46854 (1119) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 6,  6,  0]  1 */
    18553172, /* 46855 (1119) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    18439610, /* 46856 (1119) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
        7896, /* 46857 (1119) [ 0, -1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  0]  1 */
       11784, /* 46858 (1119) [ 0,  1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    18544584, /* 46859 (1119) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
    18549284, /* 46860 (1119) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    18557868, /* 46861 (1119) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
      134418, /* 46862 (1119) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  6]  1 */
      125510, /* 46863 (1119) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  6]  1 */
    18426650, /* 46864 (1119) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
      130370, /* 46865 (1119) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 0,  0,  6]  1 */
       16484, /* 46866 (1120) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    18435558, /* 46867 (1120) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 6,  6,  0]  1 */
    18549284, /* 46868 (1120) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    18544584, /* 46869 (1120) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
       11784, /* 46870 (1120) [ 0,  1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    34146642, /* 46871 (1120) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
    34133682, /* 46872 (1120) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
    18426650, /* 46873 (1120) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    52442922, /* 46874 (1120) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 6,  6,  0] -1 */
    52451834, /* 46875 (1120) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
    18430698, /* 46876 (1120) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 6,  6,  0]  1 */
    34142594, /* 46877 (1120) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 0,  0,  6] -1 */
      134418, /* 46878 (1120) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  6]  1 */
    34015424, /* 46879 (1120) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    34028708, /* 46880 (1120) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
      121458, /* 46881 (1120) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  6]  1 */
    34020120, /* 46882 (1120) [ 0, -1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    18439610, /* 46883 (1120) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    52570092, /* 46884 (1120) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    34137734, /* 46885 (1120) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    52565396, /* 46886 (1120) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 6,  6,  6] -1 */
      130370, /* 46887 (1120) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 0,  0,  6]  1 */
        3200, /* 46888 (1120) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    52447782, /* 46889 (1120) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 6,  6,  0] -1 */
    34024008, /* 46890 (1120) [ 0,  1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    52556808, /* 46891 (1120) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    52561508, /* 46892 (1120) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    52438874, /* 46893 (1120) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
    18557868, /* 46894 (1120) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
        7896, /* 46895 (1120) [ 0, -1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  0]  1 */
      125510, /* 46896 (1120) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  6]  1 */
    18553172, /* 46897 (1120) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 6,  6,  6]  1 */
       16484, /* 46898 (1121) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
        3200, /* 46899 (1121) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    52447782, /* 46900 (1121) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 6,  6,  0] -1 */
    34024008, /* 46901 (1121) [ 0,  1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    52556808, /* 46902 (1121) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    34020120, /* 46903 (1121) [ 0, -1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    18553172, /* 46904 (1121) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    18439610, /* 46905 (1121) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    52570092, /* 46906 (1121) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
      125510, /* 46907 (1121) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  6]  1 */
    34146642, /* 46908 (1121) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
    18549284, /* 46909 (1121) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    34133682, /* 46910 (1121) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
    52442922, /* 46911 (1121) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 6,  6,  0] -1 */
    18426650, /* 46912 (1121) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
      130370, /* 46913 (1121) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 0,  0,  6]  1 */
       16484, /* 46914 (1122) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
        3200, /* 46915 (1122) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34024008, /* 46916 (1122) [ 0,  1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    18435558, /* 46917 (1122) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 6,  6,  0]  1 */
    52561508, /* 46918 (1122) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    18430698, /* 46919 (1122) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 6,  6,  0]  1 */
    34020120, /* 46920 (1122) [ 0, -1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    52438874, /* 46921 (1122) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
    34146642, /* 46922 (1122) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
    18544584, /* 46923 (1122) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
    52565396, /* 46924 (1122) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    18557868, /* 46925 (1122) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
    34133682, /* 46926 (1122) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
      125510, /* 46927 (1122) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  6]  1 */
      130370, /* 46928 (1122) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 0,  0,  6]  1 */
    52451834, /* 46929 (1122) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
       16484, /* 46930 (1123) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
        3200, /* 46931 (1123) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    52447782, /* 46932 (1123) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 6,  6,  0] -1 */
    34024008, /* 46933 (1123) [ 0,  1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  0] -1 */
      121458, /* 46934 (1123) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  6]  1 */
    52561508, /* 46935 (1123) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    34020120, /* 46936 (1123) [ 0, -1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    18439610, /* 46937 (1123) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    18544584, /* 46938 (1123) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
    34137734, /* 46939 (1123) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    52565396, /* 46940 (1123) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    18557868, /* 46941 (1123) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
    34142594, /* 46942 (1123) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 0,  0,  6] -1 */
      134418, /* 46943 (1123) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  6]  1 */
    52442922, /* 46944 (1123) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 6,  6,  0] -1 */
    18426650, /* 46945 (1123) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
       16484, /* 46946 (1124) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
        3200, /* 46947 (1124) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    52447782, /* 46948 (1124) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 6,  6,  0] -1 */
    52556808, /* 46949 (1124) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
      121458, /* 46950 (1124) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  6]  1 */
    52561508, /* 46951 (1124) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    52438874, /* 46952 (1124) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
    52570092, /* 46953 (1124) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
      125510, /* 46954 (1124) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  6]  1 */
       11784, /* 46955 (1124) [ 0,  1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    52565396, /* 46956 (1124) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 6,  6,  6] -1 */
      134418, /* 46957 (1124) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  6]  1 */
    52442922, /* 46958 (1124) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 6,  6,  0] -1 */
        7896, /* 46959 (1124) [ 0, -1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  0]  1 */
      130370, /* 46960 (1124) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 0,  0,  6]  1 */
    52451834, /* 46961 (1124) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
       16484, /* 46962 (1125) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
        3200, /* 46963 (1125) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    52447782, /* 46964 (1125) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 6,  6,  0] -1 */
    52438874, /* 46965 (1125) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
    34146642, /* 46966 (1125) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
    18544584, /* 46967 (1125) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
       11784, /* 46968 (1125) [ 0,  1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    18549284, /* 46969 (1125) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    34137734, /* 46970 (1125) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    18557868, /* 46971 (1125) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
    34142594, /* 46972 (1125) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 0,  0,  6] -1 */
        7896, /* 46973 (1125) [ 0, -1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    34133682, /* 46974 (1125) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
    52442922, /* 46975 (1125) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 6,  6,  0] -1 */
    18553172, /* 46976 (1125) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    52451834, /* 46977 (1125) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
       16484, /* 46978 (1126) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
        3200, /* 46979 (1126) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    52556808, /* 46980 (1126) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    18435558, /* 46981 (1126) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 6,  6,  0]  1 */
    52561508, /* 46982 (1126) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    18430698, /* 46983 (1126) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 6,  6,  0]  1 */
    18439610, /* 46984 (1126) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    52570092, /* 46985 (1126) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    34146642, /* 46986 (1126) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
       11784, /* 46987 (1126) [ 0,  1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    34137734, /* 46988 (1126) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    52565396, /* 46989 (1126) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    34142594, /* 46990 (1126) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 0,  0,  6] -1 */
        7896, /* 46991 (1126) [ 0, -1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    34133682, /* 46992 (1126) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
    18426650, /* 46993 (1126) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
       16484, /* 46994 (1127) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
        3200, /* 46995 (1127) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34024008, /* 46996 (1127) [ 0,  1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    52556808, /* 46997 (1127) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
      121458, /* 46998 (1127) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  6]  1 */
    18435558, /* 46999 (1127) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 6,  6,  0]  1 */
    18430698, /* 47000 (1127) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 6,  6,  0]  1 */
    34020120, /* 47001 (1127) [ 0, -1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    52438874, /* 47002 (1127) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
    52570092, /* 47003 (1127) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    18549284, /* 47004 (1127) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    34137734, /* 47005 (1127) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    34142594, /* 47006 (1127) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 0,  0,  6] -1 */
      134418, /* 47007 (1127) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  6]  1 */
    18553172, /* 47008 (1127) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    52451834, /* 47009 (1127) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
       16484, /* 47010 (1128) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    52561020, /* 47011 (1128) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    18435558, /* 47012 (1128) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 6,  6,  0]  1 */
    34142106, /* 47013 (1128) [ 0,  1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  6] -1 */
    18549284, /* 47014 (1128) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    18544584, /* 47015 (1128) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
       11784, /* 47016 (1128) [ 0,  1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    34028544, /* 47017 (1128) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    18426650, /* 47018 (1128) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    52443410, /* 47019 (1128) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 6,  6,  0] -1 */
    18430698, /* 47020 (1128) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 6,  6,  0]  1 */
    34146806, /* 47021 (1128) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
      134418, /* 47022 (1128) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  6]  1 */
    34024496, /* 47023 (1128) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    34138218, /* 47024 (1128) [ 0, -1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  6] -1 */
    34133522, /* 47025 (1128) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
      121458, /* 47026 (1128) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  6]  1 */
    34019636, /* 47027 (1128) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    18439610, /* 47028 (1128) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    52451994, /* 47029 (1128) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
    52447298, /* 47030 (1128) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 6,  6,  0] -1 */
      130370, /* 47031 (1128) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 0,  0,  6]  1 */
        3200, /* 47032 (1128) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34015584, /* 47033 (1128) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    52569932, /* 47034 (1128) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    52556972, /* 47035 (1128) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    52565880, /* 47036 (1128) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    52438710, /* 47037 (1128) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
    18557868, /* 47038 (1128) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
        7896, /* 47039 (1128) [ 0, -1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  0]  1 */
      125510, /* 47040 (1128) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  6]  1 */
    18553172, /* 47041 (1128) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 6,  6,  6]  1 */
       16484, /* 47042 (1129) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34019634, /* 47043 (1129) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    18435558, /* 47044 (1129) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 6,  6,  0]  1 */
    52451996, /* 47045 (1129) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
    18544584, /* 47046 (1129) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
    18549284, /* 47047 (1129) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 6,  6,  6]  1 */
       11784, /* 47048 (1129) [ 0,  1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    18426650, /* 47049 (1129) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    34015586, /* 47050 (1129) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    18430698, /* 47051 (1129) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 6,  6,  0]  1 */
      134418, /* 47052 (1129) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  6]  1 */
    52438712, /* 47053 (1129) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
      121458, /* 47054 (1129) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  6]  1 */
    52565882, /* 47055 (1129) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    52569930, /* 47056 (1129) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    18439610, /* 47057 (1129) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    34146804, /* 47058 (1129) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
    52556970, /* 47059 (1129) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    52443408, /* 47060 (1129) [ 0, -1,  0,  1,  0,  0,  0,  0, -1] [ 6,  6,  0] -1 */
    34028546, /* 47061 (1129) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    52561022, /* 47062 (1129) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    52447296, /* 47063 (1129) [ 0,  1,  0, -1,  0,  0,  0,  0, -1] [ 6,  6,  0] -1 */
    34138220, /* 47064 (1129) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    34024494, /* 47065 (1129) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  0] -1 */
      130370, /* 47066 (1129) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 0,  0,  6]  1 */
    34142108, /* 47067 (1129) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  6] -1 */
        3200, /* 47068 (1129) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34133520, /* 47069 (1129) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
    18557868, /* 47070 (1129) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
        7896, /* 47071 (1129) [ 0, -1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  0]  1 */
      125510, /* 47072 (1129) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  6]  1 */
    18553172, /* 47073 (1129) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 6,  6,  6]  1 */
       16484, /* 47074 (1130) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34137732, /* 47075 (1130) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  6] -1 */
    18435558, /* 47076 (1130) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 6,  6,  0]  1 */
    52561506, /* 47077 (1130) [ 0, -1,  0,  1,  0,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    18549284, /* 47078 (1130) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    18544584, /* 47079 (1130) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
       11784, /* 47080 (1130) [ 0,  1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    52451832, /* 47081 (1130) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
    18426650, /* 47082 (1130) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    52570094, /* 47083 (1130) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    34024010, /* 47084 (1130) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    18430698, /* 47085 (1130) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 6,  6,  0]  1 */
      134418, /* 47086 (1130) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  6]  1 */
    52447784, /* 47087 (1130) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 6,  6,  0] -1 */
    52556810, /* 47088 (1130) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
      121458, /* 47089 (1130) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  6]  1 */
    52442924, /* 47090 (1130) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 6,  6,  0] -1 */
    18439610, /* 47091 (1130) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    52565394, /* 47092 (1130) [ 0,  1,  0, -1,  0,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    34142592, /* 47093 (1130) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  6] -1 */
    52438872, /* 47094 (1130) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
    34028706, /* 47095 (1130) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
      130370, /* 47096 (1130) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 0,  0,  6]  1 */
    34015422, /* 47097 (1130) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
        3200, /* 47098 (1130) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34146644, /* 47099 (1130) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    34020122, /* 47100 (1130) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    34133684, /* 47101 (1130) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    18557868, /* 47102 (1130) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
        7896, /* 47103 (1130) [ 0, -1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  0]  1 */
      125510, /* 47104 (1130) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  6]  1 */
    18553172, /* 47105 (1130) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 6,  6,  6]  1 */
       16484, /* 47106 (1119) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    18426488, /* 47107 (1119) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    17009472, /* 47108 (1119) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  0]  1 */
      130368, /* 47109 (1119) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  6]  1 */
    18548796, /* 47110 (1119) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 6,  6,  6]  1 */
     1547060, /* 47111 (1119) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 0,  6,  6]  1 */
    17022434, /* 47112 (1119) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  0]  1 */
     1543170, /* 47113 (1119) [ 0, -1,  0,  1,  0,  0,  0,  0, -1] [ 0,  6,  6]  1 */
    17135994, /* 47114 (1119) [ 0,  1,  0, -1,  0,  0,  0,  0, -1] [ 6,  0,  6]  1 */
        3198, /* 47115 (1119) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    17132108, /* 47116 (1119) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 6,  0,  6]  1 */
    18439770, /* 47117 (1119) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
     1433496, /* 47118 (1119) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  0]  1 */
      125510, /* 47119 (1119) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  6]  1 */
     1420538, /* 47120 (1119) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  0]  1 */
    18553658, /* 47121 (1119) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 6,  6,  6]  1 */
       16484, /* 47122 (1120) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
      130368, /* 47123 (1120) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  6]  1 */
    17132108, /* 47124 (1120) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 6,  0,  6]  1 */
        3198, /* 47125 (1120) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    17135994, /* 47126 (1120) [ 0,  1,  0, -1,  0,  0,  0,  0, -1] [ 6,  0,  6]  1 */
    35445720, /* 47127 (1120) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  0] -1 */
    51021696, /* 47128 (1120) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  0] -1 */
     1420538, /* 47129 (1120) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  0]  1 */
    52561020, /* 47130 (1120) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    51034658, /* 47131 (1120) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  0] -1 */
    18548796, /* 47132 (1120) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 6,  6,  6]  1 */
    52565882, /* 47133 (1120) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 6,  6,  6] -1 */
     1433496, /* 47134 (1120) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  0]  1 */
    52438712, /* 47135 (1120) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
    34028708, /* 47136 (1120) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    17009472, /* 47137 (1120) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  0]  1 */
    35555394, /* 47138 (1120) [ 0, -1,  0,  1,  0,  0,  0,  0, -1] [ 0,  6,  6] -1 */
    17022434, /* 47139 (1120) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  0]  1 */
    52451994, /* 47140 (1120) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
    34137734, /* 47141 (1120) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    35559284, /* 47142 (1120) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 0,  6,  6] -1 */
    18553658, /* 47143 (1120) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    18426488, /* 47144 (1120) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    34142592, /* 47145 (1120) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  6] -1 */
    51148218, /* 47146 (1120) [ 0,  1,  0, -1,  0,  0,  0,  0, -1] [ 6,  0,  6] -1 */
    34015422, /* 47147 (1120) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    51144332, /* 47148 (1120) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 6,  0,  6] -1 */
    35432762, /* 47149 (1120) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  0] -1 */
    18439770, /* 47150 (1120) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
     1543170, /* 47151 (1120) [ 0, -1,  0,  1,  0,  0,  0,  0, -1] [ 0,  6,  6]  1 */
      125510, /* 47152 (1120) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  6]  1 */
     1547060, /* 47153 (1120) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 0,  6,  6]  1 */
       16484, /* 47154 (1121) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    18426488, /* 47155 (1121) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    34142592, /* 47156 (1121) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  6] -1 */
    51148218, /* 47157 (1121) [ 0,  1,  0, -1,  0,  0,  0,  0, -1] [ 6,  0,  6] -1 */
    34015422, /* 47158 (1121) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    35555394, /* 47159 (1121) [ 0, -1,  0,  1,  0,  0,  0,  0, -1] [ 0,  6,  6] -1 */
     1547060, /* 47160 (1121) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 0,  6,  6]  1 */
    17022434, /* 47161 (1121) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  0]  1 */
    52451994, /* 47162 (1121) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
      125510, /* 47163 (1121) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  6]  1 */
    35445720, /* 47164 (1121) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  0] -1 */
    17132108, /* 47165 (1121) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 6,  0,  6]  1 */
    51021696, /* 47166 (1121) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  0] -1 */
    52561020, /* 47167 (1121) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 6,  6,  6] -1 */
     1420538, /* 47168 (1121) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  0]  1 */
    18553658, /* 47169 (1121) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 6,  6,  6]  1 */
       16484, /* 47170 (1122) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    18426488, /* 47171 (1122) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    51148218, /* 47172 (1122) [ 0,  1,  0, -1,  0,  0,  0,  0, -1] [ 6,  0,  6] -1 */
      130368, /* 47173 (1122) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  6]  1 */
    51144332, /* 47174 (1122) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 6,  0,  6] -1 */
    18548796, /* 47175 (1122) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 6,  6,  6]  1 */
    35555394, /* 47176 (1122) [ 0, -1,  0,  1,  0,  0,  0,  0, -1] [ 0,  6,  6] -1 */
    35432762, /* 47177 (1122) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  0] -1 */
    35445720, /* 47178 (1122) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  0] -1 */
        3198, /* 47179 (1122) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    35559284, /* 47180 (1122) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 0,  6,  6] -1 */
    18439770, /* 47181 (1122) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
    51021696, /* 47182 (1122) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  0] -1 */
      125510, /* 47183 (1122) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  6]  1 */
    18553658, /* 47184 (1122) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    51034658, /* 47185 (1122) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  0] -1 */
       16484, /* 47186 (1123) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    18426488, /* 47187 (1123) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    34142592, /* 47188 (1123) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  6] -1 */
    51148218, /* 47189 (1123) [ 0,  1,  0, -1,  0,  0,  0,  0, -1] [ 6,  0,  6] -1 */
    17009472, /* 47190 (1123) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  0]  1 */
    51144332, /* 47191 (1123) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 6,  0,  6] -1 */
    35555394, /* 47192 (1123) [ 0, -1,  0,  1,  0,  0,  0,  0, -1] [ 0,  6,  6] -1 */
    17022434, /* 47193 (1123) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  0]  1 */
        3198, /* 47194 (1123) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    34137734, /* 47195 (1123) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    35559284, /* 47196 (1123) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 0,  6,  6] -1 */
    18439770, /* 47197 (1123) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
    52565882, /* 47198 (1123) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 6,  6,  6] -1 */
     1433496, /* 47199 (1123) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  0]  1 */
    52561020, /* 47200 (1123) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 6,  6,  6] -1 */
     1420538, /* 47201 (1123) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  0]  1 */
       16484, /* 47202 (1124) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    18426488, /* 47203 (1124) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    34142592, /* 47204 (1124) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  6] -1 */
    34015422, /* 47205 (1124) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    17009472, /* 47206 (1124) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  0]  1 */
    51144332, /* 47207 (1124) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 6,  0,  6] -1 */
    35432762, /* 47208 (1124) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  0] -1 */
    52451994, /* 47209 (1124) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
      125510, /* 47210 (1124) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  6]  1 */
    17135994, /* 47211 (1124) [ 0,  1,  0, -1,  0,  0,  0,  0, -1] [ 6,  0,  6]  1 */
    35559284, /* 47212 (1124) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 0,  6,  6] -1 */
     1433496, /* 47213 (1124) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  0]  1 */
    52561020, /* 47214 (1124) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 6,  6,  6] -1 */
     1543170, /* 47215 (1124) [ 0, -1,  0,  1,  0,  0,  0,  0, -1] [ 0,  6,  6]  1 */
    18553658, /* 47216 (1124) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    51034658, /* 47217 (1124) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  0] -1 */
       16484, /* 47218 (1125) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    18426488, /* 47219 (1125) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    34142592, /* 47220 (1125) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  6] -1 */
    35432762, /* 47221 (1125) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  0] -1 */
    35445720, /* 47222 (1125) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  0] -1 */
        3198, /* 47223 (1125) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    17135994, /* 47224 (1125) [ 0,  1,  0, -1,  0,  0,  0,  0, -1] [ 6,  0,  6]  1 */
    17132108, /* 47225 (1125) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 6,  0,  6]  1 */
    34137734, /* 47226 (1125) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    18439770, /* 47227 (1125) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
    52565882, /* 47228 (1125) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 6,  6,  6] -1 */
     1543170, /* 47229 (1125) [ 0, -1,  0,  1,  0,  0,  0,  0, -1] [ 0,  6,  6]  1 */
    51021696, /* 47230 (1125) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  0] -1 */
    52561020, /* 47231 (1125) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 6,  6,  6] -1 */
     1547060, /* 47232 (1125) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 0,  6,  6]  1 */
    51034658, /* 47233 (1125) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  0] -1 */
       16484, /* 47234 (1126) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    18426488, /* 47235 (1126) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    34015422, /* 47236 (1126) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
      130368, /* 47237 (1126) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  6]  1 */
    51144332, /* 47238 (1126) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 6,  0,  6] -1 */
    18548796, /* 47239 (1126) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 6,  6,  6]  1 */
    17022434, /* 47240 (1126) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  0]  1 */
    52451994, /* 47241 (1126) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
    35445720, /* 47242 (1126) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  0] -1 */
    17135994, /* 47243 (1126) [ 0,  1,  0, -1,  0,  0,  0,  0, -1] [ 6,  0,  6]  1 */
    34137734, /* 47244 (1126) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    35559284, /* 47245 (1126) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 0,  6,  6] -1 */
    52565882, /* 47246 (1126) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 6,  6,  6] -1 */
     1543170, /* 47247 (1126) [ 0, -1,  0,  1,  0,  0,  0,  0, -1] [ 0,  6,  6]  1 */
    51021696, /* 47248 (1126) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  0] -1 */
     1420538, /* 47249 (1126) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  0]  1 */
       16484, /* 47250 (1127) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    18426488, /* 47251 (1127) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    51148218, /* 47252 (1127) [ 0,  1,  0, -1,  0,  0,  0,  0, -1] [ 6,  0,  6] -1 */
    34015422, /* 47253 (1127) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    17009472, /* 47254 (1127) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  0]  1 */
      130368, /* 47255 (1127) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  6]  1 */
    18548796, /* 47256 (1127) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 6,  6,  6]  1 */
    35555394, /* 47257 (1127) [ 0, -1,  0,  1,  0,  0,  0,  0, -1] [ 0,  6,  6] -1 */
    35432762, /* 47258 (1127) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  0] -1 */
    52451994, /* 47259 (1127) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
    17132108, /* 47260 (1127) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 6,  0,  6]  1 */
    34137734, /* 47261 (1127) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    52565882, /* 47262 (1127) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 6,  6,  6] -1 */
     1433496, /* 47263 (1127) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  0]  1 */
     1547060, /* 47264 (1127) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 0,  6,  6]  1 */
    51034658, /* 47265 (1127) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  0] -1 */
       16484, /* 47266 (1128) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    52442922, /* 47267 (1128) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 6,  6,  0] -1 */
      130368, /* 47268 (1128) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  6]  1 */
    51030120, /* 47269 (1128) [ 0,  1,  0, -1,  0,  0,  0,  0, -1] [ 6,  0,  0] -1 */
    17132108, /* 47270 (1128) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 6,  0,  6]  1 */
        3198, /* 47271 (1128) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    17135994, /* 47272 (1128) [ 0,  1,  0, -1,  0,  0,  0,  0, -1] [ 6,  0,  6]  1 */
    35563818, /* 47273 (1128) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  6] -1 */
     1420538, /* 47274 (1128) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  0]  1 */
    51026234, /* 47275 (1128) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 6,  0,  0] -1 */
    18548796, /* 47276 (1128) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 6,  6,  6]  1 */
    34146806, /* 47277 (1128) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
     1433496, /* 47278 (1128) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  0]  1 */
    52447784, /* 47279 (1128) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 6,  6,  0] -1 */
    35437296, /* 47280 (1128) [ 0, -1,  0,  1,  0,  0,  0,  0, -1] [ 0,  6,  0] -1 */
    52556810, /* 47281 (1128) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    17009472, /* 47282 (1128) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  0]  1 */
    34019636, /* 47283 (1128) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    17022434, /* 47284 (1128) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  0]  1 */
    52570092, /* 47285 (1128) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    35441186, /* 47286 (1128) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 0,  6,  0] -1 */
    18553658, /* 47287 (1128) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    18426488, /* 47288 (1128) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    51139794, /* 47289 (1128) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6] -1 */
    51152756, /* 47290 (1128) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
    35550860, /* 47291 (1128) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
    34024494, /* 47292 (1128) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    34133520, /* 47293 (1128) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
    18439770, /* 47294 (1128) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
     1543170, /* 47295 (1128) [ 0, -1,  0,  1,  0,  0,  0,  0, -1] [ 0,  6,  6]  1 */
      125510, /* 47296 (1128) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  6]  1 */
     1547060, /* 47297 (1128) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 0,  6,  6]  1 */
       16484, /* 47298 (1129) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34137732, /* 47299 (1129) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  6] -1 */
      130368, /* 47300 (1129) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  6]  1 */
    52451996, /* 47301 (1129) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
        3198, /* 47302 (1129) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    17132108, /* 47303 (1129) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 6,  0,  6]  1 */
    17135994, /* 47304 (1129) [ 0,  1,  0, -1,  0,  0,  0,  0, -1] [ 6,  0,  6]  1 */
     1420538, /* 47305 (1129) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  0]  1 */
    51021698, /* 47306 (1129) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  0] -1 */
    18548796, /* 47307 (1129) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 6,  6,  6]  1 */
     1433496, /* 47308 (1129) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  0]  1 */
    34015424, /* 47309 (1129) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    17009472, /* 47310 (1129) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  0]  1 */
    34142594, /* 47311 (1129) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    51034656, /* 47312 (1129) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  0] -1 */
    17022434, /* 47313 (1129) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  0]  1 */
    34028706, /* 47314 (1129) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    35432760, /* 47315 (1129) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  0] -1 */
    51144330, /* 47316 (1129) [ 0, -1,  0,  1,  0,  0,  0,  0, -1] [ 6,  0,  6] -1 */
    35445722, /* 47317 (1129) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  0] -1 */
    52561022, /* 47318 (1129) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    35559282, /* 47319 (1129) [ 0,  1,  0, -1,  0,  0,  0,  0, -1] [ 0,  6,  6] -1 */
    35555396, /* 47320 (1129) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 0,  6,  6] -1 */
    52565880, /* 47321 (1129) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    18553658, /* 47322 (1129) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    51148220, /* 47323 (1129) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 6,  0,  6] -1 */
    18426488, /* 47324 (1129) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    52438710, /* 47325 (1129) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
    18439770, /* 47326 (1129) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
     1543170, /* 47327 (1129) [ 0, -1,  0,  1,  0,  0,  0,  0, -1] [ 0,  6,  6]  1 */
      125510, /* 47328 (1129) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  6]  1 */
     1547060, /* 47329 (1129) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 0,  6,  6]  1 */
       16484, /* 47330 (1130) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34019634, /* 47331 (1130) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  0] -1 */
      130368, /* 47332 (1130) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  6]  1 */
    51026232, /* 47333 (1130) [ 0, -1,  0,  1,  0,  0,  0,  0, -1] [ 6,  0,  0] -1 */
    17132108, /* 47334 (1130) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 6,  0,  6]  1 */
        3198, /* 47335 (1130) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    17135994, /* 47336 (1130) [ 0,  1,  0, -1,  0,  0,  0,  0, -1] [ 6,  0,  6]  1 */
    51152754, /* 47337 (1130) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  6] -1 */
     1420538, /* 47338 (1130) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  0]  1 */
    52570094, /* 47339 (1130) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    51030122, /* 47340 (1130) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 6,  0,  0] -1 */
    18548796, /* 47341 (1130) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 6,  6,  6]  1 */
     1433496, /* 47342 (1130) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  0]  1 */
    34024496, /* 47343 (1130) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    34133522, /* 47344 (1130) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    17009472, /* 47345 (1130) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  0]  1 */
    52442924, /* 47346 (1130) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 6,  6,  0] -1 */
    17022434, /* 47347 (1130) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  0]  1 */
    35441184, /* 47348 (1130) [ 0,  1,  0, -1,  0,  0,  0,  0, -1] [ 0,  6,  0] -1 */
    52447782, /* 47349 (1130) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 6,  6,  0] -1 */
    35550858, /* 47350 (1130) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6] -1 */
    34146804, /* 47351 (1130) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
    18553658, /* 47352 (1130) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    52556808, /* 47353 (1130) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    18426488, /* 47354 (1130) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    35563820, /* 47355 (1130) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
    35437298, /* 47356 (1130) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 0,  6,  0] -1 */
    51139796, /* 47357 (1130) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
    18439770, /* 47358 (1130) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
     1543170, /* 47359 (1130) [ 0, -1,  0,  1,  0,  0,  0,  0, -1] [ 0,  6,  6]  1 */
      125510, /* 47360 (1130) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  6]  1 */
     1547060, /* 47361 (1130) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 0,  6,  6]  1 */
       16484, /* 47362 (1131) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
        3200, /* 47363 (1131) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
       16320, /* 47364 (1131) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
       12272, /* 47365 (1131) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 0,  0,  0]  1 */
        3360, /* 47366 (1131) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    18544748, /* 47367 (1131) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    18553656, /* 47368 (1131) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 6,  6,  6]  1 */
       11784, /* 47369 (1131) [ 0,  1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    18544584, /* 47370 (1131) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
    18549284, /* 47371 (1131) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    18548796, /* 47372 (1131) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 6,  6,  6]  1 */
        7412, /* 47373 (1131) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    18557868, /* 47374 (1131) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
    18557708, /* 47375 (1131) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
        7896, /* 47376 (1131) [ 0, -1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    18553172, /* 47377 (1131) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 6,  6,  6]  1 */
       16484, /* 47378 (1132) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    52561020, /* 47379 (1132) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 6,  6,  6] -1 */
        3360, /* 47380 (1132) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    18544748, /* 47381 (1132) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    18553656, /* 47382 (1132) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 6,  6,  6]  1 */
    18549284, /* 47383 (1132) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    18544584, /* 47384 (1132) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
       11784, /* 47385 (1132) [ 0,  1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    18557708, /* 47386 (1132) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    34028544, /* 47387 (1132) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    18548796, /* 47388 (1132) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 6,  6,  6]  1 */
    34015424, /* 47389 (1132) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    34028708, /* 47390 (1132) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    34024496, /* 47391 (1132) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 0,  0,  0] -1 */
       16320, /* 47392 (1132) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    34019636, /* 47393 (1132) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    34020120, /* 47394 (1132) [ 0, -1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    52570092, /* 47395 (1132) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    52565396, /* 47396 (1132) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 6,  6,  6] -1 */
        3200, /* 47397 (1132) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34015584, /* 47398 (1132) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    34024008, /* 47399 (1132) [ 0,  1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    52556808, /* 47400 (1132) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
       12272, /* 47401 (1132) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    52569932, /* 47402 (1132) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    52556972, /* 47403 (1132) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    52565880, /* 47404 (1132) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    52561508, /* 47405 (1132) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 6,  6,  6] -1 */
        7412, /* 47406 (1132) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    18557868, /* 47407 (1132) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
        7896, /* 47408 (1132) [ 0, -1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    18553172, /* 47409 (1132) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 6,  6,  6]  1 */
       16484, /* 47410 (1133) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
        3200, /* 47411 (1133) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    52561020, /* 47412 (1133) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    34024008, /* 47413 (1133) [ 0,  1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    52556808, /* 47414 (1133) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    34015584, /* 47415 (1133) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
       12272, /* 47416 (1133) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    52565880, /* 47417 (1133) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    34020120, /* 47418 (1133) [ 0, -1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    18553172, /* 47419 (1133) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    18544748, /* 47420 (1133) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    52570092, /* 47421 (1133) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    18549284, /* 47422 (1133) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 6,  6,  6]  1 */
        7412, /* 47423 (1133) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    18557708, /* 47424 (1133) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    34028544, /* 47425 (1133) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
       16484, /* 47426 (1134) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
        3200, /* 47427 (1134) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34015584, /* 47428 (1134) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    34024008, /* 47429 (1134) [ 0,  1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  0] -1 */
       12272, /* 47430 (1134) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    52569932, /* 47431 (1134) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    52556972, /* 47432 (1134) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    52561508, /* 47433 (1134) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    34020120, /* 47434 (1134) [ 0, -1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    18553656, /* 47435 (1134) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 6,  6,  6]  1 */
    18548796, /* 47436 (1134) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 6,  6,  6]  1 */
        7412, /* 47437 (1134) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    18544584, /* 47438 (1134) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
    52565396, /* 47439 (1134) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    18557868, /* 47440 (1134) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
    34028544, /* 47441 (1134) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
       16484, /* 47442 (1135) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
        3200, /* 47443 (1135) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    52561020, /* 47444 (1135) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 6,  6,  6] -1 */
       16320, /* 47445 (1135) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    34024008, /* 47446 (1135) [ 0,  1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    52565880, /* 47447 (1135) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    34019636, /* 47448 (1135) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    52561508, /* 47449 (1135) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 6,  6,  6] -1 */
        3360, /* 47450 (1135) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    34020120, /* 47451 (1135) [ 0, -1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    18544748, /* 47452 (1135) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    18544584, /* 47453 (1135) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
    52565396, /* 47454 (1135) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    18557868, /* 47455 (1135) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
    18557708, /* 47456 (1135) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    34024496, /* 47457 (1135) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 0,  0,  0] -1 */
       16484, /* 47458 (1136) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
        3200, /* 47459 (1136) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    52561020, /* 47460 (1136) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 6,  6,  6] -1 */
       16320, /* 47461 (1136) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    52556808, /* 47462 (1136) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
       12272, /* 47463 (1136) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    52569932, /* 47464 (1136) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    52565880, /* 47465 (1136) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    52556972, /* 47466 (1136) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    52561508, /* 47467 (1136) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 6,  6,  6] -1 */
        3360, /* 47468 (1136) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    52570092, /* 47469 (1136) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
        7412, /* 47470 (1136) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  0]  1 */
       11784, /* 47471 (1136) [ 0,  1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    52565396, /* 47472 (1136) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 6,  6,  6] -1 */
        7896, /* 47473 (1136) [ 0, -1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  0]  1 */
       16484, /* 47474 (1137) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
        3200, /* 47475 (1137) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    52561020, /* 47476 (1137) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    34015584, /* 47477 (1137) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    52569932, /* 47478 (1137) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    52556972, /* 47479 (1137) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    52565880, /* 47480 (1137) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    34019636, /* 47481 (1137) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    18553172, /* 47482 (1137) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 6,  6,  6]  1 */
       11784, /* 47483 (1137) [ 0,  1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    18544584, /* 47484 (1137) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
    18549284, /* 47485 (1137) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    18557868, /* 47486 (1137) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
        7896, /* 47487 (1137) [ 0, -1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    34028544, /* 47488 (1137) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    34024496, /* 47489 (1137) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 0,  0,  0] -1 */
       16484, /* 47490 (1138) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
        3200, /* 47491 (1138) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34015584, /* 47492 (1138) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    52556808, /* 47493 (1138) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    34019636, /* 47494 (1138) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    52561508, /* 47495 (1138) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    18553656, /* 47496 (1138) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 6,  6,  6]  1 */
    18548796, /* 47497 (1138) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 6,  6,  6]  1 */
       11784, /* 47498 (1138) [ 0,  1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    18544748, /* 47499 (1138) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    52570092, /* 47500 (1138) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    52565396, /* 47501 (1138) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    18557708, /* 47502 (1138) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
        7896, /* 47503 (1138) [ 0, -1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    34028544, /* 47504 (1138) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    34024496, /* 47505 (1138) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 0,  0,  0] -1 */
       16484, /* 47506 (1139) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
        3200, /* 47507 (1139) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
       16320, /* 47508 (1139) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    52556808, /* 47509 (1139) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    34024008, /* 47510 (1139) [ 0,  1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    52569932, /* 47511 (1139) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    52556972, /* 47512 (1139) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
        3360, /* 47513 (1139) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    34019636, /* 47514 (1139) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    34020120, /* 47515 (1139) [ 0, -1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    18553656, /* 47516 (1139) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 6,  6,  6]  1 */
    18548796, /* 47517 (1139) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 6,  6,  6]  1 */
    18549284, /* 47518 (1139) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    52570092, /* 47519 (1139) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    18553172, /* 47520 (1139) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    34024496, /* 47521 (1139) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 0,  0,  0] -1 */
       16484, /* 47522 (1140) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
        3360, /* 47523 (1140) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    34142106, /* 47524 (1140) [ 0,  1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  6] -1 */
    18544748, /* 47525 (1140) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    18553656, /* 47526 (1140) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 6,  6,  6]  1 */
    18549284, /* 47527 (1140) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    18544584, /* 47528 (1140) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
       11784, /* 47529 (1140) [ 0,  1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    34146642, /* 47530 (1140) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
    18557708, /* 47531 (1140) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    34133682, /* 47532 (1140) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
    52451834, /* 47533 (1140) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
    52443410, /* 47534 (1140) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 6,  6,  0] -1 */
    18548796, /* 47535 (1140) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 6,  6,  6]  1 */
    34146806, /* 47536 (1140) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    34142594, /* 47537 (1140) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    34138218, /* 47538 (1140) [ 0, -1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  6] -1 */
       16320, /* 47539 (1140) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    34133522, /* 47540 (1140) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    34137734, /* 47541 (1140) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    52451994, /* 47542 (1140) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
    52447298, /* 47543 (1140) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 6,  6,  0] -1 */
        3200, /* 47544 (1140) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    52447782, /* 47545 (1140) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 6,  6,  0] -1 */
       12272, /* 47546 (1140) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    52438874, /* 47547 (1140) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
    52438710, /* 47548 (1140) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
        7412, /* 47549 (1140) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    18557868, /* 47550 (1140) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
        7896, /* 47551 (1140) [ 0, -1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    52442922, /* 47552 (1140) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 6,  6,  0] -1 */
    18553172, /* 47553 (1140) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 6,  6,  6]  1 */
       16484, /* 47554 (1141) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34137732, /* 47555 (1141) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  6] -1 */
        3360, /* 47556 (1141) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    18544748, /* 47557 (1141) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    18553656, /* 47558 (1141) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 6,  6,  6]  1 */
    52451996, /* 47559 (1141) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
    18544584, /* 47560 (1141) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
    18549284, /* 47561 (1141) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 6,  6,  6]  1 */
       11784, /* 47562 (1141) [ 0,  1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    52451832, /* 47563 (1141) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
    18557708, /* 47564 (1141) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    18548796, /* 47565 (1141) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 6,  6,  6]  1 */
    52438712, /* 47566 (1141) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
    52447784, /* 47567 (1141) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 6,  6,  0] -1 */
       16320, /* 47568 (1141) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    52442924, /* 47569 (1141) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 6,  6,  0] -1 */
    34146804, /* 47570 (1141) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
    34142592, /* 47571 (1141) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  6] -1 */
    52443408, /* 47572 (1141) [ 0, -1,  0,  1,  0,  0,  0,  0, -1] [ 6,  6,  0] -1 */
    52438872, /* 47573 (1141) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
    52447296, /* 47574 (1141) [ 0,  1,  0, -1,  0,  0,  0,  0, -1] [ 6,  6,  0] -1 */
    34138220, /* 47575 (1141) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    34142108, /* 47576 (1141) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    34146644, /* 47577 (1141) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
        3200, /* 47578 (1141) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
       12272, /* 47579 (1141) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34133520, /* 47580 (1141) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
        7412, /* 47581 (1141) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34133684, /* 47582 (1141) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    18557868, /* 47583 (1141) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
        7896, /* 47584 (1141) [ 0, -1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    18553172, /* 47585 (1141) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 6,  6,  6]  1 */
       16484, /* 47586 (1142) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34019634, /* 47587 (1142) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  0] -1 */
        3360, /* 47588 (1142) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    52561506, /* 47589 (1142) [ 0, -1,  0,  1,  0,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    18544748, /* 47590 (1142) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    18553656, /* 47591 (1142) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 6,  6,  6]  1 */
    18549284, /* 47592 (1142) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    18544584, /* 47593 (1142) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
       11784, /* 47594 (1142) [ 0,  1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    18557708, /* 47595 (1142) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    52570094, /* 47596 (1142) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    34024010, /* 47597 (1142) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    34015586, /* 47598 (1142) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    18548796, /* 47599 (1142) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 6,  6,  6]  1 */
       16320, /* 47600 (1142) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    52556810, /* 47601 (1142) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    52565882, /* 47602 (1142) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    52569930, /* 47603 (1142) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    52556970, /* 47604 (1142) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    52565394, /* 47605 (1142) [ 0,  1,  0, -1,  0,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    34028546, /* 47606 (1142) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    52561022, /* 47607 (1142) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    34028706, /* 47608 (1142) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    34024494, /* 47609 (1142) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    34015422, /* 47610 (1142) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
        3200, /* 47611 (1142) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
       12272, /* 47612 (1142) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34020122, /* 47613 (1142) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 0,  0,  0] -1 */
        7412, /* 47614 (1142) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    18557868, /* 47615 (1142) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
        7896, /* 47616 (1142) [ 0, -1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    18553172, /* 47617 (1142) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 6,  6,  6]  1 */
       16484, /* 47618 (1131) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    18426488, /* 47619 (1131) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
     1551594, /* 47620 (1131) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
    18435560, /* 47621 (1131) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    17127570, /* 47622 (1131) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6]  1 */
     1538636, /* 47623 (1131) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
       12270, /* 47624 (1131) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    17135994, /* 47625 (1131) [ 0,  1,  0, -1,  0,  0,  0,  0, -1] [ 6,  0,  6]  1 */
        3198, /* 47626 (1131) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    17132108, /* 47627 (1131) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 6,  0,  6]  1 */
    18430698, /* 47628 (1131) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 6,  6,  0]  1 */
        7412, /* 47629 (1131) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    18439770, /* 47630 (1131) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
    17140532, /* 47631 (1131) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
     1543170, /* 47632 (1131) [ 0, -1,  0,  1,  0,  0,  0,  0, -1] [ 0,  6,  6]  1 */
     1547060, /* 47633 (1131) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 0,  6,  6]  1 */
       16484, /* 47634 (1132) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    52442922, /* 47635 (1132) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 6,  6,  0] -1 */
    17127570, /* 47636 (1132) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6]  1 */
     1538636, /* 47637 (1132) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
       12270, /* 47638 (1132) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    17132108, /* 47639 (1132) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 6,  0,  6]  1 */
        3198, /* 47640 (1132) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    17135994, /* 47641 (1132) [ 0,  1,  0, -1,  0,  0,  0,  0, -1] [ 6,  0,  6]  1 */
    17140532, /* 47642 (1132) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
    35563818, /* 47643 (1132) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  6] -1 */
    18430698, /* 47644 (1132) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 6,  6,  0]  1 */
    52438712, /* 47645 (1132) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
    34028708, /* 47646 (1132) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    52447784, /* 47647 (1132) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 6,  6,  0] -1 */
     1551594, /* 47648 (1132) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
    34019636, /* 47649 (1132) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    35555394, /* 47650 (1132) [ 0, -1,  0,  1,  0,  0,  0,  0, -1] [ 0,  6,  6] -1 */
    52451994, /* 47651 (1132) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
    35559284, /* 47652 (1132) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 0,  6,  6] -1 */
    18426488, /* 47653 (1132) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    51139794, /* 47654 (1132) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6] -1 */
    51148218, /* 47655 (1132) [ 0,  1,  0, -1,  0,  0,  0,  0, -1] [ 6,  0,  6] -1 */
    34015422, /* 47656 (1132) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    18435560, /* 47657 (1132) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    51152756, /* 47658 (1132) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
    35550860, /* 47659 (1132) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
    34024494, /* 47660 (1132) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    51144332, /* 47661 (1132) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 6,  0,  6] -1 */
        7412, /* 47662 (1132) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    18439770, /* 47663 (1132) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
     1543170, /* 47664 (1132) [ 0, -1,  0,  1,  0,  0,  0,  0, -1] [ 0,  6,  6]  1 */
     1547060, /* 47665 (1132) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 0,  6,  6]  1 */
       16484, /* 47666 (1133) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    18426488, /* 47667 (1133) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    52442922, /* 47668 (1133) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 6,  6,  0] -1 */
    51148218, /* 47669 (1133) [ 0,  1,  0, -1,  0,  0,  0,  0, -1] [ 6,  0,  6] -1 */
    34015422, /* 47670 (1133) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    51139794, /* 47671 (1133) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6] -1 */
    18435560, /* 47672 (1133) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    34024494, /* 47673 (1133) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    35555394, /* 47674 (1133) [ 0, -1,  0,  1,  0,  0,  0,  0, -1] [ 0,  6,  6] -1 */
     1547060, /* 47675 (1133) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 0,  6,  6]  1 */
     1538636, /* 47676 (1133) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
    52451994, /* 47677 (1133) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
    17132108, /* 47678 (1133) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 6,  0,  6]  1 */
        7412, /* 47679 (1133) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    17140532, /* 47680 (1133) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
    35563818, /* 47681 (1133) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  6] -1 */
       16484, /* 47682 (1134) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    18426488, /* 47683 (1134) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    51139794, /* 47684 (1134) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6] -1 */
    51148218, /* 47685 (1134) [ 0,  1,  0, -1,  0,  0,  0,  0, -1] [ 6,  0,  6] -1 */
    18435560, /* 47686 (1134) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    51152756, /* 47687 (1134) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
    35550860, /* 47688 (1134) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
    51144332, /* 47689 (1134) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 6,  0,  6] -1 */
    35555394, /* 47690 (1134) [ 0, -1,  0,  1,  0,  0,  0,  0, -1] [ 0,  6,  6] -1 */
       12270, /* 47691 (1134) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    18430698, /* 47692 (1134) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 6,  6,  0]  1 */
        7412, /* 47693 (1134) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  0]  1 */
        3198, /* 47694 (1134) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    35559284, /* 47695 (1134) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 0,  6,  6] -1 */
    18439770, /* 47696 (1134) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
    35563818, /* 47697 (1134) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  6] -1 */
       16484, /* 47698 (1135) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    18426488, /* 47699 (1135) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    52442922, /* 47700 (1135) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 6,  6,  0] -1 */
     1551594, /* 47701 (1135) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
    51148218, /* 47702 (1135) [ 0,  1,  0, -1,  0,  0,  0,  0, -1] [ 6,  0,  6] -1 */
    34024494, /* 47703 (1135) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    34019636, /* 47704 (1135) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    51144332, /* 47705 (1135) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 6,  0,  6] -1 */
    17127570, /* 47706 (1135) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6]  1 */
    35555394, /* 47707 (1135) [ 0, -1,  0,  1,  0,  0,  0,  0, -1] [ 0,  6,  6] -1 */
     1538636, /* 47708 (1135) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
        3198, /* 47709 (1135) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    35559284, /* 47710 (1135) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 0,  6,  6] -1 */
    18439770, /* 47711 (1135) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
    17140532, /* 47712 (1135) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
    52447784, /* 47713 (1135) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 6,  6,  0] -1 */
       16484, /* 47714 (1136) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    18426488, /* 47715 (1136) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    52442922, /* 47716 (1136) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 6,  6,  0] -1 */
     1551594, /* 47717 (1136) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
    34015422, /* 47718 (1136) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    18435560, /* 47719 (1136) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    51152756, /* 47720 (1136) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
    34024494, /* 47721 (1136) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    35550860, /* 47722 (1136) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
    51144332, /* 47723 (1136) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 6,  0,  6] -1 */
    17127570, /* 47724 (1136) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6]  1 */
    52451994, /* 47725 (1136) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
        7412, /* 47726 (1136) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    17135994, /* 47727 (1136) [ 0,  1,  0, -1,  0,  0,  0,  0, -1] [ 6,  0,  6]  1 */
    35559284, /* 47728 (1136) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 0,  6,  6] -1 */
     1543170, /* 47729 (1136) [ 0, -1,  0,  1,  0,  0,  0,  0, -1] [ 0,  6,  6]  1 */
       16484, /* 47730 (1137) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    18426488, /* 47731 (1137) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    52442922, /* 47732 (1137) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 6,  6,  0] -1 */
    51139794, /* 47733 (1137) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6] -1 */
    51152756, /* 47734 (1137) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
    35550860, /* 47735 (1137) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
    34024494, /* 47736 (1137) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    34019636, /* 47737 (1137) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  0] -1 */
     1547060, /* 47738 (1137) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 0,  6,  6]  1 */
    17135994, /* 47739 (1137) [ 0,  1,  0, -1,  0,  0,  0,  0, -1] [ 6,  0,  6]  1 */
        3198, /* 47740 (1137) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    17132108, /* 47741 (1137) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 6,  0,  6]  1 */
    18439770, /* 47742 (1137) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
     1543170, /* 47743 (1137) [ 0, -1,  0,  1,  0,  0,  0,  0, -1] [ 0,  6,  6]  1 */
    35563818, /* 47744 (1137) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  6] -1 */
    52447784, /* 47745 (1137) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 6,  6,  0] -1 */
       16484, /* 47746 (1138) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    18426488, /* 47747 (1138) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    51139794, /* 47748 (1138) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6] -1 */
    34015422, /* 47749 (1138) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    34019636, /* 47750 (1138) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    51144332, /* 47751 (1138) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 6,  0,  6] -1 */
       12270, /* 47752 (1138) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    18430698, /* 47753 (1138) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 6,  6,  0]  1 */
    17135994, /* 47754 (1138) [ 0,  1,  0, -1,  0,  0,  0,  0, -1] [ 6,  0,  6]  1 */
     1538636, /* 47755 (1138) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
    52451994, /* 47756 (1138) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
    35559284, /* 47757 (1138) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 0,  6,  6] -1 */
    17140532, /* 47758 (1138) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
     1543170, /* 47759 (1138) [ 0, -1,  0,  1,  0,  0,  0,  0, -1] [ 0,  6,  6]  1 */
    35563818, /* 47760 (1138) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  6] -1 */
    52447784, /* 47761 (1138) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 6,  6,  0] -1 */
       16484, /* 47762 (1139) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    18426488, /* 47763 (1139) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
     1551594, /* 47764 (1139) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
    34015422, /* 47765 (1139) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    51148218, /* 47766 (1139) [ 0,  1,  0, -1,  0,  0,  0,  0, -1] [ 6,  0,  6] -1 */
    51152756, /* 47767 (1139) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
    35550860, /* 47768 (1139) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
    17127570, /* 47769 (1139) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6]  1 */
    34019636, /* 47770 (1139) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    35555394, /* 47771 (1139) [ 0, -1,  0,  1,  0,  0,  0,  0, -1] [ 0,  6,  6] -1 */
       12270, /* 47772 (1139) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    18430698, /* 47773 (1139) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 6,  6,  0]  1 */
    17132108, /* 47774 (1139) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 6,  0,  6]  1 */
    52451994, /* 47775 (1139) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
     1547060, /* 47776 (1139) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 0,  6,  6]  1 */
    52447784, /* 47777 (1139) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 6,  6,  0] -1 */
       16484, /* 47778 (1140) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    17127570, /* 47779 (1140) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6]  1 */
    51030120, /* 47780 (1140) [ 0,  1,  0, -1,  0,  0,  0,  0, -1] [ 6,  0,  0] -1 */
     1538636, /* 47781 (1140) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
       12270, /* 47782 (1140) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    17132108, /* 47783 (1140) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 6,  0,  6]  1 */
        3198, /* 47784 (1140) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    17135994, /* 47785 (1140) [ 0,  1,  0, -1,  0,  0,  0,  0, -1] [ 6,  0,  6]  1 */
    35445720, /* 47786 (1140) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  0] -1 */
    17140532, /* 47787 (1140) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
    51021696, /* 47788 (1140) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  0] -1 */
    51034658, /* 47789 (1140) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  0] -1 */
    51026234, /* 47790 (1140) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 6,  0,  0] -1 */
    18430698, /* 47791 (1140) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 6,  6,  0]  1 */
    34146806, /* 47792 (1140) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    52565882, /* 47793 (1140) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    35437296, /* 47794 (1140) [ 0, -1,  0,  1,  0,  0,  0,  0, -1] [ 0,  6,  0] -1 */
     1551594, /* 47795 (1140) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
    52556810, /* 47796 (1140) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    34137734, /* 47797 (1140) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    52570092, /* 47798 (1140) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    35441186, /* 47799 (1140) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 0,  6,  0] -1 */
    18426488, /* 47800 (1140) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    34142592, /* 47801 (1140) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  6] -1 */
    18435560, /* 47802 (1140) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    35432762, /* 47803 (1140) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  0] -1 */
    34133520, /* 47804 (1140) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
        7412, /* 47805 (1140) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    18439770, /* 47806 (1140) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
     1543170, /* 47807 (1140) [ 0, -1,  0,  1,  0,  0,  0,  0, -1] [ 0,  6,  6]  1 */
    52561020, /* 47808 (1140) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 6,  6,  6] -1 */
     1547060, /* 47809 (1140) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 0,  6,  6]  1 */
       16484, /* 47810 (1141) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34019634, /* 47811 (1141) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    17127570, /* 47812 (1141) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6]  1 */
     1538636, /* 47813 (1141) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
       12270, /* 47814 (1141) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    52451996, /* 47815 (1141) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
        3198, /* 47816 (1141) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    17132108, /* 47817 (1141) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 6,  0,  6]  1 */
    17135994, /* 47818 (1141) [ 0,  1,  0, -1,  0,  0,  0,  0, -1] [ 6,  0,  6]  1 */
    51152754, /* 47819 (1141) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  6] -1 */
    17140532, /* 47820 (1141) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
    18430698, /* 47821 (1141) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 6,  6,  0]  1 */
    34015424, /* 47822 (1141) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    34024496, /* 47823 (1141) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 0,  0,  0] -1 */
     1551594, /* 47824 (1141) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
    52442924, /* 47825 (1141) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 6,  6,  0] -1 */
    34028706, /* 47826 (1141) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    52447782, /* 47827 (1141) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 6,  6,  0] -1 */
    51144330, /* 47828 (1141) [ 0, -1,  0,  1,  0,  0,  0,  0, -1] [ 6,  0,  6] -1 */
    35550858, /* 47829 (1141) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6] -1 */
    35559282, /* 47830 (1141) [ 0,  1,  0, -1,  0,  0,  0,  0, -1] [ 0,  6,  6] -1 */
    35555396, /* 47831 (1141) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 0,  6,  6] -1 */
    51148220, /* 47832 (1141) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 6,  0,  6] -1 */
    35563820, /* 47833 (1141) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
    18426488, /* 47834 (1141) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    18435560, /* 47835 (1141) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    52438710, /* 47836 (1141) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
        7412, /* 47837 (1141) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    51139796, /* 47838 (1141) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
    18439770, /* 47839 (1141) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
     1543170, /* 47840 (1141) [ 0, -1,  0,  1,  0,  0,  0,  0, -1] [ 0,  6,  6]  1 */
     1547060, /* 47841 (1141) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 0,  6,  6]  1 */
       16484, /* 47842 (1142) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34137732, /* 47843 (1142) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  6] -1 */
    17127570, /* 47844 (1142) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6]  1 */
    51026232, /* 47845 (1142) [ 0, -1,  0,  1,  0,  0,  0,  0, -1] [ 6,  0,  0] -1 */
     1538636, /* 47846 (1142) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
       12270, /* 47847 (1142) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    17132108, /* 47848 (1142) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 6,  0,  6]  1 */
        3198, /* 47849 (1142) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    17135994, /* 47850 (1142) [ 0,  1,  0, -1,  0,  0,  0,  0, -1] [ 6,  0,  6]  1 */
    17140532, /* 47851 (1142) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
    52570094, /* 47852 (1142) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    51030122, /* 47853 (1142) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 6,  0,  0] -1 */
    51021698, /* 47854 (1142) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  0] -1 */
    18430698, /* 47855 (1142) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 6,  6,  0]  1 */
     1551594, /* 47856 (1142) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
    34133522, /* 47857 (1142) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    34142594, /* 47858 (1142) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    51034656, /* 47859 (1142) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  0] -1 */
    35432760, /* 47860 (1142) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  0] -1 */
    35441184, /* 47861 (1142) [ 0,  1,  0, -1,  0,  0,  0,  0, -1] [ 0,  6,  0] -1 */
    35445722, /* 47862 (1142) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  0] -1 */
    52561022, /* 47863 (1142) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    34146804, /* 47864 (1142) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
    52565880, /* 47865 (1142) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    52556808, /* 47866 (1142) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    18426488, /* 47867 (1142) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    18435560, /* 47868 (1142) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    35437298, /* 47869 (1142) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 0,  6,  0] -1 */
        7412, /* 47870 (1142) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    18439770, /* 47871 (1142) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
     1543170, /* 47872 (1142) [ 0, -1,  0,  1,  0,  0,  0,  0, -1] [ 0,  6,  6]  1 */
     1547060, /* 47873 (1142) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 0,  6,  6]  1 */
       16484, /* 47874 (1143) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    18426648, /* 47875 (1143) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
    18439608, /* 47876 (1143) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
        3200, /* 47877 (1143) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    18439610, /* 47878 (1143) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
      129884, /* 47879 (1143) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  6]  1 */
    18548796, /* 47880 (1143) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 6,  6,  6]  1 */
    18553656, /* 47881 (1143) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 6,  6,  6]  1 */
    18426650, /* 47882 (1143) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
        3198, /* 47883 (1143) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
      129882, /* 47884 (1143) [ 0,  1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  6]  1 */
      125996, /* 47885 (1143) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 0,  0,  6]  1 */
    18548798, /* 47886 (1143) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 6,  6,  6]  1 */
      125994, /* 47887 (1143) [ 0, -1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  6]  1 */
       16482, /* 47888 (1143) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    18553658, /* 47889 (1143) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 6,  6,  6]  1 */
       16484, /* 47890 (1144) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    18439608, /* 47891 (1144) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
    18553656, /* 47892 (1144) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 6,  6,  6]  1 */
       16482, /* 47893 (1144) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
        3198, /* 47894 (1144) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    52438872, /* 47895 (1144) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
    52451834, /* 47896 (1144) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
    34142108, /* 47897 (1144) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    18548796, /* 47898 (1144) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 6,  6,  6]  1 */
    52438874, /* 47899 (1144) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
    34138220, /* 47900 (1144) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    34142106, /* 47901 (1144) [ 0,  1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  6] -1 */
    34138218, /* 47902 (1144) [ 0, -1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  6] -1 */
    52565882, /* 47903 (1144) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    34015424, /* 47904 (1144) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    34028708, /* 47905 (1144) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    18426648, /* 47906 (1144) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
    18439610, /* 47907 (1144) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
      129884, /* 47908 (1144) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  6]  1 */
    34028706, /* 47909 (1144) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    18426650, /* 47910 (1144) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
      125996, /* 47911 (1144) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 0,  0,  6]  1 */
      129882, /* 47912 (1144) [ 0,  1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  6]  1 */
      125994, /* 47913 (1144) [ 0, -1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  6]  1 */
    52561022, /* 47914 (1144) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    52565880, /* 47915 (1144) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    18553658, /* 47916 (1144) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    52451832, /* 47917 (1144) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
    34015422, /* 47918 (1144) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
        3200, /* 47919 (1144) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    52561020, /* 47920 (1144) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    18548798, /* 47921 (1144) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 6,  6,  6]  1 */
       16484, /* 47922 (1145) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34015422, /* 47923 (1145) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
        3200, /* 47924 (1145) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    18439610, /* 47925 (1145) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
      129884, /* 47926 (1145) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  6]  1 */
    34142106, /* 47927 (1145) [ 0,  1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  6] -1 */
    34028706, /* 47928 (1145) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    18553658, /* 47929 (1145) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    34138218, /* 47930 (1145) [ 0, -1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  6] -1 */
    18426650, /* 47931 (1145) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
      125996, /* 47932 (1145) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 0,  0,  6]  1 */
    18548798, /* 47933 (1145) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    52438872, /* 47934 (1145) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
    52561020, /* 47935 (1145) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    52565880, /* 47936 (1145) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    52451832, /* 47937 (1145) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
       16484, /* 47938 (1146) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    52451834, /* 47939 (1146) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
    34142108, /* 47940 (1146) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  6] -1 */
        3200, /* 47941 (1146) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    18548796, /* 47942 (1146) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 6,  6,  6]  1 */
    52438874, /* 47943 (1146) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
    18553656, /* 47944 (1146) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 6,  6,  6]  1 */
    34142106, /* 47945 (1146) [ 0,  1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  6] -1 */
    34138220, /* 47946 (1146) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    18553658, /* 47947 (1146) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    34138218, /* 47948 (1146) [ 0, -1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  6] -1 */
        3198, /* 47949 (1146) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    18548798, /* 47950 (1146) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    52438872, /* 47951 (1146) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
       16482, /* 47952 (1146) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    52451832, /* 47953 (1146) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
       16484, /* 47954 (1147) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34142108, /* 47955 (1147) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    18426648, /* 47956 (1147) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
    18439608, /* 47957 (1147) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
        3200, /* 47958 (1147) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    18439610, /* 47959 (1147) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
       16482, /* 47960 (1147) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    34142106, /* 47961 (1147) [ 0,  1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  6] -1 */
    34138220, /* 47962 (1147) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    34138218, /* 47963 (1147) [ 0, -1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  6] -1 */
    18426650, /* 47964 (1147) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
        3198, /* 47965 (1147) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    52561022, /* 47966 (1147) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    52565882, /* 47967 (1147) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    52561020, /* 47968 (1147) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    52565880, /* 47969 (1147) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 6,  6,  6] -1 */
       16484, /* 47970 (1148) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    52451834, /* 47971 (1148) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
    34142108, /* 47972 (1148) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    18426648, /* 47973 (1148) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
    34015422, /* 47974 (1148) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    18439608, /* 47975 (1148) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
        3200, /* 47976 (1148) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    52438874, /* 47977 (1148) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
    34138220, /* 47978 (1148) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    34028706, /* 47979 (1148) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
      129882, /* 47980 (1148) [ 0,  1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  6]  1 */
    18548798, /* 47981 (1148) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 6,  6,  6]  1 */
      125994, /* 47982 (1148) [ 0, -1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  6]  1 */
    52561020, /* 47983 (1148) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    52565880, /* 47984 (1148) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    18553658, /* 47985 (1148) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 6,  6,  6]  1 */
       16484, /* 47986 (1149) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    52451834, /* 47987 (1149) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
        3200, /* 47988 (1149) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
      129884, /* 47989 (1149) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  6]  1 */
    52438874, /* 47990 (1149) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
       16482, /* 47991 (1149) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
        3198, /* 47992 (1149) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
      129882, /* 47993 (1149) [ 0,  1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  6]  1 */
      125996, /* 47994 (1149) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 0,  0,  6]  1 */
    52561022, /* 47995 (1149) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    52565882, /* 47996 (1149) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 6,  6,  6] -1 */
      125994, /* 47997 (1149) [ 0, -1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  6]  1 */
    52438872, /* 47998 (1149) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
    52561020, /* 47999 (1149) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    52565880, /* 48000 (1149) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    52451832, /* 48001 (1149) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
       16484, /* 48002 (1150) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34142108, /* 48003 (1150) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    34015422, /* 48004 (1150) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
        3200, /* 48005 (1150) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    18439610, /* 48006 (1150) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    18548796, /* 48007 (1150) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 6,  6,  6]  1 */
    18553656, /* 48008 (1150) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 6,  6,  6]  1 */
    34138220, /* 48009 (1150) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    34028706, /* 48010 (1150) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    18426650, /* 48011 (1150) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
      129882, /* 48012 (1150) [ 0,  1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  6]  1 */
    52561022, /* 48013 (1150) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 6,  6,  6] -1 */
      125994, /* 48014 (1150) [ 0, -1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  6]  1 */
    52565882, /* 48015 (1150) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    52438872, /* 48016 (1150) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
    52451832, /* 48017 (1150) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
       16484, /* 48018 (1151) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    52451834, /* 48019 (1151) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
    18426648, /* 48020 (1151) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
    34015422, /* 48021 (1151) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    18439608, /* 48022 (1151) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
        3200, /* 48023 (1151) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
      129884, /* 48024 (1151) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  6]  1 */
    18548796, /* 48025 (1151) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 6,  6,  6]  1 */
    18553656, /* 48026 (1151) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 6,  6,  6]  1 */
    52438874, /* 48027 (1151) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
    34142106, /* 48028 (1151) [ 0,  1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  6] -1 */
    34028706, /* 48029 (1151) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    34138218, /* 48030 (1151) [ 0, -1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  6] -1 */
      125996, /* 48031 (1151) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 0,  0,  6]  1 */
    52561022, /* 48032 (1151) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    52565882, /* 48033 (1151) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 6,  6,  6] -1 */
       16484, /* 48034 (1152) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    52442922, /* 48035 (1152) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 6,  6,  0] -1 */
    18439608, /* 48036 (1152) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
    18553656, /* 48037 (1152) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 6,  6,  6]  1 */
       16482, /* 48038 (1152) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
        3198, /* 48039 (1152) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    52556970, /* 48040 (1152) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    34024008, /* 48041 (1152) [ 0,  1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    34020120, /* 48042 (1152) [ 0, -1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    34024010, /* 48043 (1152) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    18548796, /* 48044 (1152) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 6,  6,  6]  1 */
    52569932, /* 48045 (1152) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    34020122, /* 48046 (1152) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    34146806, /* 48047 (1152) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    52556972, /* 48048 (1152) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    52447784, /* 48049 (1152) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 6,  6,  0] -1 */
    18426648, /* 48050 (1152) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
    34133522, /* 48051 (1152) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    18439610, /* 48052 (1152) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
      129884, /* 48053 (1152) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  6]  1 */
    52442924, /* 48054 (1152) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 6,  6,  0] -1 */
    18426650, /* 48055 (1152) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    52447782, /* 48056 (1152) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 6,  6,  0] -1 */
      125996, /* 48057 (1152) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 0,  0,  6]  1 */
      129882, /* 48058 (1152) [ 0,  1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  6]  1 */
      125994, /* 48059 (1152) [ 0, -1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  6]  1 */
    52569930, /* 48060 (1152) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    34146804, /* 48061 (1152) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
    18553658, /* 48062 (1152) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 6,  6,  6]  1 */
        3200, /* 48063 (1152) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34133520, /* 48064 (1152) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
    18548798, /* 48065 (1152) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 6,  6,  6]  1 */
       16484, /* 48066 (1153) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34137732, /* 48067 (1153) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  6] -1 */
    18439608, /* 48068 (1153) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
    52561506, /* 48069 (1153) [ 0, -1,  0,  1,  0,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    18553656, /* 48070 (1153) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 6,  6,  6]  1 */
       16482, /* 48071 (1153) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    52451996, /* 48072 (1153) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
        3198, /* 48073 (1153) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    52565394, /* 48074 (1153) [ 0,  1,  0, -1,  0,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    52565396, /* 48075 (1153) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    52561508, /* 48076 (1153) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    18548796, /* 48077 (1153) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 6,  6,  6]  1 */
    34015584, /* 48078 (1153) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    34028546, /* 48079 (1153) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    52438712, /* 48080 (1153) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
    34015586, /* 48081 (1153) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    18426648, /* 48082 (1153) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
    18439610, /* 48083 (1153) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
      129884, /* 48084 (1153) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  6]  1 */
    34142594, /* 48085 (1153) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    52451994, /* 48086 (1153) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
    18426650, /* 48087 (1153) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
      125996, /* 48088 (1153) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 0,  0,  6]  1 */
      129882, /* 48089 (1153) [ 0,  1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  6]  1 */
      125994, /* 48090 (1153) [ 0, -1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  6]  1 */
    34137734, /* 48091 (1153) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    34028544, /* 48092 (1153) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    18553658, /* 48093 (1153) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    34142592, /* 48094 (1153) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  6] -1 */
    52438710, /* 48095 (1153) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
        3200, /* 48096 (1153) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    18548798, /* 48097 (1153) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 6,  6,  6]  1 */
       16484, /* 48098 (1154) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    18439608, /* 48099 (1154) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
    34019634, /* 48100 (1154) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    18553656, /* 48101 (1154) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 6,  6,  6]  1 */
    52443408, /* 48102 (1154) [ 0, -1,  0,  1,  0,  0,  0,  0, -1] [ 6,  6,  0] -1 */
    52447298, /* 48103 (1154) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 6,  6,  0] -1 */
        3198, /* 48104 (1154) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    52447296, /* 48105 (1154) [ 0,  1,  0, -1,  0,  0,  0,  0, -1] [ 6,  6,  0] -1 */
    52570094, /* 48106 (1154) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    52443410, /* 48107 (1154) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 6,  6,  0] -1 */
    18548796, /* 48108 (1154) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 6,  6,  6]  1 */
    34146644, /* 48109 (1154) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    34133684, /* 48110 (1154) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    34133682, /* 48111 (1154) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
    34024496, /* 48112 (1154) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    18426648, /* 48113 (1154) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
    52556810, /* 48114 (1154) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    18439610, /* 48115 (1154) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
      129884, /* 48116 (1154) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  6]  1 */
    34019636, /* 48117 (1154) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    18426650, /* 48118 (1154) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
      125996, /* 48119 (1154) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 0,  0,  6]  1 */
      129882, /* 48120 (1154) [ 0,  1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  6]  1 */
      125994, /* 48121 (1154) [ 0, -1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  6]  1 */
    34146642, /* 48122 (1154) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
    52570092, /* 48123 (1154) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    18553658, /* 48124 (1154) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    52556808, /* 48125 (1154) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
        3200, /* 48126 (1154) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34024494, /* 48127 (1154) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    18548798, /* 48128 (1154) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 6,  6,  6]  1 */
       16482, /* 48129 (1154) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
       16484, /* 48130 (1155) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
        3200, /* 48131 (1155) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    18553172, /* 48132 (1155) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 6,  6,  6]  1 */
       12272, /* 48133 (1155) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 0,  0,  0]  1 */
       16482, /* 48134 (1155) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    18549282, /* 48135 (1155) [ 0, -1,  0,  1,  0,  0,  0,  0, -1] [ 6,  6,  6]  1 */
        7410, /* 48136 (1155) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  0]  1 */
       12270, /* 48137 (1155) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  0]  1 */
        7412, /* 48138 (1155) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  0]  1 */
        3198, /* 48139 (1155) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    18549284, /* 48140 (1155) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    18557708, /* 48141 (1155) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    18544746, /* 48142 (1155) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
    18544748, /* 48143 (1155) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    18553170, /* 48144 (1155) [ 0,  1,  0, -1,  0,  0,  0,  0, -1] [ 6,  6,  6]  1 */
    18557706, /* 48145 (1155) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
       16484, /* 48146 (1156) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    52561506, /* 48147 (1156) [ 0, -1,  0,  1,  0,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    34019634, /* 48148 (1156) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  0] -1 */
       12270, /* 48149 (1156) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  0]  1 */
        3198, /* 48150 (1156) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    52556970, /* 48151 (1156) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    52565394, /* 48152 (1156) [ 0,  1,  0, -1,  0,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    52565396, /* 48153 (1156) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    52561508, /* 48154 (1156) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    52569932, /* 48155 (1156) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    18549282, /* 48156 (1156) [ 0, -1,  0,  1,  0,  0,  0,  0, -1] [ 6,  6,  6]  1 */
        7410, /* 48157 (1156) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    52556972, /* 48158 (1156) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    34015424, /* 48159 (1156) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    34028708, /* 48160 (1156) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    18544746, /* 48161 (1156) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
    34024496, /* 48162 (1156) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    18553170, /* 48163 (1156) [ 0,  1,  0, -1,  0,  0,  0,  0, -1] [ 6,  6,  6]  1 */
    18553172, /* 48164 (1156) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    34019636, /* 48165 (1156) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    34028706, /* 48166 (1156) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    18549284, /* 48167 (1156) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    52569930, /* 48168 (1156) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    18557708, /* 48169 (1156) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    18544748, /* 48170 (1156) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    34015422, /* 48171 (1156) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
        3200, /* 48172 (1156) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34024494, /* 48173 (1156) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  0] -1 */
       12272, /* 48174 (1156) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 0,  0,  0]  1 */
        7412, /* 48175 (1156) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  0]  1 */
       16482, /* 48176 (1156) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    18557706, /* 48177 (1156) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
       16484, /* 48178 (1157) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34015422, /* 48179 (1157) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
        3200, /* 48180 (1157) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34019634, /* 48181 (1157) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    34024494, /* 48182 (1157) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    18553172, /* 48183 (1157) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 6,  6,  6]  1 */
       12272, /* 48184 (1157) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    52561506, /* 48185 (1157) [ 0, -1,  0,  1,  0,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    34028706, /* 48186 (1157) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
        7412, /* 48187 (1157) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    52556970, /* 48188 (1157) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    18549284, /* 48189 (1157) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    52565394, /* 48190 (1157) [ 0,  1,  0, -1,  0,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    52569930, /* 48191 (1157) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    18557708, /* 48192 (1157) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    18544748, /* 48193 (1157) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
       16484, /* 48194 (1158) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    52565396, /* 48195 (1158) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 6,  6,  6] -1 */
        3200, /* 48196 (1158) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    52561508, /* 48197 (1158) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    52561506, /* 48198 (1158) [ 0, -1,  0,  1,  0,  0,  0,  0, -1] [ 6,  6,  6] -1 */
       12272, /* 48199 (1158) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    52569932, /* 48200 (1158) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
        7410, /* 48201 (1158) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  0]  1 */
       12270, /* 48202 (1158) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  0]  1 */
        7412, /* 48203 (1158) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  0]  1 */
        3198, /* 48204 (1158) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    52556970, /* 48205 (1158) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    52556972, /* 48206 (1158) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    52565394, /* 48207 (1158) [ 0,  1,  0, -1,  0,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    52569930, /* 48208 (1158) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
       16482, /* 48209 (1158) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
       16484, /* 48210 (1159) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    52565396, /* 48211 (1159) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 6,  6,  6] -1 */
        3200, /* 48212 (1159) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    52561508, /* 48213 (1159) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    34024494, /* 48214 (1159) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    34019634, /* 48215 (1159) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    34019636, /* 48216 (1159) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    52561506, /* 48217 (1159) [ 0, -1,  0,  1,  0,  0,  0,  0, -1] [ 6,  6,  6] -1 */
       16482, /* 48218 (1159) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    34024496, /* 48219 (1159) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 0,  0,  0] -1 */
        3198, /* 48220 (1159) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    52565394, /* 48221 (1159) [ 0,  1,  0, -1,  0,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    18557708, /* 48222 (1159) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    18544746, /* 48223 (1159) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
    18544748, /* 48224 (1159) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    18557706, /* 48225 (1159) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
       16484, /* 48226 (1160) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    52565396, /* 48227 (1160) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    34015422, /* 48228 (1160) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
        3200, /* 48229 (1160) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    52561508, /* 48230 (1160) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    34024494, /* 48231 (1160) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    34019634, /* 48232 (1160) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  0] -1 */
       12272, /* 48233 (1160) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    52569932, /* 48234 (1160) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    18549282, /* 48235 (1160) [ 0, -1,  0,  1,  0,  0,  0,  0, -1] [ 6,  6,  6]  1 */
    34028706, /* 48236 (1160) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
        7412, /* 48237 (1160) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    52556972, /* 48238 (1160) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    18544746, /* 48239 (1160) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
    18553170, /* 48240 (1160) [ 0,  1,  0, -1,  0,  0,  0,  0, -1] [ 6,  6,  6]  1 */
    18557706, /* 48241 (1160) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
       16484, /* 48242 (1161) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
        3200, /* 48243 (1161) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34019634, /* 48244 (1161) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    34024494, /* 48245 (1161) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    34019636, /* 48246 (1161) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    18553172, /* 48247 (1161) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    52569932, /* 48248 (1161) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    18549282, /* 48249 (1161) [ 0, -1,  0,  1,  0,  0,  0,  0, -1] [ 6,  6,  6]  1 */
    34024496, /* 48250 (1161) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 0,  0,  0] -1 */
        3198, /* 48251 (1161) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    52556970, /* 48252 (1161) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    18549284, /* 48253 (1161) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    52556972, /* 48254 (1161) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    52569930, /* 48255 (1161) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
       16482, /* 48256 (1161) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    18553170, /* 48257 (1161) [ 0,  1,  0, -1,  0,  0,  0,  0, -1] [ 6,  6,  6]  1 */
       16484, /* 48258 (1162) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    52565396, /* 48259 (1162) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    34015422, /* 48260 (1162) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
        3200, /* 48261 (1162) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    52561508, /* 48262 (1162) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    34019636, /* 48263 (1162) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    18549282, /* 48264 (1162) [ 0, -1,  0,  1,  0,  0,  0,  0, -1] [ 6,  6,  6]  1 */
        7410, /* 48265 (1162) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  0]  1 */
       12270, /* 48266 (1162) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    34028706, /* 48267 (1162) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    34024496, /* 48268 (1162) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    52556970, /* 48269 (1162) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    52569930, /* 48270 (1162) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    18557708, /* 48271 (1162) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    18544748, /* 48272 (1162) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    18553170, /* 48273 (1162) [ 0,  1,  0, -1,  0,  0,  0,  0, -1] [ 6,  6,  6]  1 */
       16484, /* 48274 (1163) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34015422, /* 48275 (1163) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
        3200, /* 48276 (1163) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    52561506, /* 48277 (1163) [ 0, -1,  0,  1,  0,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    18553172, /* 48278 (1163) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    34019636, /* 48279 (1163) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    52569932, /* 48280 (1163) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
        7410, /* 48281 (1163) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  0]  1 */
       12270, /* 48282 (1163) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    34028706, /* 48283 (1163) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    18549284, /* 48284 (1163) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    52565394, /* 48285 (1163) [ 0,  1,  0, -1,  0,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    52556972, /* 48286 (1163) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    18544746, /* 48287 (1163) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
    34024496, /* 48288 (1163) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    18557706, /* 48289 (1163) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
       16484, /* 48290 (1164) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34137732, /* 48291 (1164) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  6] -1 */
    52443408, /* 48292 (1164) [ 0, -1,  0,  1,  0,  0,  0,  0, -1] [ 6,  6,  0] -1 */
       12270, /* 48293 (1164) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    52447298, /* 48294 (1164) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 6,  6,  0] -1 */
        3198, /* 48295 (1164) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    52438872, /* 48296 (1164) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
    52443410, /* 48297 (1164) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 6,  6,  0] -1 */
    52447296, /* 48298 (1164) [ 0,  1,  0, -1,  0,  0,  0,  0, -1] [ 6,  6,  0] -1 */
    52451834, /* 48299 (1164) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
    52438874, /* 48300 (1164) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
    18549282, /* 48301 (1164) [ 0, -1,  0,  1,  0,  0,  0,  0, -1] [ 6,  6,  6]  1 */
        7410, /* 48302 (1164) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    34146806, /* 48303 (1164) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    18544746, /* 48304 (1164) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
    18553170, /* 48305 (1164) [ 0,  1,  0, -1,  0,  0,  0,  0, -1] [ 6,  6,  6]  1 */
    34133522, /* 48306 (1164) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    34142594, /* 48307 (1164) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    18553172, /* 48308 (1164) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    34137734, /* 48309 (1164) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    18549284, /* 48310 (1164) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    18557708, /* 48311 (1164) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    34146804, /* 48312 (1164) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
    18544748, /* 48313 (1164) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    52451832, /* 48314 (1164) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
    34142592, /* 48315 (1164) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  6] -1 */
        3200, /* 48316 (1164) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
       12272, /* 48317 (1164) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34133520, /* 48318 (1164) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
        7412, /* 48319 (1164) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  0]  1 */
       16482, /* 48320 (1164) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    18557706, /* 48321 (1164) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
       16484, /* 48322 (1165) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    52442922, /* 48323 (1165) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 6,  6,  0] -1 */
       12270, /* 48324 (1165) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    52451996, /* 48325 (1165) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
        3198, /* 48326 (1165) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    34142108, /* 48327 (1165) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    34146644, /* 48328 (1165) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    34138220, /* 48329 (1165) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 0,  0,  6] -1 */
        7410, /* 48330 (1165) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    34142106, /* 48331 (1165) [ 0,  1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  6] -1 */
    18549282, /* 48332 (1165) [ 0, -1,  0,  1,  0,  0,  0,  0, -1] [ 6,  6,  6]  1 */
    34138218, /* 48333 (1165) [ 0, -1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  6] -1 */
    34133684, /* 48334 (1165) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    34133682, /* 48335 (1165) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
    52438712, /* 48336 (1165) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
    18544746, /* 48337 (1165) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
    18553170, /* 48338 (1165) [ 0,  1,  0, -1,  0,  0,  0,  0, -1] [ 6,  6,  6]  1 */
    52447784, /* 48339 (1165) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 6,  6,  0] -1 */
    18553172, /* 48340 (1165) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    52442924, /* 48341 (1165) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 6,  6,  0] -1 */
    52451994, /* 48342 (1165) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
    52447782, /* 48343 (1165) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 6,  6,  0] -1 */
    18549284, /* 48344 (1165) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    34146642, /* 48345 (1165) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
    18557708, /* 48346 (1165) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    18544748, /* 48347 (1165) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    52438710, /* 48348 (1165) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
        3200, /* 48349 (1165) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
       12272, /* 48350 (1165) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 0,  0,  0]  1 */
        7412, /* 48351 (1165) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  0]  1 */
       16482, /* 48352 (1165) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    18557706, /* 48353 (1165) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
       16484, /* 48354 (1166) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
       12270, /* 48355 (1166) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  0]  1 */
        3198, /* 48356 (1166) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    52570094, /* 48357 (1166) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    34024008, /* 48358 (1166) [ 0,  1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    34020120, /* 48359 (1166) [ 0, -1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    34024010, /* 48360 (1166) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    34015584, /* 48361 (1166) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    18549282, /* 48362 (1166) [ 0, -1,  0,  1,  0,  0,  0,  0, -1] [ 6,  6,  6]  1 */
        7410, /* 48363 (1166) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    34020122, /* 48364 (1166) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    52565882, /* 48365 (1166) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    34028546, /* 48366 (1166) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    18544746, /* 48367 (1166) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
    18553170, /* 48368 (1166) [ 0,  1,  0, -1,  0,  0,  0,  0, -1] [ 6,  6,  6]  1 */
    34015586, /* 48369 (1166) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    52556810, /* 48370 (1166) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    18553172, /* 48371 (1166) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    18549284, /* 48372 (1166) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    52561022, /* 48373 (1166) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    18557708, /* 48374 (1166) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    52570092, /* 48375 (1166) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    18544748, /* 48376 (1166) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    34028544, /* 48377 (1166) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    52565880, /* 48378 (1166) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    52556808, /* 48379 (1166) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
        3200, /* 48380 (1166) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
       12272, /* 48381 (1166) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 0,  0,  0]  1 */
        7412, /* 48382 (1166) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    52561020, /* 48383 (1166) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 6,  6,  6] -1 */
       16482, /* 48384 (1166) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    18557706, /* 48385 (1166) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
       16484, /* 48386 (1167) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
        3200, /* 48387 (1167) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
        7410, /* 48388 (1167) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  0]  1 */
       12270, /* 48389 (1167) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    18553172, /* 48390 (1167) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 6,  6,  6]  1 */
        7896, /* 48391 (1167) [ 0, -1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  0]  1 */
       11784, /* 48392 (1167) [ 0,  1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    18544584, /* 48393 (1167) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
    18549284, /* 48394 (1167) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    18557706, /* 48395 (1167) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
    18553658, /* 48396 (1167) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 6,  6,  6]  1 */
        3362, /* 48397 (1167) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    18557868, /* 48398 (1167) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
    18544746, /* 48399 (1167) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
       16322, /* 48400 (1167) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    18548798, /* 48401 (1167) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 6,  6,  6]  1 */
       16484, /* 48402 (1168) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34019634, /* 48403 (1168) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  0] -1 */
       12270, /* 48404 (1168) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    18549284, /* 48405 (1168) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    18544584, /* 48406 (1168) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
       11784, /* 48407 (1168) [ 0,  1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  0]  1 */
        7410, /* 48408 (1168) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    34015586, /* 48409 (1168) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    34015424, /* 48410 (1168) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    34028708, /* 48411 (1168) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    52565882, /* 48412 (1168) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    34020120, /* 48413 (1168) [ 0, -1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    52569930, /* 48414 (1168) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    52556970, /* 48415 (1168) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    52570092, /* 48416 (1168) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    34028546, /* 48417 (1168) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    52561022, /* 48418 (1168) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 6,  6,  6] -1 */
        3362, /* 48419 (1168) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    52565396, /* 48420 (1168) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    34024494, /* 48421 (1168) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  0] -1 */
        3200, /* 48422 (1168) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34024008, /* 48423 (1168) [ 0,  1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    52556808, /* 48424 (1168) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    52561508, /* 48425 (1168) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    18557706, /* 48426 (1168) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
    18548798, /* 48427 (1168) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    18553658, /* 48428 (1168) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    18557868, /* 48429 (1168) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
    18544746, /* 48430 (1168) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
        7896, /* 48431 (1168) [ 0, -1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  0]  1 */
       16322, /* 48432 (1168) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    18553172, /* 48433 (1168) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 6,  6,  6]  1 */
       16484, /* 48434 (1169) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
        3200, /* 48435 (1169) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34019634, /* 48436 (1169) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    34024008, /* 48437 (1169) [ 0,  1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    52556808, /* 48438 (1169) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    34020120, /* 48439 (1169) [ 0, -1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    52569930, /* 48440 (1169) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    18553172, /* 48441 (1169) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    52556970, /* 48442 (1169) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    52570092, /* 48443 (1169) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    18549284, /* 48444 (1169) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    18548798, /* 48445 (1169) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    18553658, /* 48446 (1169) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 6,  6,  6]  1 */
        3362, /* 48447 (1169) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
       16322, /* 48448 (1169) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34024494, /* 48449 (1169) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  0] -1 */
       16484, /* 48450 (1170) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
        3200, /* 48451 (1170) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34024008, /* 48452 (1170) [ 0,  1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    34015586, /* 48453 (1170) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
        7410, /* 48454 (1170) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    52561508, /* 48455 (1170) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    52569930, /* 48456 (1170) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
       12270, /* 48457 (1170) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    52556970, /* 48458 (1170) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    34020120, /* 48459 (1170) [ 0, -1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    18544584, /* 48460 (1170) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
    34028546, /* 48461 (1170) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    18553658, /* 48462 (1170) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    18557868, /* 48463 (1170) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
    52565396, /* 48464 (1170) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    18548798, /* 48465 (1170) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 6,  6,  6]  1 */
       16484, /* 48466 (1171) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
        3200, /* 48467 (1171) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34019634, /* 48468 (1171) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    34024008, /* 48469 (1171) [ 0,  1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    52565882, /* 48470 (1171) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    52561508, /* 48471 (1171) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    34020120, /* 48472 (1171) [ 0, -1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    18544584, /* 48473 (1171) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
    18557706, /* 48474 (1171) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
    18544746, /* 48475 (1171) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
    52561022, /* 48476 (1171) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 6,  6,  6] -1 */
        3362, /* 48477 (1171) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    18557868, /* 48478 (1171) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
    52565396, /* 48479 (1171) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 6,  6,  6] -1 */
       16322, /* 48480 (1171) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34024494, /* 48481 (1171) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  0] -1 */
       16484, /* 48482 (1172) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
        3200, /* 48483 (1172) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34019634, /* 48484 (1172) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    52556808, /* 48485 (1172) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    34015586, /* 48486 (1172) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    52561508, /* 48487 (1172) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    52570092, /* 48488 (1172) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
       11784, /* 48489 (1172) [ 0,  1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    18557706, /* 48490 (1172) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
    34028546, /* 48491 (1172) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    18544746, /* 48492 (1172) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
    52565396, /* 48493 (1172) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    18548798, /* 48494 (1172) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    18553658, /* 48495 (1172) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 6,  6,  6]  1 */
        7896, /* 48496 (1172) [ 0, -1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    34024494, /* 48497 (1172) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  0] -1 */
       16484, /* 48498 (1173) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
        3200, /* 48499 (1173) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34019634, /* 48500 (1173) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    52565882, /* 48501 (1173) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    34015586, /* 48502 (1173) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    52569930, /* 48503 (1173) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    18553172, /* 48504 (1173) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    52556970, /* 48505 (1173) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
       11784, /* 48506 (1173) [ 0,  1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    18544584, /* 48507 (1173) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
    18549284, /* 48508 (1173) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    34028546, /* 48509 (1173) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    52561022, /* 48510 (1173) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    18557868, /* 48511 (1173) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
        7896, /* 48512 (1173) [ 0, -1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    34024494, /* 48513 (1173) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  0] -1 */
       16484, /* 48514 (1174) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
        3200, /* 48515 (1174) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    52556808, /* 48516 (1174) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    52565882, /* 48517 (1174) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 6,  6,  6] -1 */
        7410, /* 48518 (1174) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    52561508, /* 48519 (1174) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    52569930, /* 48520 (1174) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
       12270, /* 48521 (1174) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    52556970, /* 48522 (1174) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    52570092, /* 48523 (1174) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
       11784, /* 48524 (1174) [ 0,  1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    52565396, /* 48525 (1174) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 6,  6,  6] -1 */
        3362, /* 48526 (1174) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    52561022, /* 48527 (1174) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 6,  6,  6] -1 */
        7896, /* 48528 (1174) [ 0, -1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  0]  1 */
       16322, /* 48529 (1174) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
       16484, /* 48530 (1175) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
        3200, /* 48531 (1175) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34024008, /* 48532 (1175) [ 0,  1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    52556808, /* 48533 (1175) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    52565882, /* 48534 (1175) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 6,  6,  6] -1 */
        7410, /* 48535 (1175) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    34015586, /* 48536 (1175) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
       12270, /* 48537 (1175) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    34020120, /* 48538 (1175) [ 0, -1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    52570092, /* 48539 (1175) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    18549284, /* 48540 (1175) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    18557706, /* 48541 (1175) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
    34028546, /* 48542 (1175) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    18544746, /* 48543 (1175) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
    52561022, /* 48544 (1175) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    18553172, /* 48545 (1175) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 6,  6,  6]  1 */
       16484, /* 48546 (1176) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34137732, /* 48547 (1176) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  6] -1 */
    34142106, /* 48548 (1176) [ 0,  1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  6] -1 */
       12270, /* 48549 (1176) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    18549284, /* 48550 (1176) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    18544584, /* 48551 (1176) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
       11784, /* 48552 (1176) [ 0,  1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    52451832, /* 48553 (1176) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
    52443410, /* 48554 (1176) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 6,  6,  0] -1 */
        7410, /* 48555 (1176) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    34146806, /* 48556 (1176) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    52447784, /* 48557 (1176) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 6,  6,  0] -1 */
    34138218, /* 48558 (1176) [ 0, -1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  6] -1 */
    34133522, /* 48559 (1176) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    52442924, /* 48560 (1176) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 6,  6,  0] -1 */
    34142592, /* 48561 (1176) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  6] -1 */
        3362, /* 48562 (1176) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    52438872, /* 48563 (1176) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
    52451994, /* 48564 (1176) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
    52447298, /* 48565 (1176) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 6,  6,  0] -1 */
    34146644, /* 48566 (1176) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
        3200, /* 48567 (1176) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    52438710, /* 48568 (1176) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
    34133684, /* 48569 (1176) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    18557706, /* 48570 (1176) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
    18548798, /* 48571 (1176) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    18553658, /* 48572 (1176) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    18557868, /* 48573 (1176) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
    18544746, /* 48574 (1176) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
        7896, /* 48575 (1176) [ 0, -1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  0]  1 */
       16322, /* 48576 (1176) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    18553172, /* 48577 (1176) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 6,  6,  6]  1 */
       16484, /* 48578 (1177) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
       12270, /* 48579 (1177) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    52451996, /* 48580 (1177) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
    18544584, /* 48581 (1177) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
    18549284, /* 48582 (1177) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 6,  6,  6]  1 */
       11784, /* 48583 (1177) [ 0,  1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    34146642, /* 48584 (1177) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
    34133682, /* 48585 (1177) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
    52451834, /* 48586 (1177) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
        7410, /* 48587 (1177) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    34142594, /* 48588 (1177) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    52438712, /* 48589 (1177) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
    34146804, /* 48590 (1177) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
    52443408, /* 48591 (1177) [ 0, -1,  0,  1,  0,  0,  0,  0, -1] [ 6,  6,  0] -1 */
    34137734, /* 48592 (1177) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  6] -1 */
        3362, /* 48593 (1177) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    52447296, /* 48594 (1177) [ 0,  1,  0, -1,  0,  0,  0,  0, -1] [ 6,  6,  0] -1 */
    34138220, /* 48595 (1177) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    34142108, /* 48596 (1177) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  6] -1 */
        3200, /* 48597 (1177) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    52447782, /* 48598 (1177) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 6,  6,  0] -1 */
    34133520, /* 48599 (1177) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
    52438874, /* 48600 (1177) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
    18557706, /* 48601 (1177) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
    18548798, /* 48602 (1177) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    18553658, /* 48603 (1177) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    18557868, /* 48604 (1177) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
    18544746, /* 48605 (1177) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
        7896, /* 48606 (1177) [ 0, -1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  0]  1 */
       16322, /* 48607 (1177) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    52442922, /* 48608 (1177) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 6,  6,  0] -1 */
    18553172, /* 48609 (1177) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 6,  6,  6]  1 */
       16484, /* 48610 (1178) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    52561020, /* 48611 (1178) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 6,  6,  6] -1 */
       12270, /* 48612 (1178) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    52561506, /* 48613 (1178) [ 0, -1,  0,  1,  0,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    18549284, /* 48614 (1178) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    18544584, /* 48615 (1178) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
       11784, /* 48616 (1178) [ 0,  1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    34028544, /* 48617 (1178) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    52570094, /* 48618 (1178) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    34024010, /* 48619 (1178) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  0] -1 */
        7410, /* 48620 (1178) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    34024496, /* 48621 (1178) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    52556810, /* 48622 (1178) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    34019636, /* 48623 (1178) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    52565394, /* 48624 (1178) [ 0,  1,  0, -1,  0,  0,  0,  0, -1] [ 6,  6,  6] -1 */
        3362, /* 48625 (1178) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34028706, /* 48626 (1178) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    34015422, /* 48627 (1178) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
        3200, /* 48628 (1178) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34015584, /* 48629 (1178) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    34020122, /* 48630 (1178) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    52556972, /* 48631 (1178) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    52565880, /* 48632 (1178) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    52569932, /* 48633 (1178) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    18557706, /* 48634 (1178) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
    18548798, /* 48635 (1178) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    18553658, /* 48636 (1178) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    18557868, /* 48637 (1178) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
    18544746, /* 48638 (1178) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
        7896, /* 48639 (1178) [ 0, -1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  0]  1 */
       16322, /* 48640 (1178) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    18553172, /* 48641 (1178) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 6,  6,  6]  1 */
       16484, /* 48642 (1167) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    18426488, /* 48643 (1167) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
      125508, /* 48644 (1167) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  6]  1 */
    18553656, /* 48645 (1167) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 6,  6,  6]  1 */
     1547060, /* 48646 (1167) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 0,  6,  6]  1 */
     1543170, /* 48647 (1167) [ 0, -1,  0,  1,  0,  0,  0,  0, -1] [ 0,  6,  6]  1 */
    17135994, /* 48648 (1167) [ 0,  1,  0, -1,  0,  0,  0,  0, -1] [ 6,  0,  6]  1 */
        3198, /* 48649 (1167) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    17132108, /* 48650 (1167) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 6,  0,  6]  1 */
    17022432, /* 48651 (1167) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  0]  1 */
      130370, /* 48652 (1167) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 0,  0,  6]  1 */
    17009474, /* 48653 (1167) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  0]  1 */
    18439770, /* 48654 (1167) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
     1420536, /* 48655 (1167) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  0]  1 */
     1433498, /* 48656 (1167) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  0]  1 */
    18548798, /* 48657 (1167) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 6,  6,  6]  1 */
       16484, /* 48658 (1168) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34137732, /* 48659 (1168) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  6] -1 */
    18553656, /* 48660 (1168) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 6,  6,  6]  1 */
    17132108, /* 48661 (1168) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 6,  0,  6]  1 */
        3198, /* 48662 (1168) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    17135994, /* 48663 (1168) [ 0,  1,  0, -1,  0,  0,  0,  0, -1] [ 6,  0,  6]  1 */
      125508, /* 48664 (1168) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  6]  1 */
    51021698, /* 48665 (1168) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  0] -1 */
    52438712, /* 48666 (1168) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
    34028708, /* 48667 (1168) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    34142594, /* 48668 (1168) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    35555394, /* 48669 (1168) [ 0, -1,  0,  1,  0,  0,  0,  0, -1] [ 0,  6,  6] -1 */
    51034656, /* 48670 (1168) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  0] -1 */
    35432760, /* 48671 (1168) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  0] -1 */
    52451994, /* 48672 (1168) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
    35445722, /* 48673 (1168) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  0] -1 */
    52561022, /* 48674 (1168) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    17009474, /* 48675 (1168) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  0]  1 */
    35559284, /* 48676 (1168) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 0,  6,  6] -1 */
    52565880, /* 48677 (1168) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    18426488, /* 48678 (1168) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    51148218, /* 48679 (1168) [ 0,  1,  0, -1,  0,  0,  0,  0, -1] [ 6,  0,  6] -1 */
    34015422, /* 48680 (1168) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    51144332, /* 48681 (1168) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 6,  0,  6] -1 */
    17022432, /* 48682 (1168) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  0]  1 */
    18548798, /* 48683 (1168) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 6,  6,  6]  1 */
      130370, /* 48684 (1168) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 0,  0,  6]  1 */
    18439770, /* 48685 (1168) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
     1420536, /* 48686 (1168) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  0]  1 */
     1543170, /* 48687 (1168) [ 0, -1,  0,  1,  0,  0,  0,  0, -1] [ 0,  6,  6]  1 */
     1433498, /* 48688 (1168) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  0]  1 */
     1547060, /* 48689 (1168) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 0,  6,  6]  1 */
       16484, /* 48690 (1169) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    18426488, /* 48691 (1169) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    34137732, /* 48692 (1169) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  6] -1 */
    51148218, /* 48693 (1169) [ 0,  1,  0, -1,  0,  0,  0,  0, -1] [ 6,  0,  6] -1 */
    34015422, /* 48694 (1169) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    35555394, /* 48695 (1169) [ 0, -1,  0,  1,  0,  0,  0,  0, -1] [ 0,  6,  6] -1 */
    51034656, /* 48696 (1169) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  0] -1 */
     1547060, /* 48697 (1169) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 0,  6,  6]  1 */
    35432760, /* 48698 (1169) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  0] -1 */
    52451994, /* 48699 (1169) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
    17132108, /* 48700 (1169) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 6,  0,  6]  1 */
    18548798, /* 48701 (1169) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 6,  6,  6]  1 */
      130370, /* 48702 (1169) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 0,  0,  6]  1 */
    17009474, /* 48703 (1169) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  0]  1 */
     1433498, /* 48704 (1169) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  0]  1 */
    52565880, /* 48705 (1169) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 6,  6,  6] -1 */
       16484, /* 48706 (1170) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    18426488, /* 48707 (1170) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    51148218, /* 48708 (1170) [ 0,  1,  0, -1,  0,  0,  0,  0, -1] [ 6,  0,  6] -1 */
    51021698, /* 48709 (1170) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  0] -1 */
      125508, /* 48710 (1170) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  6]  1 */
    51144332, /* 48711 (1170) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 6,  0,  6] -1 */
    51034656, /* 48712 (1170) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  0] -1 */
    18553656, /* 48713 (1170) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 6,  6,  6]  1 */
    35432760, /* 48714 (1170) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  0] -1 */
    35555394, /* 48715 (1170) [ 0, -1,  0,  1,  0,  0,  0,  0, -1] [ 0,  6,  6] -1 */
        3198, /* 48716 (1170) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    35445722, /* 48717 (1170) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  0] -1 */
      130370, /* 48718 (1170) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 0,  0,  6]  1 */
    18439770, /* 48719 (1170) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
    35559284, /* 48720 (1170) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 0,  6,  6] -1 */
    18548798, /* 48721 (1170) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 6,  6,  6]  1 */
       16484, /* 48722 (1171) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    18426488, /* 48723 (1171) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    34137732, /* 48724 (1171) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  6] -1 */
    51148218, /* 48725 (1171) [ 0,  1,  0, -1,  0,  0,  0,  0, -1] [ 6,  0,  6] -1 */
    34142594, /* 48726 (1171) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    51144332, /* 48727 (1171) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 6,  0,  6] -1 */
    35555394, /* 48728 (1171) [ 0, -1,  0,  1,  0,  0,  0,  0, -1] [ 0,  6,  6] -1 */
        3198, /* 48729 (1171) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    17022432, /* 48730 (1171) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  0]  1 */
     1420536, /* 48731 (1171) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  0]  1 */
    52561022, /* 48732 (1171) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    17009474, /* 48733 (1171) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  0]  1 */
    18439770, /* 48734 (1171) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
    35559284, /* 48735 (1171) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 0,  6,  6] -1 */
     1433498, /* 48736 (1171) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  0]  1 */
    52565880, /* 48737 (1171) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 6,  6,  6] -1 */
       16484, /* 48738 (1172) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    18426488, /* 48739 (1172) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    34137732, /* 48740 (1172) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  6] -1 */
    34015422, /* 48741 (1172) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    51021698, /* 48742 (1172) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  0] -1 */
    51144332, /* 48743 (1172) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 6,  0,  6] -1 */
    52451994, /* 48744 (1172) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
    17135994, /* 48745 (1172) [ 0,  1,  0, -1,  0,  0,  0,  0, -1] [ 6,  0,  6]  1 */
    17022432, /* 48746 (1172) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  0]  1 */
    35445722, /* 48747 (1172) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  0] -1 */
     1420536, /* 48748 (1172) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  0]  1 */
    35559284, /* 48749 (1172) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 0,  6,  6] -1 */
    18548798, /* 48750 (1172) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 6,  6,  6]  1 */
      130370, /* 48751 (1172) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 0,  0,  6]  1 */
     1543170, /* 48752 (1172) [ 0, -1,  0,  1,  0,  0,  0,  0, -1] [ 0,  6,  6]  1 */
    52565880, /* 48753 (1172) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 6,  6,  6] -1 */
       16484, /* 48754 (1173) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    18426488, /* 48755 (1173) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    34137732, /* 48756 (1173) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  6] -1 */
    34142594, /* 48757 (1173) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    51021698, /* 48758 (1173) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  0] -1 */
    51034656, /* 48759 (1173) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  0] -1 */
     1547060, /* 48760 (1173) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 0,  6,  6]  1 */
    35432760, /* 48761 (1173) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  0] -1 */
    17135994, /* 48762 (1173) [ 0,  1,  0, -1,  0,  0,  0,  0, -1] [ 6,  0,  6]  1 */
        3198, /* 48763 (1173) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    17132108, /* 48764 (1173) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 6,  0,  6]  1 */
    35445722, /* 48765 (1173) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  0] -1 */
    52561022, /* 48766 (1173) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    18439770, /* 48767 (1173) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
     1543170, /* 48768 (1173) [ 0, -1,  0,  1,  0,  0,  0,  0, -1] [ 0,  6,  6]  1 */
    52565880, /* 48769 (1173) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 6,  6,  6] -1 */
       16484, /* 48770 (1174) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    18426488, /* 48771 (1174) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    34015422, /* 48772 (1174) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    34142594, /* 48773 (1174) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 0,  0,  6] -1 */
      125508, /* 48774 (1174) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  6]  1 */
    51144332, /* 48775 (1174) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 6,  0,  6] -1 */
    51034656, /* 48776 (1174) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  0] -1 */
    18553656, /* 48777 (1174) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 6,  6,  6]  1 */
    35432760, /* 48778 (1174) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  0] -1 */
    52451994, /* 48779 (1174) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
    17135994, /* 48780 (1174) [ 0,  1,  0, -1,  0,  0,  0,  0, -1] [ 6,  0,  6]  1 */
    35559284, /* 48781 (1174) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 0,  6,  6] -1 */
    17009474, /* 48782 (1174) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  0]  1 */
    52561022, /* 48783 (1174) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 6,  6,  6] -1 */
     1543170, /* 48784 (1174) [ 0, -1,  0,  1,  0,  0,  0,  0, -1] [ 0,  6,  6]  1 */
     1433498, /* 48785 (1174) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  0]  1 */
       16484, /* 48786 (1175) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    18426488, /* 48787 (1175) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    51148218, /* 48788 (1175) [ 0,  1,  0, -1,  0,  0,  0,  0, -1] [ 6,  0,  6] -1 */
    34015422, /* 48789 (1175) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    34142594, /* 48790 (1175) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 0,  0,  6] -1 */
      125508, /* 48791 (1175) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  6]  1 */
    51021698, /* 48792 (1175) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  0] -1 */
    18553656, /* 48793 (1175) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 6,  6,  6]  1 */
    35555394, /* 48794 (1175) [ 0, -1,  0,  1,  0,  0,  0,  0, -1] [ 0,  6,  6] -1 */
    52451994, /* 48795 (1175) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
    17132108, /* 48796 (1175) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 6,  0,  6]  1 */
    17022432, /* 48797 (1175) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  0]  1 */
    35445722, /* 48798 (1175) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  0] -1 */
     1420536, /* 48799 (1175) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  0]  1 */
    52561022, /* 48800 (1175) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 6,  6,  6] -1 */
     1547060, /* 48801 (1175) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 0,  6,  6]  1 */
       16484, /* 48802 (1176) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34019634, /* 48803 (1176) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    51030120, /* 48804 (1176) [ 0,  1,  0, -1,  0,  0,  0,  0, -1] [ 6,  0,  0] -1 */
    18553656, /* 48805 (1176) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 6,  6,  6]  1 */
    17132108, /* 48806 (1176) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 6,  0,  6]  1 */
        3198, /* 48807 (1176) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    17135994, /* 48808 (1176) [ 0,  1,  0, -1,  0,  0,  0,  0, -1] [ 6,  0,  6]  1 */
    51152754, /* 48809 (1176) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  6] -1 */
    51026234, /* 48810 (1176) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 6,  0,  0] -1 */
      125508, /* 48811 (1176) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  6]  1 */
    34146806, /* 48812 (1176) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    34024496, /* 48813 (1176) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    35437296, /* 48814 (1176) [ 0, -1,  0,  1,  0,  0,  0,  0, -1] [ 0,  6,  0] -1 */
    52556810, /* 48815 (1176) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    52442924, /* 48816 (1176) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 6,  6,  0] -1 */
    52447782, /* 48817 (1176) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 6,  6,  0] -1 */
    17009474, /* 48818 (1176) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  0]  1 */
    35550858, /* 48819 (1176) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6] -1 */
    52570092, /* 48820 (1176) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    35441186, /* 48821 (1176) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 0,  6,  0] -1 */
    35563820, /* 48822 (1176) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
    18426488, /* 48823 (1176) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    34133520, /* 48824 (1176) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
    51139796, /* 48825 (1176) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
    17022432, /* 48826 (1176) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  0]  1 */
    18548798, /* 48827 (1176) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 6,  6,  6]  1 */
      130370, /* 48828 (1176) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 0,  0,  6]  1 */
    18439770, /* 48829 (1176) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
     1420536, /* 48830 (1176) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  0]  1 */
     1543170, /* 48831 (1176) [ 0, -1,  0,  1,  0,  0,  0,  0, -1] [ 0,  6,  6]  1 */
     1433498, /* 48832 (1176) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  0]  1 */
     1547060, /* 48833 (1176) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 0,  6,  6]  1 */
       16484, /* 48834 (1177) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    18553656, /* 48835 (1177) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 6,  6,  6]  1 */
    52451996, /* 48836 (1177) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
        3198, /* 48837 (1177) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    17132108, /* 48838 (1177) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 6,  0,  6]  1 */
    17135994, /* 48839 (1177) [ 0,  1,  0, -1,  0,  0,  0,  0, -1] [ 6,  0,  6]  1 */
    35445720, /* 48840 (1177) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  0] -1 */
    51021696, /* 48841 (1177) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  0] -1 */
    51034658, /* 48842 (1177) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  0] -1 */
      125508, /* 48843 (1177) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  6]  1 */
    52565882, /* 48844 (1177) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    34015424, /* 48845 (1177) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    34028706, /* 48846 (1177) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    51144330, /* 48847 (1177) [ 0, -1,  0,  1,  0,  0,  0,  0, -1] [ 6,  0,  6] -1 */
    34137734, /* 48848 (1177) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    17009474, /* 48849 (1177) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  0]  1 */
    35559282, /* 48850 (1177) [ 0,  1,  0, -1,  0,  0,  0,  0, -1] [ 0,  6,  6] -1 */
    35555396, /* 48851 (1177) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 0,  6,  6] -1 */
    51148220, /* 48852 (1177) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 6,  0,  6] -1 */
    18426488, /* 48853 (1177) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    34142592, /* 48854 (1177) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  6] -1 */
    52438710, /* 48855 (1177) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
    35432762, /* 48856 (1177) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  0] -1 */
    17022432, /* 48857 (1177) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  0]  1 */
    18548798, /* 48858 (1177) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 6,  6,  6]  1 */
      130370, /* 48859 (1177) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 0,  0,  6]  1 */
    18439770, /* 48860 (1177) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
     1420536, /* 48861 (1177) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  0]  1 */
     1543170, /* 48862 (1177) [ 0, -1,  0,  1,  0,  0,  0,  0, -1] [ 0,  6,  6]  1 */
     1433498, /* 48863 (1177) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  0]  1 */
    52561020, /* 48864 (1177) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 6,  6,  6] -1 */
     1547060, /* 48865 (1177) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 0,  6,  6]  1 */
       16484, /* 48866 (1178) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    52442922, /* 48867 (1178) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 6,  6,  0] -1 */
    18553656, /* 48868 (1178) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 6,  6,  6]  1 */
    51026232, /* 48869 (1178) [ 0, -1,  0,  1,  0,  0,  0,  0, -1] [ 6,  0,  0] -1 */
    17132108, /* 48870 (1178) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 6,  0,  6]  1 */
        3198, /* 48871 (1178) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    17135994, /* 48872 (1178) [ 0,  1,  0, -1,  0,  0,  0,  0, -1] [ 6,  0,  6]  1 */
    35563818, /* 48873 (1178) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  6] -1 */
    52570094, /* 48874 (1178) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    51030122, /* 48875 (1178) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 6,  0,  0] -1 */
      125508, /* 48876 (1178) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  6]  1 */
    52447784, /* 48877 (1178) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 6,  6,  0] -1 */
    34133522, /* 48878 (1178) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    34019636, /* 48879 (1178) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    35441184, /* 48880 (1178) [ 0,  1,  0, -1,  0,  0,  0,  0, -1] [ 0,  6,  0] -1 */
    17009474, /* 48881 (1178) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  0]  1 */
    34146804, /* 48882 (1178) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
    52556808, /* 48883 (1178) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    18426488, /* 48884 (1178) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    51139794, /* 48885 (1178) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6] -1 */
    35437298, /* 48886 (1178) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 0,  6,  0] -1 */
    35550860, /* 48887 (1178) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
    34024494, /* 48888 (1178) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    51152756, /* 48889 (1178) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
    17022432, /* 48890 (1178) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  0]  1 */
    18548798, /* 48891 (1178) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 6,  6,  6]  1 */
      130370, /* 48892 (1178) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 0,  0,  6]  1 */
    18439770, /* 48893 (1178) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
     1420536, /* 48894 (1178) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  0]  1 */
     1543170, /* 48895 (1178) [ 0, -1,  0,  1,  0,  0,  0,  0, -1] [ 0,  6,  6]  1 */
     1433498, /* 48896 (1178) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  0]  1 */
     1547060, /* 48897 (1178) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 0,  6,  6]  1 */
       16484, /* 48898 (1179) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
        3200, /* 48899 (1179) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
      130368, /* 48900 (1179) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  6]  1 */
    18435560, /* 48901 (1179) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 6,  6,  0]  1 */
      134420, /* 48902 (1179) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6]  1 */
      125508, /* 48903 (1179) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  6]  1 */
    18426648, /* 48904 (1179) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
       11784, /* 48905 (1179) [ 0,  1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    18544584, /* 48906 (1179) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
    18549284, /* 48907 (1179) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    18430700, /* 48908 (1179) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    18557868, /* 48909 (1179) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
        7896, /* 48910 (1179) [ 0, -1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    18439608, /* 48911 (1179) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
    18553172, /* 48912 (1179) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 6,  6,  6]  1 */
      121460, /* 48913 (1179) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6]  1 */
       16484, /* 48914 (1180) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34137732, /* 48915 (1180) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  6] -1 */
      134420, /* 48916 (1180) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6]  1 */
    18549284, /* 48917 (1180) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    18544584, /* 48918 (1180) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
       11784, /* 48919 (1180) [ 0,  1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    52451832, /* 48920 (1180) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
      121460, /* 48921 (1180) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6]  1 */
      125508, /* 48922 (1180) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  6]  1 */
    34015424, /* 48923 (1180) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    34028708, /* 48924 (1180) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    18439608, /* 48925 (1180) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
    52447784, /* 48926 (1180) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 6,  6,  0] -1 */
    52442924, /* 48927 (1180) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 6,  6,  0] -1 */
    34020120, /* 48928 (1180) [ 0, -1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    52570092, /* 48929 (1180) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    34142592, /* 48930 (1180) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  6] -1 */
    52565396, /* 48931 (1180) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    52438872, /* 48932 (1180) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
    34146644, /* 48933 (1180) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
        3200, /* 48934 (1180) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34024008, /* 48935 (1180) [ 0,  1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    52556808, /* 48936 (1180) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    52561508, /* 48937 (1180) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    18435560, /* 48938 (1180) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    18426648, /* 48939 (1180) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
    18430700, /* 48940 (1180) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    34133684, /* 48941 (1180) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    18557868, /* 48942 (1180) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
        7896, /* 48943 (1180) [ 0, -1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    18553172, /* 48944 (1180) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 6,  6,  6]  1 */
      130368, /* 48945 (1180) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  6]  1 */
       16484, /* 48946 (1181) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
        3200, /* 48947 (1181) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34024008, /* 48948 (1181) [ 0,  1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    52556808, /* 48949 (1181) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    34137732, /* 48950 (1181) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  6] -1 */
    18435560, /* 48951 (1181) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    34020120, /* 48952 (1181) [ 0, -1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  0] -1 */
      134420, /* 48953 (1181) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6]  1 */
    52570092, /* 48954 (1181) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    18549284, /* 48955 (1181) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    34142592, /* 48956 (1181) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  6] -1 */
    18430700, /* 48957 (1181) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    52451832, /* 48958 (1181) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
    52438872, /* 48959 (1181) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
    18553172, /* 48960 (1181) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 6,  6,  6]  1 */
      121460, /* 48961 (1181) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6]  1 */
       16484, /* 48962 (1182) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
        3200, /* 48963 (1182) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34024008, /* 48964 (1182) [ 0,  1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    52561508, /* 48965 (1182) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    18435560, /* 48966 (1182) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    34020120, /* 48967 (1182) [ 0, -1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  0] -1 */
      125508, /* 48968 (1182) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  6]  1 */
    34133684, /* 48969 (1182) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    18544584, /* 48970 (1182) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
    18430700, /* 48971 (1182) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    52451832, /* 48972 (1182) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
    52565396, /* 48973 (1182) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    18557868, /* 48974 (1182) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
    52438872, /* 48975 (1182) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
    34146644, /* 48976 (1182) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
      130368, /* 48977 (1182) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  6]  1 */
       16484, /* 48978 (1183) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
        3200, /* 48979 (1183) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34024008, /* 48980 (1183) [ 0,  1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    34137732, /* 48981 (1183) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  6] -1 */
    52561508, /* 48982 (1183) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    52442924, /* 48983 (1183) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 6,  6,  0] -1 */
    34020120, /* 48984 (1183) [ 0, -1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  0] -1 */
      134420, /* 48985 (1183) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6]  1 */
    18426648, /* 48986 (1183) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
    34142592, /* 48987 (1183) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  6] -1 */
    18544584, /* 48988 (1183) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
    52565396, /* 48989 (1183) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    18557868, /* 48990 (1183) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
    18439608, /* 48991 (1183) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
    52447784, /* 48992 (1183) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 6,  6,  0] -1 */
      121460, /* 48993 (1183) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6]  1 */
       16484, /* 48994 (1184) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
        3200, /* 48995 (1184) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    52556808, /* 48996 (1184) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    34137732, /* 48997 (1184) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  6] -1 */
    52561508, /* 48998 (1184) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    18435560, /* 48999 (1184) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    52570092, /* 49000 (1184) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    34142592, /* 49001 (1184) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  6] -1 */
       11784, /* 49002 (1184) [ 0,  1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    34133684, /* 49003 (1184) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    18430700, /* 49004 (1184) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    52565396, /* 49005 (1184) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 6,  6,  6] -1 */
        7896, /* 49006 (1184) [ 0, -1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    18439608, /* 49007 (1184) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
    34146644, /* 49008 (1184) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    18426648, /* 49009 (1184) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
       16484, /* 49010 (1185) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
        3200, /* 49011 (1185) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34137732, /* 49012 (1185) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  6] -1 */
    52442924, /* 49013 (1185) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 6,  6,  0] -1 */
    18553172, /* 49014 (1185) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 6,  6,  6]  1 */
        7896, /* 49015 (1185) [ 0, -1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  0]  1 */
       11784, /* 49016 (1185) [ 0,  1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    18544584, /* 49017 (1185) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
    18549284, /* 49018 (1185) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    52451832, /* 49019 (1185) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
    34133684, /* 49020 (1185) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    34142592, /* 49021 (1185) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  6] -1 */
    18557868, /* 49022 (1185) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
    52438872, /* 49023 (1185) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
    52447784, /* 49024 (1185) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 6,  6,  0] -1 */
    34146644, /* 49025 (1185) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
       16484, /* 49026 (1186) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
        3200, /* 49027 (1186) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    52556808, /* 49028 (1186) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    52561508, /* 49029 (1186) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    52442924, /* 49030 (1186) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 6,  6,  0] -1 */
      134420, /* 49031 (1186) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6]  1 */
      125508, /* 49032 (1186) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  6]  1 */
    52570092, /* 49033 (1186) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
      121460, /* 49034 (1186) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6]  1 */
       11784, /* 49035 (1186) [ 0,  1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  0]  1 */
        7896, /* 49036 (1186) [ 0, -1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    52451832, /* 49037 (1186) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
    52565396, /* 49038 (1186) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    52438872, /* 49039 (1186) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
    52447784, /* 49040 (1186) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 6,  6,  0] -1 */
      130368, /* 49041 (1186) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  6]  1 */
       16484, /* 49042 (1187) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
        3200, /* 49043 (1187) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34024008, /* 49044 (1187) [ 0,  1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    52556808, /* 49045 (1187) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    52442924, /* 49046 (1187) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 6,  6,  0] -1 */
    34020120, /* 49047 (1187) [ 0, -1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  0] -1 */
      125508, /* 49048 (1187) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  6]  1 */
    18426648, /* 49049 (1187) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
    52570092, /* 49050 (1187) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    18549284, /* 49051 (1187) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    34133684, /* 49052 (1187) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    52447784, /* 49053 (1187) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 6,  6,  0] -1 */
    18439608, /* 49054 (1187) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
    18553172, /* 49055 (1187) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    34146644, /* 49056 (1187) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
      130368, /* 49057 (1187) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  6]  1 */
       16484, /* 49058 (1188) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34019634, /* 49059 (1188) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    34142106, /* 49060 (1188) [ 0,  1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  6] -1 */
      134420, /* 49061 (1188) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6]  1 */
    18549284, /* 49062 (1188) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    18544584, /* 49063 (1188) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
       11784, /* 49064 (1188) [ 0,  1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  0]  1 */
      121460, /* 49065 (1188) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6]  1 */
    52443410, /* 49066 (1188) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 6,  6,  0] -1 */
    34015586, /* 49067 (1188) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
      125508, /* 49068 (1188) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  6]  1 */
    34146806, /* 49069 (1188) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    18439608, /* 49070 (1188) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
    34138218, /* 49071 (1188) [ 0, -1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  6] -1 */
    34133522, /* 49072 (1188) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    52565882, /* 49073 (1188) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    52569930, /* 49074 (1188) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    52556970, /* 49075 (1188) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    34028546, /* 49076 (1188) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    52561022, /* 49077 (1188) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    52451994, /* 49078 (1188) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
    52447298, /* 49079 (1188) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 6,  6,  0] -1 */
    34024494, /* 49080 (1188) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  0] -1 */
        3200, /* 49081 (1188) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    18435560, /* 49082 (1188) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    52438710, /* 49083 (1188) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
    18426648, /* 49084 (1188) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
    18430700, /* 49085 (1188) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    18557868, /* 49086 (1188) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
        7896, /* 49087 (1188) [ 0, -1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    18553172, /* 49088 (1188) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 6,  6,  6]  1 */
      130368, /* 49089 (1188) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  6]  1 */
       16484, /* 49090 (1189) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    52561020, /* 49091 (1189) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 6,  6,  6] -1 */
      134420, /* 49092 (1189) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6]  1 */
    52451996, /* 49093 (1189) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
    18544584, /* 49094 (1189) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
    18549284, /* 49095 (1189) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 6,  6,  6]  1 */
       11784, /* 49096 (1189) [ 0,  1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    34028544, /* 49097 (1189) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
      121460, /* 49098 (1189) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6]  1 */
      125508, /* 49099 (1189) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  6]  1 */
    52438712, /* 49100 (1189) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
    18439608, /* 49101 (1189) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
    34024496, /* 49102 (1189) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    34019636, /* 49103 (1189) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    34146804, /* 49104 (1189) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
    52443408, /* 49105 (1189) [ 0, -1,  0,  1,  0,  0,  0,  0, -1] [ 6,  6,  0] -1 */
    52447296, /* 49106 (1189) [ 0,  1,  0, -1,  0,  0,  0,  0, -1] [ 6,  6,  0] -1 */
    34138220, /* 49107 (1189) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    34142108, /* 49108 (1189) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  6] -1 */
        3200, /* 49109 (1189) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34015584, /* 49110 (1189) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    34133520, /* 49111 (1189) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
    52569932, /* 49112 (1189) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    52556972, /* 49113 (1189) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    52565880, /* 49114 (1189) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    18435560, /* 49115 (1189) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    18426648, /* 49116 (1189) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
    18430700, /* 49117 (1189) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    18557868, /* 49118 (1189) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
        7896, /* 49119 (1189) [ 0, -1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    18553172, /* 49120 (1189) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 6,  6,  6]  1 */
      130368, /* 49121 (1189) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  6]  1 */
       16484, /* 49122 (1190) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    52561506, /* 49123 (1190) [ 0, -1,  0,  1,  0,  0,  0,  0, -1] [ 6,  6,  6] -1 */
      134420, /* 49124 (1190) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6]  1 */
    18549284, /* 49125 (1190) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    18544584, /* 49126 (1190) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
       11784, /* 49127 (1190) [ 0,  1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    34146642, /* 49128 (1190) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
    34133682, /* 49129 (1190) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
    52570094, /* 49130 (1190) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
      121460, /* 49131 (1190) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6]  1 */
    52451834, /* 49132 (1190) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
    34024010, /* 49133 (1190) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  0] -1 */
      125508, /* 49134 (1190) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  6]  1 */
    34142594, /* 49135 (1190) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    18439608, /* 49136 (1190) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
    52556810, /* 49137 (1190) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    52565394, /* 49138 (1190) [ 0,  1,  0, -1,  0,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    34137734, /* 49139 (1190) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    34028706, /* 49140 (1190) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    34015422, /* 49141 (1190) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
        3200, /* 49142 (1190) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    52447782, /* 49143 (1190) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 6,  6,  0] -1 */
    34020122, /* 49144 (1190) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    18435560, /* 49145 (1190) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    52438874, /* 49146 (1190) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
    18426648, /* 49147 (1190) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
    18430700, /* 49148 (1190) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    18557868, /* 49149 (1190) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
        7896, /* 49150 (1190) [ 0, -1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    52442922, /* 49151 (1190) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 6,  6,  0] -1 */
    18553172, /* 49152 (1190) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 6,  6,  6]  1 */
      130368, /* 49153 (1190) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  6]  1 */
       16484, /* 49154 (1179) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    18426488, /* 49155 (1179) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    18435558, /* 49156 (1179) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 6,  6,  0]  1 */
       12272, /* 49157 (1179) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 0,  0,  0]  1 */
     1551596, /* 49158 (1179) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
        7410, /* 49159 (1179) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  0]  1 */
     1538634, /* 49160 (1179) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
    17135994, /* 49161 (1179) [ 0,  1,  0, -1,  0,  0,  0,  0, -1] [ 6,  0,  6]  1 */
        3198, /* 49162 (1179) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    17132108, /* 49163 (1179) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 6,  0,  6]  1 */
    18430700, /* 49164 (1179) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    18439770, /* 49165 (1179) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
     1543170, /* 49166 (1179) [ 0, -1,  0,  1,  0,  0,  0,  0, -1] [ 0,  6,  6]  1 */
    17140530, /* 49167 (1179) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  6]  1 */
     1547060, /* 49168 (1179) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 0,  6,  6]  1 */
    17127572, /* 49169 (1179) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
       16484, /* 49170 (1180) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34019634, /* 49171 (1180) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  0] -1 */
     1551596, /* 49172 (1180) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
    17132108, /* 49173 (1180) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 6,  0,  6]  1 */
        3198, /* 49174 (1180) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    17135994, /* 49175 (1180) [ 0,  1,  0, -1,  0,  0,  0,  0, -1] [ 6,  0,  6]  1 */
    51152754, /* 49176 (1180) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  6] -1 */
    17127572, /* 49177 (1180) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
        7410, /* 49178 (1180) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    52438712, /* 49179 (1180) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
    34028708, /* 49180 (1180) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    17140530, /* 49181 (1180) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  6]  1 */
    34024496, /* 49182 (1180) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    52442924, /* 49183 (1180) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 6,  6,  0] -1 */
    35555394, /* 49184 (1180) [ 0, -1,  0,  1,  0,  0,  0,  0, -1] [ 0,  6,  6] -1 */
    52451994, /* 49185 (1180) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
    52447782, /* 49186 (1180) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 6,  6,  0] -1 */
    35559284, /* 49187 (1180) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 0,  6,  6] -1 */
    35550858, /* 49188 (1180) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6] -1 */
    35563820, /* 49189 (1180) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
    18426488, /* 49190 (1180) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    51148218, /* 49191 (1180) [ 0,  1,  0, -1,  0,  0,  0,  0, -1] [ 6,  0,  6] -1 */
    34015422, /* 49192 (1180) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    51144332, /* 49193 (1180) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 6,  0,  6] -1 */
       12272, /* 49194 (1180) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 0,  0,  0]  1 */
     1538634, /* 49195 (1180) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
    18430700, /* 49196 (1180) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    51139796, /* 49197 (1180) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
    18439770, /* 49198 (1180) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
     1543170, /* 49199 (1180) [ 0, -1,  0,  1,  0,  0,  0,  0, -1] [ 0,  6,  6]  1 */
     1547060, /* 49200 (1180) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 0,  6,  6]  1 */
    18435558, /* 49201 (1180) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 6,  6,  0]  1 */
       16484, /* 49202 (1181) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    18426488, /* 49203 (1181) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    51148218, /* 49204 (1181) [ 0,  1,  0, -1,  0,  0,  0,  0, -1] [ 6,  0,  6] -1 */
    34015422, /* 49205 (1181) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    34019634, /* 49206 (1181) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  0] -1 */
       12272, /* 49207 (1181) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    35555394, /* 49208 (1181) [ 0, -1,  0,  1,  0,  0,  0,  0, -1] [ 0,  6,  6] -1 */
     1551596, /* 49209 (1181) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
    52451994, /* 49210 (1181) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
    17132108, /* 49211 (1181) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 6,  0,  6]  1 */
    52447782, /* 49212 (1181) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 6,  6,  0] -1 */
    18430700, /* 49213 (1181) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    51152754, /* 49214 (1181) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  6] -1 */
    35550858, /* 49215 (1181) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6] -1 */
     1547060, /* 49216 (1181) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 0,  6,  6]  1 */
    17127572, /* 49217 (1181) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
       16484, /* 49218 (1182) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    18426488, /* 49219 (1182) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    51148218, /* 49220 (1182) [ 0,  1,  0, -1,  0,  0,  0,  0, -1] [ 6,  0,  6] -1 */
    51144332, /* 49221 (1182) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 6,  0,  6] -1 */
       12272, /* 49222 (1182) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    35555394, /* 49223 (1182) [ 0, -1,  0,  1,  0,  0,  0,  0, -1] [ 0,  6,  6] -1 */
        7410, /* 49224 (1182) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    51139796, /* 49225 (1182) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
        3198, /* 49226 (1182) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    18430700, /* 49227 (1182) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    51152754, /* 49228 (1182) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  6] -1 */
    35559284, /* 49229 (1182) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 0,  6,  6] -1 */
    18439770, /* 49230 (1182) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
    35550858, /* 49231 (1182) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6] -1 */
    35563820, /* 49232 (1182) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
    18435558, /* 49233 (1182) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 6,  6,  0]  1 */
       16484, /* 49234 (1183) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    18426488, /* 49235 (1183) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    51148218, /* 49236 (1183) [ 0,  1,  0, -1,  0,  0,  0,  0, -1] [ 6,  0,  6] -1 */
    34019634, /* 49237 (1183) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    51144332, /* 49238 (1183) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 6,  0,  6] -1 */
    52442924, /* 49239 (1183) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 6,  6,  0] -1 */
    35555394, /* 49240 (1183) [ 0, -1,  0,  1,  0,  0,  0,  0, -1] [ 0,  6,  6] -1 */
     1551596, /* 49241 (1183) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
     1538634, /* 49242 (1183) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
    52447782, /* 49243 (1183) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 6,  6,  0] -1 */
        3198, /* 49244 (1183) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    35559284, /* 49245 (1183) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 0,  6,  6] -1 */
    18439770, /* 49246 (1183) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
    17140530, /* 49247 (1183) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  6]  1 */
    34024496, /* 49248 (1183) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    17127572, /* 49249 (1183) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
       16484, /* 49250 (1184) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    18426488, /* 49251 (1184) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    34015422, /* 49252 (1184) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    34019634, /* 49253 (1184) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    51144332, /* 49254 (1184) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 6,  0,  6] -1 */
       12272, /* 49255 (1184) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    52451994, /* 49256 (1184) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
    52447782, /* 49257 (1184) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 6,  6,  0] -1 */
    17135994, /* 49258 (1184) [ 0,  1,  0, -1,  0,  0,  0,  0, -1] [ 6,  0,  6]  1 */
    51139796, /* 49259 (1184) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
    18430700, /* 49260 (1184) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    35559284, /* 49261 (1184) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 0,  6,  6] -1 */
     1543170, /* 49262 (1184) [ 0, -1,  0,  1,  0,  0,  0,  0, -1] [ 0,  6,  6]  1 */
    17140530, /* 49263 (1184) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  6]  1 */
    35563820, /* 49264 (1184) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
     1538634, /* 49265 (1184) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
       16484, /* 49266 (1185) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    18426488, /* 49267 (1185) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    34019634, /* 49268 (1185) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    52442924, /* 49269 (1185) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 6,  6,  0] -1 */
     1547060, /* 49270 (1185) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 0,  6,  6]  1 */
     1543170, /* 49271 (1185) [ 0, -1,  0,  1,  0,  0,  0,  0, -1] [ 0,  6,  6]  1 */
    17135994, /* 49272 (1185) [ 0,  1,  0, -1,  0,  0,  0,  0, -1] [ 6,  0,  6]  1 */
        3198, /* 49273 (1185) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    17132108, /* 49274 (1185) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 6,  0,  6]  1 */
    51152754, /* 49275 (1185) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  6] -1 */
    51139796, /* 49276 (1185) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
    52447782, /* 49277 (1185) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 6,  6,  0] -1 */
    18439770, /* 49278 (1185) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
    35550858, /* 49279 (1185) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6] -1 */
    34024496, /* 49280 (1185) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    35563820, /* 49281 (1185) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
       16484, /* 49282 (1186) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    18426488, /* 49283 (1186) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    34015422, /* 49284 (1186) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    51144332, /* 49285 (1186) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 6,  0,  6] -1 */
    52442924, /* 49286 (1186) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 6,  6,  0] -1 */
     1551596, /* 49287 (1186) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
        7410, /* 49288 (1186) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    52451994, /* 49289 (1186) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
    17127572, /* 49290 (1186) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
    17135994, /* 49291 (1186) [ 0,  1,  0, -1,  0,  0,  0,  0, -1] [ 6,  0,  6]  1 */
     1543170, /* 49292 (1186) [ 0, -1,  0,  1,  0,  0,  0,  0, -1] [ 0,  6,  6]  1 */
    51152754, /* 49293 (1186) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  6] -1 */
    35559284, /* 49294 (1186) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 0,  6,  6] -1 */
    35550858, /* 49295 (1186) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6] -1 */
    34024496, /* 49296 (1186) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    18435558, /* 49297 (1186) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 6,  6,  0]  1 */
       16484, /* 49298 (1187) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    18426488, /* 49299 (1187) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    51148218, /* 49300 (1187) [ 0,  1,  0, -1,  0,  0,  0,  0, -1] [ 6,  0,  6] -1 */
    34015422, /* 49301 (1187) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    52442924, /* 49302 (1187) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 6,  6,  0] -1 */
    35555394, /* 49303 (1187) [ 0, -1,  0,  1,  0,  0,  0,  0, -1] [ 0,  6,  6] -1 */
        7410, /* 49304 (1187) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  0]  1 */
     1538634, /* 49305 (1187) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
    52451994, /* 49306 (1187) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
    17132108, /* 49307 (1187) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 6,  0,  6]  1 */
    51139796, /* 49308 (1187) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
    34024496, /* 49309 (1187) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    17140530, /* 49310 (1187) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  6]  1 */
     1547060, /* 49311 (1187) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 0,  6,  6]  1 */
    35563820, /* 49312 (1187) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
    18435558, /* 49313 (1187) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 6,  6,  0]  1 */
       16484, /* 49314 (1188) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34137732, /* 49315 (1188) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  6] -1 */
    51030120, /* 49316 (1188) [ 0,  1,  0, -1,  0,  0,  0,  0, -1] [ 6,  0,  0] -1 */
     1551596, /* 49317 (1188) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
    17132108, /* 49318 (1188) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 6,  0,  6]  1 */
        3198, /* 49319 (1188) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    17135994, /* 49320 (1188) [ 0,  1,  0, -1,  0,  0,  0,  0, -1] [ 6,  0,  6]  1 */
    17127572, /* 49321 (1188) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
    51026234, /* 49322 (1188) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 6,  0,  0] -1 */
    51021698, /* 49323 (1188) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  0] -1 */
        7410, /* 49324 (1188) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    34146806, /* 49325 (1188) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    17140530, /* 49326 (1188) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  6]  1 */
    35437296, /* 49327 (1188) [ 0, -1,  0,  1,  0,  0,  0,  0, -1] [ 0,  6,  0] -1 */
    52556810, /* 49328 (1188) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    34142594, /* 49329 (1188) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    51034656, /* 49330 (1188) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  0] -1 */
    35432760, /* 49331 (1188) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  0] -1 */
    35445722, /* 49332 (1188) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  0] -1 */
    52561022, /* 49333 (1188) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    52570092, /* 49334 (1188) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    35441186, /* 49335 (1188) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 0,  6,  0] -1 */
    52565880, /* 49336 (1188) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    18426488, /* 49337 (1188) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
       12272, /* 49338 (1188) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34133520, /* 49339 (1188) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
     1538634, /* 49340 (1188) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
    18430700, /* 49341 (1188) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    18439770, /* 49342 (1188) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
     1543170, /* 49343 (1188) [ 0, -1,  0,  1,  0,  0,  0,  0, -1] [ 0,  6,  6]  1 */
     1547060, /* 49344 (1188) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 0,  6,  6]  1 */
    18435558, /* 49345 (1188) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 6,  6,  0]  1 */
       16484, /* 49346 (1189) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    52442922, /* 49347 (1189) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 6,  6,  0] -1 */
     1551596, /* 49348 (1189) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
    52451996, /* 49349 (1189) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
        3198, /* 49350 (1189) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    17132108, /* 49351 (1189) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 6,  0,  6]  1 */
    17135994, /* 49352 (1189) [ 0,  1,  0, -1,  0,  0,  0,  0, -1] [ 6,  0,  6]  1 */
    35563818, /* 49353 (1189) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  6] -1 */
    17127572, /* 49354 (1189) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
        7410, /* 49355 (1189) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    34015424, /* 49356 (1189) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    17140530, /* 49357 (1189) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  6]  1 */
    52447784, /* 49358 (1189) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 6,  6,  0] -1 */
    34019636, /* 49359 (1189) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    34028706, /* 49360 (1189) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    51144330, /* 49361 (1189) [ 0, -1,  0,  1,  0,  0,  0,  0, -1] [ 6,  0,  6] -1 */
    35559282, /* 49362 (1189) [ 0,  1,  0, -1,  0,  0,  0,  0, -1] [ 0,  6,  6] -1 */
    35555396, /* 49363 (1189) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 0,  6,  6] -1 */
    51148220, /* 49364 (1189) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 6,  0,  6] -1 */
    18426488, /* 49365 (1189) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    51139794, /* 49366 (1189) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6] -1 */
    52438710, /* 49367 (1189) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
    51152756, /* 49368 (1189) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
    35550860, /* 49369 (1189) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
    34024494, /* 49370 (1189) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  0] -1 */
       12272, /* 49371 (1189) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 0,  0,  0]  1 */
     1538634, /* 49372 (1189) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
    18430700, /* 49373 (1189) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    18439770, /* 49374 (1189) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
     1543170, /* 49375 (1189) [ 0, -1,  0,  1,  0,  0,  0,  0, -1] [ 0,  6,  6]  1 */
     1547060, /* 49376 (1189) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 0,  6,  6]  1 */
    18435558, /* 49377 (1189) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 6,  6,  0]  1 */
       16484, /* 49378 (1190) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    51026232, /* 49379 (1190) [ 0, -1,  0,  1,  0,  0,  0,  0, -1] [ 6,  0,  0] -1 */
     1551596, /* 49380 (1190) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
    17132108, /* 49381 (1190) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 6,  0,  6]  1 */
        3198, /* 49382 (1190) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    17135994, /* 49383 (1190) [ 0,  1,  0, -1,  0,  0,  0,  0, -1] [ 6,  0,  6]  1 */
    35445720, /* 49384 (1190) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  0] -1 */
    51021696, /* 49385 (1190) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  0] -1 */
    52570094, /* 49386 (1190) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    17127572, /* 49387 (1190) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
    51034658, /* 49388 (1190) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  0] -1 */
    51030122, /* 49389 (1190) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 6,  0,  0] -1 */
        7410, /* 49390 (1190) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    52565882, /* 49391 (1190) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    17140530, /* 49392 (1190) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  6]  1 */
    34133522, /* 49393 (1190) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    35441184, /* 49394 (1190) [ 0,  1,  0, -1,  0,  0,  0,  0, -1] [ 0,  6,  0] -1 */
    34137734, /* 49395 (1190) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    34146804, /* 49396 (1190) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
    52556808, /* 49397 (1190) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    18426488, /* 49398 (1190) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    34142592, /* 49399 (1190) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  6] -1 */
    35437298, /* 49400 (1190) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 0,  6,  0] -1 */
       12272, /* 49401 (1190) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    35432762, /* 49402 (1190) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  0] -1 */
     1538634, /* 49403 (1190) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
    18430700, /* 49404 (1190) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    18439770, /* 49405 (1190) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
     1543170, /* 49406 (1190) [ 0, -1,  0,  1,  0,  0,  0,  0, -1] [ 0,  6,  6]  1 */
    52561020, /* 49407 (1190) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 6,  6,  6] -1 */
     1547060, /* 49408 (1190) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 0,  6,  6]  1 */
    18435558, /* 49409 (1190) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 6,  6,  0]  1 */
       16484, /* 49410 (1191) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    18557868, /* 49411 (1191) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
    18544584, /* 49412 (1191) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
    18553656, /* 49413 (1191) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 6,  6,  6]  1 */
       16320, /* 49414 (1191) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
       12270, /* 49415 (1191) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  0]  1 */
        3198, /* 49416 (1191) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    18548796, /* 49417 (1191) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 6,  6,  6]  1 */
    18549282, /* 49418 (1191) [ 0, -1,  0,  1,  0,  0,  0,  0, -1] [ 6,  6,  6]  1 */
        7410, /* 49419 (1191) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    18544746, /* 49420 (1191) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
    18553170, /* 49421 (1191) [ 0,  1,  0, -1,  0,  0,  0,  0, -1] [ 6,  6,  6]  1 */
    18557870, /* 49422 (1191) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
       11784, /* 49423 (1191) [ 0,  1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    18553172, /* 49424 (1191) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 6,  6,  6]  1 */
        7896, /* 49425 (1191) [ 0, -1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    18549284, /* 49426 (1191) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 6,  6,  6]  1 */
       11786, /* 49427 (1191) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  0]  1 */
        3360, /* 49428 (1191) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
        7898, /* 49429 (1191) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    18557708, /* 49430 (1191) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    18544748, /* 49431 (1191) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    18553658, /* 49432 (1191) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 6,  6,  6]  1 */
       16322, /* 49433 (1191) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
        3200, /* 49434 (1191) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
        3362, /* 49435 (1191) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
       12272, /* 49436 (1191) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 0,  0,  0]  1 */
        7412, /* 49437 (1191) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    18544586, /* 49438 (1191) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    18548798, /* 49439 (1191) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 6,  6,  6]  1 */
       16482, /* 49440 (1191) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    18557706, /* 49441 (1191) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
       16484, /* 49442 (1192) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    18557868, /* 49443 (1192) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
    18544584, /* 49444 (1192) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
    34019634, /* 49445 (1192) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    52561506, /* 49446 (1192) [ 0, -1,  0,  1,  0,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    18553656, /* 49447 (1192) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 6,  6,  6]  1 */
       16320, /* 49448 (1192) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
       12270, /* 49449 (1192) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  0]  1 */
        3198, /* 49450 (1192) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    52556970, /* 49451 (1192) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    52565394, /* 49452 (1192) [ 0,  1,  0, -1,  0,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    52570094, /* 49453 (1192) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    34024008, /* 49454 (1192) [ 0,  1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    52565396, /* 49455 (1192) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    34020120, /* 49456 (1192) [ 0, -1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    52561508, /* 49457 (1192) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    34024010, /* 49458 (1192) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    18548796, /* 49459 (1192) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 6,  6,  6]  1 */
    34015584, /* 49460 (1192) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    52569932, /* 49461 (1192) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    18549282, /* 49462 (1192) [ 0, -1,  0,  1,  0,  0,  0,  0, -1] [ 6,  6,  6]  1 */
        7410, /* 49463 (1192) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    34020122, /* 49464 (1192) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    52556972, /* 49465 (1192) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    52565882, /* 49466 (1192) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    34015424, /* 49467 (1192) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    34028546, /* 49468 (1192) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    34028708, /* 49469 (1192) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    18544746, /* 49470 (1192) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
    34024496, /* 49471 (1192) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    18553170, /* 49472 (1192) [ 0,  1,  0, -1,  0,  0,  0,  0, -1] [ 6,  6,  6]  1 */
    34015586, /* 49473 (1192) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    18557870, /* 49474 (1192) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    52556810, /* 49475 (1192) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
       11784, /* 49476 (1192) [ 0,  1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    18553172, /* 49477 (1192) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 6,  6,  6]  1 */
        7896, /* 49478 (1192) [ 0, -1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    34019636, /* 49479 (1192) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    34028706, /* 49480 (1192) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    18549284, /* 49481 (1192) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 6,  6,  6]  1 */
       11786, /* 49482 (1192) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    52561022, /* 49483 (1192) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    52569930, /* 49484 (1192) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
        3360, /* 49485 (1192) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
        7898, /* 49486 (1192) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    18557708, /* 49487 (1192) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    18544748, /* 49488 (1192) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    34028544, /* 49489 (1192) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    18553658, /* 49490 (1192) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    52556808, /* 49491 (1192) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    52565880, /* 49492 (1192) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 6,  6,  6] -1 */
       16322, /* 49493 (1192) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    52570092, /* 49494 (1192) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    34015422, /* 49495 (1192) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
        3200, /* 49496 (1192) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
        3362, /* 49497 (1192) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34024494, /* 49498 (1192) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  0] -1 */
       12272, /* 49499 (1192) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 0,  0,  0]  1 */
        7412, /* 49500 (1192) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    18544586, /* 49501 (1192) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    18548798, /* 49502 (1192) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    52561020, /* 49503 (1192) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 6,  6,  6] -1 */
       16482, /* 49504 (1192) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    18557706, /* 49505 (1192) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
       16484, /* 49506 (1193) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    52561506, /* 49507 (1193) [ 0, -1,  0,  1,  0,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    34019634, /* 49508 (1193) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    52556970, /* 49509 (1193) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    52565394, /* 49510 (1193) [ 0,  1,  0, -1,  0,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    34024008, /* 49511 (1193) [ 0,  1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    34020120, /* 49512 (1193) [ 0, -1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    34015584, /* 49513 (1193) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    18557870, /* 49514 (1193) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    18553172, /* 49515 (1193) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    34028706, /* 49516 (1193) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    18549284, /* 49517 (1193) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 6,  6,  6]  1 */
       11786, /* 49518 (1193) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    52569930, /* 49519 (1193) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    18557708, /* 49520 (1193) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
        7898, /* 49521 (1193) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    52570092, /* 49522 (1193) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    18544748, /* 49523 (1193) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    52565880, /* 49524 (1193) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    34028544, /* 49525 (1193) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    52556808, /* 49526 (1193) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    18553658, /* 49527 (1193) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 6,  6,  6]  1 */
       16322, /* 49528 (1193) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34015422, /* 49529 (1193) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
        3200, /* 49530 (1193) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34024494, /* 49531 (1193) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  0] -1 */
        3362, /* 49532 (1193) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
       12272, /* 49533 (1193) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 0,  0,  0]  1 */
        7412, /* 49534 (1193) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    18544586, /* 49535 (1193) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    52561020, /* 49536 (1193) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    18548798, /* 49537 (1193) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 6,  6,  6]  1 */
       16484, /* 49538 (1194) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    18557868, /* 49539 (1194) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
    18544584, /* 49540 (1194) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
    52561506, /* 49541 (1194) [ 0, -1,  0,  1,  0,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    18553656, /* 49542 (1194) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 6,  6,  6]  1 */
       12270, /* 49543 (1194) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  0]  1 */
        3198, /* 49544 (1194) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    52556970, /* 49545 (1194) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    52565394, /* 49546 (1194) [ 0,  1,  0, -1,  0,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    34024008, /* 49547 (1194) [ 0,  1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    52565396, /* 49548 (1194) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    34020120, /* 49549 (1194) [ 0, -1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    52561508, /* 49550 (1194) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    34024010, /* 49551 (1194) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    18548796, /* 49552 (1194) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 6,  6,  6]  1 */
    34015584, /* 49553 (1194) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    52569932, /* 49554 (1194) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
        7410, /* 49555 (1194) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    34020122, /* 49556 (1194) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    52556972, /* 49557 (1194) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    34028546, /* 49558 (1194) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    34015586, /* 49559 (1194) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    18557870, /* 49560 (1194) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    52569930, /* 49561 (1194) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    34028544, /* 49562 (1194) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    18553658, /* 49563 (1194) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 6,  6,  6]  1 */
        3200, /* 49564 (1194) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
       12272, /* 49565 (1194) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 0,  0,  0]  1 */
        7412, /* 49566 (1194) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    18544586, /* 49567 (1194) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    18548798, /* 49568 (1194) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 6,  6,  6]  1 */
       16482, /* 49569 (1194) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
       16484, /* 49570 (1195) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    18557868, /* 49571 (1195) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
    18544584, /* 49572 (1195) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
    34019634, /* 49573 (1195) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    52561506, /* 49574 (1195) [ 0, -1,  0,  1,  0,  0,  0,  0, -1] [ 6,  6,  6] -1 */
       16320, /* 49575 (1195) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
        3198, /* 49576 (1195) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    52565394, /* 49577 (1195) [ 0,  1,  0, -1,  0,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    34024008, /* 49578 (1195) [ 0,  1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    52565396, /* 49579 (1195) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    34020120, /* 49580 (1195) [ 0, -1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    52561508, /* 49581 (1195) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    34024010, /* 49582 (1195) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    34020122, /* 49583 (1195) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    52565882, /* 49584 (1195) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    18544746, /* 49585 (1195) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
    34024496, /* 49586 (1195) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    18557870, /* 49587 (1195) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    34019636, /* 49588 (1195) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    52561022, /* 49589 (1195) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 6,  6,  6] -1 */
        3360, /* 49590 (1195) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    18557708, /* 49591 (1195) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    52565880, /* 49592 (1195) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    18544748, /* 49593 (1195) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
       16322, /* 49594 (1195) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
        3200, /* 49595 (1195) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
        3362, /* 49596 (1195) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34024494, /* 49597 (1195) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    18544586, /* 49598 (1195) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    52561020, /* 49599 (1195) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 6,  6,  6] -1 */
       16482, /* 49600 (1195) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    18557706, /* 49601 (1195) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
       16484, /* 49602 (1196) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34019634, /* 49603 (1196) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  0] -1 */
       16320, /* 49604 (1196) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    52565396, /* 49605 (1196) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    52561508, /* 49606 (1196) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    34024010, /* 49607 (1196) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    52569932, /* 49608 (1196) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    18549282, /* 49609 (1196) [ 0, -1,  0,  1,  0,  0,  0,  0, -1] [ 6,  6,  6]  1 */
    34020122, /* 49610 (1196) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    52556972, /* 49611 (1196) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    34028546, /* 49612 (1196) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    18544746, /* 49613 (1196) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
    18553170, /* 49614 (1196) [ 0,  1,  0, -1,  0,  0,  0,  0, -1] [ 6,  6,  6]  1 */
    34015586, /* 49615 (1196) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    18557870, /* 49616 (1196) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
       11784, /* 49617 (1196) [ 0,  1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  0]  1 */
        7896, /* 49618 (1196) [ 0, -1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    34028706, /* 49619 (1196) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
        3360, /* 49620 (1196) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    52570092, /* 49621 (1196) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    52565880, /* 49622 (1196) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    18553658, /* 49623 (1196) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    52556808, /* 49624 (1196) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    34015422, /* 49625 (1196) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
        3200, /* 49626 (1196) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34024494, /* 49627 (1196) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  0] -1 */
       12272, /* 49628 (1196) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 0,  0,  0]  1 */
        7412, /* 49629 (1196) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    18544586, /* 49630 (1196) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    52561020, /* 49631 (1196) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    18548798, /* 49632 (1196) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    18557706, /* 49633 (1196) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
       16484, /* 49634 (1197) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    18557868, /* 49635 (1197) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
    18544584, /* 49636 (1197) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
    34019634, /* 49637 (1197) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  0] -1 */
        3198, /* 49638 (1197) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    52556970, /* 49639 (1197) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    34015584, /* 49640 (1197) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    52569932, /* 49641 (1197) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    18549282, /* 49642 (1197) [ 0, -1,  0,  1,  0,  0,  0,  0, -1] [ 6,  6,  6]  1 */
    52556972, /* 49643 (1197) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    52565882, /* 49644 (1197) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    34028546, /* 49645 (1197) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    34024496, /* 49646 (1197) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    18553170, /* 49647 (1197) [ 0,  1,  0, -1,  0,  0,  0,  0, -1] [ 6,  6,  6]  1 */
    34015586, /* 49648 (1197) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    18557870, /* 49649 (1197) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
       11784, /* 49650 (1197) [ 0,  1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    34019636, /* 49651 (1197) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    18553172, /* 49652 (1197) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 6,  6,  6]  1 */
        7896, /* 49653 (1197) [ 0, -1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    18549284, /* 49654 (1197) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 6,  6,  6]  1 */
       11786, /* 49655 (1197) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    52561022, /* 49656 (1197) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    52569930, /* 49657 (1197) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
        7898, /* 49658 (1197) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    52565880, /* 49659 (1197) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    34028544, /* 49660 (1197) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
        3200, /* 49661 (1197) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34024494, /* 49662 (1197) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    18544586, /* 49663 (1197) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    52561020, /* 49664 (1197) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 6,  6,  6] -1 */
       16482, /* 49665 (1197) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
       16484, /* 49666 (1198) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    18553656, /* 49667 (1198) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 6,  6,  6]  1 */
       12270, /* 49668 (1198) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    52556970, /* 49669 (1198) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    52565396, /* 49670 (1198) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    52561508, /* 49671 (1198) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    34024010, /* 49672 (1198) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    18548796, /* 49673 (1198) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 6,  6,  6]  1 */
    34015584, /* 49674 (1198) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    18549282, /* 49675 (1198) [ 0, -1,  0,  1,  0,  0,  0,  0, -1] [ 6,  6,  6]  1 */
        7410, /* 49676 (1198) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    34020122, /* 49677 (1198) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    52565882, /* 49678 (1198) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    34024496, /* 49679 (1198) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    18553170, /* 49680 (1198) [ 0,  1,  0, -1,  0,  0,  0,  0, -1] [ 6,  6,  6]  1 */
    18557870, /* 49681 (1198) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
       11784, /* 49682 (1198) [ 0,  1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    34019636, /* 49683 (1198) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  0] -1 */
        7896, /* 49684 (1198) [ 0, -1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    34028706, /* 49685 (1198) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    52561022, /* 49686 (1198) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    52569930, /* 49687 (1198) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    18557708, /* 49688 (1198) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    52570092, /* 49689 (1198) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    18544748, /* 49690 (1198) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    34028544, /* 49691 (1198) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    52556808, /* 49692 (1198) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
       16322, /* 49693 (1198) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34015422, /* 49694 (1198) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
        3200, /* 49695 (1198) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
        3362, /* 49696 (1198) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    18544586, /* 49697 (1198) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
       16484, /* 49698 (1199) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    52561506, /* 49699 (1199) [ 0, -1,  0,  1,  0,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    18553656, /* 49700 (1199) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 6,  6,  6]  1 */
       16320, /* 49701 (1199) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
       12270, /* 49702 (1199) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    52565394, /* 49703 (1199) [ 0,  1,  0, -1,  0,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    34024008, /* 49704 (1199) [ 0,  1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    34020120, /* 49705 (1199) [ 0, -1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    18548796, /* 49706 (1199) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 6,  6,  6]  1 */
    52569932, /* 49707 (1199) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
        7410, /* 49708 (1199) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    52556972, /* 49709 (1199) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    52565882, /* 49710 (1199) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    34028546, /* 49711 (1199) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    18544746, /* 49712 (1199) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
    34024496, /* 49713 (1199) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    34015586, /* 49714 (1199) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    18557870, /* 49715 (1199) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    34019636, /* 49716 (1199) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    18553172, /* 49717 (1199) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    34028706, /* 49718 (1199) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    18549284, /* 49719 (1199) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 6,  6,  6]  1 */
       11786, /* 49720 (1199) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    52561022, /* 49721 (1199) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 6,  6,  6] -1 */
        3360, /* 49722 (1199) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
        7898, /* 49723 (1199) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    52570092, /* 49724 (1199) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    52556808, /* 49725 (1199) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    34015422, /* 49726 (1199) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
        3200, /* 49727 (1199) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    18544586, /* 49728 (1199) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    18557706, /* 49729 (1199) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
       16484, /* 49730 (1200) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34137732, /* 49731 (1200) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  6] -1 */
    18557868, /* 49732 (1200) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
    52442922, /* 49733 (1200) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 6,  6,  0] -1 */
    18544584, /* 49734 (1200) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
    18553656, /* 49735 (1200) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 6,  6,  6]  1 */
       16320, /* 49736 (1200) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    52443408, /* 49737 (1200) [ 0, -1,  0,  1,  0,  0,  0,  0, -1] [ 6,  6,  0] -1 */
       12270, /* 49738 (1200) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    52447298, /* 49739 (1200) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 6,  6,  0] -1 */
    52451996, /* 49740 (1200) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
        3198, /* 49741 (1200) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    52438872, /* 49742 (1200) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
    52443410, /* 49743 (1200) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 6,  6,  0] -1 */
    52447296, /* 49744 (1200) [ 0,  1,  0, -1,  0,  0,  0,  0, -1] [ 6,  6,  0] -1 */
    52451834, /* 49745 (1200) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
    34142108, /* 49746 (1200) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    18548796, /* 49747 (1200) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 6,  6,  6]  1 */
    52438874, /* 49748 (1200) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
    34146644, /* 49749 (1200) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    34138220, /* 49750 (1200) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 0,  0,  6] -1 */
        7410, /* 49751 (1200) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    34142106, /* 49752 (1200) [ 0,  1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  6] -1 */
    18549282, /* 49753 (1200) [ 0, -1,  0,  1,  0,  0,  0,  0, -1] [ 6,  6,  6]  1 */
    34138218, /* 49754 (1200) [ 0, -1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  6] -1 */
    34146806, /* 49755 (1200) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    34133684, /* 49756 (1200) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    34133682, /* 49757 (1200) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
    52438712, /* 49758 (1200) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
    18544746, /* 49759 (1200) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
    18553170, /* 49760 (1200) [ 0,  1,  0, -1,  0,  0,  0,  0, -1] [ 6,  6,  6]  1 */
    52447784, /* 49761 (1200) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 6,  6,  0] -1 */
    18557870, /* 49762 (1200) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    34133522, /* 49763 (1200) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    34142594, /* 49764 (1200) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 0,  0,  6] -1 */
       11784, /* 49765 (1200) [ 0,  1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    18553172, /* 49766 (1200) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 6,  6,  6]  1 */
        7896, /* 49767 (1200) [ 0, -1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    52442924, /* 49768 (1200) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 6,  6,  0] -1 */
    52451994, /* 49769 (1200) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
    52447782, /* 49770 (1200) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 6,  6,  0] -1 */
    34137734, /* 49771 (1200) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    18549284, /* 49772 (1200) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 6,  6,  6]  1 */
       11786, /* 49773 (1200) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34146642, /* 49774 (1200) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
        3360, /* 49775 (1200) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
        7898, /* 49776 (1200) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34146804, /* 49777 (1200) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
    18544748, /* 49778 (1200) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    18557708, /* 49779 (1200) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    52451832, /* 49780 (1200) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
    18553658, /* 49781 (1200) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 6,  6,  6]  1 */
       16322, /* 49782 (1200) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34142592, /* 49783 (1200) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  6] -1 */
    52438710, /* 49784 (1200) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
        3200, /* 49785 (1200) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
        3362, /* 49786 (1200) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
       12272, /* 49787 (1200) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34133520, /* 49788 (1200) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
        7412, /* 49789 (1200) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    18544586, /* 49790 (1200) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    18548798, /* 49791 (1200) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 6,  6,  6]  1 */
       16482, /* 49792 (1200) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    18557706, /* 49793 (1200) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
       16484, /* 49794 (1201) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    18557868, /* 49795 (1201) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
      134418, /* 49796 (1201) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  6]  1 */
    18544584, /* 49797 (1201) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
    18439608, /* 49798 (1201) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
      130368, /* 49799 (1201) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  6]  1 */
        3198, /* 49800 (1201) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
      125508, /* 49801 (1201) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  6]  1 */
    18549282, /* 49802 (1201) [ 0, -1,  0,  1,  0,  0,  0,  0, -1] [ 6,  6,  6]  1 */
    18430698, /* 49803 (1201) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 6,  6,  0]  1 */
    18553170, /* 49804 (1201) [ 0,  1,  0, -1,  0,  0,  0,  0, -1] [ 6,  6,  6]  1 */
    18426648, /* 49805 (1201) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
    18557870, /* 49806 (1201) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    18439610, /* 49807 (1201) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
       11784, /* 49808 (1201) [ 0,  1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    18553172, /* 49809 (1201) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 6,  6,  6]  1 */
        7896, /* 49810 (1201) [ 0, -1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    18426650, /* 49811 (1201) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    18549284, /* 49812 (1201) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 6,  6,  6]  1 */
       11786, /* 49813 (1201) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  0]  1 */
      134420, /* 49814 (1201) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6]  1 */
        7898, /* 49815 (1201) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 0,  0,  0]  1 */
      121460, /* 49816 (1201) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6]  1 */
      121458, /* 49817 (1201) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  6]  1 */
    18435560, /* 49818 (1201) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 6,  6,  0]  1 */
        3200, /* 49819 (1201) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    18430700, /* 49820 (1201) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    18544586, /* 49821 (1201) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
      130370, /* 49822 (1201) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 0,  0,  6]  1 */
      125510, /* 49823 (1201) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  6]  1 */
       16482, /* 49824 (1201) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    18435558, /* 49825 (1201) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 6,  6,  0]  1 */
       16484, /* 49826 (1202) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34137732, /* 49827 (1202) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  6] -1 */
    18557868, /* 49828 (1202) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
    52442922, /* 49829 (1202) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 6,  6,  0] -1 */
      134418, /* 49830 (1202) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  6]  1 */
    18544584, /* 49831 (1202) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
    18439608, /* 49832 (1202) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
    52561506, /* 49833 (1202) [ 0, -1,  0,  1,  0,  0,  0,  0, -1] [ 6,  6,  6] -1 */
      130368, /* 49834 (1202) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  6]  1 */
        3198, /* 49835 (1202) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    52565394, /* 49836 (1202) [ 0,  1,  0, -1,  0,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    52438872, /* 49837 (1202) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
    52570094, /* 49838 (1202) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    52451834, /* 49839 (1202) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
    34024008, /* 49840 (1202) [ 0,  1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    52565396, /* 49841 (1202) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    34020120, /* 49842 (1202) [ 0, -1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    52561508, /* 49843 (1202) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 6,  6,  6] -1 */
      125508, /* 49844 (1202) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  6]  1 */
    34024010, /* 49845 (1202) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    52438874, /* 49846 (1202) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
    34146644, /* 49847 (1202) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    18549282, /* 49848 (1202) [ 0, -1,  0,  1,  0,  0,  0,  0, -1] [ 6,  6,  6]  1 */
    18430698, /* 49849 (1202) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 6,  6,  0]  1 */
    34020122, /* 49850 (1202) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    34133684, /* 49851 (1202) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    34133682, /* 49852 (1202) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
    34015424, /* 49853 (1202) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    34028708, /* 49854 (1202) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    18553170, /* 49855 (1202) [ 0,  1,  0, -1,  0,  0,  0,  0, -1] [ 6,  6,  6]  1 */
    52447784, /* 49856 (1202) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 6,  6,  0] -1 */
    18426648, /* 49857 (1202) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
    18557870, /* 49858 (1202) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    52556810, /* 49859 (1202) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    34142594, /* 49860 (1202) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    18439610, /* 49861 (1202) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
       11784, /* 49862 (1202) [ 0,  1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    18553172, /* 49863 (1202) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 6,  6,  6]  1 */
        7896, /* 49864 (1202) [ 0, -1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    52442924, /* 49865 (1202) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 6,  6,  0] -1 */
    34028706, /* 49866 (1202) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    18426650, /* 49867 (1202) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    52447782, /* 49868 (1202) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 6,  6,  0] -1 */
    34137734, /* 49869 (1202) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    18549284, /* 49870 (1202) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 6,  6,  6]  1 */
       11786, /* 49871 (1202) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34146642, /* 49872 (1202) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
      134420, /* 49873 (1202) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6]  1 */
        7898, /* 49874 (1202) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    52570092, /* 49875 (1202) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    52451832, /* 49876 (1202) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
    52556808, /* 49877 (1202) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
      121460, /* 49878 (1202) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6]  1 */
    34142592, /* 49879 (1202) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  6] -1 */
    34015422, /* 49880 (1202) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
      121458, /* 49881 (1202) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  6]  1 */
        3200, /* 49882 (1202) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    18435560, /* 49883 (1202) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    18430700, /* 49884 (1202) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    18544586, /* 49885 (1202) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
      130370, /* 49886 (1202) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 0,  0,  6]  1 */
      125510, /* 49887 (1202) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  6]  1 */
       16482, /* 49888 (1202) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    18435558, /* 49889 (1202) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 6,  6,  0]  1 */
       16484, /* 49890 (1203) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34137732, /* 49891 (1203) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  6] -1 */
    52442922, /* 49892 (1203) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 6,  6,  0] -1 */
    52561506, /* 49893 (1203) [ 0, -1,  0,  1,  0,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    52565394, /* 49894 (1203) [ 0,  1,  0, -1,  0,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    52438872, /* 49895 (1203) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
    34024008, /* 49896 (1203) [ 0,  1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    34020120, /* 49897 (1203) [ 0, -1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    34133682, /* 49898 (1203) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
    18557870, /* 49899 (1203) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    18439610, /* 49900 (1203) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    18553172, /* 49901 (1203) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    34028706, /* 49902 (1203) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    52447782, /* 49903 (1203) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 6,  6,  0] -1 */
    18426650, /* 49904 (1203) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    18549284, /* 49905 (1203) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 6,  6,  6]  1 */
       11786, /* 49906 (1203) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34146642, /* 49907 (1203) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
      134420, /* 49908 (1203) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6]  1 */
        7898, /* 49909 (1203) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    52570092, /* 49910 (1203) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    52451832, /* 49911 (1203) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
    52556808, /* 49912 (1203) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    34142592, /* 49913 (1203) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  6] -1 */
      121460, /* 49914 (1203) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6]  1 */
    34015422, /* 49915 (1203) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    18435560, /* 49916 (1203) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 6,  6,  0]  1 */
        3200, /* 49917 (1203) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    18430700, /* 49918 (1203) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    18544586, /* 49919 (1203) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
      130370, /* 49920 (1203) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 0,  0,  6]  1 */
      125510, /* 49921 (1203) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  6]  1 */
       16484, /* 49922 (1204) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    18557868, /* 49923 (1204) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
    18544584, /* 49924 (1204) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
    52561506, /* 49925 (1204) [ 0, -1,  0,  1,  0,  0,  0,  0, -1] [ 6,  6,  6] -1 */
      130368, /* 49926 (1204) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  6]  1 */
        3198, /* 49927 (1204) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    52565394, /* 49928 (1204) [ 0,  1,  0, -1,  0,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    52438872, /* 49929 (1204) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
    52451834, /* 49930 (1204) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
    34024008, /* 49931 (1204) [ 0,  1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    52565396, /* 49932 (1204) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    34020120, /* 49933 (1204) [ 0, -1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    52561508, /* 49934 (1204) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 6,  6,  6] -1 */
      125508, /* 49935 (1204) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  6]  1 */
    34024010, /* 49936 (1204) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    52438874, /* 49937 (1204) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
    34146644, /* 49938 (1204) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    18430698, /* 49939 (1204) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 6,  6,  0]  1 */
    34020122, /* 49940 (1204) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    34133684, /* 49941 (1204) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    34133682, /* 49942 (1204) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
    18557870, /* 49943 (1204) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    34146642, /* 49944 (1204) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
    52451832, /* 49945 (1204) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
    18435560, /* 49946 (1204) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 6,  6,  0]  1 */
        3200, /* 49947 (1204) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    18430700, /* 49948 (1204) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    18544586, /* 49949 (1204) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
      130370, /* 49950 (1204) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 0,  0,  6]  1 */
      125510, /* 49951 (1204) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  6]  1 */
       16482, /* 49952 (1204) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    18435558, /* 49953 (1204) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 6,  6,  0]  1 */
       16484, /* 49954 (1205) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    52442922, /* 49955 (1205) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 6,  6,  0] -1 */
    34137732, /* 49956 (1205) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  6] -1 */
    18557868, /* 49957 (1205) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
      134418, /* 49958 (1205) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  6]  1 */
    18544584, /* 49959 (1205) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
    18439608, /* 49960 (1205) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
    52561506, /* 49961 (1205) [ 0, -1,  0,  1,  0,  0,  0,  0, -1] [ 6,  6,  6] -1 */
        3198, /* 49962 (1205) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    52565394, /* 49963 (1205) [ 0,  1,  0, -1,  0,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    34024008, /* 49964 (1205) [ 0,  1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    52565396, /* 49965 (1205) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    34020120, /* 49966 (1205) [ 0, -1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    52561508, /* 49967 (1205) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    34024010, /* 49968 (1205) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    34020122, /* 49969 (1205) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    52447784, /* 49970 (1205) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 6,  6,  0] -1 */
    18426648, /* 49971 (1205) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
    18557870, /* 49972 (1205) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    34142594, /* 49973 (1205) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    18439610, /* 49974 (1205) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    52442924, /* 49975 (1205) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 6,  6,  0] -1 */
    18426650, /* 49976 (1205) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    52447782, /* 49977 (1205) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 6,  6,  0] -1 */
    34137734, /* 49978 (1205) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  6] -1 */
      134420, /* 49979 (1205) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6]  1 */
      121460, /* 49980 (1205) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6]  1 */
    34142592, /* 49981 (1205) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  6] -1 */
      121458, /* 49982 (1205) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  6]  1 */
        3200, /* 49983 (1205) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    18544586, /* 49984 (1205) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
       16482, /* 49985 (1205) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
       16484, /* 49986 (1206) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34137732, /* 49987 (1206) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  6] -1 */
    52442922, /* 49988 (1206) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 6,  6,  0] -1 */
      134418, /* 49989 (1206) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  6]  1 */
    18439608, /* 49990 (1206) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
    52451834, /* 49991 (1206) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
    52565396, /* 49992 (1206) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    52561508, /* 49993 (1206) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    34024010, /* 49994 (1206) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    52438874, /* 49995 (1206) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
    34146644, /* 49996 (1206) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    18549282, /* 49997 (1206) [ 0, -1,  0,  1,  0,  0,  0,  0, -1] [ 6,  6,  6]  1 */
    34020122, /* 49998 (1206) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    34133684, /* 49999 (1206) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    18553170, /* 50000 (1206) [ 0,  1,  0, -1,  0,  0,  0,  0, -1] [ 6,  6,  6]  1 */
    18426648, /* 50001 (1206) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
    18557870, /* 50002 (1206) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
       11784, /* 50003 (1206) [ 0,  1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  0]  1 */
        7896, /* 50004 (1206) [ 0, -1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    34028706, /* 50005 (1206) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    52447782, /* 50006 (1206) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 6,  6,  0] -1 */
    52570092, /* 50007 (1206) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    52556808, /* 50008 (1206) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    34142592, /* 50009 (1206) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  6] -1 */
    34015422, /* 50010 (1206) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
      121458, /* 50011 (1206) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  6]  1 */
        3200, /* 50012 (1206) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    18435560, /* 50013 (1206) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    18430700, /* 50014 (1206) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    18544586, /* 50015 (1206) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
      130370, /* 50016 (1206) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 0,  0,  6]  1 */
      125510, /* 50017 (1206) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  6]  1 */
       16484, /* 50018 (1207) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34137732, /* 50019 (1207) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  6] -1 */
    52442922, /* 50020 (1207) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 6,  6,  0] -1 */
    18557868, /* 50021 (1207) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
    18544584, /* 50022 (1207) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
        3198, /* 50023 (1207) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    52438872, /* 50024 (1207) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
    52451834, /* 50025 (1207) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
    52438874, /* 50026 (1207) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
    34146644, /* 50027 (1207) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    18549282, /* 50028 (1207) [ 0, -1,  0,  1,  0,  0,  0,  0, -1] [ 6,  6,  6]  1 */
    34133684, /* 50029 (1207) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    34133682, /* 50030 (1207) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
    18553170, /* 50031 (1207) [ 0,  1,  0, -1,  0,  0,  0,  0, -1] [ 6,  6,  6]  1 */
    52447784, /* 50032 (1207) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 6,  6,  0] -1 */
    18557870, /* 50033 (1207) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    34142594, /* 50034 (1207) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 0,  0,  6] -1 */
       11784, /* 50035 (1207) [ 0,  1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    52442924, /* 50036 (1207) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 6,  6,  0] -1 */
    18553172, /* 50037 (1207) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 6,  6,  6]  1 */
        7896, /* 50038 (1207) [ 0, -1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    52447782, /* 50039 (1207) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 6,  6,  0] -1 */
    34137734, /* 50040 (1207) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    18549284, /* 50041 (1207) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 6,  6,  6]  1 */
       11786, /* 50042 (1207) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34146642, /* 50043 (1207) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
        7898, /* 50044 (1207) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    52451832, /* 50045 (1207) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
    34142592, /* 50046 (1207) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  6] -1 */
        3200, /* 50047 (1207) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    18544586, /* 50048 (1207) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
       16482, /* 50049 (1207) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
       16484, /* 50050 (1208) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
      130368, /* 50051 (1208) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  6]  1 */
    52438872, /* 50052 (1208) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
    52565396, /* 50053 (1208) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    52561508, /* 50054 (1208) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 6,  6,  6] -1 */
      125508, /* 50055 (1208) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  6]  1 */
    34024010, /* 50056 (1208) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    18549282, /* 50057 (1208) [ 0, -1,  0,  1,  0,  0,  0,  0, -1] [ 6,  6,  6]  1 */
    18430698, /* 50058 (1208) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 6,  6,  0]  1 */
    34020122, /* 50059 (1208) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    34133682, /* 50060 (1208) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
    18553170, /* 50061 (1208) [ 0,  1,  0, -1,  0,  0,  0,  0, -1] [ 6,  6,  6]  1 */
    52447784, /* 50062 (1208) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 6,  6,  0] -1 */
    18557870, /* 50063 (1208) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    34142594, /* 50064 (1208) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    18439610, /* 50065 (1208) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
       11784, /* 50066 (1208) [ 0,  1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    52442924, /* 50067 (1208) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 6,  6,  0] -1 */
        7896, /* 50068 (1208) [ 0, -1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    34028706, /* 50069 (1208) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    18426650, /* 50070 (1208) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    34137734, /* 50071 (1208) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    34146642, /* 50072 (1208) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
      134420, /* 50073 (1208) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6]  1 */
    52570092, /* 50074 (1208) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    52451832, /* 50075 (1208) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
    52556808, /* 50076 (1208) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
      121460, /* 50077 (1208) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6]  1 */
    34015422, /* 50078 (1208) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
        3200, /* 50079 (1208) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    18544586, /* 50080 (1208) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    18435558, /* 50081 (1208) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 6,  6,  0]  1 */
       16484, /* 50082 (1209) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
      134418, /* 50083 (1209) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  6]  1 */
    18439608, /* 50084 (1209) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
    52561506, /* 50085 (1209) [ 0, -1,  0,  1,  0,  0,  0,  0, -1] [ 6,  6,  6] -1 */
      130368, /* 50086 (1209) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  6]  1 */
    52565394, /* 50087 (1209) [ 0,  1,  0, -1,  0,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    52451834, /* 50088 (1209) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
    34024008, /* 50089 (1209) [ 0,  1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    34020120, /* 50090 (1209) [ 0, -1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  0] -1 */
      125508, /* 50091 (1209) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  6]  1 */
    52438874, /* 50092 (1209) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
    34146644, /* 50093 (1209) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    18430698, /* 50094 (1209) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 6,  6,  0]  1 */
    34133684, /* 50095 (1209) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    52447784, /* 50096 (1209) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 6,  6,  0] -1 */
    18426648, /* 50097 (1209) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
    18557870, /* 50098 (1209) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    34142594, /* 50099 (1209) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    18553172, /* 50100 (1209) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    52442924, /* 50101 (1209) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 6,  6,  0] -1 */
    34028706, /* 50102 (1209) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    34137734, /* 50103 (1209) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    18549284, /* 50104 (1209) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 6,  6,  6]  1 */
       11786, /* 50105 (1209) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  0]  1 */
        7898, /* 50106 (1209) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    52570092, /* 50107 (1209) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    52556808, /* 50108 (1209) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    34015422, /* 50109 (1209) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
      121458, /* 50110 (1209) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  6]  1 */
        3200, /* 50111 (1209) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    18544586, /* 50112 (1209) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    18435558, /* 50113 (1209) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 6,  6,  0]  1 */
       16484, /* 50114 (1210) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    18557868, /* 50115 (1210) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
      134418, /* 50116 (1210) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  6]  1 */
    18544584, /* 50117 (1210) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
    18439608, /* 50118 (1210) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
    34019634, /* 50119 (1210) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  0] -1 */
      130368, /* 50120 (1210) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  6]  1 */
    52443408, /* 50121 (1210) [ 0, -1,  0,  1,  0,  0,  0,  0, -1] [ 6,  6,  0] -1 */
    52447298, /* 50122 (1210) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 6,  6,  0] -1 */
    52451996, /* 50123 (1210) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
        3198, /* 50124 (1210) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    52556970, /* 50125 (1210) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    52443410, /* 50126 (1210) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 6,  6,  0] -1 */
    52447296, /* 50127 (1210) [ 0,  1,  0, -1,  0,  0,  0,  0, -1] [ 6,  6,  0] -1 */
    52561020, /* 50128 (1210) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    34142108, /* 50129 (1210) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  6] -1 */
      125508, /* 50130 (1210) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  6]  1 */
    34015584, /* 50131 (1210) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    52569932, /* 50132 (1210) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    34138220, /* 50133 (1210) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    34142106, /* 50134 (1210) [ 0,  1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  6] -1 */
    18430698, /* 50135 (1210) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 6,  6,  0]  1 */
    18549282, /* 50136 (1210) [ 0, -1,  0,  1,  0,  0,  0,  0, -1] [ 6,  6,  6]  1 */
    34138218, /* 50137 (1210) [ 0, -1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  6] -1 */
    34146806, /* 50138 (1210) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    52556972, /* 50139 (1210) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    52565882, /* 50140 (1210) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    34028546, /* 50141 (1210) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    52438712, /* 50142 (1210) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
    34024496, /* 50143 (1210) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    18553170, /* 50144 (1210) [ 0,  1,  0, -1,  0,  0,  0,  0, -1] [ 6,  6,  6]  1 */
    34015586, /* 50145 (1210) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    18426648, /* 50146 (1210) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
    18557870, /* 50147 (1210) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    34133522, /* 50148 (1210) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    18439610, /* 50149 (1210) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
       11784, /* 50150 (1210) [ 0,  1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    18553172, /* 50151 (1210) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 6,  6,  6]  1 */
        7896, /* 50152 (1210) [ 0, -1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    34019636, /* 50153 (1210) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    52451994, /* 50154 (1210) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
    18426650, /* 50155 (1210) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    18549284, /* 50156 (1210) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 6,  6,  6]  1 */
       11786, /* 50157 (1210) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    52561022, /* 50158 (1210) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    52569930, /* 50159 (1210) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
      134420, /* 50160 (1210) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6]  1 */
        7898, /* 50161 (1210) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34146804, /* 50162 (1210) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
    52565880, /* 50163 (1210) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    34028544, /* 50164 (1210) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
      121460, /* 50165 (1210) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6]  1 */
      121458, /* 50166 (1210) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  6]  1 */
    52438710, /* 50167 (1210) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
        3200, /* 50168 (1210) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    18435560, /* 50169 (1210) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    34024494, /* 50170 (1210) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    34133520, /* 50171 (1210) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
    18430700, /* 50172 (1210) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    18544586, /* 50173 (1210) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
      130370, /* 50174 (1210) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 0,  0,  6]  1 */
      125510, /* 50175 (1210) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  6]  1 */
       16482, /* 50176 (1210) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    18435558, /* 50177 (1210) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 6,  6,  0]  1 */
       16484, /* 50178 (1211) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    18553656, /* 50179 (1211) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 6,  6,  6]  1 */
    17186457, /* 50180 (1211) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  9]  1 */
       12270, /* 50181 (1211) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  0]  1 */
     1483637, /* 50182 (1211) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 0,  6,  3]  1 */
    17186619, /* 50183 (1211) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  9]  1 */
        7896, /* 50184 (1211) [ 0, -1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  0]  1 */
     1492545, /* 50185 (1211) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  3]  1 */
    17190671, /* 50186 (1211) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 6,  0,  9]  1 */
    18549282, /* 50187 (1211) [ 0, -1,  0,  1,  0,  0,  0,  0, -1] [ 6,  6,  6]  1 */
     1488011, /* 50188 (1211) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 0,  6,  3]  1 */
     1479423, /* 50189 (1211) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  3]  1 */
        3200, /* 50190 (1211) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    18544586, /* 50191 (1211) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    18557708, /* 50192 (1211) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    17195045, /* 50193 (1211) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 6,  0,  9]  1 */
    17195531, /* 50194 (1211) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 6,  0,  9]  1 */
     1488497, /* 50195 (1211) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 0,  6,  3]  1 */
     1492707, /* 50196 (1211) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  3]  1 */
    18553170, /* 50197 (1211) [ 0,  1,  0, -1,  0,  0,  0,  0, -1] [ 6,  6,  6]  1 */
    18557870, /* 50198 (1211) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    17199741, /* 50199 (1211) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  9]  1 */
     1484123, /* 50200 (1211) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 0,  6,  3]  1 */
    17191157, /* 50201 (1211) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 6,  0,  9]  1 */
       11784, /* 50202 (1211) [ 0,  1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    18544748, /* 50203 (1211) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
        3362, /* 50204 (1211) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
        7410, /* 50205 (1211) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    18548796, /* 50206 (1211) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 6,  6,  6]  1 */
     1479585, /* 50207 (1211) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  3]  1 */
       16322, /* 50208 (1211) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    17199579, /* 50209 (1211) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  9]  1 */
       16484, /* 50210 (1212) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    35504931, /* 50211 (1212) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  3] -1 */
    18553656, /* 50212 (1212) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 6,  6,  6]  1 */
    17186457, /* 50213 (1212) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  9]  1 */
       12270, /* 50214 (1212) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  0]  1 */
     1483637, /* 50215 (1212) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 0,  6,  3]  1 */
    17186619, /* 50216 (1212) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  9]  1 */
        7896, /* 50217 (1212) [ 0, -1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  0]  1 */
     1492545, /* 50218 (1212) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  3]  1 */
    17190671, /* 50219 (1212) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 6,  0,  9]  1 */
    18549282, /* 50220 (1212) [ 0, -1,  0,  1,  0,  0,  0,  0, -1] [ 6,  6,  6]  1 */
    52565394, /* 50221 (1212) [ 0,  1,  0, -1,  0,  0,  0,  0, -1] [ 6,  6,  6] -1 */
     1488011, /* 50222 (1212) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 0,  6,  3]  1 */
     1479423, /* 50223 (1212) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  3]  1 */
        3200, /* 50224 (1212) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    18544586, /* 50225 (1212) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    18557708, /* 50226 (1212) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    51211965, /* 50227 (1212) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  9] -1 */
    52570094, /* 50228 (1212) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    17195045, /* 50229 (1212) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 6,  0,  9]  1 */
    17195531, /* 50230 (1212) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 6,  0,  9]  1 */
    35496347, /* 50231 (1212) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 0,  6,  3] -1 */
    51203381, /* 50232 (1212) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 6,  0,  9] -1 */
    34024008, /* 50233 (1212) [ 0,  1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  0] -1 */
     1488497, /* 50234 (1212) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 0,  6,  3]  1 */
     1492707, /* 50235 (1212) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  3]  1 */
    52556972, /* 50236 (1212) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    18553170, /* 50237 (1212) [ 0,  1,  0, -1,  0,  0,  0,  0, -1] [ 6,  6,  6]  1 */
    34028708, /* 50238 (1212) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    34019634, /* 50239 (1212) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    34015586, /* 50240 (1212) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    52561020, /* 50241 (1212) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    18557870, /* 50242 (1212) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    17199741, /* 50243 (1212) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  9]  1 */
    35491809, /* 50244 (1212) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  3] -1 */
     1484123, /* 50245 (1212) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 0,  6,  3]  1 */
    17191157, /* 50246 (1212) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 6,  0,  9]  1 */
       11784, /* 50247 (1212) [ 0,  1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    34028546, /* 50248 (1212) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    52565880, /* 50249 (1212) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    51211803, /* 50250 (1212) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  9] -1 */
    34024494, /* 50251 (1212) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    34020120, /* 50252 (1212) [ 0, -1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    18544748, /* 50253 (1212) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    35504769, /* 50254 (1212) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  3] -1 */
    51198681, /* 50255 (1212) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  9] -1 */
    52561506, /* 50256 (1212) [ 0, -1,  0,  1,  0,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    35495861, /* 50257 (1212) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 0,  6,  3] -1 */
    51198843, /* 50258 (1212) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  9] -1 */
    35491647, /* 50259 (1212) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  3] -1 */
    51202895, /* 50260 (1212) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 6,  0,  9] -1 */
    35500235, /* 50261 (1212) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 0,  6,  3] -1 */
    52569932, /* 50262 (1212) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
        3362, /* 50263 (1212) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
        7410, /* 50264 (1212) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    34015424, /* 50265 (1212) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    52556810, /* 50266 (1212) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    18548796, /* 50267 (1212) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 6,  6,  6]  1 */
     1479585, /* 50268 (1212) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  3]  1 */
    51207269, /* 50269 (1212) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 6,  0,  9] -1 */
    51207755, /* 50270 (1212) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 6,  0,  9] -1 */
       16322, /* 50271 (1212) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    35500721, /* 50272 (1212) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 0,  6,  3] -1 */
    17199579, /* 50273 (1212) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  9]  1 */
       16484, /* 50274 (1213) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    35504931, /* 50275 (1213) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  3] -1 */
     1483637, /* 50276 (1213) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 0,  6,  3]  1 */
    17190671, /* 50277 (1213) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 6,  0,  9]  1 */
    52565394, /* 50278 (1213) [ 0,  1,  0, -1,  0,  0,  0,  0, -1] [ 6,  6,  6] -1 */
     1488011, /* 50279 (1213) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 0,  6,  3]  1 */
        3200, /* 50280 (1213) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    18544586, /* 50281 (1213) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    51211965, /* 50282 (1213) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  9] -1 */
    18557708, /* 50283 (1213) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    17195045, /* 50284 (1213) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 6,  0,  9]  1 */
    17195531, /* 50285 (1213) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 6,  0,  9]  1 */
    34024008, /* 50286 (1213) [ 0,  1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  0] -1 */
     1488497, /* 50287 (1213) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 0,  6,  3]  1 */
    34019634, /* 50288 (1213) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    52561020, /* 50289 (1213) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    18557870, /* 50290 (1213) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    35491809, /* 50291 (1213) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  3] -1 */
     1484123, /* 50292 (1213) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 0,  6,  3]  1 */
    17191157, /* 50293 (1213) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 6,  0,  9]  1 */
    52565880, /* 50294 (1213) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    51211803, /* 50295 (1213) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  9] -1 */
    34024494, /* 50296 (1213) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    34020120, /* 50297 (1213) [ 0, -1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    18544748, /* 50298 (1213) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    35504769, /* 50299 (1213) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  3] -1 */
    51198681, /* 50300 (1213) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  9] -1 */
    52561506, /* 50301 (1213) [ 0, -1,  0,  1,  0,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    51198843, /* 50302 (1213) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  9] -1 */
    35491647, /* 50303 (1213) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  3] -1 */
        3362, /* 50304 (1213) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
       16322, /* 50305 (1213) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
       16484, /* 50306 (1214) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    18553656, /* 50307 (1214) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 6,  6,  6]  1 */
    17186457, /* 50308 (1214) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  9]  1 */
       12270, /* 50309 (1214) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  0]  1 */
     1483637, /* 50310 (1214) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 0,  6,  3]  1 */
    17190671, /* 50311 (1214) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 6,  0,  9]  1 */
    52565394, /* 50312 (1214) [ 0,  1,  0, -1,  0,  0,  0,  0, -1] [ 6,  6,  6] -1 */
     1479423, /* 50313 (1214) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  3]  1 */
        3200, /* 50314 (1214) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    18544586, /* 50315 (1214) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    17195531, /* 50316 (1214) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 6,  0,  9]  1 */
    35496347, /* 50317 (1214) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 0,  6,  3] -1 */
    51203381, /* 50318 (1214) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 6,  0,  9] -1 */
    34024008, /* 50319 (1214) [ 0,  1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  0] -1 */
     1488497, /* 50320 (1214) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 0,  6,  3]  1 */
     1492707, /* 50321 (1214) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  3]  1 */
    52556972, /* 50322 (1214) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    34015586, /* 50323 (1214) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    18557870, /* 50324 (1214) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    17199741, /* 50325 (1214) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  9]  1 */
    35491809, /* 50326 (1214) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  3] -1 */
    34028546, /* 50327 (1214) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    51211803, /* 50328 (1214) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  9] -1 */
    34020120, /* 50329 (1214) [ 0, -1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    35504769, /* 50330 (1214) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  3] -1 */
    52561506, /* 50331 (1214) [ 0, -1,  0,  1,  0,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    51198843, /* 50332 (1214) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  9] -1 */
    35500235, /* 50333 (1214) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 0,  6,  3] -1 */
    52569932, /* 50334 (1214) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
        7410, /* 50335 (1214) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    18548796, /* 50336 (1214) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 6,  6,  6]  1 */
    51207269, /* 50337 (1214) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 6,  0,  9] -1 */
       16484, /* 50338 (1215) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    17186457, /* 50339 (1215) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  9]  1 */
    17186619, /* 50340 (1215) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  9]  1 */
     1492545, /* 50341 (1215) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  3]  1 */
    52565394, /* 50342 (1215) [ 0,  1,  0, -1,  0,  0,  0,  0, -1] [ 6,  6,  6] -1 */
     1479423, /* 50343 (1215) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  3]  1 */
        3200, /* 50344 (1215) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    18544586, /* 50345 (1215) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    18557708, /* 50346 (1215) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    35496347, /* 50347 (1215) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 0,  6,  3] -1 */
    51203381, /* 50348 (1215) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 6,  0,  9] -1 */
    34024008, /* 50349 (1215) [ 0,  1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  0] -1 */
     1492707, /* 50350 (1215) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  3]  1 */
    34019634, /* 50351 (1215) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    52561020, /* 50352 (1215) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    18557870, /* 50353 (1215) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    17199741, /* 50354 (1215) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  9]  1 */
    52565880, /* 50355 (1215) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    34024494, /* 50356 (1215) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    34020120, /* 50357 (1215) [ 0, -1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    18544748, /* 50358 (1215) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    52561506, /* 50359 (1215) [ 0, -1,  0,  1,  0,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    35495861, /* 50360 (1215) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 0,  6,  3] -1 */
    35500235, /* 50361 (1215) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 0,  6,  3] -1 */
    51202895, /* 50362 (1215) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 6,  0,  9] -1 */
        3362, /* 50363 (1215) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
     1479585, /* 50364 (1215) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  3]  1 */
    51207269, /* 50365 (1215) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 6,  0,  9] -1 */
    51207755, /* 50366 (1215) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 6,  0,  9] -1 */
       16322, /* 50367 (1215) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    35500721, /* 50368 (1215) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 0,  6,  3] -1 */
    17199579, /* 50369 (1215) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  9]  1 */
       16484, /* 50370 (1216) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    35504931, /* 50371 (1216) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  3] -1 */
        7896, /* 50372 (1216) [ 0, -1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    17186619, /* 50373 (1216) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  9]  1 */
     1483637, /* 50374 (1216) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 0,  6,  3]  1 */
     1492545, /* 50375 (1216) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  3]  1 */
    17190671, /* 50376 (1216) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 6,  0,  9]  1 */
    18549282, /* 50377 (1216) [ 0, -1,  0,  1,  0,  0,  0,  0, -1] [ 6,  6,  6]  1 */
        3200, /* 50378 (1216) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    18544586, /* 50379 (1216) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    51211965, /* 50380 (1216) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  9] -1 */
    17195531, /* 50381 (1216) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 6,  0,  9]  1 */
    35496347, /* 50382 (1216) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 0,  6,  3] -1 */
    51203381, /* 50383 (1216) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 6,  0,  9] -1 */
     1488497, /* 50384 (1216) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 0,  6,  3]  1 */
    52556972, /* 50385 (1216) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    18553170, /* 50386 (1216) [ 0,  1,  0, -1,  0,  0,  0,  0, -1] [ 6,  6,  6]  1 */
    34019634, /* 50387 (1216) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    34015586, /* 50388 (1216) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    52561020, /* 50389 (1216) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    18557870, /* 50390 (1216) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
       11784, /* 50391 (1216) [ 0,  1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    34028546, /* 50392 (1216) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    52565880, /* 50393 (1216) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    34024494, /* 50394 (1216) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    51198681, /* 50395 (1216) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  9] -1 */
    35500235, /* 50396 (1216) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 0,  6,  3] -1 */
    35491647, /* 50397 (1216) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  3] -1 */
    52569932, /* 50398 (1216) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
     1479585, /* 50399 (1216) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  3]  1 */
    51207269, /* 50400 (1216) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 6,  0,  9] -1 */
    17199579, /* 50401 (1216) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  9]  1 */
       16484, /* 50402 (1217) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    17186457, /* 50403 (1217) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  9]  1 */
        7896, /* 50404 (1217) [ 0, -1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    18549282, /* 50405 (1217) [ 0, -1,  0,  1,  0,  0,  0,  0, -1] [ 6,  6,  6]  1 */
     1488011, /* 50406 (1217) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 0,  6,  3]  1 */
     1479423, /* 50407 (1217) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  3]  1 */
        3200, /* 50408 (1217) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    18544586, /* 50409 (1217) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    17195045, /* 50410 (1217) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 6,  0,  9]  1 */
     1492707, /* 50411 (1217) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  3]  1 */
    52556972, /* 50412 (1217) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    18553170, /* 50413 (1217) [ 0,  1,  0, -1,  0,  0,  0,  0, -1] [ 6,  6,  6]  1 */
    34019634, /* 50414 (1217) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    34015586, /* 50415 (1217) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    52561020, /* 50416 (1217) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    18557870, /* 50417 (1217) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    17199741, /* 50418 (1217) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  9]  1 */
    35491809, /* 50419 (1217) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  3] -1 */
     1484123, /* 50420 (1217) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 0,  6,  3]  1 */
    17191157, /* 50421 (1217) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 6,  0,  9]  1 */
       11784, /* 50422 (1217) [ 0,  1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    34028546, /* 50423 (1217) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    52565880, /* 50424 (1217) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    51211803, /* 50425 (1217) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  9] -1 */
    34024494, /* 50426 (1217) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    35504769, /* 50427 (1217) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  3] -1 */
    35495861, /* 50428 (1217) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 0,  6,  3] -1 */
    51198843, /* 50429 (1217) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  9] -1 */
    51202895, /* 50430 (1217) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 6,  0,  9] -1 */
    52569932, /* 50431 (1217) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    51207755, /* 50432 (1217) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 6,  0,  9] -1 */
    35500721, /* 50433 (1217) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 0,  6,  3] -1 */
       16484, /* 50434 (1218) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    35504931, /* 50435 (1218) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  3] -1 */
    18553656, /* 50436 (1218) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 6,  6,  6]  1 */
       12270, /* 50437 (1218) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  0]  1 */
        7896, /* 50438 (1218) [ 0, -1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    18549282, /* 50439 (1218) [ 0, -1,  0,  1,  0,  0,  0,  0, -1] [ 6,  6,  6]  1 */
        3200, /* 50440 (1218) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    18544586, /* 50441 (1218) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    51211965, /* 50442 (1218) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  9] -1 */
    18557708, /* 50443 (1218) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    35496347, /* 50444 (1218) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 0,  6,  3] -1 */
    51203381, /* 50445 (1218) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 6,  0,  9] -1 */
    18553170, /* 50446 (1218) [ 0,  1,  0, -1,  0,  0,  0,  0, -1] [ 6,  6,  6]  1 */
    18557870, /* 50447 (1218) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    35491809, /* 50448 (1218) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  3] -1 */
       11784, /* 50449 (1218) [ 0,  1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    51211803, /* 50450 (1218) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  9] -1 */
    18544748, /* 50451 (1218) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    35504769, /* 50452 (1218) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  3] -1 */
    51198681, /* 50453 (1218) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  9] -1 */
    51198843, /* 50454 (1218) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  9] -1 */
    35495861, /* 50455 (1218) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 0,  6,  3] -1 */
    35491647, /* 50456 (1218) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  3] -1 */
    51202895, /* 50457 (1218) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 6,  0,  9] -1 */
    35500235, /* 50458 (1218) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 0,  6,  3] -1 */
        3362, /* 50459 (1218) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
        7410, /* 50460 (1218) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    18548796, /* 50461 (1218) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 6,  6,  6]  1 */
    51207269, /* 50462 (1218) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 6,  0,  9] -1 */
    51207755, /* 50463 (1218) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 6,  0,  9] -1 */
       16322, /* 50464 (1218) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    35500721, /* 50465 (1218) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 0,  6,  3] -1 */
       16484, /* 50466 (1219) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    35504931, /* 50467 (1219) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  3] -1 */
    18553656, /* 50468 (1219) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 6,  6,  6]  1 */
       12270, /* 50469 (1219) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    17186619, /* 50470 (1219) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  9]  1 */
     1492545, /* 50471 (1219) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  3]  1 */
    52565394, /* 50472 (1219) [ 0,  1,  0, -1,  0,  0,  0,  0, -1] [ 6,  6,  6] -1 */
     1488011, /* 50473 (1219) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 0,  6,  3]  1 */
        3200, /* 50474 (1219) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    18544586, /* 50475 (1219) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    51211965, /* 50476 (1219) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  9] -1 */
    17195045, /* 50477 (1219) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 6,  0,  9]  1 */
    34024008, /* 50478 (1219) [ 0,  1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    52556972, /* 50479 (1219) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    34015586, /* 50480 (1219) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    18557870, /* 50481 (1219) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
     1484123, /* 50482 (1219) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 0,  6,  3]  1 */
    17191157, /* 50483 (1219) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 6,  0,  9]  1 */
    34028546, /* 50484 (1219) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    34020120, /* 50485 (1219) [ 0, -1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    51198681, /* 50486 (1219) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  9] -1 */
    52561506, /* 50487 (1219) [ 0, -1,  0,  1,  0,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    35495861, /* 50488 (1219) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 0,  6,  3] -1 */
    35491647, /* 50489 (1219) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  3] -1 */
    51202895, /* 50490 (1219) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 6,  0,  9] -1 */
    52569932, /* 50491 (1219) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
        7410, /* 50492 (1219) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    18548796, /* 50493 (1219) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 6,  6,  6]  1 */
     1479585, /* 50494 (1219) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  3]  1 */
    51207755, /* 50495 (1219) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 6,  0,  9] -1 */
    35500721, /* 50496 (1219) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 0,  6,  3] -1 */
    17199579, /* 50497 (1219) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  9]  1 */
       16484, /* 50498 (1220) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    18553656, /* 50499 (1220) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 6,  6,  6]  1 */
    17186457, /* 50500 (1220) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  9]  1 */
       12270, /* 50501 (1220) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  0]  1 */
     1483637, /* 50502 (1220) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 0,  6,  3]  1 */
    17186619, /* 50503 (1220) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  9]  1 */
    35618819, /* 50504 (1220) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 0,  6,  9] -1 */
     1492545, /* 50505 (1220) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  3]  1 */
    17190671, /* 50506 (1220) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 6,  0,  9]  1 */
    18549282, /* 50507 (1220) [ 0, -1,  0,  1,  0,  0,  0,  0, -1] [ 6,  6,  6]  1 */
        7896, /* 50508 (1220) [ 0, -1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    35623029, /* 50509 (1220) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  9] -1 */
    34138218, /* 50510 (1220) [ 0, -1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  6] -1 */
    52451996, /* 50511 (1220) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
     1479423, /* 50512 (1220) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  3]  1 */
        3200, /* 50513 (1220) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
     1488011, /* 50514 (1220) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 0,  6,  3]  1 */
    18544586, /* 50515 (1220) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    18557708, /* 50516 (1220) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    34142106, /* 50517 (1220) [ 0,  1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  6] -1 */
    51080745, /* 50518 (1220) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  3] -1 */
    52447296, /* 50519 (1220) [ 0,  1,  0, -1,  0,  0,  0,  0, -1] [ 6,  6,  0] -1 */
    17195045, /* 50520 (1220) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 6,  0,  9]  1 */
    51089171, /* 50521 (1220) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 6,  0,  3] -1 */
    17195531, /* 50522 (1220) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 6,  0,  9]  1 */
    52451834, /* 50523 (1220) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
     1488497, /* 50524 (1220) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 0,  6,  3]  1 */
     1492707, /* 50525 (1220) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  3]  1 */
    51085283, /* 50526 (1220) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 6,  0,  3] -1 */
    52438874, /* 50527 (1220) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
    35614445, /* 50528 (1220) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 0,  6,  9] -1 */
    51089657, /* 50529 (1220) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 6,  0,  3] -1 */
    34146806, /* 50530 (1220) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    34133684, /* 50531 (1220) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    18553170, /* 50532 (1220) [ 0,  1,  0, -1,  0,  0,  0,  0, -1] [ 6,  6,  6]  1 */
    52438712, /* 50533 (1220) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
    52442922, /* 50534 (1220) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 6,  6,  0] -1 */
    18557870, /* 50535 (1220) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    17199741, /* 50536 (1220) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  9]  1 */
    51093867, /* 50537 (1220) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  3] -1 */
       16322, /* 50538 (1220) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
     1484123, /* 50539 (1220) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 0,  6,  3]  1 */
    52447782, /* 50540 (1220) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 6,  6,  0] -1 */
    17191157, /* 50541 (1220) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 6,  0,  9]  1 */
       11784, /* 50542 (1220) [ 0,  1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    35622867, /* 50543 (1220) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  9] -1 */
    35609907, /* 50544 (1220) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  9] -1 */
    51084797, /* 50545 (1220) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 6,  0,  3] -1 */
    35613959, /* 50546 (1220) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 0,  6,  9] -1 */
    18544748, /* 50547 (1220) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    51093705, /* 50548 (1220) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  3] -1 */
    34146644, /* 50549 (1220) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    51080583, /* 50550 (1220) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  3] -1 */
    34142592, /* 50551 (1220) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  6] -1 */
        3362, /* 50552 (1220) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
        7410, /* 50553 (1220) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    52443408, /* 50554 (1220) [ 0, -1,  0,  1,  0,  0,  0,  0, -1] [ 6,  6,  0] -1 */
    35609745, /* 50555 (1220) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  9] -1 */
    18548796, /* 50556 (1220) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 6,  6,  6]  1 */
     1479585, /* 50557 (1220) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  3]  1 */
    35618333, /* 50558 (1220) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 0,  6,  9] -1 */
    34133522, /* 50559 (1220) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    34137732, /* 50560 (1220) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  6] -1 */
    17199579, /* 50561 (1220) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  9]  1 */
       16484, /* 50562 (1211) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    10700139, /* 50563 (1211) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 3,  9,  3]  1 */
    18544584, /* 50564 (1211) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
    26407173, /* 50565 (1211) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 9,  3,  9]  1 */
    10695281, /* 50566 (1211) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 3,  9,  3]  1 */
    17127570, /* 50567 (1211) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6]  1 */
     9396687, /* 50568 (1211) [ 0, -1,  0,  1,  0,  0,  0,  0, -1] [ 3,  3,  9]  1 */
       16320, /* 50569 (1211) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    26402315, /* 50570 (1211) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 9,  3,  9]  1 */
    27701877, /* 50571 (1211) [ 0, -1,  0,  1,  0,  0,  0,  0, -1] [ 9,  9,  3]  1 */
    27705767, /* 50572 (1211) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 9,  9,  3]  1 */
        3198, /* 50573 (1211) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
     1420376, /* 50574 (1211) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  0]  1 */
    17127410, /* 50575 (1211) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
    17140532, /* 50576 (1211) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
     9400577, /* 50577 (1211) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 3,  3,  9]  1 */
     9401063, /* 50578 (1211) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 3,  3,  9]  1 */
    27706253, /* 50579 (1211) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 9,  9,  3]  1 */
     1433658, /* 50580 (1211) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  0]  1 */
    10699653, /* 50581 (1211) [ 0,  1,  0, -1,  0,  0,  0,  0, -1] [ 3,  9,  3]  1 */
    18557870, /* 50582 (1211) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    17140692, /* 50583 (1211) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6]  1 */
    10695767, /* 50584 (1211) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 3,  9,  3]  1 */
    26402801, /* 50585 (1211) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 9,  3,  9]  1 */
    26406687, /* 50586 (1211) [ 0,  1,  0, -1,  0,  0,  0,  0, -1] [ 9,  3,  9]  1 */
    18544748, /* 50587 (1211) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
        3362, /* 50588 (1211) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
     9396201, /* 50589 (1211) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 3,  3,  9]  1 */
    27701391, /* 50590 (1211) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 9,  9,  3]  1 */
     1420536, /* 50591 (1211) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  0]  1 */
     1433498, /* 50592 (1211) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  0]  1 */
    18557706, /* 50593 (1211) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
       16484, /* 50594 (1212) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    35445882, /* 50595 (1212) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  0] -1 */
    10700139, /* 50596 (1212) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 3,  9,  3]  1 */
    18544584, /* 50597 (1212) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
    26407173, /* 50598 (1212) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 9,  3,  9]  1 */
    10695281, /* 50599 (1212) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 3,  9,  3]  1 */
    17127570, /* 50600 (1212) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6]  1 */
     9396687, /* 50601 (1212) [ 0, -1,  0,  1,  0,  0,  0,  0, -1] [ 3,  3,  9]  1 */
       16320, /* 50602 (1212) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    26402315, /* 50603 (1212) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 9,  3,  9]  1 */
    27701877, /* 50604 (1212) [ 0, -1,  0,  1,  0,  0,  0,  0, -1] [ 9,  9,  3]  1 */
    44711877, /* 50605 (1212) [ 0,  1,  0, -1,  0,  0,  0,  0, -1] [ 3,  9,  3] -1 */
    27705767, /* 50606 (1212) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 9,  9,  3]  1 */
        3198, /* 50607 (1212) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
     1420376, /* 50608 (1212) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  0]  1 */
    17127410, /* 50609 (1212) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
    17140532, /* 50610 (1212) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
    51152916, /* 50611 (1212) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6] -1 */
    52570094, /* 50612 (1212) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
     9400577, /* 50613 (1212) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 3,  3,  9]  1 */
     9401063, /* 50614 (1212) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 3,  3,  9]  1 */
    44707991, /* 50615 (1212) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 3,  9,  3] -1 */
    60415025, /* 50616 (1212) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 9,  3,  9] -1 */
    60418911, /* 50617 (1212) [ 0,  1,  0, -1,  0,  0,  0,  0, -1] [ 9,  3,  9] -1 */
    27706253, /* 50618 (1212) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 9,  9,  3]  1 */
     1433658, /* 50619 (1212) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  0]  1 */
    52556972, /* 50620 (1212) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    10699653, /* 50621 (1212) [ 0,  1,  0, -1,  0,  0,  0,  0, -1] [ 3,  9,  3]  1 */
    34028708, /* 50622 (1212) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    43408425, /* 50623 (1212) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 3,  3,  9] -1 */
    34015586, /* 50624 (1212) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    61713615, /* 50625 (1212) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 9,  9,  3] -1 */
    18557870, /* 50626 (1212) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    17140692, /* 50627 (1212) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6]  1 */
    35432760, /* 50628 (1212) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  0] -1 */
    10695767, /* 50629 (1212) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 3,  9,  3]  1 */
    26402801, /* 50630 (1212) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 9,  3,  9]  1 */
    26406687, /* 50631 (1212) [ 0,  1,  0, -1,  0,  0,  0,  0, -1] [ 9,  3,  9]  1 */
    35445722, /* 50632 (1212) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  0] -1 */
    44712363, /* 50633 (1212) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 3,  9,  3] -1 */
    52569930, /* 50634 (1212) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    60419397, /* 50635 (1212) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 9,  3,  9] -1 */
    43408911, /* 50636 (1212) [ 0, -1,  0,  1,  0,  0,  0,  0, -1] [ 3,  3,  9] -1 */
    18544748, /* 50637 (1212) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    34028544, /* 50638 (1212) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    52556808, /* 50639 (1212) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    61714101, /* 50640 (1212) [ 0, -1,  0,  1,  0,  0,  0,  0, -1] [ 9,  9,  3] -1 */
    44707505, /* 50641 (1212) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 3,  9,  3] -1 */
    51139794, /* 50642 (1212) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6] -1 */
    34015422, /* 50643 (1212) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    60414539, /* 50644 (1212) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 9,  3,  9] -1 */
    61717991, /* 50645 (1212) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 9,  9,  3] -1 */
    51152756, /* 50646 (1212) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
        3362, /* 50647 (1212) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
     9396201, /* 50648 (1212) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 3,  3,  9]  1 */
    35432600, /* 50649 (1212) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  0] -1 */
    51139634, /* 50650 (1212) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
    27701391, /* 50651 (1212) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 9,  9,  3]  1 */
     1420536, /* 50652 (1212) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  0]  1 */
    43412801, /* 50653 (1212) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 3,  3,  9] -1 */
    43413287, /* 50654 (1212) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 3,  3,  9] -1 */
     1433498, /* 50655 (1212) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  0]  1 */
    61718477, /* 50656 (1212) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 9,  9,  3] -1 */
    18557706, /* 50657 (1212) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
       16484, /* 50658 (1213) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    35445882, /* 50659 (1213) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  0] -1 */
    10695281, /* 50660 (1213) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 3,  9,  3]  1 */
    26402315, /* 50661 (1213) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 9,  3,  9]  1 */
    44711877, /* 50662 (1213) [ 0,  1,  0, -1,  0,  0,  0,  0, -1] [ 3,  9,  3] -1 */
    27705767, /* 50663 (1213) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 9,  9,  3]  1 */
     1420376, /* 50664 (1213) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  0]  1 */
    17127410, /* 50665 (1213) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
    51152916, /* 50666 (1213) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6] -1 */
    17140532, /* 50667 (1213) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
     9400577, /* 50668 (1213) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 3,  3,  9]  1 */
     9401063, /* 50669 (1213) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 3,  3,  9]  1 */
    60418911, /* 50670 (1213) [ 0,  1,  0, -1,  0,  0,  0,  0, -1] [ 9,  3,  9] -1 */
    27706253, /* 50671 (1213) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 9,  9,  3]  1 */
    43408425, /* 50672 (1213) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 3,  3,  9] -1 */
    61713615, /* 50673 (1213) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 9,  9,  3] -1 */
    18557870, /* 50674 (1213) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    35432760, /* 50675 (1213) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  0] -1 */
    10695767, /* 50676 (1213) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 3,  9,  3]  1 */
    26402801, /* 50677 (1213) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 9,  3,  9]  1 */
    44712363, /* 50678 (1213) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 3,  9,  3] -1 */
    52569930, /* 50679 (1213) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    60419397, /* 50680 (1213) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 9,  3,  9] -1 */
    43408911, /* 50681 (1213) [ 0, -1,  0,  1,  0,  0,  0,  0, -1] [ 3,  3,  9] -1 */
    18544748, /* 50682 (1213) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    34028544, /* 50683 (1213) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    52556808, /* 50684 (1213) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    61714101, /* 50685 (1213) [ 0, -1,  0,  1,  0,  0,  0,  0, -1] [ 9,  9,  3] -1 */
    51139794, /* 50686 (1213) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6] -1 */
    34015422, /* 50687 (1213) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
        3362, /* 50688 (1213) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
     1433498, /* 50689 (1213) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  0]  1 */
       16484, /* 50690 (1214) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    10700139, /* 50691 (1214) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 3,  9,  3]  1 */
    18544584, /* 50692 (1214) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
    26407173, /* 50693 (1214) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 9,  3,  9]  1 */
    10695281, /* 50694 (1214) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 3,  9,  3]  1 */
    26402315, /* 50695 (1214) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 9,  3,  9]  1 */
    44711877, /* 50696 (1214) [ 0,  1,  0, -1,  0,  0,  0,  0, -1] [ 3,  9,  3] -1 */
        3198, /* 50697 (1214) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
     1420376, /* 50698 (1214) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  0]  1 */
    17127410, /* 50699 (1214) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
     9401063, /* 50700 (1214) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 3,  3,  9]  1 */
    44707991, /* 50701 (1214) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 3,  9,  3] -1 */
    60415025, /* 50702 (1214) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 9,  3,  9] -1 */
    60418911, /* 50703 (1214) [ 0,  1,  0, -1,  0,  0,  0,  0, -1] [ 9,  3,  9] -1 */
    27706253, /* 50704 (1214) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 9,  9,  3]  1 */
     1433658, /* 50705 (1214) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  0]  1 */
    52556972, /* 50706 (1214) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    34015586, /* 50707 (1214) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    18557870, /* 50708 (1214) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    17140692, /* 50709 (1214) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6]  1 */
    35432760, /* 50710 (1214) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  0] -1 */
    35445722, /* 50711 (1214) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  0] -1 */
    52569930, /* 50712 (1214) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    43408911, /* 50713 (1214) [ 0, -1,  0,  1,  0,  0,  0,  0, -1] [ 3,  3,  9] -1 */
    34028544, /* 50714 (1214) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    61714101, /* 50715 (1214) [ 0, -1,  0,  1,  0,  0,  0,  0, -1] [ 9,  9,  3] -1 */
    51139794, /* 50716 (1214) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6] -1 */
    61717991, /* 50717 (1214) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 9,  9,  3] -1 */
    51152756, /* 50718 (1214) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
     9396201, /* 50719 (1214) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 3,  3,  9]  1 */
    27701391, /* 50720 (1214) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 9,  9,  3]  1 */
    43412801, /* 50721 (1214) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 3,  3,  9] -1 */
       16484, /* 50722 (1215) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    18544584, /* 50723 (1215) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
    17127570, /* 50724 (1215) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6]  1 */
       16320, /* 50725 (1215) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    44711877, /* 50726 (1215) [ 0,  1,  0, -1,  0,  0,  0,  0, -1] [ 3,  9,  3] -1 */
        3198, /* 50727 (1215) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
     1420376, /* 50728 (1215) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  0]  1 */
    17127410, /* 50729 (1215) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
    17140532, /* 50730 (1215) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
    44707991, /* 50731 (1215) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 3,  9,  3] -1 */
    60415025, /* 50732 (1215) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 9,  3,  9] -1 */
    60418911, /* 50733 (1215) [ 0,  1,  0, -1,  0,  0,  0,  0, -1] [ 9,  3,  9] -1 */
     1433658, /* 50734 (1215) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  0]  1 */
    43408425, /* 50735 (1215) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 3,  3,  9] -1 */
    61713615, /* 50736 (1215) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 9,  9,  3] -1 */
    18557870, /* 50737 (1215) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    17140692, /* 50738 (1215) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6]  1 */
    44712363, /* 50739 (1215) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 3,  9,  3] -1 */
    60419397, /* 50740 (1215) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 9,  3,  9] -1 */
    43408911, /* 50741 (1215) [ 0, -1,  0,  1,  0,  0,  0,  0, -1] [ 3,  3,  9] -1 */
    18544748, /* 50742 (1215) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    61714101, /* 50743 (1215) [ 0, -1,  0,  1,  0,  0,  0,  0, -1] [ 9,  9,  3] -1 */
    44707505, /* 50744 (1215) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 3,  9,  3] -1 */
    61717991, /* 50745 (1215) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 9,  9,  3] -1 */
    60414539, /* 50746 (1215) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 9,  3,  9] -1 */
        3362, /* 50747 (1215) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
     1420536, /* 50748 (1215) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  0]  1 */
    43412801, /* 50749 (1215) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 3,  3,  9] -1 */
    43413287, /* 50750 (1215) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 3,  3,  9] -1 */
     1433498, /* 50751 (1215) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  0]  1 */
    61718477, /* 50752 (1215) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 9,  9,  3] -1 */
    18557706, /* 50753 (1215) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
       16484, /* 50754 (1216) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    35445882, /* 50755 (1216) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  0] -1 */
     9396687, /* 50756 (1216) [ 0, -1,  0,  1,  0,  0,  0,  0, -1] [ 3,  3,  9]  1 */
    17127570, /* 50757 (1216) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6]  1 */
    10695281, /* 50758 (1216) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 3,  9,  3]  1 */
       16320, /* 50759 (1216) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    26402315, /* 50760 (1216) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 9,  3,  9]  1 */
    27701877, /* 50761 (1216) [ 0, -1,  0,  1,  0,  0,  0,  0, -1] [ 9,  9,  3]  1 */
     1420376, /* 50762 (1216) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  0]  1 */
    17127410, /* 50763 (1216) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
    51152916, /* 50764 (1216) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6] -1 */
     9401063, /* 50765 (1216) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 3,  3,  9]  1 */
    44707991, /* 50766 (1216) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 3,  9,  3] -1 */
    60415025, /* 50767 (1216) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 9,  3,  9] -1 */
    27706253, /* 50768 (1216) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 9,  9,  3]  1 */
    52556972, /* 50769 (1216) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    10699653, /* 50770 (1216) [ 0,  1,  0, -1,  0,  0,  0,  0, -1] [ 3,  9,  3]  1 */
    43408425, /* 50771 (1216) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 3,  3,  9] -1 */
    34015586, /* 50772 (1216) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    61713615, /* 50773 (1216) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 9,  9,  3] -1 */
    18557870, /* 50774 (1216) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    26406687, /* 50775 (1216) [ 0,  1,  0, -1,  0,  0,  0,  0, -1] [ 9,  3,  9]  1 */
    35445722, /* 50776 (1216) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  0] -1 */
    44712363, /* 50777 (1216) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 3,  9,  3] -1 */
    60419397, /* 50778 (1216) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 9,  3,  9] -1 */
    52556808, /* 50779 (1216) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    61717991, /* 50780 (1216) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 9,  9,  3] -1 */
    34015422, /* 50781 (1216) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    51152756, /* 50782 (1216) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
     1420536, /* 50783 (1216) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  0]  1 */
    43412801, /* 50784 (1216) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 3,  3,  9] -1 */
    18557706, /* 50785 (1216) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
       16484, /* 50786 (1217) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    18544584, /* 50787 (1217) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
     9396687, /* 50788 (1217) [ 0, -1,  0,  1,  0,  0,  0,  0, -1] [ 3,  3,  9]  1 */
    27701877, /* 50789 (1217) [ 0, -1,  0,  1,  0,  0,  0,  0, -1] [ 9,  9,  3]  1 */
    27705767, /* 50790 (1217) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 9,  9,  3]  1 */
        3198, /* 50791 (1217) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
     1420376, /* 50792 (1217) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  0]  1 */
    17127410, /* 50793 (1217) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
     9400577, /* 50794 (1217) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 3,  3,  9]  1 */
     1433658, /* 50795 (1217) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  0]  1 */
    52556972, /* 50796 (1217) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    10699653, /* 50797 (1217) [ 0,  1,  0, -1,  0,  0,  0,  0, -1] [ 3,  9,  3]  1 */
    43408425, /* 50798 (1217) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 3,  3,  9] -1 */
    34015586, /* 50799 (1217) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    61713615, /* 50800 (1217) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 9,  9,  3] -1 */
    18557870, /* 50801 (1217) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    17140692, /* 50802 (1217) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6]  1 */
    35432760, /* 50803 (1217) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  0] -1 */
    10695767, /* 50804 (1217) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 3,  9,  3]  1 */
    26402801, /* 50805 (1217) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 9,  3,  9]  1 */
    26406687, /* 50806 (1217) [ 0,  1,  0, -1,  0,  0,  0,  0, -1] [ 9,  3,  9]  1 */
    35445722, /* 50807 (1217) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  0] -1 */
    44712363, /* 50808 (1217) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 3,  9,  3] -1 */
    52569930, /* 50809 (1217) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    60419397, /* 50810 (1217) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 9,  3,  9] -1 */
    34028544, /* 50811 (1217) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    44707505, /* 50812 (1217) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 3,  9,  3] -1 */
    51139794, /* 50813 (1217) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6] -1 */
    60414539, /* 50814 (1217) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 9,  3,  9] -1 */
    51152756, /* 50815 (1217) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
    43413287, /* 50816 (1217) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 3,  3,  9] -1 */
    61718477, /* 50817 (1217) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 9,  9,  3] -1 */
       16484, /* 50818 (1218) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    35445882, /* 50819 (1218) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  0] -1 */
    10700139, /* 50820 (1218) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 3,  9,  3]  1 */
    26407173, /* 50821 (1218) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 9,  3,  9]  1 */
     9396687, /* 50822 (1218) [ 0, -1,  0,  1,  0,  0,  0,  0, -1] [ 3,  3,  9]  1 */
    27701877, /* 50823 (1218) [ 0, -1,  0,  1,  0,  0,  0,  0, -1] [ 9,  9,  3]  1 */
     1420376, /* 50824 (1218) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  0]  1 */
    17127410, /* 50825 (1218) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
    51152916, /* 50826 (1218) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6] -1 */
    17140532, /* 50827 (1218) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
    44707991, /* 50828 (1218) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 3,  9,  3] -1 */
    60415025, /* 50829 (1218) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 9,  3,  9] -1 */
    10699653, /* 50830 (1218) [ 0,  1,  0, -1,  0,  0,  0,  0, -1] [ 3,  9,  3]  1 */
    18557870, /* 50831 (1218) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    35432760, /* 50832 (1218) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  0] -1 */
    26406687, /* 50833 (1218) [ 0,  1,  0, -1,  0,  0,  0,  0, -1] [ 9,  3,  9]  1 */
    52569930, /* 50834 (1218) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    18544748, /* 50835 (1218) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    34028544, /* 50836 (1218) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    52556808, /* 50837 (1218) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    51139794, /* 50838 (1218) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6] -1 */
    44707505, /* 50839 (1218) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 3,  9,  3] -1 */
    34015422, /* 50840 (1218) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    60414539, /* 50841 (1218) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 9,  3,  9] -1 */
    61717991, /* 50842 (1218) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 9,  9,  3] -1 */
        3362, /* 50843 (1218) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
     9396201, /* 50844 (1218) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 3,  3,  9]  1 */
    27701391, /* 50845 (1218) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 9,  9,  3]  1 */
    43412801, /* 50846 (1218) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 3,  3,  9] -1 */
    43413287, /* 50847 (1218) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 3,  3,  9] -1 */
     1433498, /* 50848 (1218) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  0]  1 */
    61718477, /* 50849 (1218) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 9,  9,  3] -1 */
       16484, /* 50850 (1219) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    35445882, /* 50851 (1219) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  0] -1 */
    10700139, /* 50852 (1219) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 3,  9,  3]  1 */
    26407173, /* 50853 (1219) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 9,  3,  9]  1 */
    17127570, /* 50854 (1219) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6]  1 */
       16320, /* 50855 (1219) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    44711877, /* 50856 (1219) [ 0,  1,  0, -1,  0,  0,  0,  0, -1] [ 3,  9,  3] -1 */
    27705767, /* 50857 (1219) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 9,  9,  3]  1 */
     1420376, /* 50858 (1219) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  0]  1 */
    17127410, /* 50859 (1219) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
    51152916, /* 50860 (1219) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6] -1 */
     9400577, /* 50861 (1219) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 3,  3,  9]  1 */
    60418911, /* 50862 (1219) [ 0,  1,  0, -1,  0,  0,  0,  0, -1] [ 9,  3,  9] -1 */
    52556972, /* 50863 (1219) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    34015586, /* 50864 (1219) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    18557870, /* 50865 (1219) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    10695767, /* 50866 (1219) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 3,  9,  3]  1 */
    26402801, /* 50867 (1219) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 9,  3,  9]  1 */
    35445722, /* 50868 (1219) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  0] -1 */
    43408911, /* 50869 (1219) [ 0, -1,  0,  1,  0,  0,  0,  0, -1] [ 3,  3,  9] -1 */
    52556808, /* 50870 (1219) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    61714101, /* 50871 (1219) [ 0, -1,  0,  1,  0,  0,  0,  0, -1] [ 9,  9,  3] -1 */
    44707505, /* 50872 (1219) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 3,  9,  3] -1 */
    34015422, /* 50873 (1219) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    60414539, /* 50874 (1219) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 9,  3,  9] -1 */
    51152756, /* 50875 (1219) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
     9396201, /* 50876 (1219) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 3,  3,  9]  1 */
    27701391, /* 50877 (1219) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 9,  9,  3]  1 */
     1420536, /* 50878 (1219) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  0]  1 */
    43413287, /* 50879 (1219) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 3,  3,  9] -1 */
    61718477, /* 50880 (1219) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 9,  9,  3] -1 */
    18557706, /* 50881 (1219) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
       16484, /* 50882 (1220) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    10700139, /* 50883 (1220) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 3,  9,  3]  1 */
    18544584, /* 50884 (1220) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
    26407173, /* 50885 (1220) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 9,  3,  9]  1 */
    10695281, /* 50886 (1220) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 3,  9,  3]  1 */
    17127570, /* 50887 (1220) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6]  1 */
    61836575, /* 50888 (1220) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 9,  9,  9] -1 */
       16320, /* 50889 (1220) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    26402315, /* 50890 (1220) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 9,  3,  9]  1 */
    27701877, /* 50891 (1220) [ 0, -1,  0,  1,  0,  0,  0,  0, -1] [ 9,  9,  3]  1 */
     9396687, /* 50892 (1220) [ 0, -1,  0,  1,  0,  0,  0,  0, -1] [ 3,  3,  9]  1 */
    35563980, /* 50893 (1220) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6] -1 */
    43290813, /* 50894 (1220) [ 0, -1,  0,  1,  0,  0,  0,  0, -1] [ 3,  3,  3] -1 */
    52451996, /* 50895 (1220) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
        3198, /* 50896 (1220) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
     1420376, /* 50897 (1220) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  0]  1 */
    27705767, /* 50898 (1220) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 9,  9,  3]  1 */
    17127410, /* 50899 (1220) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
    17140532, /* 50900 (1220) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
    60300813, /* 50901 (1220) [ 0,  1,  0, -1,  0,  0,  0,  0, -1] [ 9,  3,  3] -1 */
    51021696, /* 50902 (1220) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  0] -1 */
    44829975, /* 50903 (1220) [ 0,  1,  0, -1,  0,  0,  0,  0, -1] [ 3,  9,  9] -1 */
     9400577, /* 50904 (1220) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 3,  3,  9]  1 */
    43294703, /* 50905 (1220) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 3,  3,  3] -1 */
     9401063, /* 50906 (1220) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 3,  3,  9]  1 */
    51034658, /* 50907 (1220) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  0] -1 */
    27706253, /* 50908 (1220) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 9,  9,  3]  1 */
     1433658, /* 50909 (1220) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  0]  1 */
    60296927, /* 50910 (1220) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 9,  3,  3] -1 */
    52438874, /* 50911 (1220) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
    44826089, /* 50912 (1220) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 3,  9,  9] -1 */
    43295189, /* 50913 (1220) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 3,  3,  3] -1 */
    34146806, /* 50914 (1220) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    34133684, /* 50915 (1220) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    10699653, /* 50916 (1220) [ 0,  1,  0, -1,  0,  0,  0,  0, -1] [ 3,  9,  3]  1 */
    51021536, /* 50917 (1220) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  0] -1 */
    61831713, /* 50918 (1220) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 9,  9,  9] -1 */
    18557870, /* 50919 (1220) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    17140692, /* 50920 (1220) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6]  1 */
    51034818, /* 50921 (1220) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  0] -1 */
     1433498, /* 50922 (1220) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  0]  1 */
    10695767, /* 50923 (1220) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 3,  9,  3]  1 */
    44830461, /* 50924 (1220) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 3,  9,  9] -1 */
    26402801, /* 50925 (1220) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 9,  3,  9]  1 */
    26406687, /* 50926 (1220) [ 0,  1,  0, -1,  0,  0,  0,  0, -1] [ 9,  3,  9]  1 */
    34146642, /* 50927 (1220) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
    35550858, /* 50928 (1220) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6] -1 */
    60296441, /* 50929 (1220) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 9,  3,  3] -1 */
    44825603, /* 50930 (1220) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 3,  9,  9] -1 */
    18544748, /* 50931 (1220) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    52451832, /* 50932 (1220) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
    35563820, /* 50933 (1220) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
    52438710, /* 50934 (1220) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
    60301299, /* 50935 (1220) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 9,  3,  3] -1 */
        3362, /* 50936 (1220) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
     9396201, /* 50937 (1220) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 3,  3,  9]  1 */
    61832199, /* 50938 (1220) [ 0, -1,  0,  1,  0,  0,  0,  0, -1] [ 9,  9,  9] -1 */
    34133520, /* 50939 (1220) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
    27701391, /* 50940 (1220) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 9,  9,  3]  1 */
     1420536, /* 50941 (1220) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  0]  1 */
    61836089, /* 50942 (1220) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 9,  9,  9] -1 */
    35550698, /* 50943 (1220) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
    43290327, /* 50944 (1220) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 3,  3,  3] -1 */
    18557706, /* 50945 (1220) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
       16484, /* 50946 (1221) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    17072573, /* 50947 (1221) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 6,  0,  3]  1 */
     1601735, /* 50948 (1221) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 0,  6,  9]  1 */
     1610643, /* 50949 (1221) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  9]  1 */
    17186457, /* 50950 (1221) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  9]  1 */
    17081481, /* 50951 (1221) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  3]  1 */
        7896, /* 50952 (1221) [ 0, -1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  0]  1 */
      134420, /* 50953 (1221) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6]  1 */
      130368, /* 50954 (1221) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  6]  1 */
    18549282, /* 50955 (1221) [ 0, -1,  0,  1,  0,  0,  0,  0, -1] [ 6,  6,  6]  1 */
     1488011, /* 50956 (1221) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 0,  6,  3]  1 */
     1479423, /* 50957 (1221) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  3]  1 */
        3200, /* 50958 (1221) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    18544586, /* 50959 (1221) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    17195045, /* 50960 (1221) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 6,  0,  9]  1 */
      125508, /* 50961 (1221) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  6]  1 */
     1492707, /* 50962 (1221) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  3]  1 */
     1606595, /* 50963 (1221) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 0,  6,  9]  1 */
    18553170, /* 50964 (1221) [ 0,  1,  0, -1,  0,  0,  0,  0, -1] [ 6,  6,  6]  1 */
    18557870, /* 50965 (1221) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    17199741, /* 50966 (1221) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  9]  1 */
    17068521, /* 50967 (1221) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  3]  1 */
    18439610, /* 50968 (1221) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
     1484123, /* 50969 (1221) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 0,  6,  3]  1 */
    18426650, /* 50970 (1221) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    17191157, /* 50971 (1221) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 6,  0,  9]  1 */
       11784, /* 50972 (1221) [ 0,  1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    17077433, /* 50973 (1221) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 6,  0,  3]  1 */
      121460, /* 50974 (1221) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6]  1 */
    18430698, /* 50975 (1221) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 6,  6,  0]  1 */
    18435558, /* 50976 (1221) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 6,  6,  0]  1 */
     1597683, /* 50977 (1221) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  9]  1 */
       16484, /* 50978 (1222) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    17072573, /* 50979 (1222) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 6,  0,  3]  1 */
     1601735, /* 50980 (1222) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 0,  6,  9]  1 */
    35504931, /* 50981 (1222) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  3] -1 */
     1610643, /* 50982 (1222) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  9]  1 */
    17186457, /* 50983 (1222) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  9]  1 */
    17081481, /* 50984 (1222) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  3]  1 */
        7896, /* 50985 (1222) [ 0, -1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    35618819, /* 50986 (1222) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 0,  6,  9] -1 */
      134420, /* 50987 (1222) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6]  1 */
      130368, /* 50988 (1222) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  6]  1 */
    18549282, /* 50989 (1222) [ 0, -1,  0,  1,  0,  0,  0,  0, -1] [ 6,  6,  6]  1 */
    52565394, /* 50990 (1222) [ 0,  1,  0, -1,  0,  0,  0,  0, -1] [ 6,  6,  6] -1 */
     1488011, /* 50991 (1222) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 0,  6,  3]  1 */
     1479423, /* 50992 (1222) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  3]  1 */
        3200, /* 50993 (1222) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    18544586, /* 50994 (1222) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    51211965, /* 50995 (1222) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  9] -1 */
    51080745, /* 50996 (1222) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  3] -1 */
    52570094, /* 50997 (1222) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    17195045, /* 50998 (1222) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 6,  0,  9]  1 */
    52451834, /* 50999 (1222) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
    35496347, /* 51000 (1222) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 0,  6,  3] -1 */
      125508, /* 51001 (1222) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  6]  1 */
    51203381, /* 51002 (1222) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 6,  0,  9] -1 */
    34024008, /* 51003 (1222) [ 0,  1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  0] -1 */
     1492707, /* 51004 (1222) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  3]  1 */
    52438874, /* 51005 (1222) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
    51089657, /* 51006 (1222) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 6,  0,  3] -1 */
     1606595, /* 51007 (1222) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 0,  6,  9]  1 */
    34133684, /* 51008 (1222) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    18553170, /* 51009 (1222) [ 0,  1,  0, -1,  0,  0,  0,  0, -1] [ 6,  6,  6]  1 */
    34028708, /* 51010 (1222) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    52442922, /* 51011 (1222) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 6,  6,  0] -1 */
    18557870, /* 51012 (1222) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    17199741, /* 51013 (1222) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  9]  1 */
    17068521, /* 51014 (1222) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  3]  1 */
    18439610, /* 51015 (1222) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
     1484123, /* 51016 (1222) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 0,  6,  3]  1 */
    52447782, /* 51017 (1222) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 6,  6,  0] -1 */
    18426650, /* 51018 (1222) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    17191157, /* 51019 (1222) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 6,  0,  9]  1 */
       11784, /* 51020 (1222) [ 0,  1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    35622867, /* 51021 (1222) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  9] -1 */
    35609907, /* 51022 (1222) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  9] -1 */
    51084797, /* 51023 (1222) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 6,  0,  3] -1 */
    34020120, /* 51024 (1222) [ 0, -1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    35613959, /* 51025 (1222) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 0,  6,  9] -1 */
    17077433, /* 51026 (1222) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 6,  0,  3]  1 */
    51093705, /* 51027 (1222) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  3] -1 */
    51198681, /* 51028 (1222) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  9] -1 */
    52561506, /* 51029 (1222) [ 0, -1,  0,  1,  0,  0,  0,  0, -1] [ 6,  6,  6] -1 */
      121460, /* 51030 (1222) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6]  1 */
    18430698, /* 51031 (1222) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 6,  6,  0]  1 */
    35491647, /* 51032 (1222) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  3] -1 */
    35500235, /* 51033 (1222) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 0,  6,  3] -1 */
    34142592, /* 51034 (1222) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  6] -1 */
    34146644, /* 51035 (1222) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    34015424, /* 51036 (1222) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    52556810, /* 51037 (1222) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    51207269, /* 51038 (1222) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 6,  0,  9] -1 */
    34137732, /* 51039 (1222) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  6] -1 */
    18435558, /* 51040 (1222) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 6,  6,  0]  1 */
     1597683, /* 51041 (1222) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  9]  1 */
       16484, /* 51042 (1223) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    17072573, /* 51043 (1223) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 6,  0,  3]  1 */
     1601735, /* 51044 (1223) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 0,  6,  9]  1 */
    35504931, /* 51045 (1223) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  3] -1 */
      134420, /* 51046 (1223) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6]  1 */
    52565394, /* 51047 (1223) [ 0,  1,  0, -1,  0,  0,  0,  0, -1] [ 6,  6,  6] -1 */
     1488011, /* 51048 (1223) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 0,  6,  3]  1 */
        3200, /* 51049 (1223) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    18544586, /* 51050 (1223) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    51211965, /* 51051 (1223) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  9] -1 */
    51080745, /* 51052 (1223) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  3] -1 */
    17195045, /* 51053 (1223) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 6,  0,  9]  1 */
    34024008, /* 51054 (1223) [ 0,  1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  0] -1 */
     1606595, /* 51055 (1223) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 0,  6,  9]  1 */
    52442922, /* 51056 (1223) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 6,  6,  0] -1 */
    18557870, /* 51057 (1223) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    18439610, /* 51058 (1223) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
     1484123, /* 51059 (1223) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 0,  6,  3]  1 */
    52447782, /* 51060 (1223) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 6,  6,  0] -1 */
    18426650, /* 51061 (1223) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    17191157, /* 51062 (1223) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 6,  0,  9]  1 */
    35622867, /* 51063 (1223) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  9] -1 */
    35609907, /* 51064 (1223) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  9] -1 */
    34020120, /* 51065 (1223) [ 0, -1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    17077433, /* 51066 (1223) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 6,  0,  3]  1 */
    51093705, /* 51067 (1223) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  3] -1 */
    51198681, /* 51068 (1223) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  9] -1 */
    52561506, /* 51069 (1223) [ 0, -1,  0,  1,  0,  0,  0,  0, -1] [ 6,  6,  6] -1 */
      121460, /* 51070 (1223) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6]  1 */
    35491647, /* 51071 (1223) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  3] -1 */
    34142592, /* 51072 (1223) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  6] -1 */
    34137732, /* 51073 (1223) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  6] -1 */
       16484, /* 51074 (1224) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    17072573, /* 51075 (1224) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 6,  0,  3]  1 */
     1601735, /* 51076 (1224) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 0,  6,  9]  1 */
    17186457, /* 51077 (1224) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  9]  1 */
      130368, /* 51078 (1224) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  6]  1 */
    52565394, /* 51079 (1224) [ 0,  1,  0, -1,  0,  0,  0,  0, -1] [ 6,  6,  6] -1 */
     1479423, /* 51080 (1224) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  3]  1 */
        3200, /* 51081 (1224) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    18544586, /* 51082 (1224) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    51080745, /* 51083 (1224) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  3] -1 */
    52451834, /* 51084 (1224) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
    35496347, /* 51085 (1224) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 0,  6,  3] -1 */
      125508, /* 51086 (1224) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  6]  1 */
    51203381, /* 51087 (1224) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 6,  0,  9] -1 */
    34024008, /* 51088 (1224) [ 0,  1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  0] -1 */
     1492707, /* 51089 (1224) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  3]  1 */
    52438874, /* 51090 (1224) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
     1606595, /* 51091 (1224) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 0,  6,  9]  1 */
    34133684, /* 51092 (1224) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    18557870, /* 51093 (1224) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    17199741, /* 51094 (1224) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  9]  1 */
    35622867, /* 51095 (1224) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  9] -1 */
    35609907, /* 51096 (1224) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  9] -1 */
    34020120, /* 51097 (1224) [ 0, -1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    17077433, /* 51098 (1224) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 6,  0,  3]  1 */
    51093705, /* 51099 (1224) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  3] -1 */
    52561506, /* 51100 (1224) [ 0, -1,  0,  1,  0,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    34146644, /* 51101 (1224) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    18430698, /* 51102 (1224) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 6,  6,  0]  1 */
    35500235, /* 51103 (1224) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 0,  6,  3] -1 */
    51207269, /* 51104 (1224) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 6,  0,  9] -1 */
    18435558, /* 51105 (1224) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 6,  6,  0]  1 */
       16484, /* 51106 (1225) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
     1610643, /* 51107 (1225) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  9]  1 */
    17186457, /* 51108 (1225) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  9]  1 */
    17081481, /* 51109 (1225) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  3]  1 */
    35618819, /* 51110 (1225) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 0,  6,  9] -1 */
      134420, /* 51111 (1225) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6]  1 */
    52565394, /* 51112 (1225) [ 0,  1,  0, -1,  0,  0,  0,  0, -1] [ 6,  6,  6] -1 */
     1479423, /* 51113 (1225) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  3]  1 */
        3200, /* 51114 (1225) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    18544586, /* 51115 (1225) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    35496347, /* 51116 (1225) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 0,  6,  3] -1 */
    51203381, /* 51117 (1225) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 6,  0,  9] -1 */
    34024008, /* 51118 (1225) [ 0,  1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  0] -1 */
     1492707, /* 51119 (1225) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  3]  1 */
    51089657, /* 51120 (1225) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 6,  0,  3] -1 */
    52442922, /* 51121 (1225) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 6,  6,  0] -1 */
    18557870, /* 51122 (1225) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    17199741, /* 51123 (1225) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  9]  1 */
    17068521, /* 51124 (1225) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  3]  1 */
    18439610, /* 51125 (1225) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    52447782, /* 51126 (1225) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 6,  6,  0] -1 */
    18426650, /* 51127 (1225) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    51084797, /* 51128 (1225) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 6,  0,  3] -1 */
    34020120, /* 51129 (1225) [ 0, -1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    35613959, /* 51130 (1225) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 0,  6,  9] -1 */
    52561506, /* 51131 (1225) [ 0, -1,  0,  1,  0,  0,  0,  0, -1] [ 6,  6,  6] -1 */
      121460, /* 51132 (1225) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6]  1 */
    35500235, /* 51133 (1225) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 0,  6,  3] -1 */
    34142592, /* 51134 (1225) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  6] -1 */
    51207269, /* 51135 (1225) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 6,  0,  9] -1 */
    34137732, /* 51136 (1225) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  6] -1 */
     1597683, /* 51137 (1225) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  9]  1 */
       16484, /* 51138 (1226) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    17072573, /* 51139 (1226) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 6,  0,  3]  1 */
     1601735, /* 51140 (1226) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 0,  6,  9]  1 */
    35504931, /* 51141 (1226) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  3] -1 */
     1610643, /* 51142 (1226) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  9]  1 */
    17081481, /* 51143 (1226) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  3]  1 */
        7896, /* 51144 (1226) [ 0, -1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    18549282, /* 51145 (1226) [ 0, -1,  0,  1,  0,  0,  0,  0, -1] [ 6,  6,  6]  1 */
        3200, /* 51146 (1226) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    18544586, /* 51147 (1226) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    51211965, /* 51148 (1226) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  9] -1 */
    52451834, /* 51149 (1226) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
    35496347, /* 51150 (1226) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 0,  6,  3] -1 */
    51203381, /* 51151 (1226) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 6,  0,  9] -1 */
    52438874, /* 51152 (1226) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
     1606595, /* 51153 (1226) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 0,  6,  9]  1 */
    34133684, /* 51154 (1226) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    18553170, /* 51155 (1226) [ 0,  1,  0, -1,  0,  0,  0,  0, -1] [ 6,  6,  6]  1 */
    52442922, /* 51156 (1226) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 6,  6,  0] -1 */
    18557870, /* 51157 (1226) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    17068521, /* 51158 (1226) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  3]  1 */
    52447782, /* 51159 (1226) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 6,  6,  0] -1 */
       11784, /* 51160 (1226) [ 0,  1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    17077433, /* 51161 (1226) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 6,  0,  3]  1 */
    34146644, /* 51162 (1226) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    51198681, /* 51163 (1226) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  9] -1 */
    35500235, /* 51164 (1226) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 0,  6,  3] -1 */
    35491647, /* 51165 (1226) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  3] -1 */
    34142592, /* 51166 (1226) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  6] -1 */
    51207269, /* 51167 (1226) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 6,  0,  9] -1 */
    34137732, /* 51168 (1226) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  6] -1 */
     1597683, /* 51169 (1226) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  9]  1 */
       16484, /* 51170 (1227) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    17186457, /* 51171 (1227) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  9]  1 */
        7896, /* 51172 (1227) [ 0, -1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    35618819, /* 51173 (1227) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 0,  6,  9] -1 */
    18549282, /* 51174 (1227) [ 0, -1,  0,  1,  0,  0,  0,  0, -1] [ 6,  6,  6]  1 */
     1488011, /* 51175 (1227) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 0,  6,  3]  1 */
     1479423, /* 51176 (1227) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  3]  1 */
        3200, /* 51177 (1227) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    18544586, /* 51178 (1227) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    51080745, /* 51179 (1227) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  3] -1 */
    17195045, /* 51180 (1227) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 6,  0,  9]  1 */
    52451834, /* 51181 (1227) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
     1492707, /* 51182 (1227) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  3]  1 */
    52438874, /* 51183 (1227) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
    51089657, /* 51184 (1227) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 6,  0,  3] -1 */
    34133684, /* 51185 (1227) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    18553170, /* 51186 (1227) [ 0,  1,  0, -1,  0,  0,  0,  0, -1] [ 6,  6,  6]  1 */
    52442922, /* 51187 (1227) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 6,  6,  0] -1 */
    18557870, /* 51188 (1227) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    17199741, /* 51189 (1227) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  9]  1 */
     1484123, /* 51190 (1227) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 0,  6,  3]  1 */
    52447782, /* 51191 (1227) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 6,  6,  0] -1 */
    17191157, /* 51192 (1227) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 6,  0,  9]  1 */
       11784, /* 51193 (1227) [ 0,  1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    35622867, /* 51194 (1227) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  9] -1 */
    35609907, /* 51195 (1227) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  9] -1 */
    51084797, /* 51196 (1227) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 6,  0,  3] -1 */
    35613959, /* 51197 (1227) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 0,  6,  9] -1 */
    51093705, /* 51198 (1227) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  3] -1 */
    34146644, /* 51199 (1227) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    34142592, /* 51200 (1227) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  6] -1 */
    34137732, /* 51201 (1227) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  6] -1 */
       16484, /* 51202 (1228) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    35504931, /* 51203 (1228) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  3] -1 */
        7896, /* 51204 (1228) [ 0, -1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    35618819, /* 51205 (1228) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 0,  6,  9] -1 */
      134420, /* 51206 (1228) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6]  1 */
      130368, /* 51207 (1228) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  6]  1 */
    18549282, /* 51208 (1228) [ 0, -1,  0,  1,  0,  0,  0,  0, -1] [ 6,  6,  6]  1 */
        3200, /* 51209 (1228) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    18544586, /* 51210 (1228) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    51211965, /* 51211 (1228) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  9] -1 */
    51080745, /* 51212 (1228) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  3] -1 */
    35496347, /* 51213 (1228) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 0,  6,  3] -1 */
      125508, /* 51214 (1228) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  6]  1 */
    51203381, /* 51215 (1228) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 6,  0,  9] -1 */
    51089657, /* 51216 (1228) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 6,  0,  3] -1 */
    18553170, /* 51217 (1228) [ 0,  1,  0, -1,  0,  0,  0,  0, -1] [ 6,  6,  6]  1 */
    18557870, /* 51218 (1228) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    18439610, /* 51219 (1228) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    18426650, /* 51220 (1228) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
       11784, /* 51221 (1228) [ 0,  1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    35622867, /* 51222 (1228) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  9] -1 */
    35609907, /* 51223 (1228) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  9] -1 */
    51084797, /* 51224 (1228) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 6,  0,  3] -1 */
    35613959, /* 51225 (1228) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 0,  6,  9] -1 */
    51093705, /* 51226 (1228) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  3] -1 */
    51198681, /* 51227 (1228) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  9] -1 */
      121460, /* 51228 (1228) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6]  1 */
    18430698, /* 51229 (1228) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 6,  6,  0]  1 */
    35491647, /* 51230 (1228) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  3] -1 */
    35500235, /* 51231 (1228) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 0,  6,  3] -1 */
    51207269, /* 51232 (1228) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 6,  0,  9] -1 */
    18435558, /* 51233 (1228) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 6,  6,  0]  1 */
       16484, /* 51234 (1229) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    35504931, /* 51235 (1229) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  3] -1 */
     1610643, /* 51236 (1229) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  9]  1 */
    17081481, /* 51237 (1229) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  3]  1 */
    35618819, /* 51238 (1229) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 0,  6,  9] -1 */
      130368, /* 51239 (1229) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  6]  1 */
    52565394, /* 51240 (1229) [ 0,  1,  0, -1,  0,  0,  0,  0, -1] [ 6,  6,  6] -1 */
     1488011, /* 51241 (1229) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 0,  6,  3]  1 */
        3200, /* 51242 (1229) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    18544586, /* 51243 (1229) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    51211965, /* 51244 (1229) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  9] -1 */
    17195045, /* 51245 (1229) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 6,  0,  9]  1 */
    52451834, /* 51246 (1229) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
      125508, /* 51247 (1229) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  6]  1 */
    34024008, /* 51248 (1229) [ 0,  1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    52438874, /* 51249 (1229) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
    51089657, /* 51250 (1229) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 6,  0,  3] -1 */
    34133684, /* 51251 (1229) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    18557870, /* 51252 (1229) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    17068521, /* 51253 (1229) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  3]  1 */
     1484123, /* 51254 (1229) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 0,  6,  3]  1 */
    17191157, /* 51255 (1229) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 6,  0,  9]  1 */
    51084797, /* 51256 (1229) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 6,  0,  3] -1 */
    34020120, /* 51257 (1229) [ 0, -1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    35613959, /* 51258 (1229) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 0,  6,  9] -1 */
    34146644, /* 51259 (1229) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    51198681, /* 51260 (1229) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  9] -1 */
    52561506, /* 51261 (1229) [ 0, -1,  0,  1,  0,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    18430698, /* 51262 (1229) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 6,  6,  0]  1 */
    35491647, /* 51263 (1229) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  3] -1 */
    18435558, /* 51264 (1229) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 6,  6,  0]  1 */
     1597683, /* 51265 (1229) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  9]  1 */
       16484, /* 51266 (1230) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    17072573, /* 51267 (1230) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 6,  0,  3]  1 */
     1601735, /* 51268 (1230) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 0,  6,  9]  1 */
    35500721, /* 51269 (1230) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 0,  6,  3] -1 */
     1610643, /* 51270 (1230) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  9]  1 */
    17186457, /* 51271 (1230) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  9]  1 */
    17081481, /* 51272 (1230) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  3]  1 */
        7896, /* 51273 (1230) [ 0, -1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  0]  1 */
      134420, /* 51274 (1230) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6]  1 */
      130368, /* 51275 (1230) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  6]  1 */
    18549282, /* 51276 (1230) [ 0, -1,  0,  1,  0,  0,  0,  0, -1] [ 6,  6,  6]  1 */
    35623029, /* 51277 (1230) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  9] -1 */
    34138218, /* 51278 (1230) [ 0, -1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  6] -1 */
    52451996, /* 51279 (1230) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
     1479423, /* 51280 (1230) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  3]  1 */
        3200, /* 51281 (1230) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
     1488011, /* 51282 (1230) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 0,  6,  3]  1 */
    18544586, /* 51283 (1230) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    34142106, /* 51284 (1230) [ 0,  1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  6] -1 */
    52447296, /* 51285 (1230) [ 0,  1,  0, -1,  0,  0,  0,  0, -1] [ 6,  6,  0] -1 */
    17195045, /* 51286 (1230) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 6,  0,  9]  1 */
    51089171, /* 51287 (1230) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 6,  0,  3] -1 */
      125508, /* 51288 (1230) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  6]  1 */
     1492707, /* 51289 (1230) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  3]  1 */
    51085283, /* 51290 (1230) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 6,  0,  3] -1 */
    35614445, /* 51291 (1230) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 0,  6,  9] -1 */
     1606595, /* 51292 (1230) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 0,  6,  9]  1 */
    34146806, /* 51293 (1230) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    52556972, /* 51294 (1230) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    18553170, /* 51295 (1230) [ 0,  1,  0, -1,  0,  0,  0,  0, -1] [ 6,  6,  6]  1 */
    52438712, /* 51296 (1230) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
    34019634, /* 51297 (1230) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    34015586, /* 51298 (1230) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    52561020, /* 51299 (1230) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    18557870, /* 51300 (1230) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    17199741, /* 51301 (1230) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  9]  1 */
    17068521, /* 51302 (1230) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  3]  1 */
    18439610, /* 51303 (1230) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    51093867, /* 51304 (1230) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  3] -1 */
     1484123, /* 51305 (1230) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 0,  6,  3]  1 */
    35491809, /* 51306 (1230) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  3] -1 */
    18426650, /* 51307 (1230) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    17191157, /* 51308 (1230) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 6,  0,  9]  1 */
       11784, /* 51309 (1230) [ 0,  1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    34028546, /* 51310 (1230) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    52565880, /* 51311 (1230) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    51211803, /* 51312 (1230) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  9] -1 */
    34024494, /* 51313 (1230) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    35504769, /* 51314 (1230) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  3] -1 */
    17077433, /* 51315 (1230) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 6,  0,  3]  1 */
      121460, /* 51316 (1230) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6]  1 */
    18430698, /* 51317 (1230) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 6,  6,  0]  1 */
    51202895, /* 51318 (1230) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 6,  0,  9] -1 */
    51080583, /* 51319 (1230) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  3] -1 */
    35495861, /* 51320 (1230) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 0,  6,  3] -1 */
    51198843, /* 51321 (1230) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  9] -1 */
    52569932, /* 51322 (1230) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    52443408, /* 51323 (1230) [ 0, -1,  0,  1,  0,  0,  0,  0, -1] [ 6,  6,  0] -1 */
    35609745, /* 51324 (1230) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  9] -1 */
    35618333, /* 51325 (1230) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 0,  6,  9] -1 */
    34133522, /* 51326 (1230) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    51207755, /* 51327 (1230) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 6,  0,  9] -1 */
    18435558, /* 51328 (1230) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 6,  6,  0]  1 */
     1597683, /* 51329 (1230) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  9]  1 */
       16484, /* 51330 (1221) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    26284217, /* 51331 (1221) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 9,  3,  3]  1 */
    10813379, /* 51332 (1221) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 3,  9,  9]  1 */
      134418, /* 51333 (1221) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  6]  1 */
    18544584, /* 51334 (1221) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
    18439608, /* 51335 (1221) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
     9396687, /* 51336 (1221) [ 0, -1,  0,  1,  0,  0,  0,  0, -1] [ 3,  3,  9]  1 */
     1551596, /* 51337 (1221) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
    26289075, /* 51338 (1221) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 9,  3,  3]  1 */
    27701877, /* 51339 (1221) [ 0, -1,  0,  1,  0,  0,  0,  0, -1] [ 9,  9,  3]  1 */
    27705767, /* 51340 (1221) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 9,  9,  3]  1 */
        3198, /* 51341 (1221) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
     1420376, /* 51342 (1221) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  0]  1 */
    17127410, /* 51343 (1221) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
     9400577, /* 51344 (1221) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 3,  3,  9]  1 */
     9278103, /* 51345 (1221) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 3,  3,  3]  1 */
     1433658, /* 51346 (1221) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  0]  1 */
    27824351, /* 51347 (1221) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 9,  9,  9]  1 */
    10699653, /* 51348 (1221) [ 0,  1,  0, -1,  0,  0,  0,  0, -1] [ 3,  9,  3]  1 */
    18557870, /* 51349 (1221) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    17140692, /* 51350 (1221) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6]  1 */
    17009472, /* 51351 (1221) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  0]  1 */
    17022434, /* 51352 (1221) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  0]  1 */
    10695767, /* 51353 (1221) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 3,  9,  3]  1 */
    18426650, /* 51354 (1221) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    26402801, /* 51355 (1221) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 9,  3,  9]  1 */
    26406687, /* 51356 (1221) [ 0,  1,  0, -1,  0,  0,  0,  0, -1] [ 9,  3,  9]  1 */
     9282965, /* 51357 (1221) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 3,  3,  3]  1 */
      121460, /* 51358 (1221) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6]  1 */
    27819489, /* 51359 (1221) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 9,  9,  9]  1 */
    10818237, /* 51360 (1221) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 3,  9,  9]  1 */
     1538634, /* 51361 (1221) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
       16484, /* 51362 (1222) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    26284217, /* 51363 (1222) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 9,  3,  3]  1 */
    10813379, /* 51364 (1222) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 3,  9,  9]  1 */
    35445882, /* 51365 (1222) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  0] -1 */
      134418, /* 51366 (1222) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  6]  1 */
    18544584, /* 51367 (1222) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
    18439608, /* 51368 (1222) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
     9396687, /* 51369 (1222) [ 0, -1,  0,  1,  0,  0,  0,  0, -1] [ 3,  3,  9]  1 */
    61836575, /* 51370 (1222) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 9,  9,  9] -1 */
     1551596, /* 51371 (1222) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
    26289075, /* 51372 (1222) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 9,  3,  3]  1 */
    27701877, /* 51373 (1222) [ 0, -1,  0,  1,  0,  0,  0,  0, -1] [ 9,  9,  3]  1 */
    44711877, /* 51374 (1222) [ 0,  1,  0, -1,  0,  0,  0,  0, -1] [ 3,  9,  3] -1 */
    27705767, /* 51375 (1222) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 9,  9,  3]  1 */
        3198, /* 51376 (1222) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
     1420376, /* 51377 (1222) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  0]  1 */
    17127410, /* 51378 (1222) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
    51152916, /* 51379 (1222) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6] -1 */
    51021696, /* 51380 (1222) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  0] -1 */
    52570094, /* 51381 (1222) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
     9400577, /* 51382 (1222) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 3,  3,  9]  1 */
    51034658, /* 51383 (1222) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  0] -1 */
    44707991, /* 51384 (1222) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 3,  9,  3] -1 */
     9278103, /* 51385 (1222) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 3,  3,  3]  1 */
    60415025, /* 51386 (1222) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 9,  3,  9] -1 */
    60418911, /* 51387 (1222) [ 0,  1,  0, -1,  0,  0,  0,  0, -1] [ 9,  3,  9] -1 */
     1433658, /* 51388 (1222) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  0]  1 */
    52438874, /* 51389 (1222) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
    43295189, /* 51390 (1222) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 3,  3,  3] -1 */
    27824351, /* 51391 (1222) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 9,  9,  9]  1 */
    34133684, /* 51392 (1222) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    10699653, /* 51393 (1222) [ 0,  1,  0, -1,  0,  0,  0,  0, -1] [ 3,  9,  3]  1 */
    34028708, /* 51394 (1222) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    61831713, /* 51395 (1222) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 9,  9,  9] -1 */
    18557870, /* 51396 (1222) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    17140692, /* 51397 (1222) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6]  1 */
    17009472, /* 51398 (1222) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  0]  1 */
    17022434, /* 51399 (1222) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  0]  1 */
    10695767, /* 51400 (1222) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 3,  9,  3]  1 */
    44830461, /* 51401 (1222) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 3,  9,  9] -1 */
    18426650, /* 51402 (1222) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    26402801, /* 51403 (1222) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 9,  3,  9]  1 */
    26406687, /* 51404 (1222) [ 0,  1,  0, -1,  0,  0,  0,  0, -1] [ 9,  3,  9]  1 */
    34146642, /* 51405 (1222) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
    35550858, /* 51406 (1222) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6] -1 */
    60296441, /* 51407 (1222) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 9,  3,  3] -1 */
    43408911, /* 51408 (1222) [ 0, -1,  0,  1,  0,  0,  0,  0, -1] [ 3,  3,  9] -1 */
    44825603, /* 51409 (1222) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 3,  9,  9] -1 */
     9282965, /* 51410 (1222) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 3,  3,  3]  1 */
    52451832, /* 51411 (1222) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
    52556808, /* 51412 (1222) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    61714101, /* 51413 (1222) [ 0, -1,  0,  1,  0,  0,  0,  0, -1] [ 9,  9,  3] -1 */
      121460, /* 51414 (1222) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6]  1 */
    27819489, /* 51415 (1222) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 9,  9,  9]  1 */
    34015422, /* 51416 (1222) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    61717991, /* 51417 (1222) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 9,  9,  3] -1 */
    60301299, /* 51418 (1222) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 9,  3,  3] -1 */
    35563820, /* 51419 (1222) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
    35432600, /* 51420 (1222) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  0] -1 */
    51139634, /* 51421 (1222) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
    43412801, /* 51422 (1222) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 3,  3,  9] -1 */
    43290327, /* 51423 (1222) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 3,  3,  3] -1 */
    10818237, /* 51424 (1222) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 3,  9,  9]  1 */
     1538634, /* 51425 (1222) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
       16484, /* 51426 (1223) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    26284217, /* 51427 (1223) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 9,  3,  3]  1 */
    10813379, /* 51428 (1223) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 3,  9,  9]  1 */
    35445882, /* 51429 (1223) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  0] -1 */
     1551596, /* 51430 (1223) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
    44711877, /* 51431 (1223) [ 0,  1,  0, -1,  0,  0,  0,  0, -1] [ 3,  9,  3] -1 */
    27705767, /* 51432 (1223) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 9,  9,  3]  1 */
     1420376, /* 51433 (1223) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  0]  1 */
    17127410, /* 51434 (1223) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
    51152916, /* 51435 (1223) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6] -1 */
    51021696, /* 51436 (1223) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  0] -1 */
     9400577, /* 51437 (1223) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 3,  3,  9]  1 */
    60418911, /* 51438 (1223) [ 0,  1,  0, -1,  0,  0,  0,  0, -1] [ 9,  3,  9] -1 */
    27824351, /* 51439 (1223) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 9,  9,  9]  1 */
    61831713, /* 51440 (1223) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 9,  9,  9] -1 */
    18557870, /* 51441 (1223) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    17022434, /* 51442 (1223) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  0]  1 */
    10695767, /* 51443 (1223) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 3,  9,  3]  1 */
    44830461, /* 51444 (1223) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 3,  9,  9] -1 */
    18426650, /* 51445 (1223) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    26402801, /* 51446 (1223) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 9,  3,  9]  1 */
    34146642, /* 51447 (1223) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
    35550858, /* 51448 (1223) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6] -1 */
    43408911, /* 51449 (1223) [ 0, -1,  0,  1,  0,  0,  0,  0, -1] [ 3,  3,  9] -1 */
     9282965, /* 51450 (1223) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 3,  3,  3]  1 */
    52451832, /* 51451 (1223) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
    52556808, /* 51452 (1223) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    61714101, /* 51453 (1223) [ 0, -1,  0,  1,  0,  0,  0,  0, -1] [ 9,  9,  3] -1 */
      121460, /* 51454 (1223) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6]  1 */
    34015422, /* 51455 (1223) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    60301299, /* 51456 (1223) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 9,  3,  3] -1 */
    43290327, /* 51457 (1223) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 3,  3,  3] -1 */
       16484, /* 51458 (1224) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    26284217, /* 51459 (1224) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 9,  3,  3]  1 */
    10813379, /* 51460 (1224) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 3,  9,  9]  1 */
    18544584, /* 51461 (1224) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
    26289075, /* 51462 (1224) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 9,  3,  3]  1 */
    44711877, /* 51463 (1224) [ 0,  1,  0, -1,  0,  0,  0,  0, -1] [ 3,  9,  3] -1 */
        3198, /* 51464 (1224) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
     1420376, /* 51465 (1224) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  0]  1 */
    17127410, /* 51466 (1224) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
    51021696, /* 51467 (1224) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  0] -1 */
    51034658, /* 51468 (1224) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  0] -1 */
    44707991, /* 51469 (1224) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 3,  9,  3] -1 */
     9278103, /* 51470 (1224) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 3,  3,  3]  1 */
    60415025, /* 51471 (1224) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 9,  3,  9] -1 */
    60418911, /* 51472 (1224) [ 0,  1,  0, -1,  0,  0,  0,  0, -1] [ 9,  3,  9] -1 */
     1433658, /* 51473 (1224) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  0]  1 */
    52438874, /* 51474 (1224) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
    27824351, /* 51475 (1224) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 9,  9,  9]  1 */
    34133684, /* 51476 (1224) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    18557870, /* 51477 (1224) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    17140692, /* 51478 (1224) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6]  1 */
    34146642, /* 51479 (1224) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
    35550858, /* 51480 (1224) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6] -1 */
    43408911, /* 51481 (1224) [ 0, -1,  0,  1,  0,  0,  0,  0, -1] [ 3,  3,  9] -1 */
     9282965, /* 51482 (1224) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 3,  3,  3]  1 */
    52451832, /* 51483 (1224) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
    61714101, /* 51484 (1224) [ 0, -1,  0,  1,  0,  0,  0,  0, -1] [ 9,  9,  3] -1 */
    35563820, /* 51485 (1224) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
    27819489, /* 51486 (1224) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 9,  9,  9]  1 */
    61717991, /* 51487 (1224) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 9,  9,  3] -1 */
    43412801, /* 51488 (1224) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 3,  3,  9] -1 */
    10818237, /* 51489 (1224) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 3,  9,  9]  1 */
       16484, /* 51490 (1225) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
      134418, /* 51491 (1225) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  6]  1 */
    18544584, /* 51492 (1225) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
    18439608, /* 51493 (1225) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
    61836575, /* 51494 (1225) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 9,  9,  9] -1 */
     1551596, /* 51495 (1225) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
    44711877, /* 51496 (1225) [ 0,  1,  0, -1,  0,  0,  0,  0, -1] [ 3,  9,  3] -1 */
        3198, /* 51497 (1225) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
     1420376, /* 51498 (1225) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  0]  1 */
    17127410, /* 51499 (1225) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
    44707991, /* 51500 (1225) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 3,  9,  3] -1 */
    60415025, /* 51501 (1225) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 9,  3,  9] -1 */
    60418911, /* 51502 (1225) [ 0,  1,  0, -1,  0,  0,  0,  0, -1] [ 9,  3,  9] -1 */
     1433658, /* 51503 (1225) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  0]  1 */
    43295189, /* 51504 (1225) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 3,  3,  3] -1 */
    61831713, /* 51505 (1225) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 9,  9,  9] -1 */
    18557870, /* 51506 (1225) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    17140692, /* 51507 (1225) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6]  1 */
    17009472, /* 51508 (1225) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  0]  1 */
    17022434, /* 51509 (1225) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  0]  1 */
    44830461, /* 51510 (1225) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 3,  9,  9] -1 */
    18426650, /* 51511 (1225) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    60296441, /* 51512 (1225) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 9,  3,  3] -1 */
    43408911, /* 51513 (1225) [ 0, -1,  0,  1,  0,  0,  0,  0, -1] [ 3,  3,  9] -1 */
    44825603, /* 51514 (1225) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 3,  9,  9] -1 */
    61714101, /* 51515 (1225) [ 0, -1,  0,  1,  0,  0,  0,  0, -1] [ 9,  9,  3] -1 */
      121460, /* 51516 (1225) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6]  1 */
    61717991, /* 51517 (1225) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 9,  9,  3] -1 */
    60301299, /* 51518 (1225) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 9,  3,  3] -1 */
    43412801, /* 51519 (1225) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 3,  3,  9] -1 */
    43290327, /* 51520 (1225) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 3,  3,  3] -1 */
     1538634, /* 51521 (1225) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
       16484, /* 51522 (1226) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    26284217, /* 51523 (1226) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 9,  3,  3]  1 */
    10813379, /* 51524 (1226) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 3,  9,  9]  1 */
    35445882, /* 51525 (1226) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  0] -1 */
      134418, /* 51526 (1226) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  6]  1 */
    18439608, /* 51527 (1226) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
     9396687, /* 51528 (1226) [ 0, -1,  0,  1,  0,  0,  0,  0, -1] [ 3,  3,  9]  1 */
    27701877, /* 51529 (1226) [ 0, -1,  0,  1,  0,  0,  0,  0, -1] [ 9,  9,  3]  1 */
     1420376, /* 51530 (1226) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  0]  1 */
    17127410, /* 51531 (1226) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
    51152916, /* 51532 (1226) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6] -1 */
    51034658, /* 51533 (1226) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  0] -1 */
    44707991, /* 51534 (1226) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 3,  9,  3] -1 */
    60415025, /* 51535 (1226) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 9,  3,  9] -1 */
    52438874, /* 51536 (1226) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
    27824351, /* 51537 (1226) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 9,  9,  9]  1 */
    34133684, /* 51538 (1226) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    10699653, /* 51539 (1226) [ 0,  1,  0, -1,  0,  0,  0,  0, -1] [ 3,  9,  3]  1 */
    61831713, /* 51540 (1226) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 9,  9,  9] -1 */
    18557870, /* 51541 (1226) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    17009472, /* 51542 (1226) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  0]  1 */
    44830461, /* 51543 (1226) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 3,  9,  9] -1 */
    26406687, /* 51544 (1226) [ 0,  1,  0, -1,  0,  0,  0,  0, -1] [ 9,  3,  9]  1 */
     9282965, /* 51545 (1226) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 3,  3,  3]  1 */
    35563820, /* 51546 (1226) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
    52556808, /* 51547 (1226) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    61717991, /* 51548 (1226) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 9,  9,  3] -1 */
    34015422, /* 51549 (1226) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    60301299, /* 51550 (1226) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 9,  3,  3] -1 */
    43412801, /* 51551 (1226) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 3,  3,  9] -1 */
    43290327, /* 51552 (1226) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 3,  3,  3] -1 */
     1538634, /* 51553 (1226) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
       16484, /* 51554 (1227) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    18544584, /* 51555 (1227) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
     9396687, /* 51556 (1227) [ 0, -1,  0,  1,  0,  0,  0,  0, -1] [ 3,  3,  9]  1 */
    61836575, /* 51557 (1227) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 9,  9,  9] -1 */
    27701877, /* 51558 (1227) [ 0, -1,  0,  1,  0,  0,  0,  0, -1] [ 9,  9,  3]  1 */
    27705767, /* 51559 (1227) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 9,  9,  3]  1 */
        3198, /* 51560 (1227) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
     1420376, /* 51561 (1227) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  0]  1 */
    17127410, /* 51562 (1227) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
    51021696, /* 51563 (1227) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  0] -1 */
     9400577, /* 51564 (1227) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 3,  3,  9]  1 */
    51034658, /* 51565 (1227) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  0] -1 */
     1433658, /* 51566 (1227) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  0]  1 */
    52438874, /* 51567 (1227) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
    43295189, /* 51568 (1227) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 3,  3,  3] -1 */
    34133684, /* 51569 (1227) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    10699653, /* 51570 (1227) [ 0,  1,  0, -1,  0,  0,  0,  0, -1] [ 3,  9,  3]  1 */
    61831713, /* 51571 (1227) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 9,  9,  9] -1 */
    18557870, /* 51572 (1227) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    17140692, /* 51573 (1227) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6]  1 */
    10695767, /* 51574 (1227) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 3,  9,  3]  1 */
    44830461, /* 51575 (1227) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 3,  9,  9] -1 */
    26402801, /* 51576 (1227) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 9,  3,  9]  1 */
    26406687, /* 51577 (1227) [ 0,  1,  0, -1,  0,  0,  0,  0, -1] [ 9,  3,  9]  1 */
    34146642, /* 51578 (1227) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
    35550858, /* 51579 (1227) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6] -1 */
    60296441, /* 51580 (1227) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 9,  3,  3] -1 */
    44825603, /* 51581 (1227) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 3,  9,  9] -1 */
    52451832, /* 51582 (1227) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
    35563820, /* 51583 (1227) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
    60301299, /* 51584 (1227) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 9,  3,  3] -1 */
    43290327, /* 51585 (1227) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 3,  3,  3] -1 */
       16484, /* 51586 (1228) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    35445882, /* 51587 (1228) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  0] -1 */
     9396687, /* 51588 (1228) [ 0, -1,  0,  1,  0,  0,  0,  0, -1] [ 3,  3,  9]  1 */
    61836575, /* 51589 (1228) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 9,  9,  9] -1 */
     1551596, /* 51590 (1228) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
    26289075, /* 51591 (1228) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 9,  3,  3]  1 */
    27701877, /* 51592 (1228) [ 0, -1,  0,  1,  0,  0,  0,  0, -1] [ 9,  9,  3]  1 */
     1420376, /* 51593 (1228) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  0]  1 */
    17127410, /* 51594 (1228) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
    51152916, /* 51595 (1228) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6] -1 */
    51021696, /* 51596 (1228) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  0] -1 */
    44707991, /* 51597 (1228) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 3,  9,  3] -1 */
     9278103, /* 51598 (1228) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 3,  3,  3]  1 */
    60415025, /* 51599 (1228) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 9,  3,  9] -1 */
    43295189, /* 51600 (1228) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 3,  3,  3] -1 */
    10699653, /* 51601 (1228) [ 0,  1,  0, -1,  0,  0,  0,  0, -1] [ 3,  9,  3]  1 */
    18557870, /* 51602 (1228) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    17022434, /* 51603 (1228) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  0]  1 */
    18426650, /* 51604 (1228) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    26406687, /* 51605 (1228) [ 0,  1,  0, -1,  0,  0,  0,  0, -1] [ 9,  3,  9]  1 */
    34146642, /* 51606 (1228) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
    35550858, /* 51607 (1228) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6] -1 */
    60296441, /* 51608 (1228) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 9,  3,  3] -1 */
    44825603, /* 51609 (1228) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 3,  9,  9] -1 */
    52451832, /* 51610 (1228) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
    52556808, /* 51611 (1228) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
      121460, /* 51612 (1228) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6]  1 */
    27819489, /* 51613 (1228) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 9,  9,  9]  1 */
    34015422, /* 51614 (1228) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    61717991, /* 51615 (1228) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 9,  9,  3] -1 */
    43412801, /* 51616 (1228) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 3,  3,  9] -1 */
    10818237, /* 51617 (1228) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 3,  9,  9]  1 */
       16484, /* 51618 (1229) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    35445882, /* 51619 (1229) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  0] -1 */
      134418, /* 51620 (1229) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  6]  1 */
    18439608, /* 51621 (1229) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
    61836575, /* 51622 (1229) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 9,  9,  9] -1 */
    26289075, /* 51623 (1229) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 9,  3,  3]  1 */
    44711877, /* 51624 (1229) [ 0,  1,  0, -1,  0,  0,  0,  0, -1] [ 3,  9,  3] -1 */
    27705767, /* 51625 (1229) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 9,  9,  3]  1 */
     1420376, /* 51626 (1229) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  0]  1 */
    17127410, /* 51627 (1229) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
    51152916, /* 51628 (1229) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6] -1 */
     9400577, /* 51629 (1229) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 3,  3,  9]  1 */
    51034658, /* 51630 (1229) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  0] -1 */
     9278103, /* 51631 (1229) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 3,  3,  3]  1 */
    60418911, /* 51632 (1229) [ 0,  1,  0, -1,  0,  0,  0,  0, -1] [ 9,  3,  9] -1 */
    52438874, /* 51633 (1229) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
    43295189, /* 51634 (1229) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 3,  3,  3] -1 */
    34133684, /* 51635 (1229) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    18557870, /* 51636 (1229) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    17009472, /* 51637 (1229) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  0]  1 */
    10695767, /* 51638 (1229) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 3,  9,  3]  1 */
    26402801, /* 51639 (1229) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 9,  3,  9]  1 */
    60296441, /* 51640 (1229) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 9,  3,  3] -1 */
    43408911, /* 51641 (1229) [ 0, -1,  0,  1,  0,  0,  0,  0, -1] [ 3,  3,  9] -1 */
    44825603, /* 51642 (1229) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 3,  9,  9] -1 */
    35563820, /* 51643 (1229) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
    52556808, /* 51644 (1229) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    61714101, /* 51645 (1229) [ 0, -1,  0,  1,  0,  0,  0,  0, -1] [ 9,  9,  3] -1 */
    27819489, /* 51646 (1229) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 9,  9,  9]  1 */
    34015422, /* 51647 (1229) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    10818237, /* 51648 (1229) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 3,  9,  9]  1 */
     1538634, /* 51649 (1229) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
       16484, /* 51650 (1230) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    26284217, /* 51651 (1230) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 9,  3,  3]  1 */
    10813379, /* 51652 (1230) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 3,  9,  9]  1 */
    61718477, /* 51653 (1230) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 9,  9,  3] -1 */
      134418, /* 51654 (1230) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  6]  1 */
    18544584, /* 51655 (1230) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
    18439608, /* 51656 (1230) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
     9396687, /* 51657 (1230) [ 0, -1,  0,  1,  0,  0,  0,  0, -1] [ 3,  3,  9]  1 */
     1551596, /* 51658 (1230) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
    26289075, /* 51659 (1230) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 9,  3,  3]  1 */
    27701877, /* 51660 (1230) [ 0, -1,  0,  1,  0,  0,  0,  0, -1] [ 9,  9,  3]  1 */
    35563980, /* 51661 (1230) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6] -1 */
    43290813, /* 51662 (1230) [ 0, -1,  0,  1,  0,  0,  0,  0, -1] [ 3,  3,  3] -1 */
    52451996, /* 51663 (1230) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
        3198, /* 51664 (1230) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
     1420376, /* 51665 (1230) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  0]  1 */
    27705767, /* 51666 (1230) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 9,  9,  3]  1 */
    17127410, /* 51667 (1230) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
    60300813, /* 51668 (1230) [ 0,  1,  0, -1,  0,  0,  0,  0, -1] [ 9,  3,  3] -1 */
    44829975, /* 51669 (1230) [ 0,  1,  0, -1,  0,  0,  0,  0, -1] [ 3,  9,  9] -1 */
     9400577, /* 51670 (1230) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 3,  3,  9]  1 */
    43294703, /* 51671 (1230) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 3,  3,  3] -1 */
     9278103, /* 51672 (1230) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 3,  3,  3]  1 */
     1433658, /* 51673 (1230) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  0]  1 */
    60296927, /* 51674 (1230) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 9,  3,  3] -1 */
    44826089, /* 51675 (1230) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 3,  9,  9] -1 */
    27824351, /* 51676 (1230) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 9,  9,  9]  1 */
    34146806, /* 51677 (1230) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    52556972, /* 51678 (1230) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    10699653, /* 51679 (1230) [ 0,  1,  0, -1,  0,  0,  0,  0, -1] [ 3,  9,  3]  1 */
    51021536, /* 51680 (1230) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  0] -1 */
    43408425, /* 51681 (1230) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 3,  3,  9] -1 */
    34015586, /* 51682 (1230) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    61713615, /* 51683 (1230) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 9,  9,  3] -1 */
    18557870, /* 51684 (1230) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    17140692, /* 51685 (1230) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6]  1 */
    17009472, /* 51686 (1230) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  0]  1 */
    17022434, /* 51687 (1230) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  0]  1 */
    51034818, /* 51688 (1230) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  0] -1 */
    10695767, /* 51689 (1230) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 3,  9,  3]  1 */
    35432760, /* 51690 (1230) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  0] -1 */
    18426650, /* 51691 (1230) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    26402801, /* 51692 (1230) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 9,  3,  9]  1 */
    26406687, /* 51693 (1230) [ 0,  1,  0, -1,  0,  0,  0,  0, -1] [ 9,  3,  9]  1 */
    35445722, /* 51694 (1230) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  0] -1 */
    44712363, /* 51695 (1230) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 3,  9,  3] -1 */
    52569930, /* 51696 (1230) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    60419397, /* 51697 (1230) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 9,  3,  9] -1 */
    34028544, /* 51698 (1230) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
     9282965, /* 51699 (1230) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 3,  3,  3]  1 */
      121460, /* 51700 (1230) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6]  1 */
    27819489, /* 51701 (1230) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 9,  9,  9]  1 */
    60414539, /* 51702 (1230) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 9,  3,  9] -1 */
    52438710, /* 51703 (1230) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
    44707505, /* 51704 (1230) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 3,  9,  3] -1 */
    51139794, /* 51705 (1230) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6] -1 */
    51152756, /* 51706 (1230) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
    61832199, /* 51707 (1230) [ 0, -1,  0,  1,  0,  0,  0,  0, -1] [ 9,  9,  9] -1 */
    34133520, /* 51708 (1230) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
    61836089, /* 51709 (1230) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 9,  9,  9] -1 */
    35550698, /* 51710 (1230) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
    43413287, /* 51711 (1230) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 3,  3,  9] -1 */
    10818237, /* 51712 (1230) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 3,  9,  9]  1 */
     1538634, /* 51713 (1230) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
       16484, /* 51714 (1231) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
        7817, /* 51715 (1231) [ 0, -1,  0,  1, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
        5225, /* 51716 (1231) [-1,  1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  0]  1 */
       16484, /* 51717 (1232) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34017449, /* 51718 (1232) [-1,  1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    34020041, /* 51719 (1232) [ 0, -1,  0,  1, -1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
        5225, /* 51720 (1232) [-1,  1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  0]  1 */
        7817, /* 51721 (1232) [ 0, -1,  0,  1, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34028708, /* 51722 (1232) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
       16484, /* 51723 (1233) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34138139, /* 51724 (1233) [ 0, -1,  0,  1, -1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
        5225, /* 51725 (1233) [-1,  1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  0]  1 */
        7817, /* 51726 (1233) [ 0, -1,  0,  1, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34146806, /* 51727 (1233) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    34135547, /* 51728 (1233) [-1,  1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  6] -1 */
       16484, /* 51729 (1234) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
      162689, /* 51730 (1234) [-1,  1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  8]  1 */
       86549, /* 51731 (1234) [ 0, -1,  0,  1, -1,  0,  0,  0,  1] [ 0,  0,  4]  1 */
       16484, /* 51732 (1235) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
      162689, /* 51733 (1235) [-1,  1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  8]  1 */
       86549, /* 51734 (1235) [ 0, -1,  0,  1, -1,  0,  0,  0,  1] [ 0,  0,  4]  1 */
    34174913, /* 51735 (1235) [-1,  1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  8] -1 */
    34098773, /* 51736 (1235) [ 0, -1,  0,  1, -1,  0,  0,  0,  1] [ 0,  0,  4] -1 */
    34028708, /* 51737 (1235) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
       16484, /* 51738 (1236) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
      162689, /* 51739 (1236) [-1,  1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  8]  1 */
       86549, /* 51740 (1236) [ 0, -1,  0,  1, -1,  0,  0,  0,  1] [ 0,  0,  4]  1 */
    34056815, /* 51741 (1236) [-1,  1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  2] -1 */
    34216871, /* 51742 (1236) [ 0, -1,  0,  1, -1,  0,  0,  0,  1] [ 0,  0, 10] -1 */
    34146806, /* 51743 (1236) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
       16484, /* 51744 (1237) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
      165281, /* 51745 (1237) [ 0, -1,  0,  1, -1,  0,  0,  0,  1] [ 0,  0,  8]  1 */
       83957, /* 51746 (1237) [-1,  1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  4]  1 */
       16484, /* 51747 (1238) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34177505, /* 51748 (1238) [ 0, -1,  0,  1, -1,  0,  0,  0,  1] [ 0,  0,  8] -1 */
    34096181, /* 51749 (1238) [-1,  1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  4] -1 */
       83957, /* 51750 (1238) [-1,  1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  4]  1 */
      165281, /* 51751 (1238) [ 0, -1,  0,  1, -1,  0,  0,  0,  1] [ 0,  0,  8]  1 */
    34028708, /* 51752 (1238) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
       16484, /* 51753 (1239) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34214279, /* 51754 (1239) [-1,  1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0, 10] -1 */
       83957, /* 51755 (1239) [-1,  1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  4]  1 */
    34059407, /* 51756 (1239) [ 0, -1,  0,  1, -1,  0,  0,  0,  1] [ 0,  0,  2] -1 */
      165281, /* 51757 (1239) [ 0, -1,  0,  1, -1,  0,  0,  0,  1] [ 0,  0,  8]  1 */
    34146806, /* 51758 (1239) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
       16484, /* 51759 (1240) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    23714816, /* 51760 (1240) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 8,  4,  4]  1 */
    13389665, /* 51761 (1240) [-1,  1,  0, -1,  0,  0,  0,  0,  1] [ 4,  8,  8]  1 */
    13400924, /* 51762 (1240) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 4,  8,  8]  1 */
    23703557, /* 51763 (1240) [-1,  1,  0, -1,  0,  0,  0,  0,  1] [ 8,  4,  4]  1 */
        5225, /* 51764 (1240) [-1,  1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    23706149, /* 51765 (1240) [ 0, -1,  0,  1, -1,  0,  0,  0,  1] [ 8,  4,  4]  1 */
        7817, /* 51766 (1240) [ 0, -1,  0,  1, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    13392257, /* 51767 (1240) [ 0, -1,  0,  1, -1,  0,  0,  0,  1] [ 4,  8,  8]  1 */
       16484, /* 51768 (1241) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    23714816, /* 51769 (1241) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 8,  4,  4]  1 */
    13389665, /* 51770 (1241) [-1,  1,  0, -1,  0,  0,  0,  0,  1] [ 4,  8,  8]  1 */
    47413148, /* 51771 (1241) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 4,  8,  8] -1 */
    34017449, /* 51772 (1241) [-1,  1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    13400924, /* 51773 (1241) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 4,  8,  8]  1 */
    34020041, /* 51774 (1241) [ 0, -1,  0,  1, -1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    57718373, /* 51775 (1241) [ 0, -1,  0,  1, -1,  0,  0,  0,  1] [ 8,  4,  4] -1 */
    23703557, /* 51776 (1241) [-1,  1,  0, -1,  0,  0,  0,  0,  1] [ 8,  4,  4]  1 */
        5225, /* 51777 (1241) [-1,  1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    47404481, /* 51778 (1241) [ 0, -1,  0,  1, -1,  0,  0,  0,  1] [ 4,  8,  8] -1 */
    23706149, /* 51779 (1241) [ 0, -1,  0,  1, -1,  0,  0,  0,  1] [ 8,  4,  4]  1 */
        7817, /* 51780 (1241) [ 0, -1,  0,  1, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    57727040, /* 51781 (1241) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 8,  4,  4] -1 */
    34028708, /* 51782 (1241) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    47401889, /* 51783 (1241) [-1,  1,  0, -1,  0,  0,  0,  0,  1] [ 4,  8,  8] -1 */
    13392257, /* 51784 (1241) [ 0, -1,  0,  1, -1,  0,  0,  0,  1] [ 4,  8,  8]  1 */
    57715781, /* 51785 (1241) [-1,  1,  0, -1,  0,  0,  0,  0,  1] [ 8,  4,  4] -1 */
       16484, /* 51786 (1242) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    23714816, /* 51787 (1242) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 8,  4,  4]  1 */
    13389665, /* 51788 (1242) [-1,  1,  0, -1,  0,  0,  0,  0,  1] [ 4,  8,  8]  1 */
    34138139, /* 51789 (1242) [ 0, -1,  0,  1, -1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    47283791, /* 51790 (1242) [-1,  1,  0, -1,  0,  0,  0,  0,  1] [ 4,  8,  2] -1 */
    57833879, /* 51791 (1242) [-1,  1,  0, -1,  0,  0,  0,  0,  1] [ 8,  4, 10] -1 */
    13400924, /* 51792 (1242) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 4,  8,  8]  1 */
    57845138, /* 51793 (1242) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 8,  4, 10] -1 */
    47286383, /* 51794 (1242) [ 0, -1,  0,  1, -1,  0,  0,  0,  1] [ 4,  8,  2] -1 */
    23703557, /* 51795 (1242) [-1,  1,  0, -1,  0,  0,  0,  0,  1] [ 8,  4,  4]  1 */
        5225, /* 51796 (1242) [-1,  1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    23706149, /* 51797 (1242) [ 0, -1,  0,  1, -1,  0,  0,  0,  1] [ 8,  4,  4]  1 */
        7817, /* 51798 (1242) [ 0, -1,  0,  1, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34135547, /* 51799 (1242) [-1,  1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    34146806, /* 51800 (1242) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    47295050, /* 51801 (1242) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 4,  8,  2] -1 */
    57836471, /* 51802 (1242) [ 0, -1,  0,  1, -1,  0,  0,  0,  1] [ 8,  4, 10] -1 */
    13392257, /* 51803 (1242) [ 0, -1,  0,  1, -1,  0,  0,  0,  1] [ 4,  8,  8]  1 */
       16484, /* 51804 (1240) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
       10816, /* 51805 (1240) [ 0,  0,  1,  1,  0,  0,  0,  1,  0] [ 0,  0,  0]  1 */
       12064, /* 51806 (1240) [ 0,  1,  0,  0,  0,  1,  1,  0,  0] [ 0,  0,  0]  1 */
       16484, /* 51807 (1241) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
       10816, /* 51808 (1241) [ 0,  0,  1,  1,  0,  0,  0,  1,  0] [ 0,  0,  0]  1 */
    34024288, /* 51809 (1241) [ 0,  1,  0,  0,  0,  1,  1,  0,  0] [ 0,  0,  0] -1 */
       12064, /* 51810 (1241) [ 0,  1,  0,  0,  0,  1,  1,  0,  0] [ 0,  0,  0]  1 */
    34028708, /* 51811 (1241) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    34023040, /* 51812 (1241) [ 0,  0,  1,  1,  0,  0,  0,  1,  0] [ 0,  0,  0] -1 */
       16484, /* 51813 (1242) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
       10816, /* 51814 (1242) [ 0,  0,  1,  1,  0,  0,  0,  1,  0] [ 0,  0,  0]  1 */
    52564426, /* 51815 (1242) [ 0,  0,  1,  1,  0,  0,  0,  1,  0] [ 6,  6,  6] -1 */
       12064, /* 51816 (1242) [ 0,  1,  0,  0,  0,  1,  1,  0,  0] [ 0,  0,  0]  1 */
    52570094, /* 51817 (1242) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    52565674, /* 51818 (1242) [ 0,  1,  0,  0,  0,  1,  1,  0,  0] [ 6,  6,  6] -1 */
       16484, /* 51819 (1243) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
       14457, /* 51820 (1243) [ 1, -1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  0]  1 */
        5225, /* 51821 (1243) [-1,  1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  0]  1 */
        3198, /* 51822 (1243) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
        7817, /* 51823 (1243) [ 0, -1,  0,  1, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
       11865, /* 51824 (1243) [ 0,  1,  0, -1,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
       16484, /* 51825 (1244) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34017449, /* 51826 (1244) [-1,  1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    34026681, /* 51827 (1244) [ 1, -1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    34015422, /* 51828 (1244) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
       14457, /* 51829 (1244) [ 1, -1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    34020041, /* 51830 (1244) [ 0, -1,  0,  1, -1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
        5225, /* 51831 (1244) [-1,  1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  0]  1 */
        3198, /* 51832 (1244) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
        7817, /* 51833 (1244) [ 0, -1,  0,  1, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34024089, /* 51834 (1244) [ 0,  1,  0, -1,  1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    34028708, /* 51835 (1244) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
       11865, /* 51836 (1244) [ 0,  1,  0, -1,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
       16484, /* 51837 (1245) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34026681, /* 51838 (1245) [ 1, -1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    34015422, /* 51839 (1245) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
        5225, /* 51840 (1245) [-1,  1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  0]  1 */
        7817, /* 51841 (1245) [ 0, -1,  0,  1, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34024089, /* 51842 (1245) [ 0,  1,  0, -1,  1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
       16484, /* 51843 (1246) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34138139, /* 51844 (1246) [ 0, -1,  0,  1, -1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
       14457, /* 51845 (1246) [ 1, -1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    34144779, /* 51846 (1246) [ 1, -1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  6] -1 */
        5225, /* 51847 (1246) [-1,  1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34133520, /* 51848 (1246) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
    34142187, /* 51849 (1246) [ 0,  1,  0, -1,  1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
        3198, /* 51850 (1246) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
        7817, /* 51851 (1246) [ 0, -1,  0,  1, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34146806, /* 51852 (1246) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    34135547, /* 51853 (1246) [-1,  1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  6] -1 */
       11865, /* 51854 (1246) [ 0,  1,  0, -1,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
       16484, /* 51855 (1247) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    23714816, /* 51856 (1247) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 8,  4,  4]  1 */
    13389665, /* 51857 (1247) [-1,  1,  0, -1,  0,  0,  0,  0,  1] [ 4,  8,  8]  1 */
    23710197, /* 51858 (1247) [ 0,  1,  0, -1,  1,  0,  0,  0, -1] [ 8,  4,  4]  1 */
    23712789, /* 51859 (1247) [ 1, -1,  0,  1,  0,  0,  0,  0, -1] [ 8,  4,  4]  1 */
    13398897, /* 51860 (1247) [ 1, -1,  0,  1,  0,  0,  0,  0, -1] [ 4,  8,  8]  1 */
    13387638, /* 51861 (1247) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 4,  8,  8]  1 */
       14457, /* 51862 (1247) [ 1, -1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    13400924, /* 51863 (1247) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 4,  8,  8]  1 */
    23703557, /* 51864 (1247) [-1,  1,  0, -1,  0,  0,  0,  0,  1] [ 8,  4,  4]  1 */
        5225, /* 51865 (1247) [-1,  1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    23701530, /* 51866 (1247) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 8,  4,  4]  1 */
        3198, /* 51867 (1247) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
        7817, /* 51868 (1247) [ 0, -1,  0,  1, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    23706149, /* 51869 (1247) [ 0, -1,  0,  1, -1,  0,  0,  0,  1] [ 8,  4,  4]  1 */
    13396305, /* 51870 (1247) [ 0,  1,  0, -1,  1,  0,  0,  0, -1] [ 4,  8,  8]  1 */
    13392257, /* 51871 (1247) [ 0, -1,  0,  1, -1,  0,  0,  0,  1] [ 4,  8,  8]  1 */
       11865, /* 51872 (1247) [ 0,  1,  0, -1,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
       16484, /* 51873 (1248) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    13389665, /* 51874 (1248) [-1,  1,  0, -1,  0,  0,  0,  0,  1] [ 4,  8,  8]  1 */
    23710197, /* 51875 (1248) [ 0,  1,  0, -1,  1,  0,  0,  0, -1] [ 8,  4,  4]  1 */
    13398897, /* 51876 (1248) [ 1, -1,  0,  1,  0,  0,  0,  0, -1] [ 4,  8,  8]  1 */
    13400924, /* 51877 (1248) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 4,  8,  8]  1 */
    23701530, /* 51878 (1248) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 8,  4,  4]  1 */
        3198, /* 51879 (1248) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    47408529, /* 51880 (1248) [ 0,  1,  0, -1,  1,  0,  0,  0, -1] [ 4,  8,  8] -1 */
    47399862, /* 51881 (1248) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 4,  8,  8] -1 */
    34017449, /* 51882 (1248) [-1,  1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    57715781, /* 51883 (1248) [-1,  1,  0, -1,  0,  0,  0,  0,  1] [ 8,  4,  4] -1 */
    34026681, /* 51884 (1248) [ 1, -1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    57718373, /* 51885 (1248) [ 0, -1,  0,  1, -1,  0,  0,  0,  1] [ 8,  4,  4] -1 */
    34020041, /* 51886 (1248) [ 0, -1,  0,  1, -1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    57725013, /* 51887 (1248) [ 1, -1,  0,  1,  0,  0,  0,  0, -1] [ 8,  4,  4] -1 */
    13396305, /* 51888 (1248) [ 0,  1,  0, -1,  1,  0,  0,  0, -1] [ 4,  8,  8]  1 */
    57727040, /* 51889 (1248) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 8,  4,  4] -1 */
    34028708, /* 51890 (1248) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    13387638, /* 51891 (1248) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 4,  8,  8]  1 */
       14457, /* 51892 (1248) [ 1, -1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    23703557, /* 51893 (1248) [-1,  1,  0, -1,  0,  0,  0,  0,  1] [ 8,  4,  4]  1 */
        5225, /* 51894 (1248) [-1,  1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    47404481, /* 51895 (1248) [ 0, -1,  0,  1, -1,  0,  0,  0,  1] [ 4,  8,  8] -1 */
    23706149, /* 51896 (1248) [ 0, -1,  0,  1, -1,  0,  0,  0,  1] [ 8,  4,  4]  1 */
        7817, /* 51897 (1248) [ 0, -1,  0,  1, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    57722421, /* 51898 (1248) [ 0,  1,  0, -1,  1,  0,  0,  0, -1] [ 8,  4,  4] -1 */
    34024089, /* 51899 (1248) [ 0,  1,  0, -1,  1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    47401889, /* 51900 (1248) [-1,  1,  0, -1,  0,  0,  0,  0,  1] [ 4,  8,  8] -1 */
    47411121, /* 51901 (1248) [ 1, -1,  0,  1,  0,  0,  0,  0, -1] [ 4,  8,  8] -1 */
    23714816, /* 51902 (1248) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 8,  4,  4]  1 */
    23712789, /* 51903 (1248) [ 1, -1,  0,  1,  0,  0,  0,  0, -1] [ 8,  4,  4]  1 */
    47413148, /* 51904 (1248) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 4,  8,  8] -1 */
    34015422, /* 51905 (1248) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    57713754, /* 51906 (1248) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 8,  4,  4] -1 */
    13392257, /* 51907 (1248) [ 0, -1,  0,  1, -1,  0,  0,  0,  1] [ 4,  8,  8]  1 */
       11865, /* 51908 (1248) [ 0,  1,  0, -1,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
       16484, /* 51909 (1249) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    23714816, /* 51910 (1249) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 8,  4,  4]  1 */
    13389665, /* 51911 (1249) [-1,  1,  0, -1,  0,  0,  0,  0,  1] [ 4,  8,  8]  1 */
    57713754, /* 51912 (1249) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 8,  4,  4] -1 */
    34015422, /* 51913 (1249) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    34026681, /* 51914 (1249) [ 1, -1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    13400924, /* 51915 (1249) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 4,  8,  8]  1 */
    23703557, /* 51916 (1249) [-1,  1,  0, -1,  0,  0,  0,  0,  1] [ 8,  4,  4]  1 */
        5225, /* 51917 (1249) [-1,  1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    23706149, /* 51918 (1249) [ 0, -1,  0,  1, -1,  0,  0,  0,  1] [ 8,  4,  4]  1 */
        7817, /* 51919 (1249) [ 0, -1,  0,  1, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    47408529, /* 51920 (1249) [ 0,  1,  0, -1,  1,  0,  0,  0, -1] [ 4,  8,  8] -1 */
    57725013, /* 51921 (1249) [ 1, -1,  0,  1,  0,  0,  0,  0, -1] [ 8,  4,  4] -1 */
    57722421, /* 51922 (1249) [ 0,  1,  0, -1,  1,  0,  0,  0, -1] [ 8,  4,  4] -1 */
    34024089, /* 51923 (1249) [ 0,  1,  0, -1,  1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    13392257, /* 51924 (1249) [ 0, -1,  0,  1, -1,  0,  0,  0,  1] [ 4,  8,  8]  1 */
    47411121, /* 51925 (1249) [ 1, -1,  0,  1,  0,  0,  0,  0, -1] [ 4,  8,  8] -1 */
    47399862, /* 51926 (1249) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 4,  8,  8] -1 */
       16484, /* 51927 (1250) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    13389665, /* 51928 (1250) [-1,  1,  0, -1,  0,  0,  0,  0,  1] [ 4,  8,  8]  1 */
    23710197, /* 51929 (1250) [ 0,  1,  0, -1,  1,  0,  0,  0, -1] [ 8,  4,  4]  1 */
    13398897, /* 51930 (1250) [ 1, -1,  0,  1,  0,  0,  0,  0, -1] [ 4,  8,  8]  1 */
    57833879, /* 51931 (1250) [-1,  1,  0, -1,  0,  0,  0,  0,  1] [ 8,  4, 10] -1 */
    13400924, /* 51932 (1250) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 4,  8,  8]  1 */
    57845138, /* 51933 (1250) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 8,  4, 10] -1 */
    47281764, /* 51934 (1250) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 4,  8,  2] -1 */
    23701530, /* 51935 (1250) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 8,  4,  4]  1 */
        3198, /* 51936 (1250) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    34135547, /* 51937 (1250) [-1,  1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    34138139, /* 51938 (1250) [ 0, -1,  0,  1, -1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    34144779, /* 51939 (1250) [ 1, -1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  6] -1 */
    34146806, /* 51940 (1250) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    13396305, /* 51941 (1250) [ 0,  1,  0, -1,  1,  0,  0,  0, -1] [ 4,  8,  8]  1 */
    57831852, /* 51942 (1250) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 8,  4, 10] -1 */
    57840519, /* 51943 (1250) [ 0,  1,  0, -1,  1,  0,  0,  0, -1] [ 8,  4, 10] -1 */
    47293023, /* 51944 (1250) [ 1, -1,  0,  1,  0,  0,  0,  0, -1] [ 4,  8,  2] -1 */
    13387638, /* 51945 (1250) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 4,  8,  8]  1 */
    47283791, /* 51946 (1250) [-1,  1,  0, -1,  0,  0,  0,  0,  1] [ 4,  8,  2] -1 */
       14457, /* 51947 (1250) [ 1, -1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    47290431, /* 51948 (1250) [ 0,  1,  0, -1,  1,  0,  0,  0, -1] [ 4,  8,  2] -1 */
    47286383, /* 51949 (1250) [ 0, -1,  0,  1, -1,  0,  0,  0,  1] [ 4,  8,  2] -1 */
    23703557, /* 51950 (1250) [-1,  1,  0, -1,  0,  0,  0,  0,  1] [ 8,  4,  4]  1 */
        5225, /* 51951 (1250) [-1,  1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34142187, /* 51952 (1250) [ 0,  1,  0, -1,  1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
    23706149, /* 51953 (1250) [ 0, -1,  0,  1, -1,  0,  0,  0,  1] [ 8,  4,  4]  1 */
        7817, /* 51954 (1250) [ 0, -1,  0,  1, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    47295050, /* 51955 (1250) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 4,  8,  2] -1 */
    23714816, /* 51956 (1250) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 8,  4,  4]  1 */
    23712789, /* 51957 (1250) [ 1, -1,  0,  1,  0,  0,  0,  0, -1] [ 8,  4,  4]  1 */
    34133520, /* 51958 (1250) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
    57843111, /* 51959 (1250) [ 1, -1,  0,  1,  0,  0,  0,  0, -1] [ 8,  4, 10] -1 */
    57836471, /* 51960 (1250) [ 0, -1,  0,  1, -1,  0,  0,  0,  1] [ 8,  4, 10] -1 */
    13392257, /* 51961 (1250) [ 0, -1,  0,  1, -1,  0,  0,  0,  1] [ 4,  8,  8]  1 */
       11865, /* 51962 (1250) [ 0,  1,  0, -1,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
       16484, /* 51963 (1247) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
       10816, /* 51964 (1247) [ 0,  0,  1,  1,  0,  0,  0,  1,  0] [ 0,  0,  0]  1 */
       12064, /* 51965 (1247) [ 0,  1,  0,  0,  0,  1,  1,  0,  0] [ 0,  0,  0]  1 */
        3198, /* 51966 (1247) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
        7618, /* 51967 (1247) [ 0, -1,  0,  0,  0, -1, -1,  0,  0] [ 0,  0,  0]  1 */
        8866, /* 51968 (1247) [ 0,  0, -1, -1,  0,  0,  0, -1,  0] [ 0,  0,  0]  1 */
       16484, /* 51969 (1248) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34015422, /* 51970 (1248) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
       10816, /* 51971 (1248) [ 0,  0,  1,  1,  0,  0,  0,  1,  0] [ 0,  0,  0]  1 */
    34024288, /* 51972 (1248) [ 0,  1,  0,  0,  0,  1,  1,  0,  0] [ 0,  0,  0] -1 */
       12064, /* 51973 (1248) [ 0,  1,  0,  0,  0,  1,  1,  0,  0] [ 0,  0,  0]  1 */
        3198, /* 51974 (1248) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    34019842, /* 51975 (1248) [ 0, -1,  0,  0,  0, -1, -1,  0,  0] [ 0,  0,  0] -1 */
    34021090, /* 51976 (1248) [ 0,  0, -1, -1,  0,  0,  0, -1,  0] [ 0,  0,  0] -1 */
        7618, /* 51977 (1248) [ 0, -1,  0,  0,  0, -1, -1,  0,  0] [ 0,  0,  0]  1 */
    34028708, /* 51978 (1248) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    34023040, /* 51979 (1248) [ 0,  0,  1,  1,  0,  0,  0,  1,  0] [ 0,  0,  0] -1 */
        8866, /* 51980 (1248) [ 0,  0, -1, -1,  0,  0,  0, -1,  0] [ 0,  0,  0]  1 */
       16484, /* 51981 (1249) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
       10816, /* 51982 (1249) [ 0,  0,  1,  1,  0,  0,  0,  1,  0] [ 0,  0,  0]  1 */
    34015422, /* 51983 (1249) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
       12064, /* 51984 (1249) [ 0,  1,  0,  0,  0,  1,  1,  0,  0] [ 0,  0,  0]  1 */
    34019842, /* 51985 (1249) [ 0, -1,  0,  0,  0, -1, -1,  0,  0] [ 0,  0,  0] -1 */
    34021090, /* 51986 (1249) [ 0,  0, -1, -1,  0,  0,  0, -1,  0] [ 0,  0,  0] -1 */
       16484, /* 51987 (1250) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
       10816, /* 51988 (1250) [ 0,  0,  1,  1,  0,  0,  0,  1,  0] [ 0,  0,  0]  1 */
    52561228, /* 51989 (1250) [ 0, -1,  0,  0,  0, -1, -1,  0,  0] [ 6,  6,  6] -1 */
    52564426, /* 51990 (1250) [ 0,  0,  1,  1,  0,  0,  0,  1,  0] [ 6,  6,  6] -1 */
    52562476, /* 51991 (1250) [ 0,  0, -1, -1,  0,  0,  0, -1,  0] [ 6,  6,  6] -1 */
       12064, /* 51992 (1250) [ 0,  1,  0,  0,  0,  1,  1,  0,  0] [ 0,  0,  0]  1 */
    52556808, /* 51993 (1250) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
        3198, /* 51994 (1250) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
        7618, /* 51995 (1250) [ 0, -1,  0,  0,  0, -1, -1,  0,  0] [ 0,  0,  0]  1 */
    52570094, /* 51996 (1250) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    52565674, /* 51997 (1250) [ 0,  1,  0,  0,  0,  1,  1,  0,  0] [ 6,  6,  6] -1 */
        8866, /* 51998 (1250) [ 0,  0, -1, -1,  0,  0,  0, -1,  0] [ 0,  0,  0]  1 */
       16484, /* 51999 (1251) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
       16563, /* 52000 (1251) [ 1,  0,  0,  1, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
        7410, /* 52001 (1251) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  0]  1 */
        5225, /* 52002 (1251) [-1,  1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  0]  1 */
        7817, /* 52003 (1251) [ 0, -1,  0,  1, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
        5547, /* 52004 (1251) [-1,  1,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
       16484, /* 52005 (1252) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34017449, /* 52006 (1252) [-1,  1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    34028787, /* 52007 (1252) [ 1,  0,  0,  1, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
       16563, /* 52008 (1252) [ 1,  0,  0,  1, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    34019634, /* 52009 (1252) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    34020041, /* 52010 (1252) [ 0, -1,  0,  1, -1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    34017771, /* 52011 (1252) [-1,  1,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
        7410, /* 52012 (1252) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  0]  1 */
        5225, /* 52013 (1252) [-1,  1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  0]  1 */
        7817, /* 52014 (1252) [ 0, -1,  0,  1, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
        5547, /* 52015 (1252) [-1,  1,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    34028708, /* 52016 (1252) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
       16484, /* 52017 (1253) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34028787, /* 52018 (1253) [ 1,  0,  0,  1, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    34019634, /* 52019 (1253) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    34017771, /* 52020 (1253) [-1,  1,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
        5225, /* 52021 (1253) [-1,  1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  0]  1 */
        7817, /* 52022 (1253) [ 0, -1,  0,  1, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
       16484, /* 52023 (1254) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34137732, /* 52024 (1254) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  6] -1 */
    34138139, /* 52025 (1254) [ 0, -1,  0,  1, -1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    34135869, /* 52026 (1254) [-1,  1,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
       16563, /* 52027 (1254) [ 1,  0,  0,  1, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    34146885, /* 52028 (1254) [ 1,  0,  0,  1, -1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
        7410, /* 52029 (1254) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  0]  1 */
        5225, /* 52030 (1254) [-1,  1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  0]  1 */
        7817, /* 52031 (1254) [ 0, -1,  0,  1, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34146806, /* 52032 (1254) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
        5547, /* 52033 (1254) [-1,  1,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    34135547, /* 52034 (1254) [-1,  1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  6] -1 */
       16484, /* 52035 (1255) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
        3117, /* 52036 (1255) [-1,  0,  0, -1,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
        5225, /* 52037 (1255) [-1,  1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  0]  1 */
       12270, /* 52038 (1255) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  0]  1 */
        7817, /* 52039 (1255) [ 0, -1,  0,  1, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
       14133, /* 52040 (1255) [ 1, -1,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
       16484, /* 52041 (1256) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34017449, /* 52042 (1256) [-1,  1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    34015341, /* 52043 (1256) [-1,  0,  0, -1,  1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    34024494, /* 52044 (1256) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  0] -1 */
        3117, /* 52045 (1256) [-1,  0,  0, -1,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    34020041, /* 52046 (1256) [ 0, -1,  0,  1, -1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
        5225, /* 52047 (1256) [-1,  1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  0]  1 */
       12270, /* 52048 (1256) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    34026357, /* 52049 (1256) [ 1, -1,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
        7817, /* 52050 (1256) [ 0, -1,  0,  1, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
       14133, /* 52051 (1256) [ 1, -1,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    34028708, /* 52052 (1256) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
       16484, /* 52053 (1257) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34015341, /* 52054 (1257) [-1,  0,  0, -1,  1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    34024494, /* 52055 (1257) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  0] -1 */
        5225, /* 52056 (1257) [-1,  1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34026357, /* 52057 (1257) [ 1, -1,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
        7817, /* 52058 (1257) [ 0, -1,  0,  1, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
       16484, /* 52059 (1258) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34142592, /* 52060 (1258) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  6] -1 */
    34138139, /* 52061 (1258) [ 0, -1,  0,  1, -1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    34144455, /* 52062 (1258) [ 1, -1,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
        3117, /* 52063 (1258) [-1,  0,  0, -1,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
        5225, /* 52064 (1258) [-1,  1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  0]  1 */
       12270, /* 52065 (1258) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  0]  1 */
        7817, /* 52066 (1258) [ 0, -1,  0,  1, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34146806, /* 52067 (1258) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
       14133, /* 52068 (1258) [ 1, -1,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    34135547, /* 52069 (1258) [-1,  1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    34133439, /* 52070 (1258) [-1,  0,  0, -1,  1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
       16484, /* 52071 (1259) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
      162689, /* 52072 (1259) [-1,  1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  8]  1 */
       86549, /* 52073 (1259) [ 0, -1,  0,  1, -1,  0,  0,  0,  1] [ 0,  0,  4]  1 */
       84279, /* 52074 (1259) [-1,  1,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  4]  1 */
       16563, /* 52075 (1259) [ 1,  0,  0,  1, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
      164874, /* 52076 (1259) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  8]  1 */
       16484, /* 52077 (1260) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34028787, /* 52078 (1260) [ 1,  0,  0,  1, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
      162689, /* 52079 (1260) [-1,  1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  8]  1 */
       86549, /* 52080 (1260) [ 0, -1,  0,  1, -1,  0,  0,  0,  1] [ 0,  0,  4]  1 */
       84279, /* 52081 (1260) [-1,  1,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  4]  1 */
       16563, /* 52082 (1260) [ 1,  0,  0,  1, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    34177098, /* 52083 (1260) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  8] -1 */
      164874, /* 52084 (1260) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  8]  1 */
    34174913, /* 52085 (1260) [-1,  1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  8] -1 */
    34098773, /* 52086 (1260) [ 0, -1,  0,  1, -1,  0,  0,  0,  1] [ 0,  0,  4] -1 */
    34028708, /* 52087 (1260) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    34096503, /* 52088 (1260) [-1,  1,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  4] -1 */
       16484, /* 52089 (1261) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34028787, /* 52090 (1261) [ 1,  0,  0,  1, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
      162689, /* 52091 (1261) [-1,  1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  8]  1 */
       86549, /* 52092 (1261) [ 0, -1,  0,  1, -1,  0,  0,  0,  1] [ 0,  0,  4]  1 */
    34177098, /* 52093 (1261) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  8] -1 */
    34096503, /* 52094 (1261) [-1,  1,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  4] -1 */
       16484, /* 52095 (1262) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
      162689, /* 52096 (1262) [-1,  1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  8]  1 */
       86549, /* 52097 (1262) [ 0, -1,  0,  1, -1,  0,  0,  0,  1] [ 0,  0,  4]  1 */
       84279, /* 52098 (1262) [-1,  1,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  4]  1 */
       16563, /* 52099 (1262) [ 1,  0,  0,  1, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    34146885, /* 52100 (1262) [ 1,  0,  0,  1, -1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
    34056815, /* 52101 (1262) [-1,  1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  2] -1 */
      164874, /* 52102 (1262) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  8]  1 */
    34216871, /* 52103 (1262) [ 0, -1,  0,  1, -1,  0,  0,  0,  1] [ 0,  0, 10] -1 */
    34146806, /* 52104 (1262) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    34059000, /* 52105 (1262) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  2] -1 */
    34214601, /* 52106 (1262) [-1,  1,  0,  0,  1,  0,  0,  0, -1] [ 0,  0, 10] -1 */
       16484, /* 52107 (1263) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
      162689, /* 52108 (1263) [-1,  1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  8]  1 */
       86549, /* 52109 (1263) [ 0, -1,  0,  1, -1,  0,  0,  0,  1] [ 0,  0,  4]  1 */
      171597, /* 52110 (1263) [ 1, -1,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  8]  1 */
       81849, /* 52111 (1263) [-1,  0,  0, -1,  1,  0,  0,  0, -1] [ 0,  0,  4]  1 */
       12270, /* 52112 (1263) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  0]  1 */
       16484, /* 52113 (1264) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
      162689, /* 52114 (1264) [-1,  1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  8]  1 */
    34183821, /* 52115 (1264) [ 1, -1,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  8] -1 */
       86549, /* 52116 (1264) [ 0, -1,  0,  1, -1,  0,  0,  0,  1] [ 0,  0,  4]  1 */
    34094073, /* 52117 (1264) [-1,  0,  0, -1,  1,  0,  0,  0, -1] [ 0,  0,  4] -1 */
      171597, /* 52118 (1264) [ 1, -1,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  8]  1 */
    34024494, /* 52119 (1264) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  0] -1 */
       81849, /* 52120 (1264) [-1,  0,  0, -1,  1,  0,  0,  0, -1] [ 0,  0,  4]  1 */
       12270, /* 52121 (1264) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    34174913, /* 52122 (1264) [-1,  1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  8] -1 */
    34098773, /* 52123 (1264) [ 0, -1,  0,  1, -1,  0,  0,  0,  1] [ 0,  0,  4] -1 */
    34028708, /* 52124 (1264) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
       16484, /* 52125 (1265) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
      162689, /* 52126 (1265) [-1,  1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  8]  1 */
    34183821, /* 52127 (1265) [ 1, -1,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  8] -1 */
       86549, /* 52128 (1265) [ 0, -1,  0,  1, -1,  0,  0,  0,  1] [ 0,  0,  4]  1 */
    34094073, /* 52129 (1265) [-1,  0,  0, -1,  1,  0,  0,  0, -1] [ 0,  0,  4] -1 */
    34024494, /* 52130 (1265) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  0] -1 */
       16484, /* 52131 (1266) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
      162689, /* 52132 (1266) [-1,  1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  8]  1 */
    34142592, /* 52133 (1266) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  6] -1 */
       86549, /* 52134 (1266) [ 0, -1,  0,  1, -1,  0,  0,  0,  1] [ 0,  0,  4]  1 */
      171597, /* 52135 (1266) [ 1, -1,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  8]  1 */
    34212171, /* 52136 (1266) [-1,  0,  0, -1,  1,  0,  0,  0, -1] [ 0,  0, 10] -1 */
       81849, /* 52137 (1266) [-1,  0,  0, -1,  1,  0,  0,  0, -1] [ 0,  0,  4]  1 */
    34056815, /* 52138 (1266) [-1,  1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  2] -1 */
       12270, /* 52139 (1266) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    34216871, /* 52140 (1266) [ 0, -1,  0,  1, -1,  0,  0,  0,  1] [ 0,  0, 10] -1 */
    34146806, /* 52141 (1266) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    34065723, /* 52142 (1266) [ 1, -1,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  2] -1 */
       16484, /* 52143 (1267) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
       16563, /* 52144 (1267) [ 1,  0,  0,  1, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
       83957, /* 52145 (1267) [-1,  1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  4]  1 */
       86142, /* 52146 (1267) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  4]  1 */
      165281, /* 52147 (1267) [ 0, -1,  0,  1, -1,  0,  0,  0,  1] [ 0,  0,  8]  1 */
      163011, /* 52148 (1267) [-1,  1,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  8]  1 */
       16484, /* 52149 (1268) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34028787, /* 52150 (1268) [ 1,  0,  0,  1, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    34177505, /* 52151 (1268) [ 0, -1,  0,  1, -1,  0,  0,  0,  1] [ 0,  0,  8] -1 */
    34096181, /* 52152 (1268) [-1,  1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  4] -1 */
       16563, /* 52153 (1268) [ 1,  0,  0,  1, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    34098366, /* 52154 (1268) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  4] -1 */
       83957, /* 52155 (1268) [-1,  1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  4]  1 */
    34175235, /* 52156 (1268) [-1,  1,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  8] -1 */
       86142, /* 52157 (1268) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  4]  1 */
      165281, /* 52158 (1268) [ 0, -1,  0,  1, -1,  0,  0,  0,  1] [ 0,  0,  8]  1 */
      163011, /* 52159 (1268) [-1,  1,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  8]  1 */
    34028708, /* 52160 (1268) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
       16484, /* 52161 (1269) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34028787, /* 52162 (1269) [ 1,  0,  0,  1, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    34098366, /* 52163 (1269) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  4] -1 */
       83957, /* 52164 (1269) [-1,  1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  4]  1 */
    34175235, /* 52165 (1269) [-1,  1,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  8] -1 */
      165281, /* 52166 (1269) [ 0, -1,  0,  1, -1,  0,  0,  0,  1] [ 0,  0,  8]  1 */
       16484, /* 52167 (1270) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34057137, /* 52168 (1270) [-1,  1,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  2] -1 */
       16563, /* 52169 (1270) [ 1,  0,  0,  1, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    34214279, /* 52170 (1270) [-1,  1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0, 10] -1 */
    34146885, /* 52171 (1270) [ 1,  0,  0,  1, -1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
       83957, /* 52172 (1270) [-1,  1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  4]  1 */
    34216464, /* 52173 (1270) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0, 10] -1 */
    34059407, /* 52174 (1270) [ 0, -1,  0,  1, -1,  0,  0,  0,  1] [ 0,  0,  2] -1 */
       86142, /* 52175 (1270) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  4]  1 */
      165281, /* 52176 (1270) [ 0, -1,  0,  1, -1,  0,  0,  0,  1] [ 0,  0,  8]  1 */
    34146806, /* 52177 (1270) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
      163011, /* 52178 (1270) [-1,  1,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  8]  1 */
       16484, /* 52179 (1271) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
      160581, /* 52180 (1271) [-1,  0,  0, -1,  1,  0,  0,  0, -1] [ 0,  0,  8]  1 */
       92865, /* 52181 (1271) [ 1, -1,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  4]  1 */
       83957, /* 52182 (1271) [-1,  1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  4]  1 */
       12270, /* 52183 (1271) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  0]  1 */
      165281, /* 52184 (1271) [ 0, -1,  0,  1, -1,  0,  0,  0,  1] [ 0,  0,  8]  1 */
       16484, /* 52185 (1272) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34172805, /* 52186 (1272) [-1,  0,  0, -1,  1,  0,  0,  0, -1] [ 0,  0,  8] -1 */
    34105089, /* 52187 (1272) [ 1, -1,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  4] -1 */
    34177505, /* 52188 (1272) [ 0, -1,  0,  1, -1,  0,  0,  0,  1] [ 0,  0,  8] -1 */
    34096181, /* 52189 (1272) [-1,  1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  4] -1 */
    34024494, /* 52190 (1272) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  0] -1 */
      160581, /* 52191 (1272) [-1,  0,  0, -1,  1,  0,  0,  0, -1] [ 0,  0,  8]  1 */
       92865, /* 52192 (1272) [ 1, -1,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  4]  1 */
       83957, /* 52193 (1272) [-1,  1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  4]  1 */
       12270, /* 52194 (1272) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  0]  1 */
      165281, /* 52195 (1272) [ 0, -1,  0,  1, -1,  0,  0,  0,  1] [ 0,  0,  8]  1 */
    34028708, /* 52196 (1272) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
       16484, /* 52197 (1273) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34172805, /* 52198 (1273) [-1,  0,  0, -1,  1,  0,  0,  0, -1] [ 0,  0,  8] -1 */
    34105089, /* 52199 (1273) [ 1, -1,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  4] -1 */
    34024494, /* 52200 (1273) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  0] -1 */
       83957, /* 52201 (1273) [-1,  1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  4]  1 */
      165281, /* 52202 (1273) [ 0, -1,  0,  1, -1,  0,  0,  0,  1] [ 0,  0,  8]  1 */
       16484, /* 52203 (1274) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34142592, /* 52204 (1274) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  6] -1 */
    34214279, /* 52205 (1274) [-1,  1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0, 10] -1 */
      160581, /* 52206 (1274) [-1,  0,  0, -1,  1,  0,  0,  0, -1] [ 0,  0,  8]  1 */
       92865, /* 52207 (1274) [ 1, -1,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  4]  1 */
       83957, /* 52208 (1274) [-1,  1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  4]  1 */
       12270, /* 52209 (1274) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    34059407, /* 52210 (1274) [ 0, -1,  0,  1, -1,  0,  0,  0,  1] [ 0,  0,  2] -1 */
      165281, /* 52211 (1274) [ 0, -1,  0,  1, -1,  0,  0,  0,  1] [ 0,  0,  8]  1 */
    34146806, /* 52212 (1274) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    34054707, /* 52213 (1274) [-1,  0,  0, -1,  1,  0,  0,  0, -1] [ 0,  0,  2] -1 */
    34223187, /* 52214 (1274) [ 1, -1,  0,  0, -1,  0,  0,  0, -1] [ 0,  0, 10] -1 */
       16484, /* 52215 (1275) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    23714816, /* 52216 (1275) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 8,  4,  4]  1 */
    13389665, /* 52217 (1275) [-1,  1,  0, -1,  0,  0,  0,  0,  1] [ 4,  8,  8]  1 */
    23701449, /* 52218 (1275) [-1,  0,  0, -1,  1,  0,  0,  0, -1] [ 8,  4,  4]  1 */
        3117, /* 52219 (1275) [-1,  0,  0, -1,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    13400924, /* 52220 (1275) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 4,  8,  8]  1 */
    23703557, /* 52221 (1275) [-1,  1,  0, -1,  0,  0,  0,  0,  1] [ 8,  4,  4]  1 */
        5225, /* 52222 (1275) [-1,  1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  0]  1 */
       12270, /* 52223 (1275) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    13398573, /* 52224 (1275) [ 1, -1,  0,  0, -1,  0,  0,  0, -1] [ 4,  8,  8]  1 */
    23706149, /* 52225 (1275) [ 0, -1,  0,  1, -1,  0,  0,  0,  1] [ 8,  4,  4]  1 */
        7817, /* 52226 (1275) [ 0, -1,  0,  1, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    13387557, /* 52227 (1275) [-1,  0,  0, -1,  1,  0,  0,  0, -1] [ 4,  8,  8]  1 */
    23710602, /* 52228 (1275) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 8,  4,  4]  1 */
       14133, /* 52229 (1275) [ 1, -1,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    13396710, /* 52230 (1275) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 4,  8,  8]  1 */
    23712465, /* 52231 (1275) [ 1, -1,  0,  0, -1,  0,  0,  0, -1] [ 8,  4,  4]  1 */
    13392257, /* 52232 (1275) [ 0, -1,  0,  1, -1,  0,  0,  0,  1] [ 4,  8,  8]  1 */
       16484, /* 52233 (1276) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    13389665, /* 52234 (1276) [-1,  1,  0, -1,  0,  0,  0,  0,  1] [ 4,  8,  8]  1 */
    47410797, /* 52235 (1276) [ 1, -1,  0,  0, -1,  0,  0,  0, -1] [ 4,  8,  8] -1 */
    13400924, /* 52236 (1276) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 4,  8,  8]  1 */
       12270, /* 52237 (1276) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    13387557, /* 52238 (1276) [-1,  0,  0, -1,  1,  0,  0,  0, -1] [ 4,  8,  8]  1 */
    47408934, /* 52239 (1276) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 4,  8,  8] -1 */
    23710602, /* 52240 (1276) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 8,  4,  4]  1 */
    57715781, /* 52241 (1276) [-1,  1,  0, -1,  0,  0,  0,  0,  1] [ 8,  4,  4] -1 */
    34017449, /* 52242 (1276) [-1,  1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    57718373, /* 52243 (1276) [ 0, -1,  0,  1, -1,  0,  0,  0,  1] [ 8,  4,  4] -1 */
    34020041, /* 52244 (1276) [ 0, -1,  0,  1, -1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    13398573, /* 52245 (1276) [ 1, -1,  0,  0, -1,  0,  0,  0, -1] [ 4,  8,  8]  1 */
    57727040, /* 52246 (1276) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 8,  4,  4] -1 */
    34028708, /* 52247 (1276) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    13396710, /* 52248 (1276) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 4,  8,  8]  1 */
    57713673, /* 52249 (1276) [-1,  0,  0, -1,  1,  0,  0,  0, -1] [ 8,  4,  4] -1 */
    34015341, /* 52250 (1276) [-1,  0,  0, -1,  1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    23703557, /* 52251 (1276) [-1,  1,  0, -1,  0,  0,  0,  0,  1] [ 8,  4,  4]  1 */
        5225, /* 52252 (1276) [-1,  1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    47404481, /* 52253 (1276) [ 0, -1,  0,  1, -1,  0,  0,  0,  1] [ 4,  8,  8] -1 */
    34026357, /* 52254 (1276) [ 1, -1,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    23706149, /* 52255 (1276) [ 0, -1,  0,  1, -1,  0,  0,  0,  1] [ 8,  4,  4]  1 */
        7817, /* 52256 (1276) [ 0, -1,  0,  1, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    57724689, /* 52257 (1276) [ 1, -1,  0,  0, -1,  0,  0,  0, -1] [ 8,  4,  4] -1 */
    47401889, /* 52258 (1276) [-1,  1,  0, -1,  0,  0,  0,  0,  1] [ 4,  8,  8] -1 */
    23714816, /* 52259 (1276) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 8,  4,  4]  1 */
    47413148, /* 52260 (1276) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 4,  8,  8] -1 */
    47399781, /* 52261 (1276) [-1,  0,  0, -1,  1,  0,  0,  0, -1] [ 4,  8,  8] -1 */
    57722826, /* 52262 (1276) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 8,  4,  4] -1 */
    34024494, /* 52263 (1276) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  0] -1 */
        3117, /* 52264 (1276) [-1,  0,  0, -1,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    23701449, /* 52265 (1276) [-1,  0,  0, -1,  1,  0,  0,  0, -1] [ 8,  4,  4]  1 */
       14133, /* 52266 (1276) [ 1, -1,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    23712465, /* 52267 (1276) [ 1, -1,  0,  0, -1,  0,  0,  0, -1] [ 8,  4,  4]  1 */
    13392257, /* 52268 (1276) [ 0, -1,  0,  1, -1,  0,  0,  0,  1] [ 4,  8,  8]  1 */
       16484, /* 52269 (1277) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    23714816, /* 52270 (1277) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 8,  4,  4]  1 */
    34015341, /* 52271 (1277) [-1,  0,  0, -1,  1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    57713673, /* 52272 (1277) [-1,  0,  0, -1,  1,  0,  0,  0, -1] [ 8,  4,  4] -1 */
    13389665, /* 52273 (1277) [-1,  1,  0, -1,  0,  0,  0,  0,  1] [ 4,  8,  8]  1 */
    47399781, /* 52274 (1277) [-1,  0,  0, -1,  1,  0,  0,  0, -1] [ 4,  8,  8] -1 */
    57722826, /* 52275 (1277) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 8,  4,  4] -1 */
    34024494, /* 52276 (1277) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    47410797, /* 52277 (1277) [ 1, -1,  0,  0, -1,  0,  0,  0, -1] [ 4,  8,  8] -1 */
    13400924, /* 52278 (1277) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 4,  8,  8]  1 */
    23703557, /* 52279 (1277) [-1,  1,  0, -1,  0,  0,  0,  0,  1] [ 8,  4,  4]  1 */
        5225, /* 52280 (1277) [-1,  1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34026357, /* 52281 (1277) [ 1, -1,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    57724689, /* 52282 (1277) [ 1, -1,  0,  0, -1,  0,  0,  0, -1] [ 8,  4,  4] -1 */
    23706149, /* 52283 (1277) [ 0, -1,  0,  1, -1,  0,  0,  0,  1] [ 8,  4,  4]  1 */
        7817, /* 52284 (1277) [ 0, -1,  0,  1, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    47408934, /* 52285 (1277) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 4,  8,  8] -1 */
    13392257, /* 52286 (1277) [ 0, -1,  0,  1, -1,  0,  0,  0,  1] [ 4,  8,  8]  1 */
       16484, /* 52287 (1278) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    13389665, /* 52288 (1278) [-1,  1,  0, -1,  0,  0,  0,  0,  1] [ 4,  8,  8]  1 */
    57833879, /* 52289 (1278) [-1,  1,  0, -1,  0,  0,  0,  0,  1] [ 8,  4, 10] -1 */
    13400924, /* 52290 (1278) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 4,  8,  8]  1 */
    57845138, /* 52291 (1278) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 8,  4, 10] -1 */
       12270, /* 52292 (1278) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    47290836, /* 52293 (1278) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 4,  8,  2] -1 */
    13387557, /* 52294 (1278) [-1,  0,  0, -1,  1,  0,  0,  0, -1] [ 4,  8,  8]  1 */
    57831771, /* 52295 (1278) [-1,  0,  0, -1,  1,  0,  0,  0, -1] [ 8,  4, 10] -1 */
    23710602, /* 52296 (1278) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 8,  4,  4]  1 */
    34135547, /* 52297 (1278) [-1,  1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    57842787, /* 52298 (1278) [ 1, -1,  0,  0, -1,  0,  0,  0, -1] [ 8,  4, 10] -1 */
    34138139, /* 52299 (1278) [ 0, -1,  0,  1, -1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    13398573, /* 52300 (1278) [ 1, -1,  0,  0, -1,  0,  0,  0, -1] [ 4,  8,  8]  1 */
    34146806, /* 52301 (1278) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    13396710, /* 52302 (1278) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 4,  8,  8]  1 */
    34133439, /* 52303 (1278) [-1,  0,  0, -1,  1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
    47283791, /* 52304 (1278) [-1,  1,  0, -1,  0,  0,  0,  0,  1] [ 4,  8,  2] -1 */
    34144455, /* 52305 (1278) [ 1, -1,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
    47286383, /* 52306 (1278) [ 0, -1,  0,  1, -1,  0,  0,  0,  1] [ 4,  8,  2] -1 */
    23703557, /* 52307 (1278) [-1,  1,  0, -1,  0,  0,  0,  0,  1] [ 8,  4,  4]  1 */
        5225, /* 52308 (1278) [-1,  1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    23706149, /* 52309 (1278) [ 0, -1,  0,  1, -1,  0,  0,  0,  1] [ 8,  4,  4]  1 */
        7817, /* 52310 (1278) [ 0, -1,  0,  1, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    57840924, /* 52311 (1278) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 8,  4, 10] -1 */
    47295050, /* 52312 (1278) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 4,  8,  2] -1 */
    23714816, /* 52313 (1278) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 8,  4,  4]  1 */
    34142592, /* 52314 (1278) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  6] -1 */
    23712465, /* 52315 (1278) [ 1, -1,  0,  0, -1,  0,  0,  0, -1] [ 8,  4,  4]  1 */
    47281683, /* 52316 (1278) [-1,  0,  0, -1,  1,  0,  0,  0, -1] [ 4,  8,  2] -1 */
    23701449, /* 52317 (1278) [-1,  0,  0, -1,  1,  0,  0,  0, -1] [ 8,  4,  4]  1 */
        3117, /* 52318 (1278) [-1,  0,  0, -1,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
       14133, /* 52319 (1278) [ 1, -1,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    47292699, /* 52320 (1278) [ 1, -1,  0,  0, -1,  0,  0,  0, -1] [ 4,  8,  2] -1 */
    57836471, /* 52321 (1278) [ 0, -1,  0,  1, -1,  0,  0,  0,  1] [ 8,  4, 10] -1 */
    13392257, /* 52322 (1278) [ 0, -1,  0,  1, -1,  0,  0,  0,  1] [ 4,  8,  8]  1 */
       16484, /* 52323 (1275) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
       10816, /* 52324 (1275) [ 0,  0,  1,  1,  0,  0,  0,  1,  0] [ 0,  0,  0]  1 */
        9022, /* 52325 (1275) [ 0,  0, -1,  0, -1,  0, -1,  0,  0] [ 0,  0,  0]  1 */
        7410, /* 52326 (1275) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  0]  1 */
       12064, /* 52327 (1275) [ 0,  1,  0,  0,  0,  1,  1,  0,  0] [ 0,  0,  0]  1 */
        3250, /* 52328 (1275) [-1,  0,  0,  0,  0, -1,  0, -1,  0] [ 0,  0,  0]  1 */
       16484, /* 52329 (1276) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34021246, /* 52330 (1276) [ 0,  0, -1,  0, -1,  0, -1,  0,  0] [ 0,  0,  0] -1 */
       10816, /* 52331 (1276) [ 0,  0,  1,  1,  0,  0,  0,  1,  0] [ 0,  0,  0]  1 */
    34019634, /* 52332 (1276) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  0] -1 */
        9022, /* 52333 (1276) [ 0,  0, -1,  0, -1,  0, -1,  0,  0] [ 0,  0,  0]  1 */
    34024288, /* 52334 (1276) [ 0,  1,  0,  0,  0,  1,  1,  0,  0] [ 0,  0,  0] -1 */
    34015474, /* 52335 (1276) [-1,  0,  0,  0,  0, -1,  0, -1,  0] [ 0,  0,  0] -1 */
        7410, /* 52336 (1276) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  0]  1 */
       12064, /* 52337 (1276) [ 0,  1,  0,  0,  0,  1,  1,  0,  0] [ 0,  0,  0]  1 */
        3250, /* 52338 (1276) [-1,  0,  0,  0,  0, -1,  0, -1,  0] [ 0,  0,  0]  1 */
    34028708, /* 52339 (1276) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    34023040, /* 52340 (1276) [ 0,  0,  1,  1,  0,  0,  0,  1,  0] [ 0,  0,  0] -1 */
       16484, /* 52341 (1277) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34021246, /* 52342 (1277) [ 0,  0, -1,  0, -1,  0, -1,  0,  0] [ 0,  0,  0] -1 */
       10816, /* 52343 (1277) [ 0,  0,  1,  1,  0,  0,  0,  1,  0] [ 0,  0,  0]  1 */
    34019634, /* 52344 (1277) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    34015474, /* 52345 (1277) [-1,  0,  0,  0,  0, -1,  0, -1,  0] [ 0,  0,  0] -1 */
       12064, /* 52346 (1277) [ 0,  1,  0,  0,  0,  1,  1,  0,  0] [ 0,  0,  0]  1 */
       16484, /* 52347 (1278) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
       10816, /* 52348 (1278) [ 0,  0,  1,  1,  0,  0,  0,  1,  0] [ 0,  0,  0]  1 */
    52556860, /* 52349 (1278) [-1,  0,  0,  0,  0, -1,  0, -1,  0] [ 6,  6,  6] -1 */
    52562632, /* 52350 (1278) [ 0,  0, -1,  0, -1,  0, -1,  0,  0] [ 6,  6,  6] -1 */
        9022, /* 52351 (1278) [ 0,  0, -1,  0, -1,  0, -1,  0,  0] [ 0,  0,  0]  1 */
    52564426, /* 52352 (1278) [ 0,  0,  1,  1,  0,  0,  0,  1,  0] [ 6,  6,  6] -1 */
        7410, /* 52353 (1278) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  0]  1 */
       12064, /* 52354 (1278) [ 0,  1,  0,  0,  0,  1,  1,  0,  0] [ 0,  0,  0]  1 */
        3250, /* 52355 (1278) [-1,  0,  0,  0,  0, -1,  0, -1,  0] [ 0,  0,  0]  1 */
    52561020, /* 52356 (1278) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    52570094, /* 52357 (1278) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    52565674, /* 52358 (1278) [ 0,  1,  0,  0,  0,  1,  1,  0,  0] [ 6,  6,  6] -1 */
       16484, /* 52359 (1279) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
        5225, /* 52360 (1279) [-1,  1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  0]  1 */
        7412, /* 52361 (1279) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  0]  1 */
        7817, /* 52362 (1279) [ 0, -1,  0,  1, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
       16565, /* 52363 (1279) [ 1,  0,  0,  1, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
        5549, /* 52364 (1279) [-1,  1,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
       16484, /* 52365 (1280) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34017449, /* 52366 (1280) [-1,  1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    34019636, /* 52367 (1280) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    34020041, /* 52368 (1280) [ 0, -1,  0,  1, -1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    34028789, /* 52369 (1280) [ 1,  0,  0,  1, -1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    34017773, /* 52370 (1280) [-1,  1,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
        5225, /* 52371 (1280) [-1,  1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  0]  1 */
        7412, /* 52372 (1280) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  0]  1 */
        7817, /* 52373 (1280) [ 0, -1,  0,  1, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
       16565, /* 52374 (1280) [ 1,  0,  0,  1, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34028708, /* 52375 (1280) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
        5549, /* 52376 (1280) [-1,  1,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
       16484, /* 52377 (1281) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34019636, /* 52378 (1281) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    34028789, /* 52379 (1281) [ 1,  0,  0,  1, -1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    34017773, /* 52380 (1281) [-1,  1,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
        5225, /* 52381 (1281) [-1,  1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  0]  1 */
        7817, /* 52382 (1281) [ 0, -1,  0,  1, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
       16484, /* 52383 (1282) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34138139, /* 52384 (1282) [ 0, -1,  0,  1, -1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
        5225, /* 52385 (1282) [-1,  1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  0]  1 */
        7412, /* 52386 (1282) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  0]  1 */
        7817, /* 52387 (1282) [ 0, -1,  0,  1, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
       16565, /* 52388 (1282) [ 1,  0,  0,  1, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34146806, /* 52389 (1282) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    34137734, /* 52390 (1282) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    34135871, /* 52391 (1282) [-1,  1,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    34135547, /* 52392 (1282) [-1,  1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  6] -1 */
        5549, /* 52393 (1282) [-1,  1,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34146887, /* 52394 (1282) [ 1,  0,  0,  1, -1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
       16484, /* 52395 (1283) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
        3119, /* 52396 (1283) [-1,  0,  0, -1,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
       12272, /* 52397 (1283) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 0,  0,  0]  1 */
        5225, /* 52398 (1283) [-1,  1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  0]  1 */
       14135, /* 52399 (1283) [ 1, -1,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
        7817, /* 52400 (1283) [ 0, -1,  0,  1, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
       16484, /* 52401 (1284) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34017449, /* 52402 (1284) [-1,  1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    34015343, /* 52403 (1284) [-1,  0,  0, -1,  1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
        3119, /* 52404 (1284) [-1,  0,  0, -1,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34026359, /* 52405 (1284) [ 1, -1,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
       12272, /* 52406 (1284) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34020041, /* 52407 (1284) [ 0, -1,  0,  1, -1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
        5225, /* 52408 (1284) [-1,  1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  0]  1 */
       14135, /* 52409 (1284) [ 1, -1,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
        7817, /* 52410 (1284) [ 0, -1,  0,  1, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34028708, /* 52411 (1284) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    34024496, /* 52412 (1284) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 0,  0,  0] -1 */
       16484, /* 52413 (1285) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34015343, /* 52414 (1285) [-1,  0,  0, -1,  1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    34026359, /* 52415 (1285) [ 1, -1,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
        5225, /* 52416 (1285) [-1,  1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  0]  1 */
        7817, /* 52417 (1285) [ 0, -1,  0,  1, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34024496, /* 52418 (1285) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 0,  0,  0] -1 */
       16484, /* 52419 (1286) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34138139, /* 52420 (1286) [ 0, -1,  0,  1, -1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
        3119, /* 52421 (1286) [-1,  0,  0, -1,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34142594, /* 52422 (1286) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 0,  0,  6] -1 */
       12272, /* 52423 (1286) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34133441, /* 52424 (1286) [-1,  0,  0, -1,  1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
        5225, /* 52425 (1286) [-1,  1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  0]  1 */
       14135, /* 52426 (1286) [ 1, -1,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
        7817, /* 52427 (1286) [ 0, -1,  0,  1, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34144457, /* 52428 (1286) [ 1, -1,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    34146806, /* 52429 (1286) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    34135547, /* 52430 (1286) [-1,  1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  6] -1 */
       16484, /* 52431 (1287) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
      123647, /* 52432 (1287) [-1,  1,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6]  1 */
      134663, /* 52433 (1287) [ 1,  0,  0,  1, -1,  0,  0,  0,  1] [ 0,  0,  6]  1 */
        5225, /* 52434 (1287) [-1,  1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  0]  1 */
        7817, /* 52435 (1287) [ 0, -1,  0,  1, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
      125510, /* 52436 (1287) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  6]  1 */
       16484, /* 52437 (1288) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34017449, /* 52438 (1288) [-1,  1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  0] -1 */
      123647, /* 52439 (1288) [-1,  1,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6]  1 */
      134663, /* 52440 (1288) [ 1,  0,  0,  1, -1,  0,  0,  0,  1] [ 0,  0,  6]  1 */
    34020041, /* 52441 (1288) [ 0, -1,  0,  1, -1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
        5225, /* 52442 (1288) [-1,  1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  0]  1 */
        7817, /* 52443 (1288) [ 0, -1,  0,  1, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34137734, /* 52444 (1288) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    34135871, /* 52445 (1288) [-1,  1,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    34028708, /* 52446 (1288) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
      125510, /* 52447 (1288) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  6]  1 */
    34146887, /* 52448 (1288) [ 1,  0,  0,  1, -1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
       16484, /* 52449 (1289) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
        5225, /* 52450 (1289) [-1,  1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  0]  1 */
        7817, /* 52451 (1289) [ 0, -1,  0,  1, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34137734, /* 52452 (1289) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    34135871, /* 52453 (1289) [-1,  1,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    34146887, /* 52454 (1289) [ 1,  0,  0,  1, -1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
       16484, /* 52455 (1290) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34138139, /* 52456 (1290) [ 0, -1,  0,  1, -1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
      123647, /* 52457 (1290) [-1,  1,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6]  1 */
    34019636, /* 52458 (1290) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  0] -1 */
      134663, /* 52459 (1290) [ 1,  0,  0,  1, -1,  0,  0,  0,  1] [ 0,  0,  6]  1 */
    34028789, /* 52460 (1290) [ 1,  0,  0,  1, -1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    34017773, /* 52461 (1290) [-1,  1,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
        5225, /* 52462 (1290) [-1,  1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  0]  1 */
        7817, /* 52463 (1290) [ 0, -1,  0,  1, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34146806, /* 52464 (1290) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    34135547, /* 52465 (1290) [-1,  1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  6] -1 */
      125510, /* 52466 (1290) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  6]  1 */
       16484, /* 52467 (1291) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
        5225, /* 52468 (1291) [-1,  1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  0]  1 */
        7817, /* 52469 (1291) [ 0, -1,  0,  1, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
      121217, /* 52470 (1291) [-1,  0,  0, -1,  1,  0,  0,  0,  1] [ 0,  0,  6]  1 */
      130370, /* 52471 (1291) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 0,  0,  6]  1 */
      132233, /* 52472 (1291) [ 1, -1,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6]  1 */
       16484, /* 52473 (1292) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34017449, /* 52474 (1292) [-1,  1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    34142594, /* 52475 (1292) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    34020041, /* 52476 (1292) [ 0, -1,  0,  1, -1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    34133441, /* 52477 (1292) [-1,  0,  0, -1,  1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
        5225, /* 52478 (1292) [-1,  1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  0]  1 */
      132233, /* 52479 (1292) [ 1, -1,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6]  1 */
        7817, /* 52480 (1292) [ 0, -1,  0,  1, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
      121217, /* 52481 (1292) [-1,  0,  0, -1,  1,  0,  0,  0,  1] [ 0,  0,  6]  1 */
    34144457, /* 52482 (1292) [ 1, -1,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
      130370, /* 52483 (1292) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 0,  0,  6]  1 */
    34028708, /* 52484 (1292) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
       16484, /* 52485 (1293) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34142594, /* 52486 (1293) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    34133441, /* 52487 (1293) [-1,  0,  0, -1,  1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
        5225, /* 52488 (1293) [-1,  1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  0]  1 */
        7817, /* 52489 (1293) [ 0, -1,  0,  1, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34144457, /* 52490 (1293) [ 1, -1,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
       16484, /* 52491 (1294) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34015343, /* 52492 (1294) [-1,  0,  0, -1,  1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    34138139, /* 52493 (1294) [ 0, -1,  0,  1, -1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    34026359, /* 52494 (1294) [ 1, -1,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
        5225, /* 52495 (1294) [-1,  1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  0]  1 */
        7817, /* 52496 (1294) [ 0, -1,  0,  1, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
      121217, /* 52497 (1294) [-1,  0,  0, -1,  1,  0,  0,  0,  1] [ 0,  0,  6]  1 */
    34146806, /* 52498 (1294) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
      130370, /* 52499 (1294) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 0,  0,  6]  1 */
    34135547, /* 52500 (1294) [-1,  1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  6] -1 */
      132233, /* 52501 (1294) [ 1, -1,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6]  1 */
    34024496, /* 52502 (1294) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 0,  0,  0] -1 */
       16484, /* 52503 (1295) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    23714816, /* 52504 (1295) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 8,  4,  4]  1 */
    13389665, /* 52505 (1295) [-1,  1,  0, -1,  0,  0,  0,  0,  1] [ 4,  8,  8]  1 */
    23705744, /* 52506 (1295) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 8,  4,  4]  1 */
    13400924, /* 52507 (1295) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 4,  8,  8]  1 */
    13391852, /* 52508 (1295) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 4,  8,  8]  1 */
    23703881, /* 52509 (1295) [-1,  1,  0,  0,  1,  0,  0,  0,  1] [ 8,  4,  4]  1 */
    23703557, /* 52510 (1295) [-1,  1,  0, -1,  0,  0,  0,  0,  1] [ 8,  4,  4]  1 */
        5225, /* 52511 (1295) [-1,  1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  0]  1 */
        7412, /* 52512 (1295) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    23706149, /* 52513 (1295) [ 0, -1,  0,  1, -1,  0,  0,  0,  1] [ 8,  4,  4]  1 */
        7817, /* 52514 (1295) [ 0, -1,  0,  1, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
       16565, /* 52515 (1295) [ 1,  0,  0,  1, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    23714897, /* 52516 (1295) [ 1,  0,  0,  1, -1,  0,  0,  0,  1] [ 8,  4,  4]  1 */
    13401005, /* 52517 (1295) [ 1,  0,  0,  1, -1,  0,  0,  0,  1] [ 4,  8,  8]  1 */
    13389989, /* 52518 (1295) [-1,  1,  0,  0,  1,  0,  0,  0,  1] [ 4,  8,  8]  1 */
        5549, /* 52519 (1295) [-1,  1,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    13392257, /* 52520 (1295) [ 0, -1,  0,  1, -1,  0,  0,  0,  1] [ 4,  8,  8]  1 */
       16484, /* 52521 (1296) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    13389665, /* 52522 (1296) [-1,  1,  0, -1,  0,  0,  0,  0,  1] [ 4,  8,  8]  1 */
    47404076, /* 52523 (1296) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 4,  8,  8] -1 */
    23705744, /* 52524 (1296) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 8,  4,  4]  1 */
    47402213, /* 52525 (1296) [-1,  1,  0,  0,  1,  0,  0,  0,  1] [ 4,  8,  8] -1 */
    13400924, /* 52526 (1296) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 4,  8,  8]  1 */
    23703881, /* 52527 (1296) [-1,  1,  0,  0,  1,  0,  0,  0,  1] [ 8,  4,  4]  1 */
    47413229, /* 52528 (1296) [ 1,  0,  0,  1, -1,  0,  0,  0,  1] [ 4,  8,  8] -1 */
    23714897, /* 52529 (1296) [ 1,  0,  0,  1, -1,  0,  0,  0,  1] [ 8,  4,  4]  1 */
       16565, /* 52530 (1296) [ 1,  0,  0,  1, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    57715781, /* 52531 (1296) [-1,  1,  0, -1,  0,  0,  0,  0,  1] [ 8,  4,  4] -1 */
    34017449, /* 52532 (1296) [-1,  1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    57718373, /* 52533 (1296) [ 0, -1,  0,  1, -1,  0,  0,  0,  1] [ 8,  4,  4] -1 */
    13391852, /* 52534 (1296) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 4,  8,  8]  1 */
    34020041, /* 52535 (1296) [ 0, -1,  0,  1, -1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    13389989, /* 52536 (1296) [-1,  1,  0,  0,  1,  0,  0,  0,  1] [ 4,  8,  8]  1 */
    57727040, /* 52537 (1296) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 8,  4,  4] -1 */
    34028708, /* 52538 (1296) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    13401005, /* 52539 (1296) [ 1,  0,  0,  1, -1,  0,  0,  0,  1] [ 4,  8,  8]  1 */
    34019636, /* 52540 (1296) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    23703557, /* 52541 (1296) [-1,  1,  0, -1,  0,  0,  0,  0,  1] [ 8,  4,  4]  1 */
        5225, /* 52542 (1296) [-1,  1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    47404481, /* 52543 (1296) [ 0, -1,  0,  1, -1,  0,  0,  0,  1] [ 4,  8,  8] -1 */
    34017773, /* 52544 (1296) [-1,  1,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    23706149, /* 52545 (1296) [ 0, -1,  0,  1, -1,  0,  0,  0,  1] [ 8,  4,  4]  1 */
        7817, /* 52546 (1296) [ 0, -1,  0,  1, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    57717968, /* 52547 (1296) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 8,  4,  4] -1 */
    47401889, /* 52548 (1296) [-1,  1,  0, -1,  0,  0,  0,  0,  1] [ 4,  8,  8] -1 */
    23714816, /* 52549 (1296) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 8,  4,  4]  1 */
    47413148, /* 52550 (1296) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 4,  8,  8] -1 */
    57716105, /* 52551 (1296) [-1,  1,  0,  0,  1,  0,  0,  0,  1] [ 8,  4,  4] -1 */
    57727121, /* 52552 (1296) [ 1,  0,  0,  1, -1,  0,  0,  0,  1] [ 8,  4,  4] -1 */
    34028789, /* 52553 (1296) [ 1,  0,  0,  1, -1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
        7412, /* 52554 (1296) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  0]  1 */
        5549, /* 52555 (1296) [-1,  1,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    13392257, /* 52556 (1296) [ 0, -1,  0,  1, -1,  0,  0,  0,  1] [ 4,  8,  8]  1 */
       16484, /* 52557 (1297) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    23714816, /* 52558 (1297) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 8,  4,  4]  1 */
    13389665, /* 52559 (1297) [-1,  1,  0, -1,  0,  0,  0,  0,  1] [ 4,  8,  8]  1 */
    47404076, /* 52560 (1297) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 4,  8,  8] -1 */
    57716105, /* 52561 (1297) [-1,  1,  0,  0,  1,  0,  0,  0,  1] [ 8,  4,  4] -1 */
    47402213, /* 52562 (1297) [-1,  1,  0,  0,  1,  0,  0,  0,  1] [ 4,  8,  8] -1 */
    34019636, /* 52563 (1297) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    13400924, /* 52564 (1297) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 4,  8,  8]  1 */
    34028789, /* 52565 (1297) [ 1,  0,  0,  1, -1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    57727121, /* 52566 (1297) [ 1,  0,  0,  1, -1,  0,  0,  0,  1] [ 8,  4,  4] -1 */
    34017773, /* 52567 (1297) [-1,  1,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
        5225, /* 52568 (1297) [-1,  1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    23703557, /* 52569 (1297) [-1,  1,  0, -1,  0,  0,  0,  0,  1] [ 8,  4,  4]  1 */
    47413229, /* 52570 (1297) [ 1,  0,  0,  1, -1,  0,  0,  0,  1] [ 4,  8,  8] -1 */
    23706149, /* 52571 (1297) [ 0, -1,  0,  1, -1,  0,  0,  0,  1] [ 8,  4,  4]  1 */
        7817, /* 52572 (1297) [ 0, -1,  0,  1, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    57717968, /* 52573 (1297) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 8,  4,  4] -1 */
    13392257, /* 52574 (1297) [ 0, -1,  0,  1, -1,  0,  0,  0,  1] [ 4,  8,  8]  1 */
       16484, /* 52575 (1298) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    13389665, /* 52576 (1298) [-1,  1,  0, -1,  0,  0,  0,  0,  1] [ 4,  8,  8]  1 */
    23705744, /* 52577 (1298) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 8,  4,  4]  1 */
    57833879, /* 52578 (1298) [-1,  1,  0, -1,  0,  0,  0,  0,  1] [ 8,  4, 10] -1 */
    13400924, /* 52579 (1298) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 4,  8,  8]  1 */
    57845138, /* 52580 (1298) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 8,  4, 10] -1 */
    23703881, /* 52581 (1298) [-1,  1,  0,  0,  1,  0,  0,  0,  1] [ 8,  4,  4]  1 */
    23714897, /* 52582 (1298) [ 1,  0,  0,  1, -1,  0,  0,  0,  1] [ 8,  4,  4]  1 */
       16565, /* 52583 (1298) [ 1,  0,  0,  1, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34135547, /* 52584 (1298) [-1,  1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    34138139, /* 52585 (1298) [ 0, -1,  0,  1, -1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    13391852, /* 52586 (1298) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 4,  8,  8]  1 */
    57836066, /* 52587 (1298) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 8,  4, 10] -1 */
    57836471, /* 52588 (1298) [ 0, -1,  0,  1, -1,  0,  0,  0,  1] [ 8,  4, 10] -1 */
    34146806, /* 52589 (1298) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    13389989, /* 52590 (1298) [-1,  1,  0,  0,  1,  0,  0,  0,  1] [ 4,  8,  8]  1 */
    57834203, /* 52591 (1298) [-1,  1,  0,  0,  1,  0,  0,  0,  1] [ 8,  4, 10] -1 */
    13401005, /* 52592 (1298) [ 1,  0,  0,  1, -1,  0,  0,  0,  1] [ 4,  8,  8]  1 */
    57845219, /* 52593 (1298) [ 1,  0,  0,  1, -1,  0,  0,  0,  1] [ 8,  4, 10] -1 */
    47283791, /* 52594 (1298) [-1,  1,  0, -1,  0,  0,  0,  0,  1] [ 4,  8,  2] -1 */
    47286383, /* 52595 (1298) [ 0, -1,  0,  1, -1,  0,  0,  0,  1] [ 4,  8,  2] -1 */
    23703557, /* 52596 (1298) [-1,  1,  0, -1,  0,  0,  0,  0,  1] [ 8,  4,  4]  1 */
        5225, /* 52597 (1298) [-1,  1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    23706149, /* 52598 (1298) [ 0, -1,  0,  1, -1,  0,  0,  0,  1] [ 8,  4,  4]  1 */
        7817, /* 52599 (1298) [ 0, -1,  0,  1, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34137734, /* 52600 (1298) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    34135871, /* 52601 (1298) [-1,  1,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    47295050, /* 52602 (1298) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 4,  8,  2] -1 */
    34146887, /* 52603 (1298) [ 1,  0,  0,  1, -1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    23714816, /* 52604 (1298) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 8,  4,  4]  1 */
    47285978, /* 52605 (1298) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 4,  8,  2] -1 */
        7412, /* 52606 (1298) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    47284115, /* 52607 (1298) [-1,  1,  0,  0,  1,  0,  0,  0,  1] [ 4,  8,  2] -1 */
    47295131, /* 52608 (1298) [ 1,  0,  0,  1, -1,  0,  0,  0,  1] [ 4,  8,  2] -1 */
        5549, /* 52609 (1298) [-1,  1,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    13392257, /* 52610 (1298) [ 0, -1,  0,  1, -1,  0,  0,  0,  1] [ 4,  8,  8]  1 */
       16484, /* 52611 (1295) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
       10816, /* 52612 (1295) [ 0,  0,  1,  1,  0,  0,  0,  1,  0] [ 0,  0,  0]  1 */
       10660, /* 52613 (1295) [ 0,  0,  1,  0,  1,  0,  1,  0,  0] [ 0,  0,  0]  1 */
       12272, /* 52614 (1295) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 0,  0,  0]  1 */
       12064, /* 52615 (1295) [ 0,  1,  0,  0,  0,  1,  1,  0,  0] [ 0,  0,  0]  1 */
       16432, /* 52616 (1295) [ 1,  0,  0,  0,  0,  1,  0,  1,  0] [ 0,  0,  0]  1 */
       16484, /* 52617 (1296) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
       10816, /* 52618 (1296) [ 0,  0,  1,  1,  0,  0,  0,  1,  0] [ 0,  0,  0]  1 */
       10660, /* 52619 (1296) [ 0,  0,  1,  0,  1,  0,  1,  0,  0] [ 0,  0,  0]  1 */
       12272, /* 52620 (1296) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34024288, /* 52621 (1296) [ 0,  1,  0,  0,  0,  1,  1,  0,  0] [ 0,  0,  0] -1 */
    34028656, /* 52622 (1296) [ 1,  0,  0,  0,  0,  1,  0,  1,  0] [ 0,  0,  0] -1 */
       12064, /* 52623 (1296) [ 0,  1,  0,  0,  0,  1,  1,  0,  0] [ 0,  0,  0]  1 */
       16432, /* 52624 (1296) [ 1,  0,  0,  0,  0,  1,  0,  1,  0] [ 0,  0,  0]  1 */
    34022884, /* 52625 (1296) [ 0,  0,  1,  0,  1,  0,  1,  0,  0] [ 0,  0,  0] -1 */
    34028708, /* 52626 (1296) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    34024496, /* 52627 (1296) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    34023040, /* 52628 (1296) [ 0,  0,  1,  1,  0,  0,  0,  1,  0] [ 0,  0,  0] -1 */
       16484, /* 52629 (1297) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
       10816, /* 52630 (1297) [ 0,  0,  1,  1,  0,  0,  0,  1,  0] [ 0,  0,  0]  1 */
    34028656, /* 52631 (1297) [ 1,  0,  0,  0,  0,  1,  0,  1,  0] [ 0,  0,  0] -1 */
       12064, /* 52632 (1297) [ 0,  1,  0,  0,  0,  1,  1,  0,  0] [ 0,  0,  0]  1 */
    34022884, /* 52633 (1297) [ 0,  0,  1,  0,  1,  0,  1,  0,  0] [ 0,  0,  0] -1 */
    34024496, /* 52634 (1297) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 0,  0,  0] -1 */
       16484, /* 52635 (1298) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
       10816, /* 52636 (1298) [ 0,  0,  1,  1,  0,  0,  0,  1,  0] [ 0,  0,  0]  1 */
       10660, /* 52637 (1298) [ 0,  0,  1,  0,  1,  0,  1,  0,  0] [ 0,  0,  0]  1 */
    52564426, /* 52638 (1298) [ 0,  0,  1,  1,  0,  0,  0,  1,  0] [ 6,  6,  6] -1 */
       12272, /* 52639 (1298) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    52570042, /* 52640 (1298) [ 1,  0,  0,  0,  0,  1,  0,  1,  0] [ 6,  6,  6] -1 */
       12064, /* 52641 (1298) [ 0,  1,  0,  0,  0,  1,  1,  0,  0] [ 0,  0,  0]  1 */
    52564270, /* 52642 (1298) [ 0,  0,  1,  0,  1,  0,  1,  0,  0] [ 6,  6,  6] -1 */
       16432, /* 52643 (1298) [ 1,  0,  0,  0,  0,  1,  0,  1,  0] [ 0,  0,  0]  1 */
    52565882, /* 52644 (1298) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    52570094, /* 52645 (1298) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    52565674, /* 52646 (1298) [ 0,  1,  0,  0,  0,  1,  1,  0,  0] [ 6,  6,  6] -1 */
       16484, /* 52647 (1299) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    23714816, /* 52648 (1299) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 8,  4,  4]  1 */
    23832995, /* 52649 (1299) [ 1,  0,  0,  1, -1,  0,  0,  0,  1] [ 8,  4, 10]  1 */
    13389665, /* 52650 (1299) [-1,  1,  0, -1,  0,  0,  0,  0,  1] [ 4,  8,  8]  1 */
    13282907, /* 52651 (1299) [ 1,  0,  0,  1, -1,  0,  0,  0,  1] [ 4,  8,  2]  1 */
      123647, /* 52652 (1299) [-1,  1,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6]  1 */
    13400924, /* 52653 (1299) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 4,  8,  8]  1 */
      134663, /* 52654 (1299) [ 1,  0,  0,  1, -1,  0,  0,  0,  1] [ 0,  0,  6]  1 */
    23703557, /* 52655 (1299) [-1,  1,  0, -1,  0,  0,  0,  0,  1] [ 8,  4,  4]  1 */
        5225, /* 52656 (1299) [-1,  1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    23706149, /* 52657 (1299) [ 0, -1,  0,  1, -1,  0,  0,  0,  1] [ 8,  4,  4]  1 */
        7817, /* 52658 (1299) [ 0, -1,  0,  1, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    13271891, /* 52659 (1299) [-1,  1,  0,  0,  1,  0,  0,  0,  1] [ 4,  8,  2]  1 */
    13273754, /* 52660 (1299) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 4,  8,  2]  1 */
    23823842, /* 52661 (1299) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 8,  4, 10]  1 */
      125510, /* 52662 (1299) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  6]  1 */
    13392257, /* 52663 (1299) [ 0, -1,  0,  1, -1,  0,  0,  0,  1] [ 4,  8,  8]  1 */
    23821979, /* 52664 (1299) [-1,  1,  0,  0,  1,  0,  0,  0,  1] [ 8,  4, 10]  1 */
       16484, /* 52665 (1300) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    13389665, /* 52666 (1300) [-1,  1,  0, -1,  0,  0,  0,  0,  1] [ 4,  8,  8]  1 */
      123647, /* 52667 (1300) [-1,  1,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6]  1 */
    13400924, /* 52668 (1300) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 4,  8,  8]  1 */
      134663, /* 52669 (1300) [ 1,  0,  0,  1, -1,  0,  0,  0,  1] [ 0,  0,  6]  1 */
    13273754, /* 52670 (1300) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 4,  8,  2]  1 */
    13271891, /* 52671 (1300) [-1,  1,  0,  0,  1,  0,  0,  0,  1] [ 4,  8,  2]  1 */
    57715781, /* 52672 (1300) [-1,  1,  0, -1,  0,  0,  0,  0,  1] [ 8,  4,  4] -1 */
    13282907, /* 52673 (1300) [ 1,  0,  0,  1, -1,  0,  0,  0,  1] [ 4,  8,  2]  1 */
    34017449, /* 52674 (1300) [-1,  1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    57718373, /* 52675 (1300) [ 0, -1,  0,  1, -1,  0,  0,  0,  1] [ 8,  4,  4] -1 */
    34020041, /* 52676 (1300) [ 0, -1,  0,  1, -1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    57836066, /* 52677 (1300) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 8,  4, 10] -1 */
    57834203, /* 52678 (1300) [-1,  1,  0,  0,  1,  0,  0,  0,  1] [ 8,  4, 10] -1 */
    57727040, /* 52679 (1300) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 8,  4,  4] -1 */
    34028708, /* 52680 (1300) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    57845219, /* 52681 (1300) [ 1,  0,  0,  1, -1,  0,  0,  0,  1] [ 8,  4, 10] -1 */
    23703557, /* 52682 (1300) [-1,  1,  0, -1,  0,  0,  0,  0,  1] [ 8,  4,  4]  1 */
        5225, /* 52683 (1300) [-1,  1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    47404481, /* 52684 (1300) [ 0, -1,  0,  1, -1,  0,  0,  0,  1] [ 4,  8,  8] -1 */
    23706149, /* 52685 (1300) [ 0, -1,  0,  1, -1,  0,  0,  0,  1] [ 8,  4,  4]  1 */
        7817, /* 52686 (1300) [ 0, -1,  0,  1, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34137734, /* 52687 (1300) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    34135871, /* 52688 (1300) [-1,  1,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    23823842, /* 52689 (1300) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 8,  4, 10]  1 */
    47401889, /* 52690 (1300) [-1,  1,  0, -1,  0,  0,  0,  0,  1] [ 4,  8,  8] -1 */
    23821979, /* 52691 (1300) [-1,  1,  0,  0,  1,  0,  0,  0,  1] [ 8,  4, 10]  1 */
    34146887, /* 52692 (1300) [ 1,  0,  0,  1, -1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    23714816, /* 52693 (1300) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 8,  4,  4]  1 */
    23832995, /* 52694 (1300) [ 1,  0,  0,  1, -1,  0,  0,  0,  1] [ 8,  4, 10]  1 */
    47413148, /* 52695 (1300) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 4,  8,  8] -1 */
    47285978, /* 52696 (1300) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 4,  8,  2] -1 */
    47284115, /* 52697 (1300) [-1,  1,  0,  0,  1,  0,  0,  0,  1] [ 4,  8,  2] -1 */
    47295131, /* 52698 (1300) [ 1,  0,  0,  1, -1,  0,  0,  0,  1] [ 4,  8,  2] -1 */
      125510, /* 52699 (1300) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  6]  1 */
    13392257, /* 52700 (1300) [ 0, -1,  0,  1, -1,  0,  0,  0,  1] [ 4,  8,  8]  1 */
       16484, /* 52701 (1301) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    23714816, /* 52702 (1301) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 8,  4,  4]  1 */
    13389665, /* 52703 (1301) [-1,  1,  0, -1,  0,  0,  0,  0,  1] [ 4,  8,  8]  1 */
    47285978, /* 52704 (1301) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 4,  8,  2] -1 */
    13400924, /* 52705 (1301) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 4,  8,  8]  1 */
    23703557, /* 52706 (1301) [-1,  1,  0, -1,  0,  0,  0,  0,  1] [ 8,  4,  4]  1 */
        5225, /* 52707 (1301) [-1,  1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    23706149, /* 52708 (1301) [ 0, -1,  0,  1, -1,  0,  0,  0,  1] [ 8,  4,  4]  1 */
        7817, /* 52709 (1301) [ 0, -1,  0,  1, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    57836066, /* 52710 (1301) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 8,  4, 10] -1 */
    34137734, /* 52711 (1301) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    47284115, /* 52712 (1301) [-1,  1,  0,  0,  1,  0,  0,  0,  1] [ 4,  8,  2] -1 */
    57834203, /* 52713 (1301) [-1,  1,  0,  0,  1,  0,  0,  0,  1] [ 8,  4, 10] -1 */
    34135871, /* 52714 (1301) [-1,  1,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    47295131, /* 52715 (1301) [ 1,  0,  0,  1, -1,  0,  0,  0,  1] [ 4,  8,  2] -1 */
    57845219, /* 52716 (1301) [ 1,  0,  0,  1, -1,  0,  0,  0,  1] [ 8,  4, 10] -1 */
    13392257, /* 52717 (1301) [ 0, -1,  0,  1, -1,  0,  0,  0,  1] [ 4,  8,  8]  1 */
    34146887, /* 52718 (1301) [ 1,  0,  0,  1, -1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
       16484, /* 52719 (1302) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    13389665, /* 52720 (1302) [-1,  1,  0, -1,  0,  0,  0,  0,  1] [ 4,  8,  8]  1 */
    47404076, /* 52721 (1302) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 4,  8,  8] -1 */
      123647, /* 52722 (1302) [-1,  1,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6]  1 */
    47402213, /* 52723 (1302) [-1,  1,  0,  0,  1,  0,  0,  0,  1] [ 4,  8,  8] -1 */
    57833879, /* 52724 (1302) [-1,  1,  0, -1,  0,  0,  0,  0,  1] [ 8,  4, 10] -1 */
    13400924, /* 52725 (1302) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 4,  8,  8]  1 */
    57845138, /* 52726 (1302) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 8,  4, 10] -1 */
      134663, /* 52727 (1302) [ 1,  0,  0,  1, -1,  0,  0,  0,  1] [ 0,  0,  6]  1 */
    47413229, /* 52728 (1302) [ 1,  0,  0,  1, -1,  0,  0,  0,  1] [ 4,  8,  8] -1 */
    13273754, /* 52729 (1302) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 4,  8,  2]  1 */
    34135547, /* 52730 (1302) [-1,  1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    13271891, /* 52731 (1302) [-1,  1,  0,  0,  1,  0,  0,  0,  1] [ 4,  8,  2]  1 */
    13282907, /* 52732 (1302) [ 1,  0,  0,  1, -1,  0,  0,  0,  1] [ 4,  8,  2]  1 */
    34138139, /* 52733 (1302) [ 0, -1,  0,  1, -1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    57836471, /* 52734 (1302) [ 0, -1,  0,  1, -1,  0,  0,  0,  1] [ 8,  4, 10] -1 */
    34146806, /* 52735 (1302) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    47283791, /* 52736 (1302) [-1,  1,  0, -1,  0,  0,  0,  0,  1] [ 4,  8,  2] -1 */
    34019636, /* 52737 (1302) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    47286383, /* 52738 (1302) [ 0, -1,  0,  1, -1,  0,  0,  0,  1] [ 4,  8,  2] -1 */
    23703557, /* 52739 (1302) [-1,  1,  0, -1,  0,  0,  0,  0,  1] [ 8,  4,  4]  1 */
        5225, /* 52740 (1302) [-1,  1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34017773, /* 52741 (1302) [-1,  1,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    23706149, /* 52742 (1302) [ 0, -1,  0,  1, -1,  0,  0,  0,  1] [ 8,  4,  4]  1 */
        7817, /* 52743 (1302) [ 0, -1,  0,  1, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    23823842, /* 52744 (1302) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 8,  4, 10]  1 */
    47295050, /* 52745 (1302) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 4,  8,  2] -1 */
    57717968, /* 52746 (1302) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 8,  4,  4] -1 */
    23821979, /* 52747 (1302) [-1,  1,  0,  0,  1,  0,  0,  0,  1] [ 8,  4, 10]  1 */
    23714816, /* 52748 (1302) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 8,  4,  4]  1 */
    23832995, /* 52749 (1302) [ 1,  0,  0,  1, -1,  0,  0,  0,  1] [ 8,  4, 10]  1 */
    57716105, /* 52750 (1302) [-1,  1,  0,  0,  1,  0,  0,  0,  1] [ 8,  4,  4] -1 */
    57727121, /* 52751 (1302) [ 1,  0,  0,  1, -1,  0,  0,  0,  1] [ 8,  4,  4] -1 */
    34028789, /* 52752 (1302) [ 1,  0,  0,  1, -1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
      125510, /* 52753 (1302) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  6]  1 */
    13392257, /* 52754 (1302) [ 0, -1,  0,  1, -1,  0,  0,  0,  1] [ 4,  8,  8]  1 */
       16484, /* 52755 (1299) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
       10816, /* 52756 (1299) [ 0,  0,  1,  1,  0,  0,  0,  1,  0] [ 0,  0,  0]  1 */
       12064, /* 52757 (1299) [ 0,  1,  0,  0,  0,  1,  1,  0,  0] [ 0,  0,  0]  1 */
    18557818, /* 52758 (1299) [ 1,  0,  0,  0,  0,  1,  0,  1,  0] [ 6,  6,  6]  1 */
    18552046, /* 52759 (1299) [ 0,  0,  1,  0,  1,  0,  1,  0,  0] [ 6,  6,  6]  1 */
    18553658, /* 52760 (1299) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 6,  6,  6]  1 */
       16484, /* 52761 (1300) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
       10816, /* 52762 (1300) [ 0,  0,  1,  1,  0,  0,  0,  1,  0] [ 0,  0,  0]  1 */
    52565882, /* 52763 (1300) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    34024288, /* 52764 (1300) [ 0,  1,  0,  0,  0,  1,  1,  0,  0] [ 0,  0,  0] -1 */
    52570042, /* 52765 (1300) [ 1,  0,  0,  0,  0,  1,  0,  1,  0] [ 6,  6,  6] -1 */
       12064, /* 52766 (1300) [ 0,  1,  0,  0,  0,  1,  1,  0,  0] [ 0,  0,  0]  1 */
    52564270, /* 52767 (1300) [ 0,  0,  1,  0,  1,  0,  1,  0,  0] [ 6,  6,  6] -1 */
    18557818, /* 52768 (1300) [ 1,  0,  0,  0,  0,  1,  0,  1,  0] [ 6,  6,  6]  1 */
    18552046, /* 52769 (1300) [ 0,  0,  1,  0,  1,  0,  1,  0,  0] [ 6,  6,  6]  1 */
    34028708, /* 52770 (1300) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    34023040, /* 52771 (1300) [ 0,  0,  1,  1,  0,  0,  0,  1,  0] [ 0,  0,  0] -1 */
    18553658, /* 52772 (1300) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 6,  6,  6]  1 */
       16484, /* 52773 (1301) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
       10816, /* 52774 (1301) [ 0,  0,  1,  1,  0,  0,  0,  1,  0] [ 0,  0,  0]  1 */
    52570042, /* 52775 (1301) [ 1,  0,  0,  0,  0,  1,  0,  1,  0] [ 6,  6,  6] -1 */
       12064, /* 52776 (1301) [ 0,  1,  0,  0,  0,  1,  1,  0,  0] [ 0,  0,  0]  1 */
    52564270, /* 52777 (1301) [ 0,  0,  1,  0,  1,  0,  1,  0,  0] [ 6,  6,  6] -1 */
    52565882, /* 52778 (1301) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 6,  6,  6] -1 */
       16484, /* 52779 (1302) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    52565674, /* 52780 (1302) [ 0,  1,  0,  0,  0,  1,  1,  0,  0] [ 6,  6,  6] -1 */
       10816, /* 52781 (1302) [ 0,  0,  1,  1,  0,  0,  0,  1,  0] [ 0,  0,  0]  1 */
    18552046, /* 52782 (1302) [ 0,  0,  1,  0,  1,  0,  1,  0,  0] [ 6,  6,  6]  1 */
    52564426, /* 52783 (1302) [ 0,  0,  1,  1,  0,  0,  0,  1,  0] [ 6,  6,  6] -1 */
    34028656, /* 52784 (1302) [ 1,  0,  0,  0,  0,  1,  0,  1,  0] [ 0,  0,  0] -1 */
       12064, /* 52785 (1302) [ 0,  1,  0,  0,  0,  1,  1,  0,  0] [ 0,  0,  0]  1 */
    34022884, /* 52786 (1302) [ 0,  0,  1,  0,  1,  0,  1,  0,  0] [ 0,  0,  0] -1 */
    52570094, /* 52787 (1302) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    18557818, /* 52788 (1302) [ 1,  0,  0,  0,  0,  1,  0,  1,  0] [ 6,  6,  6]  1 */
    34024496, /* 52789 (1302) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    18553658, /* 52790 (1302) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 6,  6,  6]  1 */
       16484, /* 52791 (1303) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
       16563, /* 52792 (1303) [ 1,  0,  0,  1, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
        3119, /* 52793 (1303) [-1,  0,  0, -1,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
       14457, /* 52794 (1303) [ 1, -1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  0]  1 */
       12272, /* 52795 (1303) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 0,  0,  0]  1 */
        7410, /* 52796 (1303) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  0]  1 */
        5225, /* 52797 (1303) [-1,  1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  0]  1 */
       14135, /* 52798 (1303) [ 1, -1,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
        3198, /* 52799 (1303) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
        7817, /* 52800 (1303) [ 0, -1,  0,  1, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
        5547, /* 52801 (1303) [-1,  1,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
       11865, /* 52802 (1303) [ 0,  1,  0, -1,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
       16484, /* 52803 (1304) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
       16563, /* 52804 (1304) [ 1,  0,  0,  1, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    34019634, /* 52805 (1304) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    34017771, /* 52806 (1304) [-1,  1,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
        3198, /* 52807 (1304) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    34017449, /* 52808 (1304) [-1,  1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    34026681, /* 52809 (1304) [ 1, -1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    34020041, /* 52810 (1304) [ 0, -1,  0,  1, -1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
        7410, /* 52811 (1304) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  0]  1 */
        5547, /* 52812 (1304) [-1,  1,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    34028708, /* 52813 (1304) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    34024496, /* 52814 (1304) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    34015343, /* 52815 (1304) [-1,  0,  0, -1,  1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    34026359, /* 52816 (1304) [ 1, -1,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
       14457, /* 52817 (1304) [ 1, -1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  0]  1 */
        5225, /* 52818 (1304) [-1,  1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  0]  1 */
        7817, /* 52819 (1304) [ 0, -1,  0,  1, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34024089, /* 52820 (1304) [ 0,  1,  0, -1,  1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    34028787, /* 52821 (1304) [ 1,  0,  0,  1, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    34015422, /* 52822 (1304) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
        3119, /* 52823 (1304) [-1,  0,  0, -1,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
       12272, /* 52824 (1304) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 0,  0,  0]  1 */
       14135, /* 52825 (1304) [ 1, -1,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
       11865, /* 52826 (1304) [ 0,  1,  0, -1,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
       16484, /* 52827 (1305) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34028787, /* 52828 (1305) [ 1,  0,  0,  1, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    34026681, /* 52829 (1305) [ 1, -1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    34015422, /* 52830 (1305) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    34019634, /* 52831 (1305) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  0] -1 */
        3119, /* 52832 (1305) [-1,  0,  0, -1,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
       12272, /* 52833 (1305) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34017771, /* 52834 (1305) [-1,  1,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
        5225, /* 52835 (1305) [-1,  1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  0]  1 */
       14135, /* 52836 (1305) [ 1, -1,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
        7817, /* 52837 (1305) [ 0, -1,  0,  1, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34024089, /* 52838 (1305) [ 0,  1,  0, -1,  1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
       16484, /* 52839 (1306) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34015343, /* 52840 (1306) [-1,  0,  0, -1,  1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    34026681, /* 52841 (1306) [ 1, -1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    34015422, /* 52842 (1306) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
       16563, /* 52843 (1306) [ 1,  0,  0,  1, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    34026359, /* 52844 (1306) [ 1, -1,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
        7410, /* 52845 (1306) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  0]  1 */
        5225, /* 52846 (1306) [-1,  1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  0]  1 */
        7817, /* 52847 (1306) [ 0, -1,  0,  1, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34024089, /* 52848 (1306) [ 0,  1,  0, -1,  1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
        5547, /* 52849 (1306) [-1,  1,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    34024496, /* 52850 (1306) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 0,  0,  0] -1 */
       16484, /* 52851 (1307) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34028787, /* 52852 (1307) [ 1,  0,  0,  1, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    34015343, /* 52853 (1307) [-1,  0,  0, -1,  1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    34019634, /* 52854 (1307) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    34026359, /* 52855 (1307) [ 1, -1,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
       14457, /* 52856 (1307) [ 1, -1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    34017771, /* 52857 (1307) [-1,  1,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
        5225, /* 52858 (1307) [-1,  1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  0]  1 */
        3198, /* 52859 (1307) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
        7817, /* 52860 (1307) [ 0, -1,  0,  1, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34024496, /* 52861 (1307) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 0,  0,  0] -1 */
       11865, /* 52862 (1307) [ 0,  1,  0, -1,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
       16484, /* 52863 (1308) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34137732, /* 52864 (1308) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  6] -1 */
    34135869, /* 52865 (1308) [-1,  1,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
       16563, /* 52866 (1308) [ 1,  0,  0,  1, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
        3198, /* 52867 (1308) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    34135547, /* 52868 (1308) [-1,  1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    34138139, /* 52869 (1308) [ 0, -1,  0,  1, -1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    34144779, /* 52870 (1308) [ 1, -1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  6] -1 */
        7410, /* 52871 (1308) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    34146806, /* 52872 (1308) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
        5547, /* 52873 (1308) [-1,  1,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    34142594, /* 52874 (1308) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 0,  0,  6] -1 */
       14457, /* 52875 (1308) [ 1, -1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    34133441, /* 52876 (1308) [-1,  0,  0, -1,  1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
        5225, /* 52877 (1308) [-1,  1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34142187, /* 52878 (1308) [ 0,  1,  0, -1,  1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
        7817, /* 52879 (1308) [ 0, -1,  0,  1, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34144457, /* 52880 (1308) [ 1, -1,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
        3119, /* 52881 (1308) [-1,  0,  0, -1,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
       12272, /* 52882 (1308) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34146885, /* 52883 (1308) [ 1,  0,  0,  1, -1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
    34133520, /* 52884 (1308) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
       14135, /* 52885 (1308) [ 1, -1,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
       11865, /* 52886 (1308) [ 0,  1,  0, -1,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
       16484, /* 52887 (1309) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
      125508, /* 52888 (1309) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  6]  1 */
       14457, /* 52889 (1309) [ 1, -1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  0]  1 */
        5225, /* 52890 (1309) [-1,  1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  0]  1 */
        3198, /* 52891 (1309) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
        7817, /* 52892 (1309) [ 0, -1,  0,  1, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
      134661, /* 52893 (1309) [ 1,  0,  0,  1, -1,  0,  0,  0, -1] [ 0,  0,  6]  1 */
      130370, /* 52894 (1309) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 0,  0,  6]  1 */
      123645, /* 52895 (1309) [-1,  1,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  6]  1 */
      121217, /* 52896 (1309) [-1,  0,  0, -1,  1,  0,  0,  0,  1] [ 0,  0,  6]  1 */
      132233, /* 52897 (1309) [ 1, -1,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6]  1 */
       11865, /* 52898 (1309) [ 0,  1,  0, -1,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
       16484, /* 52899 (1310) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34137732, /* 52900 (1310) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  6] -1 */
    34135869, /* 52901 (1310) [-1,  1,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
        3198, /* 52902 (1310) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
      134661, /* 52903 (1310) [ 1,  0,  0,  1, -1,  0,  0,  0, -1] [ 0,  0,  6]  1 */
    34017449, /* 52904 (1310) [-1,  1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    34026681, /* 52905 (1310) [ 1, -1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  0] -1 */
      125508, /* 52906 (1310) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  6]  1 */
    34020041, /* 52907 (1310) [ 0, -1,  0,  1, -1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
      123645, /* 52908 (1310) [-1,  1,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  6]  1 */
    34028708, /* 52909 (1310) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    34142594, /* 52910 (1310) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 0,  0,  6] -1 */
       14457, /* 52911 (1310) [ 1, -1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    34133441, /* 52912 (1310) [-1,  0,  0, -1,  1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
        5225, /* 52913 (1310) [-1,  1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  0]  1 */
        7817, /* 52914 (1310) [ 0, -1,  0,  1, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34144457, /* 52915 (1310) [ 1, -1,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    34024089, /* 52916 (1310) [ 0,  1,  0, -1,  1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    34015422, /* 52917 (1310) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    34146885, /* 52918 (1310) [ 1,  0,  0,  1, -1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
      121217, /* 52919 (1310) [-1,  0,  0, -1,  1,  0,  0,  0,  1] [ 0,  0,  6]  1 */
      130370, /* 52920 (1310) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 0,  0,  6]  1 */
      132233, /* 52921 (1310) [ 1, -1,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6]  1 */
       11865, /* 52922 (1310) [ 0,  1,  0, -1,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
       16484, /* 52923 (1311) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34137732, /* 52924 (1311) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  6] -1 */
    34026681, /* 52925 (1311) [ 1, -1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    34015422, /* 52926 (1311) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    34135869, /* 52927 (1311) [-1,  1,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
    34146885, /* 52928 (1311) [ 1,  0,  0,  1, -1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
        5225, /* 52929 (1311) [-1,  1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  0]  1 */
        7817, /* 52930 (1311) [ 0, -1,  0,  1, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
      121217, /* 52931 (1311) [-1,  0,  0, -1,  1,  0,  0,  0,  1] [ 0,  0,  6]  1 */
      130370, /* 52932 (1311) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 0,  0,  6]  1 */
    34024089, /* 52933 (1311) [ 0,  1,  0, -1,  1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
      132233, /* 52934 (1311) [ 1, -1,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6]  1 */
       16484, /* 52935 (1312) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34026681, /* 52936 (1312) [ 1, -1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    34015422, /* 52937 (1312) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    34142594, /* 52938 (1312) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 0,  0,  6] -1 */
      125508, /* 52939 (1312) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  6]  1 */
    34133441, /* 52940 (1312) [-1,  0,  0, -1,  1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
        5225, /* 52941 (1312) [-1,  1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  0]  1 */
        7817, /* 52942 (1312) [ 0, -1,  0,  1, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
      134661, /* 52943 (1312) [ 1,  0,  0,  1, -1,  0,  0,  0, -1] [ 0,  0,  6]  1 */
      123645, /* 52944 (1312) [-1,  1,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  6]  1 */
    34144457, /* 52945 (1312) [ 1, -1,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    34024089, /* 52946 (1312) [ 0,  1,  0, -1,  1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
       16484, /* 52947 (1313) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34137732, /* 52948 (1313) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  6] -1 */
    34135869, /* 52949 (1313) [-1,  1,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
    34142594, /* 52950 (1313) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 0,  0,  6] -1 */
       14457, /* 52951 (1313) [ 1, -1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    34146885, /* 52952 (1313) [ 1,  0,  0,  1, -1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
    34133441, /* 52953 (1313) [-1,  0,  0, -1,  1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
        5225, /* 52954 (1313) [-1,  1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  0]  1 */
        3198, /* 52955 (1313) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
        7817, /* 52956 (1313) [ 0, -1,  0,  1, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34144457, /* 52957 (1313) [ 1, -1,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
       11865, /* 52958 (1313) [ 0,  1,  0, -1,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
       16484, /* 52959 (1314) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34019634, /* 52960 (1314) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    34017771, /* 52961 (1314) [-1,  1,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
        3198, /* 52962 (1314) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
      134661, /* 52963 (1314) [ 1,  0,  0,  1, -1,  0,  0,  0, -1] [ 0,  0,  6]  1 */
    34135547, /* 52964 (1314) [-1,  1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    34138139, /* 52965 (1314) [ 0, -1,  0,  1, -1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
      125508, /* 52966 (1314) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  6]  1 */
    34144779, /* 52967 (1314) [ 1, -1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  6] -1 */
      123645, /* 52968 (1314) [-1,  1,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  6]  1 */
    34146806, /* 52969 (1314) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    34024496, /* 52970 (1314) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    34015343, /* 52971 (1314) [-1,  0,  0, -1,  1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    34026359, /* 52972 (1314) [ 1, -1,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
       14457, /* 52973 (1314) [ 1, -1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  0]  1 */
        5225, /* 52974 (1314) [-1,  1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34142187, /* 52975 (1314) [ 0,  1,  0, -1,  1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
        7817, /* 52976 (1314) [ 0, -1,  0,  1, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34028787, /* 52977 (1314) [ 1,  0,  0,  1, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    34133520, /* 52978 (1314) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
      121217, /* 52979 (1314) [-1,  0,  0, -1,  1,  0,  0,  0,  1] [ 0,  0,  6]  1 */
      130370, /* 52980 (1314) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 0,  0,  6]  1 */
      132233, /* 52981 (1314) [ 1, -1,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6]  1 */
       11865, /* 52982 (1314) [ 0,  1,  0, -1,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
       16484, /* 52983 (1315) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
        3117, /* 52984 (1315) [-1,  0,  0, -1,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
       14457, /* 52985 (1315) [ 1, -1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  0]  1 */
        5225, /* 52986 (1315) [-1,  1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  0]  1 */
       12270, /* 52987 (1315) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  0]  1 */
        7412, /* 52988 (1315) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  0]  1 */
        3198, /* 52989 (1315) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
        7817, /* 52990 (1315) [ 0, -1,  0,  1, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
       16565, /* 52991 (1315) [ 1,  0,  0,  1, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
       14133, /* 52992 (1315) [ 1, -1,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
        5549, /* 52993 (1315) [-1,  1,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
       11865, /* 52994 (1315) [ 0,  1,  0, -1,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
       16484, /* 52995 (1316) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
       12270, /* 52996 (1316) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  0]  1 */
        3198, /* 52997 (1316) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
       16565, /* 52998 (1316) [ 1,  0,  0,  1, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34017449, /* 52999 (1316) [-1,  1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    34026681, /* 53000 (1316) [ 1, -1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    34020041, /* 53001 (1316) [ 0, -1,  0,  1, -1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    34028708, /* 53002 (1316) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    34015341, /* 53003 (1316) [-1,  0,  0, -1,  1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
       14457, /* 53004 (1316) [ 1, -1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    34019636, /* 53005 (1316) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    34017773, /* 53006 (1316) [-1,  1,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
        5225, /* 53007 (1316) [-1,  1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34026357, /* 53008 (1316) [ 1, -1,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
        7817, /* 53009 (1316) [ 0, -1,  0,  1, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34024089, /* 53010 (1316) [ 0,  1,  0, -1,  1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    34015422, /* 53011 (1316) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    34024494, /* 53012 (1316) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  0] -1 */
        3117, /* 53013 (1316) [-1,  0,  0, -1,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    34028789, /* 53014 (1316) [ 1,  0,  0,  1, -1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
        7412, /* 53015 (1316) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  0]  1 */
       14133, /* 53016 (1316) [ 1, -1,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
        5549, /* 53017 (1316) [-1,  1,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
       11865, /* 53018 (1316) [ 0,  1,  0, -1,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
       16484, /* 53019 (1317) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34015341, /* 53020 (1317) [-1,  0,  0, -1,  1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    34026681, /* 53021 (1317) [ 1, -1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    34015422, /* 53022 (1317) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    34024494, /* 53023 (1317) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  0] -1 */
        5225, /* 53024 (1317) [-1,  1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34026357, /* 53025 (1317) [ 1, -1,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
        7412, /* 53026 (1317) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  0]  1 */
        7817, /* 53027 (1317) [ 0, -1,  0,  1, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
       16565, /* 53028 (1317) [ 1,  0,  0,  1, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34024089, /* 53029 (1317) [ 0,  1,  0, -1,  1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
        5549, /* 53030 (1317) [-1,  1,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
       16484, /* 53031 (1318) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34026681, /* 53032 (1318) [ 1, -1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    34015422, /* 53033 (1318) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
        3117, /* 53034 (1318) [-1,  0,  0, -1,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    34019636, /* 53035 (1318) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    34028789, /* 53036 (1318) [ 1,  0,  0,  1, -1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    34017773, /* 53037 (1318) [-1,  1,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
        5225, /* 53038 (1318) [-1,  1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  0]  1 */
       12270, /* 53039 (1318) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  0]  1 */
        7817, /* 53040 (1318) [ 0, -1,  0,  1, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
       14133, /* 53041 (1318) [ 1, -1,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    34024089, /* 53042 (1318) [ 0,  1,  0, -1,  1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
       16484, /* 53043 (1319) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34015341, /* 53044 (1319) [-1,  0,  0, -1,  1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    34024494, /* 53045 (1319) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    34019636, /* 53046 (1319) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  0] -1 */
       14457, /* 53047 (1319) [ 1, -1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    34028789, /* 53048 (1319) [ 1,  0,  0,  1, -1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    34017773, /* 53049 (1319) [-1,  1,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
        5225, /* 53050 (1319) [-1,  1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34026357, /* 53051 (1319) [ 1, -1,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
        3198, /* 53052 (1319) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
        7817, /* 53053 (1319) [ 0, -1,  0,  1, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
       11865, /* 53054 (1319) [ 0,  1,  0, -1,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
       16484, /* 53055 (1320) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
       12270, /* 53056 (1320) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  0]  1 */
        3198, /* 53057 (1320) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
       16565, /* 53058 (1320) [ 1,  0,  0,  1, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34135547, /* 53059 (1320) [-1,  1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    34138139, /* 53060 (1320) [ 0, -1,  0,  1, -1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    34144779, /* 53061 (1320) [ 1, -1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  6] -1 */
    34146806, /* 53062 (1320) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    34133439, /* 53063 (1320) [-1,  0,  0, -1,  1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
    34144455, /* 53064 (1320) [ 1, -1,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
       14457, /* 53065 (1320) [ 1, -1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  0]  1 */
        5225, /* 53066 (1320) [-1,  1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34142187, /* 53067 (1320) [ 0,  1,  0, -1,  1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
        7817, /* 53068 (1320) [ 0, -1,  0,  1, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34137734, /* 53069 (1320) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    34135871, /* 53070 (1320) [-1,  1,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    34146887, /* 53071 (1320) [ 1,  0,  0,  1, -1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    34142592, /* 53072 (1320) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  6] -1 */
        3117, /* 53073 (1320) [-1,  0,  0, -1,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    34133520, /* 53074 (1320) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
        7412, /* 53075 (1320) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  0]  1 */
       14133, /* 53076 (1320) [ 1, -1,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
        5549, /* 53077 (1320) [-1,  1,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
       11865, /* 53078 (1320) [ 0,  1,  0, -1,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
       16484, /* 53079 (1321) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
      121215, /* 53080 (1321) [-1,  0,  0, -1,  1,  0,  0,  0, -1] [ 0,  0,  6]  1 */
      123647, /* 53081 (1321) [-1,  1,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6]  1 */
      130368, /* 53082 (1321) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  6]  1 */
       14457, /* 53083 (1321) [ 1, -1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  0]  1 */
      134663, /* 53084 (1321) [ 1,  0,  0,  1, -1,  0,  0,  0,  1] [ 0,  0,  6]  1 */
        5225, /* 53085 (1321) [-1,  1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  0]  1 */
      132231, /* 53086 (1321) [ 1, -1,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  6]  1 */
        3198, /* 53087 (1321) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
        7817, /* 53088 (1321) [ 0, -1,  0,  1, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
      125510, /* 53089 (1321) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  6]  1 */
       11865, /* 53090 (1321) [ 0,  1,  0, -1,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
       16484, /* 53091 (1322) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
      123647, /* 53092 (1322) [-1,  1,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6]  1 */
      130368, /* 53093 (1322) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  6]  1 */
      134663, /* 53094 (1322) [ 1,  0,  0,  1, -1,  0,  0,  0,  1] [ 0,  0,  6]  1 */
        3198, /* 53095 (1322) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    34017449, /* 53096 (1322) [-1,  1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    34026681, /* 53097 (1322) [ 1, -1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    34020041, /* 53098 (1322) [ 0, -1,  0,  1, -1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    34028708, /* 53099 (1322) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    34133439, /* 53100 (1322) [-1,  0,  0, -1,  1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
    34144455, /* 53101 (1322) [ 1, -1,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
       14457, /* 53102 (1322) [ 1, -1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  0]  1 */
        5225, /* 53103 (1322) [-1,  1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  0]  1 */
        7817, /* 53104 (1322) [ 0, -1,  0,  1, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34137734, /* 53105 (1322) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    34024089, /* 53106 (1322) [ 0,  1,  0, -1,  1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    34135871, /* 53107 (1322) [-1,  1,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    34146887, /* 53108 (1322) [ 1,  0,  0,  1, -1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    34142592, /* 53109 (1322) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  6] -1 */
      121215, /* 53110 (1322) [-1,  0,  0, -1,  1,  0,  0,  0, -1] [ 0,  0,  6]  1 */
    34015422, /* 53111 (1322) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
      132231, /* 53112 (1322) [ 1, -1,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  6]  1 */
      125510, /* 53113 (1322) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  6]  1 */
       11865, /* 53114 (1322) [ 0,  1,  0, -1,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
       16484, /* 53115 (1323) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34142592, /* 53116 (1323) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  6] -1 */
    34026681, /* 53117 (1323) [ 1, -1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    34015422, /* 53118 (1323) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
      123647, /* 53119 (1323) [-1,  1,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6]  1 */
    34144455, /* 53120 (1323) [ 1, -1,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
      134663, /* 53121 (1323) [ 1,  0,  0,  1, -1,  0,  0,  0,  1] [ 0,  0,  6]  1 */
        5225, /* 53122 (1323) [-1,  1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  0]  1 */
        7817, /* 53123 (1323) [ 0, -1,  0,  1, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34024089, /* 53124 (1323) [ 0,  1,  0, -1,  1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
      125510, /* 53125 (1323) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  6]  1 */
    34133439, /* 53126 (1323) [-1,  0,  0, -1,  1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
       16484, /* 53127 (1324) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34026681, /* 53128 (1324) [ 1, -1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  0] -1 */
      121215, /* 53129 (1324) [-1,  0,  0, -1,  1,  0,  0,  0, -1] [ 0,  0,  6]  1 */
    34015422, /* 53130 (1324) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
      130368, /* 53131 (1324) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  6]  1 */
        5225, /* 53132 (1324) [-1,  1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  0]  1 */
      132231, /* 53133 (1324) [ 1, -1,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  6]  1 */
        7817, /* 53134 (1324) [ 0, -1,  0,  1, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34137734, /* 53135 (1324) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    34024089, /* 53136 (1324) [ 0,  1,  0, -1,  1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    34135871, /* 53137 (1324) [-1,  1,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    34146887, /* 53138 (1324) [ 1,  0,  0,  1, -1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
       16484, /* 53139 (1325) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34142592, /* 53140 (1325) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  6] -1 */
    34144455, /* 53141 (1325) [ 1, -1,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
       14457, /* 53142 (1325) [ 1, -1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    34146887, /* 53143 (1325) [ 1,  0,  0,  1, -1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
        5225, /* 53144 (1325) [-1,  1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  0]  1 */
        3198, /* 53145 (1325) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
        7817, /* 53146 (1325) [ 0, -1,  0,  1, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34137734, /* 53147 (1325) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    34135871, /* 53148 (1325) [-1,  1,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    34133439, /* 53149 (1325) [-1,  0,  0, -1,  1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
       11865, /* 53150 (1325) [ 0,  1,  0, -1,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
       16484, /* 53151 (1326) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
      123647, /* 53152 (1326) [-1,  1,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6]  1 */
      130368, /* 53153 (1326) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  6]  1 */
      134663, /* 53154 (1326) [ 1,  0,  0,  1, -1,  0,  0,  0,  1] [ 0,  0,  6]  1 */
        3198, /* 53155 (1326) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    34135547, /* 53156 (1326) [-1,  1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    34138139, /* 53157 (1326) [ 0, -1,  0,  1, -1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    34144779, /* 53158 (1326) [ 1, -1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  6] -1 */
    34146806, /* 53159 (1326) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    34015341, /* 53160 (1326) [-1,  0,  0, -1,  1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
       14457, /* 53161 (1326) [ 1, -1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    34019636, /* 53162 (1326) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    34017773, /* 53163 (1326) [-1,  1,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
        5225, /* 53164 (1326) [-1,  1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34026357, /* 53165 (1326) [ 1, -1,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    34142187, /* 53166 (1326) [ 0,  1,  0, -1,  1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
        7817, /* 53167 (1326) [ 0, -1,  0,  1, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
      121215, /* 53168 (1326) [-1,  0,  0, -1,  1,  0,  0,  0, -1] [ 0,  0,  6]  1 */
    34024494, /* 53169 (1326) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    34028789, /* 53170 (1326) [ 1,  0,  0,  1, -1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    34133520, /* 53171 (1326) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
      132231, /* 53172 (1326) [ 1, -1,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  6]  1 */
      125510, /* 53173 (1326) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  6]  1 */
       11865, /* 53174 (1326) [ 0,  1,  0, -1,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
       16484, /* 53175 (1327) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    13389665, /* 53176 (1327) [-1,  1,  0, -1,  0,  0,  0,  0,  1] [ 4,  8,  8]  1 */
    23710197, /* 53177 (1327) [ 0,  1,  0, -1,  1,  0,  0,  0, -1] [ 8,  4,  4]  1 */
    13398897, /* 53178 (1327) [ 1, -1,  0,  1,  0,  0,  0,  0, -1] [ 4,  8,  8]  1 */
    23705744, /* 53179 (1327) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 8,  4,  4]  1 */
    13400924, /* 53180 (1327) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 4,  8,  8]  1 */
    23703881, /* 53181 (1327) [-1,  1,  0,  0,  1,  0,  0,  0,  1] [ 8,  4,  4]  1 */
       12270, /* 53182 (1327) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    23701530, /* 53183 (1327) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 8,  4,  4]  1 */
        3198, /* 53184 (1327) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    13387557, /* 53185 (1327) [-1,  0,  0, -1,  1,  0,  0,  0, -1] [ 4,  8,  8]  1 */
       16565, /* 53186 (1327) [ 1,  0,  0,  1, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    23710602, /* 53187 (1327) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 8,  4,  4]  1 */
    23714897, /* 53188 (1327) [ 1,  0,  0,  1, -1,  0,  0,  0,  1] [ 8,  4,  4]  1 */
    13391852, /* 53189 (1327) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 4,  8,  8]  1 */
    13398573, /* 53190 (1327) [ 1, -1,  0,  0, -1,  0,  0,  0, -1] [ 4,  8,  8]  1 */
    13389989, /* 53191 (1327) [-1,  1,  0,  0,  1,  0,  0,  0,  1] [ 4,  8,  8]  1 */
    13396305, /* 53192 (1327) [ 0,  1,  0, -1,  1,  0,  0,  0, -1] [ 4,  8,  8]  1 */
    13396710, /* 53193 (1327) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 4,  8,  8]  1 */
    13401005, /* 53194 (1327) [ 1,  0,  0,  1, -1,  0,  0,  0,  1] [ 4,  8,  8]  1 */
    13387638, /* 53195 (1327) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 4,  8,  8]  1 */
       14457, /* 53196 (1327) [ 1, -1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    23703557, /* 53197 (1327) [-1,  1,  0, -1,  0,  0,  0,  0,  1] [ 8,  4,  4]  1 */
        5225, /* 53198 (1327) [-1,  1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    23706149, /* 53199 (1327) [ 0, -1,  0,  1, -1,  0,  0,  0,  1] [ 8,  4,  4]  1 */
        7817, /* 53200 (1327) [ 0, -1,  0,  1, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
        5549, /* 53201 (1327) [-1,  1,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    23714816, /* 53202 (1327) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 8,  4,  4]  1 */
    23712789, /* 53203 (1327) [ 1, -1,  0,  1,  0,  0,  0,  0, -1] [ 8,  4,  4]  1 */
    23701449, /* 53204 (1327) [-1,  0,  0, -1,  1,  0,  0,  0, -1] [ 8,  4,  4]  1 */
        3117, /* 53205 (1327) [-1,  0,  0, -1,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
        7412, /* 53206 (1327) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  0]  1 */
       14133, /* 53207 (1327) [ 1, -1,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    23712465, /* 53208 (1327) [ 1, -1,  0,  0, -1,  0,  0,  0, -1] [ 8,  4,  4]  1 */
    13392257, /* 53209 (1327) [ 0, -1,  0,  1, -1,  0,  0,  0,  1] [ 4,  8,  8]  1 */
       11865, /* 53210 (1327) [ 0,  1,  0, -1,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
       16484, /* 53211 (1328) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    13389665, /* 53212 (1328) [-1,  1,  0, -1,  0,  0,  0,  0,  1] [ 4,  8,  8]  1 */
    23710197, /* 53213 (1328) [ 0,  1,  0, -1,  1,  0,  0,  0, -1] [ 8,  4,  4]  1 */
    13398897, /* 53214 (1328) [ 1, -1,  0,  1,  0,  0,  0,  0, -1] [ 4,  8,  8]  1 */
    47404076, /* 53215 (1328) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 4,  8,  8] -1 */
    23705744, /* 53216 (1328) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 8,  4,  4]  1 */
    47402213, /* 53217 (1328) [-1,  1,  0,  0,  1,  0,  0,  0,  1] [ 4,  8,  8] -1 */
    47410797, /* 53218 (1328) [ 1, -1,  0,  0, -1,  0,  0,  0, -1] [ 4,  8,  8] -1 */
    13400924, /* 53219 (1328) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 4,  8,  8]  1 */
    23703881, /* 53220 (1328) [-1,  1,  0,  0,  1,  0,  0,  0,  1] [ 8,  4,  4]  1 */
    47413229, /* 53221 (1328) [ 1,  0,  0,  1, -1,  0,  0,  0,  1] [ 4,  8,  8] -1 */
       12270, /* 53222 (1328) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    23701530, /* 53223 (1328) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 8,  4,  4]  1 */
        3198, /* 53224 (1328) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    13387557, /* 53225 (1328) [-1,  0,  0, -1,  1,  0,  0,  0, -1] [ 4,  8,  8]  1 */
    47408934, /* 53226 (1328) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 4,  8,  8] -1 */
    23710602, /* 53227 (1328) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 8,  4,  4]  1 */
       16565, /* 53228 (1328) [ 1,  0,  0,  1, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    23714897, /* 53229 (1328) [ 1,  0,  0,  1, -1,  0,  0,  0,  1] [ 8,  4,  4]  1 */
    47408529, /* 53230 (1328) [ 0,  1,  0, -1,  1,  0,  0,  0, -1] [ 4,  8,  8] -1 */
    47399862, /* 53231 (1328) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 4,  8,  8] -1 */
    34017449, /* 53232 (1328) [-1,  1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    57715781, /* 53233 (1328) [-1,  1,  0, -1,  0,  0,  0,  0,  1] [ 8,  4,  4] -1 */
    34026681, /* 53234 (1328) [ 1, -1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    57718373, /* 53235 (1328) [ 0, -1,  0,  1, -1,  0,  0,  0,  1] [ 8,  4,  4] -1 */
    34020041, /* 53236 (1328) [ 0, -1,  0,  1, -1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    13391852, /* 53237 (1328) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 4,  8,  8]  1 */
    13398573, /* 53238 (1328) [ 1, -1,  0,  0, -1,  0,  0,  0, -1] [ 4,  8,  8]  1 */
    57725013, /* 53239 (1328) [ 1, -1,  0,  1,  0,  0,  0,  0, -1] [ 8,  4,  4] -1 */
    13389989, /* 53240 (1328) [-1,  1,  0,  0,  1,  0,  0,  0,  1] [ 4,  8,  8]  1 */
    13396305, /* 53241 (1328) [ 0,  1,  0, -1,  1,  0,  0,  0, -1] [ 4,  8,  8]  1 */
    57727040, /* 53242 (1328) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 8,  4,  4] -1 */
    34028708, /* 53243 (1328) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    13396710, /* 53244 (1328) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 4,  8,  8]  1 */
    13401005, /* 53245 (1328) [ 1,  0,  0,  1, -1,  0,  0,  0,  1] [ 4,  8,  8]  1 */
    57713673, /* 53246 (1328) [-1,  0,  0, -1,  1,  0,  0,  0, -1] [ 8,  4,  4] -1 */
    34015341, /* 53247 (1328) [-1,  0,  0, -1,  1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    13387638, /* 53248 (1328) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 4,  8,  8]  1 */
       14457, /* 53249 (1328) [ 1, -1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    34019636, /* 53250 (1328) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    23703557, /* 53251 (1328) [-1,  1,  0, -1,  0,  0,  0,  0,  1] [ 8,  4,  4]  1 */
        5225, /* 53252 (1328) [-1,  1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    47404481, /* 53253 (1328) [ 0, -1,  0,  1, -1,  0,  0,  0,  1] [ 4,  8,  8] -1 */
    34026357, /* 53254 (1328) [ 1, -1,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    23706149, /* 53255 (1328) [ 0, -1,  0,  1, -1,  0,  0,  0,  1] [ 8,  4,  4]  1 */
        7817, /* 53256 (1328) [ 0, -1,  0,  1, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    57724689, /* 53257 (1328) [ 1, -1,  0,  0, -1,  0,  0,  0, -1] [ 8,  4,  4] -1 */
    34017773, /* 53258 (1328) [-1,  1,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    57722421, /* 53259 (1328) [ 0,  1,  0, -1,  1,  0,  0,  0, -1] [ 8,  4,  4] -1 */
    34024089, /* 53260 (1328) [ 0,  1,  0, -1,  1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    57717968, /* 53261 (1328) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 8,  4,  4] -1 */
    47401889, /* 53262 (1328) [-1,  1,  0, -1,  0,  0,  0,  0,  1] [ 4,  8,  8] -1 */
    47411121, /* 53263 (1328) [ 1, -1,  0,  1,  0,  0,  0,  0, -1] [ 4,  8,  8] -1 */
        5549, /* 53264 (1328) [-1,  1,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    23714816, /* 53265 (1328) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 8,  4,  4]  1 */
    23712789, /* 53266 (1328) [ 1, -1,  0,  1,  0,  0,  0,  0, -1] [ 8,  4,  4]  1 */
    47413148, /* 53267 (1328) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 4,  8,  8] -1 */
    34015422, /* 53268 (1328) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    57713754, /* 53269 (1328) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 8,  4,  4] -1 */
    47399781, /* 53270 (1328) [-1,  0,  0, -1,  1,  0,  0,  0, -1] [ 4,  8,  8] -1 */
    57722826, /* 53271 (1328) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 8,  4,  4] -1 */
    34024494, /* 53272 (1328) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  0] -1 */
        3117, /* 53273 (1328) [-1,  0,  0, -1,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    23701449, /* 53274 (1328) [-1,  0,  0, -1,  1,  0,  0,  0, -1] [ 8,  4,  4]  1 */
    34028789, /* 53275 (1328) [ 1,  0,  0,  1, -1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    57727121, /* 53276 (1328) [ 1,  0,  0,  1, -1,  0,  0,  0,  1] [ 8,  4,  4] -1 */
    57716105, /* 53277 (1328) [-1,  1,  0,  0,  1,  0,  0,  0,  1] [ 8,  4,  4] -1 */
        7412, /* 53278 (1328) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  0]  1 */
       14133, /* 53279 (1328) [ 1, -1,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    23712465, /* 53280 (1328) [ 1, -1,  0,  0, -1,  0,  0,  0, -1] [ 8,  4,  4]  1 */
    13392257, /* 53281 (1328) [ 0, -1,  0,  1, -1,  0,  0,  0,  1] [ 4,  8,  8]  1 */
       11865, /* 53282 (1328) [ 0,  1,  0, -1,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
       16484, /* 53283 (1329) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    13389665, /* 53284 (1329) [-1,  1,  0, -1,  0,  0,  0,  0,  1] [ 4,  8,  8]  1 */
    23705744, /* 53285 (1329) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 8,  4,  4]  1 */
    47410797, /* 53286 (1329) [ 1, -1,  0,  0, -1,  0,  0,  0, -1] [ 4,  8,  8] -1 */
    13400924, /* 53287 (1329) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 4,  8,  8]  1 */
    23703881, /* 53288 (1329) [-1,  1,  0,  0,  1,  0,  0,  0,  1] [ 8,  4,  4]  1 */
    47408529, /* 53289 (1329) [ 0,  1,  0, -1,  1,  0,  0,  0, -1] [ 4,  8,  8] -1 */
    47408934, /* 53290 (1329) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 4,  8,  8] -1 */
       16565, /* 53291 (1329) [ 1,  0,  0,  1, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    23714897, /* 53292 (1329) [ 1,  0,  0,  1, -1,  0,  0,  0,  1] [ 8,  4,  4]  1 */
    47399862, /* 53293 (1329) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 4,  8,  8] -1 */
    34026681, /* 53294 (1329) [ 1, -1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    13391852, /* 53295 (1329) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 4,  8,  8]  1 */
    57725013, /* 53296 (1329) [ 1, -1,  0,  1,  0,  0,  0,  0, -1] [ 8,  4,  4] -1 */
    13389989, /* 53297 (1329) [-1,  1,  0,  0,  1,  0,  0,  0,  1] [ 4,  8,  8]  1 */
    13401005, /* 53298 (1329) [ 1,  0,  0,  1, -1,  0,  0,  0,  1] [ 4,  8,  8]  1 */
    57713673, /* 53299 (1329) [-1,  0,  0, -1,  1,  0,  0,  0, -1] [ 8,  4,  4] -1 */
    34015341, /* 53300 (1329) [-1,  0,  0, -1,  1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    23703557, /* 53301 (1329) [-1,  1,  0, -1,  0,  0,  0,  0,  1] [ 8,  4,  4]  1 */
        5225, /* 53302 (1329) [-1,  1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34026357, /* 53303 (1329) [ 1, -1,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    57724689, /* 53304 (1329) [ 1, -1,  0,  0, -1,  0,  0,  0, -1] [ 8,  4,  4] -1 */
    23706149, /* 53305 (1329) [ 0, -1,  0,  1, -1,  0,  0,  0,  1] [ 8,  4,  4]  1 */
        7817, /* 53306 (1329) [ 0, -1,  0,  1, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    57722421, /* 53307 (1329) [ 0,  1,  0, -1,  1,  0,  0,  0, -1] [ 8,  4,  4] -1 */
    34024089, /* 53308 (1329) [ 0,  1,  0, -1,  1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    47411121, /* 53309 (1329) [ 1, -1,  0,  1,  0,  0,  0,  0, -1] [ 4,  8,  8] -1 */
    23714816, /* 53310 (1329) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 8,  4,  4]  1 */
    57713754, /* 53311 (1329) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 8,  4,  4] -1 */
    34015422, /* 53312 (1329) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    47399781, /* 53313 (1329) [-1,  0,  0, -1,  1,  0,  0,  0, -1] [ 4,  8,  8] -1 */
    57722826, /* 53314 (1329) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 8,  4,  4] -1 */
    34024494, /* 53315 (1329) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  0] -1 */
        7412, /* 53316 (1329) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  0]  1 */
        5549, /* 53317 (1329) [-1,  1,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    13392257, /* 53318 (1329) [ 0, -1,  0,  1, -1,  0,  0,  0,  1] [ 4,  8,  8]  1 */
       16484, /* 53319 (1330) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    13389665, /* 53320 (1330) [-1,  1,  0, -1,  0,  0,  0,  0,  1] [ 4,  8,  8]  1 */
    47404076, /* 53321 (1330) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 4,  8,  8] -1 */
    47402213, /* 53322 (1330) [-1,  1,  0,  0,  1,  0,  0,  0,  1] [ 4,  8,  8] -1 */
    13400924, /* 53323 (1330) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 4,  8,  8]  1 */
    47413229, /* 53324 (1330) [ 1,  0,  0,  1, -1,  0,  0,  0,  1] [ 4,  8,  8] -1 */
       12270, /* 53325 (1330) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    47408529, /* 53326 (1330) [ 0,  1,  0, -1,  1,  0,  0,  0, -1] [ 4,  8,  8] -1 */
    13387557, /* 53327 (1330) [-1,  0,  0, -1,  1,  0,  0,  0, -1] [ 4,  8,  8]  1 */
    23710602, /* 53328 (1330) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 8,  4,  4]  1 */
    47399862, /* 53329 (1330) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 4,  8,  8] -1 */
    34026681, /* 53330 (1330) [ 1, -1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    13398573, /* 53331 (1330) [ 1, -1,  0,  0, -1,  0,  0,  0, -1] [ 4,  8,  8]  1 */
    57725013, /* 53332 (1330) [ 1, -1,  0,  1,  0,  0,  0,  0, -1] [ 8,  4,  4] -1 */
    13396710, /* 53333 (1330) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 4,  8,  8]  1 */
    34019636, /* 53334 (1330) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    23703557, /* 53335 (1330) [-1,  1,  0, -1,  0,  0,  0,  0,  1] [ 8,  4,  4]  1 */
        5225, /* 53336 (1330) [-1,  1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34017773, /* 53337 (1330) [-1,  1,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    23706149, /* 53338 (1330) [ 0, -1,  0,  1, -1,  0,  0,  0,  1] [ 8,  4,  4]  1 */
        7817, /* 53339 (1330) [ 0, -1,  0,  1, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    57722421, /* 53340 (1330) [ 0,  1,  0, -1,  1,  0,  0,  0, -1] [ 8,  4,  4] -1 */
    34024089, /* 53341 (1330) [ 0,  1,  0, -1,  1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    57717968, /* 53342 (1330) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 8,  4,  4] -1 */
    47411121, /* 53343 (1330) [ 1, -1,  0,  1,  0,  0,  0,  0, -1] [ 4,  8,  8] -1 */
    23714816, /* 53344 (1330) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 8,  4,  4]  1 */
    57713754, /* 53345 (1330) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 8,  4,  4] -1 */
    34015422, /* 53346 (1330) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    57716105, /* 53347 (1330) [-1,  1,  0,  0,  1,  0,  0,  0,  1] [ 8,  4,  4] -1 */
    23701449, /* 53348 (1330) [-1,  0,  0, -1,  1,  0,  0,  0, -1] [ 8,  4,  4]  1 */
        3117, /* 53349 (1330) [-1,  0,  0, -1,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    57727121, /* 53350 (1330) [ 1,  0,  0,  1, -1,  0,  0,  0,  1] [ 8,  4,  4] -1 */
    34028789, /* 53351 (1330) [ 1,  0,  0,  1, -1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
       14133, /* 53352 (1330) [ 1, -1,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    23712465, /* 53353 (1330) [ 1, -1,  0,  0, -1,  0,  0,  0, -1] [ 8,  4,  4]  1 */
    13392257, /* 53354 (1330) [ 0, -1,  0,  1, -1,  0,  0,  0,  1] [ 4,  8,  8]  1 */
       16484, /* 53355 (1331) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    13389665, /* 53356 (1331) [-1,  1,  0, -1,  0,  0,  0,  0,  1] [ 4,  8,  8]  1 */
    23710197, /* 53357 (1331) [ 0,  1,  0, -1,  1,  0,  0,  0, -1] [ 8,  4,  4]  1 */
    47404076, /* 53358 (1331) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 4,  8,  8] -1 */
    13398897, /* 53359 (1331) [ 1, -1,  0,  1,  0,  0,  0,  0, -1] [ 4,  8,  8]  1 */
    47402213, /* 53360 (1331) [-1,  1,  0,  0,  1,  0,  0,  0,  1] [ 4,  8,  8] -1 */
    47410797, /* 53361 (1331) [ 1, -1,  0,  0, -1,  0,  0,  0, -1] [ 4,  8,  8] -1 */
    13400924, /* 53362 (1331) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 4,  8,  8]  1 */
    47413229, /* 53363 (1331) [ 1,  0,  0,  1, -1,  0,  0,  0,  1] [ 4,  8,  8] -1 */
    23701530, /* 53364 (1331) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 8,  4,  4]  1 */
        3198, /* 53365 (1331) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    47408934, /* 53366 (1331) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 4,  8,  8] -1 */
    13396305, /* 53367 (1331) [ 0,  1,  0, -1,  1,  0,  0,  0, -1] [ 4,  8,  8]  1 */
    57713673, /* 53368 (1331) [-1,  0,  0, -1,  1,  0,  0,  0, -1] [ 8,  4,  4] -1 */
    34015341, /* 53369 (1331) [-1,  0,  0, -1,  1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    13387638, /* 53370 (1331) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 4,  8,  8]  1 */
    34019636, /* 53371 (1331) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  0] -1 */
       14457, /* 53372 (1331) [ 1, -1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    23703557, /* 53373 (1331) [-1,  1,  0, -1,  0,  0,  0,  0,  1] [ 8,  4,  4]  1 */
        5225, /* 53374 (1331) [-1,  1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34026357, /* 53375 (1331) [ 1, -1,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    57724689, /* 53376 (1331) [ 1, -1,  0,  0, -1,  0,  0,  0, -1] [ 8,  4,  4] -1 */
    23706149, /* 53377 (1331) [ 0, -1,  0,  1, -1,  0,  0,  0,  1] [ 8,  4,  4]  1 */
        7817, /* 53378 (1331) [ 0, -1,  0,  1, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34017773, /* 53379 (1331) [-1,  1,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    57717968, /* 53380 (1331) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 8,  4,  4] -1 */
    23714816, /* 53381 (1331) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 8,  4,  4]  1 */
    23712789, /* 53382 (1331) [ 1, -1,  0,  1,  0,  0,  0,  0, -1] [ 8,  4,  4]  1 */
    47399781, /* 53383 (1331) [-1,  0,  0, -1,  1,  0,  0,  0, -1] [ 4,  8,  8] -1 */
    57716105, /* 53384 (1331) [-1,  1,  0,  0,  1,  0,  0,  0,  1] [ 8,  4,  4] -1 */
    57722826, /* 53385 (1331) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 8,  4,  4] -1 */
    34024494, /* 53386 (1331) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    57727121, /* 53387 (1331) [ 1,  0,  0,  1, -1,  0,  0,  0,  1] [ 8,  4,  4] -1 */
    34028789, /* 53388 (1331) [ 1,  0,  0,  1, -1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    13392257, /* 53389 (1331) [ 0, -1,  0,  1, -1,  0,  0,  0,  1] [ 4,  8,  8]  1 */
       11865, /* 53390 (1331) [ 0,  1,  0, -1,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
       16484, /* 53391 (1332) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    13389665, /* 53392 (1332) [-1,  1,  0, -1,  0,  0,  0,  0,  1] [ 4,  8,  8]  1 */
    23710197, /* 53393 (1332) [ 0,  1,  0, -1,  1,  0,  0,  0, -1] [ 8,  4,  4]  1 */
    13398897, /* 53394 (1332) [ 1, -1,  0,  1,  0,  0,  0,  0, -1] [ 4,  8,  8]  1 */
    23705744, /* 53395 (1332) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 8,  4,  4]  1 */
    57833879, /* 53396 (1332) [-1,  1,  0, -1,  0,  0,  0,  0,  1] [ 8,  4, 10] -1 */
    13400924, /* 53397 (1332) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 4,  8,  8]  1 */
    57845138, /* 53398 (1332) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 8,  4, 10] -1 */
    47281764, /* 53399 (1332) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 4,  8,  2] -1 */
    23703881, /* 53400 (1332) [-1,  1,  0,  0,  1,  0,  0,  0,  1] [ 8,  4,  4]  1 */
       12270, /* 53401 (1332) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    47290836, /* 53402 (1332) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 4,  8,  2] -1 */
    23701530, /* 53403 (1332) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 8,  4,  4]  1 */
        3198, /* 53404 (1332) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    13387557, /* 53405 (1332) [-1,  0,  0, -1,  1,  0,  0,  0, -1] [ 4,  8,  8]  1 */
       16565, /* 53406 (1332) [ 1,  0,  0,  1, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    23710602, /* 53407 (1332) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 8,  4,  4]  1 */
    23714897, /* 53408 (1332) [ 1,  0,  0,  1, -1,  0,  0,  0,  1] [ 8,  4,  4]  1 */
    57831771, /* 53409 (1332) [-1,  0,  0, -1,  1,  0,  0,  0, -1] [ 8,  4, 10] -1 */
    34135547, /* 53410 (1332) [-1,  1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    57842787, /* 53411 (1332) [ 1, -1,  0,  0, -1,  0,  0,  0, -1] [ 8,  4, 10] -1 */
    34138139, /* 53412 (1332) [ 0, -1,  0,  1, -1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    13391852, /* 53413 (1332) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 4,  8,  8]  1 */
    34144779, /* 53414 (1332) [ 1, -1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  6] -1 */
    13398573, /* 53415 (1332) [ 1, -1,  0,  0, -1,  0,  0,  0, -1] [ 4,  8,  8]  1 */
    57836066, /* 53416 (1332) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 8,  4, 10] -1 */
    34146806, /* 53417 (1332) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    13389989, /* 53418 (1332) [-1,  1,  0,  0,  1,  0,  0,  0,  1] [ 4,  8,  8]  1 */
    57834203, /* 53419 (1332) [-1,  1,  0,  0,  1,  0,  0,  0,  1] [ 8,  4, 10] -1 */
    13396305, /* 53420 (1332) [ 0,  1,  0, -1,  1,  0,  0,  0, -1] [ 4,  8,  8]  1 */
    13396710, /* 53421 (1332) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 4,  8,  8]  1 */
    57831852, /* 53422 (1332) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 8,  4, 10] -1 */
    34133439, /* 53423 (1332) [-1,  0,  0, -1,  1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
    13401005, /* 53424 (1332) [ 1,  0,  0,  1, -1,  0,  0,  0,  1] [ 4,  8,  8]  1 */
    57845219, /* 53425 (1332) [ 1,  0,  0,  1, -1,  0,  0,  0,  1] [ 8,  4, 10] -1 */
    57840519, /* 53426 (1332) [ 0,  1,  0, -1,  1,  0,  0,  0, -1] [ 8,  4, 10] -1 */
    47293023, /* 53427 (1332) [ 1, -1,  0,  1,  0,  0,  0,  0, -1] [ 4,  8,  2] -1 */
    13387638, /* 53428 (1332) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 4,  8,  8]  1 */
    47283791, /* 53429 (1332) [-1,  1,  0, -1,  0,  0,  0,  0,  1] [ 4,  8,  2] -1 */
    34144455, /* 53430 (1332) [ 1, -1,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
       14457, /* 53431 (1332) [ 1, -1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    47290431, /* 53432 (1332) [ 0,  1,  0, -1,  1,  0,  0,  0, -1] [ 4,  8,  2] -1 */
    47286383, /* 53433 (1332) [ 0, -1,  0,  1, -1,  0,  0,  0,  1] [ 4,  8,  2] -1 */
    23703557, /* 53434 (1332) [-1,  1,  0, -1,  0,  0,  0,  0,  1] [ 8,  4,  4]  1 */
        5225, /* 53435 (1332) [-1,  1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34142187, /* 53436 (1332) [ 0,  1,  0, -1,  1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
    23706149, /* 53437 (1332) [ 0, -1,  0,  1, -1,  0,  0,  0,  1] [ 8,  4,  4]  1 */
        7817, /* 53438 (1332) [ 0, -1,  0,  1, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    57840924, /* 53439 (1332) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 8,  4, 10] -1 */
    34137734, /* 53440 (1332) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    34135871, /* 53441 (1332) [-1,  1,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    47295050, /* 53442 (1332) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 4,  8,  2] -1 */
    34146887, /* 53443 (1332) [ 1,  0,  0,  1, -1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
        5549, /* 53444 (1332) [-1,  1,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    23714816, /* 53445 (1332) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 8,  4,  4]  1 */
    34142592, /* 53446 (1332) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  6] -1 */
    23712465, /* 53447 (1332) [ 1, -1,  0,  0, -1,  0,  0,  0, -1] [ 8,  4,  4]  1 */
    23712789, /* 53448 (1332) [ 1, -1,  0,  1,  0,  0,  0,  0, -1] [ 8,  4,  4]  1 */
    47281683, /* 53449 (1332) [-1,  0,  0, -1,  1,  0,  0,  0, -1] [ 4,  8,  2] -1 */
    23701449, /* 53450 (1332) [-1,  0,  0, -1,  1,  0,  0,  0, -1] [ 8,  4,  4]  1 */
        3117, /* 53451 (1332) [-1,  0,  0, -1,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    47285978, /* 53452 (1332) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 4,  8,  2] -1 */
    34133520, /* 53453 (1332) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
        7412, /* 53454 (1332) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    57843111, /* 53455 (1332) [ 1, -1,  0,  1,  0,  0,  0,  0, -1] [ 8,  4, 10] -1 */
    47284115, /* 53456 (1332) [-1,  1,  0,  0,  1,  0,  0,  0,  1] [ 4,  8,  2] -1 */
       14133, /* 53457 (1332) [ 1, -1,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    47292699, /* 53458 (1332) [ 1, -1,  0,  0, -1,  0,  0,  0, -1] [ 4,  8,  2] -1 */
    47295131, /* 53459 (1332) [ 1,  0,  0,  1, -1,  0,  0,  0,  1] [ 4,  8,  2] -1 */
    57836471, /* 53460 (1332) [ 0, -1,  0,  1, -1,  0,  0,  0,  1] [ 8,  4, 10] -1 */
    13392257, /* 53461 (1332) [ 0, -1,  0,  1, -1,  0,  0,  0,  1] [ 4,  8,  8]  1 */
       11865, /* 53462 (1332) [ 0,  1,  0, -1,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
       16484, /* 53463 (1327) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
       10816, /* 53464 (1327) [ 0,  0,  1,  1,  0,  0,  0,  1,  0] [ 0,  0,  0]  1 */
       10660, /* 53465 (1327) [ 0,  0,  1,  0,  1,  0,  1,  0,  0] [ 0,  0,  0]  1 */
        9022, /* 53466 (1327) [ 0,  0, -1,  0, -1,  0, -1,  0,  0] [ 0,  0,  0]  1 */
       12272, /* 53467 (1327) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 0,  0,  0]  1 */
        7410, /* 53468 (1327) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  0]  1 */
        3250, /* 53469 (1327) [-1,  0,  0,  0,  0, -1,  0, -1,  0] [ 0,  0,  0]  1 */
       12064, /* 53470 (1327) [ 0,  1,  0,  0,  0,  1,  1,  0,  0] [ 0,  0,  0]  1 */
        3198, /* 53471 (1327) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
       16432, /* 53472 (1327) [ 1,  0,  0,  0,  0,  1,  0,  1,  0] [ 0,  0,  0]  1 */
        7618, /* 53473 (1327) [ 0, -1,  0,  0,  0, -1, -1,  0,  0] [ 0,  0,  0]  1 */
        8866, /* 53474 (1327) [ 0,  0, -1, -1,  0,  0,  0, -1,  0] [ 0,  0,  0]  1 */
       16484, /* 53475 (1328) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
       10660, /* 53476 (1328) [ 0,  0,  1,  0,  1,  0,  1,  0,  0] [ 0,  0,  0]  1 */
    34019634, /* 53477 (1328) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  0] -1 */
        9022, /* 53478 (1328) [ 0,  0, -1,  0, -1,  0, -1,  0,  0] [ 0,  0,  0]  1 */
        3198, /* 53479 (1328) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
       16432, /* 53480 (1328) [ 1,  0,  0,  0,  0,  1,  0,  1,  0] [ 0,  0,  0]  1 */
        8866, /* 53481 (1328) [ 0,  0, -1, -1,  0,  0,  0, -1,  0] [ 0,  0,  0]  1 */
    34015474, /* 53482 (1328) [-1,  0,  0,  0,  0, -1,  0, -1,  0] [ 0,  0,  0] -1 */
        7410, /* 53483 (1328) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    34028708, /* 53484 (1328) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    34024496, /* 53485 (1328) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    34023040, /* 53486 (1328) [ 0,  0,  1,  1,  0,  0,  0,  1,  0] [ 0,  0,  0] -1 */
    34024288, /* 53487 (1328) [ 0,  1,  0,  0,  0,  1,  1,  0,  0] [ 0,  0,  0] -1 */
    34019842, /* 53488 (1328) [ 0, -1,  0,  0,  0, -1, -1,  0,  0] [ 0,  0,  0] -1 */
    34022884, /* 53489 (1328) [ 0,  0,  1,  0,  1,  0,  1,  0,  0] [ 0,  0,  0] -1 */
        3250, /* 53490 (1328) [-1,  0,  0,  0,  0, -1,  0, -1,  0] [ 0,  0,  0]  1 */
    34021246, /* 53491 (1328) [ 0,  0, -1,  0, -1,  0, -1,  0,  0] [ 0,  0,  0] -1 */
    34015422, /* 53492 (1328) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
       10816, /* 53493 (1328) [ 0,  0,  1,  1,  0,  0,  0,  1,  0] [ 0,  0,  0]  1 */
       12272, /* 53494 (1328) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34028656, /* 53495 (1328) [ 1,  0,  0,  0,  0,  1,  0,  1,  0] [ 0,  0,  0] -1 */
       12064, /* 53496 (1328) [ 0,  1,  0,  0,  0,  1,  1,  0,  0] [ 0,  0,  0]  1 */
    34021090, /* 53497 (1328) [ 0,  0, -1, -1,  0,  0,  0, -1,  0] [ 0,  0,  0] -1 */
        7618, /* 53498 (1328) [ 0, -1,  0,  0,  0, -1, -1,  0,  0] [ 0,  0,  0]  1 */
       16484, /* 53499 (1329) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34021246, /* 53500 (1329) [ 0,  0, -1,  0, -1,  0, -1,  0,  0] [ 0,  0,  0] -1 */
    34015422, /* 53501 (1329) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
       10660, /* 53502 (1329) [ 0,  0,  1,  0,  1,  0,  1,  0,  0] [ 0,  0,  0]  1 */
       10816, /* 53503 (1329) [ 0,  0,  1,  1,  0,  0,  0,  1,  0] [ 0,  0,  0]  1 */
    34019634, /* 53504 (1329) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  0] -1 */
       12272, /* 53505 (1329) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34015474, /* 53506 (1329) [-1,  0,  0,  0,  0, -1,  0, -1,  0] [ 0,  0,  0] -1 */
       12064, /* 53507 (1329) [ 0,  1,  0,  0,  0,  1,  1,  0,  0] [ 0,  0,  0]  1 */
    34019842, /* 53508 (1329) [ 0, -1,  0,  0,  0, -1, -1,  0,  0] [ 0,  0,  0] -1 */
       16432, /* 53509 (1329) [ 1,  0,  0,  0,  0,  1,  0,  1,  0] [ 0,  0,  0]  1 */
    34021090, /* 53510 (1329) [ 0,  0, -1, -1,  0,  0,  0, -1,  0] [ 0,  0,  0] -1 */
       16484, /* 53511 (1330) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34015422, /* 53512 (1330) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
       10816, /* 53513 (1330) [ 0,  0,  1,  1,  0,  0,  0,  1,  0] [ 0,  0,  0]  1 */
        9022, /* 53514 (1330) [ 0,  0, -1,  0, -1,  0, -1,  0,  0] [ 0,  0,  0]  1 */
    34028656, /* 53515 (1330) [ 1,  0,  0,  0,  0,  1,  0,  1,  0] [ 0,  0,  0] -1 */
        7410, /* 53516 (1330) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  0]  1 */
       12064, /* 53517 (1330) [ 0,  1,  0,  0,  0,  1,  1,  0,  0] [ 0,  0,  0]  1 */
    34019842, /* 53518 (1330) [ 0, -1,  0,  0,  0, -1, -1,  0,  0] [ 0,  0,  0] -1 */
    34022884, /* 53519 (1330) [ 0,  0,  1,  0,  1,  0,  1,  0,  0] [ 0,  0,  0] -1 */
    34021090, /* 53520 (1330) [ 0,  0, -1, -1,  0,  0,  0, -1,  0] [ 0,  0,  0] -1 */
        3250, /* 53521 (1330) [-1,  0,  0,  0,  0, -1,  0, -1,  0] [ 0,  0,  0]  1 */
    34024496, /* 53522 (1330) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 0,  0,  0] -1 */
       16484, /* 53523 (1331) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34021246, /* 53524 (1331) [ 0,  0, -1,  0, -1,  0, -1,  0,  0] [ 0,  0,  0] -1 */
       10816, /* 53525 (1331) [ 0,  0,  1,  1,  0,  0,  0,  1,  0] [ 0,  0,  0]  1 */
    34019634, /* 53526 (1331) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    34015474, /* 53527 (1331) [-1,  0,  0,  0,  0, -1,  0, -1,  0] [ 0,  0,  0] -1 */
    34028656, /* 53528 (1331) [ 1,  0,  0,  0,  0,  1,  0,  1,  0] [ 0,  0,  0] -1 */
       12064, /* 53529 (1331) [ 0,  1,  0,  0,  0,  1,  1,  0,  0] [ 0,  0,  0]  1 */
        3198, /* 53530 (1331) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    34022884, /* 53531 (1331) [ 0,  0,  1,  0,  1,  0,  1,  0,  0] [ 0,  0,  0] -1 */
        7618, /* 53532 (1331) [ 0, -1,  0,  0,  0, -1, -1,  0,  0] [ 0,  0,  0]  1 */
    34024496, /* 53533 (1331) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 0,  0,  0] -1 */
        8866, /* 53534 (1331) [ 0,  0, -1, -1,  0,  0,  0, -1,  0] [ 0,  0,  0]  1 */
       16484, /* 53535 (1332) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
       10660, /* 53536 (1332) [ 0,  0,  1,  0,  1,  0,  1,  0,  0] [ 0,  0,  0]  1 */
        9022, /* 53537 (1332) [ 0,  0, -1,  0, -1,  0, -1,  0,  0] [ 0,  0,  0]  1 */
        3198, /* 53538 (1332) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
       16432, /* 53539 (1332) [ 1,  0,  0,  0,  0,  1,  0,  1,  0] [ 0,  0,  0]  1 */
    52570094, /* 53540 (1332) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
        8866, /* 53541 (1332) [ 0,  0, -1, -1,  0,  0,  0, -1,  0] [ 0,  0,  0]  1 */
    52556860, /* 53542 (1332) [-1,  0,  0,  0,  0, -1,  0, -1,  0] [ 6,  6,  6] -1 */
        7410, /* 53543 (1332) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    52565882, /* 53544 (1332) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    52565674, /* 53545 (1332) [ 0,  1,  0,  0,  0,  1,  1,  0,  0] [ 6,  6,  6] -1 */
    52561228, /* 53546 (1332) [ 0, -1,  0,  0,  0, -1, -1,  0,  0] [ 6,  6,  6] -1 */
    52564426, /* 53547 (1332) [ 0,  0,  1,  1,  0,  0,  0,  1,  0] [ 6,  6,  6] -1 */
    52570042, /* 53548 (1332) [ 1,  0,  0,  0,  0,  1,  0,  1,  0] [ 6,  6,  6] -1 */
    52564270, /* 53549 (1332) [ 0,  0,  1,  0,  1,  0,  1,  0,  0] [ 6,  6,  6] -1 */
        3250, /* 53550 (1332) [-1,  0,  0,  0,  0, -1,  0, -1,  0] [ 0,  0,  0]  1 */
    52556808, /* 53551 (1332) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
       10816, /* 53552 (1332) [ 0,  0,  1,  1,  0,  0,  0,  1,  0] [ 0,  0,  0]  1 */
    52562632, /* 53553 (1332) [ 0,  0, -1,  0, -1,  0, -1,  0,  0] [ 6,  6,  6] -1 */
       12272, /* 53554 (1332) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    52562476, /* 53555 (1332) [ 0,  0, -1, -1,  0,  0,  0, -1,  0] [ 6,  6,  6] -1 */
       12064, /* 53556 (1332) [ 0,  1,  0,  0,  0,  1,  1,  0,  0] [ 0,  0,  0]  1 */
        7618, /* 53557 (1332) [ 0, -1,  0,  0,  0, -1, -1,  0,  0] [ 0,  0,  0]  1 */
    52561020, /* 53558 (1332) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 6,  6,  6] -1 */
       16484, /* 53559 (1333) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    13389665, /* 53560 (1333) [-1,  1,  0, -1,  0,  0,  0,  0,  1] [ 4,  8,  8]  1 */
    23710197, /* 53561 (1333) [ 0,  1,  0, -1,  1,  0,  0,  0, -1] [ 8,  4,  4]  1 */
    13398897, /* 53562 (1333) [ 1, -1,  0,  1,  0,  0,  0,  0, -1] [ 4,  8,  8]  1 */
      123647, /* 53563 (1333) [-1,  1,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6]  1 */
      130368, /* 53564 (1333) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  6]  1 */
    13400924, /* 53565 (1333) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 4,  8,  8]  1 */
      134663, /* 53566 (1333) [ 1,  0,  0,  1, -1,  0,  0,  0,  1] [ 0,  0,  6]  1 */
    13269459, /* 53567 (1333) [-1,  0,  0, -1,  1,  0,  0,  0, -1] [ 4,  8,  2]  1 */
    23701530, /* 53568 (1333) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 8,  4,  4]  1 */
        3198, /* 53569 (1333) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    13273754, /* 53570 (1333) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 4,  8,  2]  1 */
    13271891, /* 53571 (1333) [-1,  1,  0,  0,  1,  0,  0,  0,  1] [ 4,  8,  2]  1 */
    13280475, /* 53572 (1333) [ 1, -1,  0,  0, -1,  0,  0,  0, -1] [ 4,  8,  2]  1 */
    13282907, /* 53573 (1333) [ 1,  0,  0,  1, -1,  0,  0,  0,  1] [ 4,  8,  2]  1 */
    13278612, /* 53574 (1333) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 4,  8,  2]  1 */
    13396305, /* 53575 (1333) [ 0,  1,  0, -1,  1,  0,  0,  0, -1] [ 4,  8,  8]  1 */
    23819547, /* 53576 (1333) [-1,  0,  0, -1,  1,  0,  0,  0, -1] [ 8,  4, 10]  1 */
    13387638, /* 53577 (1333) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 4,  8,  8]  1 */
       14457, /* 53578 (1333) [ 1, -1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    23830563, /* 53579 (1333) [ 1, -1,  0,  0, -1,  0,  0,  0, -1] [ 8,  4, 10]  1 */
    23703557, /* 53580 (1333) [-1,  1,  0, -1,  0,  0,  0,  0,  1] [ 8,  4,  4]  1 */
        5225, /* 53581 (1333) [-1,  1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    23706149, /* 53582 (1333) [ 0, -1,  0,  1, -1,  0,  0,  0,  1] [ 8,  4,  4]  1 */
        7817, /* 53583 (1333) [ 0, -1,  0,  1, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    23823842, /* 53584 (1333) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 8,  4, 10]  1 */
    23821979, /* 53585 (1333) [-1,  1,  0,  0,  1,  0,  0,  0,  1] [ 8,  4, 10]  1 */
    23714816, /* 53586 (1333) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 8,  4,  4]  1 */
    23712789, /* 53587 (1333) [ 1, -1,  0,  1,  0,  0,  0,  0, -1] [ 8,  4,  4]  1 */
      121215, /* 53588 (1333) [-1,  0,  0, -1,  1,  0,  0,  0, -1] [ 0,  0,  6]  1 */
    23832995, /* 53589 (1333) [ 1,  0,  0,  1, -1,  0,  0,  0,  1] [ 8,  4, 10]  1 */
      132231, /* 53590 (1333) [ 1, -1,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  6]  1 */
    23828700, /* 53591 (1333) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 8,  4, 10]  1 */
      125510, /* 53592 (1333) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  6]  1 */
    13392257, /* 53593 (1333) [ 0, -1,  0,  1, -1,  0,  0,  0,  1] [ 4,  8,  8]  1 */
       11865, /* 53594 (1333) [ 0,  1,  0, -1,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
       16484, /* 53595 (1334) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    13389665, /* 53596 (1334) [-1,  1,  0, -1,  0,  0,  0,  0,  1] [ 4,  8,  8]  1 */
    23710197, /* 53597 (1334) [ 0,  1,  0, -1,  1,  0,  0,  0, -1] [ 8,  4,  4]  1 */
    13398897, /* 53598 (1334) [ 1, -1,  0,  1,  0,  0,  0,  0, -1] [ 4,  8,  8]  1 */
      123647, /* 53599 (1334) [-1,  1,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6]  1 */
      130368, /* 53600 (1334) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  6]  1 */
    13400924, /* 53601 (1334) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 4,  8,  8]  1 */
      134663, /* 53602 (1334) [ 1,  0,  0,  1, -1,  0,  0,  0,  1] [ 0,  0,  6]  1 */
    47290836, /* 53603 (1334) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 4,  8,  2] -1 */
    13269459, /* 53604 (1334) [-1,  0,  0, -1,  1,  0,  0,  0, -1] [ 4,  8,  2]  1 */
    23701530, /* 53605 (1334) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 8,  4,  4]  1 */
        3198, /* 53606 (1334) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    57831771, /* 53607 (1334) [-1,  0,  0, -1,  1,  0,  0,  0, -1] [ 8,  4, 10] -1 */
    47408529, /* 53608 (1334) [ 0,  1,  0, -1,  1,  0,  0,  0, -1] [ 4,  8,  8] -1 */
    13273754, /* 53609 (1334) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 4,  8,  2]  1 */
    13271891, /* 53610 (1334) [-1,  1,  0,  0,  1,  0,  0,  0,  1] [ 4,  8,  2]  1 */
    13280475, /* 53611 (1334) [ 1, -1,  0,  0, -1,  0,  0,  0, -1] [ 4,  8,  2]  1 */
    57842787, /* 53612 (1334) [ 1, -1,  0,  0, -1,  0,  0,  0, -1] [ 8,  4, 10] -1 */
    47399862, /* 53613 (1334) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 4,  8,  8] -1 */
    34017449, /* 53614 (1334) [-1,  1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    57715781, /* 53615 (1334) [-1,  1,  0, -1,  0,  0,  0,  0,  1] [ 8,  4,  4] -1 */
    13282907, /* 53616 (1334) [ 1,  0,  0,  1, -1,  0,  0,  0,  1] [ 4,  8,  2]  1 */
    34026681, /* 53617 (1334) [ 1, -1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    57718373, /* 53618 (1334) [ 0, -1,  0,  1, -1,  0,  0,  0,  1] [ 8,  4,  4] -1 */
    34020041, /* 53619 (1334) [ 0, -1,  0,  1, -1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    57836066, /* 53620 (1334) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 8,  4, 10] -1 */
    57725013, /* 53621 (1334) [ 1, -1,  0,  1,  0,  0,  0,  0, -1] [ 8,  4,  4] -1 */
    13278612, /* 53622 (1334) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 4,  8,  2]  1 */
    57834203, /* 53623 (1334) [-1,  1,  0,  0,  1,  0,  0,  0,  1] [ 8,  4, 10] -1 */
    13396305, /* 53624 (1334) [ 0,  1,  0, -1,  1,  0,  0,  0, -1] [ 4,  8,  8]  1 */
    57727040, /* 53625 (1334) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 8,  4,  4] -1 */
    34028708, /* 53626 (1334) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    57845219, /* 53627 (1334) [ 1,  0,  0,  1, -1,  0,  0,  0,  1] [ 8,  4, 10] -1 */
    34133439, /* 53628 (1334) [-1,  0,  0, -1,  1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
    23819547, /* 53629 (1334) [-1,  0,  0, -1,  1,  0,  0,  0, -1] [ 8,  4, 10]  1 */
    13387638, /* 53630 (1334) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 4,  8,  8]  1 */
    34144455, /* 53631 (1334) [ 1, -1,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
       14457, /* 53632 (1334) [ 1, -1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    23830563, /* 53633 (1334) [ 1, -1,  0,  0, -1,  0,  0,  0, -1] [ 8,  4, 10]  1 */
    23703557, /* 53634 (1334) [-1,  1,  0, -1,  0,  0,  0,  0,  1] [ 8,  4,  4]  1 */
        5225, /* 53635 (1334) [-1,  1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    47404481, /* 53636 (1334) [ 0, -1,  0,  1, -1,  0,  0,  0,  1] [ 4,  8,  8] -1 */
    23706149, /* 53637 (1334) [ 0, -1,  0,  1, -1,  0,  0,  0,  1] [ 8,  4,  4]  1 */
        7817, /* 53638 (1334) [ 0, -1,  0,  1, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    57840924, /* 53639 (1334) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 8,  4, 10] -1 */
    34137734, /* 53640 (1334) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    57722421, /* 53641 (1334) [ 0,  1,  0, -1,  1,  0,  0,  0, -1] [ 8,  4,  4] -1 */
    34024089, /* 53642 (1334) [ 0,  1,  0, -1,  1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    34135871, /* 53643 (1334) [-1,  1,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    23823842, /* 53644 (1334) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 8,  4, 10]  1 */
    47401889, /* 53645 (1334) [-1,  1,  0, -1,  0,  0,  0,  0,  1] [ 4,  8,  8] -1 */
    23821979, /* 53646 (1334) [-1,  1,  0,  0,  1,  0,  0,  0,  1] [ 8,  4, 10]  1 */
    34146887, /* 53647 (1334) [ 1,  0,  0,  1, -1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    47411121, /* 53648 (1334) [ 1, -1,  0,  1,  0,  0,  0,  0, -1] [ 4,  8,  8] -1 */
    23714816, /* 53649 (1334) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 8,  4,  4]  1 */
    34142592, /* 53650 (1334) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  6] -1 */
    47413148, /* 53651 (1334) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 4,  8,  8] -1 */
    34015422, /* 53652 (1334) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
      121215, /* 53653 (1334) [-1,  0,  0, -1,  1,  0,  0,  0, -1] [ 0,  0,  6]  1 */
    57713754, /* 53654 (1334) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 8,  4,  4] -1 */
    23712789, /* 53655 (1334) [ 1, -1,  0,  1,  0,  0,  0,  0, -1] [ 8,  4,  4]  1 */
    23832995, /* 53656 (1334) [ 1,  0,  0,  1, -1,  0,  0,  0,  1] [ 8,  4, 10]  1 */
    47285978, /* 53657 (1334) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 4,  8,  2] -1 */
    47281683, /* 53658 (1334) [-1,  0,  0, -1,  1,  0,  0,  0, -1] [ 4,  8,  2] -1 */
      132231, /* 53659 (1334) [ 1, -1,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  6]  1 */
    47284115, /* 53660 (1334) [-1,  1,  0,  0,  1,  0,  0,  0,  1] [ 4,  8,  2] -1 */
    47292699, /* 53661 (1334) [ 1, -1,  0,  0, -1,  0,  0,  0, -1] [ 4,  8,  2] -1 */
    23828700, /* 53662 (1334) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 8,  4, 10]  1 */
    47295131, /* 53663 (1334) [ 1,  0,  0,  1, -1,  0,  0,  0,  1] [ 4,  8,  2] -1 */
      125510, /* 53664 (1334) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  6]  1 */
    13392257, /* 53665 (1334) [ 0, -1,  0,  1, -1,  0,  0,  0,  1] [ 4,  8,  8]  1 */
       11865, /* 53666 (1334) [ 0,  1,  0, -1,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
       16484, /* 53667 (1335) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    13389665, /* 53668 (1335) [-1,  1,  0, -1,  0,  0,  0,  0,  1] [ 4,  8,  8]  1 */
      123647, /* 53669 (1335) [-1,  1,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6]  1 */
    13400924, /* 53670 (1335) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 4,  8,  8]  1 */
      134663, /* 53671 (1335) [ 1,  0,  0,  1, -1,  0,  0,  0,  1] [ 0,  0,  6]  1 */
    47290836, /* 53672 (1335) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 4,  8,  2] -1 */
    47408529, /* 53673 (1335) [ 0,  1,  0, -1,  1,  0,  0,  0, -1] [ 4,  8,  8] -1 */
    57831771, /* 53674 (1335) [-1,  0,  0, -1,  1,  0,  0,  0, -1] [ 8,  4, 10] -1 */
    13273754, /* 53675 (1335) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 4,  8,  2]  1 */
    13271891, /* 53676 (1335) [-1,  1,  0,  0,  1,  0,  0,  0,  1] [ 4,  8,  2]  1 */
    57842787, /* 53677 (1335) [ 1, -1,  0,  0, -1,  0,  0,  0, -1] [ 8,  4, 10] -1 */
    47399862, /* 53678 (1335) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 4,  8,  8] -1 */
    13282907, /* 53679 (1335) [ 1,  0,  0,  1, -1,  0,  0,  0,  1] [ 4,  8,  2]  1 */
    34026681, /* 53680 (1335) [ 1, -1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    57725013, /* 53681 (1335) [ 1, -1,  0,  1,  0,  0,  0,  0, -1] [ 8,  4,  4] -1 */
    34133439, /* 53682 (1335) [-1,  0,  0, -1,  1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
    34144455, /* 53683 (1335) [ 1, -1,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
    23703557, /* 53684 (1335) [-1,  1,  0, -1,  0,  0,  0,  0,  1] [ 8,  4,  4]  1 */
        5225, /* 53685 (1335) [-1,  1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    23706149, /* 53686 (1335) [ 0, -1,  0,  1, -1,  0,  0,  0,  1] [ 8,  4,  4]  1 */
        7817, /* 53687 (1335) [ 0, -1,  0,  1, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    57840924, /* 53688 (1335) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 8,  4, 10] -1 */
    57722421, /* 53689 (1335) [ 0,  1,  0, -1,  1,  0,  0,  0, -1] [ 8,  4,  4] -1 */
    34024089, /* 53690 (1335) [ 0,  1,  0, -1,  1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    23823842, /* 53691 (1335) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 8,  4, 10]  1 */
    23821979, /* 53692 (1335) [-1,  1,  0,  0,  1,  0,  0,  0,  1] [ 8,  4, 10]  1 */
    47411121, /* 53693 (1335) [ 1, -1,  0,  1,  0,  0,  0,  0, -1] [ 4,  8,  8] -1 */
    23714816, /* 53694 (1335) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 8,  4,  4]  1 */
    34142592, /* 53695 (1335) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  6] -1 */
    57713754, /* 53696 (1335) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 8,  4,  4] -1 */
    34015422, /* 53697 (1335) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    47281683, /* 53698 (1335) [-1,  0,  0, -1,  1,  0,  0,  0, -1] [ 4,  8,  2] -1 */
    23832995, /* 53699 (1335) [ 1,  0,  0,  1, -1,  0,  0,  0,  1] [ 8,  4, 10]  1 */
    47292699, /* 53700 (1335) [ 1, -1,  0,  0, -1,  0,  0,  0, -1] [ 4,  8,  2] -1 */
      125510, /* 53701 (1335) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  6]  1 */
    13392257, /* 53702 (1335) [ 0, -1,  0,  1, -1,  0,  0,  0,  1] [ 4,  8,  8]  1 */
       16484, /* 53703 (1336) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    13389665, /* 53704 (1336) [-1,  1,  0, -1,  0,  0,  0,  0,  1] [ 4,  8,  8]  1 */
      130368, /* 53705 (1336) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  6]  1 */
    13400924, /* 53706 (1336) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 4,  8,  8]  1 */
    13269459, /* 53707 (1336) [-1,  0,  0, -1,  1,  0,  0,  0, -1] [ 4,  8,  2]  1 */
    47408529, /* 53708 (1336) [ 0,  1,  0, -1,  1,  0,  0,  0, -1] [ 4,  8,  8] -1 */
    13280475, /* 53709 (1336) [ 1, -1,  0,  0, -1,  0,  0,  0, -1] [ 4,  8,  2]  1 */
    47399862, /* 53710 (1336) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 4,  8,  8] -1 */
    34026681, /* 53711 (1336) [ 1, -1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    57836066, /* 53712 (1336) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 8,  4, 10] -1 */
    57725013, /* 53713 (1336) [ 1, -1,  0,  1,  0,  0,  0,  0, -1] [ 8,  4,  4] -1 */
    13278612, /* 53714 (1336) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 4,  8,  2]  1 */
    57834203, /* 53715 (1336) [-1,  1,  0,  0,  1,  0,  0,  0,  1] [ 8,  4, 10] -1 */
    57845219, /* 53716 (1336) [ 1,  0,  0,  1, -1,  0,  0,  0,  1] [ 8,  4, 10] -1 */
    23819547, /* 53717 (1336) [-1,  0,  0, -1,  1,  0,  0,  0, -1] [ 8,  4, 10]  1 */
    23830563, /* 53718 (1336) [ 1, -1,  0,  0, -1,  0,  0,  0, -1] [ 8,  4, 10]  1 */
    23703557, /* 53719 (1336) [-1,  1,  0, -1,  0,  0,  0,  0,  1] [ 8,  4,  4]  1 */
        5225, /* 53720 (1336) [-1,  1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    23706149, /* 53721 (1336) [ 0, -1,  0,  1, -1,  0,  0,  0,  1] [ 8,  4,  4]  1 */
        7817, /* 53722 (1336) [ 0, -1,  0,  1, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34137734, /* 53723 (1336) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    57722421, /* 53724 (1336) [ 0,  1,  0, -1,  1,  0,  0,  0, -1] [ 8,  4,  4] -1 */
    34024089, /* 53725 (1336) [ 0,  1,  0, -1,  1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    34135871, /* 53726 (1336) [-1,  1,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    34146887, /* 53727 (1336) [ 1,  0,  0,  1, -1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    47411121, /* 53728 (1336) [ 1, -1,  0,  1,  0,  0,  0,  0, -1] [ 4,  8,  8] -1 */
    23714816, /* 53729 (1336) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 8,  4,  4]  1 */
    57713754, /* 53730 (1336) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 8,  4,  4] -1 */
    34015422, /* 53731 (1336) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
      121215, /* 53732 (1336) [-1,  0,  0, -1,  1,  0,  0,  0, -1] [ 0,  0,  6]  1 */
    47285978, /* 53733 (1336) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 4,  8,  2] -1 */
      132231, /* 53734 (1336) [ 1, -1,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  6]  1 */
    47284115, /* 53735 (1336) [-1,  1,  0,  0,  1,  0,  0,  0,  1] [ 4,  8,  2] -1 */
    23828700, /* 53736 (1336) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 8,  4, 10]  1 */
    47295131, /* 53737 (1336) [ 1,  0,  0,  1, -1,  0,  0,  0,  1] [ 4,  8,  2] -1 */
    13392257, /* 53738 (1336) [ 0, -1,  0,  1, -1,  0,  0,  0,  1] [ 4,  8,  8]  1 */
       16484, /* 53739 (1337) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    13389665, /* 53740 (1337) [-1,  1,  0, -1,  0,  0,  0,  0,  1] [ 4,  8,  8]  1 */
    23710197, /* 53741 (1337) [ 0,  1,  0, -1,  1,  0,  0,  0, -1] [ 8,  4,  4]  1 */
    13398897, /* 53742 (1337) [ 1, -1,  0,  1,  0,  0,  0,  0, -1] [ 4,  8,  8]  1 */
    13400924, /* 53743 (1337) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 4,  8,  8]  1 */
    47290836, /* 53744 (1337) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 4,  8,  2] -1 */
    23701530, /* 53745 (1337) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 8,  4,  4]  1 */
        3198, /* 53746 (1337) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    57831771, /* 53747 (1337) [-1,  0,  0, -1,  1,  0,  0,  0, -1] [ 8,  4, 10] -1 */
    57842787, /* 53748 (1337) [ 1, -1,  0,  0, -1,  0,  0,  0, -1] [ 8,  4, 10] -1 */
    57836066, /* 53749 (1337) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 8,  4, 10] -1 */
    57834203, /* 53750 (1337) [-1,  1,  0,  0,  1,  0,  0,  0,  1] [ 8,  4, 10] -1 */
    13396305, /* 53751 (1337) [ 0,  1,  0, -1,  1,  0,  0,  0, -1] [ 4,  8,  8]  1 */
    57845219, /* 53752 (1337) [ 1,  0,  0,  1, -1,  0,  0,  0,  1] [ 8,  4, 10] -1 */
    34133439, /* 53753 (1337) [-1,  0,  0, -1,  1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
    13387638, /* 53754 (1337) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 4,  8,  8]  1 */
    34144455, /* 53755 (1337) [ 1, -1,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
       14457, /* 53756 (1337) [ 1, -1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    23703557, /* 53757 (1337) [-1,  1,  0, -1,  0,  0,  0,  0,  1] [ 8,  4,  4]  1 */
        5225, /* 53758 (1337) [-1,  1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    23706149, /* 53759 (1337) [ 0, -1,  0,  1, -1,  0,  0,  0,  1] [ 8,  4,  4]  1 */
        7817, /* 53760 (1337) [ 0, -1,  0,  1, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    57840924, /* 53761 (1337) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 8,  4, 10] -1 */
    34137734, /* 53762 (1337) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    34135871, /* 53763 (1337) [-1,  1,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    34146887, /* 53764 (1337) [ 1,  0,  0,  1, -1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    23714816, /* 53765 (1337) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 8,  4,  4]  1 */
    34142592, /* 53766 (1337) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  6] -1 */
    47281683, /* 53767 (1337) [-1,  0,  0, -1,  1,  0,  0,  0, -1] [ 4,  8,  2] -1 */
    23712789, /* 53768 (1337) [ 1, -1,  0,  1,  0,  0,  0,  0, -1] [ 8,  4,  4]  1 */
    47285978, /* 53769 (1337) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 4,  8,  2] -1 */
    47284115, /* 53770 (1337) [-1,  1,  0,  0,  1,  0,  0,  0,  1] [ 4,  8,  2] -1 */
    47292699, /* 53771 (1337) [ 1, -1,  0,  0, -1,  0,  0,  0, -1] [ 4,  8,  2] -1 */
    47295131, /* 53772 (1337) [ 1,  0,  0,  1, -1,  0,  0,  0,  1] [ 4,  8,  2] -1 */
    13392257, /* 53773 (1337) [ 0, -1,  0,  1, -1,  0,  0,  0,  1] [ 4,  8,  8]  1 */
       11865, /* 53774 (1337) [ 0,  1,  0, -1,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
       16484, /* 53775 (1338) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    13389665, /* 53776 (1338) [-1,  1,  0, -1,  0,  0,  0,  0,  1] [ 4,  8,  8]  1 */
    23710197, /* 53777 (1338) [ 0,  1,  0, -1,  1,  0,  0,  0, -1] [ 8,  4,  4]  1 */
    13398897, /* 53778 (1338) [ 1, -1,  0,  1,  0,  0,  0,  0, -1] [ 4,  8,  8]  1 */
    47404076, /* 53779 (1338) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 4,  8,  8] -1 */
      123647, /* 53780 (1338) [-1,  1,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6]  1 */
    47402213, /* 53781 (1338) [-1,  1,  0,  0,  1,  0,  0,  0,  1] [ 4,  8,  8] -1 */
      130368, /* 53782 (1338) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  6]  1 */
    13400924, /* 53783 (1338) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 4,  8,  8]  1 */
    57845138, /* 53784 (1338) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 8,  4, 10] -1 */
    47281764, /* 53785 (1338) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 4,  8,  2] -1 */
      134663, /* 53786 (1338) [ 1,  0,  0,  1, -1,  0,  0,  0,  1] [ 0,  0,  6]  1 */
    57833879, /* 53787 (1338) [-1,  1,  0, -1,  0,  0,  0,  0,  1] [ 8,  4, 10] -1 */
    47410797, /* 53788 (1338) [ 1, -1,  0,  0, -1,  0,  0,  0, -1] [ 4,  8,  8] -1 */
    13269459, /* 53789 (1338) [-1,  0,  0, -1,  1,  0,  0,  0, -1] [ 4,  8,  2]  1 */
    23701530, /* 53790 (1338) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 8,  4,  4]  1 */
        3198, /* 53791 (1338) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    47408934, /* 53792 (1338) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 4,  8,  8] -1 */
    47413229, /* 53793 (1338) [ 1,  0,  0,  1, -1,  0,  0,  0,  1] [ 4,  8,  8] -1 */
    13273754, /* 53794 (1338) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 4,  8,  2]  1 */
    34135547, /* 53795 (1338) [-1,  1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    13271891, /* 53796 (1338) [-1,  1,  0,  0,  1,  0,  0,  0,  1] [ 4,  8,  2]  1 */
    13280475, /* 53797 (1338) [ 1, -1,  0,  0, -1,  0,  0,  0, -1] [ 4,  8,  2]  1 */
    13282907, /* 53798 (1338) [ 1,  0,  0,  1, -1,  0,  0,  0,  1] [ 4,  8,  2]  1 */
    34138139, /* 53799 (1338) [ 0, -1,  0,  1, -1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    34144779, /* 53800 (1338) [ 1, -1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  6] -1 */
    57836471, /* 53801 (1338) [ 0, -1,  0,  1, -1,  0,  0,  0,  1] [ 8,  4, 10] -1 */
    34146806, /* 53802 (1338) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    13278612, /* 53803 (1338) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 4,  8,  2]  1 */
    13396305, /* 53804 (1338) [ 0,  1,  0, -1,  1,  0,  0,  0, -1] [ 4,  8,  8]  1 */
    57831852, /* 53805 (1338) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 8,  4, 10] -1 */
    57840519, /* 53806 (1338) [ 0,  1,  0, -1,  1,  0,  0,  0, -1] [ 8,  4, 10] -1 */
    23819547, /* 53807 (1338) [-1,  0,  0, -1,  1,  0,  0,  0, -1] [ 8,  4, 10]  1 */
    57713673, /* 53808 (1338) [-1,  0,  0, -1,  1,  0,  0,  0, -1] [ 8,  4,  4] -1 */
    34015341, /* 53809 (1338) [-1,  0,  0, -1,  1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    47293023, /* 53810 (1338) [ 1, -1,  0,  1,  0,  0,  0,  0, -1] [ 4,  8,  2] -1 */
    13387638, /* 53811 (1338) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 4,  8,  8]  1 */
    47283791, /* 53812 (1338) [-1,  1,  0, -1,  0,  0,  0,  0,  1] [ 4,  8,  2] -1 */
       14457, /* 53813 (1338) [ 1, -1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    34019636, /* 53814 (1338) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    47286383, /* 53815 (1338) [ 0, -1,  0,  1, -1,  0,  0,  0,  1] [ 4,  8,  2] -1 */
    23830563, /* 53816 (1338) [ 1, -1,  0,  0, -1,  0,  0,  0, -1] [ 8,  4, 10]  1 */
    23703557, /* 53817 (1338) [-1,  1,  0, -1,  0,  0,  0,  0,  1] [ 8,  4,  4]  1 */
        5225, /* 53818 (1338) [-1,  1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34026357, /* 53819 (1338) [ 1, -1,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    34142187, /* 53820 (1338) [ 0,  1,  0, -1,  1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
    23706149, /* 53821 (1338) [ 0, -1,  0,  1, -1,  0,  0,  0,  1] [ 8,  4,  4]  1 */
        7817, /* 53822 (1338) [ 0, -1,  0,  1, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    57724689, /* 53823 (1338) [ 1, -1,  0,  0, -1,  0,  0,  0, -1] [ 8,  4,  4] -1 */
    34017773, /* 53824 (1338) [-1,  1,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    23823842, /* 53825 (1338) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 8,  4, 10]  1 */
    47295050, /* 53826 (1338) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 4,  8,  2] -1 */
    57717968, /* 53827 (1338) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 8,  4,  4] -1 */
    23821979, /* 53828 (1338) [-1,  1,  0,  0,  1,  0,  0,  0,  1] [ 8,  4, 10]  1 */
    23714816, /* 53829 (1338) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 8,  4,  4]  1 */
    23712789, /* 53830 (1338) [ 1, -1,  0,  1,  0,  0,  0,  0, -1] [ 8,  4,  4]  1 */
      121215, /* 53831 (1338) [-1,  0,  0, -1,  1,  0,  0,  0, -1] [ 0,  0,  6]  1 */
    23832995, /* 53832 (1338) [ 1,  0,  0,  1, -1,  0,  0,  0,  1] [ 8,  4, 10]  1 */
    47399781, /* 53833 (1338) [-1,  0,  0, -1,  1,  0,  0,  0, -1] [ 4,  8,  8] -1 */
    57716105, /* 53834 (1338) [-1,  1,  0,  0,  1,  0,  0,  0,  1] [ 8,  4,  4] -1 */
    57722826, /* 53835 (1338) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 8,  4,  4] -1 */
    34024494, /* 53836 (1338) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    57727121, /* 53837 (1338) [ 1,  0,  0,  1, -1,  0,  0,  0,  1] [ 8,  4,  4] -1 */
    34028789, /* 53838 (1338) [ 1,  0,  0,  1, -1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    34133520, /* 53839 (1338) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
      132231, /* 53840 (1338) [ 1, -1,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  6]  1 */
    57843111, /* 53841 (1338) [ 1, -1,  0,  1,  0,  0,  0,  0, -1] [ 8,  4, 10] -1 */
    47290431, /* 53842 (1338) [ 0,  1,  0, -1,  1,  0,  0,  0, -1] [ 4,  8,  2] -1 */
    23828700, /* 53843 (1338) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 8,  4, 10]  1 */
      125510, /* 53844 (1338) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  6]  1 */
    13392257, /* 53845 (1338) [ 0, -1,  0,  1, -1,  0,  0,  0,  1] [ 4,  8,  8]  1 */
       11865, /* 53846 (1338) [ 0,  1,  0, -1,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
       16484, /* 53847 (1333) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
       10816, /* 53848 (1333) [ 0,  0,  1,  1,  0,  0,  0,  1,  0] [ 0,  0,  0]  1 */
    18552046, /* 53849 (1333) [ 0,  0,  1,  0,  1,  0,  1,  0,  0] [ 6,  6,  6]  1 */
    18548796, /* 53850 (1333) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 6,  6,  6]  1 */
    18544636, /* 53851 (1333) [-1,  0,  0,  0,  0, -1,  0, -1,  0] [ 6,  6,  6]  1 */
       12064, /* 53852 (1333) [ 0,  1,  0,  0,  0,  1,  1,  0,  0] [ 0,  0,  0]  1 */
        3198, /* 53853 (1333) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    18550408, /* 53854 (1333) [ 0,  0, -1,  0, -1,  0, -1,  0,  0] [ 6,  6,  6]  1 */
    18557818, /* 53855 (1333) [ 1,  0,  0,  0,  0,  1,  0,  1,  0] [ 6,  6,  6]  1 */
        7618, /* 53856 (1333) [ 0, -1,  0,  0,  0, -1, -1,  0,  0] [ 0,  0,  0]  1 */
    18553658, /* 53857 (1333) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 6,  6,  6]  1 */
        8866, /* 53858 (1333) [ 0,  0, -1, -1,  0,  0,  0, -1,  0] [ 0,  0,  0]  1 */
       16484, /* 53859 (1334) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
        3198, /* 53860 (1334) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    18550408, /* 53861 (1334) [ 0,  0, -1,  0, -1,  0, -1,  0,  0] [ 6,  6,  6]  1 */
        8866, /* 53862 (1334) [ 0,  0, -1, -1,  0,  0,  0, -1,  0] [ 0,  0,  0]  1 */
    52556860, /* 53863 (1334) [-1,  0,  0,  0,  0, -1,  0, -1,  0] [ 6,  6,  6] -1 */
    18548796, /* 53864 (1334) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 6,  6,  6]  1 */
    52565882, /* 53865 (1334) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    34028708, /* 53866 (1334) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    34023040, /* 53867 (1334) [ 0,  0,  1,  1,  0,  0,  0,  1,  0] [ 0,  0,  0] -1 */
    34024288, /* 53868 (1334) [ 0,  1,  0,  0,  0,  1,  1,  0,  0] [ 0,  0,  0] -1 */
    18544636, /* 53869 (1334) [-1,  0,  0,  0,  0, -1,  0, -1,  0] [ 6,  6,  6]  1 */
    52570042, /* 53870 (1334) [ 1,  0,  0,  0,  0,  1,  0,  1,  0] [ 6,  6,  6] -1 */
    34019842, /* 53871 (1334) [ 0, -1,  0,  0,  0, -1, -1,  0,  0] [ 0,  0,  0] -1 */
    52564270, /* 53872 (1334) [ 0,  0,  1,  0,  1,  0,  1,  0,  0] [ 6,  6,  6] -1 */
    18553658, /* 53873 (1334) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    34015422, /* 53874 (1334) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
       10816, /* 53875 (1334) [ 0,  0,  1,  1,  0,  0,  0,  1,  0] [ 0,  0,  0]  1 */
    52562632, /* 53876 (1334) [ 0,  0, -1,  0, -1,  0, -1,  0,  0] [ 6,  6,  6] -1 */
        7618, /* 53877 (1334) [ 0, -1,  0,  0,  0, -1, -1,  0,  0] [ 0,  0,  0]  1 */
       12064, /* 53878 (1334) [ 0,  1,  0,  0,  0,  1,  1,  0,  0] [ 0,  0,  0]  1 */
    18557818, /* 53879 (1334) [ 1,  0,  0,  0,  0,  1,  0,  1,  0] [ 6,  6,  6]  1 */
    34021090, /* 53880 (1334) [ 0,  0, -1, -1,  0,  0,  0, -1,  0] [ 0,  0,  0] -1 */
    18552046, /* 53881 (1334) [ 0,  0,  1,  0,  1,  0,  1,  0,  0] [ 6,  6,  6]  1 */
    52561020, /* 53882 (1334) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 6,  6,  6] -1 */
       16484, /* 53883 (1335) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34015422, /* 53884 (1335) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
       10816, /* 53885 (1335) [ 0,  0,  1,  1,  0,  0,  0,  1,  0] [ 0,  0,  0]  1 */
    52556860, /* 53886 (1335) [-1,  0,  0,  0,  0, -1,  0, -1,  0] [ 6,  6,  6] -1 */
    52562632, /* 53887 (1335) [ 0,  0, -1,  0, -1,  0, -1,  0,  0] [ 6,  6,  6] -1 */
       12064, /* 53888 (1335) [ 0,  1,  0,  0,  0,  1,  1,  0,  0] [ 0,  0,  0]  1 */
    34019842, /* 53889 (1335) [ 0, -1,  0,  0,  0, -1, -1,  0,  0] [ 0,  0,  0] -1 */
    18557818, /* 53890 (1335) [ 1,  0,  0,  0,  0,  1,  0,  1,  0] [ 6,  6,  6]  1 */
    34021090, /* 53891 (1335) [ 0,  0, -1, -1,  0,  0,  0, -1,  0] [ 0,  0,  0] -1 */
    18552046, /* 53892 (1335) [ 0,  0,  1,  0,  1,  0,  1,  0,  0] [ 6,  6,  6]  1 */
    52561020, /* 53893 (1335) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    18553658, /* 53894 (1335) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 6,  6,  6]  1 */
       16484, /* 53895 (1336) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34015422, /* 53896 (1336) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
       10816, /* 53897 (1336) [ 0,  0,  1,  1,  0,  0,  0,  1,  0] [ 0,  0,  0]  1 */
    18548796, /* 53898 (1336) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 6,  6,  6]  1 */
    18544636, /* 53899 (1336) [-1,  0,  0,  0,  0, -1,  0, -1,  0] [ 6,  6,  6]  1 */
    52570042, /* 53900 (1336) [ 1,  0,  0,  0,  0,  1,  0,  1,  0] [ 6,  6,  6] -1 */
       12064, /* 53901 (1336) [ 0,  1,  0,  0,  0,  1,  1,  0,  0] [ 0,  0,  0]  1 */
    34019842, /* 53902 (1336) [ 0, -1,  0,  0,  0, -1, -1,  0,  0] [ 0,  0,  0] -1 */
    52564270, /* 53903 (1336) [ 0,  0,  1,  0,  1,  0,  1,  0,  0] [ 6,  6,  6] -1 */
    18550408, /* 53904 (1336) [ 0,  0, -1,  0, -1,  0, -1,  0,  0] [ 6,  6,  6]  1 */
    52565882, /* 53905 (1336) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    34021090, /* 53906 (1336) [ 0,  0, -1, -1,  0,  0,  0, -1,  0] [ 0,  0,  0] -1 */
       16484, /* 53907 (1337) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
       10816, /* 53908 (1337) [ 0,  0,  1,  1,  0,  0,  0,  1,  0] [ 0,  0,  0]  1 */
    52556860, /* 53909 (1337) [-1,  0,  0,  0,  0, -1,  0, -1,  0] [ 6,  6,  6] -1 */
    52562632, /* 53910 (1337) [ 0,  0, -1,  0, -1,  0, -1,  0,  0] [ 6,  6,  6] -1 */
    52570042, /* 53911 (1337) [ 1,  0,  0,  0,  0,  1,  0,  1,  0] [ 6,  6,  6] -1 */
       12064, /* 53912 (1337) [ 0,  1,  0,  0,  0,  1,  1,  0,  0] [ 0,  0,  0]  1 */
        3198, /* 53913 (1337) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    52564270, /* 53914 (1337) [ 0,  0,  1,  0,  1,  0,  1,  0,  0] [ 6,  6,  6] -1 */
    52565882, /* 53915 (1337) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 6,  6,  6] -1 */
        7618, /* 53916 (1337) [ 0, -1,  0,  0,  0, -1, -1,  0,  0] [ 0,  0,  0]  1 */
    52561020, /* 53917 (1337) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 6,  6,  6] -1 */
        8866, /* 53918 (1337) [ 0,  0, -1, -1,  0,  0,  0, -1,  0] [ 0,  0,  0]  1 */
       16484, /* 53919 (1338) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34019634, /* 53920 (1338) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  0] -1 */
        3198, /* 53921 (1338) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    18550408, /* 53922 (1338) [ 0,  0, -1,  0, -1,  0, -1,  0,  0] [ 6,  6,  6]  1 */
    52570094, /* 53923 (1338) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
        8866, /* 53924 (1338) [ 0,  0, -1, -1,  0,  0,  0, -1,  0] [ 0,  0,  0]  1 */
    18548796, /* 53925 (1338) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 6,  6,  6]  1 */
    34015474, /* 53926 (1338) [-1,  0,  0,  0,  0, -1,  0, -1,  0] [ 0,  0,  0] -1 */
    34024496, /* 53927 (1338) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    52565674, /* 53928 (1338) [ 0,  1,  0,  0,  0,  1,  1,  0,  0] [ 6,  6,  6] -1 */
    52561228, /* 53929 (1338) [ 0, -1,  0,  0,  0, -1, -1,  0,  0] [ 6,  6,  6] -1 */
    52564426, /* 53930 (1338) [ 0,  0,  1,  1,  0,  0,  0,  1,  0] [ 6,  6,  6] -1 */
    18544636, /* 53931 (1338) [-1,  0,  0,  0,  0, -1,  0, -1,  0] [ 6,  6,  6]  1 */
    34022884, /* 53932 (1338) [ 0,  0,  1,  0,  1,  0,  1,  0,  0] [ 0,  0,  0] -1 */
    18553658, /* 53933 (1338) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    52556808, /* 53934 (1338) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    34021246, /* 53935 (1338) [ 0,  0, -1,  0, -1,  0, -1,  0,  0] [ 0,  0,  0] -1 */
       10816, /* 53936 (1338) [ 0,  0,  1,  1,  0,  0,  0,  1,  0] [ 0,  0,  0]  1 */
        7618, /* 53937 (1338) [ 0, -1,  0,  0,  0, -1, -1,  0,  0] [ 0,  0,  0]  1 */
    52562476, /* 53938 (1338) [ 0,  0, -1, -1,  0,  0,  0, -1,  0] [ 6,  6,  6] -1 */
    34028656, /* 53939 (1338) [ 1,  0,  0,  0,  0,  1,  0,  1,  0] [ 0,  0,  0] -1 */
       12064, /* 53940 (1338) [ 0,  1,  0,  0,  0,  1,  1,  0,  0] [ 0,  0,  0]  1 */
    18557818, /* 53941 (1338) [ 1,  0,  0,  0,  0,  1,  0,  1,  0] [ 6,  6,  6]  1 */
    18552046, /* 53942 (1338) [ 0,  0,  1,  0,  1,  0,  1,  0,  0] [ 6,  6,  6]  1 */
       16484, /* 53943 (1339) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
        3200, /* 53944 (1339) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
        5225, /* 53945 (1339) [-1,  1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  0]  1 */
        7817, /* 53946 (1339) [ 0, -1,  0,  1, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
       14459, /* 53947 (1339) [ 1, -1,  0,  1,  0,  0,  0,  0,  1] [ 0,  0,  0]  1 */
       11867, /* 53948 (1339) [ 0,  1,  0, -1,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
       16484, /* 53949 (1340) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34017449, /* 53950 (1340) [-1,  1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  0] -1 */
        3200, /* 53951 (1340) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34026683, /* 53952 (1340) [ 1, -1,  0,  1,  0,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    34024091, /* 53953 (1340) [ 0,  1,  0, -1,  1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    34020041, /* 53954 (1340) [ 0, -1,  0,  1, -1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
        5225, /* 53955 (1340) [-1,  1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  0]  1 */
        7817, /* 53956 (1340) [ 0, -1,  0,  1, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
       14459, /* 53957 (1340) [ 1, -1,  0,  1,  0,  0,  0,  0,  1] [ 0,  0,  0]  1 */
       11867, /* 53958 (1340) [ 0,  1,  0, -1,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34015424, /* 53959 (1340) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    34028708, /* 53960 (1340) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
       16484, /* 53961 (1341) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34026683, /* 53962 (1341) [ 1, -1,  0,  1,  0,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    34024091, /* 53963 (1341) [ 0,  1,  0, -1,  1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
        5225, /* 53964 (1341) [-1,  1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  0]  1 */
        7817, /* 53965 (1341) [ 0, -1,  0,  1, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34015424, /* 53966 (1341) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
       16484, /* 53967 (1342) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34144781, /* 53968 (1342) [ 1, -1,  0,  1,  0,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    34133522, /* 53969 (1342) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    34138139, /* 53970 (1342) [ 0, -1,  0,  1, -1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
        3200, /* 53971 (1342) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
        5225, /* 53972 (1342) [-1,  1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  0]  1 */
        7817, /* 53973 (1342) [ 0, -1,  0,  1, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34146806, /* 53974 (1342) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
       14459, /* 53975 (1342) [ 1, -1,  0,  1,  0,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34142189, /* 53976 (1342) [ 0,  1,  0, -1,  1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
       11867, /* 53977 (1342) [ 0,  1,  0, -1,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34135547, /* 53978 (1342) [-1,  1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  6] -1 */
       16484, /* 53979 (1343) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
      208697, /* 53980 (1343) [ 0,  1,  0, -1,  1,  0,  0,  0,  1] [ 0,  0, 10]  1 */
      162689, /* 53981 (1343) [-1,  1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  8]  1 */
       86549, /* 53982 (1343) [ 0, -1,  0,  1, -1,  0,  0,  0,  1] [ 0,  0,  4]  1 */
       53825, /* 53983 (1343) [ 1, -1,  0,  1,  0,  0,  0,  0,  1] [ 0,  0,  2]  1 */
      121298, /* 53984 (1343) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6]  1 */
       16484, /* 53985 (1344) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
      208697, /* 53986 (1344) [ 0,  1,  0, -1,  1,  0,  0,  0,  1] [ 0,  0, 10]  1 */
    34066049, /* 53987 (1344) [ 1, -1,  0,  1,  0,  0,  0,  0,  1] [ 0,  0,  2] -1 */
      162689, /* 53988 (1344) [-1,  1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  8]  1 */
    34133522, /* 53989 (1344) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
       86549, /* 53990 (1344) [ 0, -1,  0,  1, -1,  0,  0,  0,  1] [ 0,  0,  4]  1 */
       53825, /* 53991 (1344) [ 1, -1,  0,  1,  0,  0,  0,  0,  1] [ 0,  0,  2]  1 */
      121298, /* 53992 (1344) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6]  1 */
    34220921, /* 53993 (1344) [ 0,  1,  0, -1,  1,  0,  0,  0,  1] [ 0,  0, 10] -1 */
    34174913, /* 53994 (1344) [-1,  1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  8] -1 */
    34098773, /* 53995 (1344) [ 0, -1,  0,  1, -1,  0,  0,  0,  1] [ 0,  0,  4] -1 */
    34028708, /* 53996 (1344) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
       16484, /* 53997 (1345) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34066049, /* 53998 (1345) [ 1, -1,  0,  1,  0,  0,  0,  0,  1] [ 0,  0,  2] -1 */
    34133522, /* 53999 (1345) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
      162689, /* 54000 (1345) [-1,  1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  8]  1 */
       86549, /* 54001 (1345) [ 0, -1,  0,  1, -1,  0,  0,  0,  1] [ 0,  0,  4]  1 */
    34220921, /* 54002 (1345) [ 0,  1,  0, -1,  1,  0,  0,  0,  1] [ 0,  0, 10] -1 */
       16484, /* 54003 (1346) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
      208697, /* 54004 (1346) [ 0,  1,  0, -1,  1,  0,  0,  0,  1] [ 0,  0, 10]  1 */
      162689, /* 54005 (1346) [-1,  1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  8]  1 */
       86549, /* 54006 (1346) [ 0, -1,  0,  1, -1,  0,  0,  0,  1] [ 0,  0,  4]  1 */
    34184147, /* 54007 (1346) [ 1, -1,  0,  1,  0,  0,  0,  0,  1] [ 0,  0,  8] -1 */
       53825, /* 54008 (1346) [ 1, -1,  0,  1,  0,  0,  0,  0,  1] [ 0,  0,  2]  1 */
    34056815, /* 54009 (1346) [-1,  1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  2] -1 */
    34102823, /* 54010 (1346) [ 0,  1,  0, -1,  1,  0,  0,  0,  1] [ 0,  0,  4] -1 */
      121298, /* 54011 (1346) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6]  1 */
    34216871, /* 54012 (1346) [ 0, -1,  0,  1, -1,  0,  0,  0,  1] [ 0,  0, 10] -1 */
    34146806, /* 54013 (1346) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    34015424, /* 54014 (1346) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
       16484, /* 54015 (1347) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
       83957, /* 54016 (1347) [-1,  1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  4]  1 */
      121298, /* 54017 (1347) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6]  1 */
      165281, /* 54018 (1347) [ 0, -1,  0,  1, -1,  0,  0,  0,  1] [ 0,  0,  8]  1 */
       51233, /* 54019 (1347) [ 0,  1,  0, -1,  1,  0,  0,  0,  1] [ 0,  0,  2]  1 */
      211289, /* 54020 (1347) [ 1, -1,  0,  1,  0,  0,  0,  0,  1] [ 0,  0, 10]  1 */
       16484, /* 54021 (1348) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34133522, /* 54022 (1348) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    34177505, /* 54023 (1348) [ 0, -1,  0,  1, -1,  0,  0,  0,  1] [ 0,  0,  8] -1 */
    34096181, /* 54024 (1348) [-1,  1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  4] -1 */
    34063457, /* 54025 (1348) [ 0,  1,  0, -1,  1,  0,  0,  0,  1] [ 0,  0,  2] -1 */
       83957, /* 54026 (1348) [-1,  1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  4]  1 */
    34223513, /* 54027 (1348) [ 1, -1,  0,  1,  0,  0,  0,  0,  1] [ 0,  0, 10] -1 */
      121298, /* 54028 (1348) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6]  1 */
      165281, /* 54029 (1348) [ 0, -1,  0,  1, -1,  0,  0,  0,  1] [ 0,  0,  8]  1 */
       51233, /* 54030 (1348) [ 0,  1,  0, -1,  1,  0,  0,  0,  1] [ 0,  0,  2]  1 */
    34028708, /* 54031 (1348) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
      211289, /* 54032 (1348) [ 1, -1,  0,  1,  0,  0,  0,  0,  1] [ 0,  0, 10]  1 */
       16484, /* 54033 (1349) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34133522, /* 54034 (1349) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    34063457, /* 54035 (1349) [ 0,  1,  0, -1,  1,  0,  0,  0,  1] [ 0,  0,  2] -1 */
       83957, /* 54036 (1349) [-1,  1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  4]  1 */
    34223513, /* 54037 (1349) [ 1, -1,  0,  1,  0,  0,  0,  0,  1] [ 0,  0, 10] -1 */
      165281, /* 54038 (1349) [ 0, -1,  0,  1, -1,  0,  0,  0,  1] [ 0,  0,  8]  1 */
       16484, /* 54039 (1350) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34214279, /* 54040 (1350) [-1,  1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0, 10] -1 */
    34105415, /* 54041 (1350) [ 1, -1,  0,  1,  0,  0,  0,  0,  1] [ 0,  0,  4] -1 */
       83957, /* 54042 (1350) [-1,  1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  4]  1 */
    34181555, /* 54043 (1350) [ 0,  1,  0, -1,  1,  0,  0,  0,  1] [ 0,  0,  8] -1 */
      121298, /* 54044 (1350) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6]  1 */
    34059407, /* 54045 (1350) [ 0, -1,  0,  1, -1,  0,  0,  0,  1] [ 0,  0,  2] -1 */
      165281, /* 54046 (1350) [ 0, -1,  0,  1, -1,  0,  0,  0,  1] [ 0,  0,  8]  1 */
    34146806, /* 54047 (1350) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
       51233, /* 54048 (1350) [ 0,  1,  0, -1,  1,  0,  0,  0,  1] [ 0,  0,  2]  1 */
    34015424, /* 54049 (1350) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
      211289, /* 54050 (1350) [ 1, -1,  0,  1,  0,  0,  0,  0,  1] [ 0,  0, 10]  1 */
       16484, /* 54051 (1351) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
        3200, /* 54052 (1351) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
       83957, /* 54053 (1351) [-1,  1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  4]  1 */
      169331, /* 54054 (1351) [ 0,  1,  0, -1,  1,  0,  0,  0,  1] [ 0,  0,  8]  1 */
      165281, /* 54055 (1351) [ 0, -1,  0,  1, -1,  0,  0,  0,  1] [ 0,  0,  8]  1 */
       93191, /* 54056 (1351) [ 1, -1,  0,  1,  0,  0,  0,  0,  1] [ 0,  0,  4]  1 */
       16484, /* 54057 (1352) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34177505, /* 54058 (1352) [ 0, -1,  0,  1, -1,  0,  0,  0,  1] [ 0,  0,  8] -1 */
        3200, /* 54059 (1352) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34096181, /* 54060 (1352) [-1,  1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  4] -1 */
    34105415, /* 54061 (1352) [ 1, -1,  0,  1,  0,  0,  0,  0,  1] [ 0,  0,  4] -1 */
       83957, /* 54062 (1352) [-1,  1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  4]  1 */
    34181555, /* 54063 (1352) [ 0,  1,  0, -1,  1,  0,  0,  0,  1] [ 0,  0,  8] -1 */
      169331, /* 54064 (1352) [ 0,  1,  0, -1,  1,  0,  0,  0,  1] [ 0,  0,  8]  1 */
      165281, /* 54065 (1352) [ 0, -1,  0,  1, -1,  0,  0,  0,  1] [ 0,  0,  8]  1 */
    34015424, /* 54066 (1352) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
       93191, /* 54067 (1352) [ 1, -1,  0,  1,  0,  0,  0,  0,  1] [ 0,  0,  4]  1 */
    34028708, /* 54068 (1352) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
       16484, /* 54069 (1353) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34105415, /* 54070 (1353) [ 1, -1,  0,  1,  0,  0,  0,  0,  1] [ 0,  0,  4] -1 */
       83957, /* 54071 (1353) [-1,  1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  4]  1 */
    34181555, /* 54072 (1353) [ 0,  1,  0, -1,  1,  0,  0,  0,  1] [ 0,  0,  8] -1 */
      165281, /* 54073 (1353) [ 0, -1,  0,  1, -1,  0,  0,  0,  1] [ 0,  0,  8]  1 */
    34015424, /* 54074 (1353) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
       16484, /* 54075 (1354) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34133522, /* 54076 (1354) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
        3200, /* 54077 (1354) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34214279, /* 54078 (1354) [-1,  1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0, 10] -1 */
    34063457, /* 54079 (1354) [ 0,  1,  0, -1,  1,  0,  0,  0,  1] [ 0,  0,  2] -1 */
       83957, /* 54080 (1354) [-1,  1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  4]  1 */
    34223513, /* 54081 (1354) [ 1, -1,  0,  1,  0,  0,  0,  0,  1] [ 0,  0, 10] -1 */
    34059407, /* 54082 (1354) [ 0, -1,  0,  1, -1,  0,  0,  0,  1] [ 0,  0,  2] -1 */
      169331, /* 54083 (1354) [ 0,  1,  0, -1,  1,  0,  0,  0,  1] [ 0,  0,  8]  1 */
      165281, /* 54084 (1354) [ 0, -1,  0,  1, -1,  0,  0,  0,  1] [ 0,  0,  8]  1 */
    34146806, /* 54085 (1354) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
       93191, /* 54086 (1354) [ 1, -1,  0,  1,  0,  0,  0,  0,  1] [ 0,  0,  4]  1 */
       16484, /* 54087 (1355) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
      162689, /* 54088 (1355) [-1,  1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  8]  1 */
       86549, /* 54089 (1355) [ 0, -1,  0,  1, -1,  0,  0,  0,  1] [ 0,  0,  4]  1 */
        3200, /* 54090 (1355) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
       90599, /* 54091 (1355) [ 0,  1,  0, -1,  1,  0,  0,  0,  1] [ 0,  0,  4]  1 */
      171923, /* 54092 (1355) [ 1, -1,  0,  1,  0,  0,  0,  0,  1] [ 0,  0,  8]  1 */
       16484, /* 54093 (1356) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
      162689, /* 54094 (1356) [-1,  1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  8]  1 */
       86549, /* 54095 (1356) [ 0, -1,  0,  1, -1,  0,  0,  0,  1] [ 0,  0,  4]  1 */
        3200, /* 54096 (1356) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34184147, /* 54097 (1356) [ 1, -1,  0,  1,  0,  0,  0,  0,  1] [ 0,  0,  8] -1 */
    34102823, /* 54098 (1356) [ 0,  1,  0, -1,  1,  0,  0,  0,  1] [ 0,  0,  4] -1 */
    34174913, /* 54099 (1356) [-1,  1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  8] -1 */
       90599, /* 54100 (1356) [ 0,  1,  0, -1,  1,  0,  0,  0,  1] [ 0,  0,  4]  1 */
      171923, /* 54101 (1356) [ 1, -1,  0,  1,  0,  0,  0,  0,  1] [ 0,  0,  8]  1 */
    34098773, /* 54102 (1356) [ 0, -1,  0,  1, -1,  0,  0,  0,  1] [ 0,  0,  4] -1 */
    34015424, /* 54103 (1356) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    34028708, /* 54104 (1356) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
       16484, /* 54105 (1357) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
      162689, /* 54106 (1357) [-1,  1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  8]  1 */
       86549, /* 54107 (1357) [ 0, -1,  0,  1, -1,  0,  0,  0,  1] [ 0,  0,  4]  1 */
    34184147, /* 54108 (1357) [ 1, -1,  0,  1,  0,  0,  0,  0,  1] [ 0,  0,  8] -1 */
    34102823, /* 54109 (1357) [ 0,  1,  0, -1,  1,  0,  0,  0,  1] [ 0,  0,  4] -1 */
    34015424, /* 54110 (1357) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
       16484, /* 54111 (1358) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34066049, /* 54112 (1358) [ 1, -1,  0,  1,  0,  0,  0,  0,  1] [ 0,  0,  2] -1 */
      162689, /* 54113 (1358) [-1,  1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  8]  1 */
    34133522, /* 54114 (1358) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
       86549, /* 54115 (1358) [ 0, -1,  0,  1, -1,  0,  0,  0,  1] [ 0,  0,  4]  1 */
        3200, /* 54116 (1358) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34056815, /* 54117 (1358) [-1,  1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  2] -1 */
    34220921, /* 54118 (1358) [ 0,  1,  0, -1,  1,  0,  0,  0,  1] [ 0,  0, 10] -1 */
    34216871, /* 54119 (1358) [ 0, -1,  0,  1, -1,  0,  0,  0,  1] [ 0,  0, 10] -1 */
    34146806, /* 54120 (1358) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
       90599, /* 54121 (1358) [ 0,  1,  0, -1,  1,  0,  0,  0,  1] [ 0,  0,  4]  1 */
      171923, /* 54122 (1358) [ 1, -1,  0,  1,  0,  0,  0,  0,  1] [ 0,  0,  8]  1 */
       16484, /* 54123 (1359) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
      129965, /* 54124 (1359) [ 0,  1,  0, -1,  1,  0,  0,  0,  1] [ 0,  0,  6]  1 */
        5225, /* 54125 (1359) [-1,  1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  0]  1 */
      132557, /* 54126 (1359) [ 1, -1,  0,  1,  0,  0,  0,  0,  1] [ 0,  0,  6]  1 */
      121298, /* 54127 (1359) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6]  1 */
        7817, /* 54128 (1359) [ 0, -1,  0,  1, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
       16484, /* 54129 (1360) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34017449, /* 54130 (1360) [-1,  1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    34144781, /* 54131 (1360) [ 1, -1,  0,  1,  0,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    34133522, /* 54132 (1360) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
      129965, /* 54133 (1360) [ 0,  1,  0, -1,  1,  0,  0,  0,  1] [ 0,  0,  6]  1 */
    34020041, /* 54134 (1360) [ 0, -1,  0,  1, -1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
        5225, /* 54135 (1360) [-1,  1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  0]  1 */
      132557, /* 54136 (1360) [ 1, -1,  0,  1,  0,  0,  0,  0,  1] [ 0,  0,  6]  1 */
      121298, /* 54137 (1360) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6]  1 */
        7817, /* 54138 (1360) [ 0, -1,  0,  1, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34142189, /* 54139 (1360) [ 0,  1,  0, -1,  1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    34028708, /* 54140 (1360) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
       16484, /* 54141 (1361) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34144781, /* 54142 (1361) [ 1, -1,  0,  1,  0,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    34133522, /* 54143 (1361) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
        5225, /* 54144 (1361) [-1,  1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  0]  1 */
        7817, /* 54145 (1361) [ 0, -1,  0,  1, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34142189, /* 54146 (1361) [ 0,  1,  0, -1,  1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
       16484, /* 54147 (1362) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
      129965, /* 54148 (1362) [ 0,  1,  0, -1,  1,  0,  0,  0,  1] [ 0,  0,  6]  1 */
    34138139, /* 54149 (1362) [ 0, -1,  0,  1, -1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    34026683, /* 54150 (1362) [ 1, -1,  0,  1,  0,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    34024091, /* 54151 (1362) [ 0,  1,  0, -1,  1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
        5225, /* 54152 (1362) [-1,  1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  0]  1 */
      132557, /* 54153 (1362) [ 1, -1,  0,  1,  0,  0,  0,  0,  1] [ 0,  0,  6]  1 */
      121298, /* 54154 (1362) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6]  1 */
        7817, /* 54155 (1362) [ 0, -1,  0,  1, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34146806, /* 54156 (1362) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    34015424, /* 54157 (1362) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    34135547, /* 54158 (1362) [-1,  1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  6] -1 */
       16484, /* 54159 (1363) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
        7815, /* 54160 (1363) [ 0, -1,  0,  1, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
        5225, /* 54161 (1363) [-1,  1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  0]  1 */
        7817, /* 54162 (1363) [ 0, -1,  0,  1, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
        5223, /* 54163 (1363) [-1,  1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  0]  1 */
       16482, /* 54164 (1363) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
       16484, /* 54165 (1364) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34017449, /* 54166 (1364) [-1,  1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  0] -1 */
        7815, /* 54167 (1364) [ 0, -1,  0,  1, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    34020041, /* 54168 (1364) [ 0, -1,  0,  1, -1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    34017447, /* 54169 (1364) [-1,  1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  0] -1 */
        5225, /* 54170 (1364) [-1,  1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34028706, /* 54171 (1364) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    34020039, /* 54172 (1364) [ 0, -1,  0,  1, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
        7817, /* 54173 (1364) [ 0, -1,  0,  1, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
        5223, /* 54174 (1364) [-1,  1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    34028708, /* 54175 (1364) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
       16482, /* 54176 (1364) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
       16484, /* 54177 (1365) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34017447, /* 54178 (1365) [-1,  1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    34028706, /* 54179 (1365) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
        5225, /* 54180 (1365) [-1,  1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  0]  1 */
        7817, /* 54181 (1365) [ 0, -1,  0,  1, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34020039, /* 54182 (1365) [ 0, -1,  0,  1, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
       16484, /* 54183 (1366) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
        7815, /* 54184 (1366) [ 0, -1,  0,  1, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    34138139, /* 54185 (1366) [ 0, -1,  0,  1, -1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    34138137, /* 54186 (1366) [ 0, -1,  0,  1, -1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
        5225, /* 54187 (1366) [-1,  1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  0]  1 */
        7817, /* 54188 (1366) [ 0, -1,  0,  1, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34146806, /* 54189 (1366) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
        5223, /* 54190 (1366) [-1,  1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    34135545, /* 54191 (1366) [-1,  1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  6] -1 */
    34146804, /* 54192 (1366) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
    34135547, /* 54193 (1366) [-1,  1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  6] -1 */
       16482, /* 54194 (1366) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
       16484, /* 54195 (1367) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
        7815, /* 54196 (1367) [ 0, -1,  0,  1, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
        3200, /* 54197 (1367) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
       14457, /* 54198 (1367) [ 1, -1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  0]  1 */
        5225, /* 54199 (1367) [-1,  1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  0]  1 */
        7817, /* 54200 (1367) [ 0, -1,  0,  1, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
        3198, /* 54201 (1367) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
        5223, /* 54202 (1367) [-1,  1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  0]  1 */
       14459, /* 54203 (1367) [ 1, -1,  0,  1,  0,  0,  0,  0,  1] [ 0,  0,  0]  1 */
       11867, /* 54204 (1367) [ 0,  1,  0, -1,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
       16482, /* 54205 (1367) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
       11865, /* 54206 (1367) [ 0,  1,  0, -1,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
       16484, /* 54207 (1368) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34026683, /* 54208 (1368) [ 1, -1,  0,  1,  0,  0,  0,  0,  1] [ 0,  0,  0] -1 */
        3198, /* 54209 (1368) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    34020039, /* 54210 (1368) [ 0, -1,  0,  1, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    34017449, /* 54211 (1368) [-1,  1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    34026681, /* 54212 (1368) [ 1, -1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    34024091, /* 54213 (1368) [ 0,  1,  0, -1,  1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    34020041, /* 54214 (1368) [ 0, -1,  0,  1, -1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
       14459, /* 54215 (1368) [ 1, -1,  0,  1,  0,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34015424, /* 54216 (1368) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    34028708, /* 54217 (1368) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
        7815, /* 54218 (1368) [ 0, -1,  0,  1, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
       14457, /* 54219 (1368) [ 1, -1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    34017447, /* 54220 (1368) [-1,  1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  0] -1 */
        5225, /* 54221 (1368) [-1,  1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34028706, /* 54222 (1368) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
        7817, /* 54223 (1368) [ 0, -1,  0,  1, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34024089, /* 54224 (1368) [ 0,  1,  0, -1,  1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
       11867, /* 54225 (1368) [ 0,  1,  0, -1,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34015422, /* 54226 (1368) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
        3200, /* 54227 (1368) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
        5223, /* 54228 (1368) [-1,  1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  0]  1 */
       16482, /* 54229 (1368) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
       11865, /* 54230 (1368) [ 0,  1,  0, -1,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
       16484, /* 54231 (1369) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34026681, /* 54232 (1369) [ 1, -1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  0] -1 */
        7815, /* 54233 (1369) [ 0, -1,  0,  1, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    34015422, /* 54234 (1369) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    34026683, /* 54235 (1369) [ 1, -1,  0,  1,  0,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    34024091, /* 54236 (1369) [ 0,  1,  0, -1,  1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
        5225, /* 54237 (1369) [-1,  1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  0]  1 */
        7817, /* 54238 (1369) [ 0, -1,  0,  1, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
        5223, /* 54239 (1369) [-1,  1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    34024089, /* 54240 (1369) [ 0,  1,  0, -1,  1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    34015424, /* 54241 (1369) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
       16482, /* 54242 (1369) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
       16484, /* 54243 (1370) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34026681, /* 54244 (1370) [ 1, -1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    34015422, /* 54245 (1370) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
        3200, /* 54246 (1370) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34017447, /* 54247 (1370) [-1,  1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  0] -1 */
        5225, /* 54248 (1370) [-1,  1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34028706, /* 54249 (1370) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
        7817, /* 54250 (1370) [ 0, -1,  0,  1, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
       14459, /* 54251 (1370) [ 1, -1,  0,  1,  0,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34024089, /* 54252 (1370) [ 0,  1,  0, -1,  1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
       11867, /* 54253 (1370) [ 0,  1,  0, -1,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34020039, /* 54254 (1370) [ 0, -1,  0,  1, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
       16484, /* 54255 (1371) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34026683, /* 54256 (1371) [ 1, -1,  0,  1,  0,  0,  0,  0,  1] [ 0,  0,  0] -1 */
       14457, /* 54257 (1371) [ 1, -1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    34024091, /* 54258 (1371) [ 0,  1,  0, -1,  1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    34017447, /* 54259 (1371) [-1,  1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    34028706, /* 54260 (1371) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
        5225, /* 54261 (1371) [-1,  1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  0]  1 */
        7817, /* 54262 (1371) [ 0, -1,  0,  1, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
        3198, /* 54263 (1371) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    34015424, /* 54264 (1371) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    34020039, /* 54265 (1371) [ 0, -1,  0,  1, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
       11865, /* 54266 (1371) [ 0,  1,  0, -1,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
       16484, /* 54267 (1372) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34144781, /* 54268 (1372) [ 1, -1,  0,  1,  0,  0,  0,  0,  1] [ 0,  0,  6] -1 */
        3198, /* 54269 (1372) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    34135547, /* 54270 (1372) [-1,  1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    34138139, /* 54271 (1372) [ 0, -1,  0,  1, -1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    34138137, /* 54272 (1372) [ 0, -1,  0,  1, -1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
    34144779, /* 54273 (1372) [ 1, -1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  6] -1 */
    34146806, /* 54274 (1372) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
       14459, /* 54275 (1372) [ 1, -1,  0,  1,  0,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34142189, /* 54276 (1372) [ 0,  1,  0, -1,  1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    34133522, /* 54277 (1372) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
        7815, /* 54278 (1372) [ 0, -1,  0,  1, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
       14457, /* 54279 (1372) [ 1, -1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  0]  1 */
        5225, /* 54280 (1372) [-1,  1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34142187, /* 54281 (1372) [ 0,  1,  0, -1,  1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
        7817, /* 54282 (1372) [ 0, -1,  0,  1, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
       11867, /* 54283 (1372) [ 0,  1,  0, -1,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34135545, /* 54284 (1372) [-1,  1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  6] -1 */
    34146804, /* 54285 (1372) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
        3200, /* 54286 (1372) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34133520, /* 54287 (1372) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
        5223, /* 54288 (1372) [-1,  1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  0]  1 */
       16482, /* 54289 (1372) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
       11865, /* 54290 (1372) [ 0,  1,  0, -1,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
       16484, /* 54291 (1373) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
      129965, /* 54292 (1373) [ 0,  1,  0, -1,  1,  0,  0,  0,  1] [ 0,  0,  6]  1 */
      134580, /* 54293 (1373) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  6]  1 */
       14457, /* 54294 (1373) [ 1, -1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  0]  1 */
        5225, /* 54295 (1373) [-1,  1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  0]  1 */
      132557, /* 54296 (1373) [ 1, -1,  0,  1,  0,  0,  0,  0,  1] [ 0,  0,  6]  1 */
      125913, /* 54297 (1373) [ 0, -1,  0,  1, -1,  0,  0,  0, -1] [ 0,  0,  6]  1 */
      121298, /* 54298 (1373) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6]  1 */
        3198, /* 54299 (1373) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
        7817, /* 54300 (1373) [ 0, -1,  0,  1, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
       11865, /* 54301 (1373) [ 0,  1,  0, -1,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
      123321, /* 54302 (1373) [-1,  1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  6]  1 */
       16484, /* 54303 (1374) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34144781, /* 54304 (1374) [ 1, -1,  0,  1,  0,  0,  0,  0,  1] [ 0,  0,  6] -1 */
      134580, /* 54305 (1374) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  6]  1 */
        3198, /* 54306 (1374) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    34017449, /* 54307 (1374) [-1,  1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    34026681, /* 54308 (1374) [ 1, -1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    34138137, /* 54309 (1374) [ 0, -1,  0,  1, -1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
    34020041, /* 54310 (1374) [ 0, -1,  0,  1, -1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
      132557, /* 54311 (1374) [ 1, -1,  0,  1,  0,  0,  0,  0,  1] [ 0,  0,  6]  1 */
    34142189, /* 54312 (1374) [ 0,  1,  0, -1,  1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    34028708, /* 54313 (1374) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    34133522, /* 54314 (1374) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
       14457, /* 54315 (1374) [ 1, -1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  0]  1 */
        5225, /* 54316 (1374) [-1,  1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  0]  1 */
      125913, /* 54317 (1374) [ 0, -1,  0,  1, -1,  0,  0,  0, -1] [ 0,  0,  6]  1 */
        7817, /* 54318 (1374) [ 0, -1,  0,  1, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34024089, /* 54319 (1374) [ 0,  1,  0, -1,  1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    34135545, /* 54320 (1374) [-1,  1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  6] -1 */
    34146804, /* 54321 (1374) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
      129965, /* 54322 (1374) [ 0,  1,  0, -1,  1,  0,  0,  0,  1] [ 0,  0,  6]  1 */
    34015422, /* 54323 (1374) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
      121298, /* 54324 (1374) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6]  1 */
       11865, /* 54325 (1374) [ 0,  1,  0, -1,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
      123321, /* 54326 (1374) [-1,  1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  6]  1 */
       16484, /* 54327 (1375) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34144781, /* 54328 (1375) [ 1, -1,  0,  1,  0,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    34133522, /* 54329 (1375) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    34015422, /* 54330 (1375) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    34026681, /* 54331 (1375) [ 1, -1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  0] -1 */
      134580, /* 54332 (1375) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  6]  1 */
        5225, /* 54333 (1375) [-1,  1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  0]  1 */
      125913, /* 54334 (1375) [ 0, -1,  0,  1, -1,  0,  0,  0, -1] [ 0,  0,  6]  1 */
        7817, /* 54335 (1375) [ 0, -1,  0,  1, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34142189, /* 54336 (1375) [ 0,  1,  0, -1,  1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    34024089, /* 54337 (1375) [ 0,  1,  0, -1,  1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
      123321, /* 54338 (1375) [-1,  1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  6]  1 */
       16484, /* 54339 (1376) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34026681, /* 54340 (1376) [ 1, -1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  0] -1 */
      129965, /* 54341 (1376) [ 0,  1,  0, -1,  1,  0,  0,  0,  1] [ 0,  0,  6]  1 */
    34015422, /* 54342 (1376) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    34138137, /* 54343 (1376) [ 0, -1,  0,  1, -1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
        5225, /* 54344 (1376) [-1,  1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  0]  1 */
      132557, /* 54345 (1376) [ 1, -1,  0,  1,  0,  0,  0,  0,  1] [ 0,  0,  6]  1 */
      121298, /* 54346 (1376) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6]  1 */
        7817, /* 54347 (1376) [ 0, -1,  0,  1, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34024089, /* 54348 (1376) [ 0,  1,  0, -1,  1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    34135545, /* 54349 (1376) [-1,  1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  6] -1 */
    34146804, /* 54350 (1376) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
       16484, /* 54351 (1377) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34144781, /* 54352 (1377) [ 1, -1,  0,  1,  0,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    34133522, /* 54353 (1377) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    34138137, /* 54354 (1377) [ 0, -1,  0,  1, -1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
       14457, /* 54355 (1377) [ 1, -1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  0]  1 */
        5225, /* 54356 (1377) [-1,  1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  0]  1 */
        3198, /* 54357 (1377) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
        7817, /* 54358 (1377) [ 0, -1,  0,  1, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34142189, /* 54359 (1377) [ 0,  1,  0, -1,  1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    34135545, /* 54360 (1377) [-1,  1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  6] -1 */
    34146804, /* 54361 (1377) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
       11865, /* 54362 (1377) [ 0,  1,  0, -1,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
       16484, /* 54363 (1378) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34026683, /* 54364 (1378) [ 1, -1,  0,  1,  0,  0,  0,  0,  1] [ 0,  0,  0] -1 */
      134580, /* 54365 (1378) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  6]  1 */
        3198, /* 54366 (1378) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    34135547, /* 54367 (1378) [-1,  1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    34020039, /* 54368 (1378) [ 0, -1,  0,  1, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    34138139, /* 54369 (1378) [ 0, -1,  0,  1, -1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    34024091, /* 54370 (1378) [ 0,  1,  0, -1,  1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    34144779, /* 54371 (1378) [ 1, -1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  6] -1 */
      132557, /* 54372 (1378) [ 1, -1,  0,  1,  0,  0,  0,  0,  1] [ 0,  0,  6]  1 */
    34146806, /* 54373 (1378) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    34015424, /* 54374 (1378) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
       14457, /* 54375 (1378) [ 1, -1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    34017447, /* 54376 (1378) [-1,  1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  0] -1 */
        5225, /* 54377 (1378) [-1,  1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34028706, /* 54378 (1378) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    34142187, /* 54379 (1378) [ 0,  1,  0, -1,  1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
      125913, /* 54380 (1378) [ 0, -1,  0,  1, -1,  0,  0,  0, -1] [ 0,  0,  6]  1 */
        7817, /* 54381 (1378) [ 0, -1,  0,  1, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
      129965, /* 54382 (1378) [ 0,  1,  0, -1,  1,  0,  0,  0,  1] [ 0,  0,  6]  1 */
    34133520, /* 54383 (1378) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
      121298, /* 54384 (1378) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6]  1 */
       11865, /* 54385 (1378) [ 0,  1,  0, -1,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
      123321, /* 54386 (1378) [-1,  1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  6]  1 */
       16484, /* 54387 (1379) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
        3200, /* 54388 (1379) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
       16563, /* 54389 (1379) [ 1,  0,  0,  1, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
        3117, /* 54390 (1379) [-1,  0,  0, -1,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
        7410, /* 54391 (1379) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  0]  1 */
        5225, /* 54392 (1379) [-1,  1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  0]  1 */
       12270, /* 54393 (1379) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  0]  1 */
        7817, /* 54394 (1379) [ 0, -1,  0,  1, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
       14133, /* 54395 (1379) [ 1, -1,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
       14459, /* 54396 (1379) [ 1, -1,  0,  1,  0,  0,  0,  0,  1] [ 0,  0,  0]  1 */
       11867, /* 54397 (1379) [ 0,  1,  0, -1,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
        5547, /* 54398 (1379) [-1,  1,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
       16484, /* 54399 (1380) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34026683, /* 54400 (1380) [ 1, -1,  0,  1,  0,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    34019634, /* 54401 (1380) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  0] -1 */
       16563, /* 54402 (1380) [ 1,  0,  0,  1, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    34017771, /* 54403 (1380) [-1,  1,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
       12270, /* 54404 (1380) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    34017449, /* 54405 (1380) [-1,  1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    34024091, /* 54406 (1380) [ 0,  1,  0, -1,  1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    34020041, /* 54407 (1380) [ 0, -1,  0,  1, -1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
        7410, /* 54408 (1380) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  0]  1 */
       14459, /* 54409 (1380) [ 1, -1,  0,  1,  0,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34015424, /* 54410 (1380) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
        5547, /* 54411 (1380) [-1,  1,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    34028708, /* 54412 (1380) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    34015341, /* 54413 (1380) [-1,  0,  0, -1,  1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    34026357, /* 54414 (1380) [ 1, -1,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
        5225, /* 54415 (1380) [-1,  1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  0]  1 */
        7817, /* 54416 (1380) [ 0, -1,  0,  1, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
       11867, /* 54417 (1380) [ 0,  1,  0, -1,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34028787, /* 54418 (1380) [ 1,  0,  0,  1, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
        3200, /* 54419 (1380) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34024494, /* 54420 (1380) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  0] -1 */
        3117, /* 54421 (1380) [-1,  0,  0, -1,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
       14133, /* 54422 (1380) [ 1, -1,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
       16484, /* 54423 (1381) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34015341, /* 54424 (1381) [-1,  0,  0, -1,  1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    34026683, /* 54425 (1381) [ 1, -1,  0,  1,  0,  0,  0,  0,  1] [ 0,  0,  0] -1 */
       16563, /* 54426 (1381) [ 1,  0,  0,  1, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    34024494, /* 54427 (1381) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    34024091, /* 54428 (1381) [ 0,  1,  0, -1,  1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    34026357, /* 54429 (1381) [ 1, -1,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
        7410, /* 54430 (1381) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  0]  1 */
        5225, /* 54431 (1381) [-1,  1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  0]  1 */
        7817, /* 54432 (1381) [ 0, -1,  0,  1, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34015424, /* 54433 (1381) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
        5547, /* 54434 (1381) [-1,  1,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
       16484, /* 54435 (1382) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34028787, /* 54436 (1382) [ 1,  0,  0,  1, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    34019634, /* 54437 (1382) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    34026683, /* 54438 (1382) [ 1, -1,  0,  1,  0,  0,  0,  0,  1] [ 0,  0,  0] -1 */
        3117, /* 54439 (1382) [-1,  0,  0, -1,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    34024091, /* 54440 (1382) [ 0,  1,  0, -1,  1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    34017771, /* 54441 (1382) [-1,  1,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
        5225, /* 54442 (1382) [-1,  1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  0]  1 */
       12270, /* 54443 (1382) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  0]  1 */
        7817, /* 54444 (1382) [ 0, -1,  0,  1, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
       14133, /* 54445 (1382) [ 1, -1,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    34015424, /* 54446 (1382) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
       16484, /* 54447 (1383) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34028787, /* 54448 (1383) [ 1,  0,  0,  1, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    34015341, /* 54449 (1383) [-1,  0,  0, -1,  1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
        3200, /* 54450 (1383) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34019634, /* 54451 (1383) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    34024494, /* 54452 (1383) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    34017771, /* 54453 (1383) [-1,  1,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    34026357, /* 54454 (1383) [ 1, -1,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
        5225, /* 54455 (1383) [-1,  1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  0]  1 */
        7817, /* 54456 (1383) [ 0, -1,  0,  1, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
       14459, /* 54457 (1383) [ 1, -1,  0,  1,  0,  0,  0,  0,  1] [ 0,  0,  0]  1 */
       11867, /* 54458 (1383) [ 0,  1,  0, -1,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
       16484, /* 54459 (1384) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34144781, /* 54460 (1384) [ 1, -1,  0,  1,  0,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    34137732, /* 54461 (1384) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  6] -1 */
    34135869, /* 54462 (1384) [-1,  1,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
       16563, /* 54463 (1384) [ 1,  0,  0,  1, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
       12270, /* 54464 (1384) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    34135547, /* 54465 (1384) [-1,  1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    34138139, /* 54466 (1384) [ 0, -1,  0,  1, -1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
        7410, /* 54467 (1384) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    34146806, /* 54468 (1384) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
       14459, /* 54469 (1384) [ 1, -1,  0,  1,  0,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34142189, /* 54470 (1384) [ 0,  1,  0, -1,  1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
        5547, /* 54471 (1384) [-1,  1,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    34133439, /* 54472 (1384) [-1,  0,  0, -1,  1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
    34133522, /* 54473 (1384) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    34144455, /* 54474 (1384) [ 1, -1,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
        5225, /* 54475 (1384) [-1,  1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  0]  1 */
        7817, /* 54476 (1384) [ 0, -1,  0,  1, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
       11867, /* 54477 (1384) [ 0,  1,  0, -1,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34142592, /* 54478 (1384) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  6] -1 */
        3200, /* 54479 (1384) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
        3117, /* 54480 (1384) [-1,  0,  0, -1,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    34146885, /* 54481 (1384) [ 1,  0,  0,  1, -1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
       14133, /* 54482 (1384) [ 1, -1,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
       16484, /* 54483 (1385) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
      208697, /* 54484 (1385) [ 0,  1,  0, -1,  1,  0,  0,  0,  1] [ 0,  0, 10]  1 */
      162689, /* 54485 (1385) [-1,  1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  8]  1 */
       86549, /* 54486 (1385) [ 0, -1,  0,  1, -1,  0,  0,  0,  1] [ 0,  0,  4]  1 */
       53825, /* 54487 (1385) [ 1, -1,  0,  1,  0,  0,  0,  0,  1] [ 0,  0,  2]  1 */
      160581, /* 54488 (1385) [-1,  0,  0, -1,  1,  0,  0,  0, -1] [ 0,  0,  8]  1 */
      121298, /* 54489 (1385) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6]  1 */
       55929, /* 54490 (1385) [ 1,  0,  0,  1, -1,  0,  0,  0, -1] [ 0,  0,  2]  1 */
      123645, /* 54491 (1385) [-1,  1,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  6]  1 */
       14133, /* 54492 (1385) [ 1, -1,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
      204240, /* 54493 (1385) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0, 10]  1 */
       91002, /* 54494 (1385) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  4]  1 */
       16484, /* 54495 (1386) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34066049, /* 54496 (1386) [ 1, -1,  0,  1,  0,  0,  0,  0,  1] [ 0,  0,  2] -1 */
    34172805, /* 54497 (1386) [-1,  0,  0, -1,  1,  0,  0,  0, -1] [ 0,  0,  8] -1 */
    34135869, /* 54498 (1386) [-1,  1,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
    34220921, /* 54499 (1386) [ 0,  1,  0, -1,  1,  0,  0,  0,  1] [ 0,  0, 10] -1 */
       55929, /* 54500 (1386) [ 1,  0,  0,  1, -1,  0,  0,  0, -1] [ 0,  0,  2]  1 */
      204240, /* 54501 (1386) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0, 10]  1 */
      162689, /* 54502 (1386) [-1,  1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  8]  1 */
       86549, /* 54503 (1386) [ 0, -1,  0,  1, -1,  0,  0,  0,  1] [ 0,  0,  4]  1 */
       53825, /* 54504 (1386) [ 1, -1,  0,  1,  0,  0,  0,  0,  1] [ 0,  0,  2]  1 */
      160581, /* 54505 (1386) [-1,  0,  0, -1,  1,  0,  0,  0, -1] [ 0,  0,  8]  1 */
      123645, /* 54506 (1386) [-1,  1,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  6]  1 */
    34028708, /* 54507 (1386) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
      208697, /* 54508 (1386) [ 0,  1,  0, -1,  1,  0,  0,  0,  1] [ 0,  0, 10]  1 */
    34133522, /* 54509 (1386) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    34103226, /* 54510 (1386) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  4] -1 */
    34026357, /* 54511 (1386) [ 1, -1,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    34068153, /* 54512 (1386) [ 1,  0,  0,  1, -1,  0,  0,  0, -1] [ 0,  0,  2] -1 */
    34216464, /* 54513 (1386) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0, 10] -1 */
      121298, /* 54514 (1386) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6]  1 */
    34174913, /* 54515 (1386) [-1,  1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  8] -1 */
       91002, /* 54516 (1386) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  4]  1 */
       14133, /* 54517 (1386) [ 1, -1,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    34098773, /* 54518 (1386) [ 0, -1,  0,  1, -1,  0,  0,  0,  1] [ 0,  0,  4] -1 */
       16484, /* 54519 (1387) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34066049, /* 54520 (1387) [ 1, -1,  0,  1,  0,  0,  0,  0,  1] [ 0,  0,  2] -1 */
    34172805, /* 54521 (1387) [-1,  0,  0, -1,  1,  0,  0,  0, -1] [ 0,  0,  8] -1 */
    34133522, /* 54522 (1387) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
       86549, /* 54523 (1387) [ 0, -1,  0,  1, -1,  0,  0,  0,  1] [ 0,  0,  4]  1 */
      162689, /* 54524 (1387) [-1,  1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  8]  1 */
    34103226, /* 54525 (1387) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  4] -1 */
    34026357, /* 54526 (1387) [ 1, -1,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    34220921, /* 54527 (1387) [ 0,  1,  0, -1,  1,  0,  0,  0,  1] [ 0,  0, 10] -1 */
       55929, /* 54528 (1387) [ 1,  0,  0,  1, -1,  0,  0,  0, -1] [ 0,  0,  2]  1 */
      123645, /* 54529 (1387) [-1,  1,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  6]  1 */
      204240, /* 54530 (1387) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0, 10]  1 */
       16484, /* 54531 (1388) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34066049, /* 54532 (1388) [ 1, -1,  0,  1,  0,  0,  0,  0,  1] [ 0,  0,  2] -1 */
    34133522, /* 54533 (1388) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
      162689, /* 54534 (1388) [-1,  1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  8]  1 */
       86549, /* 54535 (1388) [ 0, -1,  0,  1, -1,  0,  0,  0,  1] [ 0,  0,  4]  1 */
    34068153, /* 54536 (1388) [ 1,  0,  0,  1, -1,  0,  0,  0, -1] [ 0,  0,  2] -1 */
    34135869, /* 54537 (1388) [-1,  1,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
      160581, /* 54538 (1388) [-1,  0,  0, -1,  1,  0,  0,  0, -1] [ 0,  0,  8]  1 */
    34216464, /* 54539 (1388) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0, 10] -1 */
    34220921, /* 54540 (1388) [ 0,  1,  0, -1,  1,  0,  0,  0,  1] [ 0,  0, 10] -1 */
       91002, /* 54541 (1388) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  4]  1 */
       14133, /* 54542 (1388) [ 1, -1,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
       16484, /* 54543 (1389) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
      208697, /* 54544 (1389) [ 0,  1,  0, -1,  1,  0,  0,  0,  1] [ 0,  0, 10]  1 */
      162689, /* 54545 (1389) [-1,  1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  8]  1 */
    34172805, /* 54546 (1389) [-1,  0,  0, -1,  1,  0,  0,  0, -1] [ 0,  0,  8] -1 */
       86549, /* 54547 (1389) [ 0, -1,  0,  1, -1,  0,  0,  0,  1] [ 0,  0,  4]  1 */
    34068153, /* 54548 (1389) [ 1,  0,  0,  1, -1,  0,  0,  0, -1] [ 0,  0,  2] -1 */
    34135869, /* 54549 (1389) [-1,  1,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
       53825, /* 54550 (1389) [ 1, -1,  0,  1,  0,  0,  0,  0,  1] [ 0,  0,  2]  1 */
    34103226, /* 54551 (1389) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  4] -1 */
    34026357, /* 54552 (1389) [ 1, -1,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    34216464, /* 54553 (1389) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0, 10] -1 */
      121298, /* 54554 (1389) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6]  1 */
       16484, /* 54555 (1390) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34017771, /* 54556 (1390) [-1,  1,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    34102823, /* 54557 (1390) [ 0,  1,  0, -1,  1,  0,  0,  0,  1] [ 0,  0,  4] -1 */
       55929, /* 54558 (1390) [ 1,  0,  0,  1, -1,  0,  0,  0, -1] [ 0,  0,  2]  1 */
    34216871, /* 54559 (1390) [ 0, -1,  0,  1, -1,  0,  0,  0,  1] [ 0,  0, 10] -1 */
      204240, /* 54560 (1390) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0, 10]  1 */
    34186251, /* 54561 (1390) [ 1,  0,  0,  1, -1,  0,  0,  0, -1] [ 0,  0,  8] -1 */
      162689, /* 54562 (1390) [-1,  1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  8]  1 */
       86549, /* 54563 (1390) [ 0, -1,  0,  1, -1,  0,  0,  0,  1] [ 0,  0,  4]  1 */
       53825, /* 54564 (1390) [ 1, -1,  0,  1,  0,  0,  0,  0,  1] [ 0,  0,  2]  1 */
      160581, /* 54565 (1390) [-1,  0,  0, -1,  1,  0,  0,  0, -1] [ 0,  0,  8]  1 */
    34056815, /* 54566 (1390) [-1,  1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  2] -1 */
      123645, /* 54567 (1390) [-1,  1,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  6]  1 */
    34146806, /* 54568 (1390) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    34054707, /* 54569 (1390) [-1,  0,  0, -1,  1,  0,  0,  0, -1] [ 0,  0,  2] -1 */
    34015424, /* 54570 (1390) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    34221324, /* 54571 (1390) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0, 10] -1 */
      208697, /* 54572 (1390) [ 0,  1,  0, -1,  1,  0,  0,  0,  1] [ 0,  0, 10]  1 */
    34184147, /* 54573 (1390) [ 1, -1,  0,  1,  0,  0,  0,  0,  1] [ 0,  0,  8] -1 */
    34144455, /* 54574 (1390) [ 1, -1,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
    34098366, /* 54575 (1390) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  4] -1 */
      121298, /* 54576 (1390) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6]  1 */
       91002, /* 54577 (1390) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  4]  1 */
       14133, /* 54578 (1390) [ 1, -1,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
       16484, /* 54579 (1391) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
      169734, /* 54580 (1391) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  8]  1 */
       83957, /* 54581 (1391) [-1,  1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  4]  1 */
       81849, /* 54582 (1391) [-1,  0,  0, -1,  1,  0,  0,  0, -1] [ 0,  0,  4]  1 */
      213393, /* 54583 (1391) [ 1,  0,  0,  1, -1,  0,  0,  0, -1] [ 0,  0, 10]  1 */
      121298, /* 54584 (1391) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6]  1 */
      165281, /* 54585 (1391) [ 0, -1,  0,  1, -1,  0,  0,  0,  1] [ 0,  0,  8]  1 */
      123645, /* 54586 (1391) [-1,  1,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  6]  1 */
       14133, /* 54587 (1391) [ 1, -1,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
       51233, /* 54588 (1391) [ 0,  1,  0, -1,  1,  0,  0,  0,  1] [ 0,  0,  2]  1 */
       46776, /* 54589 (1391) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  2]  1 */
      211289, /* 54590 (1391) [ 1, -1,  0,  1,  0,  0,  0,  0,  1] [ 0,  0, 10]  1 */
       16484, /* 54591 (1392) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34135869, /* 54592 (1392) [-1,  1,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
    34096181, /* 54593 (1392) [-1,  1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  4] -1 */
      165281, /* 54594 (1392) [ 0, -1,  0,  1, -1,  0,  0,  0,  1] [ 0,  0,  8]  1 */
    34059000, /* 54595 (1392) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  2] -1 */
      211289, /* 54596 (1392) [ 1, -1,  0,  1,  0,  0,  0,  0,  1] [ 0,  0, 10]  1 */
    34094073, /* 54597 (1392) [-1,  0,  0, -1,  1,  0,  0,  0, -1] [ 0,  0,  4] -1 */
       83957, /* 54598 (1392) [-1,  1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  4]  1 */
      123645, /* 54599 (1392) [-1,  1,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  6]  1 */
    34028708, /* 54600 (1392) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
       46776, /* 54601 (1392) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  2]  1 */
    34181958, /* 54602 (1392) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  8] -1 */
    34133522, /* 54603 (1392) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    34225617, /* 54604 (1392) [ 1,  0,  0,  1, -1,  0,  0,  0, -1] [ 0,  0, 10] -1 */
    34063457, /* 54605 (1392) [ 0,  1,  0, -1,  1,  0,  0,  0,  1] [ 0,  0,  2] -1 */
       81849, /* 54606 (1392) [-1,  0,  0, -1,  1,  0,  0,  0, -1] [ 0,  0,  4]  1 */
    34026357, /* 54607 (1392) [ 1, -1,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
      169734, /* 54608 (1392) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  8]  1 */
    34177505, /* 54609 (1392) [ 0, -1,  0,  1, -1,  0,  0,  0,  1] [ 0,  0,  8] -1 */
    34223513, /* 54610 (1392) [ 1, -1,  0,  1,  0,  0,  0,  0,  1] [ 0,  0, 10] -1 */
      213393, /* 54611 (1392) [ 1,  0,  0,  1, -1,  0,  0,  0, -1] [ 0,  0, 10]  1 */
      121298, /* 54612 (1392) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6]  1 */
       14133, /* 54613 (1392) [ 1, -1,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
       51233, /* 54614 (1392) [ 0,  1,  0, -1,  1,  0,  0,  0,  1] [ 0,  0,  2]  1 */
       16484, /* 54615 (1393) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34133522, /* 54616 (1393) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    34094073, /* 54617 (1393) [-1,  0,  0, -1,  1,  0,  0,  0, -1] [ 0,  0,  4] -1 */
    34063457, /* 54618 (1393) [ 0,  1,  0, -1,  1,  0,  0,  0,  1] [ 0,  0,  2] -1 */
       83957, /* 54619 (1393) [-1,  1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  4]  1 */
    34026357, /* 54620 (1393) [ 1, -1,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    34223513, /* 54621 (1393) [ 1, -1,  0,  1,  0,  0,  0,  0,  1] [ 0,  0, 10] -1 */
      213393, /* 54622 (1393) [ 1,  0,  0,  1, -1,  0,  0,  0, -1] [ 0,  0, 10]  1 */
      165281, /* 54623 (1393) [ 0, -1,  0,  1, -1,  0,  0,  0,  1] [ 0,  0,  8]  1 */
      123645, /* 54624 (1393) [-1,  1,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  6]  1 */
    34181958, /* 54625 (1393) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  8] -1 */
       46776, /* 54626 (1393) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  2]  1 */
       16484, /* 54627 (1394) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
      169734, /* 54628 (1394) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  8]  1 */
    34133522, /* 54629 (1394) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    34135869, /* 54630 (1394) [-1,  1,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
    34225617, /* 54631 (1394) [ 1,  0,  0,  1, -1,  0,  0,  0, -1] [ 0,  0, 10] -1 */
    34063457, /* 54632 (1394) [ 0,  1,  0, -1,  1,  0,  0,  0,  1] [ 0,  0,  2] -1 */
       83957, /* 54633 (1394) [-1,  1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  4]  1 */
       81849, /* 54634 (1394) [-1,  0,  0, -1,  1,  0,  0,  0, -1] [ 0,  0,  4]  1 */
    34223513, /* 54635 (1394) [ 1, -1,  0,  1,  0,  0,  0,  0,  1] [ 0,  0, 10] -1 */
      165281, /* 54636 (1394) [ 0, -1,  0,  1, -1,  0,  0,  0,  1] [ 0,  0,  8]  1 */
    34059000, /* 54637 (1394) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  2] -1 */
       14133, /* 54638 (1394) [ 1, -1,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
       16484, /* 54639 (1395) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34135869, /* 54640 (1395) [-1,  1,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
    34094073, /* 54641 (1395) [-1,  0,  0, -1,  1,  0,  0,  0, -1] [ 0,  0,  4] -1 */
    34225617, /* 54642 (1395) [ 1,  0,  0,  1, -1,  0,  0,  0, -1] [ 0,  0, 10] -1 */
       83957, /* 54643 (1395) [-1,  1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  4]  1 */
    34026357, /* 54644 (1395) [ 1, -1,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
      121298, /* 54645 (1395) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6]  1 */
      165281, /* 54646 (1395) [ 0, -1,  0,  1, -1,  0,  0,  0,  1] [ 0,  0,  8]  1 */
    34059000, /* 54647 (1395) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  2] -1 */
       51233, /* 54648 (1395) [ 0,  1,  0, -1,  1,  0,  0,  0,  1] [ 0,  0,  2]  1 */
    34181958, /* 54649 (1395) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  8] -1 */
      211289, /* 54650 (1395) [ 1, -1,  0,  1,  0,  0,  0,  0,  1] [ 0,  0, 10]  1 */
       16484, /* 54651 (1396) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34214279, /* 54652 (1396) [-1,  1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0, 10] -1 */
    34017771, /* 54653 (1396) [-1,  1,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
      165281, /* 54654 (1396) [ 0, -1,  0,  1, -1,  0,  0,  0,  1] [ 0,  0,  8]  1 */
      211289, /* 54655 (1396) [ 1, -1,  0,  1,  0,  0,  0,  0,  1] [ 0,  0, 10]  1 */
    34212171, /* 54656 (1396) [-1,  0,  0, -1,  1,  0,  0,  0, -1] [ 0,  0, 10] -1 */
       83957, /* 54657 (1396) [-1,  1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  4]  1 */
    34059407, /* 54658 (1396) [ 0, -1,  0,  1, -1,  0,  0,  0,  1] [ 0,  0,  2] -1 */
      123645, /* 54659 (1396) [-1,  1,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  6]  1 */
    34146806, /* 54660 (1396) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    34015424, /* 54661 (1396) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
       46776, /* 54662 (1396) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  2]  1 */
    34107519, /* 54663 (1396) [ 1,  0,  0,  1, -1,  0,  0,  0, -1] [ 0,  0,  4] -1 */
    34177098, /* 54664 (1396) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  8] -1 */
    34144455, /* 54665 (1396) [ 1, -1,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
       81849, /* 54666 (1396) [-1,  0,  0, -1,  1,  0,  0,  0, -1] [ 0,  0,  4]  1 */
      169734, /* 54667 (1396) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  8]  1 */
    34105415, /* 54668 (1396) [ 1, -1,  0,  1,  0,  0,  0,  0,  1] [ 0,  0,  4] -1 */
    34181555, /* 54669 (1396) [ 0,  1,  0, -1,  1,  0,  0,  0,  1] [ 0,  0,  8] -1 */
      213393, /* 54670 (1396) [ 1,  0,  0,  1, -1,  0,  0,  0, -1] [ 0,  0, 10]  1 */
      121298, /* 54671 (1396) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6]  1 */
       14133, /* 54672 (1396) [ 1, -1,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
       51233, /* 54673 (1396) [ 0,  1,  0, -1,  1,  0,  0,  0,  1] [ 0,  0,  2]  1 */
    34063860, /* 54674 (1396) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  2] -1 */
       16484, /* 54675 (1397) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
      169734, /* 54676 (1397) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  8]  1 */
        3200, /* 54677 (1397) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
       95295, /* 54678 (1397) [ 1,  0,  0,  1, -1,  0,  0,  0, -1] [ 0,  0,  4]  1 */
       83957, /* 54679 (1397) [-1,  1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  4]  1 */
       81849, /* 54680 (1397) [-1,  0,  0, -1,  1,  0,  0,  0, -1] [ 0,  0,  4]  1 */
      164874, /* 54681 (1397) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  8]  1 */
      169331, /* 54682 (1397) [ 0,  1,  0, -1,  1,  0,  0,  0,  1] [ 0,  0,  8]  1 */
      165281, /* 54683 (1397) [ 0, -1,  0,  1, -1,  0,  0,  0,  1] [ 0,  0,  8]  1 */
       14133, /* 54684 (1397) [ 1, -1,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
       93191, /* 54685 (1397) [ 1, -1,  0,  1,  0,  0,  0,  0,  1] [ 0,  0,  4]  1 */
        5547, /* 54686 (1397) [-1,  1,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
       16484, /* 54687 (1398) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34096181, /* 54688 (1398) [-1,  1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  4] -1 */
    34017771, /* 54689 (1398) [-1,  1,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
      169331, /* 54690 (1398) [ 0,  1,  0, -1,  1,  0,  0,  0,  1] [ 0,  0,  8]  1 */
      165281, /* 54691 (1398) [ 0, -1,  0,  1, -1,  0,  0,  0,  1] [ 0,  0,  8]  1 */
       93191, /* 54692 (1398) [ 1, -1,  0,  1,  0,  0,  0,  0,  1] [ 0,  0,  4]  1 */
    34094073, /* 54693 (1398) [-1,  0,  0, -1,  1,  0,  0,  0, -1] [ 0,  0,  4] -1 */
       83957, /* 54694 (1398) [-1,  1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  4]  1 */
    34015424, /* 54695 (1398) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
        5547, /* 54696 (1398) [-1,  1,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    34028708, /* 54697 (1398) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    34181958, /* 54698 (1398) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  8] -1 */
    34107519, /* 54699 (1398) [ 1,  0,  0,  1, -1,  0,  0,  0, -1] [ 0,  0,  4] -1 */
    34177098, /* 54700 (1398) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  8] -1 */
       81849, /* 54701 (1398) [-1,  0,  0, -1,  1,  0,  0,  0, -1] [ 0,  0,  4]  1 */
    34026357, /* 54702 (1398) [ 1, -1,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
      169734, /* 54703 (1398) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  8]  1 */
    34177505, /* 54704 (1398) [ 0, -1,  0,  1, -1,  0,  0,  0,  1] [ 0,  0,  8] -1 */
        3200, /* 54705 (1398) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34105415, /* 54706 (1398) [ 1, -1,  0,  1,  0,  0,  0,  0,  1] [ 0,  0,  4] -1 */
       95295, /* 54707 (1398) [ 1,  0,  0,  1, -1,  0,  0,  0, -1] [ 0,  0,  4]  1 */
    34181555, /* 54708 (1398) [ 0,  1,  0, -1,  1,  0,  0,  0,  1] [ 0,  0,  8] -1 */
      164874, /* 54709 (1398) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  8]  1 */
       14133, /* 54710 (1398) [ 1, -1,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
       16484, /* 54711 (1399) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34094073, /* 54712 (1399) [-1,  0,  0, -1,  1,  0,  0,  0, -1] [ 0,  0,  4] -1 */
    34105415, /* 54713 (1399) [ 1, -1,  0,  1,  0,  0,  0,  0,  1] [ 0,  0,  4] -1 */
       95295, /* 54714 (1399) [ 1,  0,  0,  1, -1,  0,  0,  0, -1] [ 0,  0,  4]  1 */
    34181555, /* 54715 (1399) [ 0,  1,  0, -1,  1,  0,  0,  0,  1] [ 0,  0,  8] -1 */
    34026357, /* 54716 (1399) [ 1, -1,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
      164874, /* 54717 (1399) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  8]  1 */
       83957, /* 54718 (1399) [-1,  1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  4]  1 */
      165281, /* 54719 (1399) [ 0, -1,  0,  1, -1,  0,  0,  0,  1] [ 0,  0,  8]  1 */
    34015424, /* 54720 (1399) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
        5547, /* 54721 (1399) [-1,  1,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    34181958, /* 54722 (1399) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  8] -1 */
       16484, /* 54723 (1400) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
      169734, /* 54724 (1400) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  8]  1 */
    34107519, /* 54725 (1400) [ 1,  0,  0,  1, -1,  0,  0,  0, -1] [ 0,  0,  4] -1 */
    34177098, /* 54726 (1400) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  8] -1 */
    34105415, /* 54727 (1400) [ 1, -1,  0,  1,  0,  0,  0,  0,  1] [ 0,  0,  4] -1 */
    34017771, /* 54728 (1400) [-1,  1,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
       81849, /* 54729 (1400) [-1,  0,  0, -1,  1,  0,  0,  0, -1] [ 0,  0,  4]  1 */
    34181555, /* 54730 (1400) [ 0,  1,  0, -1,  1,  0,  0,  0,  1] [ 0,  0,  8] -1 */
       83957, /* 54731 (1400) [-1,  1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  4]  1 */
      165281, /* 54732 (1400) [ 0, -1,  0,  1, -1,  0,  0,  0,  1] [ 0,  0,  8]  1 */
       14133, /* 54733 (1400) [ 1, -1,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    34015424, /* 54734 (1400) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
       16484, /* 54735 (1401) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34107519, /* 54736 (1401) [ 1,  0,  0,  1, -1,  0,  0,  0, -1] [ 0,  0,  4] -1 */
    34094073, /* 54737 (1401) [-1,  0,  0, -1,  1,  0,  0,  0, -1] [ 0,  0,  4] -1 */
        3200, /* 54738 (1401) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34177098, /* 54739 (1401) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  8] -1 */
    34017771, /* 54740 (1401) [-1,  1,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
       83957, /* 54741 (1401) [-1,  1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  4]  1 */
    34026357, /* 54742 (1401) [ 1, -1,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
      169331, /* 54743 (1401) [ 0,  1,  0, -1,  1,  0,  0,  0,  1] [ 0,  0,  8]  1 */
      165281, /* 54744 (1401) [ 0, -1,  0,  1, -1,  0,  0,  0,  1] [ 0,  0,  8]  1 */
       93191, /* 54745 (1401) [ 1, -1,  0,  1,  0,  0,  0,  0,  1] [ 0,  0,  4]  1 */
    34181958, /* 54746 (1401) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  8] -1 */
       16484, /* 54747 (1402) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34135869, /* 54748 (1402) [-1,  1,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
    34214279, /* 54749 (1402) [-1,  1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0, 10] -1 */
      169331, /* 54750 (1402) [ 0,  1,  0, -1,  1,  0,  0,  0,  1] [ 0,  0,  8]  1 */
      165281, /* 54751 (1402) [ 0, -1,  0,  1, -1,  0,  0,  0,  1] [ 0,  0,  8]  1 */
    34059000, /* 54752 (1402) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  2] -1 */
       93191, /* 54753 (1402) [ 1, -1,  0,  1,  0,  0,  0,  0,  1] [ 0,  0,  4]  1 */
    34212171, /* 54754 (1402) [-1,  0,  0, -1,  1,  0,  0,  0, -1] [ 0,  0, 10] -1 */
       83957, /* 54755 (1402) [-1,  1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  4]  1 */
    34059407, /* 54756 (1402) [ 0, -1,  0,  1, -1,  0,  0,  0,  1] [ 0,  0,  2] -1 */
    34146806, /* 54757 (1402) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
        5547, /* 54758 (1402) [-1,  1,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    34133522, /* 54759 (1402) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    34144455, /* 54760 (1402) [ 1, -1,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
    34225617, /* 54761 (1402) [ 1,  0,  0,  1, -1,  0,  0,  0, -1] [ 0,  0, 10] -1 */
    34063457, /* 54762 (1402) [ 0,  1,  0, -1,  1,  0,  0,  0,  1] [ 0,  0,  2] -1 */
       81849, /* 54763 (1402) [-1,  0,  0, -1,  1,  0,  0,  0, -1] [ 0,  0,  4]  1 */
      169734, /* 54764 (1402) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  8]  1 */
        3200, /* 54765 (1402) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
       95295, /* 54766 (1402) [ 1,  0,  0,  1, -1,  0,  0,  0, -1] [ 0,  0,  4]  1 */
      164874, /* 54767 (1402) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  8]  1 */
    34223513, /* 54768 (1402) [ 1, -1,  0,  1,  0,  0,  0,  0,  1] [ 0,  0, 10] -1 */
       14133, /* 54769 (1402) [ 1, -1,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    34063860, /* 54770 (1402) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  2] -1 */
       16484, /* 54771 (1403) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
      162689, /* 54772 (1403) [-1,  1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  8]  1 */
       86549, /* 54773 (1403) [ 0, -1,  0,  1, -1,  0,  0,  0,  1] [ 0,  0,  4]  1 */
        3200, /* 54774 (1403) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
      174027, /* 54775 (1403) [ 1,  0,  0,  1, -1,  0,  0,  0, -1] [ 0,  0,  8]  1 */
      160581, /* 54776 (1403) [-1,  0,  0, -1,  1,  0,  0,  0, -1] [ 0,  0,  8]  1 */
       86142, /* 54777 (1403) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  4]  1 */
       91002, /* 54778 (1403) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  4]  1 */
       14133, /* 54779 (1403) [ 1, -1,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
      171923, /* 54780 (1403) [ 1, -1,  0,  1,  0,  0,  0,  0,  1] [ 0,  0,  8]  1 */
       90599, /* 54781 (1403) [ 0,  1,  0, -1,  1,  0,  0,  0,  1] [ 0,  0,  4]  1 */
        5547, /* 54782 (1403) [-1,  1,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
       16484, /* 54783 (1404) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34172805, /* 54784 (1404) [-1,  0,  0, -1,  1,  0,  0,  0, -1] [ 0,  0,  8] -1 */
    34017771, /* 54785 (1404) [-1,  1,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    34102823, /* 54786 (1404) [ 0,  1,  0, -1,  1,  0,  0,  0,  1] [ 0,  0,  4] -1 */
       86142, /* 54787 (1404) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  4]  1 */
    34186251, /* 54788 (1404) [ 1,  0,  0,  1, -1,  0,  0,  0, -1] [ 0,  0,  8] -1 */
      162689, /* 54789 (1404) [-1,  1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  8]  1 */
       86549, /* 54790 (1404) [ 0, -1,  0,  1, -1,  0,  0,  0,  1] [ 0,  0,  4]  1 */
      160581, /* 54791 (1404) [-1,  0,  0, -1,  1,  0,  0,  0, -1] [ 0,  0,  8]  1 */
       90599, /* 54792 (1404) [ 0,  1,  0, -1,  1,  0,  0,  0,  1] [ 0,  0,  4]  1 */
    34015424, /* 54793 (1404) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
        5547, /* 54794 (1404) [-1,  1,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    34028708, /* 54795 (1404) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    34184147, /* 54796 (1404) [ 1, -1,  0,  1,  0,  0,  0,  0,  1] [ 0,  0,  8] -1 */
      174027, /* 54797 (1404) [ 1,  0,  0,  1, -1,  0,  0,  0, -1] [ 0,  0,  8]  1 */
    34103226, /* 54798 (1404) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  4] -1 */
    34026357, /* 54799 (1404) [ 1, -1,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
        3200, /* 54800 (1404) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34098366, /* 54801 (1404) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  4] -1 */
    34174913, /* 54802 (1404) [-1,  1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  8] -1 */
       91002, /* 54803 (1404) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  4]  1 */
       14133, /* 54804 (1404) [ 1, -1,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
      171923, /* 54805 (1404) [ 1, -1,  0,  1,  0,  0,  0,  0,  1] [ 0,  0,  8]  1 */
    34098773, /* 54806 (1404) [ 0, -1,  0,  1, -1,  0,  0,  0,  1] [ 0,  0,  4] -1 */
       16484, /* 54807 (1405) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
      162689, /* 54808 (1405) [-1,  1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  8]  1 */
    34172805, /* 54809 (1405) [-1,  0,  0, -1,  1,  0,  0,  0, -1] [ 0,  0,  8] -1 */
       86549, /* 54810 (1405) [ 0, -1,  0,  1, -1,  0,  0,  0,  1] [ 0,  0,  4]  1 */
    34184147, /* 54811 (1405) [ 1, -1,  0,  1,  0,  0,  0,  0,  1] [ 0,  0,  8] -1 */
      174027, /* 54812 (1405) [ 1,  0,  0,  1, -1,  0,  0,  0, -1] [ 0,  0,  8]  1 */
    34103226, /* 54813 (1405) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  4] -1 */
    34026357, /* 54814 (1405) [ 1, -1,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    34102823, /* 54815 (1405) [ 0,  1,  0, -1,  1,  0,  0,  0,  1] [ 0,  0,  4] -1 */
       86142, /* 54816 (1405) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  4]  1 */
    34015424, /* 54817 (1405) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
        5547, /* 54818 (1405) [-1,  1,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
       16484, /* 54819 (1406) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
      162689, /* 54820 (1406) [-1,  1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  8]  1 */
       86549, /* 54821 (1406) [ 0, -1,  0,  1, -1,  0,  0,  0,  1] [ 0,  0,  4]  1 */
    34184147, /* 54822 (1406) [ 1, -1,  0,  1,  0,  0,  0,  0,  1] [ 0,  0,  8] -1 */
      160581, /* 54823 (1406) [-1,  0,  0, -1,  1,  0,  0,  0, -1] [ 0,  0,  8]  1 */
    34098366, /* 54824 (1406) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  4] -1 */
    34017771, /* 54825 (1406) [-1,  1,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    34102823, /* 54826 (1406) [ 0,  1,  0, -1,  1,  0,  0,  0,  1] [ 0,  0,  4] -1 */
       91002, /* 54827 (1406) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  4]  1 */
       14133, /* 54828 (1406) [ 1, -1,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    34015424, /* 54829 (1406) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    34186251, /* 54830 (1406) [ 1,  0,  0,  1, -1,  0,  0,  0, -1] [ 0,  0,  8] -1 */
       16484, /* 54831 (1407) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
      162689, /* 54832 (1407) [-1,  1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  8]  1 */
    34172805, /* 54833 (1407) [-1,  0,  0, -1,  1,  0,  0,  0, -1] [ 0,  0,  8] -1 */
       86549, /* 54834 (1407) [ 0, -1,  0,  1, -1,  0,  0,  0,  1] [ 0,  0,  4]  1 */
        3200, /* 54835 (1407) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34098366, /* 54836 (1407) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  4] -1 */
    34017771, /* 54837 (1407) [-1,  1,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    34103226, /* 54838 (1407) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  4] -1 */
    34026357, /* 54839 (1407) [ 1, -1,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
       90599, /* 54840 (1407) [ 0,  1,  0, -1,  1,  0,  0,  0,  1] [ 0,  0,  4]  1 */
      171923, /* 54841 (1407) [ 1, -1,  0,  1,  0,  0,  0,  0,  1] [ 0,  0,  8]  1 */
    34186251, /* 54842 (1407) [ 1,  0,  0,  1, -1,  0,  0,  0, -1] [ 0,  0,  8] -1 */
       16484, /* 54843 (1408) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34066049, /* 54844 (1408) [ 1, -1,  0,  1,  0,  0,  0,  0,  1] [ 0,  0,  2] -1 */
    34135869, /* 54845 (1408) [-1,  1,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
       86142, /* 54846 (1408) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  4]  1 */
    34216871, /* 54847 (1408) [ 0, -1,  0,  1, -1,  0,  0,  0,  1] [ 0,  0, 10] -1 */
    34220921, /* 54848 (1408) [ 0,  1,  0, -1,  1,  0,  0,  0,  1] [ 0,  0, 10] -1 */
      162689, /* 54849 (1408) [-1,  1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  8]  1 */
       86549, /* 54850 (1408) [ 0, -1,  0,  1, -1,  0,  0,  0,  1] [ 0,  0,  4]  1 */
      160581, /* 54851 (1408) [-1,  0,  0, -1,  1,  0,  0,  0, -1] [ 0,  0,  8]  1 */
    34056815, /* 54852 (1408) [-1,  1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  2] -1 */
    34146806, /* 54853 (1408) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
       90599, /* 54854 (1408) [ 0,  1,  0, -1,  1,  0,  0,  0,  1] [ 0,  0,  4]  1 */
    34054707, /* 54855 (1408) [-1,  0,  0, -1,  1,  0,  0,  0, -1] [ 0,  0,  2] -1 */
        5547, /* 54856 (1408) [-1,  1,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    34221324, /* 54857 (1408) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0, 10] -1 */
    34133522, /* 54858 (1408) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
      174027, /* 54859 (1408) [ 1,  0,  0,  1, -1,  0,  0,  0, -1] [ 0,  0,  8]  1 */
    34144455, /* 54860 (1408) [ 1, -1,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
    34068153, /* 54861 (1408) [ 1,  0,  0,  1, -1,  0,  0,  0, -1] [ 0,  0,  2] -1 */
        3200, /* 54862 (1408) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34216464, /* 54863 (1408) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0, 10] -1 */
       91002, /* 54864 (1408) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  4]  1 */
       14133, /* 54865 (1408) [ 1, -1,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
      171923, /* 54866 (1408) [ 1, -1,  0,  1,  0,  0,  0,  0,  1] [ 0,  0,  8]  1 */
       16484, /* 54867 (1409) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
      129965, /* 54868 (1409) [ 0,  1,  0, -1,  1,  0,  0,  0,  1] [ 0,  0,  6]  1 */
      125508, /* 54869 (1409) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  6]  1 */
        3117, /* 54870 (1409) [-1,  0,  0, -1,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
        5225, /* 54871 (1409) [-1,  1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  0]  1 */
      132557, /* 54872 (1409) [ 1, -1,  0,  1,  0,  0,  0,  0,  1] [ 0,  0,  6]  1 */
       12270, /* 54873 (1409) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  0]  1 */
      121298, /* 54874 (1409) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6]  1 */
        7817, /* 54875 (1409) [ 0, -1,  0,  1, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
      134661, /* 54876 (1409) [ 1,  0,  0,  1, -1,  0,  0,  0, -1] [ 0,  0,  6]  1 */
      123645, /* 54877 (1409) [-1,  1,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  6]  1 */
       14133, /* 54878 (1409) [ 1, -1,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
       16484, /* 54879 (1410) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34144781, /* 54880 (1410) [ 1, -1,  0,  1,  0,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    34137732, /* 54881 (1410) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  6] -1 */
    34135869, /* 54882 (1410) [-1,  1,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
       12270, /* 54883 (1410) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  0]  1 */
      134661, /* 54884 (1410) [ 1,  0,  0,  1, -1,  0,  0,  0, -1] [ 0,  0,  6]  1 */
    34017449, /* 54885 (1410) [-1,  1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  0] -1 */
      125508, /* 54886 (1410) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  6]  1 */
    34020041, /* 54887 (1410) [ 0, -1,  0,  1, -1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
      132557, /* 54888 (1410) [ 1, -1,  0,  1,  0,  0,  0,  0,  1] [ 0,  0,  6]  1 */
      123645, /* 54889 (1410) [-1,  1,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  6]  1 */
    34142189, /* 54890 (1410) [ 0,  1,  0, -1,  1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    34028708, /* 54891 (1410) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    34015341, /* 54892 (1410) [-1,  0,  0, -1,  1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    34133522, /* 54893 (1410) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    34026357, /* 54894 (1410) [ 1, -1,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
        5225, /* 54895 (1410) [-1,  1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  0]  1 */
        7817, /* 54896 (1410) [ 0, -1,  0,  1, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
      129965, /* 54897 (1410) [ 0,  1,  0, -1,  1,  0,  0,  0,  1] [ 0,  0,  6]  1 */
    34024494, /* 54898 (1410) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  0] -1 */
        3117, /* 54899 (1410) [-1,  0,  0, -1,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    34146885, /* 54900 (1410) [ 1,  0,  0,  1, -1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
      121298, /* 54901 (1410) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6]  1 */
       14133, /* 54902 (1410) [ 1, -1,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
       16484, /* 54903 (1411) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34144781, /* 54904 (1411) [ 1, -1,  0,  1,  0,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    34015341, /* 54905 (1411) [-1,  0,  0, -1,  1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    34133522, /* 54906 (1411) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
      125508, /* 54907 (1411) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  6]  1 */
    34024494, /* 54908 (1411) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    34026357, /* 54909 (1411) [ 1, -1,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
        5225, /* 54910 (1411) [-1,  1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  0]  1 */
        7817, /* 54911 (1411) [ 0, -1,  0,  1, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
      134661, /* 54912 (1411) [ 1,  0,  0,  1, -1,  0,  0,  0, -1] [ 0,  0,  6]  1 */
      123645, /* 54913 (1411) [-1,  1,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  6]  1 */
    34142189, /* 54914 (1411) [ 0,  1,  0, -1,  1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
       16484, /* 54915 (1412) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34137732, /* 54916 (1412) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  6] -1 */
    34144781, /* 54917 (1412) [ 1, -1,  0,  1,  0,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    34133522, /* 54918 (1412) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    34135869, /* 54919 (1412) [-1,  1,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
        3117, /* 54920 (1412) [-1,  0,  0, -1,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    34146885, /* 54921 (1412) [ 1,  0,  0,  1, -1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
        5225, /* 54922 (1412) [-1,  1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  0]  1 */
       12270, /* 54923 (1412) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  0]  1 */
        7817, /* 54924 (1412) [ 0, -1,  0,  1, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
       14133, /* 54925 (1412) [ 1, -1,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    34142189, /* 54926 (1412) [ 0,  1,  0, -1,  1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
       16484, /* 54927 (1413) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34137732, /* 54928 (1413) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  6] -1 */
    34015341, /* 54929 (1413) [-1,  0,  0, -1,  1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
      129965, /* 54930 (1413) [ 0,  1,  0, -1,  1,  0,  0,  0,  1] [ 0,  0,  6]  1 */
    34135869, /* 54931 (1413) [-1,  1,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
    34024494, /* 54932 (1413) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    34146885, /* 54933 (1413) [ 1,  0,  0,  1, -1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
    34026357, /* 54934 (1413) [ 1, -1,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
      132557, /* 54935 (1413) [ 1, -1,  0,  1,  0,  0,  0,  0,  1] [ 0,  0,  6]  1 */
        5225, /* 54936 (1413) [-1,  1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  0]  1 */
      121298, /* 54937 (1413) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6]  1 */
        7817, /* 54938 (1413) [ 0, -1,  0,  1, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
       16484, /* 54939 (1414) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34026683, /* 54940 (1414) [ 1, -1,  0,  1,  0,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    34019634, /* 54941 (1414) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    34017771, /* 54942 (1414) [-1,  1,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
       12270, /* 54943 (1414) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  0]  1 */
      134661, /* 54944 (1414) [ 1,  0,  0,  1, -1,  0,  0,  0, -1] [ 0,  0,  6]  1 */
    34135547, /* 54945 (1414) [-1,  1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    34138139, /* 54946 (1414) [ 0, -1,  0,  1, -1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
      125508, /* 54947 (1414) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  6]  1 */
    34024091, /* 54948 (1414) [ 0,  1,  0, -1,  1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
      132557, /* 54949 (1414) [ 1, -1,  0,  1,  0,  0,  0,  0,  1] [ 0,  0,  6]  1 */
      123645, /* 54950 (1414) [-1,  1,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  6]  1 */
    34146806, /* 54951 (1414) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    34015424, /* 54952 (1414) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    34133439, /* 54953 (1414) [-1,  0,  0, -1,  1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
    34144455, /* 54954 (1414) [ 1, -1,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
        5225, /* 54955 (1414) [-1,  1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  0]  1 */
        7817, /* 54956 (1414) [ 0, -1,  0,  1, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34028787, /* 54957 (1414) [ 1,  0,  0,  1, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    34142592, /* 54958 (1414) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  6] -1 */
      129965, /* 54959 (1414) [ 0,  1,  0, -1,  1,  0,  0,  0,  1] [ 0,  0,  6]  1 */
        3117, /* 54960 (1414) [-1,  0,  0, -1,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
      121298, /* 54961 (1414) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6]  1 */
       14133, /* 54962 (1414) [ 1, -1,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
       16484, /* 54963 (1415) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
        3200, /* 54964 (1415) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
        3119, /* 54965 (1415) [-1,  0,  0, -1,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
       12272, /* 54966 (1415) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 0,  0,  0]  1 */
        5225, /* 54967 (1415) [-1,  1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  0]  1 */
       14135, /* 54968 (1415) [ 1, -1,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
        7412, /* 54969 (1415) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  0]  1 */
        7817, /* 54970 (1415) [ 0, -1,  0,  1, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
       16565, /* 54971 (1415) [ 1,  0,  0,  1, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
       14459, /* 54972 (1415) [ 1, -1,  0,  1,  0,  0,  0,  0,  1] [ 0,  0,  0]  1 */
       11867, /* 54973 (1415) [ 0,  1,  0, -1,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
        5549, /* 54974 (1415) [-1,  1,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
       16484, /* 54975 (1416) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34026683, /* 54976 (1416) [ 1, -1,  0,  1,  0,  0,  0,  0,  1] [ 0,  0,  0] -1 */
       16565, /* 54977 (1416) [ 1,  0,  0,  1, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34017449, /* 54978 (1416) [-1,  1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    34024091, /* 54979 (1416) [ 0,  1,  0, -1,  1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    34020041, /* 54980 (1416) [ 0, -1,  0,  1, -1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
       14459, /* 54981 (1416) [ 1, -1,  0,  1,  0,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34015424, /* 54982 (1416) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    34028708, /* 54983 (1416) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    34024496, /* 54984 (1416) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    34015343, /* 54985 (1416) [-1,  0,  0, -1,  1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    34026359, /* 54986 (1416) [ 1, -1,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    34019636, /* 54987 (1416) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    34017773, /* 54988 (1416) [-1,  1,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
        5225, /* 54989 (1416) [-1,  1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  0]  1 */
        7817, /* 54990 (1416) [ 0, -1,  0,  1, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
       11867, /* 54991 (1416) [ 0,  1,  0, -1,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
        3200, /* 54992 (1416) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
        3119, /* 54993 (1416) [-1,  0,  0, -1,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
       12272, /* 54994 (1416) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34028789, /* 54995 (1416) [ 1,  0,  0,  1, -1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
       14135, /* 54996 (1416) [ 1, -1,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
        7412, /* 54997 (1416) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  0]  1 */
        5549, /* 54998 (1416) [-1,  1,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
       16484, /* 54999 (1417) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34026683, /* 55000 (1417) [ 1, -1,  0,  1,  0,  0,  0,  0,  1] [ 0,  0,  0] -1 */
        3119, /* 55001 (1417) [-1,  0,  0, -1,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34019636, /* 55002 (1417) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  0] -1 */
       12272, /* 55003 (1417) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34028789, /* 55004 (1417) [ 1,  0,  0,  1, -1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    34024091, /* 55005 (1417) [ 0,  1,  0, -1,  1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    34017773, /* 55006 (1417) [-1,  1,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
        5225, /* 55007 (1417) [-1,  1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  0]  1 */
       14135, /* 55008 (1417) [ 1, -1,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
        7817, /* 55009 (1417) [ 0, -1,  0,  1, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34015424, /* 55010 (1417) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
       16484, /* 55011 (1418) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34015343, /* 55012 (1418) [-1,  0,  0, -1,  1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    34026683, /* 55013 (1418) [ 1, -1,  0,  1,  0,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    34026359, /* 55014 (1418) [ 1, -1,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    34024091, /* 55015 (1418) [ 0,  1,  0, -1,  1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
        5225, /* 55016 (1418) [-1,  1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  0]  1 */
        7412, /* 55017 (1418) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  0]  1 */
        7817, /* 55018 (1418) [ 0, -1,  0,  1, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
       16565, /* 55019 (1418) [ 1,  0,  0,  1, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34015424, /* 55020 (1418) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
        5549, /* 55021 (1418) [-1,  1,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34024496, /* 55022 (1418) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 0,  0,  0] -1 */
       16484, /* 55023 (1419) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34015343, /* 55024 (1419) [-1,  0,  0, -1,  1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
        3200, /* 55025 (1419) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34026359, /* 55026 (1419) [ 1, -1,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    34019636, /* 55027 (1419) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    34028789, /* 55028 (1419) [ 1,  0,  0,  1, -1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    34017773, /* 55029 (1419) [-1,  1,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
        5225, /* 55030 (1419) [-1,  1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  0]  1 */
        7817, /* 55031 (1419) [ 0, -1,  0,  1, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
       14459, /* 55032 (1419) [ 1, -1,  0,  1,  0,  0,  0,  0,  1] [ 0,  0,  0]  1 */
       11867, /* 55033 (1419) [ 0,  1,  0, -1,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34024496, /* 55034 (1419) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 0,  0,  0] -1 */
       16484, /* 55035 (1420) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34144781, /* 55036 (1420) [ 1, -1,  0,  1,  0,  0,  0,  0,  1] [ 0,  0,  6] -1 */
       16565, /* 55037 (1420) [ 1,  0,  0,  1, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34135547, /* 55038 (1420) [-1,  1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    34138139, /* 55039 (1420) [ 0, -1,  0,  1, -1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    34146806, /* 55040 (1420) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
       14459, /* 55041 (1420) [ 1, -1,  0,  1,  0,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34142189, /* 55042 (1420) [ 0,  1,  0, -1,  1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    34133522, /* 55043 (1420) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    34142594, /* 55044 (1420) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    34133441, /* 55045 (1420) [-1,  0,  0, -1,  1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
        5225, /* 55046 (1420) [-1,  1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  0]  1 */
        7817, /* 55047 (1420) [ 0, -1,  0,  1, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34144457, /* 55048 (1420) [ 1, -1,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    34137734, /* 55049 (1420) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  6] -1 */
       11867, /* 55050 (1420) [ 0,  1,  0, -1,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34135871, /* 55051 (1420) [-1,  1,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    34146887, /* 55052 (1420) [ 1,  0,  0,  1, -1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
        3200, /* 55053 (1420) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
        3119, /* 55054 (1420) [-1,  0,  0, -1,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
       12272, /* 55055 (1420) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 0,  0,  0]  1 */
       14135, /* 55056 (1420) [ 1, -1,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
        7412, /* 55057 (1420) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  0]  1 */
        5549, /* 55058 (1420) [-1,  1,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
       16484, /* 55059 (1421) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
      123647, /* 55060 (1421) [-1,  1,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6]  1 */
        3200, /* 55061 (1421) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
      134663, /* 55062 (1421) [ 1,  0,  0,  1, -1,  0,  0,  0,  1] [ 0,  0,  6]  1 */
        5225, /* 55063 (1421) [-1,  1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  0]  1 */
        7817, /* 55064 (1421) [ 0, -1,  0,  1, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
      121217, /* 55065 (1421) [-1,  0,  0, -1,  1,  0,  0,  0,  1] [ 0,  0,  6]  1 */
      130370, /* 55066 (1421) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 0,  0,  6]  1 */
       14459, /* 55067 (1421) [ 1, -1,  0,  1,  0,  0,  0,  0,  1] [ 0,  0,  0]  1 */
       11867, /* 55068 (1421) [ 0,  1,  0, -1,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
      132233, /* 55069 (1421) [ 1, -1,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6]  1 */
      125510, /* 55070 (1421) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  6]  1 */
       16484, /* 55071 (1422) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
      123647, /* 55072 (1422) [-1,  1,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6]  1 */
    34026683, /* 55073 (1422) [ 1, -1,  0,  1,  0,  0,  0,  0,  1] [ 0,  0,  0] -1 */
      134663, /* 55074 (1422) [ 1,  0,  0,  1, -1,  0,  0,  0,  1] [ 0,  0,  6]  1 */
    34017449, /* 55075 (1422) [-1,  1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    34024091, /* 55076 (1422) [ 0,  1,  0, -1,  1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    34020041, /* 55077 (1422) [ 0, -1,  0,  1, -1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
       14459, /* 55078 (1422) [ 1, -1,  0,  1,  0,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34015424, /* 55079 (1422) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    34028708, /* 55080 (1422) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    34142594, /* 55081 (1422) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    34133441, /* 55082 (1422) [-1,  0,  0, -1,  1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
        5225, /* 55083 (1422) [-1,  1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  0]  1 */
        7817, /* 55084 (1422) [ 0, -1,  0,  1, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34144457, /* 55085 (1422) [ 1, -1,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    34137734, /* 55086 (1422) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  6] -1 */
       11867, /* 55087 (1422) [ 0,  1,  0, -1,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34135871, /* 55088 (1422) [-1,  1,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    34146887, /* 55089 (1422) [ 1,  0,  0,  1, -1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
        3200, /* 55090 (1422) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
      121217, /* 55091 (1422) [-1,  0,  0, -1,  1,  0,  0,  0,  1] [ 0,  0,  6]  1 */
      130370, /* 55092 (1422) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 0,  0,  6]  1 */
      132233, /* 55093 (1422) [ 1, -1,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6]  1 */
      125510, /* 55094 (1422) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  6]  1 */
       16484, /* 55095 (1423) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34026683, /* 55096 (1423) [ 1, -1,  0,  1,  0,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    34024091, /* 55097 (1423) [ 0,  1,  0, -1,  1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
        5225, /* 55098 (1423) [-1,  1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  0]  1 */
        7817, /* 55099 (1423) [ 0, -1,  0,  1, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
      121217, /* 55100 (1423) [-1,  0,  0, -1,  1,  0,  0,  0,  1] [ 0,  0,  6]  1 */
    34137734, /* 55101 (1423) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  6] -1 */
      130370, /* 55102 (1423) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 0,  0,  6]  1 */
    34135871, /* 55103 (1423) [-1,  1,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
      132233, /* 55104 (1423) [ 1, -1,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6]  1 */
    34146887, /* 55105 (1423) [ 1,  0,  0,  1, -1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    34015424, /* 55106 (1423) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
       16484, /* 55107 (1424) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
      123647, /* 55108 (1424) [-1,  1,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6]  1 */
    34142594, /* 55109 (1424) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    34026683, /* 55110 (1424) [ 1, -1,  0,  1,  0,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    34024091, /* 55111 (1424) [ 0,  1,  0, -1,  1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
      134663, /* 55112 (1424) [ 1,  0,  0,  1, -1,  0,  0,  0,  1] [ 0,  0,  6]  1 */
    34133441, /* 55113 (1424) [-1,  0,  0, -1,  1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
        5225, /* 55114 (1424) [-1,  1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  0]  1 */
        7817, /* 55115 (1424) [ 0, -1,  0,  1, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34144457, /* 55116 (1424) [ 1, -1,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    34015424, /* 55117 (1424) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
      125510, /* 55118 (1424) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  6]  1 */
       16484, /* 55119 (1425) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
        3200, /* 55120 (1425) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34142594, /* 55121 (1425) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    34133441, /* 55122 (1425) [-1,  0,  0, -1,  1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
        5225, /* 55123 (1425) [-1,  1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  0]  1 */
        7817, /* 55124 (1425) [ 0, -1,  0,  1, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34144457, /* 55125 (1425) [ 1, -1,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    34137734, /* 55126 (1425) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  6] -1 */
       14459, /* 55127 (1425) [ 1, -1,  0,  1,  0,  0,  0,  0,  1] [ 0,  0,  0]  1 */
       11867, /* 55128 (1425) [ 0,  1,  0, -1,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34135871, /* 55129 (1425) [-1,  1,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    34146887, /* 55130 (1425) [ 1,  0,  0,  1, -1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
       16484, /* 55131 (1426) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34144781, /* 55132 (1426) [ 1, -1,  0,  1,  0,  0,  0,  0,  1] [ 0,  0,  6] -1 */
      123647, /* 55133 (1426) [-1,  1,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6]  1 */
      134663, /* 55134 (1426) [ 1,  0,  0,  1, -1,  0,  0,  0,  1] [ 0,  0,  6]  1 */
    34135547, /* 55135 (1426) [-1,  1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    34138139, /* 55136 (1426) [ 0, -1,  0,  1, -1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    34146806, /* 55137 (1426) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
       14459, /* 55138 (1426) [ 1, -1,  0,  1,  0,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34142189, /* 55139 (1426) [ 0,  1,  0, -1,  1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    34024496, /* 55140 (1426) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    34015343, /* 55141 (1426) [-1,  0,  0, -1,  1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    34133522, /* 55142 (1426) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    34026359, /* 55143 (1426) [ 1, -1,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    34019636, /* 55144 (1426) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    34017773, /* 55145 (1426) [-1,  1,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
        5225, /* 55146 (1426) [-1,  1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  0]  1 */
        7817, /* 55147 (1426) [ 0, -1,  0,  1, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
       11867, /* 55148 (1426) [ 0,  1,  0, -1,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
        3200, /* 55149 (1426) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34028789, /* 55150 (1426) [ 1,  0,  0,  1, -1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
      121217, /* 55151 (1426) [-1,  0,  0, -1,  1,  0,  0,  0,  1] [ 0,  0,  6]  1 */
      130370, /* 55152 (1426) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 0,  0,  6]  1 */
      132233, /* 55153 (1426) [ 1, -1,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6]  1 */
      125510, /* 55154 (1426) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  6]  1 */
       16484, /* 55155 (1427) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
      129965, /* 55156 (1427) [ 0,  1,  0, -1,  1,  0,  0,  0,  1] [ 0,  0,  6]  1 */
      123647, /* 55157 (1427) [-1,  1,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6]  1 */
        3119, /* 55158 (1427) [-1,  0,  0, -1,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
       12272, /* 55159 (1427) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 0,  0,  0]  1 */
      134663, /* 55160 (1427) [ 1,  0,  0,  1, -1,  0,  0,  0,  1] [ 0,  0,  6]  1 */
        5225, /* 55161 (1427) [-1,  1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  0]  1 */
      132557, /* 55162 (1427) [ 1, -1,  0,  1,  0,  0,  0,  0,  1] [ 0,  0,  6]  1 */
       14135, /* 55163 (1427) [ 1, -1,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
      121298, /* 55164 (1427) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6]  1 */
        7817, /* 55165 (1427) [ 0, -1,  0,  1, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
      125510, /* 55166 (1427) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  6]  1 */
       16484, /* 55167 (1428) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34144781, /* 55168 (1428) [ 1, -1,  0,  1,  0,  0,  0,  0,  1] [ 0,  0,  6] -1 */
      123647, /* 55169 (1428) [-1,  1,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6]  1 */
      134663, /* 55170 (1428) [ 1,  0,  0,  1, -1,  0,  0,  0,  1] [ 0,  0,  6]  1 */
    34017449, /* 55171 (1428) [-1,  1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    34020041, /* 55172 (1428) [ 0, -1,  0,  1, -1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
      132557, /* 55173 (1428) [ 1, -1,  0,  1,  0,  0,  0,  0,  1] [ 0,  0,  6]  1 */
    34142189, /* 55174 (1428) [ 0,  1,  0, -1,  1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    34028708, /* 55175 (1428) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    34024496, /* 55176 (1428) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    34015343, /* 55177 (1428) [-1,  0,  0, -1,  1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    34133522, /* 55178 (1428) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    34026359, /* 55179 (1428) [ 1, -1,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
        5225, /* 55180 (1428) [-1,  1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  0]  1 */
        7817, /* 55181 (1428) [ 0, -1,  0,  1, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34137734, /* 55182 (1428) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    34135871, /* 55183 (1428) [-1,  1,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    34146887, /* 55184 (1428) [ 1,  0,  0,  1, -1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
      129965, /* 55185 (1428) [ 0,  1,  0, -1,  1,  0,  0,  0,  1] [ 0,  0,  6]  1 */
        3119, /* 55186 (1428) [-1,  0,  0, -1,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
       12272, /* 55187 (1428) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 0,  0,  0]  1 */
       14135, /* 55188 (1428) [ 1, -1,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
      121298, /* 55189 (1428) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6]  1 */
      125510, /* 55190 (1428) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  6]  1 */
       16484, /* 55191 (1429) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34144781, /* 55192 (1429) [ 1, -1,  0,  1,  0,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    34133522, /* 55193 (1429) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
        3119, /* 55194 (1429) [-1,  0,  0, -1,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
       12272, /* 55195 (1429) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 0,  0,  0]  1 */
        5225, /* 55196 (1429) [-1,  1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  0]  1 */
       14135, /* 55197 (1429) [ 1, -1,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
        7817, /* 55198 (1429) [ 0, -1,  0,  1, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34137734, /* 55199 (1429) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    34142189, /* 55200 (1429) [ 0,  1,  0, -1,  1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    34135871, /* 55201 (1429) [-1,  1,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    34146887, /* 55202 (1429) [ 1,  0,  0,  1, -1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
       16484, /* 55203 (1430) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34015343, /* 55204 (1430) [-1,  0,  0, -1,  1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    34144781, /* 55205 (1430) [ 1, -1,  0,  1,  0,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    34133522, /* 55206 (1430) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
      123647, /* 55207 (1430) [-1,  1,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6]  1 */
    34026359, /* 55208 (1430) [ 1, -1,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
      134663, /* 55209 (1430) [ 1,  0,  0,  1, -1,  0,  0,  0,  1] [ 0,  0,  6]  1 */
        5225, /* 55210 (1430) [-1,  1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  0]  1 */
        7817, /* 55211 (1430) [ 0, -1,  0,  1, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34142189, /* 55212 (1430) [ 0,  1,  0, -1,  1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
      125510, /* 55213 (1430) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  6]  1 */
    34024496, /* 55214 (1430) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 0,  0,  0] -1 */
       16484, /* 55215 (1431) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34015343, /* 55216 (1431) [-1,  0,  0, -1,  1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
      129965, /* 55217 (1431) [ 0,  1,  0, -1,  1,  0,  0,  0,  1] [ 0,  0,  6]  1 */
    34026359, /* 55218 (1431) [ 1, -1,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
        5225, /* 55219 (1431) [-1,  1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  0]  1 */
      132557, /* 55220 (1431) [ 1, -1,  0,  1,  0,  0,  0,  0,  1] [ 0,  0,  6]  1 */
      121298, /* 55221 (1431) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6]  1 */
        7817, /* 55222 (1431) [ 0, -1,  0,  1, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34137734, /* 55223 (1431) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    34135871, /* 55224 (1431) [-1,  1,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    34024496, /* 55225 (1431) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    34146887, /* 55226 (1431) [ 1,  0,  0,  1, -1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
       16484, /* 55227 (1432) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
      123647, /* 55228 (1432) [-1,  1,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6]  1 */
    34026683, /* 55229 (1432) [ 1, -1,  0,  1,  0,  0,  0,  0,  1] [ 0,  0,  0] -1 */
      134663, /* 55230 (1432) [ 1,  0,  0,  1, -1,  0,  0,  0,  1] [ 0,  0,  6]  1 */
    34135547, /* 55231 (1432) [-1,  1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    34138139, /* 55232 (1432) [ 0, -1,  0,  1, -1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    34024091, /* 55233 (1432) [ 0,  1,  0, -1,  1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
      132557, /* 55234 (1432) [ 1, -1,  0,  1,  0,  0,  0,  0,  1] [ 0,  0,  6]  1 */
    34146806, /* 55235 (1432) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    34015424, /* 55236 (1432) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    34142594, /* 55237 (1432) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    34019636, /* 55238 (1432) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    34133441, /* 55239 (1432) [-1,  0,  0, -1,  1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    34017773, /* 55240 (1432) [-1,  1,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
        5225, /* 55241 (1432) [-1,  1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  0]  1 */
        7817, /* 55242 (1432) [ 0, -1,  0,  1, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34144457, /* 55243 (1432) [ 1, -1,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
      129965, /* 55244 (1432) [ 0,  1,  0, -1,  1,  0,  0,  0,  1] [ 0,  0,  6]  1 */
        3119, /* 55245 (1432) [-1,  0,  0, -1,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
       12272, /* 55246 (1432) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34028789, /* 55247 (1432) [ 1,  0,  0,  1, -1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
       14135, /* 55248 (1432) [ 1, -1,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
      121298, /* 55249 (1432) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6]  1 */
      125510, /* 55250 (1432) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  6]  1 */
       16484, /* 55251 (1433) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
      129965, /* 55252 (1433) [ 0,  1,  0, -1,  1,  0,  0,  0,  1] [ 0,  0,  6]  1 */
        5225, /* 55253 (1433) [-1,  1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  0]  1 */
      132557, /* 55254 (1433) [ 1, -1,  0,  1,  0,  0,  0,  0,  1] [ 0,  0,  6]  1 */
        7412, /* 55255 (1433) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  0]  1 */
      121298, /* 55256 (1433) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6]  1 */
        7817, /* 55257 (1433) [ 0, -1,  0,  1, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
       16565, /* 55258 (1433) [ 1,  0,  0,  1, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
      121217, /* 55259 (1433) [-1,  0,  0, -1,  1,  0,  0,  0,  1] [ 0,  0,  6]  1 */
      130370, /* 55260 (1433) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 0,  0,  6]  1 */
      132233, /* 55261 (1433) [ 1, -1,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6]  1 */
        5549, /* 55262 (1433) [-1,  1,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
       16484, /* 55263 (1434) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34144781, /* 55264 (1434) [ 1, -1,  0,  1,  0,  0,  0,  0,  1] [ 0,  0,  6] -1 */
       16565, /* 55265 (1434) [ 1,  0,  0,  1, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34017449, /* 55266 (1434) [-1,  1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    34020041, /* 55267 (1434) [ 0, -1,  0,  1, -1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
      132557, /* 55268 (1434) [ 1, -1,  0,  1,  0,  0,  0,  0,  1] [ 0,  0,  6]  1 */
    34142189, /* 55269 (1434) [ 0,  1,  0, -1,  1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    34028708, /* 55270 (1434) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    34133522, /* 55271 (1434) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    34142594, /* 55272 (1434) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    34019636, /* 55273 (1434) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    34133441, /* 55274 (1434) [-1,  0,  0, -1,  1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    34017773, /* 55275 (1434) [-1,  1,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
        5225, /* 55276 (1434) [-1,  1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  0]  1 */
        7817, /* 55277 (1434) [ 0, -1,  0,  1, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34144457, /* 55278 (1434) [ 1, -1,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
      129965, /* 55279 (1434) [ 0,  1,  0, -1,  1,  0,  0,  0,  1] [ 0,  0,  6]  1 */
    34028789, /* 55280 (1434) [ 1,  0,  0,  1, -1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
        7412, /* 55281 (1434) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  0]  1 */
      121298, /* 55282 (1434) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6]  1 */
      121217, /* 55283 (1434) [-1,  0,  0, -1,  1,  0,  0,  0,  1] [ 0,  0,  6]  1 */
      130370, /* 55284 (1434) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 0,  0,  6]  1 */
      132233, /* 55285 (1434) [ 1, -1,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6]  1 */
        5549, /* 55286 (1434) [-1,  1,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
       16484, /* 55287 (1435) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34144781, /* 55288 (1435) [ 1, -1,  0,  1,  0,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    34133522, /* 55289 (1435) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    34019636, /* 55290 (1435) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    34028789, /* 55291 (1435) [ 1,  0,  0,  1, -1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    34017773, /* 55292 (1435) [-1,  1,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
        5225, /* 55293 (1435) [-1,  1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  0]  1 */
        7817, /* 55294 (1435) [ 0, -1,  0,  1, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
      121217, /* 55295 (1435) [-1,  0,  0, -1,  1,  0,  0,  0,  1] [ 0,  0,  6]  1 */
      130370, /* 55296 (1435) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 0,  0,  6]  1 */
    34142189, /* 55297 (1435) [ 0,  1,  0, -1,  1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
      132233, /* 55298 (1435) [ 1, -1,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6]  1 */
       16484, /* 55299 (1436) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34144781, /* 55300 (1436) [ 1, -1,  0,  1,  0,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    34133522, /* 55301 (1436) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    34142594, /* 55302 (1436) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    34133441, /* 55303 (1436) [-1,  0,  0, -1,  1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
        5225, /* 55304 (1436) [-1,  1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  0]  1 */
        7412, /* 55305 (1436) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  0]  1 */
        7817, /* 55306 (1436) [ 0, -1,  0,  1, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
       16565, /* 55307 (1436) [ 1,  0,  0,  1, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34144457, /* 55308 (1436) [ 1, -1,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    34142189, /* 55309 (1436) [ 0,  1,  0, -1,  1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
        5549, /* 55310 (1436) [-1,  1,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
       16484, /* 55311 (1437) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
      129965, /* 55312 (1437) [ 0,  1,  0, -1,  1,  0,  0,  0,  1] [ 0,  0,  6]  1 */
    34142594, /* 55313 (1437) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    34019636, /* 55314 (1437) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    34028789, /* 55315 (1437) [ 1,  0,  0,  1, -1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    34133441, /* 55316 (1437) [-1,  0,  0, -1,  1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    34017773, /* 55317 (1437) [-1,  1,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
        5225, /* 55318 (1437) [-1,  1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  0]  1 */
      132557, /* 55319 (1437) [ 1, -1,  0,  1,  0,  0,  0,  0,  1] [ 0,  0,  6]  1 */
      121298, /* 55320 (1437) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6]  1 */
        7817, /* 55321 (1437) [ 0, -1,  0,  1, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34144457, /* 55322 (1437) [ 1, -1,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
       16484, /* 55323 (1438) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34026683, /* 55324 (1438) [ 1, -1,  0,  1,  0,  0,  0,  0,  1] [ 0,  0,  0] -1 */
       16565, /* 55325 (1438) [ 1,  0,  0,  1, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34135547, /* 55326 (1438) [-1,  1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    34138139, /* 55327 (1438) [ 0, -1,  0,  1, -1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    34024091, /* 55328 (1438) [ 0,  1,  0, -1,  1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
      132557, /* 55329 (1438) [ 1, -1,  0,  1,  0,  0,  0,  0,  1] [ 0,  0,  6]  1 */
    34146806, /* 55330 (1438) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    34015424, /* 55331 (1438) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    34024496, /* 55332 (1438) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    34015343, /* 55333 (1438) [-1,  0,  0, -1,  1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    34026359, /* 55334 (1438) [ 1, -1,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
        5225, /* 55335 (1438) [-1,  1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  0]  1 */
        7817, /* 55336 (1438) [ 0, -1,  0,  1, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34137734, /* 55337 (1438) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    34135871, /* 55338 (1438) [-1,  1,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    34146887, /* 55339 (1438) [ 1,  0,  0,  1, -1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
      129965, /* 55340 (1438) [ 0,  1,  0, -1,  1,  0,  0,  0,  1] [ 0,  0,  6]  1 */
        7412, /* 55341 (1438) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  0]  1 */
      121298, /* 55342 (1438) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6]  1 */
      121217, /* 55343 (1438) [-1,  0,  0, -1,  1,  0,  0,  0,  1] [ 0,  0,  6]  1 */
      130370, /* 55344 (1438) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 0,  0,  6]  1 */
      132233, /* 55345 (1438) [ 1, -1,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6]  1 */
        5549, /* 55346 (1438) [-1,  1,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
       16484, /* 55347 (1439) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
        7815, /* 55348 (1439) [ 0, -1,  0,  1, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
       16563, /* 55349 (1439) [ 1,  0,  0,  1, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
        7410, /* 55350 (1439) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  0]  1 */
        5225, /* 55351 (1439) [-1,  1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  0]  1 */
        7412, /* 55352 (1439) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  0]  1 */
        7817, /* 55353 (1439) [ 0, -1,  0,  1, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
       16565, /* 55354 (1439) [ 1,  0,  0,  1, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
        5223, /* 55355 (1439) [-1,  1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  0]  1 */
        5547, /* 55356 (1439) [-1,  1,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
        5549, /* 55357 (1439) [-1,  1,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
       16482, /* 55358 (1439) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
       16484, /* 55359 (1440) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34019634, /* 55360 (1440) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  0] -1 */
       16563, /* 55361 (1440) [ 1,  0,  0,  1, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    34017771, /* 55362 (1440) [-1,  1,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
       16565, /* 55363 (1440) [ 1,  0,  0,  1, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34020039, /* 55364 (1440) [ 0, -1,  0,  1, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    34017449, /* 55365 (1440) [-1,  1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    34020041, /* 55366 (1440) [ 0, -1,  0,  1, -1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
        7410, /* 55367 (1440) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  0]  1 */
        5547, /* 55368 (1440) [-1,  1,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    34028708, /* 55369 (1440) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
        7815, /* 55370 (1440) [ 0, -1,  0,  1, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    34019636, /* 55371 (1440) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    34017447, /* 55372 (1440) [-1,  1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    34017773, /* 55373 (1440) [-1,  1,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
        5225, /* 55374 (1440) [-1,  1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34028706, /* 55375 (1440) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
        7817, /* 55376 (1440) [ 0, -1,  0,  1, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34028787, /* 55377 (1440) [ 1,  0,  0,  1, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    34028789, /* 55378 (1440) [ 1,  0,  0,  1, -1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
        7412, /* 55379 (1440) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  0]  1 */
        5223, /* 55380 (1440) [-1,  1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  0]  1 */
        5549, /* 55381 (1440) [-1,  1,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
       16482, /* 55382 (1440) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
       16484, /* 55383 (1441) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
       16563, /* 55384 (1441) [ 1,  0,  0,  1, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    34019636, /* 55385 (1441) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    34028789, /* 55386 (1441) [ 1,  0,  0,  1, -1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    34017773, /* 55387 (1441) [-1,  1,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    34017447, /* 55388 (1441) [-1,  1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  0] -1 */
        7410, /* 55389 (1441) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    34028706, /* 55390 (1441) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
        5225, /* 55391 (1441) [-1,  1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  0]  1 */
        7817, /* 55392 (1441) [ 0, -1,  0,  1, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
        5547, /* 55393 (1441) [-1,  1,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    34020039, /* 55394 (1441) [ 0, -1,  0,  1, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
       16484, /* 55395 (1442) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34028787, /* 55396 (1442) [ 1,  0,  0,  1, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    34019634, /* 55397 (1442) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    34017771, /* 55398 (1442) [-1,  1,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    34017447, /* 55399 (1442) [-1,  1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    34028706, /* 55400 (1442) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
        5225, /* 55401 (1442) [-1,  1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  0]  1 */
        7412, /* 55402 (1442) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  0]  1 */
        7817, /* 55403 (1442) [ 0, -1,  0,  1, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
       16565, /* 55404 (1442) [ 1,  0,  0,  1, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
        5549, /* 55405 (1442) [-1,  1,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34020039, /* 55406 (1442) [ 0, -1,  0,  1, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
       16484, /* 55407 (1443) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34028787, /* 55408 (1443) [ 1,  0,  0,  1, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
        7815, /* 55409 (1443) [ 0, -1,  0,  1, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    34019634, /* 55410 (1443) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    34019636, /* 55411 (1443) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    34028789, /* 55412 (1443) [ 1,  0,  0,  1, -1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    34017771, /* 55413 (1443) [-1,  1,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    34017773, /* 55414 (1443) [-1,  1,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
        5225, /* 55415 (1443) [-1,  1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  0]  1 */
        7817, /* 55416 (1443) [ 0, -1,  0,  1, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
        5223, /* 55417 (1443) [-1,  1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  0]  1 */
       16482, /* 55418 (1443) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
       16484, /* 55419 (1444) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34137732, /* 55420 (1444) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  6] -1 */
    34135869, /* 55421 (1444) [-1,  1,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
       16563, /* 55422 (1444) [ 1,  0,  0,  1, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
       16565, /* 55423 (1444) [ 1,  0,  0,  1, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34135547, /* 55424 (1444) [-1,  1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    34138139, /* 55425 (1444) [ 0, -1,  0,  1, -1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    34138137, /* 55426 (1444) [ 0, -1,  0,  1, -1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
        7410, /* 55427 (1444) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    34146806, /* 55428 (1444) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
        5547, /* 55429 (1444) [-1,  1,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
        7815, /* 55430 (1444) [ 0, -1,  0,  1, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
        5225, /* 55431 (1444) [-1,  1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  0]  1 */
        7817, /* 55432 (1444) [ 0, -1,  0,  1, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34137734, /* 55433 (1444) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    34135871, /* 55434 (1444) [-1,  1,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    34146804, /* 55435 (1444) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
    34135545, /* 55436 (1444) [-1,  1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  6] -1 */
    34146887, /* 55437 (1444) [ 1,  0,  0,  1, -1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    34146885, /* 55438 (1444) [ 1,  0,  0,  1, -1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
        7412, /* 55439 (1444) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  0]  1 */
        5223, /* 55440 (1444) [-1,  1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  0]  1 */
        5549, /* 55441 (1444) [-1,  1,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
       16482, /* 55442 (1444) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
       16484, /* 55443 (1445) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
      123647, /* 55444 (1445) [-1,  1,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6]  1 */
      134580, /* 55445 (1445) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  6]  1 */
       16563, /* 55446 (1445) [ 1,  0,  0,  1, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
      134663, /* 55447 (1445) [ 1,  0,  0,  1, -1,  0,  0,  0,  1] [ 0,  0,  6]  1 */
        7410, /* 55448 (1445) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  0]  1 */
      125913, /* 55449 (1445) [ 0, -1,  0,  1, -1,  0,  0,  0, -1] [ 0,  0,  6]  1 */
        5225, /* 55450 (1445) [-1,  1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  0]  1 */
        7817, /* 55451 (1445) [ 0, -1,  0,  1, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
        5547, /* 55452 (1445) [-1,  1,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
      125510, /* 55453 (1445) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  6]  1 */
      123321, /* 55454 (1445) [-1,  1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  6]  1 */
       16484, /* 55455 (1446) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
      123647, /* 55456 (1446) [-1,  1,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6]  1 */
    34019634, /* 55457 (1446) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  0] -1 */
      134580, /* 55458 (1446) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  6]  1 */
       16563, /* 55459 (1446) [ 1,  0,  0,  1, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
      134663, /* 55460 (1446) [ 1,  0,  0,  1, -1,  0,  0,  0,  1] [ 0,  0,  6]  1 */
    34017771, /* 55461 (1446) [-1,  1,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    34017449, /* 55462 (1446) [-1,  1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    34138137, /* 55463 (1446) [ 0, -1,  0,  1, -1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
    34020041, /* 55464 (1446) [ 0, -1,  0,  1, -1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
        7410, /* 55465 (1446) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  0]  1 */
        5547, /* 55466 (1446) [-1,  1,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    34028708, /* 55467 (1446) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
      125913, /* 55468 (1446) [ 0, -1,  0,  1, -1,  0,  0,  0, -1] [ 0,  0,  6]  1 */
        5225, /* 55469 (1446) [-1,  1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  0]  1 */
        7817, /* 55470 (1446) [ 0, -1,  0,  1, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34137734, /* 55471 (1446) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    34135871, /* 55472 (1446) [-1,  1,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    34146804, /* 55473 (1446) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
    34135545, /* 55474 (1446) [-1,  1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  6] -1 */
    34146887, /* 55475 (1446) [ 1,  0,  0,  1, -1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    34028787, /* 55476 (1446) [ 1,  0,  0,  1, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
      125510, /* 55477 (1446) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  6]  1 */
      123321, /* 55478 (1446) [-1,  1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  6]  1 */
       16484, /* 55479 (1447) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34135871, /* 55480 (1447) [-1,  1,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
       16563, /* 55481 (1447) [ 1,  0,  0,  1, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    34138137, /* 55482 (1447) [ 0, -1,  0,  1, -1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
        7410, /* 55483 (1447) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  0]  1 */
        5225, /* 55484 (1447) [-1,  1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  0]  1 */
        7817, /* 55485 (1447) [ 0, -1,  0,  1, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34137734, /* 55486 (1447) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    34135545, /* 55487 (1447) [-1,  1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  6] -1 */
    34146804, /* 55488 (1447) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
        5547, /* 55489 (1447) [-1,  1,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    34146887, /* 55490 (1447) [ 1,  0,  0,  1, -1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
       16484, /* 55491 (1448) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34028787, /* 55492 (1448) [ 1,  0,  0,  1, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
      123647, /* 55493 (1448) [-1,  1,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6]  1 */
    34019634, /* 55494 (1448) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    34138137, /* 55495 (1448) [ 0, -1,  0,  1, -1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
      134663, /* 55496 (1448) [ 1,  0,  0,  1, -1,  0,  0,  0,  1] [ 0,  0,  6]  1 */
    34017771, /* 55497 (1448) [-1,  1,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
        5225, /* 55498 (1448) [-1,  1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  0]  1 */
        7817, /* 55499 (1448) [ 0, -1,  0,  1, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34135545, /* 55500 (1448) [-1,  1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  6] -1 */
    34146804, /* 55501 (1448) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
      125510, /* 55502 (1448) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  6]  1 */
       16484, /* 55503 (1449) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34028787, /* 55504 (1449) [ 1,  0,  0,  1, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    34019634, /* 55505 (1449) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  0] -1 */
      134580, /* 55506 (1449) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  6]  1 */
    34017771, /* 55507 (1449) [-1,  1,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
      125913, /* 55508 (1449) [ 0, -1,  0,  1, -1,  0,  0,  0, -1] [ 0,  0,  6]  1 */
        5225, /* 55509 (1449) [-1,  1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  0]  1 */
        7817, /* 55510 (1449) [ 0, -1,  0,  1, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34137734, /* 55511 (1449) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    34135871, /* 55512 (1449) [-1,  1,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    34146887, /* 55513 (1449) [ 1,  0,  0,  1, -1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
      123321, /* 55514 (1449) [-1,  1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  6]  1 */
       16484, /* 55515 (1450) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34137732, /* 55516 (1450) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  6] -1 */
    34135869, /* 55517 (1450) [-1,  1,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
      123647, /* 55518 (1450) [-1,  1,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6]  1 */
      134580, /* 55519 (1450) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  6]  1 */
       16563, /* 55520 (1450) [ 1,  0,  0,  1, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
      134663, /* 55521 (1450) [ 1,  0,  0,  1, -1,  0,  0,  0,  1] [ 0,  0,  6]  1 */
    34135547, /* 55522 (1450) [-1,  1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    34020039, /* 55523 (1450) [ 0, -1,  0,  1, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    34138139, /* 55524 (1450) [ 0, -1,  0,  1, -1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
        7410, /* 55525 (1450) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    34146806, /* 55526 (1450) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
        5547, /* 55527 (1450) [-1,  1,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    34019636, /* 55528 (1450) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    34017447, /* 55529 (1450) [-1,  1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    34017773, /* 55530 (1450) [-1,  1,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
      125913, /* 55531 (1450) [ 0, -1,  0,  1, -1,  0,  0,  0, -1] [ 0,  0,  6]  1 */
        5225, /* 55532 (1450) [-1,  1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34028706, /* 55533 (1450) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
        7817, /* 55534 (1450) [ 0, -1,  0,  1, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34028789, /* 55535 (1450) [ 1,  0,  0,  1, -1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    34146885, /* 55536 (1450) [ 1,  0,  0,  1, -1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
      125510, /* 55537 (1450) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  6]  1 */
      123321, /* 55538 (1450) [-1,  1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  6]  1 */
       16484, /* 55539 (1451) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
        7815, /* 55540 (1451) [ 0, -1,  0,  1, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
        3119, /* 55541 (1451) [-1,  0,  0, -1,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
        3117, /* 55542 (1451) [-1,  0,  0, -1,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
       12272, /* 55543 (1451) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 0,  0,  0]  1 */
        5225, /* 55544 (1451) [-1,  1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  0]  1 */
       14135, /* 55545 (1451) [ 1, -1,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
       12270, /* 55546 (1451) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  0]  1 */
        7817, /* 55547 (1451) [ 0, -1,  0,  1, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
        5223, /* 55548 (1451) [-1,  1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  0]  1 */
       14133, /* 55549 (1451) [ 1, -1,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
       16482, /* 55550 (1451) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
       16484, /* 55551 (1452) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
       12270, /* 55552 (1452) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    34020039, /* 55553 (1452) [ 0, -1,  0,  1, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    34017449, /* 55554 (1452) [-1,  1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    34020041, /* 55555 (1452) [ 0, -1,  0,  1, -1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    34028708, /* 55556 (1452) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    34024496, /* 55557 (1452) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    34015343, /* 55558 (1452) [-1,  0,  0, -1,  1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    34015341, /* 55559 (1452) [-1,  0,  0, -1,  1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
        7815, /* 55560 (1452) [ 0, -1,  0,  1, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    34026359, /* 55561 (1452) [ 1, -1,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    34017447, /* 55562 (1452) [-1,  1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    34026357, /* 55563 (1452) [ 1, -1,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
        5225, /* 55564 (1452) [-1,  1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34028706, /* 55565 (1452) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
        7817, /* 55566 (1452) [ 0, -1,  0,  1, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
        3119, /* 55567 (1452) [-1,  0,  0, -1,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34024494, /* 55568 (1452) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  0] -1 */
        3117, /* 55569 (1452) [-1,  0,  0, -1,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
       12272, /* 55570 (1452) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 0,  0,  0]  1 */
       14135, /* 55571 (1452) [ 1, -1,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
        5223, /* 55572 (1452) [-1,  1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  0]  1 */
       14133, /* 55573 (1452) [ 1, -1,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
       16482, /* 55574 (1452) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
       16484, /* 55575 (1453) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34015341, /* 55576 (1453) [-1,  0,  0, -1,  1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
        3119, /* 55577 (1453) [-1,  0,  0, -1,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34024494, /* 55578 (1453) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  0] -1 */
       12272, /* 55579 (1453) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34017447, /* 55580 (1453) [-1,  1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    34026357, /* 55581 (1453) [ 1, -1,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    34028706, /* 55582 (1453) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
       14135, /* 55583 (1453) [ 1, -1,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
        5225, /* 55584 (1453) [-1,  1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  0]  1 */
        7817, /* 55585 (1453) [ 0, -1,  0,  1, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34020039, /* 55586 (1453) [ 0, -1,  0,  1, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
       16484, /* 55587 (1454) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34015343, /* 55588 (1454) [-1,  0,  0, -1,  1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    34026359, /* 55589 (1454) [ 1, -1,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
        3117, /* 55590 (1454) [-1,  0,  0, -1,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    34017447, /* 55591 (1454) [-1,  1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    34028706, /* 55592 (1454) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    34020039, /* 55593 (1454) [ 0, -1,  0,  1, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
        5225, /* 55594 (1454) [-1,  1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  0]  1 */
       12270, /* 55595 (1454) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  0]  1 */
        7817, /* 55596 (1454) [ 0, -1,  0,  1, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
       14133, /* 55597 (1454) [ 1, -1,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    34024496, /* 55598 (1454) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 0,  0,  0] -1 */
       16484, /* 55599 (1455) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34015343, /* 55600 (1455) [-1,  0,  0, -1,  1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    34015341, /* 55601 (1455) [-1,  0,  0, -1,  1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
        7815, /* 55602 (1455) [ 0, -1,  0,  1, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    34026359, /* 55603 (1455) [ 1, -1,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    34024494, /* 55604 (1455) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  0] -1 */
       16482, /* 55605 (1455) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    34026357, /* 55606 (1455) [ 1, -1,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
        5225, /* 55607 (1455) [-1,  1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  0]  1 */
        7817, /* 55608 (1455) [ 0, -1,  0,  1, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
        5223, /* 55609 (1455) [-1,  1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    34024496, /* 55610 (1455) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 0,  0,  0] -1 */
       16484, /* 55611 (1456) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
       12270, /* 55612 (1456) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    34135547, /* 55613 (1456) [-1,  1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    34138139, /* 55614 (1456) [ 0, -1,  0,  1, -1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    34138137, /* 55615 (1456) [ 0, -1,  0,  1, -1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
    34146806, /* 55616 (1456) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    34133439, /* 55617 (1456) [-1,  0,  0, -1,  1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
        7815, /* 55618 (1456) [ 0, -1,  0,  1, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    34142594, /* 55619 (1456) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    34144455, /* 55620 (1456) [ 1, -1,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
    34133441, /* 55621 (1456) [-1,  0,  0, -1,  1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
        5225, /* 55622 (1456) [-1,  1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  0]  1 */
        7817, /* 55623 (1456) [ 0, -1,  0,  1, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34144457, /* 55624 (1456) [ 1, -1,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    34135545, /* 55625 (1456) [-1,  1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  6] -1 */
    34146804, /* 55626 (1456) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
    34142592, /* 55627 (1456) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  6] -1 */
        3119, /* 55628 (1456) [-1,  0,  0, -1,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
        3117, /* 55629 (1456) [-1,  0,  0, -1,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
       12272, /* 55630 (1456) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 0,  0,  0]  1 */
       14135, /* 55631 (1456) [ 1, -1,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
        5223, /* 55632 (1456) [-1,  1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  0]  1 */
       14133, /* 55633 (1456) [ 1, -1,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
       16482, /* 55634 (1456) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
       16484, /* 55635 (1457) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
      134580, /* 55636 (1457) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  6]  1 */
        3117, /* 55637 (1457) [-1,  0,  0, -1,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
      125913, /* 55638 (1457) [ 0, -1,  0,  1, -1,  0,  0,  0, -1] [ 0,  0,  6]  1 */
        5225, /* 55639 (1457) [-1,  1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  0]  1 */
       12270, /* 55640 (1457) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  0]  1 */
        7817, /* 55641 (1457) [ 0, -1,  0,  1, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
      121217, /* 55642 (1457) [-1,  0,  0, -1,  1,  0,  0,  0,  1] [ 0,  0,  6]  1 */
       14133, /* 55643 (1457) [ 1, -1,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
      130370, /* 55644 (1457) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 0,  0,  6]  1 */
      132233, /* 55645 (1457) [ 1, -1,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6]  1 */
      123321, /* 55646 (1457) [-1,  1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  6]  1 */
       16484, /* 55647 (1458) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
      134580, /* 55648 (1458) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  6]  1 */
       12270, /* 55649 (1458) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    34017449, /* 55650 (1458) [-1,  1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    34138137, /* 55651 (1458) [ 0, -1,  0,  1, -1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
    34020041, /* 55652 (1458) [ 0, -1,  0,  1, -1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    34028708, /* 55653 (1458) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    34015341, /* 55654 (1458) [-1,  0,  0, -1,  1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    34142594, /* 55655 (1458) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    34133441, /* 55656 (1458) [-1,  0,  0, -1,  1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    34026357, /* 55657 (1458) [ 1, -1,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
      125913, /* 55658 (1458) [ 0, -1,  0,  1, -1,  0,  0,  0, -1] [ 0,  0,  6]  1 */
        5225, /* 55659 (1458) [-1,  1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  0]  1 */
        7817, /* 55660 (1458) [ 0, -1,  0,  1, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34144457, /* 55661 (1458) [ 1, -1,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    34135545, /* 55662 (1458) [-1,  1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  6] -1 */
    34146804, /* 55663 (1458) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
    34024494, /* 55664 (1458) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  0] -1 */
        3117, /* 55665 (1458) [-1,  0,  0, -1,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
      121217, /* 55666 (1458) [-1,  0,  0, -1,  1,  0,  0,  0,  1] [ 0,  0,  6]  1 */
      130370, /* 55667 (1458) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 0,  0,  6]  1 */
       14133, /* 55668 (1458) [ 1, -1,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
      132233, /* 55669 (1458) [ 1, -1,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6]  1 */
      123321, /* 55670 (1458) [-1,  1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  6]  1 */
       16484, /* 55671 (1459) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34015341, /* 55672 (1459) [-1,  0,  0, -1,  1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    34138137, /* 55673 (1459) [ 0, -1,  0,  1, -1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
    34024494, /* 55674 (1459) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    34026357, /* 55675 (1459) [ 1, -1,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
        5225, /* 55676 (1459) [-1,  1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  0]  1 */
        7817, /* 55677 (1459) [ 0, -1,  0,  1, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
      121217, /* 55678 (1459) [-1,  0,  0, -1,  1,  0,  0,  0,  1] [ 0,  0,  6]  1 */
      130370, /* 55679 (1459) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 0,  0,  6]  1 */
    34135545, /* 55680 (1459) [-1,  1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  6] -1 */
    34146804, /* 55681 (1459) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
      132233, /* 55682 (1459) [ 1, -1,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6]  1 */
       16484, /* 55683 (1460) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34142594, /* 55684 (1460) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    34138137, /* 55685 (1460) [ 0, -1,  0,  1, -1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
        3117, /* 55686 (1460) [-1,  0,  0, -1,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    34133441, /* 55687 (1460) [-1,  0,  0, -1,  1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
        5225, /* 55688 (1460) [-1,  1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  0]  1 */
       12270, /* 55689 (1460) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  0]  1 */
        7817, /* 55690 (1460) [ 0, -1,  0,  1, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34144457, /* 55691 (1460) [ 1, -1,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
       14133, /* 55692 (1460) [ 1, -1,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    34135545, /* 55693 (1460) [-1,  1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  6] -1 */
    34146804, /* 55694 (1460) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
       16484, /* 55695 (1461) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34015341, /* 55696 (1461) [-1,  0,  0, -1,  1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    34142594, /* 55697 (1461) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 0,  0,  6] -1 */
      134580, /* 55698 (1461) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  6]  1 */
    34024494, /* 55699 (1461) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    34133441, /* 55700 (1461) [-1,  0,  0, -1,  1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    34026357, /* 55701 (1461) [ 1, -1,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
      125913, /* 55702 (1461) [ 0, -1,  0,  1, -1,  0,  0,  0, -1] [ 0,  0,  6]  1 */
        5225, /* 55703 (1461) [-1,  1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  0]  1 */
        7817, /* 55704 (1461) [ 0, -1,  0,  1, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34144457, /* 55705 (1461) [ 1, -1,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
      123321, /* 55706 (1461) [-1,  1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  6]  1 */
       16484, /* 55707 (1462) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
      134580, /* 55708 (1462) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  6]  1 */
       12270, /* 55709 (1462) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    34135547, /* 55710 (1462) [-1,  1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    34020039, /* 55711 (1462) [ 0, -1,  0,  1, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    34138139, /* 55712 (1462) [ 0, -1,  0,  1, -1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    34146806, /* 55713 (1462) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    34133439, /* 55714 (1462) [-1,  0,  0, -1,  1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
    34024496, /* 55715 (1462) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    34015343, /* 55716 (1462) [-1,  0,  0, -1,  1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    34144455, /* 55717 (1462) [ 1, -1,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
    34026359, /* 55718 (1462) [ 1, -1,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    34017447, /* 55719 (1462) [-1,  1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  0] -1 */
      125913, /* 55720 (1462) [ 0, -1,  0,  1, -1,  0,  0,  0, -1] [ 0,  0,  6]  1 */
        5225, /* 55721 (1462) [-1,  1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34028706, /* 55722 (1462) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
        7817, /* 55723 (1462) [ 0, -1,  0,  1, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34142592, /* 55724 (1462) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  6] -1 */
        3117, /* 55725 (1462) [-1,  0,  0, -1,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
      121217, /* 55726 (1462) [-1,  0,  0, -1,  1,  0,  0,  0,  1] [ 0,  0,  6]  1 */
      130370, /* 55727 (1462) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 0,  0,  6]  1 */
       14133, /* 55728 (1462) [ 1, -1,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
      132233, /* 55729 (1462) [ 1, -1,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6]  1 */
      123321, /* 55730 (1462) [-1,  1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  6]  1 */
       16484, /* 55731 (1463) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
       16563, /* 55732 (1463) [ 1,  0,  0,  1, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
       12270, /* 55733 (1463) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  0]  1 */
        3198, /* 55734 (1463) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
       16565, /* 55735 (1463) [ 1,  0,  0,  1, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
        7410, /* 55736 (1463) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  0]  1 */
       14459, /* 55737 (1463) [ 1, -1,  0,  1,  0,  0,  0,  0,  1] [ 0,  0,  0]  1 */
        5547, /* 55738 (1463) [-1,  1,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
        7815, /* 55739 (1463) [ 0, -1,  0,  1, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
       14457, /* 55740 (1463) [ 1, -1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  0]  1 */
        5225, /* 55741 (1463) [-1,  1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  0]  1 */
        7817, /* 55742 (1463) [ 0, -1,  0,  1, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
       11867, /* 55743 (1463) [ 0,  1,  0, -1,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
        3200, /* 55744 (1463) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
        3119, /* 55745 (1463) [-1,  0,  0, -1,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
        3117, /* 55746 (1463) [-1,  0,  0, -1,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
       12272, /* 55747 (1463) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 0,  0,  0]  1 */
       14135, /* 55748 (1463) [ 1, -1,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
        7412, /* 55749 (1463) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  0]  1 */
        5223, /* 55750 (1463) [-1,  1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  0]  1 */
       14133, /* 55751 (1463) [ 1, -1,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
        5549, /* 55752 (1463) [-1,  1,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
       16482, /* 55753 (1463) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
       11865, /* 55754 (1463) [ 0,  1,  0, -1,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
       16484, /* 55755 (1464) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34026683, /* 55756 (1464) [ 1, -1,  0,  1,  0,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    34019634, /* 55757 (1464) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  0] -1 */
       16563, /* 55758 (1464) [ 1,  0,  0,  1, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    34017771, /* 55759 (1464) [-1,  1,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
       12270, /* 55760 (1464) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  0]  1 */
        3198, /* 55761 (1464) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
       16565, /* 55762 (1464) [ 1,  0,  0,  1, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34020039, /* 55763 (1464) [ 0, -1,  0,  1, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    34017449, /* 55764 (1464) [-1,  1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    34026681, /* 55765 (1464) [ 1, -1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    34024091, /* 55766 (1464) [ 0,  1,  0, -1,  1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    34020041, /* 55767 (1464) [ 0, -1,  0,  1, -1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
        7410, /* 55768 (1464) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  0]  1 */
       14459, /* 55769 (1464) [ 1, -1,  0,  1,  0,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34015424, /* 55770 (1464) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
        5547, /* 55771 (1464) [-1,  1,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    34028708, /* 55772 (1464) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    34024496, /* 55773 (1464) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    34015343, /* 55774 (1464) [-1,  0,  0, -1,  1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    34015341, /* 55775 (1464) [-1,  0,  0, -1,  1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
        7815, /* 55776 (1464) [ 0, -1,  0,  1, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    34026359, /* 55777 (1464) [ 1, -1,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
       14457, /* 55778 (1464) [ 1, -1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    34019636, /* 55779 (1464) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    34017447, /* 55780 (1464) [-1,  1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    34026357, /* 55781 (1464) [ 1, -1,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    34017773, /* 55782 (1464) [-1,  1,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
        5225, /* 55783 (1464) [-1,  1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34028706, /* 55784 (1464) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
        7817, /* 55785 (1464) [ 0, -1,  0,  1, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34024089, /* 55786 (1464) [ 0,  1,  0, -1,  1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
       11867, /* 55787 (1464) [ 0,  1,  0, -1,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34028787, /* 55788 (1464) [ 1,  0,  0,  1, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    34015422, /* 55789 (1464) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
        3200, /* 55790 (1464) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
        3119, /* 55791 (1464) [-1,  0,  0, -1,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34024494, /* 55792 (1464) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  0] -1 */
        3117, /* 55793 (1464) [-1,  0,  0, -1,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
       12272, /* 55794 (1464) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34028789, /* 55795 (1464) [ 1,  0,  0,  1, -1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
       14135, /* 55796 (1464) [ 1, -1,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
        7412, /* 55797 (1464) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  0]  1 */
        5223, /* 55798 (1464) [-1,  1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  0]  1 */
       14133, /* 55799 (1464) [ 1, -1,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
        5549, /* 55800 (1464) [-1,  1,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
       16482, /* 55801 (1464) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
       11865, /* 55802 (1464) [ 0,  1,  0, -1,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
       16484, /* 55803 (1465) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34019634, /* 55804 (1465) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    34017771, /* 55805 (1465) [-1,  1,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
       16565, /* 55806 (1465) [ 1,  0,  0,  1, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34020039, /* 55807 (1465) [ 0, -1,  0,  1, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    34026681, /* 55808 (1465) [ 1, -1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  0] -1 */
       14459, /* 55809 (1465) [ 1, -1,  0,  1,  0,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34015341, /* 55810 (1465) [-1,  0,  0, -1,  1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    34017447, /* 55811 (1465) [-1,  1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    34026357, /* 55812 (1465) [ 1, -1,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
        5225, /* 55813 (1465) [-1,  1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34028706, /* 55814 (1465) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
        7817, /* 55815 (1465) [ 0, -1,  0,  1, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34024089, /* 55816 (1465) [ 0,  1,  0, -1,  1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
       11867, /* 55817 (1465) [ 0,  1,  0, -1,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34028787, /* 55818 (1465) [ 1,  0,  0,  1, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    34015422, /* 55819 (1465) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
        3200, /* 55820 (1465) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
        3119, /* 55821 (1465) [-1,  0,  0, -1,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34024494, /* 55822 (1465) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  0] -1 */
       12272, /* 55823 (1465) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 0,  0,  0]  1 */
       14135, /* 55824 (1465) [ 1, -1,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
        7412, /* 55825 (1465) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  0]  1 */
        5549, /* 55826 (1465) [-1,  1,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
       16484, /* 55827 (1466) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34019634, /* 55828 (1466) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    34026683, /* 55829 (1466) [ 1, -1,  0,  1,  0,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    34017771, /* 55830 (1466) [-1,  1,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
       12270, /* 55831 (1466) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    34026681, /* 55832 (1466) [ 1, -1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    34024091, /* 55833 (1466) [ 0,  1,  0, -1,  1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    34015424, /* 55834 (1466) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
        7815, /* 55835 (1466) [ 0, -1,  0,  1, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    34019636, /* 55836 (1466) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    34017773, /* 55837 (1466) [-1,  1,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
        5225, /* 55838 (1466) [-1,  1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  0]  1 */
        7817, /* 55839 (1466) [ 0, -1,  0,  1, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34024089, /* 55840 (1466) [ 0,  1,  0, -1,  1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    34028787, /* 55841 (1466) [ 1,  0,  0,  1, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    34015422, /* 55842 (1466) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
        3119, /* 55843 (1466) [-1,  0,  0, -1,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
        3117, /* 55844 (1466) [-1,  0,  0, -1,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
       12272, /* 55845 (1466) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34028789, /* 55846 (1466) [ 1,  0,  0,  1, -1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
       14135, /* 55847 (1466) [ 1, -1,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
        5223, /* 55848 (1466) [-1,  1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  0]  1 */
       14133, /* 55849 (1466) [ 1, -1,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
       16482, /* 55850 (1466) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
       16484, /* 55851 (1467) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34026683, /* 55852 (1467) [ 1, -1,  0,  1,  0,  0,  0,  0,  1] [ 0,  0,  0] -1 */
       16563, /* 55853 (1467) [ 1,  0,  0,  1, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
       16565, /* 55854 (1467) [ 1,  0,  0,  1, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34026681, /* 55855 (1467) [ 1, -1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    34024091, /* 55856 (1467) [ 0,  1,  0, -1,  1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
        7410, /* 55857 (1467) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    34015424, /* 55858 (1467) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
        5547, /* 55859 (1467) [-1,  1,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    34024496, /* 55860 (1467) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    34015343, /* 55861 (1467) [-1,  0,  0, -1,  1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    34015341, /* 55862 (1467) [-1,  0,  0, -1,  1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
        7815, /* 55863 (1467) [ 0, -1,  0,  1, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    34026359, /* 55864 (1467) [ 1, -1,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    34026357, /* 55865 (1467) [ 1, -1,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
        5225, /* 55866 (1467) [-1,  1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  0]  1 */
        7817, /* 55867 (1467) [ 0, -1,  0,  1, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34024089, /* 55868 (1467) [ 0,  1,  0, -1,  1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    34015422, /* 55869 (1467) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    34024494, /* 55870 (1467) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  0] -1 */
        7412, /* 55871 (1467) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  0]  1 */
        5223, /* 55872 (1467) [-1,  1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  0]  1 */
        5549, /* 55873 (1467) [-1,  1,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
       16482, /* 55874 (1467) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
       16484, /* 55875 (1468) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34026683, /* 55876 (1468) [ 1, -1,  0,  1,  0,  0,  0,  0,  1] [ 0,  0,  0] -1 */
       16563, /* 55877 (1468) [ 1,  0,  0,  1, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
        3198, /* 55878 (1468) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    34020039, /* 55879 (1468) [ 0, -1,  0,  1, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    34024091, /* 55880 (1468) [ 0,  1,  0, -1,  1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
        7410, /* 55881 (1468) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    34015424, /* 55882 (1468) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
        5547, /* 55883 (1468) [-1,  1,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    34015341, /* 55884 (1468) [-1,  0,  0, -1,  1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
       14457, /* 55885 (1468) [ 1, -1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    34019636, /* 55886 (1468) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    34017447, /* 55887 (1468) [-1,  1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    34026357, /* 55888 (1468) [ 1, -1,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    34017773, /* 55889 (1468) [-1,  1,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    34028706, /* 55890 (1468) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
        5225, /* 55891 (1468) [-1,  1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  0]  1 */
        7817, /* 55892 (1468) [ 0, -1,  0,  1, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
        3119, /* 55893 (1468) [-1,  0,  0, -1,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34024494, /* 55894 (1468) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  0] -1 */
       12272, /* 55895 (1468) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34028789, /* 55896 (1468) [ 1,  0,  0,  1, -1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
       14135, /* 55897 (1468) [ 1, -1,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
       11865, /* 55898 (1468) [ 0,  1,  0, -1,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
       16484, /* 55899 (1469) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34019634, /* 55900 (1469) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    34026683, /* 55901 (1469) [ 1, -1,  0,  1,  0,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    34017771, /* 55902 (1469) [-1,  1,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
       12270, /* 55903 (1469) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  0]  1 */
        3198, /* 55904 (1469) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
       16565, /* 55905 (1469) [ 1,  0,  0,  1, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34020039, /* 55906 (1469) [ 0, -1,  0,  1, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    34024091, /* 55907 (1469) [ 0,  1,  0, -1,  1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    34015424, /* 55908 (1469) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    34024496, /* 55909 (1469) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    34015343, /* 55910 (1469) [-1,  0,  0, -1,  1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    34026359, /* 55911 (1469) [ 1, -1,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
       14457, /* 55912 (1469) [ 1, -1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    34017447, /* 55913 (1469) [-1,  1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    34028706, /* 55914 (1469) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
        5225, /* 55915 (1469) [-1,  1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  0]  1 */
        7817, /* 55916 (1469) [ 0, -1,  0,  1, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34028787, /* 55917 (1469) [ 1,  0,  0,  1, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
        3117, /* 55918 (1469) [-1,  0,  0, -1,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
        7412, /* 55919 (1469) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  0]  1 */
       14133, /* 55920 (1469) [ 1, -1,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
        5549, /* 55921 (1469) [-1,  1,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
       11865, /* 55922 (1469) [ 0,  1,  0, -1,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
       16484, /* 55923 (1470) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34019634, /* 55924 (1470) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    34017771, /* 55925 (1470) [-1,  1,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
        3198, /* 55926 (1470) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
       14459, /* 55927 (1470) [ 1, -1,  0,  1,  0,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34024496, /* 55928 (1470) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    34015343, /* 55929 (1470) [-1,  0,  0, -1,  1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    34015341, /* 55930 (1470) [-1,  0,  0, -1,  1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
        7815, /* 55931 (1470) [ 0, -1,  0,  1, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    34026359, /* 55932 (1470) [ 1, -1,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
       14457, /* 55933 (1470) [ 1, -1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    34019636, /* 55934 (1470) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    34017773, /* 55935 (1470) [-1,  1,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    34026357, /* 55936 (1470) [ 1, -1,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
        5225, /* 55937 (1470) [-1,  1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  0]  1 */
        7817, /* 55938 (1470) [ 0, -1,  0,  1, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
       11867, /* 55939 (1470) [ 0,  1,  0, -1,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34028787, /* 55940 (1470) [ 1,  0,  0,  1, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
        3200, /* 55941 (1470) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34024494, /* 55942 (1470) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    34028789, /* 55943 (1470) [ 1,  0,  0,  1, -1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
        5223, /* 55944 (1470) [-1,  1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  0]  1 */
       16482, /* 55945 (1470) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
       11865, /* 55946 (1470) [ 0,  1,  0, -1,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
       16484, /* 55947 (1471) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
       16563, /* 55948 (1471) [ 1,  0,  0,  1, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
       12270, /* 55949 (1471) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    34020039, /* 55950 (1471) [ 0, -1,  0,  1, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    34026681, /* 55951 (1471) [ 1, -1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  0] -1 */
        7410, /* 55952 (1471) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  0]  1 */
       14459, /* 55953 (1471) [ 1, -1,  0,  1,  0,  0,  0,  0,  1] [ 0,  0,  0]  1 */
        5547, /* 55954 (1471) [-1,  1,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    34024496, /* 55955 (1471) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    34015343, /* 55956 (1471) [-1,  0,  0, -1,  1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    34026359, /* 55957 (1471) [ 1, -1,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    34019636, /* 55958 (1471) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    34017447, /* 55959 (1471) [-1,  1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    34017773, /* 55960 (1471) [-1,  1,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
        5225, /* 55961 (1471) [-1,  1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34028706, /* 55962 (1471) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
        7817, /* 55963 (1471) [ 0, -1,  0,  1, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34024089, /* 55964 (1471) [ 0,  1,  0, -1,  1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
       11867, /* 55965 (1471) [ 0,  1,  0, -1,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34015422, /* 55966 (1471) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
        3200, /* 55967 (1471) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
        3117, /* 55968 (1471) [-1,  0,  0, -1,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    34028789, /* 55969 (1471) [ 1,  0,  0,  1, -1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
       14133, /* 55970 (1471) [ 1, -1,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
       16484, /* 55971 (1472) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34144781, /* 55972 (1472) [ 1, -1,  0,  1,  0,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    34137732, /* 55973 (1472) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  6] -1 */
    34135869, /* 55974 (1472) [-1,  1,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
       16563, /* 55975 (1472) [ 1,  0,  0,  1, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
       12270, /* 55976 (1472) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  0]  1 */
        3198, /* 55977 (1472) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
       16565, /* 55978 (1472) [ 1,  0,  0,  1, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34135547, /* 55979 (1472) [-1,  1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    34138139, /* 55980 (1472) [ 0, -1,  0,  1, -1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    34138137, /* 55981 (1472) [ 0, -1,  0,  1, -1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
    34144779, /* 55982 (1472) [ 1, -1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  6] -1 */
        7410, /* 55983 (1472) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    34146806, /* 55984 (1472) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
       14459, /* 55985 (1472) [ 1, -1,  0,  1,  0,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34142189, /* 55986 (1472) [ 0,  1,  0, -1,  1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
        5547, /* 55987 (1472) [-1,  1,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    34133439, /* 55988 (1472) [-1,  0,  0, -1,  1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
        7815, /* 55989 (1472) [ 0, -1,  0,  1, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    34133522, /* 55990 (1472) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    34142594, /* 55991 (1472) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    34144455, /* 55992 (1472) [ 1, -1,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
       14457, /* 55993 (1472) [ 1, -1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    34133441, /* 55994 (1472) [-1,  0,  0, -1,  1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
        5225, /* 55995 (1472) [-1,  1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34142187, /* 55996 (1472) [ 0,  1,  0, -1,  1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
        7817, /* 55997 (1472) [ 0, -1,  0,  1, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34144457, /* 55998 (1472) [ 1, -1,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    34137734, /* 55999 (1472) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    34135545, /* 56000 (1472) [-1,  1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  6] -1 */
       11867, /* 56001 (1472) [ 0,  1,  0, -1,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34135871, /* 56002 (1472) [-1,  1,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    34146804, /* 56003 (1472) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
    34146887, /* 56004 (1472) [ 1,  0,  0,  1, -1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    34142592, /* 56005 (1472) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  6] -1 */
        3200, /* 56006 (1472) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
        3119, /* 56007 (1472) [-1,  0,  0, -1,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
        3117, /* 56008 (1472) [-1,  0,  0, -1,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
       12272, /* 56009 (1472) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34146885, /* 56010 (1472) [ 1,  0,  0,  1, -1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
    34133520, /* 56011 (1472) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
       14135, /* 56012 (1472) [ 1, -1,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
        7412, /* 56013 (1472) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  0]  1 */
        5223, /* 56014 (1472) [-1,  1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  0]  1 */
       14133, /* 56015 (1472) [ 1, -1,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
        5549, /* 56016 (1472) [-1,  1,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
       16482, /* 56017 (1472) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
       11865, /* 56018 (1472) [ 0,  1,  0, -1,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
       16484, /* 56019 (1473) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
      123647, /* 56020 (1473) [-1,  1,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6]  1 */
      130368, /* 56021 (1473) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  6]  1 */
      134663, /* 56022 (1473) [ 1,  0,  0,  1, -1,  0,  0,  0,  1] [ 0,  0,  6]  1 */
        3198, /* 56023 (1473) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
      134661, /* 56024 (1473) [ 1,  0,  0,  1, -1,  0,  0,  0, -1] [ 0,  0,  6]  1 */
      125508, /* 56025 (1473) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  6]  1 */
      123645, /* 56026 (1473) [-1,  1,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  6]  1 */
       14459, /* 56027 (1473) [ 1, -1,  0,  1,  0,  0,  0,  0,  1] [ 0,  0,  0]  1 */
        7815, /* 56028 (1473) [ 0, -1,  0,  1, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
       14457, /* 56029 (1473) [ 1, -1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  0]  1 */
        5225, /* 56030 (1473) [-1,  1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  0]  1 */
        7817, /* 56031 (1473) [ 0, -1,  0,  1, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
       11867, /* 56032 (1473) [ 0,  1,  0, -1,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
      121215, /* 56033 (1473) [-1,  0,  0, -1,  1,  0,  0,  0, -1] [ 0,  0,  6]  1 */
        3200, /* 56034 (1473) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
      132231, /* 56035 (1473) [ 1, -1,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  6]  1 */
      121217, /* 56036 (1473) [-1,  0,  0, -1,  1,  0,  0,  0,  1] [ 0,  0,  6]  1 */
        5223, /* 56037 (1473) [-1,  1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  0]  1 */
      130370, /* 56038 (1473) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 0,  0,  6]  1 */
      132233, /* 56039 (1473) [ 1, -1,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6]  1 */
      125510, /* 56040 (1473) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  6]  1 */
       16482, /* 56041 (1473) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
       11865, /* 56042 (1473) [ 0,  1,  0, -1,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
       16484, /* 56043 (1474) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34137732, /* 56044 (1474) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  6] -1 */
    34135869, /* 56045 (1474) [-1,  1,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
      123647, /* 56046 (1474) [-1,  1,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6]  1 */
    34026683, /* 56047 (1474) [ 1, -1,  0,  1,  0,  0,  0,  0,  1] [ 0,  0,  0] -1 */
      130368, /* 56048 (1474) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  6]  1 */
      134663, /* 56049 (1474) [ 1,  0,  0,  1, -1,  0,  0,  0,  1] [ 0,  0,  6]  1 */
        3198, /* 56050 (1474) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
      134661, /* 56051 (1474) [ 1,  0,  0,  1, -1,  0,  0,  0, -1] [ 0,  0,  6]  1 */
    34020039, /* 56052 (1474) [ 0, -1,  0,  1, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    34017449, /* 56053 (1474) [-1,  1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    34026681, /* 56054 (1474) [ 1, -1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  0] -1 */
      125508, /* 56055 (1474) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  6]  1 */
    34024091, /* 56056 (1474) [ 0,  1,  0, -1,  1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    34020041, /* 56057 (1474) [ 0, -1,  0,  1, -1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
      123645, /* 56058 (1474) [-1,  1,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  6]  1 */
       14459, /* 56059 (1474) [ 1, -1,  0,  1,  0,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34015424, /* 56060 (1474) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    34028708, /* 56061 (1474) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    34133439, /* 56062 (1474) [-1,  0,  0, -1,  1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
        7815, /* 56063 (1474) [ 0, -1,  0,  1, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    34142594, /* 56064 (1474) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    34144455, /* 56065 (1474) [ 1, -1,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
       14457, /* 56066 (1474) [ 1, -1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    34133441, /* 56067 (1474) [-1,  0,  0, -1,  1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    34017447, /* 56068 (1474) [-1,  1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  0] -1 */
        5225, /* 56069 (1474) [-1,  1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34028706, /* 56070 (1474) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
        7817, /* 56071 (1474) [ 0, -1,  0,  1, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34144457, /* 56072 (1474) [ 1, -1,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    34137734, /* 56073 (1474) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    34024089, /* 56074 (1474) [ 0,  1,  0, -1,  1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
       11867, /* 56075 (1474) [ 0,  1,  0, -1,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34135871, /* 56076 (1474) [-1,  1,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    34146887, /* 56077 (1474) [ 1,  0,  0,  1, -1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    34142592, /* 56078 (1474) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  6] -1 */
      121215, /* 56079 (1474) [-1,  0,  0, -1,  1,  0,  0,  0, -1] [ 0,  0,  6]  1 */
    34015422, /* 56080 (1474) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
        3200, /* 56081 (1474) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34146885, /* 56082 (1474) [ 1,  0,  0,  1, -1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
      132231, /* 56083 (1474) [ 1, -1,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  6]  1 */
      121217, /* 56084 (1474) [-1,  0,  0, -1,  1,  0,  0,  0,  1] [ 0,  0,  6]  1 */
        5223, /* 56085 (1474) [-1,  1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  0]  1 */
      130370, /* 56086 (1474) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 0,  0,  6]  1 */
      132233, /* 56087 (1474) [ 1, -1,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6]  1 */
      125510, /* 56088 (1474) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  6]  1 */
       16482, /* 56089 (1474) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
       11865, /* 56090 (1474) [ 0,  1,  0, -1,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
       16484, /* 56091 (1475) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34137732, /* 56092 (1475) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  6] -1 */
    34135869, /* 56093 (1475) [-1,  1,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
      123647, /* 56094 (1475) [-1,  1,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6]  1 */
      134663, /* 56095 (1475) [ 1,  0,  0,  1, -1,  0,  0,  0,  1] [ 0,  0,  6]  1 */
    34020039, /* 56096 (1475) [ 0, -1,  0,  1, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    34026681, /* 56097 (1475) [ 1, -1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  0] -1 */
       14459, /* 56098 (1475) [ 1, -1,  0,  1,  0,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34133439, /* 56099 (1475) [-1,  0,  0, -1,  1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
    34144455, /* 56100 (1475) [ 1, -1,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
    34017447, /* 56101 (1475) [-1,  1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  0] -1 */
        5225, /* 56102 (1475) [-1,  1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34028706, /* 56103 (1475) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
        7817, /* 56104 (1475) [ 0, -1,  0,  1, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34024089, /* 56105 (1475) [ 0,  1,  0, -1,  1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
       11867, /* 56106 (1475) [ 0,  1,  0, -1,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34142592, /* 56107 (1475) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  6] -1 */
    34015422, /* 56108 (1475) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
        3200, /* 56109 (1475) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34146885, /* 56110 (1475) [ 1,  0,  0,  1, -1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
      121217, /* 56111 (1475) [-1,  0,  0, -1,  1,  0,  0,  0,  1] [ 0,  0,  6]  1 */
      130370, /* 56112 (1475) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 0,  0,  6]  1 */
      132233, /* 56113 (1475) [ 1, -1,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6]  1 */
      125510, /* 56114 (1475) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  6]  1 */
       16484, /* 56115 (1476) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34137732, /* 56116 (1476) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  6] -1 */
    34135869, /* 56117 (1476) [-1,  1,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
    34026683, /* 56118 (1476) [ 1, -1,  0,  1,  0,  0,  0,  0,  1] [ 0,  0,  0] -1 */
      130368, /* 56119 (1476) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  6]  1 */
    34026681, /* 56120 (1476) [ 1, -1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    34024091, /* 56121 (1476) [ 0,  1,  0, -1,  1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    34015424, /* 56122 (1476) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
        7815, /* 56123 (1476) [ 0, -1,  0,  1, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
        5225, /* 56124 (1476) [-1,  1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  0]  1 */
        7817, /* 56125 (1476) [ 0, -1,  0,  1, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34137734, /* 56126 (1476) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    34024089, /* 56127 (1476) [ 0,  1,  0, -1,  1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    34135871, /* 56128 (1476) [-1,  1,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    34146887, /* 56129 (1476) [ 1,  0,  0,  1, -1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
      121215, /* 56130 (1476) [-1,  0,  0, -1,  1,  0,  0,  0, -1] [ 0,  0,  6]  1 */
    34015422, /* 56131 (1476) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    34146885, /* 56132 (1476) [ 1,  0,  0,  1, -1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
      132231, /* 56133 (1476) [ 1, -1,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  6]  1 */
      121217, /* 56134 (1476) [-1,  0,  0, -1,  1,  0,  0,  0,  1] [ 0,  0,  6]  1 */
        5223, /* 56135 (1476) [-1,  1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  0]  1 */
      130370, /* 56136 (1476) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 0,  0,  6]  1 */
      132233, /* 56137 (1476) [ 1, -1,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6]  1 */
       16482, /* 56138 (1476) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
       16484, /* 56139 (1477) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
      123647, /* 56140 (1477) [-1,  1,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6]  1 */
    34026683, /* 56141 (1477) [ 1, -1,  0,  1,  0,  0,  0,  0,  1] [ 0,  0,  0] -1 */
      134663, /* 56142 (1477) [ 1,  0,  0,  1, -1,  0,  0,  0,  1] [ 0,  0,  6]  1 */
      134661, /* 56143 (1477) [ 1,  0,  0,  1, -1,  0,  0,  0, -1] [ 0,  0,  6]  1 */
    34026681, /* 56144 (1477) [ 1, -1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  0] -1 */
      125508, /* 56145 (1477) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  6]  1 */
    34024091, /* 56146 (1477) [ 0,  1,  0, -1,  1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
      123645, /* 56147 (1477) [-1,  1,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  6]  1 */
    34015424, /* 56148 (1477) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    34133439, /* 56149 (1477) [-1,  0,  0, -1,  1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
        7815, /* 56150 (1477) [ 0, -1,  0,  1, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    34142594, /* 56151 (1477) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    34144455, /* 56152 (1477) [ 1, -1,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
    34133441, /* 56153 (1477) [-1,  0,  0, -1,  1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
        5225, /* 56154 (1477) [-1,  1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  0]  1 */
        7817, /* 56155 (1477) [ 0, -1,  0,  1, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34144457, /* 56156 (1477) [ 1, -1,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    34024089, /* 56157 (1477) [ 0,  1,  0, -1,  1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    34142592, /* 56158 (1477) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  6] -1 */
    34015422, /* 56159 (1477) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
        5223, /* 56160 (1477) [-1,  1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  0]  1 */
      125510, /* 56161 (1477) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  6]  1 */
       16482, /* 56162 (1477) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
       16484, /* 56163 (1478) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34026683, /* 56164 (1478) [ 1, -1,  0,  1,  0,  0,  0,  0,  1] [ 0,  0,  0] -1 */
        3198, /* 56165 (1478) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
      134661, /* 56166 (1478) [ 1,  0,  0,  1, -1,  0,  0,  0, -1] [ 0,  0,  6]  1 */
    34020039, /* 56167 (1478) [ 0, -1,  0,  1, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
      125508, /* 56168 (1478) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  6]  1 */
    34024091, /* 56169 (1478) [ 0,  1,  0, -1,  1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
      123645, /* 56170 (1478) [-1,  1,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  6]  1 */
    34015424, /* 56171 (1478) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    34133439, /* 56172 (1478) [-1,  0,  0, -1,  1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
    34144455, /* 56173 (1478) [ 1, -1,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
       14457, /* 56174 (1478) [ 1, -1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    34017447, /* 56175 (1478) [-1,  1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    34028706, /* 56176 (1478) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
        5225, /* 56177 (1478) [-1,  1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  0]  1 */
        7817, /* 56178 (1478) [ 0, -1,  0,  1, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34137734, /* 56179 (1478) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    34135871, /* 56180 (1478) [-1,  1,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    34146887, /* 56181 (1478) [ 1,  0,  0,  1, -1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    34142592, /* 56182 (1478) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  6] -1 */
      121217, /* 56183 (1478) [-1,  0,  0, -1,  1,  0,  0,  0,  1] [ 0,  0,  6]  1 */
      130370, /* 56184 (1478) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 0,  0,  6]  1 */
      132233, /* 56185 (1478) [ 1, -1,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6]  1 */
       11865, /* 56186 (1478) [ 0,  1,  0, -1,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
       16484, /* 56187 (1479) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34137732, /* 56188 (1479) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  6] -1 */
    34135869, /* 56189 (1479) [-1,  1,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
      123647, /* 56190 (1479) [-1,  1,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6]  1 */
    34026683, /* 56191 (1479) [ 1, -1,  0,  1,  0,  0,  0,  0,  1] [ 0,  0,  0] -1 */
      130368, /* 56192 (1479) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  6]  1 */
      134663, /* 56193 (1479) [ 1,  0,  0,  1, -1,  0,  0,  0,  1] [ 0,  0,  6]  1 */
        3198, /* 56194 (1479) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    34020039, /* 56195 (1479) [ 0, -1,  0,  1, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    34024091, /* 56196 (1479) [ 0,  1,  0, -1,  1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    34015424, /* 56197 (1479) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    34142594, /* 56198 (1479) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 0,  0,  6] -1 */
       14457, /* 56199 (1479) [ 1, -1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    34133441, /* 56200 (1479) [-1,  0,  0, -1,  1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    34017447, /* 56201 (1479) [-1,  1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    34028706, /* 56202 (1479) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
        5225, /* 56203 (1479) [-1,  1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  0]  1 */
        7817, /* 56204 (1479) [ 0, -1,  0,  1, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34144457, /* 56205 (1479) [ 1, -1,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
      121215, /* 56206 (1479) [-1,  0,  0, -1,  1,  0,  0,  0, -1] [ 0,  0,  6]  1 */
    34146885, /* 56207 (1479) [ 1,  0,  0,  1, -1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
      132231, /* 56208 (1479) [ 1, -1,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  6]  1 */
      125510, /* 56209 (1479) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  6]  1 */
       11865, /* 56210 (1479) [ 0,  1,  0, -1,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
       16484, /* 56211 (1480) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34137732, /* 56212 (1480) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  6] -1 */
    34135869, /* 56213 (1480) [-1,  1,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
        3198, /* 56214 (1480) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
       14459, /* 56215 (1480) [ 1, -1,  0,  1,  0,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34133439, /* 56216 (1480) [-1,  0,  0, -1,  1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
        7815, /* 56217 (1480) [ 0, -1,  0,  1, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    34142594, /* 56218 (1480) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    34144455, /* 56219 (1480) [ 1, -1,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
       14457, /* 56220 (1480) [ 1, -1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    34133441, /* 56221 (1480) [-1,  0,  0, -1,  1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
        5225, /* 56222 (1480) [-1,  1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  0]  1 */
        7817, /* 56223 (1480) [ 0, -1,  0,  1, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34144457, /* 56224 (1480) [ 1, -1,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    34137734, /* 56225 (1480) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  6] -1 */
       11867, /* 56226 (1480) [ 0,  1,  0, -1,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34135871, /* 56227 (1480) [-1,  1,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    34146887, /* 56228 (1480) [ 1,  0,  0,  1, -1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    34142592, /* 56229 (1480) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  6] -1 */
        3200, /* 56230 (1480) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34146885, /* 56231 (1480) [ 1,  0,  0,  1, -1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
        5223, /* 56232 (1480) [-1,  1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  0]  1 */
       16482, /* 56233 (1480) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
       11865, /* 56234 (1480) [ 0,  1,  0, -1,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
       16484, /* 56235 (1481) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
      130368, /* 56236 (1481) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  6]  1 */
      134661, /* 56237 (1481) [ 1,  0,  0,  1, -1,  0,  0,  0, -1] [ 0,  0,  6]  1 */
    34020039, /* 56238 (1481) [ 0, -1,  0,  1, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    34026681, /* 56239 (1481) [ 1, -1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  0] -1 */
      125508, /* 56240 (1481) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  6]  1 */
      123645, /* 56241 (1481) [-1,  1,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  6]  1 */
       14459, /* 56242 (1481) [ 1, -1,  0,  1,  0,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34142594, /* 56243 (1481) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    34133441, /* 56244 (1481) [-1,  0,  0, -1,  1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    34017447, /* 56245 (1481) [-1,  1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  0] -1 */
        5225, /* 56246 (1481) [-1,  1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34028706, /* 56247 (1481) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
        7817, /* 56248 (1481) [ 0, -1,  0,  1, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34144457, /* 56249 (1481) [ 1, -1,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    34137734, /* 56250 (1481) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    34024089, /* 56251 (1481) [ 0,  1,  0, -1,  1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
       11867, /* 56252 (1481) [ 0,  1,  0, -1,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34135871, /* 56253 (1481) [-1,  1,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    34146887, /* 56254 (1481) [ 1,  0,  0,  1, -1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
      121215, /* 56255 (1481) [-1,  0,  0, -1,  1,  0,  0,  0, -1] [ 0,  0,  6]  1 */
    34015422, /* 56256 (1481) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
        3200, /* 56257 (1481) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
      132231, /* 56258 (1481) [ 1, -1,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  6]  1 */
       16484, /* 56259 (1482) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34144781, /* 56260 (1482) [ 1, -1,  0,  1,  0,  0,  0,  0,  1] [ 0,  0,  6] -1 */
      123647, /* 56261 (1482) [-1,  1,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6]  1 */
    34019634, /* 56262 (1482) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  0] -1 */
      130368, /* 56263 (1482) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  6]  1 */
      134663, /* 56264 (1482) [ 1,  0,  0,  1, -1,  0,  0,  0,  1] [ 0,  0,  6]  1 */
    34017771, /* 56265 (1482) [-1,  1,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
        3198, /* 56266 (1482) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
      134661, /* 56267 (1482) [ 1,  0,  0,  1, -1,  0,  0,  0, -1] [ 0,  0,  6]  1 */
    34135547, /* 56268 (1482) [-1,  1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    34138139, /* 56269 (1482) [ 0, -1,  0,  1, -1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    34138137, /* 56270 (1482) [ 0, -1,  0,  1, -1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
      125508, /* 56271 (1482) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  6]  1 */
    34144779, /* 56272 (1482) [ 1, -1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  6] -1 */
      123645, /* 56273 (1482) [-1,  1,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  6]  1 */
    34146806, /* 56274 (1482) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
       14459, /* 56275 (1482) [ 1, -1,  0,  1,  0,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34142189, /* 56276 (1482) [ 0,  1,  0, -1,  1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    34024496, /* 56277 (1482) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    34015343, /* 56278 (1482) [-1,  0,  0, -1,  1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    34015341, /* 56279 (1482) [-1,  0,  0, -1,  1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
        7815, /* 56280 (1482) [ 0, -1,  0,  1, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    34133522, /* 56281 (1482) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    34026359, /* 56282 (1482) [ 1, -1,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
       14457, /* 56283 (1482) [ 1, -1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    34019636, /* 56284 (1482) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    34017773, /* 56285 (1482) [-1,  1,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    34026357, /* 56286 (1482) [ 1, -1,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
        5225, /* 56287 (1482) [-1,  1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34142187, /* 56288 (1482) [ 0,  1,  0, -1,  1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
        7817, /* 56289 (1482) [ 0, -1,  0,  1, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34135545, /* 56290 (1482) [-1,  1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  6] -1 */
       11867, /* 56291 (1482) [ 0,  1,  0, -1,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34146804, /* 56292 (1482) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
    34028787, /* 56293 (1482) [ 1,  0,  0,  1, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
      121215, /* 56294 (1482) [-1,  0,  0, -1,  1,  0,  0,  0, -1] [ 0,  0,  6]  1 */
        3200, /* 56295 (1482) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34024494, /* 56296 (1482) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    34028789, /* 56297 (1482) [ 1,  0,  0,  1, -1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    34133520, /* 56298 (1482) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
      132231, /* 56299 (1482) [ 1, -1,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  6]  1 */
      121217, /* 56300 (1482) [-1,  0,  0, -1,  1,  0,  0,  0,  1] [ 0,  0,  6]  1 */
        5223, /* 56301 (1482) [-1,  1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  0]  1 */
      130370, /* 56302 (1482) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 0,  0,  6]  1 */
      132233, /* 56303 (1482) [ 1, -1,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6]  1 */
      125510, /* 56304 (1482) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  6]  1 */
       16482, /* 56305 (1482) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
       11865, /* 56306 (1482) [ 0,  1,  0, -1,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
       16484, /* 56307 (1483) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
      123647, /* 56308 (1483) [-1,  1,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6]  1 */
       16563, /* 56309 (1483) [ 1,  0,  0,  1, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
      134580, /* 56310 (1483) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  6]  1 */
      130368, /* 56311 (1483) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  6]  1 */
      134663, /* 56312 (1483) [ 1,  0,  0,  1, -1,  0,  0,  0,  1] [ 0,  0,  6]  1 */
        3198, /* 56313 (1483) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
        7410, /* 56314 (1483) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  0]  1 */
      132557, /* 56315 (1483) [ 1, -1,  0,  1,  0,  0,  0,  0,  1] [ 0,  0,  6]  1 */
        5547, /* 56316 (1483) [-1,  1,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
       14457, /* 56317 (1483) [ 1, -1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  0]  1 */
      125913, /* 56318 (1483) [ 0, -1,  0,  1, -1,  0,  0,  0, -1] [ 0,  0,  6]  1 */
        5225, /* 56319 (1483) [-1,  1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  0]  1 */
        7817, /* 56320 (1483) [ 0, -1,  0,  1, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
      121215, /* 56321 (1483) [-1,  0,  0, -1,  1,  0,  0,  0, -1] [ 0,  0,  6]  1 */
      129965, /* 56322 (1483) [ 0,  1,  0, -1,  1,  0,  0,  0,  1] [ 0,  0,  6]  1 */
        3119, /* 56323 (1483) [-1,  0,  0, -1,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
       12272, /* 56324 (1483) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 0,  0,  0]  1 */
      132231, /* 56325 (1483) [ 1, -1,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  6]  1 */
       14135, /* 56326 (1483) [ 1, -1,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
      121298, /* 56327 (1483) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6]  1 */
      125510, /* 56328 (1483) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  6]  1 */
       11865, /* 56329 (1483) [ 0,  1,  0, -1,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
      123321, /* 56330 (1483) [-1,  1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  6]  1 */
       16484, /* 56331 (1484) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34144781, /* 56332 (1484) [ 1, -1,  0,  1,  0,  0,  0,  0,  1] [ 0,  0,  6] -1 */
      123647, /* 56333 (1484) [-1,  1,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6]  1 */
    34019634, /* 56334 (1484) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  0] -1 */
       16563, /* 56335 (1484) [ 1,  0,  0,  1, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
      134580, /* 56336 (1484) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  6]  1 */
      130368, /* 56337 (1484) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  6]  1 */
      134663, /* 56338 (1484) [ 1,  0,  0,  1, -1,  0,  0,  0,  1] [ 0,  0,  6]  1 */
    34017771, /* 56339 (1484) [-1,  1,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
        3198, /* 56340 (1484) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    34017449, /* 56341 (1484) [-1,  1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    34026681, /* 56342 (1484) [ 1, -1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    34138137, /* 56343 (1484) [ 0, -1,  0,  1, -1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
    34020041, /* 56344 (1484) [ 0, -1,  0,  1, -1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
        7410, /* 56345 (1484) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  0]  1 */
      132557, /* 56346 (1484) [ 1, -1,  0,  1,  0,  0,  0,  0,  1] [ 0,  0,  6]  1 */
    34142189, /* 56347 (1484) [ 0,  1,  0, -1,  1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
        5547, /* 56348 (1484) [-1,  1,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    34028708, /* 56349 (1484) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    34024496, /* 56350 (1484) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    34133439, /* 56351 (1484) [-1,  0,  0, -1,  1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
    34015343, /* 56352 (1484) [-1,  0,  0, -1,  1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    34133522, /* 56353 (1484) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    34144455, /* 56354 (1484) [ 1, -1,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
       14457, /* 56355 (1484) [ 1, -1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    34026359, /* 56356 (1484) [ 1, -1,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
      125913, /* 56357 (1484) [ 0, -1,  0,  1, -1,  0,  0,  0, -1] [ 0,  0,  6]  1 */
        5225, /* 56358 (1484) [-1,  1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  0]  1 */
        7817, /* 56359 (1484) [ 0, -1,  0,  1, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34137734, /* 56360 (1484) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    34024089, /* 56361 (1484) [ 0,  1,  0, -1,  1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    34135545, /* 56362 (1484) [-1,  1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  6] -1 */
    34135871, /* 56363 (1484) [-1,  1,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    34146804, /* 56364 (1484) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
    34146887, /* 56365 (1484) [ 1,  0,  0,  1, -1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    34028787, /* 56366 (1484) [ 1,  0,  0,  1, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    34142592, /* 56367 (1484) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  6] -1 */
      121215, /* 56368 (1484) [-1,  0,  0, -1,  1,  0,  0,  0, -1] [ 0,  0,  6]  1 */
    34015422, /* 56369 (1484) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
      129965, /* 56370 (1484) [ 0,  1,  0, -1,  1,  0,  0,  0,  1] [ 0,  0,  6]  1 */
        3119, /* 56371 (1484) [-1,  0,  0, -1,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
       12272, /* 56372 (1484) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 0,  0,  0]  1 */
      132231, /* 56373 (1484) [ 1, -1,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  6]  1 */
       14135, /* 56374 (1484) [ 1, -1,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
      121298, /* 56375 (1484) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6]  1 */
      125510, /* 56376 (1484) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  6]  1 */
       11865, /* 56377 (1484) [ 0,  1,  0, -1,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
      123321, /* 56378 (1484) [-1,  1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  6]  1 */
       16484, /* 56379 (1485) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
      123647, /* 56380 (1485) [-1,  1,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6]  1 */
    34019634, /* 56381 (1485) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    34017771, /* 56382 (1485) [-1,  1,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
      134663, /* 56383 (1485) [ 1,  0,  0,  1, -1,  0,  0,  0,  1] [ 0,  0,  6]  1 */
    34026681, /* 56384 (1485) [ 1, -1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    34138137, /* 56385 (1485) [ 0, -1,  0,  1, -1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
      132557, /* 56386 (1485) [ 1, -1,  0,  1,  0,  0,  0,  0,  1] [ 0,  0,  6]  1 */
    34133439, /* 56387 (1485) [-1,  0,  0, -1,  1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
    34144455, /* 56388 (1485) [ 1, -1,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
        5225, /* 56389 (1485) [-1,  1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  0]  1 */
        7817, /* 56390 (1485) [ 0, -1,  0,  1, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34024089, /* 56391 (1485) [ 0,  1,  0, -1,  1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    34135545, /* 56392 (1485) [-1,  1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  6] -1 */
    34146804, /* 56393 (1485) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
    34028787, /* 56394 (1485) [ 1,  0,  0,  1, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    34142592, /* 56395 (1485) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  6] -1 */
      129965, /* 56396 (1485) [ 0,  1,  0, -1,  1,  0,  0,  0,  1] [ 0,  0,  6]  1 */
    34015422, /* 56397 (1485) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
        3119, /* 56398 (1485) [-1,  0,  0, -1,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
       12272, /* 56399 (1485) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 0,  0,  0]  1 */
       14135, /* 56400 (1485) [ 1, -1,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
      121298, /* 56401 (1485) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6]  1 */
      125510, /* 56402 (1485) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  6]  1 */
       16484, /* 56403 (1486) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34144781, /* 56404 (1486) [ 1, -1,  0,  1,  0,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    34019634, /* 56405 (1486) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  0] -1 */
      134580, /* 56406 (1486) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  6]  1 */
      130368, /* 56407 (1486) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  6]  1 */
    34017771, /* 56408 (1486) [-1,  1,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    34026681, /* 56409 (1486) [ 1, -1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    34142189, /* 56410 (1486) [ 0,  1,  0, -1,  1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    34133522, /* 56411 (1486) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
        5225, /* 56412 (1486) [-1,  1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  0]  1 */
      125913, /* 56413 (1486) [ 0, -1,  0,  1, -1,  0,  0,  0, -1] [ 0,  0,  6]  1 */
        7817, /* 56414 (1486) [ 0, -1,  0,  1, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34137734, /* 56415 (1486) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    34024089, /* 56416 (1486) [ 0,  1,  0, -1,  1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    34135871, /* 56417 (1486) [-1,  1,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    34146887, /* 56418 (1486) [ 1,  0,  0,  1, -1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    34028787, /* 56419 (1486) [ 1,  0,  0,  1, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
      121215, /* 56420 (1486) [-1,  0,  0, -1,  1,  0,  0,  0, -1] [ 0,  0,  6]  1 */
    34015422, /* 56421 (1486) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
        3119, /* 56422 (1486) [-1,  0,  0, -1,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
       12272, /* 56423 (1486) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 0,  0,  0]  1 */
      132231, /* 56424 (1486) [ 1, -1,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  6]  1 */
       14135, /* 56425 (1486) [ 1, -1,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
      123321, /* 56426 (1486) [-1,  1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  6]  1 */
       16484, /* 56427 (1487) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34144781, /* 56428 (1487) [ 1, -1,  0,  1,  0,  0,  0,  0,  1] [ 0,  0,  6] -1 */
      123647, /* 56429 (1487) [-1,  1,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6]  1 */
       16563, /* 56430 (1487) [ 1,  0,  0,  1, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
      134580, /* 56431 (1487) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  6]  1 */
      134663, /* 56432 (1487) [ 1,  0,  0,  1, -1,  0,  0,  0,  1] [ 0,  0,  6]  1 */
    34026681, /* 56433 (1487) [ 1, -1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  0] -1 */
        7410, /* 56434 (1487) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    34142189, /* 56435 (1487) [ 0,  1,  0, -1,  1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
        5547, /* 56436 (1487) [-1,  1,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    34024496, /* 56437 (1487) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    34133439, /* 56438 (1487) [-1,  0,  0, -1,  1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
    34015343, /* 56439 (1487) [-1,  0,  0, -1,  1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    34133522, /* 56440 (1487) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    34144455, /* 56441 (1487) [ 1, -1,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
    34026359, /* 56442 (1487) [ 1, -1,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
        5225, /* 56443 (1487) [-1,  1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  0]  1 */
      125913, /* 56444 (1487) [ 0, -1,  0,  1, -1,  0,  0,  0, -1] [ 0,  0,  6]  1 */
        7817, /* 56445 (1487) [ 0, -1,  0,  1, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34024089, /* 56446 (1487) [ 0,  1,  0, -1,  1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    34142592, /* 56447 (1487) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  6] -1 */
    34015422, /* 56448 (1487) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
      125510, /* 56449 (1487) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  6]  1 */
      123321, /* 56450 (1487) [-1,  1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  6]  1 */
       16484, /* 56451 (1488) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34144781, /* 56452 (1488) [ 1, -1,  0,  1,  0,  0,  0,  0,  1] [ 0,  0,  6] -1 */
       16563, /* 56453 (1488) [ 1,  0,  0,  1, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
        3198, /* 56454 (1488) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    34138137, /* 56455 (1488) [ 0, -1,  0,  1, -1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
        7410, /* 56456 (1488) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    34142189, /* 56457 (1488) [ 0,  1,  0, -1,  1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
        5547, /* 56458 (1488) [-1,  1,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    34133439, /* 56459 (1488) [-1,  0,  0, -1,  1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
    34133522, /* 56460 (1488) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    34144455, /* 56461 (1488) [ 1, -1,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
       14457, /* 56462 (1488) [ 1, -1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  0]  1 */
        5225, /* 56463 (1488) [-1,  1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  0]  1 */
        7817, /* 56464 (1488) [ 0, -1,  0,  1, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34137734, /* 56465 (1488) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    34135871, /* 56466 (1488) [-1,  1,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    34146804, /* 56467 (1488) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
    34135545, /* 56468 (1488) [-1,  1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  6] -1 */
    34146887, /* 56469 (1488) [ 1,  0,  0,  1, -1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    34142592, /* 56470 (1488) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  6] -1 */
        3119, /* 56471 (1488) [-1,  0,  0, -1,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
       12272, /* 56472 (1488) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 0,  0,  0]  1 */
       14135, /* 56473 (1488) [ 1, -1,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
       11865, /* 56474 (1488) [ 0,  1,  0, -1,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
       16484, /* 56475 (1489) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34144781, /* 56476 (1489) [ 1, -1,  0,  1,  0,  0,  0,  0,  1] [ 0,  0,  6] -1 */
      123647, /* 56477 (1489) [-1,  1,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6]  1 */
    34019634, /* 56478 (1489) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  0] -1 */
      130368, /* 56479 (1489) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  6]  1 */
      134663, /* 56480 (1489) [ 1,  0,  0,  1, -1,  0,  0,  0,  1] [ 0,  0,  6]  1 */
    34017771, /* 56481 (1489) [-1,  1,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
        3198, /* 56482 (1489) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    34138137, /* 56483 (1489) [ 0, -1,  0,  1, -1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
    34142189, /* 56484 (1489) [ 0,  1,  0, -1,  1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    34024496, /* 56485 (1489) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    34015343, /* 56486 (1489) [-1,  0,  0, -1,  1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    34133522, /* 56487 (1489) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    34026359, /* 56488 (1489) [ 1, -1,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
       14457, /* 56489 (1489) [ 1, -1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  0]  1 */
        5225, /* 56490 (1489) [-1,  1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  0]  1 */
        7817, /* 56491 (1489) [ 0, -1,  0,  1, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34135545, /* 56492 (1489) [-1,  1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  6] -1 */
    34146804, /* 56493 (1489) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
    34028787, /* 56494 (1489) [ 1,  0,  0,  1, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
      121215, /* 56495 (1489) [-1,  0,  0, -1,  1,  0,  0,  0, -1] [ 0,  0,  6]  1 */
      132231, /* 56496 (1489) [ 1, -1,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  6]  1 */
      125510, /* 56497 (1489) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  6]  1 */
       11865, /* 56498 (1489) [ 0,  1,  0, -1,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
       16484, /* 56499 (1490) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34019634, /* 56500 (1490) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  0] -1 */
      134580, /* 56501 (1490) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  6]  1 */
    34017771, /* 56502 (1490) [-1,  1,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
        3198, /* 56503 (1490) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
      132557, /* 56504 (1490) [ 1, -1,  0,  1,  0,  0,  0,  0,  1] [ 0,  0,  6]  1 */
    34133439, /* 56505 (1490) [-1,  0,  0, -1,  1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
    34024496, /* 56506 (1490) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    34015343, /* 56507 (1490) [-1,  0,  0, -1,  1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    34144455, /* 56508 (1490) [ 1, -1,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
    34026359, /* 56509 (1490) [ 1, -1,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
       14457, /* 56510 (1490) [ 1, -1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  0]  1 */
      125913, /* 56511 (1490) [ 0, -1,  0,  1, -1,  0,  0,  0, -1] [ 0,  0,  6]  1 */
        5225, /* 56512 (1490) [-1,  1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  0]  1 */
        7817, /* 56513 (1490) [ 0, -1,  0,  1, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34137734, /* 56514 (1490) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    34135871, /* 56515 (1490) [-1,  1,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    34146887, /* 56516 (1490) [ 1,  0,  0,  1, -1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    34028787, /* 56517 (1490) [ 1,  0,  0,  1, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    34142592, /* 56518 (1490) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  6] -1 */
      129965, /* 56519 (1490) [ 0,  1,  0, -1,  1,  0,  0,  0,  1] [ 0,  0,  6]  1 */
      121298, /* 56520 (1490) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6]  1 */
       11865, /* 56521 (1490) [ 0,  1,  0, -1,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
      123321, /* 56522 (1490) [-1,  1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  6]  1 */
       16484, /* 56523 (1491) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
       16563, /* 56524 (1491) [ 1,  0,  0,  1, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
      130368, /* 56525 (1491) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  6]  1 */
    34026681, /* 56526 (1491) [ 1, -1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    34138137, /* 56527 (1491) [ 0, -1,  0,  1, -1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
        7410, /* 56528 (1491) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  0]  1 */
      132557, /* 56529 (1491) [ 1, -1,  0,  1,  0,  0,  0,  0,  1] [ 0,  0,  6]  1 */
        5547, /* 56530 (1491) [-1,  1,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    34024496, /* 56531 (1491) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    34015343, /* 56532 (1491) [-1,  0,  0, -1,  1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    34026359, /* 56533 (1491) [ 1, -1,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
        5225, /* 56534 (1491) [-1,  1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  0]  1 */
        7817, /* 56535 (1491) [ 0, -1,  0,  1, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34137734, /* 56536 (1491) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    34024089, /* 56537 (1491) [ 0,  1,  0, -1,  1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    34135871, /* 56538 (1491) [-1,  1,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    34146804, /* 56539 (1491) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
    34135545, /* 56540 (1491) [-1,  1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  6] -1 */
    34146887, /* 56541 (1491) [ 1,  0,  0,  1, -1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
      121215, /* 56542 (1491) [-1,  0,  0, -1,  1,  0,  0,  0, -1] [ 0,  0,  6]  1 */
    34015422, /* 56543 (1491) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
      129965, /* 56544 (1491) [ 0,  1,  0, -1,  1,  0,  0,  0,  1] [ 0,  0,  6]  1 */
      132231, /* 56545 (1491) [ 1, -1,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  6]  1 */
      121298, /* 56546 (1491) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6]  1 */
       16484, /* 56547 (1492) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34137732, /* 56548 (1492) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  6] -1 */
    34135869, /* 56549 (1492) [-1,  1,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
      123647, /* 56550 (1492) [-1,  1,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6]  1 */
    34026683, /* 56551 (1492) [ 1, -1,  0,  1,  0,  0,  0,  0,  1] [ 0,  0,  0] -1 */
       16563, /* 56552 (1492) [ 1,  0,  0,  1, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
      134580, /* 56553 (1492) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  6]  1 */
      130368, /* 56554 (1492) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  6]  1 */
      134663, /* 56555 (1492) [ 1,  0,  0,  1, -1,  0,  0,  0,  1] [ 0,  0,  6]  1 */
        3198, /* 56556 (1492) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    34135547, /* 56557 (1492) [-1,  1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    34020039, /* 56558 (1492) [ 0, -1,  0,  1, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    34138139, /* 56559 (1492) [ 0, -1,  0,  1, -1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    34024091, /* 56560 (1492) [ 0,  1,  0, -1,  1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    34144779, /* 56561 (1492) [ 1, -1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  6] -1 */
        7410, /* 56562 (1492) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  0]  1 */
      132557, /* 56563 (1492) [ 1, -1,  0,  1,  0,  0,  0,  0,  1] [ 0,  0,  6]  1 */
    34146806, /* 56564 (1492) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    34015424, /* 56565 (1492) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
        5547, /* 56566 (1492) [-1,  1,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    34015341, /* 56567 (1492) [-1,  0,  0, -1,  1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    34142594, /* 56568 (1492) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 0,  0,  6] -1 */
       14457, /* 56569 (1492) [ 1, -1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    34019636, /* 56570 (1492) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    34133441, /* 56571 (1492) [-1,  0,  0, -1,  1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    34017447, /* 56572 (1492) [-1,  1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    34026357, /* 56573 (1492) [ 1, -1,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    34017773, /* 56574 (1492) [-1,  1,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    34142187, /* 56575 (1492) [ 0,  1,  0, -1,  1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
      125913, /* 56576 (1492) [ 0, -1,  0,  1, -1,  0,  0,  0, -1] [ 0,  0,  6]  1 */
        7817, /* 56577 (1492) [ 0, -1,  0,  1, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
        5225, /* 56578 (1492) [-1,  1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34028706, /* 56579 (1492) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    34144457, /* 56580 (1492) [ 1, -1,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
      121215, /* 56581 (1492) [-1,  0,  0, -1,  1,  0,  0,  0, -1] [ 0,  0,  6]  1 */
      129965, /* 56582 (1492) [ 0,  1,  0, -1,  1,  0,  0,  0,  1] [ 0,  0,  6]  1 */
        3119, /* 56583 (1492) [-1,  0,  0, -1,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34024494, /* 56584 (1492) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  0] -1 */
       12272, /* 56585 (1492) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34028789, /* 56586 (1492) [ 1,  0,  0,  1, -1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    34146885, /* 56587 (1492) [ 1,  0,  0,  1, -1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
    34133520, /* 56588 (1492) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
      132231, /* 56589 (1492) [ 1, -1,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  6]  1 */
      121298, /* 56590 (1492) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6]  1 */
       14135, /* 56591 (1492) [ 1, -1,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
      125510, /* 56592 (1492) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  6]  1 */
       11865, /* 56593 (1492) [ 0,  1,  0, -1,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
      123321, /* 56594 (1492) [-1,  1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  6]  1 */
       16484, /* 56595 (1493) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
      134580, /* 56596 (1493) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  6]  1 */
       12270, /* 56597 (1493) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  0]  1 */
        3198, /* 56598 (1493) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
       16565, /* 56599 (1493) [ 1,  0,  0,  1, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
      134661, /* 56600 (1493) [ 1,  0,  0,  1, -1,  0,  0,  0, -1] [ 0,  0,  6]  1 */
      125508, /* 56601 (1493) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  6]  1 */
      132557, /* 56602 (1493) [ 1, -1,  0,  1,  0,  0,  0,  0,  1] [ 0,  0,  6]  1 */
      123645, /* 56603 (1493) [-1,  1,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  6]  1 */
       14457, /* 56604 (1493) [ 1, -1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  0]  1 */
      125913, /* 56605 (1493) [ 0, -1,  0,  1, -1,  0,  0,  0, -1] [ 0,  0,  6]  1 */
        5225, /* 56606 (1493) [-1,  1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  0]  1 */
        7817, /* 56607 (1493) [ 0, -1,  0,  1, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
      129965, /* 56608 (1493) [ 0,  1,  0, -1,  1,  0,  0,  0,  1] [ 0,  0,  6]  1 */
        3117, /* 56609 (1493) [-1,  0,  0, -1,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
        7412, /* 56610 (1493) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  0]  1 */
      121298, /* 56611 (1493) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6]  1 */
      121217, /* 56612 (1493) [-1,  0,  0, -1,  1,  0,  0,  0,  1] [ 0,  0,  6]  1 */
      130370, /* 56613 (1493) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 0,  0,  6]  1 */
       14133, /* 56614 (1493) [ 1, -1,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
      132233, /* 56615 (1493) [ 1, -1,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6]  1 */
        5549, /* 56616 (1493) [-1,  1,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
       11865, /* 56617 (1493) [ 0,  1,  0, -1,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
      123321, /* 56618 (1493) [-1,  1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  6]  1 */
       16484, /* 56619 (1494) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34144781, /* 56620 (1494) [ 1, -1,  0,  1,  0,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    34137732, /* 56621 (1494) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  6] -1 */
    34135869, /* 56622 (1494) [-1,  1,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
      134580, /* 56623 (1494) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  6]  1 */
       12270, /* 56624 (1494) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  0]  1 */
        3198, /* 56625 (1494) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
       16565, /* 56626 (1494) [ 1,  0,  0,  1, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
      134661, /* 56627 (1494) [ 1,  0,  0,  1, -1,  0,  0,  0, -1] [ 0,  0,  6]  1 */
    34017449, /* 56628 (1494) [-1,  1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    34026681, /* 56629 (1494) [ 1, -1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    34138137, /* 56630 (1494) [ 0, -1,  0,  1, -1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
      125508, /* 56631 (1494) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  6]  1 */
    34020041, /* 56632 (1494) [ 0, -1,  0,  1, -1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
      132557, /* 56633 (1494) [ 1, -1,  0,  1,  0,  0,  0,  0,  1] [ 0,  0,  6]  1 */
      123645, /* 56634 (1494) [-1,  1,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  6]  1 */
    34142189, /* 56635 (1494) [ 0,  1,  0, -1,  1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    34028708, /* 56636 (1494) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    34015341, /* 56637 (1494) [-1,  0,  0, -1,  1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    34133522, /* 56638 (1494) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    34142594, /* 56639 (1494) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 0,  0,  6] -1 */
       14457, /* 56640 (1494) [ 1, -1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    34019636, /* 56641 (1494) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    34133441, /* 56642 (1494) [-1,  0,  0, -1,  1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    34017773, /* 56643 (1494) [-1,  1,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    34026357, /* 56644 (1494) [ 1, -1,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
      125913, /* 56645 (1494) [ 0, -1,  0,  1, -1,  0,  0,  0, -1] [ 0,  0,  6]  1 */
        5225, /* 56646 (1494) [-1,  1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  0]  1 */
        7817, /* 56647 (1494) [ 0, -1,  0,  1, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34144457, /* 56648 (1494) [ 1, -1,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    34024089, /* 56649 (1494) [ 0,  1,  0, -1,  1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    34135545, /* 56650 (1494) [-1,  1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  6] -1 */
    34146804, /* 56651 (1494) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
      129965, /* 56652 (1494) [ 0,  1,  0, -1,  1,  0,  0,  0,  1] [ 0,  0,  6]  1 */
    34015422, /* 56653 (1494) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    34024494, /* 56654 (1494) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  0] -1 */
        3117, /* 56655 (1494) [-1,  0,  0, -1,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    34028789, /* 56656 (1494) [ 1,  0,  0,  1, -1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    34146885, /* 56657 (1494) [ 1,  0,  0,  1, -1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
        7412, /* 56658 (1494) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  0]  1 */
      121298, /* 56659 (1494) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6]  1 */
      121217, /* 56660 (1494) [-1,  0,  0, -1,  1,  0,  0,  0,  1] [ 0,  0,  6]  1 */
      130370, /* 56661 (1494) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 0,  0,  6]  1 */
       14133, /* 56662 (1494) [ 1, -1,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
      132233, /* 56663 (1494) [ 1, -1,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6]  1 */
        5549, /* 56664 (1494) [-1,  1,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
       11865, /* 56665 (1494) [ 0,  1,  0, -1,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
      123321, /* 56666 (1494) [-1,  1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  6]  1 */
       16484, /* 56667 (1495) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34137732, /* 56668 (1495) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  6] -1 */
    34135869, /* 56669 (1495) [-1,  1,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
       16565, /* 56670 (1495) [ 1,  0,  0,  1, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34026681, /* 56671 (1495) [ 1, -1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    34138137, /* 56672 (1495) [ 0, -1,  0,  1, -1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
      132557, /* 56673 (1495) [ 1, -1,  0,  1,  0,  0,  0,  0,  1] [ 0,  0,  6]  1 */
    34015341, /* 56674 (1495) [-1,  0,  0, -1,  1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    34026357, /* 56675 (1495) [ 1, -1,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
        5225, /* 56676 (1495) [-1,  1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  0]  1 */
        7817, /* 56677 (1495) [ 0, -1,  0,  1, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34024089, /* 56678 (1495) [ 0,  1,  0, -1,  1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    34135545, /* 56679 (1495) [-1,  1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  6] -1 */
    34146804, /* 56680 (1495) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
      129965, /* 56681 (1495) [ 0,  1,  0, -1,  1,  0,  0,  0,  1] [ 0,  0,  6]  1 */
    34015422, /* 56682 (1495) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    34024494, /* 56683 (1495) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    34146885, /* 56684 (1495) [ 1,  0,  0,  1, -1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
        7412, /* 56685 (1495) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  0]  1 */
      121298, /* 56686 (1495) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6]  1 */
      121217, /* 56687 (1495) [-1,  0,  0, -1,  1,  0,  0,  0,  1] [ 0,  0,  6]  1 */
      130370, /* 56688 (1495) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 0,  0,  6]  1 */
      132233, /* 56689 (1495) [ 1, -1,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6]  1 */
        5549, /* 56690 (1495) [-1,  1,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
       16484, /* 56691 (1496) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34137732, /* 56692 (1496) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  6] -1 */
    34144781, /* 56693 (1496) [ 1, -1,  0,  1,  0,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    34135869, /* 56694 (1496) [-1,  1,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
      134580, /* 56695 (1496) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  6]  1 */
       12270, /* 56696 (1496) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    34026681, /* 56697 (1496) [ 1, -1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    34142189, /* 56698 (1496) [ 0,  1,  0, -1,  1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    34133522, /* 56699 (1496) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    34019636, /* 56700 (1496) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    34017773, /* 56701 (1496) [-1,  1,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
        5225, /* 56702 (1496) [-1,  1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  0]  1 */
      125913, /* 56703 (1496) [ 0, -1,  0,  1, -1,  0,  0,  0, -1] [ 0,  0,  6]  1 */
        7817, /* 56704 (1496) [ 0, -1,  0,  1, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34024089, /* 56705 (1496) [ 0,  1,  0, -1,  1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    34015422, /* 56706 (1496) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
        3117, /* 56707 (1496) [-1,  0,  0, -1,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    34146885, /* 56708 (1496) [ 1,  0,  0,  1, -1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
    34028789, /* 56709 (1496) [ 1,  0,  0,  1, -1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
      121217, /* 56710 (1496) [-1,  0,  0, -1,  1,  0,  0,  0,  1] [ 0,  0,  6]  1 */
       14133, /* 56711 (1496) [ 1, -1,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
      130370, /* 56712 (1496) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 0,  0,  6]  1 */
      132233, /* 56713 (1496) [ 1, -1,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6]  1 */
      123321, /* 56714 (1496) [-1,  1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  6]  1 */
       16484, /* 56715 (1497) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34144781, /* 56716 (1497) [ 1, -1,  0,  1,  0,  0,  0,  0,  1] [ 0,  0,  6] -1 */
      134580, /* 56717 (1497) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  6]  1 */
      134661, /* 56718 (1497) [ 1,  0,  0,  1, -1,  0,  0,  0, -1] [ 0,  0,  6]  1 */
       16565, /* 56719 (1497) [ 1,  0,  0,  1, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34026681, /* 56720 (1497) [ 1, -1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  0] -1 */
      125508, /* 56721 (1497) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  6]  1 */
      123645, /* 56722 (1497) [-1,  1,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  6]  1 */
    34142189, /* 56723 (1497) [ 0,  1,  0, -1,  1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    34015341, /* 56724 (1497) [-1,  0,  0, -1,  1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    34133522, /* 56725 (1497) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    34142594, /* 56726 (1497) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    34133441, /* 56727 (1497) [-1,  0,  0, -1,  1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    34026357, /* 56728 (1497) [ 1, -1,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
        5225, /* 56729 (1497) [-1,  1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  0]  1 */
      125913, /* 56730 (1497) [ 0, -1,  0,  1, -1,  0,  0,  0, -1] [ 0,  0,  6]  1 */
        7817, /* 56731 (1497) [ 0, -1,  0,  1, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34144457, /* 56732 (1497) [ 1, -1,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    34024089, /* 56733 (1497) [ 0,  1,  0, -1,  1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    34015422, /* 56734 (1497) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    34024494, /* 56735 (1497) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  0] -1 */
        7412, /* 56736 (1497) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  0]  1 */
        5549, /* 56737 (1497) [-1,  1,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
      123321, /* 56738 (1497) [-1,  1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  6]  1 */
       16484, /* 56739 (1498) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34144781, /* 56740 (1498) [ 1, -1,  0,  1,  0,  0,  0,  0,  1] [ 0,  0,  6] -1 */
        3198, /* 56741 (1498) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
      134661, /* 56742 (1498) [ 1,  0,  0,  1, -1,  0,  0,  0, -1] [ 0,  0,  6]  1 */
    34138137, /* 56743 (1498) [ 0, -1,  0,  1, -1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
      125508, /* 56744 (1498) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  6]  1 */
      123645, /* 56745 (1498) [-1,  1,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  6]  1 */
    34142189, /* 56746 (1498) [ 0,  1,  0, -1,  1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    34015341, /* 56747 (1498) [-1,  0,  0, -1,  1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    34133522, /* 56748 (1498) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
       14457, /* 56749 (1498) [ 1, -1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    34019636, /* 56750 (1498) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    34017773, /* 56751 (1498) [-1,  1,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    34026357, /* 56752 (1498) [ 1, -1,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
        5225, /* 56753 (1498) [-1,  1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  0]  1 */
        7817, /* 56754 (1498) [ 0, -1,  0,  1, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34135545, /* 56755 (1498) [-1,  1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  6] -1 */
    34146804, /* 56756 (1498) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
    34024494, /* 56757 (1498) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    34028789, /* 56758 (1498) [ 1,  0,  0,  1, -1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
      121217, /* 56759 (1498) [-1,  0,  0, -1,  1,  0,  0,  0,  1] [ 0,  0,  6]  1 */
      130370, /* 56760 (1498) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 0,  0,  6]  1 */
      132233, /* 56761 (1498) [ 1, -1,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6]  1 */
       11865, /* 56762 (1498) [ 0,  1,  0, -1,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
       16484, /* 56763 (1499) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34137732, /* 56764 (1499) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  6] -1 */
    34144781, /* 56765 (1499) [ 1, -1,  0,  1,  0,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    34135869, /* 56766 (1499) [-1,  1,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
       12270, /* 56767 (1499) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  0]  1 */
        3198, /* 56768 (1499) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
       16565, /* 56769 (1499) [ 1,  0,  0,  1, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34138137, /* 56770 (1499) [ 0, -1,  0,  1, -1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
    34142189, /* 56771 (1499) [ 0,  1,  0, -1,  1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    34133522, /* 56772 (1499) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    34142594, /* 56773 (1499) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 0,  0,  6] -1 */
       14457, /* 56774 (1499) [ 1, -1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    34133441, /* 56775 (1499) [-1,  0,  0, -1,  1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
        5225, /* 56776 (1499) [-1,  1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  0]  1 */
        7817, /* 56777 (1499) [ 0, -1,  0,  1, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34144457, /* 56778 (1499) [ 1, -1,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    34135545, /* 56779 (1499) [-1,  1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  6] -1 */
    34146804, /* 56780 (1499) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
        3117, /* 56781 (1499) [-1,  0,  0, -1,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    34146885, /* 56782 (1499) [ 1,  0,  0,  1, -1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
        7412, /* 56783 (1499) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  0]  1 */
       14133, /* 56784 (1499) [ 1, -1,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
        5549, /* 56785 (1499) [-1,  1,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
       11865, /* 56786 (1499) [ 0,  1,  0, -1,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
       16484, /* 56787 (1500) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34137732, /* 56788 (1500) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  6] -1 */
    34135869, /* 56789 (1500) [-1,  1,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
      134580, /* 56790 (1500) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  6]  1 */
        3198, /* 56791 (1500) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
      132557, /* 56792 (1500) [ 1, -1,  0,  1,  0,  0,  0,  0,  1] [ 0,  0,  6]  1 */
    34015341, /* 56793 (1500) [-1,  0,  0, -1,  1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    34142594, /* 56794 (1500) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 0,  0,  6] -1 */
       14457, /* 56795 (1500) [ 1, -1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    34019636, /* 56796 (1500) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    34133441, /* 56797 (1500) [-1,  0,  0, -1,  1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    34017773, /* 56798 (1500) [-1,  1,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    34026357, /* 56799 (1500) [ 1, -1,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
      125913, /* 56800 (1500) [ 0, -1,  0,  1, -1,  0,  0,  0, -1] [ 0,  0,  6]  1 */
        5225, /* 56801 (1500) [-1,  1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  0]  1 */
        7817, /* 56802 (1500) [ 0, -1,  0,  1, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34144457, /* 56803 (1500) [ 1, -1,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
      129965, /* 56804 (1500) [ 0,  1,  0, -1,  1,  0,  0,  0,  1] [ 0,  0,  6]  1 */
    34024494, /* 56805 (1500) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    34028789, /* 56806 (1500) [ 1,  0,  0,  1, -1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    34146885, /* 56807 (1500) [ 1,  0,  0,  1, -1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
      121298, /* 56808 (1500) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6]  1 */
       11865, /* 56809 (1500) [ 0,  1,  0, -1,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
      123321, /* 56810 (1500) [-1,  1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  6]  1 */
       16484, /* 56811 (1501) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
       12270, /* 56812 (1501) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  0]  1 */
      134661, /* 56813 (1501) [ 1,  0,  0,  1, -1,  0,  0,  0, -1] [ 0,  0,  6]  1 */
    34026681, /* 56814 (1501) [ 1, -1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    34138137, /* 56815 (1501) [ 0, -1,  0,  1, -1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
      125508, /* 56816 (1501) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  6]  1 */
      132557, /* 56817 (1501) [ 1, -1,  0,  1,  0,  0,  0,  0,  1] [ 0,  0,  6]  1 */
      123645, /* 56818 (1501) [-1,  1,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  6]  1 */
    34142594, /* 56819 (1501) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    34019636, /* 56820 (1501) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    34133441, /* 56821 (1501) [-1,  0,  0, -1,  1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    34017773, /* 56822 (1501) [-1,  1,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
        5225, /* 56823 (1501) [-1,  1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  0]  1 */
        7817, /* 56824 (1501) [ 0, -1,  0,  1, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34144457, /* 56825 (1501) [ 1, -1,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    34024089, /* 56826 (1501) [ 0,  1,  0, -1,  1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    34135545, /* 56827 (1501) [-1,  1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  6] -1 */
    34146804, /* 56828 (1501) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
      129965, /* 56829 (1501) [ 0,  1,  0, -1,  1,  0,  0,  0,  1] [ 0,  0,  6]  1 */
    34015422, /* 56830 (1501) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
        3117, /* 56831 (1501) [-1,  0,  0, -1,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    34028789, /* 56832 (1501) [ 1,  0,  0,  1, -1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
      121298, /* 56833 (1501) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6]  1 */
       14133, /* 56834 (1501) [ 1, -1,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
       16484, /* 56835 (1502) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34026683, /* 56836 (1502) [ 1, -1,  0,  1,  0,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    34019634, /* 56837 (1502) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  0] -1 */
      134580, /* 56838 (1502) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  6]  1 */
    34017771, /* 56839 (1502) [-1,  1,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
       12270, /* 56840 (1502) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  0]  1 */
        3198, /* 56841 (1502) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
       16565, /* 56842 (1502) [ 1,  0,  0,  1, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
      134661, /* 56843 (1502) [ 1,  0,  0,  1, -1,  0,  0,  0, -1] [ 0,  0,  6]  1 */
    34135547, /* 56844 (1502) [-1,  1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    34020039, /* 56845 (1502) [ 0, -1,  0,  1, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    34138139, /* 56846 (1502) [ 0, -1,  0,  1, -1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
      125508, /* 56847 (1502) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  6]  1 */
    34024091, /* 56848 (1502) [ 0,  1,  0, -1,  1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    34144779, /* 56849 (1502) [ 1, -1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  6] -1 */
      132557, /* 56850 (1502) [ 1, -1,  0,  1,  0,  0,  0,  0,  1] [ 0,  0,  6]  1 */
      123645, /* 56851 (1502) [-1,  1,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  6]  1 */
    34146806, /* 56852 (1502) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    34015424, /* 56853 (1502) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    34024496, /* 56854 (1502) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    34133439, /* 56855 (1502) [-1,  0,  0, -1,  1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
    34015343, /* 56856 (1502) [-1,  0,  0, -1,  1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    34144455, /* 56857 (1502) [ 1, -1,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
       14457, /* 56858 (1502) [ 1, -1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    34026359, /* 56859 (1502) [ 1, -1,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    34017447, /* 56860 (1502) [-1,  1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  0] -1 */
      125913, /* 56861 (1502) [ 0, -1,  0,  1, -1,  0,  0,  0, -1] [ 0,  0,  6]  1 */
        5225, /* 56862 (1502) [-1,  1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34142187, /* 56863 (1502) [ 0,  1,  0, -1,  1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
    34028706, /* 56864 (1502) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
        7817, /* 56865 (1502) [ 0, -1,  0,  1, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34137734, /* 56866 (1502) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    34135871, /* 56867 (1502) [-1,  1,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    34146887, /* 56868 (1502) [ 1,  0,  0,  1, -1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    34028787, /* 56869 (1502) [ 1,  0,  0,  1, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    34142592, /* 56870 (1502) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  6] -1 */
      129965, /* 56871 (1502) [ 0,  1,  0, -1,  1,  0,  0,  0,  1] [ 0,  0,  6]  1 */
        3117, /* 56872 (1502) [-1,  0,  0, -1,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    34133520, /* 56873 (1502) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
        7412, /* 56874 (1502) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  0]  1 */
      121298, /* 56875 (1502) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6]  1 */
      121217, /* 56876 (1502) [-1,  0,  0, -1,  1,  0,  0,  0,  1] [ 0,  0,  6]  1 */
      130370, /* 56877 (1502) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 0,  0,  6]  1 */
       14133, /* 56878 (1502) [ 1, -1,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
      132233, /* 56879 (1502) [ 1, -1,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6]  1 */
        5549, /* 56880 (1502) [-1,  1,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
       11865, /* 56881 (1502) [ 0,  1,  0, -1,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
      123321, /* 56882 (1502) [-1,  1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  6]  1 */
       16484, /* 56883 (1503) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
       10816, /* 56884 (1503) [ 0,  0,  1,  1,  0,  0,  0,  1,  0] [ 0,  0,  0]  1 */
        8872, /* 56885 (1503) [ 0,  0, -1, -1,  0,  0,  0,  1,  0] [ 0,  0,  0]  1 */
        3200, /* 56886 (1503) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
       16320, /* 56887 (1503) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
        7636, /* 56888 (1503) [ 0, -1,  0,  0,  0, -1,  1,  0,  0] [ 0,  0,  0]  1 */
       11992, /* 56889 (1503) [ 0,  1,  0,  0,  0, -1, -1,  0,  0] [ 0,  0,  0]  1 */
       12064, /* 56890 (1503) [ 0,  1,  0,  0,  0,  1,  1,  0,  0] [ 0,  0,  0]  1 */
        9352, /* 56891 (1503) [ 0,  0, -1,  1,  0,  0,  0, -1,  0] [ 0,  0,  0]  1 */
        7672, /* 56892 (1503) [ 0, -1,  0,  0,  0,  1, -1,  0,  0] [ 0,  0,  0]  1 */
        3360, /* 56893 (1503) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
       10324, /* 56894 (1503) [ 0,  0,  1, -1,  0,  0,  0, -1,  0] [ 0,  0,  0]  1 */
       16484, /* 56895 (1504) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34019860, /* 56896 (1504) [ 0, -1,  0,  0,  0, -1,  1,  0,  0] [ 0,  0,  0] -1 */
       16320, /* 56897 (1504) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    34021576, /* 56898 (1504) [ 0,  0, -1,  1,  0,  0,  0, -1,  0] [ 0,  0,  0] -1 */
    34021096, /* 56899 (1504) [ 0,  0, -1, -1,  0,  0,  0,  1,  0] [ 0,  0,  0] -1 */
    34019896, /* 56900 (1504) [ 0, -1,  0,  0,  0,  1, -1,  0,  0] [ 0,  0,  0] -1 */
    34015584, /* 56901 (1504) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
        7636, /* 56902 (1504) [ 0, -1,  0,  0,  0, -1,  1,  0,  0] [ 0,  0,  0]  1 */
        9352, /* 56903 (1504) [ 0,  0, -1,  1,  0,  0,  0, -1,  0] [ 0,  0,  0]  1 */
    34015424, /* 56904 (1504) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    34028708, /* 56905 (1504) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    34023040, /* 56906 (1504) [ 0,  0,  1,  1,  0,  0,  0,  1,  0] [ 0,  0,  0] -1 */
    34024216, /* 56907 (1504) [ 0,  1,  0,  0,  0, -1, -1,  0,  0] [ 0,  0,  0] -1 */
        8872, /* 56908 (1504) [ 0,  0, -1, -1,  0,  0,  0,  1,  0] [ 0,  0,  0]  1 */
    34024288, /* 56909 (1504) [ 0,  1,  0,  0,  0,  1,  1,  0,  0] [ 0,  0,  0] -1 */
    34022548, /* 56910 (1504) [ 0,  0,  1, -1,  0,  0,  0, -1,  0] [ 0,  0,  0] -1 */
        7672, /* 56911 (1504) [ 0, -1,  0,  0,  0,  1, -1,  0,  0] [ 0,  0,  0]  1 */
        3360, /* 56912 (1504) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    34028544, /* 56913 (1504) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
       10816, /* 56914 (1504) [ 0,  0,  1,  1,  0,  0,  0,  1,  0] [ 0,  0,  0]  1 */
        3200, /* 56915 (1504) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
       11992, /* 56916 (1504) [ 0,  1,  0,  0,  0, -1, -1,  0,  0] [ 0,  0,  0]  1 */
       12064, /* 56917 (1504) [ 0,  1,  0,  0,  0,  1,  1,  0,  0] [ 0,  0,  0]  1 */
       10324, /* 56918 (1504) [ 0,  0,  1, -1,  0,  0,  0, -1,  0] [ 0,  0,  0]  1 */
       16484, /* 56919 (1505) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    52562962, /* 56920 (1505) [ 0,  0, -1,  1,  0,  0,  0, -1,  0] [ 6,  6,  6] -1 */
       16320, /* 56921 (1505) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    52556970, /* 56922 (1505) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    52570094, /* 56923 (1505) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    52562482, /* 56924 (1505) [ 0,  0, -1, -1,  0,  0,  0,  1,  0] [ 6,  6,  6] -1 */
        7636, /* 56925 (1505) [ 0, -1,  0,  0,  0, -1,  1,  0,  0] [ 0,  0,  0]  1 */
    52561282, /* 56926 (1505) [ 0, -1,  0,  0,  0,  1, -1,  0,  0] [ 6,  6,  6] -1 */
        9352, /* 56927 (1505) [ 0,  0, -1,  1,  0,  0,  0, -1,  0] [ 0,  0,  0]  1 */
    52565602, /* 56928 (1505) [ 0,  1,  0,  0,  0, -1, -1,  0,  0] [ 6,  6,  6] -1 */
    52565674, /* 56929 (1505) [ 0,  1,  0,  0,  0,  1,  1,  0,  0] [ 6,  6,  6] -1 */
    52556810, /* 56930 (1505) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
        8872, /* 56931 (1505) [ 0,  0, -1, -1,  0,  0,  0,  1,  0] [ 0,  0,  0]  1 */
    52564426, /* 56932 (1505) [ 0,  0,  1,  1,  0,  0,  0,  1,  0] [ 6,  6,  6] -1 */
    52563934, /* 56933 (1505) [ 0,  0,  1, -1,  0,  0,  0, -1,  0] [ 6,  6,  6] -1 */
        7672, /* 56934 (1505) [ 0, -1,  0,  0,  0,  1, -1,  0,  0] [ 0,  0,  0]  1 */
    52569930, /* 56935 (1505) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
        3360, /* 56936 (1505) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
       10816, /* 56937 (1505) [ 0,  0,  1,  1,  0,  0,  0,  1,  0] [ 0,  0,  0]  1 */
        3200, /* 56938 (1505) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
       11992, /* 56939 (1505) [ 0,  1,  0,  0,  0, -1, -1,  0,  0] [ 0,  0,  0]  1 */
       12064, /* 56940 (1505) [ 0,  1,  0,  0,  0,  1,  1,  0,  0] [ 0,  0,  0]  1 */
    52561246, /* 56941 (1505) [ 0, -1,  0,  0,  0, -1,  1,  0,  0] [ 6,  6,  6] -1 */
       10324, /* 56942 (1505) [ 0,  0,  1, -1,  0,  0,  0, -1,  0] [ 0,  0,  0]  1 */
       16484, /* 56943 (1506) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
     1544146, /* 56944 (1506) [ 0,  0, -1, -1,  0,  0,  0,  1,  0] [ 0,  6,  6]  1 */
    18439608, /* 56945 (1506) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
    17140694, /* 56946 (1506) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
    17127570, /* 56947 (1506) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6]  1 */
       16320, /* 56948 (1506) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
     1542946, /* 56949 (1506) [ 0, -1,  0,  0,  0,  1, -1,  0,  0] [ 0,  6,  6]  1 */
    17133082, /* 56950 (1506) [ 0,  0, -1, -1,  0,  0,  0,  1,  0] [ 6,  0,  6]  1 */
     1545598, /* 56951 (1506) [ 0,  0,  1, -1,  0,  0,  0, -1,  0] [ 0,  6,  6]  1 */
    17127410, /* 56952 (1506) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
     1547266, /* 56953 (1506) [ 0,  1,  0,  0,  0, -1, -1,  0,  0] [ 0,  6,  6]  1 */
    17131882, /* 56954 (1506) [ 0, -1,  0,  0,  0,  1, -1,  0,  0] [ 6,  0,  6]  1 */
    17134534, /* 56955 (1506) [ 0,  0,  1, -1,  0,  0,  0, -1,  0] [ 6,  0,  6]  1 */
    17136202, /* 56956 (1506) [ 0,  1,  0,  0,  0, -1, -1,  0,  0] [ 6,  0,  6]  1 */
     1547338, /* 56957 (1506) [ 0,  1,  0,  0,  0,  1,  1,  0,  0] [ 0,  6,  6]  1 */
     1546090, /* 56958 (1506) [ 0,  0,  1,  1,  0,  0,  0,  1,  0] [ 0,  6,  6]  1 */
    18432640, /* 56959 (1506) [ 0,  0, -1,  1,  0,  0,  0, -1,  0] [ 6,  6,  0]  1 */
     1538474, /* 56960 (1506) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
    17136274, /* 56961 (1506) [ 0,  1,  0,  0,  0,  1,  1,  0,  0] [ 6,  0,  6]  1 */
    17135026, /* 56962 (1506) [ 0,  0,  1,  1,  0,  0,  0,  1,  0] [ 6,  0,  6]  1 */
        7636, /* 56963 (1506) [ 0, -1,  0,  0,  0, -1,  1,  0,  0] [ 0,  0,  0]  1 */
    18430924, /* 56964 (1506) [ 0, -1,  0,  0,  0, -1,  1,  0,  0] [ 6,  6,  0]  1 */
        9352, /* 56965 (1506) [ 0,  0, -1,  1,  0,  0,  0, -1,  0] [ 0,  0,  0]  1 */
    18439772, /* 56966 (1506) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    17140530, /* 56967 (1506) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  6]  1 */
    18426648, /* 56968 (1506) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
     1551594, /* 56969 (1506) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
        8872, /* 56970 (1506) [ 0,  0, -1, -1,  0,  0,  0,  1,  0] [ 0,  0,  0]  1 */
    18432160, /* 56971 (1506) [ 0,  0, -1, -1,  0,  0,  0,  1,  0] [ 6,  6,  0]  1 */
    18430960, /* 56972 (1506) [ 0, -1,  0,  0,  0,  1, -1,  0,  0] [ 6,  6,  0]  1 */
        7672, /* 56973 (1506) [ 0, -1,  0,  0,  0,  1, -1,  0,  0] [ 0,  0,  0]  1 */
    18435280, /* 56974 (1506) [ 0,  1,  0,  0,  0, -1, -1,  0,  0] [ 6,  6,  0]  1 */
        3360, /* 56975 (1506) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    18435352, /* 56976 (1506) [ 0,  1,  0,  0,  0,  1,  1,  0,  0] [ 6,  6,  0]  1 */
    18426488, /* 56977 (1506) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
     1544626, /* 56978 (1506) [ 0,  0, -1,  1,  0,  0,  0, -1,  0] [ 0,  6,  6]  1 */
       10816, /* 56979 (1506) [ 0,  0,  1,  1,  0,  0,  0,  1,  0] [ 0,  0,  0]  1 */
    18434104, /* 56980 (1506) [ 0,  0,  1,  1,  0,  0,  0,  1,  0] [ 6,  6,  0]  1 */
        3200, /* 56981 (1506) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    18433612, /* 56982 (1506) [ 0,  0,  1, -1,  0,  0,  0, -1,  0] [ 6,  6,  0]  1 */
    17133562, /* 56983 (1506) [ 0,  0, -1,  1,  0,  0,  0, -1,  0] [ 6,  0,  6]  1 */
     1542910, /* 56984 (1506) [ 0, -1,  0,  0,  0, -1,  1,  0,  0] [ 0,  6,  6]  1 */
       11992, /* 56985 (1506) [ 0,  1,  0,  0,  0, -1, -1,  0,  0] [ 0,  0,  0]  1 */
       12064, /* 56986 (1506) [ 0,  1,  0,  0,  0,  1,  1,  0,  0] [ 0,  0,  0]  1 */
     1551758, /* 56987 (1506) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
    17131846, /* 56988 (1506) [ 0, -1,  0,  0,  0, -1,  1,  0,  0] [ 6,  0,  6]  1 */
       10324, /* 56989 (1506) [ 0,  0,  1, -1,  0,  0,  0, -1,  0] [ 0,  0,  0]  1 */
     1538634, /* 56990 (1506) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
       16484, /* 56991 (1507) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    17140694, /* 56992 (1507) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
       16320, /* 56993 (1507) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    52451996, /* 56994 (1507) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
     1545598, /* 56995 (1507) [ 0,  0,  1, -1,  0,  0,  0, -1,  0] [ 0,  6,  6]  1 */
    51152754, /* 56996 (1507) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  6] -1 */
     1538474, /* 56997 (1507) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
    34019896, /* 56998 (1507) [ 0, -1,  0,  0,  0,  1, -1,  0,  0] [ 0,  0,  0] -1 */
    52443184, /* 56999 (1507) [ 0, -1,  0,  0,  0,  1, -1,  0,  0] [ 6,  6,  0] -1 */
    17136274, /* 57000 (1507) [ 0,  1,  0,  0,  0,  1,  1,  0,  0] [ 6,  0,  6]  1 */
    34015584, /* 57001 (1507) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    52447576, /* 57002 (1507) [ 0,  1,  0,  0,  0,  1,  1,  0,  0] [ 6,  6,  0] -1 */
        9352, /* 57003 (1507) [ 0,  0, -1,  1,  0,  0,  0, -1,  0] [ 0,  0,  0]  1 */
    34023040, /* 57004 (1507) [ 0,  0,  1,  1,  0,  0,  0,  1,  0] [ 0,  0,  0] -1 */
    52446328, /* 57005 (1507) [ 0,  0,  1,  1,  0,  0,  0,  1,  0] [ 6,  6,  0] -1 */
    18426648, /* 57006 (1507) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
        8872, /* 57007 (1507) [ 0,  0, -1, -1,  0,  0,  0,  1,  0] [ 0,  0,  0]  1 */
    18432160, /* 57008 (1507) [ 0,  0, -1, -1,  0,  0,  0,  1,  0] [ 6,  6,  0]  1 */
    34024288, /* 57009 (1507) [ 0,  1,  0,  0,  0,  1,  1,  0,  0] [ 0,  0,  0] -1 */
    35563982, /* 57010 (1507) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
    51139794, /* 57011 (1507) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6] -1 */
    35555170, /* 57012 (1507) [ 0, -1,  0,  0,  0,  1, -1,  0,  0] [ 0,  6,  6] -1 */
    18433612, /* 57013 (1507) [ 0,  0,  1, -1,  0,  0,  0, -1,  0] [ 6,  6,  0]  1 */
    17133562, /* 57014 (1507) [ 0,  0, -1,  1,  0,  0,  0, -1,  0] [ 6,  0,  6]  1 */
    35559490, /* 57015 (1507) [ 0,  1,  0,  0,  0, -1, -1,  0,  0] [ 0,  6,  6] -1 */
    35559562, /* 57016 (1507) [ 0,  1,  0,  0,  0,  1,  1,  0,  0] [ 0,  6,  6] -1 */
    52444864, /* 57017 (1507) [ 0,  0, -1,  1,  0,  0,  0, -1,  0] [ 6,  6,  0] -1 */
    17131846, /* 57018 (1507) [ 0, -1,  0,  0,  0, -1,  1,  0,  0] [ 6,  0,  6]  1 */
    35558314, /* 57019 (1507) [ 0,  0,  1,  1,  0,  0,  0,  1,  0] [ 0,  6,  6] -1 */
       10324, /* 57020 (1507) [ 0,  0,  1, -1,  0,  0,  0, -1,  0] [ 0,  0,  0]  1 */
     1538634, /* 57021 (1507) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
    52443148, /* 57022 (1507) [ 0, -1,  0,  0,  0, -1,  1,  0,  0] [ 6,  6,  0] -1 */
     1544146, /* 57023 (1507) [ 0,  0, -1, -1,  0,  0,  0,  1,  0] [ 0,  6,  6]  1 */
    17134534, /* 57024 (1507) [ 0,  0,  1, -1,  0,  0,  0, -1,  0] [ 6,  0,  6]  1 */
    35556850, /* 57025 (1507) [ 0,  0, -1,  1,  0,  0,  0, -1,  0] [ 0,  6,  6] -1 */
    18439772, /* 57026 (1507) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    34015424, /* 57027 (1507) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    34028708, /* 57028 (1507) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    17140530, /* 57029 (1507) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  6]  1 */
    52438712, /* 57030 (1507) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
    18430960, /* 57031 (1507) [ 0, -1,  0,  0,  0,  1, -1,  0,  0] [ 6,  6,  0]  1 */
    18435280, /* 57032 (1507) [ 0,  1,  0,  0,  0, -1, -1,  0,  0] [ 6,  6,  0]  1 */
    51152918, /* 57033 (1507) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
    18435352, /* 57034 (1507) [ 0,  1,  0,  0,  0,  1,  1,  0,  0] [ 6,  6,  0]  1 */
    34028544, /* 57035 (1507) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    52451832, /* 57036 (1507) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
       10816, /* 57037 (1507) [ 0,  0,  1,  1,  0,  0,  0,  1,  0] [ 0,  0,  0]  1 */
    18434104, /* 57038 (1507) [ 0,  0,  1,  1,  0,  0,  0,  1,  0] [ 6,  6,  0]  1 */
    51139634, /* 57039 (1507) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
       11992, /* 57040 (1507) [ 0,  1,  0,  0,  0, -1, -1,  0,  0] [ 0,  0,  0]  1 */
    51144106, /* 57041 (1507) [ 0, -1,  0,  0,  0,  1, -1,  0,  0] [ 6,  0,  6] -1 */
       12064, /* 57042 (1507) [ 0,  1,  0,  0,  0,  1,  1,  0,  0] [ 0,  0,  0]  1 */
     1551758, /* 57043 (1507) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
    35550698, /* 57044 (1507) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
    51148426, /* 57045 (1507) [ 0,  1,  0,  0,  0, -1, -1,  0,  0] [ 6,  0,  6] -1 */
    51148498, /* 57046 (1507) [ 0,  1,  0,  0,  0,  1,  1,  0,  0] [ 6,  0,  6] -1 */
    51147250, /* 57047 (1507) [ 0,  0,  1,  1,  0,  0,  0,  1,  0] [ 6,  0,  6] -1 */
    34019860, /* 57048 (1507) [ 0, -1,  0,  0,  0, -1,  1,  0,  0] [ 0,  0,  0] -1 */
    17127570, /* 57049 (1507) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6]  1 */
     1542946, /* 57050 (1507) [ 0, -1,  0,  0,  0,  1, -1,  0,  0] [ 0,  6,  6]  1 */
    17133082, /* 57051 (1507) [ 0,  0, -1, -1,  0,  0,  0,  1,  0] [ 6,  0,  6]  1 */
     1547266, /* 57052 (1507) [ 0,  1,  0,  0,  0, -1, -1,  0,  0] [ 0,  6,  6]  1 */
    52444384, /* 57053 (1507) [ 0,  0, -1, -1,  0,  0,  0,  1,  0] [ 6,  6,  0] -1 */
    35563818, /* 57054 (1507) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  6] -1 */
     1546090, /* 57055 (1507) [ 0,  0,  1,  1,  0,  0,  0,  1,  0] [ 0,  6,  6]  1 */
    35555134, /* 57056 (1507) [ 0, -1,  0,  0,  0, -1,  1,  0,  0] [ 0,  6,  6] -1 */
    34022548, /* 57057 (1507) [ 0,  0,  1, -1,  0,  0,  0, -1,  0] [ 0,  0,  0] -1 */
        7672, /* 57058 (1507) [ 0, -1,  0,  0,  0,  1, -1,  0,  0] [ 0,  0,  0]  1 */
    35556370, /* 57059 (1507) [ 0,  0, -1, -1,  0,  0,  0,  1,  0] [ 0,  6,  6] -1 */
        3360, /* 57060 (1507) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    18426488, /* 57061 (1507) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    35557822, /* 57062 (1507) [ 0,  0,  1, -1,  0,  0,  0, -1,  0] [ 0,  6,  6] -1 */
    18439608, /* 57063 (1507) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
    34021576, /* 57064 (1507) [ 0,  0, -1,  1,  0,  0,  0, -1,  0] [ 0,  0,  0] -1 */
    17127410, /* 57065 (1507) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
    17131882, /* 57066 (1507) [ 0, -1,  0,  0,  0,  1, -1,  0,  0] [ 6,  0,  6]  1 */
    52438872, /* 57067 (1507) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
    34021096, /* 57068 (1507) [ 0,  0, -1, -1,  0,  0,  0,  1,  0] [ 0,  0,  0] -1 */
     1547338, /* 57069 (1507) [ 0,  1,  0,  0,  0,  1,  1,  0,  0] [ 0,  6,  6]  1 */
    17136202, /* 57070 (1507) [ 0,  1,  0,  0,  0, -1, -1,  0,  0] [ 6,  0,  6]  1 */
    18432640, /* 57071 (1507) [ 0,  0, -1,  1,  0,  0,  0, -1,  0] [ 6,  6,  0]  1 */
    52447504, /* 57072 (1507) [ 0,  1,  0,  0,  0, -1, -1,  0,  0] [ 6,  6,  0] -1 */
    17135026, /* 57073 (1507) [ 0,  0,  1,  1,  0,  0,  0,  1,  0] [ 6,  0,  6]  1 */
        7636, /* 57074 (1507) [ 0, -1,  0,  0,  0, -1,  1,  0,  0] [ 0,  0,  0]  1 */
    18430924, /* 57075 (1507) [ 0, -1,  0,  0,  0, -1,  1,  0,  0] [ 6,  6,  0]  1 */
    52445836, /* 57076 (1507) [ 0,  0,  1, -1,  0,  0,  0, -1,  0] [ 6,  6,  0] -1 */
    34024216, /* 57077 (1507) [ 0,  1,  0,  0,  0, -1, -1,  0,  0] [ 0,  0,  0] -1 */
     1551594, /* 57078 (1507) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
    51145786, /* 57079 (1507) [ 0,  0, -1,  1,  0,  0,  0, -1,  0] [ 6,  0,  6] -1 */
    51144070, /* 57080 (1507) [ 0, -1,  0,  0,  0, -1,  1,  0,  0] [ 6,  0,  6] -1 */
    35550858, /* 57081 (1507) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6] -1 */
    51145306, /* 57082 (1507) [ 0,  0, -1, -1,  0,  0,  0,  1,  0] [ 6,  0,  6] -1 */
     1544626, /* 57083 (1507) [ 0,  0, -1,  1,  0,  0,  0, -1,  0] [ 0,  6,  6]  1 */
        3200, /* 57084 (1507) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
     1542910, /* 57085 (1507) [ 0, -1,  0,  0,  0, -1,  1,  0,  0] [ 0,  6,  6]  1 */
    51146758, /* 57086 (1507) [ 0,  0,  1, -1,  0,  0,  0, -1,  0] [ 6,  0,  6] -1 */
       16484, /* 57087 (1508) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    52562962, /* 57088 (1508) [ 0,  0, -1,  1,  0,  0,  0, -1,  0] [ 6,  6,  6] -1 */
    17140694, /* 57089 (1508) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
       16320, /* 57090 (1508) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
     1545598, /* 57091 (1508) [ 0,  0,  1, -1,  0,  0,  0, -1,  0] [ 0,  6,  6]  1 */
     1538474, /* 57092 (1508) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
    51034820, /* 57093 (1508) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  0] -1 */
    17136274, /* 57094 (1508) [ 0,  1,  0,  0,  0,  1,  1,  0,  0] [ 6,  0,  6]  1 */
        9352, /* 57095 (1508) [ 0,  0, -1,  1,  0,  0,  0, -1,  0] [ 0,  0,  0]  1 */
    18426648, /* 57096 (1508) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
    34133522, /* 57097 (1508) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    52556810, /* 57098 (1508) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
        8872, /* 57099 (1508) [ 0,  0, -1, -1,  0,  0,  0,  1,  0] [ 0,  0,  0]  1 */
    18432160, /* 57100 (1508) [ 0,  0, -1, -1,  0,  0,  0,  1,  0] [ 6,  6,  0]  1 */
    51034656, /* 57101 (1508) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  0] -1 */
    35432760, /* 57102 (1508) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  0] -1 */
    35445884, /* 57103 (1508) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  0] -1 */
    18433612, /* 57104 (1508) [ 0,  0,  1, -1,  0,  0,  0, -1,  0] [ 6,  6,  0]  1 */
    17133562, /* 57105 (1508) [ 0,  0, -1,  1,  0,  0,  0, -1,  0] [ 6,  0,  6]  1 */
    35441392, /* 57106 (1508) [ 0,  1,  0,  0,  0, -1, -1,  0,  0] [ 0,  6,  0] -1 */
    51025972, /* 57107 (1508) [ 0, -1,  0,  0,  0, -1,  1,  0,  0] [ 6,  0,  0] -1 */
    17131846, /* 57108 (1508) [ 0, -1,  0,  0,  0, -1,  1,  0,  0] [ 6,  0,  6]  1 */
    35441464, /* 57109 (1508) [ 0,  1,  0,  0,  0,  1,  1,  0,  0] [ 0,  6,  0] -1 */
    52561246, /* 57110 (1508) [ 0, -1,  0,  0,  0, -1,  1,  0,  0] [ 6,  6,  6] -1 */
       10324, /* 57111 (1508) [ 0,  0,  1, -1,  0,  0,  0, -1,  0] [ 0,  0,  0]  1 */
     1538634, /* 57112 (1508) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
    35440216, /* 57113 (1508) [ 0,  0,  1,  1,  0,  0,  0,  1,  0] [ 0,  6,  0] -1 */
     1544146, /* 57114 (1508) [ 0,  0, -1, -1,  0,  0,  0,  1,  0] [ 0,  6,  6]  1 */
    34139674, /* 57115 (1508) [ 0,  0, -1,  1,  0,  0,  0, -1,  0] [ 0,  0,  6] -1 */
    51027688, /* 57116 (1508) [ 0,  0, -1,  1,  0,  0,  0, -1,  0] [ 6,  0,  0] -1 */
    34137958, /* 57117 (1508) [ 0, -1,  0,  0,  0, -1,  1,  0,  0] [ 0,  0,  6] -1 */
    17134534, /* 57118 (1508) [ 0,  0,  1, -1,  0,  0,  0, -1,  0] [ 6,  0,  6]  1 */
    52562482, /* 57119 (1508) [ 0,  0, -1, -1,  0,  0,  0,  1,  0] [ 6,  6,  6] -1 */
    34146806, /* 57120 (1508) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    18439772, /* 57121 (1508) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    17140530, /* 57122 (1508) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  6]  1 */
    51028660, /* 57123 (1508) [ 0,  0,  1, -1,  0,  0,  0, -1,  0] [ 6,  0,  0] -1 */
    18430960, /* 57124 (1508) [ 0, -1,  0,  0,  0,  1, -1,  0,  0] [ 6,  6,  0]  1 */
    34146642, /* 57125 (1508) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
    52569930, /* 57126 (1508) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    18435280, /* 57127 (1508) [ 0,  1,  0,  0,  0, -1, -1,  0,  0] [ 6,  6,  0]  1 */
    18435352, /* 57128 (1508) [ 0,  1,  0,  0,  0,  1,  1,  0,  0] [ 6,  6,  0]  1 */
    35437072, /* 57129 (1508) [ 0, -1,  0,  0,  0,  1, -1,  0,  0] [ 0,  6,  0] -1 */
       10816, /* 57130 (1508) [ 0,  0,  1,  1,  0,  0,  0,  1,  0] [ 0,  0,  0]  1 */
    18434104, /* 57131 (1508) [ 0,  0,  1,  1,  0,  0,  0,  1,  0] [ 6,  6,  0]  1 */
       11992, /* 57132 (1508) [ 0,  1,  0,  0,  0, -1, -1,  0,  0] [ 0,  0,  0]  1 */
       12064, /* 57133 (1508) [ 0,  1,  0,  0,  0,  1,  1,  0,  0] [ 0,  0,  0]  1 */
     1551758, /* 57134 (1508) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
    17127570, /* 57135 (1508) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6]  1 */
     1542946, /* 57136 (1508) [ 0, -1,  0,  0,  0,  1, -1,  0,  0] [ 0,  6,  6]  1 */
    17133082, /* 57137 (1508) [ 0,  0, -1, -1,  0,  0,  0,  1,  0] [ 6,  0,  6]  1 */
     1547266, /* 57138 (1508) [ 0,  1,  0,  0,  0, -1, -1,  0,  0] [ 0,  6,  6]  1 */
     1546090, /* 57139 (1508) [ 0,  0,  1,  1,  0,  0,  0,  1,  0] [ 0,  6,  6]  1 */
    35438752, /* 57140 (1508) [ 0,  0, -1,  1,  0,  0,  0, -1,  0] [ 0,  6,  0] -1 */
    34139194, /* 57141 (1508) [ 0,  0, -1, -1,  0,  0,  0,  1,  0] [ 0,  0,  6] -1 */
    51030328, /* 57142 (1508) [ 0,  1,  0,  0,  0, -1, -1,  0,  0] [ 6,  0,  0] -1 */
    51027208, /* 57143 (1508) [ 0,  0, -1, -1,  0,  0,  0,  1,  0] [ 6,  0,  0] -1 */
    51030400, /* 57144 (1508) [ 0,  1,  0,  0,  0,  1,  1,  0,  0] [ 6,  0,  0] -1 */
    35437036, /* 57145 (1508) [ 0, -1,  0,  0,  0, -1,  1,  0,  0] [ 0,  6,  0] -1 */
    34140646, /* 57146 (1508) [ 0,  0,  1, -1,  0,  0,  0, -1,  0] [ 0,  0,  6] -1 */
    52563934, /* 57147 (1508) [ 0,  0,  1, -1,  0,  0,  0, -1,  0] [ 6,  6,  6] -1 */
        7672, /* 57148 (1508) [ 0, -1,  0,  0,  0,  1, -1,  0,  0] [ 0,  0,  0]  1 */
        3360, /* 57149 (1508) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    18426488, /* 57150 (1508) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    35432600, /* 57151 (1508) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  0] -1 */
    35439724, /* 57152 (1508) [ 0,  0,  1, -1,  0,  0,  0, -1,  0] [ 0,  6,  0] -1 */
    18439608, /* 57153 (1508) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
    35445720, /* 57154 (1508) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  0] -1 */
    52556970, /* 57155 (1508) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    17127410, /* 57156 (1508) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
    17131882, /* 57157 (1508) [ 0, -1,  0,  0,  0,  1, -1,  0,  0] [ 6,  0,  6]  1 */
    51021696, /* 57158 (1508) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  0] -1 */
    52570094, /* 57159 (1508) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    17136202, /* 57160 (1508) [ 0,  1,  0,  0,  0, -1, -1,  0,  0] [ 6,  0,  6]  1 */
     1547338, /* 57161 (1508) [ 0,  1,  0,  0,  0,  1,  1,  0,  0] [ 0,  6,  6]  1 */
    18432640, /* 57162 (1508) [ 0,  0, -1,  1,  0,  0,  0, -1,  0] [ 6,  6,  0]  1 */
    17135026, /* 57163 (1508) [ 0,  0,  1,  1,  0,  0,  0,  1,  0] [ 6,  0,  6]  1 */
        7636, /* 57164 (1508) [ 0, -1,  0,  0,  0, -1,  1,  0,  0] [ 0,  0,  0]  1 */
    18430924, /* 57165 (1508) [ 0, -1,  0,  0,  0, -1,  1,  0,  0] [ 6,  6,  0]  1 */
    34137994, /* 57166 (1508) [ 0, -1,  0,  0,  0,  1, -1,  0,  0] [ 0,  0,  6] -1 */
    52561282, /* 57167 (1508) [ 0, -1,  0,  0,  0,  1, -1,  0,  0] [ 6,  6,  6] -1 */
    34133682, /* 57168 (1508) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
    51021536, /* 57169 (1508) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  0] -1 */
    51026008, /* 57170 (1508) [ 0, -1,  0,  0,  0,  1, -1,  0,  0] [ 6,  0,  0] -1 */
    34142314, /* 57171 (1508) [ 0,  1,  0,  0,  0, -1, -1,  0,  0] [ 0,  0,  6] -1 */
    52565602, /* 57172 (1508) [ 0,  1,  0,  0,  0, -1, -1,  0,  0] [ 6,  6,  6] -1 */
    34142386, /* 57173 (1508) [ 0,  1,  0,  0,  0,  1,  1,  0,  0] [ 0,  0,  6] -1 */
    52565674, /* 57174 (1508) [ 0,  1,  0,  0,  0,  1,  1,  0,  0] [ 6,  6,  6] -1 */
     1551594, /* 57175 (1508) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
    34141138, /* 57176 (1508) [ 0,  0,  1,  1,  0,  0,  0,  1,  0] [ 0,  0,  6] -1 */
    52564426, /* 57177 (1508) [ 0,  0,  1,  1,  0,  0,  0,  1,  0] [ 6,  6,  6] -1 */
    35438272, /* 57178 (1508) [ 0,  0, -1, -1,  0,  0,  0,  1,  0] [ 0,  6,  0] -1 */
    51029152, /* 57179 (1508) [ 0,  0,  1,  1,  0,  0,  0,  1,  0] [ 6,  0,  0] -1 */
     1544626, /* 57180 (1508) [ 0,  0, -1,  1,  0,  0,  0, -1,  0] [ 0,  6,  6]  1 */
        3200, /* 57181 (1508) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
     1542910, /* 57182 (1508) [ 0, -1,  0,  0,  0, -1,  1,  0,  0] [ 0,  6,  6]  1 */
       16484, /* 57183 (1509) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
       16320, /* 57184 (1509) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    18549022, /* 57185 (1509) [ 0, -1,  0,  0,  0, -1,  1,  0,  0] [ 6,  6,  6]  1 */
    18550738, /* 57186 (1509) [ 0,  0, -1,  1,  0,  0,  0, -1,  0] [ 6,  6,  6]  1 */
        7636, /* 57187 (1509) [ 0, -1,  0,  0,  0, -1,  1,  0,  0] [ 0,  0,  0]  1 */
        9352, /* 57188 (1509) [ 0,  0, -1,  1,  0,  0,  0, -1,  0] [ 0,  0,  0]  1 */
    18544746, /* 57189 (1509) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
    18557870, /* 57190 (1509) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
        8872, /* 57191 (1509) [ 0,  0, -1, -1,  0,  0,  0,  1,  0] [ 0,  0,  0]  1 */
    18550258, /* 57192 (1509) [ 0,  0, -1, -1,  0,  0,  0,  1,  0] [ 6,  6,  6]  1 */
        7672, /* 57193 (1509) [ 0, -1,  0,  0,  0,  1, -1,  0,  0] [ 0,  0,  0]  1 */
        3360, /* 57194 (1509) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    18549058, /* 57195 (1509) [ 0, -1,  0,  0,  0,  1, -1,  0,  0] [ 6,  6,  6]  1 */
    18553378, /* 57196 (1509) [ 0,  1,  0,  0,  0, -1, -1,  0,  0] [ 6,  6,  6]  1 */
       10816, /* 57197 (1509) [ 0,  0,  1,  1,  0,  0,  0,  1,  0] [ 0,  0,  0]  1 */
        3200, /* 57198 (1509) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    18553450, /* 57199 (1509) [ 0,  1,  0,  0,  0,  1,  1,  0,  0] [ 6,  6,  6]  1 */
       11992, /* 57200 (1509) [ 0,  1,  0,  0,  0, -1, -1,  0,  0] [ 0,  0,  0]  1 */
    18552202, /* 57201 (1509) [ 0,  0,  1,  1,  0,  0,  0,  1,  0] [ 6,  6,  6]  1 */
       12064, /* 57202 (1509) [ 0,  1,  0,  0,  0,  1,  1,  0,  0] [ 0,  0,  0]  1 */
    18544586, /* 57203 (1509) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    18551710, /* 57204 (1509) [ 0,  0,  1, -1,  0,  0,  0, -1,  0] [ 6,  6,  6]  1 */
       10324, /* 57205 (1509) [ 0,  0,  1, -1,  0,  0,  0, -1,  0] [ 0,  0,  0]  1 */
    18557706, /* 57206 (1509) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
       16484, /* 57207 (1510) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    52562962, /* 57208 (1510) [ 0,  0, -1,  1,  0,  0,  0, -1,  0] [ 6,  6,  6] -1 */
    34019860, /* 57209 (1510) [ 0, -1,  0,  0,  0, -1,  1,  0,  0] [ 0,  0,  0] -1 */
       16320, /* 57210 (1510) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    34021576, /* 57211 (1510) [ 0,  0, -1,  1,  0,  0,  0, -1,  0] [ 0,  0,  0] -1 */
    52556970, /* 57212 (1510) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    52570094, /* 57213 (1510) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    34021096, /* 57214 (1510) [ 0,  0, -1, -1,  0,  0,  0,  1,  0] [ 0,  0,  0] -1 */
    52562482, /* 57215 (1510) [ 0,  0, -1, -1,  0,  0,  0,  1,  0] [ 6,  6,  6] -1 */
    34019896, /* 57216 (1510) [ 0, -1,  0,  0,  0,  1, -1,  0,  0] [ 0,  0,  0] -1 */
    18549022, /* 57217 (1510) [ 0, -1,  0,  0,  0, -1,  1,  0,  0] [ 6,  6,  6]  1 */
    34015584, /* 57218 (1510) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    18550738, /* 57219 (1510) [ 0,  0, -1,  1,  0,  0,  0, -1,  0] [ 6,  6,  6]  1 */
        7636, /* 57220 (1510) [ 0, -1,  0,  0,  0, -1,  1,  0,  0] [ 0,  0,  0]  1 */
    52561282, /* 57221 (1510) [ 0, -1,  0,  0,  0,  1, -1,  0,  0] [ 6,  6,  6] -1 */
        9352, /* 57222 (1510) [ 0,  0, -1,  1,  0,  0,  0, -1,  0] [ 0,  0,  0]  1 */
    34015424, /* 57223 (1510) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    34028708, /* 57224 (1510) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    18544746, /* 57225 (1510) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
    52565602, /* 57226 (1510) [ 0,  1,  0,  0,  0, -1, -1,  0,  0] [ 6,  6,  6] -1 */
    34023040, /* 57227 (1510) [ 0,  0,  1,  1,  0,  0,  0,  1,  0] [ 0,  0,  0] -1 */
    52565674, /* 57228 (1510) [ 0,  1,  0,  0,  0,  1,  1,  0,  0] [ 6,  6,  6] -1 */
    34024216, /* 57229 (1510) [ 0,  1,  0,  0,  0, -1, -1,  0,  0] [ 0,  0,  0] -1 */
    18557870, /* 57230 (1510) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    52556810, /* 57231 (1510) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
        8872, /* 57232 (1510) [ 0,  0, -1, -1,  0,  0,  0,  1,  0] [ 0,  0,  0]  1 */
    52564426, /* 57233 (1510) [ 0,  0,  1,  1,  0,  0,  0,  1,  0] [ 6,  6,  6] -1 */
    34024288, /* 57234 (1510) [ 0,  1,  0,  0,  0,  1,  1,  0,  0] [ 0,  0,  0] -1 */
    52563934, /* 57235 (1510) [ 0,  0,  1, -1,  0,  0,  0, -1,  0] [ 6,  6,  6] -1 */
    34022548, /* 57236 (1510) [ 0,  0,  1, -1,  0,  0,  0, -1,  0] [ 0,  0,  0] -1 */
    18550258, /* 57237 (1510) [ 0,  0, -1, -1,  0,  0,  0,  1,  0] [ 6,  6,  6]  1 */
        7672, /* 57238 (1510) [ 0, -1,  0,  0,  0,  1, -1,  0,  0] [ 0,  0,  0]  1 */
    52569930, /* 57239 (1510) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
        3360, /* 57240 (1510) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    18549058, /* 57241 (1510) [ 0, -1,  0,  0,  0,  1, -1,  0,  0] [ 6,  6,  6]  1 */
    34028544, /* 57242 (1510) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    18553378, /* 57243 (1510) [ 0,  1,  0,  0,  0, -1, -1,  0,  0] [ 6,  6,  6]  1 */
       10816, /* 57244 (1510) [ 0,  0,  1,  1,  0,  0,  0,  1,  0] [ 0,  0,  0]  1 */
        3200, /* 57245 (1510) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    18553450, /* 57246 (1510) [ 0,  1,  0,  0,  0,  1,  1,  0,  0] [ 6,  6,  6]  1 */
       11992, /* 57247 (1510) [ 0,  1,  0,  0,  0, -1, -1,  0,  0] [ 0,  0,  0]  1 */
    18552202, /* 57248 (1510) [ 0,  0,  1,  1,  0,  0,  0,  1,  0] [ 6,  6,  6]  1 */
       12064, /* 57249 (1510) [ 0,  1,  0,  0,  0,  1,  1,  0,  0] [ 0,  0,  0]  1 */
    18544586, /* 57250 (1510) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    18551710, /* 57251 (1510) [ 0,  0,  1, -1,  0,  0,  0, -1,  0] [ 6,  6,  6]  1 */
    52561246, /* 57252 (1510) [ 0, -1,  0,  0,  0, -1,  1,  0,  0] [ 6,  6,  6] -1 */
       10324, /* 57253 (1510) [ 0,  0,  1, -1,  0,  0,  0, -1,  0] [ 0,  0,  0]  1 */
    18557706, /* 57254 (1510) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
       16484, /* 57255 (1511) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
     1544626, /* 57256 (1511) [ 0,  0, -1,  1,  0,  0,  0, -1,  0] [ 0,  6,  6]  1 */
       10816, /* 57257 (1511) [ 0,  0,  1,  1,  0,  0,  0,  1,  0] [ 0,  0,  0]  1 */
    18439608, /* 57258 (1511) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
    18433612, /* 57259 (1511) [ 0,  0,  1, -1,  0,  0,  0, -1,  0] [ 6,  6,  0]  1 */
     1542946, /* 57260 (1511) [ 0, -1,  0,  0,  0,  1, -1,  0,  0] [ 0,  6,  6]  1 */
    17133082, /* 57261 (1511) [ 0,  0, -1, -1,  0,  0,  0,  1,  0] [ 6,  0,  6]  1 */
       12064, /* 57262 (1511) [ 0,  1,  0,  0,  0,  1,  1,  0,  0] [ 0,  0,  0]  1 */
    17127410, /* 57263 (1511) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
    17131846, /* 57264 (1511) [ 0, -1,  0,  0,  0, -1,  1,  0,  0] [ 6,  0,  6]  1 */
    18435280, /* 57265 (1511) [ 0,  1,  0,  0,  0, -1, -1,  0,  0] [ 6,  6,  0]  1 */
     1538634, /* 57266 (1511) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
       16484, /* 57267 (1512) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    18439608, /* 57268 (1512) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
     1542946, /* 57269 (1512) [ 0, -1,  0,  0,  0,  1, -1,  0,  0] [ 0,  6,  6]  1 */
    17133082, /* 57270 (1512) [ 0,  0, -1, -1,  0,  0,  0,  1,  0] [ 6,  0,  6]  1 */
    17127410, /* 57271 (1512) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
    52447504, /* 57272 (1512) [ 0,  1,  0,  0,  0, -1, -1,  0,  0] [ 6,  6,  0] -1 */
    35556850, /* 57273 (1512) [ 0,  0, -1,  1,  0,  0,  0, -1,  0] [ 0,  6,  6] -1 */
    34028708, /* 57274 (1512) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    34023040, /* 57275 (1512) [ 0,  0,  1,  1,  0,  0,  0,  1,  0] [ 0,  0,  0] -1 */
    52445836, /* 57276 (1512) [ 0,  0,  1, -1,  0,  0,  0, -1,  0] [ 6,  6,  0] -1 */
    34024288, /* 57277 (1512) [ 0,  1,  0,  0,  0,  1,  1,  0,  0] [ 0,  0,  0] -1 */
    51144070, /* 57278 (1512) [ 0, -1,  0,  0,  0, -1,  1,  0,  0] [ 6,  0,  6] -1 */
    18435280, /* 57279 (1512) [ 0,  1,  0,  0,  0, -1, -1,  0,  0] [ 6,  6,  0]  1 */
    35550858, /* 57280 (1512) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6] -1 */
    52451832, /* 57281 (1512) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
    51145306, /* 57282 (1512) [ 0,  0, -1, -1,  0,  0,  0,  1,  0] [ 6,  0,  6] -1 */
     1544626, /* 57283 (1512) [ 0,  0, -1,  1,  0,  0,  0, -1,  0] [ 0,  6,  6]  1 */
       10816, /* 57284 (1512) [ 0,  0,  1,  1,  0,  0,  0,  1,  0] [ 0,  0,  0]  1 */
    35555170, /* 57285 (1512) [ 0, -1,  0,  0,  0,  1, -1,  0,  0] [ 0,  6,  6] -1 */
    18433612, /* 57286 (1512) [ 0,  0,  1, -1,  0,  0,  0, -1,  0] [ 6,  6,  0]  1 */
    51139634, /* 57287 (1512) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
       12064, /* 57288 (1512) [ 0,  1,  0,  0,  0,  1,  1,  0,  0] [ 0,  0,  0]  1 */
    17131846, /* 57289 (1512) [ 0, -1,  0,  0,  0, -1,  1,  0,  0] [ 6,  0,  6]  1 */
     1538634, /* 57290 (1512) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
       16484, /* 57291 (1513) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    18439608, /* 57292 (1513) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
     1542946, /* 57293 (1513) [ 0, -1,  0,  0,  0,  1, -1,  0,  0] [ 0,  6,  6]  1 */
    17133082, /* 57294 (1513) [ 0,  0, -1, -1,  0,  0,  0,  1,  0] [ 6,  0,  6]  1 */
    51027688, /* 57295 (1513) [ 0,  0, -1,  1,  0,  0,  0, -1,  0] [ 6,  0,  0] -1 */
    17127410, /* 57296 (1513) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
    51021696, /* 57297 (1513) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  0] -1 */
    52570094, /* 57298 (1513) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    35437036, /* 57299 (1513) [ 0, -1,  0,  0,  0, -1,  1,  0,  0] [ 0,  6,  0] -1 */
    51026008, /* 57300 (1513) [ 0, -1,  0,  0,  0,  1, -1,  0,  0] [ 6,  0,  0] -1 */
    34142314, /* 57301 (1513) [ 0,  1,  0,  0,  0, -1, -1,  0,  0] [ 0,  0,  6] -1 */
    52565674, /* 57302 (1513) [ 0,  1,  0,  0,  0,  1,  1,  0,  0] [ 6,  6,  6] -1 */
    52564426, /* 57303 (1513) [ 0,  0,  1,  1,  0,  0,  0,  1,  0] [ 6,  6,  6] -1 */
    34140646, /* 57304 (1513) [ 0,  0,  1, -1,  0,  0,  0, -1,  0] [ 0,  0,  6] -1 */
    35438272, /* 57305 (1513) [ 0,  0, -1, -1,  0,  0,  0,  1,  0] [ 0,  6,  0] -1 */
    34146642, /* 57306 (1513) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
    18435280, /* 57307 (1513) [ 0,  1,  0,  0,  0, -1, -1,  0,  0] [ 6,  6,  0]  1 */
     1544626, /* 57308 (1513) [ 0,  0, -1,  1,  0,  0,  0, -1,  0] [ 0,  6,  6]  1 */
       10816, /* 57309 (1513) [ 0,  0,  1,  1,  0,  0,  0,  1,  0] [ 0,  0,  0]  1 */
    18433612, /* 57310 (1513) [ 0,  0,  1, -1,  0,  0,  0, -1,  0] [ 6,  6,  0]  1 */
    35432600, /* 57311 (1513) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  0] -1 */
       12064, /* 57312 (1513) [ 0,  1,  0,  0,  0,  1,  1,  0,  0] [ 0,  0,  0]  1 */
    17131846, /* 57313 (1513) [ 0, -1,  0,  0,  0, -1,  1,  0,  0] [ 6,  0,  6]  1 */
     1538634, /* 57314 (1513) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
       16484, /* 57315 (1514) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
      134418, /* 57316 (1514) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  6]  1 */
    18439608, /* 57317 (1514) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
     1542946, /* 57318 (1514) [ 0, -1,  0,  0,  0,  1, -1,  0,  0] [ 0,  6,  6]  1 */
    17133082, /* 57319 (1514) [ 0,  0, -1, -1,  0,  0,  0,  1,  0] [ 6,  0,  6]  1 */
     1420376, /* 57320 (1514) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  0]  1 */
    17127410, /* 57321 (1514) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
    17015464, /* 57322 (1514) [ 0,  0, -1,  1,  0,  0,  0, -1,  0] [ 6,  0,  0]  1 */
    18557870, /* 57323 (1514) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    17009472, /* 57324 (1514) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  0]  1 */
    18435280, /* 57325 (1514) [ 0,  1,  0,  0,  0, -1, -1,  0,  0] [ 6,  6,  0]  1 */
     1544626, /* 57326 (1514) [ 0,  0, -1,  1,  0,  0,  0, -1,  0] [ 0,  6,  6]  1 */
     1424812, /* 57327 (1514) [ 0, -1,  0,  0,  0, -1,  1,  0,  0] [ 0,  6,  0]  1 */
       10816, /* 57328 (1514) [ 0,  0,  1,  1,  0,  0,  0,  1,  0] [ 0,  0,  0]  1 */
      130090, /* 57329 (1514) [ 0,  1,  0,  0,  0, -1, -1,  0,  0] [ 0,  0,  6]  1 */
    17013784, /* 57330 (1514) [ 0, -1,  0,  0,  0,  1, -1,  0,  0] [ 6,  0,  0]  1 */
    18433612, /* 57331 (1514) [ 0,  0,  1, -1,  0,  0,  0, -1,  0] [ 6,  6,  0]  1 */
    18553450, /* 57332 (1514) [ 0,  1,  0,  0,  0,  1,  1,  0,  0] [ 6,  6,  6]  1 */
    18552202, /* 57333 (1514) [ 0,  0,  1,  1,  0,  0,  0,  1,  0] [ 6,  6,  6]  1 */
       12064, /* 57334 (1514) [ 0,  1,  0,  0,  0,  1,  1,  0,  0] [ 0,  0,  0]  1 */
    17131846, /* 57335 (1514) [ 0, -1,  0,  0,  0, -1,  1,  0,  0] [ 6,  0,  6]  1 */
      128422, /* 57336 (1514) [ 0,  0,  1, -1,  0,  0,  0, -1,  0] [ 0,  0,  6]  1 */
     1426048, /* 57337 (1514) [ 0,  0, -1, -1,  0,  0,  0,  1,  0] [ 0,  6,  0]  1 */
     1538634, /* 57338 (1514) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
       16484, /* 57339 (1515) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
      134418, /* 57340 (1515) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  6]  1 */
    18439608, /* 57341 (1515) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
    51027688, /* 57342 (1515) [ 0,  0, -1,  1,  0,  0,  0, -1,  0] [ 6,  0,  0] -1 */
    17133082, /* 57343 (1515) [ 0,  0, -1, -1,  0,  0,  0,  1,  0] [ 6,  0,  6]  1 */
     1542946, /* 57344 (1515) [ 0, -1,  0,  0,  0,  1, -1,  0,  0] [ 0,  6,  6]  1 */
     1420376, /* 57345 (1515) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  0]  1 */
    17127410, /* 57346 (1515) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
    51021696, /* 57347 (1515) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  0] -1 */
    52570094, /* 57348 (1515) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    52447504, /* 57349 (1515) [ 0,  1,  0,  0,  0, -1, -1,  0,  0] [ 6,  6,  0] -1 */
    17015464, /* 57350 (1515) [ 0,  0, -1,  1,  0,  0,  0, -1,  0] [ 6,  0,  0]  1 */
    35556850, /* 57351 (1515) [ 0,  0, -1,  1,  0,  0,  0, -1,  0] [ 0,  6,  6] -1 */
    35437036, /* 57352 (1515) [ 0, -1,  0,  0,  0, -1,  1,  0,  0] [ 0,  6,  0] -1 */
    51026008, /* 57353 (1515) [ 0, -1,  0,  0,  0,  1, -1,  0,  0] [ 6,  0,  0] -1 */
    34028708, /* 57354 (1515) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    34142314, /* 57355 (1515) [ 0,  1,  0,  0,  0, -1, -1,  0,  0] [ 0,  0,  6] -1 */
    34023040, /* 57356 (1515) [ 0,  0,  1,  1,  0,  0,  0,  1,  0] [ 0,  0,  0] -1 */
    52565674, /* 57357 (1515) [ 0,  1,  0,  0,  0,  1,  1,  0,  0] [ 6,  6,  6] -1 */
    52445836, /* 57358 (1515) [ 0,  0,  1, -1,  0,  0,  0, -1,  0] [ 6,  6,  0] -1 */
    18557870, /* 57359 (1515) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    17009472, /* 57360 (1515) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  0]  1 */
    52564426, /* 57361 (1515) [ 0,  0,  1,  1,  0,  0,  0,  1,  0] [ 6,  6,  6] -1 */
    34140646, /* 57362 (1515) [ 0,  0,  1, -1,  0,  0,  0, -1,  0] [ 0,  0,  6] -1 */
    35438272, /* 57363 (1515) [ 0,  0, -1, -1,  0,  0,  0,  1,  0] [ 0,  6,  0] -1 */
    34024288, /* 57364 (1515) [ 0,  1,  0,  0,  0,  1,  1,  0,  0] [ 0,  0,  0] -1 */
    51144070, /* 57365 (1515) [ 0, -1,  0,  0,  0, -1,  1,  0,  0] [ 6,  0,  6] -1 */
    34146642, /* 57366 (1515) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
    35550858, /* 57367 (1515) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6] -1 */
    18435280, /* 57368 (1515) [ 0,  1,  0,  0,  0, -1, -1,  0,  0] [ 6,  6,  0]  1 */
    52451832, /* 57369 (1515) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
    51145306, /* 57370 (1515) [ 0,  0, -1, -1,  0,  0,  0,  1,  0] [ 6,  0,  6] -1 */
     1544626, /* 57371 (1515) [ 0,  0, -1,  1,  0,  0,  0, -1,  0] [ 0,  6,  6]  1 */
     1424812, /* 57372 (1515) [ 0, -1,  0,  0,  0, -1,  1,  0,  0] [ 0,  6,  0]  1 */
       10816, /* 57373 (1515) [ 0,  0,  1,  1,  0,  0,  0,  1,  0] [ 0,  0,  0]  1 */
      130090, /* 57374 (1515) [ 0,  1,  0,  0,  0, -1, -1,  0,  0] [ 0,  0,  6]  1 */
    17013784, /* 57375 (1515) [ 0, -1,  0,  0,  0,  1, -1,  0,  0] [ 6,  0,  0]  1 */
    18433612, /* 57376 (1515) [ 0,  0,  1, -1,  0,  0,  0, -1,  0] [ 6,  6,  0]  1 */
    35555170, /* 57377 (1515) [ 0, -1,  0,  0,  0,  1, -1,  0,  0] [ 0,  6,  6] -1 */
    35432600, /* 57378 (1515) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  0] -1 */
    18553450, /* 57379 (1515) [ 0,  1,  0,  0,  0,  1,  1,  0,  0] [ 6,  6,  6]  1 */
    51139634, /* 57380 (1515) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
    18552202, /* 57381 (1515) [ 0,  0,  1,  1,  0,  0,  0,  1,  0] [ 6,  6,  6]  1 */
       12064, /* 57382 (1515) [ 0,  1,  0,  0,  0,  1,  1,  0,  0] [ 0,  0,  0]  1 */
    17131846, /* 57383 (1515) [ 0, -1,  0,  0,  0, -1,  1,  0,  0] [ 6,  0,  6]  1 */
      128422, /* 57384 (1515) [ 0,  0,  1, -1,  0,  0,  0, -1,  0] [ 0,  0,  6]  1 */
     1426048, /* 57385 (1515) [ 0,  0, -1, -1,  0,  0,  0,  1,  0] [ 0,  6,  0]  1 */
     1538634, /* 57386 (1515) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
       16484, /* 57387 (1516) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
       16320, /* 57388 (1516) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
        3198, /* 57389 (1516) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
        7690, /* 57390 (1516) [ 0, -1,  0,  0,  0,  1,  1,  0,  0] [ 0,  0,  0]  1 */
        8866, /* 57391 (1516) [ 0,  0, -1, -1,  0,  0,  0, -1,  0] [ 0,  0,  0]  1 */
       10810, /* 57392 (1516) [ 0,  0,  1,  1,  0,  0,  0, -1,  0] [ 0,  0,  0]  1 */
        7636, /* 57393 (1516) [ 0, -1,  0,  0,  0, -1,  1,  0,  0] [ 0,  0,  0]  1 */
        9352, /* 57394 (1516) [ 0,  0, -1,  1,  0,  0,  0, -1,  0] [ 0,  0,  0]  1 */
        8872, /* 57395 (1516) [ 0,  0, -1, -1,  0,  0,  0,  1,  0] [ 0,  0,  0]  1 */
        7672, /* 57396 (1516) [ 0, -1,  0,  0,  0,  1, -1,  0,  0] [ 0,  0,  0]  1 */
       10330, /* 57397 (1516) [ 0,  0,  1, -1,  0,  0,  0,  1,  0] [ 0,  0,  0]  1 */
        3360, /* 57398 (1516) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
       12046, /* 57399 (1516) [ 0,  1,  0,  0,  0,  1, -1,  0,  0] [ 0,  0,  0]  1 */
       12010, /* 57400 (1516) [ 0,  1,  0,  0,  0, -1,  1,  0,  0] [ 0,  0,  0]  1 */
       16322, /* 57401 (1516) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
       10816, /* 57402 (1516) [ 0,  0,  1,  1,  0,  0,  0,  1,  0] [ 0,  0,  0]  1 */
        3200, /* 57403 (1516) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
        3362, /* 57404 (1516) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
        9358, /* 57405 (1516) [ 0,  0, -1,  1,  0,  0,  0,  1,  0] [ 0,  0,  0]  1 */
       11992, /* 57406 (1516) [ 0,  1,  0,  0,  0, -1, -1,  0,  0] [ 0,  0,  0]  1 */
       12064, /* 57407 (1516) [ 0,  1,  0,  0,  0,  1,  1,  0,  0] [ 0,  0,  0]  1 */
        7618, /* 57408 (1516) [ 0, -1,  0,  0,  0, -1, -1,  0,  0] [ 0,  0,  0]  1 */
       16482, /* 57409 (1516) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
       10324, /* 57410 (1516) [ 0,  0,  1, -1,  0,  0,  0, -1,  0] [ 0,  0,  0]  1 */
       16484, /* 57411 (1517) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34019860, /* 57412 (1517) [ 0, -1,  0,  0,  0, -1,  1,  0,  0] [ 0,  0,  0] -1 */
       16320, /* 57413 (1517) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    34021576, /* 57414 (1517) [ 0,  0, -1,  1,  0,  0,  0, -1,  0] [ 0,  0,  0] -1 */
        3198, /* 57415 (1517) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    34021096, /* 57416 (1517) [ 0,  0, -1, -1,  0,  0,  0,  1,  0] [ 0,  0,  0] -1 */
        8866, /* 57417 (1517) [ 0,  0, -1, -1,  0,  0,  0, -1,  0] [ 0,  0,  0]  1 */
        7690, /* 57418 (1517) [ 0, -1,  0,  0,  0,  1,  1,  0,  0] [ 0,  0,  0]  1 */
       10810, /* 57419 (1517) [ 0,  0,  1,  1,  0,  0,  0, -1,  0] [ 0,  0,  0]  1 */
    34019896, /* 57420 (1517) [ 0, -1,  0,  0,  0,  1, -1,  0,  0] [ 0,  0,  0] -1 */
    34015584, /* 57421 (1517) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
        7636, /* 57422 (1517) [ 0, -1,  0,  0,  0, -1,  1,  0,  0] [ 0,  0,  0]  1 */
    34022554, /* 57423 (1517) [ 0,  0,  1, -1,  0,  0,  0,  1,  0] [ 0,  0,  0] -1 */
    34024234, /* 57424 (1517) [ 0,  1,  0,  0,  0, -1,  1,  0,  0] [ 0,  0,  0] -1 */
        9352, /* 57425 (1517) [ 0,  0, -1,  1,  0,  0,  0, -1,  0] [ 0,  0,  0]  1 */
    34024270, /* 57426 (1517) [ 0,  1,  0,  0,  0,  1, -1,  0,  0] [ 0,  0,  0] -1 */
    34015424, /* 57427 (1517) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    34028546, /* 57428 (1517) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    34028708, /* 57429 (1517) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    34021582, /* 57430 (1517) [ 0,  0, -1,  1,  0,  0,  0,  1,  0] [ 0,  0,  0] -1 */
    34023040, /* 57431 (1517) [ 0,  0,  1,  1,  0,  0,  0,  1,  0] [ 0,  0,  0] -1 */
    34024216, /* 57432 (1517) [ 0,  1,  0,  0,  0, -1, -1,  0,  0] [ 0,  0,  0] -1 */
    34015586, /* 57433 (1517) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
        8872, /* 57434 (1517) [ 0,  0, -1, -1,  0,  0,  0,  1,  0] [ 0,  0,  0]  1 */
    34024288, /* 57435 (1517) [ 0,  1,  0,  0,  0,  1,  1,  0,  0] [ 0,  0,  0] -1 */
    34028706, /* 57436 (1517) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    34022548, /* 57437 (1517) [ 0,  0,  1, -1,  0,  0,  0, -1,  0] [ 0,  0,  0] -1 */
    34019842, /* 57438 (1517) [ 0, -1,  0,  0,  0, -1, -1,  0,  0] [ 0,  0,  0] -1 */
        7672, /* 57439 (1517) [ 0, -1,  0,  0,  0,  1, -1,  0,  0] [ 0,  0,  0]  1 */
       10330, /* 57440 (1517) [ 0,  0,  1, -1,  0,  0,  0,  1,  0] [ 0,  0,  0]  1 */
        3360, /* 57441 (1517) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
       12046, /* 57442 (1517) [ 0,  1,  0,  0,  0,  1, -1,  0,  0] [ 0,  0,  0]  1 */
    34028544, /* 57443 (1517) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
       12010, /* 57444 (1517) [ 0,  1,  0,  0,  0, -1,  1,  0,  0] [ 0,  0,  0]  1 */
       16322, /* 57445 (1517) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
       10816, /* 57446 (1517) [ 0,  0,  1,  1,  0,  0,  0,  1,  0] [ 0,  0,  0]  1 */
    34015422, /* 57447 (1517) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
        3200, /* 57448 (1517) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
        3362, /* 57449 (1517) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
        9358, /* 57450 (1517) [ 0,  0, -1,  1,  0,  0,  0,  1,  0] [ 0,  0,  0]  1 */
       11992, /* 57451 (1517) [ 0,  1,  0,  0,  0, -1, -1,  0,  0] [ 0,  0,  0]  1 */
       12064, /* 57452 (1517) [ 0,  1,  0,  0,  0,  1,  1,  0,  0] [ 0,  0,  0]  1 */
    34023034, /* 57453 (1517) [ 0,  0,  1,  1,  0,  0,  0, -1,  0] [ 0,  0,  0] -1 */
    34019914, /* 57454 (1517) [ 0, -1,  0,  0,  0,  1,  1,  0,  0] [ 0,  0,  0] -1 */
    34021090, /* 57455 (1517) [ 0,  0, -1, -1,  0,  0,  0, -1,  0] [ 0,  0,  0] -1 */
        7618, /* 57456 (1517) [ 0, -1,  0,  0,  0, -1, -1,  0,  0] [ 0,  0,  0]  1 */
       16482, /* 57457 (1517) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
       10324, /* 57458 (1517) [ 0,  0,  1, -1,  0,  0,  0, -1,  0] [ 0,  0,  0]  1 */
       16484, /* 57459 (1518) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
       16320, /* 57460 (1518) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
        7636, /* 57461 (1518) [ 0, -1,  0,  0,  0, -1,  1,  0,  0] [ 0,  0,  0]  1 */
    34022554, /* 57462 (1518) [ 0,  0,  1, -1,  0,  0,  0,  1,  0] [ 0,  0,  0] -1 */
    34024234, /* 57463 (1518) [ 0,  1,  0,  0,  0, -1,  1,  0,  0] [ 0,  0,  0] -1 */
        9352, /* 57464 (1518) [ 0,  0, -1,  1,  0,  0,  0, -1,  0] [ 0,  0,  0]  1 */
    34024270, /* 57465 (1518) [ 0,  1,  0,  0,  0,  1, -1,  0,  0] [ 0,  0,  0] -1 */
    34028546, /* 57466 (1518) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    34021582, /* 57467 (1518) [ 0,  0, -1,  1,  0,  0,  0,  1,  0] [ 0,  0,  0] -1 */
    34015586, /* 57468 (1518) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
        8872, /* 57469 (1518) [ 0,  0, -1, -1,  0,  0,  0,  1,  0] [ 0,  0,  0]  1 */
    34028706, /* 57470 (1518) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    34019842, /* 57471 (1518) [ 0, -1,  0,  0,  0, -1, -1,  0,  0] [ 0,  0,  0] -1 */
        7672, /* 57472 (1518) [ 0, -1,  0,  0,  0,  1, -1,  0,  0] [ 0,  0,  0]  1 */
        3360, /* 57473 (1518) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    34015422, /* 57474 (1518) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
       10816, /* 57475 (1518) [ 0,  0,  1,  1,  0,  0,  0,  1,  0] [ 0,  0,  0]  1 */
        3200, /* 57476 (1518) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
       11992, /* 57477 (1518) [ 0,  1,  0,  0,  0, -1, -1,  0,  0] [ 0,  0,  0]  1 */
       12064, /* 57478 (1518) [ 0,  1,  0,  0,  0,  1,  1,  0,  0] [ 0,  0,  0]  1 */
    34023034, /* 57479 (1518) [ 0,  0,  1,  1,  0,  0,  0, -1,  0] [ 0,  0,  0] -1 */
    34019914, /* 57480 (1518) [ 0, -1,  0,  0,  0,  1,  1,  0,  0] [ 0,  0,  0] -1 */
    34021090, /* 57481 (1518) [ 0,  0, -1, -1,  0,  0,  0, -1,  0] [ 0,  0,  0] -1 */
       10324, /* 57482 (1518) [ 0,  0,  1, -1,  0,  0,  0, -1,  0] [ 0,  0,  0]  1 */
       16484, /* 57483 (1519) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    52562962, /* 57484 (1519) [ 0,  0, -1,  1,  0,  0,  0, -1,  0] [ 6,  6,  6] -1 */
       16320, /* 57485 (1519) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
        3198, /* 57486 (1519) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    52556970, /* 57487 (1519) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    52570094, /* 57488 (1519) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
        7690, /* 57489 (1519) [ 0, -1,  0,  0,  0,  1,  1,  0,  0] [ 0,  0,  0]  1 */
        8866, /* 57490 (1519) [ 0,  0, -1, -1,  0,  0,  0, -1,  0] [ 0,  0,  0]  1 */
       10810, /* 57491 (1519) [ 0,  0,  1,  1,  0,  0,  0, -1,  0] [ 0,  0,  0]  1 */
    52563940, /* 57492 (1519) [ 0,  0,  1, -1,  0,  0,  0,  1,  0] [ 6,  6,  6] -1 */
    52562482, /* 57493 (1519) [ 0,  0, -1, -1,  0,  0,  0,  1,  0] [ 6,  6,  6] -1 */
    52562968, /* 57494 (1519) [ 0,  0, -1,  1,  0,  0,  0,  1,  0] [ 6,  6,  6] -1 */
    52565656, /* 57495 (1519) [ 0,  1,  0,  0,  0,  1, -1,  0,  0] [ 6,  6,  6] -1 */
    52565620, /* 57496 (1519) [ 0,  1,  0,  0,  0, -1,  1,  0,  0] [ 6,  6,  6] -1 */
    52569932, /* 57497 (1519) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
        7636, /* 57498 (1519) [ 0, -1,  0,  0,  0, -1,  1,  0,  0] [ 0,  0,  0]  1 */
    52561282, /* 57499 (1519) [ 0, -1,  0,  0,  0,  1, -1,  0,  0] [ 6,  6,  6] -1 */
        9352, /* 57500 (1519) [ 0,  0, -1,  1,  0,  0,  0, -1,  0] [ 0,  0,  0]  1 */
    52556972, /* 57501 (1519) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    52565602, /* 57502 (1519) [ 0,  1,  0,  0,  0, -1, -1,  0,  0] [ 6,  6,  6] -1 */
    52565674, /* 57503 (1519) [ 0,  1,  0,  0,  0,  1,  1,  0,  0] [ 6,  6,  6] -1 */
    52556810, /* 57504 (1519) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
        8872, /* 57505 (1519) [ 0,  0, -1, -1,  0,  0,  0,  1,  0] [ 0,  0,  0]  1 */
    52561228, /* 57506 (1519) [ 0, -1,  0,  0,  0, -1, -1,  0,  0] [ 6,  6,  6] -1 */
    52564426, /* 57507 (1519) [ 0,  0,  1,  1,  0,  0,  0,  1,  0] [ 6,  6,  6] -1 */
    52563934, /* 57508 (1519) [ 0,  0,  1, -1,  0,  0,  0, -1,  0] [ 6,  6,  6] -1 */
        7672, /* 57509 (1519) [ 0, -1,  0,  0,  0,  1, -1,  0,  0] [ 0,  0,  0]  1 */
       10330, /* 57510 (1519) [ 0,  0,  1, -1,  0,  0,  0,  1,  0] [ 0,  0,  0]  1 */
    52569930, /* 57511 (1519) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
        3360, /* 57512 (1519) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    52570092, /* 57513 (1519) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
       12046, /* 57514 (1519) [ 0,  1,  0,  0,  0,  1, -1,  0,  0] [ 0,  0,  0]  1 */
       12010, /* 57515 (1519) [ 0,  1,  0,  0,  0, -1,  1,  0,  0] [ 0,  0,  0]  1 */
       16322, /* 57516 (1519) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    52556808, /* 57517 (1519) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
       10816, /* 57518 (1519) [ 0,  0,  1,  1,  0,  0,  0,  1,  0] [ 0,  0,  0]  1 */
        3200, /* 57519 (1519) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
        3362, /* 57520 (1519) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
        9358, /* 57521 (1519) [ 0,  0, -1,  1,  0,  0,  0,  1,  0] [ 0,  0,  0]  1 */
    52562476, /* 57522 (1519) [ 0,  0, -1, -1,  0,  0,  0, -1,  0] [ 6,  6,  6] -1 */
    52561300, /* 57523 (1519) [ 0, -1,  0,  0,  0,  1,  1,  0,  0] [ 6,  6,  6] -1 */
       11992, /* 57524 (1519) [ 0,  1,  0,  0,  0, -1, -1,  0,  0] [ 0,  0,  0]  1 */
    52564420, /* 57525 (1519) [ 0,  0,  1,  1,  0,  0,  0, -1,  0] [ 6,  6,  6] -1 */
       12064, /* 57526 (1519) [ 0,  1,  0,  0,  0,  1,  1,  0,  0] [ 0,  0,  0]  1 */
        7618, /* 57527 (1519) [ 0, -1,  0,  0,  0, -1, -1,  0,  0] [ 0,  0,  0]  1 */
    52561246, /* 57528 (1519) [ 0, -1,  0,  0,  0, -1,  1,  0,  0] [ 6,  6,  6] -1 */
       16482, /* 57529 (1519) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
       10324, /* 57530 (1519) [ 0,  0,  1, -1,  0,  0,  0, -1,  0] [ 0,  0,  0]  1 */
       16484, /* 57531 (1520) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
        3360, /* 57532 (1520) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    18551716, /* 57533 (1520) [ 0,  0,  1, -1,  0,  0,  0,  1,  0] [ 6,  6,  6]  1 */
    18553396, /* 57534 (1520) [ 0,  1,  0,  0,  0, -1,  1,  0,  0] [ 6,  6,  6]  1 */
    18544748, /* 57535 (1520) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    18544584, /* 57536 (1520) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
       10324, /* 57537 (1520) [ 0,  0,  1, -1,  0,  0,  0, -1,  0] [ 0,  0,  0]  1 */
    18557708, /* 57538 (1520) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
       11992, /* 57539 (1520) [ 0,  1,  0,  0,  0, -1, -1,  0,  0] [ 0,  0,  0]  1 */
        7672, /* 57540 (1520) [ 0, -1,  0,  0,  0,  1, -1,  0,  0] [ 0,  0,  0]  1 */
    18552196, /* 57541 (1520) [ 0,  0,  1,  1,  0,  0,  0, -1,  0] [ 6,  6,  6]  1 */
    18550252, /* 57542 (1520) [ 0,  0, -1, -1,  0,  0,  0, -1,  0] [ 6,  6,  6]  1 */
        7636, /* 57543 (1520) [ 0, -1,  0,  0,  0, -1,  1,  0,  0] [ 0,  0,  0]  1 */
       16320, /* 57544 (1520) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
        8872, /* 57545 (1520) [ 0,  0, -1, -1,  0,  0,  0,  1,  0] [ 0,  0,  0]  1 */
    18553432, /* 57546 (1520) [ 0,  1,  0,  0,  0,  1, -1,  0,  0] [ 6,  6,  6]  1 */
    18549076, /* 57547 (1520) [ 0, -1,  0,  0,  0,  1,  1,  0,  0] [ 6,  6,  6]  1 */
        3200, /* 57548 (1520) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
       10816, /* 57549 (1520) [ 0,  0,  1,  1,  0,  0,  0,  1,  0] [ 0,  0,  0]  1 */
        9352, /* 57550 (1520) [ 0,  0, -1,  1,  0,  0,  0, -1,  0] [ 0,  0,  0]  1 */
       12064, /* 57551 (1520) [ 0,  1,  0,  0,  0,  1,  1,  0,  0] [ 0,  0,  0]  1 */
    18557868, /* 57552 (1520) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
    18549004, /* 57553 (1520) [ 0, -1,  0,  0,  0, -1, -1,  0,  0] [ 6,  6,  6]  1 */
    18550744, /* 57554 (1520) [ 0,  0, -1,  1,  0,  0,  0,  1,  0] [ 6,  6,  6]  1 */
       16484, /* 57555 (1521) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34019860, /* 57556 (1521) [ 0, -1,  0,  0,  0, -1,  1,  0,  0] [ 0,  0,  0] -1 */
        3360, /* 57557 (1521) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    18551716, /* 57558 (1521) [ 0,  0,  1, -1,  0,  0,  0,  1,  0] [ 6,  6,  6]  1 */
    18553396, /* 57559 (1521) [ 0,  1,  0,  0,  0, -1,  1,  0,  0] [ 6,  6,  6]  1 */
    18544748, /* 57560 (1521) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    18544584, /* 57561 (1521) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
       10324, /* 57562 (1521) [ 0,  0,  1, -1,  0,  0,  0, -1,  0] [ 0,  0,  0]  1 */
    18557708, /* 57563 (1521) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
       11992, /* 57564 (1521) [ 0,  1,  0,  0,  0, -1, -1,  0,  0] [ 0,  0,  0]  1 */
        7672, /* 57565 (1521) [ 0, -1,  0,  0,  0,  1, -1,  0,  0] [ 0,  0,  0]  1 */
    34021096, /* 57566 (1521) [ 0,  0, -1, -1,  0,  0,  0,  1,  0] [ 0,  0,  0] -1 */
    18552196, /* 57567 (1521) [ 0,  0,  1,  1,  0,  0,  0, -1,  0] [ 6,  6,  6]  1 */
    34028544, /* 57568 (1521) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    18550252, /* 57569 (1521) [ 0,  0, -1, -1,  0,  0,  0, -1,  0] [ 6,  6,  6]  1 */
        7636, /* 57570 (1521) [ 0, -1,  0,  0,  0, -1,  1,  0,  0] [ 0,  0,  0]  1 */
    52561300, /* 57571 (1521) [ 0, -1,  0,  0,  0,  1,  1,  0,  0] [ 6,  6,  6] -1 */
    52565656, /* 57572 (1521) [ 0,  1,  0,  0,  0,  1, -1,  0,  0] [ 6,  6,  6] -1 */
    34015424, /* 57573 (1521) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    34028708, /* 57574 (1521) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    34023040, /* 57575 (1521) [ 0,  0,  1,  1,  0,  0,  0,  1,  0] [ 0,  0,  0] -1 */
       16320, /* 57576 (1521) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    34021576, /* 57577 (1521) [ 0,  0, -1,  1,  0,  0,  0, -1,  0] [ 0,  0,  0] -1 */
        8872, /* 57578 (1521) [ 0,  0, -1, -1,  0,  0,  0,  1,  0] [ 0,  0,  0]  1 */
    34024288, /* 57579 (1521) [ 0,  1,  0,  0,  0,  1,  1,  0,  0] [ 0,  0,  0] -1 */
    52570092, /* 57580 (1521) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    52561228, /* 57581 (1521) [ 0, -1,  0,  0,  0, -1, -1,  0,  0] [ 6,  6,  6] -1 */
    52562968, /* 57582 (1521) [ 0,  0, -1,  1,  0,  0,  0,  1,  0] [ 6,  6,  6] -1 */
    18553432, /* 57583 (1521) [ 0,  1,  0,  0,  0,  1, -1,  0,  0] [ 6,  6,  6]  1 */
    18549076, /* 57584 (1521) [ 0, -1,  0,  0,  0,  1,  1,  0,  0] [ 6,  6,  6]  1 */
    52563940, /* 57585 (1521) [ 0,  0,  1, -1,  0,  0,  0,  1,  0] [ 6,  6,  6] -1 */
        3200, /* 57586 (1521) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34015584, /* 57587 (1521) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
       10816, /* 57588 (1521) [ 0,  0,  1,  1,  0,  0,  0,  1,  0] [ 0,  0,  0]  1 */
    52556808, /* 57589 (1521) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    52565620, /* 57590 (1521) [ 0,  1,  0,  0,  0, -1,  1,  0,  0] [ 6,  6,  6] -1 */
    52569932, /* 57591 (1521) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    52556972, /* 57592 (1521) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
        9352, /* 57593 (1521) [ 0,  0, -1,  1,  0,  0,  0, -1,  0] [ 0,  0,  0]  1 */
    34022548, /* 57594 (1521) [ 0,  0,  1, -1,  0,  0,  0, -1,  0] [ 0,  0,  0] -1 */
    34024216, /* 57595 (1521) [ 0,  1,  0,  0,  0, -1, -1,  0,  0] [ 0,  0,  0] -1 */
    34019896, /* 57596 (1521) [ 0, -1,  0,  0,  0,  1, -1,  0,  0] [ 0,  0,  0] -1 */
       12064, /* 57597 (1521) [ 0,  1,  0,  0,  0,  1,  1,  0,  0] [ 0,  0,  0]  1 */
    52564420, /* 57598 (1521) [ 0,  0,  1,  1,  0,  0,  0, -1,  0] [ 6,  6,  6] -1 */
    18557868, /* 57599 (1521) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
    52562476, /* 57600 (1521) [ 0,  0, -1, -1,  0,  0,  0, -1,  0] [ 6,  6,  6] -1 */
    18549004, /* 57601 (1521) [ 0, -1,  0,  0,  0, -1, -1,  0,  0] [ 6,  6,  6]  1 */
    18550744, /* 57602 (1521) [ 0,  0, -1,  1,  0,  0,  0,  1,  0] [ 6,  6,  6]  1 */
       16484, /* 57603 (1522) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
        3360, /* 57604 (1522) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
       10324, /* 57605 (1522) [ 0,  0,  1, -1,  0,  0,  0, -1,  0] [ 0,  0,  0]  1 */
       11992, /* 57606 (1522) [ 0,  1,  0,  0,  0, -1, -1,  0,  0] [ 0,  0,  0]  1 */
        7672, /* 57607 (1522) [ 0, -1,  0,  0,  0,  1, -1,  0,  0] [ 0,  0,  0]  1 */
        7636, /* 57608 (1522) [ 0, -1,  0,  0,  0, -1,  1,  0,  0] [ 0,  0,  0]  1 */
    52561300, /* 57609 (1522) [ 0, -1,  0,  0,  0,  1,  1,  0,  0] [ 6,  6,  6] -1 */
    52565656, /* 57610 (1522) [ 0,  1,  0,  0,  0,  1, -1,  0,  0] [ 6,  6,  6] -1 */
       16320, /* 57611 (1522) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
        8872, /* 57612 (1522) [ 0,  0, -1, -1,  0,  0,  0,  1,  0] [ 0,  0,  0]  1 */
    52570092, /* 57613 (1522) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    52561228, /* 57614 (1522) [ 0, -1,  0,  0,  0, -1, -1,  0,  0] [ 6,  6,  6] -1 */
    52562968, /* 57615 (1522) [ 0,  0, -1,  1,  0,  0,  0,  1,  0] [ 6,  6,  6] -1 */
    52563940, /* 57616 (1522) [ 0,  0,  1, -1,  0,  0,  0,  1,  0] [ 6,  6,  6] -1 */
        3200, /* 57617 (1522) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    52556808, /* 57618 (1522) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
       10816, /* 57619 (1522) [ 0,  0,  1,  1,  0,  0,  0,  1,  0] [ 0,  0,  0]  1 */
    52565620, /* 57620 (1522) [ 0,  1,  0,  0,  0, -1,  1,  0,  0] [ 6,  6,  6] -1 */
    52569932, /* 57621 (1522) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    52556972, /* 57622 (1522) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
        9352, /* 57623 (1522) [ 0,  0, -1,  1,  0,  0,  0, -1,  0] [ 0,  0,  0]  1 */
       12064, /* 57624 (1522) [ 0,  1,  0,  0,  0,  1,  1,  0,  0] [ 0,  0,  0]  1 */
    52564420, /* 57625 (1522) [ 0,  0,  1,  1,  0,  0,  0, -1,  0] [ 6,  6,  6] -1 */
    52562476, /* 57626 (1522) [ 0,  0, -1, -1,  0,  0,  0, -1,  0] [ 6,  6,  6] -1 */
       16484, /* 57627 (1523) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
        3360, /* 57628 (1523) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    34019914, /* 57629 (1523) [ 0, -1,  0,  0,  0,  1,  1,  0,  0] [ 0,  0,  0] -1 */
    18551716, /* 57630 (1523) [ 0,  0,  1, -1,  0,  0,  0,  1,  0] [ 6,  6,  6]  1 */
    18553396, /* 57631 (1523) [ 0,  1,  0,  0,  0, -1,  1,  0,  0] [ 6,  6,  6]  1 */
    18544748, /* 57632 (1523) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    18544584, /* 57633 (1523) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
       10324, /* 57634 (1523) [ 0,  0,  1, -1,  0,  0,  0, -1,  0] [ 0,  0,  0]  1 */
    52561246, /* 57635 (1523) [ 0, -1,  0,  0,  0, -1,  1,  0,  0] [ 6,  6,  6] -1 */
    18557708, /* 57636 (1523) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
       11992, /* 57637 (1523) [ 0,  1,  0,  0,  0, -1, -1,  0,  0] [ 0,  0,  0]  1 */
        7672, /* 57638 (1523) [ 0, -1,  0,  0,  0,  1, -1,  0,  0] [ 0,  0,  0]  1 */
    18552196, /* 57639 (1523) [ 0,  0,  1,  1,  0,  0,  0, -1,  0] [ 6,  6,  6]  1 */
    52570094, /* 57640 (1523) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    18550252, /* 57641 (1523) [ 0,  0, -1, -1,  0,  0,  0, -1,  0] [ 6,  6,  6]  1 */
    34015586, /* 57642 (1523) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    52562482, /* 57643 (1523) [ 0,  0, -1, -1,  0,  0,  0,  1,  0] [ 6,  6,  6] -1 */
    52562962, /* 57644 (1523) [ 0,  0, -1,  1,  0,  0,  0, -1,  0] [ 6,  6,  6] -1 */
    34021582, /* 57645 (1523) [ 0,  0, -1,  1,  0,  0,  0,  1,  0] [ 0,  0,  0] -1 */
    52565602, /* 57646 (1523) [ 0,  1,  0,  0,  0, -1, -1,  0,  0] [ 6,  6,  6] -1 */
        7636, /* 57647 (1523) [ 0, -1,  0,  0,  0, -1,  1,  0,  0] [ 0,  0,  0]  1 */
    52563934, /* 57648 (1523) [ 0,  0,  1, -1,  0,  0,  0, -1,  0] [ 6,  6,  6] -1 */
    52565674, /* 57649 (1523) [ 0,  1,  0,  0,  0,  1,  1,  0,  0] [ 6,  6,  6] -1 */
    34024270, /* 57650 (1523) [ 0,  1,  0,  0,  0,  1, -1,  0,  0] [ 0,  0,  0] -1 */
       16320, /* 57651 (1523) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    52556810, /* 57652 (1523) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
        8872, /* 57653 (1523) [ 0,  0, -1, -1,  0,  0,  0,  1,  0] [ 0,  0,  0]  1 */
    34019842, /* 57654 (1523) [ 0, -1,  0,  0,  0, -1, -1,  0,  0] [ 0,  0,  0] -1 */
    52564426, /* 57655 (1523) [ 0,  0,  1,  1,  0,  0,  0,  1,  0] [ 6,  6,  6] -1 */
    34022554, /* 57656 (1523) [ 0,  0,  1, -1,  0,  0,  0,  1,  0] [ 0,  0,  0] -1 */
    52569930, /* 57657 (1523) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    52556970, /* 57658 (1523) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    34028546, /* 57659 (1523) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    34028706, /* 57660 (1523) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    52561282, /* 57661 (1523) [ 0, -1,  0,  0,  0,  1, -1,  0,  0] [ 6,  6,  6] -1 */
    18553432, /* 57662 (1523) [ 0,  1,  0,  0,  0,  1, -1,  0,  0] [ 6,  6,  6]  1 */
    18549076, /* 57663 (1523) [ 0, -1,  0,  0,  0,  1,  1,  0,  0] [ 6,  6,  6]  1 */
    34015422, /* 57664 (1523) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
        3200, /* 57665 (1523) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34024234, /* 57666 (1523) [ 0,  1,  0,  0,  0, -1,  1,  0,  0] [ 0,  0,  0] -1 */
       10816, /* 57667 (1523) [ 0,  0,  1,  1,  0,  0,  0,  1,  0] [ 0,  0,  0]  1 */
        9352, /* 57668 (1523) [ 0,  0, -1,  1,  0,  0,  0, -1,  0] [ 0,  0,  0]  1 */
    34021090, /* 57669 (1523) [ 0,  0, -1, -1,  0,  0,  0, -1,  0] [ 0,  0,  0] -1 */
    34023034, /* 57670 (1523) [ 0,  0,  1,  1,  0,  0,  0, -1,  0] [ 0,  0,  0] -1 */
       12064, /* 57671 (1523) [ 0,  1,  0,  0,  0,  1,  1,  0,  0] [ 0,  0,  0]  1 */
    18557868, /* 57672 (1523) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
    18549004, /* 57673 (1523) [ 0, -1,  0,  0,  0, -1, -1,  0,  0] [ 6,  6,  6]  1 */
    18550744, /* 57674 (1523) [ 0,  0, -1,  1,  0,  0,  0,  1,  0] [ 6,  6,  6]  1 */
       16484, /* 57675 (1520) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    17127570, /* 57676 (1520) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6]  1 */
    17134540, /* 57677 (1520) [ 0,  0,  1, -1,  0,  0,  0,  1,  0] [ 6,  0,  6]  1 */
    17136220, /* 57678 (1520) [ 0,  1,  0,  0,  0, -1,  1,  0,  0] [ 6,  0,  6]  1 */
     1538636, /* 57679 (1520) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
        3198, /* 57680 (1520) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
     1545598, /* 57681 (1520) [ 0,  0,  1, -1,  0,  0,  0, -1,  0] [ 0,  6,  6]  1 */
    17140532, /* 57682 (1520) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
     1547266, /* 57683 (1520) [ 0,  1,  0,  0,  0, -1, -1,  0,  0] [ 0,  6,  6]  1 */
    17131882, /* 57684 (1520) [ 0, -1,  0,  0,  0,  1, -1,  0,  0] [ 6,  0,  6]  1 */
    18434098, /* 57685 (1520) [ 0,  0,  1,  1,  0,  0,  0, -1,  0] [ 6,  6,  0]  1 */
        8866, /* 57686 (1520) [ 0,  0, -1, -1,  0,  0,  0, -1,  0] [ 0,  0,  0]  1 */
    18430924, /* 57687 (1520) [ 0, -1,  0,  0,  0, -1,  1,  0,  0] [ 6,  6,  0]  1 */
     1551594, /* 57688 (1520) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
    18432160, /* 57689 (1520) [ 0,  0, -1, -1,  0,  0,  0,  1,  0] [ 6,  6,  0]  1 */
    18435334, /* 57690 (1520) [ 0,  1,  0,  0,  0,  1, -1,  0,  0] [ 6,  6,  0]  1 */
     1542964, /* 57691 (1520) [ 0, -1,  0,  0,  0,  1,  1,  0,  0] [ 0,  6,  6]  1 */
    18426488, /* 57692 (1520) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
       10816, /* 57693 (1520) [ 0,  0,  1,  1,  0,  0,  0,  1,  0] [ 0,  0,  0]  1 */
    17133562, /* 57694 (1520) [ 0,  0, -1,  1,  0,  0,  0, -1,  0] [ 6,  0,  6]  1 */
       12064, /* 57695 (1520) [ 0,  1,  0,  0,  0,  1,  1,  0,  0] [ 0,  0,  0]  1 */
    18439770, /* 57696 (1520) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
        7618, /* 57697 (1520) [ 0, -1,  0,  0,  0, -1, -1,  0,  0] [ 0,  0,  0]  1 */
     1544632, /* 57698 (1520) [ 0,  0, -1,  1,  0,  0,  0,  1,  0] [ 0,  6,  6]  1 */
       16484, /* 57699 (1521) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    52443148, /* 57700 (1521) [ 0, -1,  0,  0,  0, -1,  1,  0,  0] [ 6,  6,  0] -1 */
    17127570, /* 57701 (1521) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6]  1 */
    17134540, /* 57702 (1521) [ 0,  0,  1, -1,  0,  0,  0,  1,  0] [ 6,  0,  6]  1 */
    17136220, /* 57703 (1521) [ 0,  1,  0,  0,  0, -1,  1,  0,  0] [ 6,  0,  6]  1 */
     1538636, /* 57704 (1521) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
        3198, /* 57705 (1521) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
     1545598, /* 57706 (1521) [ 0,  0,  1, -1,  0,  0,  0, -1,  0] [ 0,  6,  6]  1 */
    17140532, /* 57707 (1521) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
     1547266, /* 57708 (1521) [ 0,  1,  0,  0,  0, -1, -1,  0,  0] [ 0,  6,  6]  1 */
    17131882, /* 57709 (1521) [ 0, -1,  0,  0,  0,  1, -1,  0,  0] [ 6,  0,  6]  1 */
    52444384, /* 57710 (1521) [ 0,  0, -1, -1,  0,  0,  0,  1,  0] [ 6,  6,  0] -1 */
    18434098, /* 57711 (1521) [ 0,  0,  1,  1,  0,  0,  0, -1,  0] [ 6,  6,  0]  1 */
    35563818, /* 57712 (1521) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  6] -1 */
        8866, /* 57713 (1521) [ 0,  0, -1, -1,  0,  0,  0, -1,  0] [ 0,  0,  0]  1 */
    18430924, /* 57714 (1521) [ 0, -1,  0,  0,  0, -1,  1,  0,  0] [ 6,  6,  0]  1 */
    35555188, /* 57715 (1521) [ 0, -1,  0,  0,  0,  1,  1,  0,  0] [ 0,  6,  6] -1 */
    52447558, /* 57716 (1521) [ 0,  1,  0,  0,  0,  1, -1,  0,  0] [ 6,  6,  0] -1 */
    52438712, /* 57717 (1521) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
    34028708, /* 57718 (1521) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    34023040, /* 57719 (1521) [ 0,  0,  1,  1,  0,  0,  0,  1,  0] [ 0,  0,  0] -1 */
     1551594, /* 57720 (1521) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
    51145786, /* 57721 (1521) [ 0,  0, -1,  1,  0,  0,  0, -1,  0] [ 6,  0,  6] -1 */
    18432160, /* 57722 (1521) [ 0,  0, -1, -1,  0,  0,  0,  1,  0] [ 6,  6,  0]  1 */
    34024288, /* 57723 (1521) [ 0,  1,  0,  0,  0,  1,  1,  0,  0] [ 0,  0,  0] -1 */
    52451994, /* 57724 (1521) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
    34019842, /* 57725 (1521) [ 0, -1,  0,  0,  0, -1, -1,  0,  0] [ 0,  0,  0] -1 */
    35556856, /* 57726 (1521) [ 0,  0, -1,  1,  0,  0,  0,  1,  0] [ 0,  6,  6] -1 */
    18435334, /* 57727 (1521) [ 0,  1,  0,  0,  0,  1, -1,  0,  0] [ 6,  6,  0]  1 */
     1542964, /* 57728 (1521) [ 0, -1,  0,  0,  0,  1,  1,  0,  0] [ 0,  6,  6]  1 */
    51146764, /* 57729 (1521) [ 0,  0,  1, -1,  0,  0,  0,  1,  0] [ 6,  0,  6] -1 */
    18426488, /* 57730 (1521) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    51139794, /* 57731 (1521) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6] -1 */
       10816, /* 57732 (1521) [ 0,  0,  1,  1,  0,  0,  0,  1,  0] [ 0,  0,  0]  1 */
    34015422, /* 57733 (1521) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    51148444, /* 57734 (1521) [ 0,  1,  0,  0,  0, -1,  1,  0,  0] [ 6,  0,  6] -1 */
    51152756, /* 57735 (1521) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
    35550860, /* 57736 (1521) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
    17133562, /* 57737 (1521) [ 0,  0, -1,  1,  0,  0,  0, -1,  0] [ 6,  0,  6]  1 */
    35557822, /* 57738 (1521) [ 0,  0,  1, -1,  0,  0,  0, -1,  0] [ 0,  6,  6] -1 */
    35559490, /* 57739 (1521) [ 0,  1,  0,  0,  0, -1, -1,  0,  0] [ 0,  6,  6] -1 */
    51144106, /* 57740 (1521) [ 0, -1,  0,  0,  0,  1, -1,  0,  0] [ 6,  0,  6] -1 */
       12064, /* 57741 (1521) [ 0,  1,  0,  0,  0,  1,  1,  0,  0] [ 0,  0,  0]  1 */
    52446322, /* 57742 (1521) [ 0,  0,  1,  1,  0,  0,  0, -1,  0] [ 6,  6,  0] -1 */
    18439770, /* 57743 (1521) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
    34021090, /* 57744 (1521) [ 0,  0, -1, -1,  0,  0,  0, -1,  0] [ 0,  0,  0] -1 */
        7618, /* 57745 (1521) [ 0, -1,  0,  0,  0, -1, -1,  0,  0] [ 0,  0,  0]  1 */
     1544632, /* 57746 (1521) [ 0,  0, -1,  1,  0,  0,  0,  1,  0] [ 0,  6,  6]  1 */
       16484, /* 57747 (1522) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    17127570, /* 57748 (1522) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6]  1 */
     1545598, /* 57749 (1522) [ 0,  0,  1, -1,  0,  0,  0, -1,  0] [ 0,  6,  6]  1 */
     1547266, /* 57750 (1522) [ 0,  1,  0,  0,  0, -1, -1,  0,  0] [ 0,  6,  6]  1 */
    17131882, /* 57751 (1522) [ 0, -1,  0,  0,  0,  1, -1,  0,  0] [ 6,  0,  6]  1 */
    18430924, /* 57752 (1522) [ 0, -1,  0,  0,  0, -1,  1,  0,  0] [ 6,  6,  0]  1 */
    35555188, /* 57753 (1522) [ 0, -1,  0,  0,  0,  1,  1,  0,  0] [ 0,  6,  6] -1 */
    52447558, /* 57754 (1522) [ 0,  1,  0,  0,  0,  1, -1,  0,  0] [ 6,  6,  0] -1 */
     1551594, /* 57755 (1522) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
    18432160, /* 57756 (1522) [ 0,  0, -1, -1,  0,  0,  0,  1,  0] [ 6,  6,  0]  1 */
    52451994, /* 57757 (1522) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
    34019842, /* 57758 (1522) [ 0, -1,  0,  0,  0, -1, -1,  0,  0] [ 0,  0,  0] -1 */
    35556856, /* 57759 (1522) [ 0,  0, -1,  1,  0,  0,  0,  1,  0] [ 0,  6,  6] -1 */
    51146764, /* 57760 (1522) [ 0,  0,  1, -1,  0,  0,  0,  1,  0] [ 6,  0,  6] -1 */
    18426488, /* 57761 (1522) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    34015422, /* 57762 (1522) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
       10816, /* 57763 (1522) [ 0,  0,  1,  1,  0,  0,  0,  1,  0] [ 0,  0,  0]  1 */
    51148444, /* 57764 (1522) [ 0,  1,  0,  0,  0, -1,  1,  0,  0] [ 6,  0,  6] -1 */
    51152756, /* 57765 (1522) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
    35550860, /* 57766 (1522) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
    17133562, /* 57767 (1522) [ 0,  0, -1,  1,  0,  0,  0, -1,  0] [ 6,  0,  6]  1 */
       12064, /* 57768 (1522) [ 0,  1,  0,  0,  0,  1,  1,  0,  0] [ 0,  0,  0]  1 */
    52446322, /* 57769 (1522) [ 0,  0,  1,  1,  0,  0,  0, -1,  0] [ 6,  6,  0] -1 */
    34021090, /* 57770 (1522) [ 0,  0, -1, -1,  0,  0,  0, -1,  0] [ 0,  0,  0] -1 */
       16484, /* 57771 (1523) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    17127570, /* 57772 (1523) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6]  1 */
    51026026, /* 57773 (1523) [ 0, -1,  0,  0,  0,  1,  1,  0,  0] [ 6,  0,  0] -1 */
    17134540, /* 57774 (1523) [ 0,  0,  1, -1,  0,  0,  0,  1,  0] [ 6,  0,  6]  1 */
    17136220, /* 57775 (1523) [ 0,  1,  0,  0,  0, -1,  1,  0,  0] [ 6,  0,  6]  1 */
     1538636, /* 57776 (1523) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
        3198, /* 57777 (1523) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
     1545598, /* 57778 (1523) [ 0,  0,  1, -1,  0,  0,  0, -1,  0] [ 0,  6,  6]  1 */
    34137958, /* 57779 (1523) [ 0, -1,  0,  0,  0, -1,  1,  0,  0] [ 0,  0,  6] -1 */
    17140532, /* 57780 (1523) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
     1547266, /* 57781 (1523) [ 0,  1,  0,  0,  0, -1, -1,  0,  0] [ 0,  6,  6]  1 */
    17131882, /* 57782 (1523) [ 0, -1,  0,  0,  0,  1, -1,  0,  0] [ 6,  0,  6]  1 */
    18434098, /* 57783 (1523) [ 0,  0,  1,  1,  0,  0,  0, -1,  0] [ 6,  6,  0]  1 */
    52570094, /* 57784 (1523) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
        8866, /* 57785 (1523) [ 0,  0, -1, -1,  0,  0,  0, -1,  0] [ 0,  0,  0]  1 */
    51021698, /* 57786 (1523) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  0] -1 */
    34139194, /* 57787 (1523) [ 0,  0, -1, -1,  0,  0,  0,  1,  0] [ 0,  0,  6] -1 */
    35438752, /* 57788 (1523) [ 0,  0, -1,  1,  0,  0,  0, -1,  0] [ 0,  6,  0] -1 */
    51027694, /* 57789 (1523) [ 0,  0, -1,  1,  0,  0,  0,  1,  0] [ 6,  0,  0] -1 */
    51030328, /* 57790 (1523) [ 0,  1,  0,  0,  0, -1, -1,  0,  0] [ 6,  0,  0] -1 */
    18430924, /* 57791 (1523) [ 0, -1,  0,  0,  0, -1,  1,  0,  0] [ 6,  6,  0]  1 */
    51028660, /* 57792 (1523) [ 0,  0,  1, -1,  0,  0,  0, -1,  0] [ 6,  0,  0] -1 */
    52565674, /* 57793 (1523) [ 0,  1,  0,  0,  0,  1,  1,  0,  0] [ 6,  6,  6] -1 */
    34142368, /* 57794 (1523) [ 0,  1,  0,  0,  0,  1, -1,  0,  0] [ 0,  0,  6] -1 */
     1551594, /* 57795 (1523) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
    34133522, /* 57796 (1523) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    18432160, /* 57797 (1523) [ 0,  0, -1, -1,  0,  0,  0,  1,  0] [ 6,  6,  0]  1 */
    52561228, /* 57798 (1523) [ 0, -1,  0,  0,  0, -1, -1,  0,  0] [ 6,  6,  6] -1 */
    52564426, /* 57799 (1523) [ 0,  0,  1,  1,  0,  0,  0,  1,  0] [ 6,  6,  6] -1 */
    35439730, /* 57800 (1523) [ 0,  0,  1, -1,  0,  0,  0,  1,  0] [ 0,  6,  0] -1 */
    51034656, /* 57801 (1523) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  0] -1 */
    35432760, /* 57802 (1523) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  0] -1 */
    35445722, /* 57803 (1523) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  0] -1 */
    34146804, /* 57804 (1523) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
    35437072, /* 57805 (1523) [ 0, -1,  0,  0,  0,  1, -1,  0,  0] [ 0,  6,  0] -1 */
    18435334, /* 57806 (1523) [ 0,  1,  0,  0,  0,  1, -1,  0,  0] [ 6,  6,  0]  1 */
     1542964, /* 57807 (1523) [ 0, -1,  0,  0,  0,  1,  1,  0,  0] [ 0,  6,  6]  1 */
    52556808, /* 57808 (1523) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    18426488, /* 57809 (1523) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    35441410, /* 57810 (1523) [ 0,  1,  0,  0,  0, -1,  1,  0,  0] [ 0,  6,  0] -1 */
       10816, /* 57811 (1523) [ 0,  0,  1,  1,  0,  0,  0,  1,  0] [ 0,  0,  0]  1 */
    17133562, /* 57812 (1523) [ 0,  0, -1,  1,  0,  0,  0, -1,  0] [ 6,  0,  6]  1 */
    52562476, /* 57813 (1523) [ 0,  0, -1, -1,  0,  0,  0, -1,  0] [ 6,  6,  6] -1 */
    34141132, /* 57814 (1523) [ 0,  0,  1,  1,  0,  0,  0, -1,  0] [ 0,  0,  6] -1 */
       12064, /* 57815 (1523) [ 0,  1,  0,  0,  0,  1,  1,  0,  0] [ 0,  0,  0]  1 */
    18439770, /* 57816 (1523) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
        7618, /* 57817 (1523) [ 0, -1,  0,  0,  0, -1, -1,  0,  0] [ 0,  0,  0]  1 */
     1544632, /* 57818 (1523) [ 0,  0, -1,  1,  0,  0,  0,  1,  0] [ 0,  6,  6]  1 */
       16484, /* 57819 (1524) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    17140694, /* 57820 (1524) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
    17133568, /* 57821 (1524) [ 0,  0, -1,  1,  0,  0,  0,  1,  0] [ 6,  0,  6]  1 */
       16320, /* 57822 (1524) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    17136220, /* 57823 (1524) [ 0,  1,  0,  0,  0, -1,  1,  0,  0] [ 6,  0,  6]  1 */
        3198, /* 57824 (1524) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
     1545598, /* 57825 (1524) [ 0,  0,  1, -1,  0,  0,  0, -1,  0] [ 0,  6,  6]  1 */
    17140532, /* 57826 (1524) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
     1538474, /* 57827 (1524) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
    17136274, /* 57828 (1524) [ 0,  1,  0,  0,  0,  1,  1,  0,  0] [ 6,  0,  6]  1 */
        9352, /* 57829 (1524) [ 0,  0, -1,  1,  0,  0,  0, -1,  0] [ 0,  0,  0]  1 */
    18426648, /* 57830 (1524) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
    17131828, /* 57831 (1524) [ 0, -1,  0,  0,  0, -1, -1,  0,  0] [ 6,  0,  6]  1 */
        8872, /* 57832 (1524) [ 0,  0, -1, -1,  0,  0,  0,  1,  0] [ 0,  0,  0]  1 */
    18432160, /* 57833 (1524) [ 0,  0, -1, -1,  0,  0,  0,  1,  0] [ 6,  6,  0]  1 */
    17135020, /* 57834 (1524) [ 0,  0,  1,  1,  0,  0,  0, -1,  0] [ 6,  0,  6]  1 */
    17131900, /* 57835 (1524) [ 0, -1,  0,  0,  0,  1,  1,  0,  0] [ 6,  0,  6]  1 */
    18433612, /* 57836 (1524) [ 0,  0,  1, -1,  0,  0,  0, -1,  0] [ 6,  6,  0]  1 */
    17133562, /* 57837 (1524) [ 0,  0, -1,  1,  0,  0,  0, -1,  0] [ 6,  0,  6]  1 */
    17131846, /* 57838 (1524) [ 0, -1,  0,  0,  0, -1,  1,  0,  0] [ 6,  0,  6]  1 */
       10324, /* 57839 (1524) [ 0,  0,  1, -1,  0,  0,  0, -1,  0] [ 0,  0,  0]  1 */
     1538634, /* 57840 (1524) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
     1544146, /* 57841 (1524) [ 0,  0, -1, -1,  0,  0,  0,  1,  0] [ 0,  6,  6]  1 */
    17134534, /* 57842 (1524) [ 0,  0,  1, -1,  0,  0,  0, -1,  0] [ 6,  0,  6]  1 */
        8866, /* 57843 (1524) [ 0,  0, -1, -1,  0,  0,  0, -1,  0] [ 0,  0,  0]  1 */
    17127572, /* 57844 (1524) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
    18432154, /* 57845 (1524) [ 0,  0, -1, -1,  0,  0,  0, -1,  0] [ 6,  6,  0]  1 */
    18439772, /* 57846 (1524) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    17140530, /* 57847 (1524) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  6]  1 */
    17127408, /* 57848 (1524) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  6]  1 */
    17140692, /* 57849 (1524) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6]  1 */
    18439610, /* 57850 (1524) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    18430960, /* 57851 (1524) [ 0, -1,  0,  0,  0,  1, -1,  0,  0] [ 6,  6,  0]  1 */
    18435280, /* 57852 (1524) [ 0,  1,  0,  0,  0, -1, -1,  0,  0] [ 6,  6,  0]  1 */
    18435352, /* 57853 (1524) [ 0,  1,  0,  0,  0,  1,  1,  0,  0] [ 6,  6,  0]  1 */
     1544140, /* 57854 (1524) [ 0,  0, -1, -1,  0,  0,  0, -1,  0] [ 0,  6,  6]  1 */
       10816, /* 57855 (1524) [ 0,  0,  1,  1,  0,  0,  0,  1,  0] [ 0,  0,  0]  1 */
    18434104, /* 57856 (1524) [ 0,  0,  1,  1,  0,  0,  0,  1,  0] [ 6,  6,  0]  1 */
       11992, /* 57857 (1524) [ 0,  1,  0,  0,  0, -1, -1,  0,  0] [ 0,  0,  0]  1 */
       12064, /* 57858 (1524) [ 0,  1,  0,  0,  0,  1,  1,  0,  0] [ 0,  0,  0]  1 */
     1551758, /* 57859 (1524) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
     1545604, /* 57860 (1524) [ 0,  0,  1, -1,  0,  0,  0,  1,  0] [ 0,  6,  6]  1 */
    17127570, /* 57861 (1524) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6]  1 */
     1547320, /* 57862 (1524) [ 0,  1,  0,  0,  0,  1, -1,  0,  0] [ 0,  6,  6]  1 */
     1542946, /* 57863 (1524) [ 0, -1,  0,  0,  0,  1, -1,  0,  0] [ 0,  6,  6]  1 */
    17133082, /* 57864 (1524) [ 0,  0, -1, -1,  0,  0,  0,  1,  0] [ 6,  0,  6]  1 */
     1547266, /* 57865 (1524) [ 0,  1,  0,  0,  0, -1, -1,  0,  0] [ 0,  6,  6]  1 */
    18434098, /* 57866 (1524) [ 0,  0,  1,  1,  0,  0,  0, -1,  0] [ 6,  6,  0]  1 */
     1546090, /* 57867 (1524) [ 0,  0,  1,  1,  0,  0,  0,  1,  0] [ 0,  6,  6]  1 */
    18435298, /* 57868 (1524) [ 0,  1,  0,  0,  0, -1,  1,  0,  0] [ 6,  6,  0]  1 */
    18426650, /* 57869 (1524) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
        7672, /* 57870 (1524) [ 0, -1,  0,  0,  0,  1, -1,  0,  0] [ 0,  0,  0]  1 */
       10330, /* 57871 (1524) [ 0,  0,  1, -1,  0,  0,  0,  1,  0] [ 0,  0,  0]  1 */
    18433618, /* 57872 (1524) [ 0,  0,  1, -1,  0,  0,  0,  1,  0] [ 6,  6,  0]  1 */
        3360, /* 57873 (1524) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
     1546084, /* 57874 (1524) [ 0,  0,  1,  1,  0,  0,  0, -1,  0] [ 0,  6,  6]  1 */
       12046, /* 57875 (1524) [ 0,  1,  0,  0,  0,  1, -1,  0,  0] [ 0,  0,  0]  1 */
       12010, /* 57876 (1524) [ 0,  1,  0,  0,  0, -1,  1,  0,  0] [ 0,  0,  0]  1 */
    18435334, /* 57877 (1524) [ 0,  1,  0,  0,  0,  1, -1,  0,  0] [ 6,  6,  0]  1 */
    18426488, /* 57878 (1524) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    17133076, /* 57879 (1524) [ 0,  0, -1, -1,  0,  0,  0, -1,  0] [ 6,  0,  6]  1 */
        3362, /* 57880 (1524) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    18439770, /* 57881 (1524) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
        7618, /* 57882 (1524) [ 0, -1,  0,  0,  0, -1, -1,  0,  0] [ 0,  0,  0]  1 */
    18430906, /* 57883 (1524) [ 0, -1,  0,  0,  0, -1, -1,  0,  0] [ 6,  6,  0]  1 */
     1544632, /* 57884 (1524) [ 0,  0, -1,  1,  0,  0,  0,  1,  0] [ 0,  6,  6]  1 */
     1547284, /* 57885 (1524) [ 0,  1,  0,  0,  0, -1,  1,  0,  0] [ 0,  6,  6]  1 */
    18439608, /* 57886 (1524) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
    18426486, /* 57887 (1524) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
     1551596, /* 57888 (1524) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
    17134540, /* 57889 (1524) [ 0,  0,  1, -1,  0,  0,  0,  1,  0] [ 6,  0,  6]  1 */
     1538636, /* 57890 (1524) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
    17136256, /* 57891 (1524) [ 0,  1,  0,  0,  0,  1, -1,  0,  0] [ 6,  0,  6]  1 */
    17127410, /* 57892 (1524) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
    17131882, /* 57893 (1524) [ 0, -1,  0,  0,  0,  1, -1,  0,  0] [ 6,  0,  6]  1 */
    17136202, /* 57894 (1524) [ 0,  1,  0,  0,  0, -1, -1,  0,  0] [ 6,  0,  6]  1 */
     1547338, /* 57895 (1524) [ 0,  1,  0,  0,  0,  1,  1,  0,  0] [ 0,  6,  6]  1 */
        7690, /* 57896 (1524) [ 0, -1,  0,  0,  0,  1,  1,  0,  0] [ 0,  0,  0]  1 */
       10810, /* 57897 (1524) [ 0,  0,  1,  1,  0,  0,  0, -1,  0] [ 0,  0,  0]  1 */
    18430978, /* 57898 (1524) [ 0, -1,  0,  0,  0,  1,  1,  0,  0] [ 6,  6,  0]  1 */
    18432640, /* 57899 (1524) [ 0,  0, -1,  1,  0,  0,  0, -1,  0] [ 6,  6,  0]  1 */
    17135026, /* 57900 (1524) [ 0,  0,  1,  1,  0,  0,  0,  1,  0] [ 6,  0,  6]  1 */
        7636, /* 57901 (1524) [ 0, -1,  0,  0,  0, -1,  1,  0,  0] [ 0,  0,  0]  1 */
    18430924, /* 57902 (1524) [ 0, -1,  0,  0,  0, -1,  1,  0,  0] [ 6,  6,  0]  1 */
     1551756, /* 57903 (1524) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
     1542892, /* 57904 (1524) [ 0, -1,  0,  0,  0, -1, -1,  0,  0] [ 0,  6,  6]  1 */
     1551594, /* 57905 (1524) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
     1538472, /* 57906 (1524) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
    18432646, /* 57907 (1524) [ 0,  0, -1,  1,  0,  0,  0,  1,  0] [ 6,  6,  0]  1 */
     1542964, /* 57908 (1524) [ 0, -1,  0,  0,  0,  1,  1,  0,  0] [ 0,  6,  6]  1 */
       16322, /* 57909 (1524) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
     1544626, /* 57910 (1524) [ 0,  0, -1,  1,  0,  0,  0, -1,  0] [ 0,  6,  6]  1 */
        3200, /* 57911 (1524) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
        9358, /* 57912 (1524) [ 0,  0, -1,  1,  0,  0,  0,  1,  0] [ 0,  0,  0]  1 */
     1542910, /* 57913 (1524) [ 0, -1,  0,  0,  0, -1,  1,  0,  0] [ 0,  6,  6]  1 */
       16482, /* 57914 (1524) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
       16484, /* 57915 (1525) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    17140694, /* 57916 (1525) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
    17133568, /* 57917 (1525) [ 0,  0, -1,  1,  0,  0,  0,  1,  0] [ 6,  0,  6]  1 */
       16320, /* 57918 (1525) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    17136220, /* 57919 (1525) [ 0,  1,  0,  0,  0, -1,  1,  0,  0] [ 6,  0,  6]  1 */
    52451996, /* 57920 (1525) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
        3198, /* 57921 (1525) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
     1545598, /* 57922 (1525) [ 0,  0,  1, -1,  0,  0,  0, -1,  0] [ 0,  6,  6]  1 */
    51152754, /* 57923 (1525) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  6] -1 */
    17140532, /* 57924 (1525) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
    51139632, /* 57925 (1525) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  6] -1 */
    52451834, /* 57926 (1525) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
     1538474, /* 57927 (1525) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
    34019896, /* 57928 (1525) [ 0, -1,  0,  0,  0,  1, -1,  0,  0] [ 0,  0,  0] -1 */
    52443184, /* 57929 (1525) [ 0, -1,  0,  0,  0,  1, -1,  0,  0] [ 6,  6,  0] -1 */
    17136274, /* 57930 (1525) [ 0,  1,  0,  0,  0,  1,  1,  0,  0] [ 6,  0,  6]  1 */
    52445842, /* 57931 (1525) [ 0,  0,  1, -1,  0,  0,  0,  1,  0] [ 6,  6,  0] -1 */
    34015584, /* 57932 (1525) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    34024234, /* 57933 (1525) [ 0,  1,  0,  0,  0, -1,  1,  0,  0] [ 0,  0,  0] -1 */
    52447576, /* 57934 (1525) [ 0,  1,  0,  0,  0,  1,  1,  0,  0] [ 6,  6,  0] -1 */
        9352, /* 57935 (1525) [ 0,  0, -1,  1,  0,  0,  0, -1,  0] [ 0,  0,  0]  1 */
    34023040, /* 57936 (1525) [ 0,  0,  1,  1,  0,  0,  0,  1,  0] [ 0,  0,  0] -1 */
    52446328, /* 57937 (1525) [ 0,  0,  1,  1,  0,  0,  0,  1,  0] [ 6,  6,  0] -1 */
    18426648, /* 57938 (1525) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
    17131828, /* 57939 (1525) [ 0, -1,  0,  0,  0, -1, -1,  0,  0] [ 6,  0,  6]  1 */
        8872, /* 57940 (1525) [ 0,  0, -1, -1,  0,  0,  0,  1,  0] [ 0,  0,  0]  1 */
    18432160, /* 57941 (1525) [ 0,  0, -1, -1,  0,  0,  0,  1,  0] [ 6,  6,  0]  1 */
    34024288, /* 57942 (1525) [ 0,  1,  0,  0,  0,  1,  1,  0,  0] [ 0,  0,  0] -1 */
    35563982, /* 57943 (1525) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
    17135020, /* 57944 (1525) [ 0,  0,  1,  1,  0,  0,  0, -1,  0] [ 6,  0,  6]  1 */
    35563820, /* 57945 (1525) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
    51146764, /* 57946 (1525) [ 0,  0,  1, -1,  0,  0,  0,  1,  0] [ 6,  0,  6] -1 */
    51139794, /* 57947 (1525) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6] -1 */
    35555170, /* 57948 (1525) [ 0, -1,  0,  0,  0,  1, -1,  0,  0] [ 0,  6,  6] -1 */
    17131900, /* 57949 (1525) [ 0, -1,  0,  0,  0,  1,  1,  0,  0] [ 6,  0,  6]  1 */
    18433612, /* 57950 (1525) [ 0,  0,  1, -1,  0,  0,  0, -1,  0] [ 6,  6,  0]  1 */
    17133562, /* 57951 (1525) [ 0,  0, -1,  1,  0,  0,  0, -1,  0] [ 6,  0,  6]  1 */
    35559490, /* 57952 (1525) [ 0,  1,  0,  0,  0, -1, -1,  0,  0] [ 0,  6,  6] -1 */
    35559562, /* 57953 (1525) [ 0,  1,  0,  0,  0,  1,  1,  0,  0] [ 0,  6,  6] -1 */
    52443202, /* 57954 (1525) [ 0, -1,  0,  0,  0,  1,  1,  0,  0] [ 6,  6,  0] -1 */
    34023034, /* 57955 (1525) [ 0,  0,  1,  1,  0,  0,  0, -1,  0] [ 0,  0,  0] -1 */
    52446322, /* 57956 (1525) [ 0,  0,  1,  1,  0,  0,  0, -1,  0] [ 6,  6,  0] -1 */
    52444864, /* 57957 (1525) [ 0,  0, -1,  1,  0,  0,  0, -1,  0] [ 6,  6,  0] -1 */
    17131846, /* 57958 (1525) [ 0, -1,  0,  0,  0, -1,  1,  0,  0] [ 6,  0,  6]  1 */
    35558314, /* 57959 (1525) [ 0,  0,  1,  1,  0,  0,  0,  1,  0] [ 0,  6,  6] -1 */
       10324, /* 57960 (1525) [ 0,  0,  1, -1,  0,  0,  0, -1,  0] [ 0,  0,  0]  1 */
     1538634, /* 57961 (1525) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
    52443148, /* 57962 (1525) [ 0, -1,  0,  0,  0, -1,  1,  0,  0] [ 6,  6,  0] -1 */
     1544146, /* 57963 (1525) [ 0,  0, -1, -1,  0,  0,  0,  1,  0] [ 0,  6,  6]  1 */
    17134534, /* 57964 (1525) [ 0,  0,  1, -1,  0,  0,  0, -1,  0] [ 6,  0,  6]  1 */
    52447522, /* 57965 (1525) [ 0,  1,  0,  0,  0, -1,  1,  0,  0] [ 6,  6,  0] -1 */
        8866, /* 57966 (1525) [ 0,  0, -1, -1,  0,  0,  0, -1,  0] [ 0,  0,  0]  1 */
    17127572, /* 57967 (1525) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
    18432154, /* 57968 (1525) [ 0,  0, -1, -1,  0,  0,  0, -1,  0] [ 6,  6,  0]  1 */
    52438874, /* 57969 (1525) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
    34022554, /* 57970 (1525) [ 0,  0,  1, -1,  0,  0,  0,  1,  0] [ 0,  0,  0] -1 */
    35555188, /* 57971 (1525) [ 0, -1,  0,  0,  0,  1,  1,  0,  0] [ 0,  6,  6] -1 */
    35558308, /* 57972 (1525) [ 0,  0,  1,  1,  0,  0,  0, -1,  0] [ 0,  6,  6] -1 */
    35556850, /* 57973 (1525) [ 0,  0, -1,  1,  0,  0,  0, -1,  0] [ 0,  6,  6] -1 */
    34024270, /* 57974 (1525) [ 0,  1,  0,  0,  0,  1, -1,  0,  0] [ 0,  0,  0] -1 */
    52447558, /* 57975 (1525) [ 0,  1,  0,  0,  0,  1, -1,  0,  0] [ 6,  6,  0] -1 */
    18439772, /* 57976 (1525) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    34015424, /* 57977 (1525) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    34028708, /* 57978 (1525) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    17140530, /* 57979 (1525) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  6]  1 */
    52438712, /* 57980 (1525) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
    34021582, /* 57981 (1525) [ 0,  0, -1,  1,  0,  0,  0,  1,  0] [ 0,  0,  0] -1 */
    51145300, /* 57982 (1525) [ 0,  0, -1, -1,  0,  0,  0, -1,  0] [ 6,  0,  6] -1 */
    34015586, /* 57983 (1525) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    17127408, /* 57984 (1525) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  6]  1 */
    17140692, /* 57985 (1525) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6]  1 */
    18439610, /* 57986 (1525) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    34028706, /* 57987 (1525) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    52451994, /* 57988 (1525) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
    18430960, /* 57989 (1525) [ 0, -1,  0,  0,  0,  1, -1,  0,  0] [ 6,  6,  0]  1 */
    34019842, /* 57990 (1525) [ 0, -1,  0,  0,  0, -1, -1,  0,  0] [ 0,  0,  0] -1 */
    52443130, /* 57991 (1525) [ 0, -1,  0,  0,  0, -1, -1,  0,  0] [ 6,  6,  0] -1 */
    35556856, /* 57992 (1525) [ 0,  0, -1,  1,  0,  0,  0,  1,  0] [ 0,  6,  6] -1 */
    18435280, /* 57993 (1525) [ 0,  1,  0,  0,  0, -1, -1,  0,  0] [ 6,  6,  0]  1 */
    51152918, /* 57994 (1525) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
    18435352, /* 57995 (1525) [ 0,  1,  0,  0,  0,  1,  1,  0,  0] [ 6,  6,  0]  1 */
    35559508, /* 57996 (1525) [ 0,  1,  0,  0,  0, -1,  1,  0,  0] [ 0,  6,  6] -1 */
    34028544, /* 57997 (1525) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
     1544140, /* 57998 (1525) [ 0,  0, -1, -1,  0,  0,  0, -1,  0] [ 0,  6,  6]  1 */
    52451832, /* 57999 (1525) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
       10816, /* 58000 (1525) [ 0,  0,  1,  1,  0,  0,  0,  1,  0] [ 0,  0,  0]  1 */
    18434104, /* 58001 (1525) [ 0,  0,  1,  1,  0,  0,  0,  1,  0] [ 6,  6,  0]  1 */
    34015422, /* 58002 (1525) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    52438710, /* 58003 (1525) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
    35550860, /* 58004 (1525) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
    51152756, /* 58005 (1525) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
    51148480, /* 58006 (1525) [ 0,  1,  0,  0,  0,  1, -1,  0,  0] [ 6,  0,  6] -1 */
    51139634, /* 58007 (1525) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
       11992, /* 58008 (1525) [ 0,  1,  0,  0,  0, -1, -1,  0,  0] [ 0,  0,  0]  1 */
    51144106, /* 58009 (1525) [ 0, -1,  0,  0,  0,  1, -1,  0,  0] [ 6,  0,  6] -1 */
       12064, /* 58010 (1525) [ 0,  1,  0,  0,  0,  1,  1,  0,  0] [ 0,  0,  0]  1 */
     1551758, /* 58011 (1525) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
    35550698, /* 58012 (1525) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
    51148426, /* 58013 (1525) [ 0,  1,  0,  0,  0, -1, -1,  0,  0] [ 6,  0,  6] -1 */
    34019914, /* 58014 (1525) [ 0, -1,  0,  0,  0,  1,  1,  0,  0] [ 0,  0,  0] -1 */
    51148498, /* 58015 (1525) [ 0,  1,  0,  0,  0,  1,  1,  0,  0] [ 6,  0,  6] -1 */
     1545604, /* 58016 (1525) [ 0,  0,  1, -1,  0,  0,  0,  1,  0] [ 0,  6,  6]  1 */
    51147250, /* 58017 (1525) [ 0,  0,  1,  1,  0,  0,  0,  1,  0] [ 6,  0,  6] -1 */
    34019860, /* 58018 (1525) [ 0, -1,  0,  0,  0, -1,  1,  0,  0] [ 0,  0,  0] -1 */
    17127570, /* 58019 (1525) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6]  1 */
     1547320, /* 58020 (1525) [ 0,  1,  0,  0,  0,  1, -1,  0,  0] [ 0,  6,  6]  1 */
     1542946, /* 58021 (1525) [ 0, -1,  0,  0,  0,  1, -1,  0,  0] [ 0,  6,  6]  1 */
    17133082, /* 58022 (1525) [ 0,  0, -1, -1,  0,  0,  0,  1,  0] [ 6,  0,  6]  1 */
    35563980, /* 58023 (1525) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6] -1 */
    35555116, /* 58024 (1525) [ 0, -1,  0,  0,  0, -1, -1,  0,  0] [ 0,  6,  6] -1 */
     1547266, /* 58025 (1525) [ 0,  1,  0,  0,  0, -1, -1,  0,  0] [ 0,  6,  6]  1 */
    52444384, /* 58026 (1525) [ 0,  0, -1, -1,  0,  0,  0,  1,  0] [ 6,  6,  0] -1 */
    18434098, /* 58027 (1525) [ 0,  0,  1,  1,  0,  0,  0, -1,  0] [ 6,  6,  0]  1 */
    35563818, /* 58028 (1525) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  6] -1 */
     1546090, /* 58029 (1525) [ 0,  0,  1,  1,  0,  0,  0,  1,  0] [ 0,  6,  6]  1 */
    35550696, /* 58030 (1525) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  6] -1 */
    52444870, /* 58031 (1525) [ 0,  0, -1,  1,  0,  0,  0,  1,  0] [ 6,  6,  0] -1 */
    34028546, /* 58032 (1525) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    18435298, /* 58033 (1525) [ 0,  1,  0,  0,  0, -1,  1,  0,  0] [ 6,  6,  0]  1 */
    35555134, /* 58034 (1525) [ 0, -1,  0,  0,  0, -1,  1,  0,  0] [ 0,  6,  6] -1 */
    34022548, /* 58035 (1525) [ 0,  0,  1, -1,  0,  0,  0, -1,  0] [ 0,  0,  0] -1 */
    18426650, /* 58036 (1525) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
        7672, /* 58037 (1525) [ 0, -1,  0,  0,  0,  1, -1,  0,  0] [ 0,  0,  0]  1 */
       10330, /* 58038 (1525) [ 0,  0,  1, -1,  0,  0,  0,  1,  0] [ 0,  0,  0]  1 */
    35556370, /* 58039 (1525) [ 0,  0, -1, -1,  0,  0,  0,  1,  0] [ 0,  6,  6] -1 */
    18433618, /* 58040 (1525) [ 0,  0,  1, -1,  0,  0,  0,  1,  0] [ 6,  6,  0]  1 */
        3360, /* 58041 (1525) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
     1546084, /* 58042 (1525) [ 0,  0,  1,  1,  0,  0,  0, -1,  0] [ 0,  6,  6]  1 */
       12046, /* 58043 (1525) [ 0,  1,  0,  0,  0,  1, -1,  0,  0] [ 0,  0,  0]  1 */
       12010, /* 58044 (1525) [ 0,  1,  0,  0,  0, -1,  1,  0,  0] [ 0,  0,  0]  1 */
    18435334, /* 58045 (1525) [ 0,  1,  0,  0,  0,  1, -1,  0,  0] [ 6,  6,  0]  1 */
    51145792, /* 58046 (1525) [ 0,  0, -1,  1,  0,  0,  0,  1,  0] [ 6,  0,  6] -1 */
    18426488, /* 58047 (1525) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    51148444, /* 58048 (1525) [ 0,  1,  0,  0,  0, -1,  1,  0,  0] [ 6,  0,  6] -1 */
    17133076, /* 58049 (1525) [ 0,  0, -1, -1,  0,  0,  0, -1,  0] [ 6,  0,  6]  1 */
        3362, /* 58050 (1525) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    35557822, /* 58051 (1525) [ 0,  0,  1, -1,  0,  0,  0, -1,  0] [ 0,  6,  6] -1 */
    51139796, /* 58052 (1525) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
    52444378, /* 58053 (1525) [ 0,  0, -1, -1,  0,  0,  0, -1,  0] [ 6,  6,  0] -1 */
    18439770, /* 58054 (1525) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
        7618, /* 58055 (1525) [ 0, -1,  0,  0,  0, -1, -1,  0,  0] [ 0,  0,  0]  1 */
    18430906, /* 58056 (1525) [ 0, -1,  0,  0,  0, -1, -1,  0,  0] [ 6,  6,  0]  1 */
     1544632, /* 58057 (1525) [ 0,  0, -1,  1,  0,  0,  0,  1,  0] [ 0,  6,  6]  1 */
     1547284, /* 58058 (1525) [ 0,  1,  0,  0,  0, -1,  1,  0,  0] [ 0,  6,  6]  1 */
    18439608, /* 58059 (1525) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
    18426486, /* 58060 (1525) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
    34021576, /* 58061 (1525) [ 0,  0, -1,  1,  0,  0,  0, -1,  0] [ 0,  0,  0] -1 */
     1551596, /* 58062 (1525) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
     1538636, /* 58063 (1525) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
    17134540, /* 58064 (1525) [ 0,  0,  1, -1,  0,  0,  0,  1,  0] [ 6,  0,  6]  1 */
    17136256, /* 58065 (1525) [ 0,  1,  0,  0,  0,  1, -1,  0,  0] [ 6,  0,  6]  1 */
    17127410, /* 58066 (1525) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
    51152916, /* 58067 (1525) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6] -1 */
    17131882, /* 58068 (1525) [ 0, -1,  0,  0,  0,  1, -1,  0,  0] [ 6,  0,  6]  1 */
    52438872, /* 58069 (1525) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
    51144052, /* 58070 (1525) [ 0, -1,  0,  0,  0, -1, -1,  0,  0] [ 6,  0,  6] -1 */
    34021096, /* 58071 (1525) [ 0,  0, -1, -1,  0,  0,  0,  1,  0] [ 0,  0,  0] -1 */
     1547338, /* 58072 (1525) [ 0,  1,  0,  0,  0,  1,  1,  0,  0] [ 0,  6,  6]  1 */
    17136202, /* 58073 (1525) [ 0,  1,  0,  0,  0, -1, -1,  0,  0] [ 6,  0,  6]  1 */
       10810, /* 58074 (1525) [ 0,  0,  1,  1,  0,  0,  0, -1,  0] [ 0,  0,  0]  1 */
        7690, /* 58075 (1525) [ 0, -1,  0,  0,  0,  1,  1,  0,  0] [ 0,  0,  0]  1 */
    18432640, /* 58076 (1525) [ 0,  0, -1,  1,  0,  0,  0, -1,  0] [ 6,  6,  0]  1 */
    18430978, /* 58077 (1525) [ 0, -1,  0,  0,  0,  1,  1,  0,  0] [ 6,  6,  0]  1 */
    52447504, /* 58078 (1525) [ 0,  1,  0,  0,  0, -1, -1,  0,  0] [ 6,  6,  0] -1 */
    51147244, /* 58079 (1525) [ 0,  0,  1,  1,  0,  0,  0, -1,  0] [ 6,  0,  6] -1 */
    17135026, /* 58080 (1525) [ 0,  0,  1,  1,  0,  0,  0,  1,  0] [ 6,  0,  6]  1 */
        7636, /* 58081 (1525) [ 0, -1,  0,  0,  0, -1,  1,  0,  0] [ 0,  0,  0]  1 */
    18430924, /* 58082 (1525) [ 0, -1,  0,  0,  0, -1,  1,  0,  0] [ 6,  6,  0]  1 */
    35556364, /* 58083 (1525) [ 0,  0, -1, -1,  0,  0,  0, -1,  0] [ 0,  6,  6] -1 */
     1551756, /* 58084 (1525) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
     1542892, /* 58085 (1525) [ 0, -1,  0,  0,  0, -1, -1,  0,  0] [ 0,  6,  6]  1 */
    51144124, /* 58086 (1525) [ 0, -1,  0,  0,  0,  1,  1,  0,  0] [ 6,  0,  6] -1 */
    52445836, /* 58087 (1525) [ 0,  0,  1, -1,  0,  0,  0, -1,  0] [ 6,  6,  0] -1 */
    34024216, /* 58088 (1525) [ 0,  1,  0,  0,  0, -1, -1,  0,  0] [ 0,  0,  0] -1 */
     1551594, /* 58089 (1525) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
    51145786, /* 58090 (1525) [ 0,  0, -1,  1,  0,  0,  0, -1,  0] [ 6,  0,  6] -1 */
     1538472, /* 58091 (1525) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
    51144070, /* 58092 (1525) [ 0, -1,  0,  0,  0, -1,  1,  0,  0] [ 6,  0,  6] -1 */
    18432646, /* 58093 (1525) [ 0,  0, -1,  1,  0,  0,  0,  1,  0] [ 6,  6,  0]  1 */
    35557828, /* 58094 (1525) [ 0,  0,  1, -1,  0,  0,  0,  1,  0] [ 0,  6,  6] -1 */
    35550858, /* 58095 (1525) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6] -1 */
    35559544, /* 58096 (1525) [ 0,  1,  0,  0,  0,  1, -1,  0,  0] [ 0,  6,  6] -1 */
     1542964, /* 58097 (1525) [ 0, -1,  0,  0,  0,  1,  1,  0,  0] [ 0,  6,  6]  1 */
       16322, /* 58098 (1525) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    51145306, /* 58099 (1525) [ 0,  0, -1, -1,  0,  0,  0,  1,  0] [ 6,  0,  6] -1 */
     1544626, /* 58100 (1525) [ 0,  0, -1,  1,  0,  0,  0, -1,  0] [ 0,  6,  6]  1 */
        3200, /* 58101 (1525) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
        9358, /* 58102 (1525) [ 0,  0, -1,  1,  0,  0,  0,  1,  0] [ 0,  0,  0]  1 */
     1542910, /* 58103 (1525) [ 0, -1,  0,  0,  0, -1,  1,  0,  0] [ 0,  6,  6]  1 */
    51146758, /* 58104 (1525) [ 0,  0,  1, -1,  0,  0,  0, -1,  0] [ 6,  0,  6] -1 */
    34021090, /* 58105 (1525) [ 0,  0, -1, -1,  0,  0,  0, -1,  0] [ 0,  0,  0] -1 */
       16482, /* 58106 (1525) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
       16484, /* 58107 (1526) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    17140694, /* 58108 (1526) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
       16320, /* 58109 (1526) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
     1545598, /* 58110 (1526) [ 0,  0,  1, -1,  0,  0,  0, -1,  0] [ 0,  6,  6]  1 */
    51139632, /* 58111 (1526) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  6] -1 */
    52451834, /* 58112 (1526) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
     1538474, /* 58113 (1526) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
    17136274, /* 58114 (1526) [ 0,  1,  0,  0,  0,  1,  1,  0,  0] [ 6,  0,  6]  1 */
    52445842, /* 58115 (1526) [ 0,  0,  1, -1,  0,  0,  0,  1,  0] [ 6,  6,  0] -1 */
    34024234, /* 58116 (1526) [ 0,  1,  0,  0,  0, -1,  1,  0,  0] [ 0,  0,  0] -1 */
        9352, /* 58117 (1526) [ 0,  0, -1,  1,  0,  0,  0, -1,  0] [ 0,  0,  0]  1 */
    18426648, /* 58118 (1526) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
        8872, /* 58119 (1526) [ 0,  0, -1, -1,  0,  0,  0,  1,  0] [ 0,  0,  0]  1 */
    18432160, /* 58120 (1526) [ 0,  0, -1, -1,  0,  0,  0,  1,  0] [ 6,  6,  0]  1 */
    35563820, /* 58121 (1526) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
    51146764, /* 58122 (1526) [ 0,  0,  1, -1,  0,  0,  0,  1,  0] [ 6,  0,  6] -1 */
    18433612, /* 58123 (1526) [ 0,  0,  1, -1,  0,  0,  0, -1,  0] [ 6,  6,  0]  1 */
    17133562, /* 58124 (1526) [ 0,  0, -1,  1,  0,  0,  0, -1,  0] [ 6,  0,  6]  1 */
    52443202, /* 58125 (1526) [ 0, -1,  0,  0,  0,  1,  1,  0,  0] [ 6,  6,  0] -1 */
    34023034, /* 58126 (1526) [ 0,  0,  1,  1,  0,  0,  0, -1,  0] [ 0,  0,  0] -1 */
    52446322, /* 58127 (1526) [ 0,  0,  1,  1,  0,  0,  0, -1,  0] [ 6,  6,  0] -1 */
    17131846, /* 58128 (1526) [ 0, -1,  0,  0,  0, -1,  1,  0,  0] [ 6,  0,  6]  1 */
       10324, /* 58129 (1526) [ 0,  0,  1, -1,  0,  0,  0, -1,  0] [ 0,  0,  0]  1 */
     1538634, /* 58130 (1526) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
     1544146, /* 58131 (1526) [ 0,  0, -1, -1,  0,  0,  0,  1,  0] [ 0,  6,  6]  1 */
    17134534, /* 58132 (1526) [ 0,  0,  1, -1,  0,  0,  0, -1,  0] [ 6,  0,  6]  1 */
    52447522, /* 58133 (1526) [ 0,  1,  0,  0,  0, -1,  1,  0,  0] [ 6,  6,  0] -1 */
    52438874, /* 58134 (1526) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
    34022554, /* 58135 (1526) [ 0,  0,  1, -1,  0,  0,  0,  1,  0] [ 0,  0,  0] -1 */
    35555188, /* 58136 (1526) [ 0, -1,  0,  0,  0,  1,  1,  0,  0] [ 0,  6,  6] -1 */
    35558308, /* 58137 (1526) [ 0,  0,  1,  1,  0,  0,  0, -1,  0] [ 0,  6,  6] -1 */
    34024270, /* 58138 (1526) [ 0,  1,  0,  0,  0,  1, -1,  0,  0] [ 0,  0,  0] -1 */
    52447558, /* 58139 (1526) [ 0,  1,  0,  0,  0,  1, -1,  0,  0] [ 6,  6,  0] -1 */
    18439772, /* 58140 (1526) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    34021582, /* 58141 (1526) [ 0,  0, -1,  1,  0,  0,  0,  1,  0] [ 0,  0,  0] -1 */
    17140530, /* 58142 (1526) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  6]  1 */
    51145300, /* 58143 (1526) [ 0,  0, -1, -1,  0,  0,  0, -1,  0] [ 6,  0,  6] -1 */
    34015586, /* 58144 (1526) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    34028706, /* 58145 (1526) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    52451994, /* 58146 (1526) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
    18430960, /* 58147 (1526) [ 0, -1,  0,  0,  0,  1, -1,  0,  0] [ 6,  6,  0]  1 */
    34019842, /* 58148 (1526) [ 0, -1,  0,  0,  0, -1, -1,  0,  0] [ 0,  0,  0] -1 */
    52443130, /* 58149 (1526) [ 0, -1,  0,  0,  0, -1, -1,  0,  0] [ 6,  6,  0] -1 */
    35556856, /* 58150 (1526) [ 0,  0, -1,  1,  0,  0,  0,  1,  0] [ 0,  6,  6] -1 */
    18435280, /* 58151 (1526) [ 0,  1,  0,  0,  0, -1, -1,  0,  0] [ 6,  6,  0]  1 */
    18435352, /* 58152 (1526) [ 0,  1,  0,  0,  0,  1,  1,  0,  0] [ 6,  6,  0]  1 */
    35559508, /* 58153 (1526) [ 0,  1,  0,  0,  0, -1,  1,  0,  0] [ 0,  6,  6] -1 */
       10816, /* 58154 (1526) [ 0,  0,  1,  1,  0,  0,  0,  1,  0] [ 0,  0,  0]  1 */
    34015422, /* 58155 (1526) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    18434104, /* 58156 (1526) [ 0,  0,  1,  1,  0,  0,  0,  1,  0] [ 6,  6,  0]  1 */
    52438710, /* 58157 (1526) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
    35550860, /* 58158 (1526) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
    51152756, /* 58159 (1526) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
    51148480, /* 58160 (1526) [ 0,  1,  0,  0,  0,  1, -1,  0,  0] [ 6,  0,  6] -1 */
       11992, /* 58161 (1526) [ 0,  1,  0,  0,  0, -1, -1,  0,  0] [ 0,  0,  0]  1 */
       12064, /* 58162 (1526) [ 0,  1,  0,  0,  0,  1,  1,  0,  0] [ 0,  0,  0]  1 */
     1551758, /* 58163 (1526) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
    34019914, /* 58164 (1526) [ 0, -1,  0,  0,  0,  1,  1,  0,  0] [ 0,  0,  0] -1 */
    17127570, /* 58165 (1526) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6]  1 */
     1542946, /* 58166 (1526) [ 0, -1,  0,  0,  0,  1, -1,  0,  0] [ 0,  6,  6]  1 */
    35563980, /* 58167 (1526) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6] -1 */
    17133082, /* 58168 (1526) [ 0,  0, -1, -1,  0,  0,  0,  1,  0] [ 6,  0,  6]  1 */
    35555116, /* 58169 (1526) [ 0, -1,  0,  0,  0, -1, -1,  0,  0] [ 0,  6,  6] -1 */
     1547266, /* 58170 (1526) [ 0,  1,  0,  0,  0, -1, -1,  0,  0] [ 0,  6,  6]  1 */
     1546090, /* 58171 (1526) [ 0,  0,  1,  1,  0,  0,  0,  1,  0] [ 0,  6,  6]  1 */
    35550696, /* 58172 (1526) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  6] -1 */
    52444870, /* 58173 (1526) [ 0,  0, -1,  1,  0,  0,  0,  1,  0] [ 6,  6,  0] -1 */
    34028546, /* 58174 (1526) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
        7672, /* 58175 (1526) [ 0, -1,  0,  0,  0,  1, -1,  0,  0] [ 0,  0,  0]  1 */
        3360, /* 58176 (1526) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    51145792, /* 58177 (1526) [ 0,  0, -1,  1,  0,  0,  0,  1,  0] [ 6,  0,  6] -1 */
    18426488, /* 58178 (1526) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    51148444, /* 58179 (1526) [ 0,  1,  0,  0,  0, -1,  1,  0,  0] [ 6,  0,  6] -1 */
    51139796, /* 58180 (1526) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
    52444378, /* 58181 (1526) [ 0,  0, -1, -1,  0,  0,  0, -1,  0] [ 6,  6,  0] -1 */
    18439608, /* 58182 (1526) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
    17127410, /* 58183 (1526) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
    51152916, /* 58184 (1526) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6] -1 */
    17131882, /* 58185 (1526) [ 0, -1,  0,  0,  0,  1, -1,  0,  0] [ 6,  0,  6]  1 */
    51144052, /* 58186 (1526) [ 0, -1,  0,  0,  0, -1, -1,  0,  0] [ 6,  0,  6] -1 */
    17136202, /* 58187 (1526) [ 0,  1,  0,  0,  0, -1, -1,  0,  0] [ 6,  0,  6]  1 */
     1547338, /* 58188 (1526) [ 0,  1,  0,  0,  0,  1,  1,  0,  0] [ 0,  6,  6]  1 */
    18432640, /* 58189 (1526) [ 0,  0, -1,  1,  0,  0,  0, -1,  0] [ 6,  6,  0]  1 */
    51147244, /* 58190 (1526) [ 0,  0,  1,  1,  0,  0,  0, -1,  0] [ 6,  0,  6] -1 */
    17135026, /* 58191 (1526) [ 0,  0,  1,  1,  0,  0,  0,  1,  0] [ 6,  0,  6]  1 */
        7636, /* 58192 (1526) [ 0, -1,  0,  0,  0, -1,  1,  0,  0] [ 0,  0,  0]  1 */
    18430924, /* 58193 (1526) [ 0, -1,  0,  0,  0, -1,  1,  0,  0] [ 6,  6,  0]  1 */
    35556364, /* 58194 (1526) [ 0,  0, -1, -1,  0,  0,  0, -1,  0] [ 0,  6,  6] -1 */
    51144124, /* 58195 (1526) [ 0, -1,  0,  0,  0,  1,  1,  0,  0] [ 6,  0,  6] -1 */
     1551594, /* 58196 (1526) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
    35557828, /* 58197 (1526) [ 0,  0,  1, -1,  0,  0,  0,  1,  0] [ 0,  6,  6] -1 */
    35559544, /* 58198 (1526) [ 0,  1,  0,  0,  0,  1, -1,  0,  0] [ 0,  6,  6] -1 */
     1544626, /* 58199 (1526) [ 0,  0, -1,  1,  0,  0,  0, -1,  0] [ 0,  6,  6]  1 */
        3200, /* 58200 (1526) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
     1542910, /* 58201 (1526) [ 0, -1,  0,  0,  0, -1,  1,  0,  0] [ 0,  6,  6]  1 */
    34021090, /* 58202 (1526) [ 0,  0, -1, -1,  0,  0,  0, -1,  0] [ 0,  0,  0] -1 */
       16484, /* 58203 (1527) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    52562962, /* 58204 (1527) [ 0,  0, -1,  1,  0,  0,  0, -1,  0] [ 6,  6,  6] -1 */
    17140694, /* 58205 (1527) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
    17133568, /* 58206 (1527) [ 0,  0, -1,  1,  0,  0,  0,  1,  0] [ 6,  0,  6]  1 */
       16320, /* 58207 (1527) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    17136220, /* 58208 (1527) [ 0,  1,  0,  0,  0, -1,  1,  0,  0] [ 6,  0,  6]  1 */
        3198, /* 58209 (1527) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
     1545598, /* 58210 (1527) [ 0,  0,  1, -1,  0,  0,  0, -1,  0] [ 0,  6,  6]  1 */
    17140532, /* 58211 (1527) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
    51034658, /* 58212 (1527) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  0] -1 */
    52562968, /* 58213 (1527) [ 0,  0, -1,  1,  0,  0,  0,  1,  0] [ 6,  6,  6] -1 */
    51030382, /* 58214 (1527) [ 0,  1,  0,  0,  0,  1, -1,  0,  0] [ 6,  0,  0] -1 */
     1538474, /* 58215 (1527) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
    35438266, /* 58216 (1527) [ 0,  0, -1, -1,  0,  0,  0, -1,  0] [ 0,  6,  0] -1 */
    51034820, /* 58217 (1527) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  0] -1 */
    17136274, /* 58218 (1527) [ 0,  1,  0,  0,  0,  1,  1,  0,  0] [ 6,  0,  6]  1 */
    51027694, /* 58219 (1527) [ 0,  0, -1,  1,  0,  0,  0,  1,  0] [ 6,  0,  0] -1 */
    52565656, /* 58220 (1527) [ 0,  1,  0,  0,  0,  1, -1,  0,  0] [ 6,  6,  6] -1 */
    52565620, /* 58221 (1527) [ 0,  1,  0,  0,  0, -1,  1,  0,  0] [ 6,  6,  6] -1 */
    34142332, /* 58222 (1527) [ 0,  1,  0,  0,  0, -1,  1,  0,  0] [ 0,  0,  6] -1 */
        9352, /* 58223 (1527) [ 0,  0, -1,  1,  0,  0,  0, -1,  0] [ 0,  0,  0]  1 */
    52556972, /* 58224 (1527) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    34133684, /* 58225 (1527) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    34140652, /* 58226 (1527) [ 0,  0,  1, -1,  0,  0,  0,  1,  0] [ 0,  0,  6] -1 */
    34142368, /* 58227 (1527) [ 0,  1,  0,  0,  0,  1, -1,  0,  0] [ 0,  0,  6] -1 */
    18426648, /* 58228 (1527) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
    17131828, /* 58229 (1527) [ 0, -1,  0,  0,  0, -1, -1,  0,  0] [ 6,  0,  6]  1 */
    34133522, /* 58230 (1527) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    52556810, /* 58231 (1527) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
        8872, /* 58232 (1527) [ 0,  0, -1, -1,  0,  0,  0,  1,  0] [ 0,  0,  0]  1 */
    18432160, /* 58233 (1527) [ 0,  0, -1, -1,  0,  0,  0,  1,  0] [ 6,  6,  0]  1 */
    52561228, /* 58234 (1527) [ 0, -1,  0,  0,  0, -1, -1,  0,  0] [ 6,  6,  6] -1 */
    35439730, /* 58235 (1527) [ 0,  0,  1, -1,  0,  0,  0,  1,  0] [ 0,  6,  0] -1 */
    51034656, /* 58236 (1527) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  0] -1 */
    35432760, /* 58237 (1527) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  0] -1 */
    17135020, /* 58238 (1527) [ 0,  0,  1,  1,  0,  0,  0, -1,  0] [ 6,  0,  6]  1 */
    51021534, /* 58239 (1527) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  0] -1 */
    35445884, /* 58240 (1527) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  0] -1 */
    34146804, /* 58241 (1527) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
    52570092, /* 58242 (1527) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    34137940, /* 58243 (1527) [ 0, -1,  0,  0,  0, -1, -1,  0,  0] [ 0,  0,  6] -1 */
    17131900, /* 58244 (1527) [ 0, -1,  0,  0,  0,  1,  1,  0,  0] [ 6,  0,  6]  1 */
    18433612, /* 58245 (1527) [ 0,  0,  1, -1,  0,  0,  0, -1,  0] [ 6,  6,  0]  1 */
    17133562, /* 58246 (1527) [ 0,  0, -1,  1,  0,  0,  0, -1,  0] [ 6,  0,  6]  1 */
    34141132, /* 58247 (1527) [ 0,  0,  1,  1,  0,  0,  0, -1,  0] [ 0,  0,  6] -1 */
    52564420, /* 58248 (1527) [ 0,  0,  1,  1,  0,  0,  0, -1,  0] [ 6,  6,  6] -1 */
    34133520, /* 58249 (1527) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
    35441392, /* 58250 (1527) [ 0,  1,  0,  0,  0, -1, -1,  0,  0] [ 0,  6,  0] -1 */
    51025972, /* 58251 (1527) [ 0, -1,  0,  0,  0, -1,  1,  0,  0] [ 6,  0,  0] -1 */
    17131846, /* 58252 (1527) [ 0, -1,  0,  0,  0, -1,  1,  0,  0] [ 6,  0,  6]  1 */
    35441464, /* 58253 (1527) [ 0,  1,  0,  0,  0,  1,  1,  0,  0] [ 0,  6,  0] -1 */
    52561246, /* 58254 (1527) [ 0, -1,  0,  0,  0, -1,  1,  0,  0] [ 6,  6,  6] -1 */
       10324, /* 58255 (1527) [ 0,  0,  1, -1,  0,  0,  0, -1,  0] [ 0,  0,  0]  1 */
     1538634, /* 58256 (1527) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
    35440216, /* 58257 (1527) [ 0,  0,  1,  1,  0,  0,  0,  1,  0] [ 0,  6,  0] -1 */
    34138012, /* 58258 (1527) [ 0, -1,  0,  0,  0,  1,  1,  0,  0] [ 0,  0,  6] -1 */
     1544146, /* 58259 (1527) [ 0,  0, -1, -1,  0,  0,  0,  1,  0] [ 0,  6,  6]  1 */
    34139674, /* 58260 (1527) [ 0,  0, -1,  1,  0,  0,  0, -1,  0] [ 0,  0,  6] -1 */
    51026026, /* 58261 (1527) [ 0, -1,  0,  0,  0,  1,  1,  0,  0] [ 6,  0,  0] -1 */
    51027688, /* 58262 (1527) [ 0,  0, -1,  1,  0,  0,  0, -1,  0] [ 6,  0,  0] -1 */
    34137958, /* 58263 (1527) [ 0, -1,  0,  0,  0, -1,  1,  0,  0] [ 0,  0,  6] -1 */
    17134534, /* 58264 (1527) [ 0,  0,  1, -1,  0,  0,  0, -1,  0] [ 6,  0,  6]  1 */
        8866, /* 58265 (1527) [ 0,  0, -1, -1,  0,  0,  0, -1,  0] [ 0,  0,  0]  1 */
    17127572, /* 58266 (1527) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
    18432154, /* 58267 (1527) [ 0,  0, -1, -1,  0,  0,  0, -1,  0] [ 6,  6,  0]  1 */
    52562482, /* 58268 (1527) [ 0,  0, -1, -1,  0,  0,  0,  1,  0] [ 6,  6,  6] -1 */
    34146806, /* 58269 (1527) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    34139680, /* 58270 (1527) [ 0,  0, -1,  1,  0,  0,  0,  1,  0] [ 0,  0,  6] -1 */
    18439772, /* 58271 (1527) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    17140530, /* 58272 (1527) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  6]  1 */
    51028660, /* 58273 (1527) [ 0,  0,  1, -1,  0,  0,  0, -1,  0] [ 6,  0,  0] -1 */
    17127408, /* 58274 (1527) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  6]  1 */
    17140692, /* 58275 (1527) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6]  1 */
    18439610, /* 58276 (1527) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    18430960, /* 58277 (1527) [ 0, -1,  0,  0,  0,  1, -1,  0,  0] [ 6,  6,  0]  1 */
    51025954, /* 58278 (1527) [ 0, -1,  0,  0,  0, -1, -1,  0,  0] [ 6,  0,  0] -1 */
    35445722, /* 58279 (1527) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  0] -1 */
    34146642, /* 58280 (1527) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
    52569930, /* 58281 (1527) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    18435280, /* 58282 (1527) [ 0,  1,  0,  0,  0, -1, -1,  0,  0] [ 6,  6,  0]  1 */
    18435352, /* 58283 (1527) [ 0,  1,  0,  0,  0,  1,  1,  0,  0] [ 6,  6,  0]  1 */
    35437072, /* 58284 (1527) [ 0, -1,  0,  0,  0,  1, -1,  0,  0] [ 0,  6,  0] -1 */
    35438758, /* 58285 (1527) [ 0,  0, -1,  1,  0,  0,  0,  1,  0] [ 0,  6,  0] -1 */
     1544140, /* 58286 (1527) [ 0,  0, -1, -1,  0,  0,  0, -1,  0] [ 0,  6,  6]  1 */
    52556808, /* 58287 (1527) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    51027202, /* 58288 (1527) [ 0,  0, -1, -1,  0,  0,  0, -1,  0] [ 6,  0,  0] -1 */
    35441410, /* 58289 (1527) [ 0,  1,  0,  0,  0, -1,  1,  0,  0] [ 0,  6,  0] -1 */
       10816, /* 58290 (1527) [ 0,  0,  1,  1,  0,  0,  0,  1,  0] [ 0,  0,  0]  1 */
    18434104, /* 58291 (1527) [ 0,  0,  1,  1,  0,  0,  0,  1,  0] [ 6,  6,  0]  1 */
       11992, /* 58292 (1527) [ 0,  1,  0,  0,  0, -1, -1,  0,  0] [ 0,  0,  0]  1 */
    35432762, /* 58293 (1527) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  0] -1 */
       12064, /* 58294 (1527) [ 0,  1,  0,  0,  0,  1,  1,  0,  0] [ 0,  0,  0]  1 */
     1551758, /* 58295 (1527) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
     1545604, /* 58296 (1527) [ 0,  0,  1, -1,  0,  0,  0,  1,  0] [ 0,  6,  6]  1 */
    17127570, /* 58297 (1527) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6]  1 */
     1547320, /* 58298 (1527) [ 0,  1,  0,  0,  0,  1, -1,  0,  0] [ 0,  6,  6]  1 */
     1542946, /* 58299 (1527) [ 0, -1,  0,  0,  0,  1, -1,  0,  0] [ 0,  6,  6]  1 */
    17133082, /* 58300 (1527) [ 0,  0, -1, -1,  0,  0,  0,  1,  0] [ 6,  0,  6]  1 */
     1547266, /* 58301 (1527) [ 0,  1,  0,  0,  0, -1, -1,  0,  0] [ 0,  6,  6]  1 */
    18434098, /* 58302 (1527) [ 0,  0,  1,  1,  0,  0,  0, -1,  0] [ 6,  6,  0]  1 */
    52563940, /* 58303 (1527) [ 0,  0,  1, -1,  0,  0,  0,  1,  0] [ 6,  6,  6] -1 */
     1546090, /* 58304 (1527) [ 0,  0,  1,  1,  0,  0,  0,  1,  0] [ 0,  6,  6]  1 */
    35437090, /* 58305 (1527) [ 0, -1,  0,  0,  0,  1,  1,  0,  0] [ 0,  6,  0] -1 */
    35440210, /* 58306 (1527) [ 0,  0,  1,  1,  0,  0,  0, -1,  0] [ 0,  6,  0] -1 */
    35438752, /* 58307 (1527) [ 0,  0, -1,  1,  0,  0,  0, -1,  0] [ 0,  6,  0] -1 */
    34139194, /* 58308 (1527) [ 0,  0, -1, -1,  0,  0,  0,  1,  0] [ 0,  0,  6] -1 */
    51030328, /* 58309 (1527) [ 0,  1,  0,  0,  0, -1, -1,  0,  0] [ 6,  0,  0] -1 */
    51027208, /* 58310 (1527) [ 0,  0, -1, -1,  0,  0,  0,  1,  0] [ 6,  0,  0] -1 */
    51030400, /* 58311 (1527) [ 0,  1,  0,  0,  0,  1,  1,  0,  0] [ 6,  0,  0] -1 */
    35437036, /* 58312 (1527) [ 0, -1,  0,  0,  0, -1,  1,  0,  0] [ 0,  6,  0] -1 */
    18435298, /* 58313 (1527) [ 0,  1,  0,  0,  0, -1,  1,  0,  0] [ 6,  6,  0]  1 */
    34140646, /* 58314 (1527) [ 0,  0,  1, -1,  0,  0,  0, -1,  0] [ 0,  0,  6] -1 */
    52563934, /* 58315 (1527) [ 0,  0,  1, -1,  0,  0,  0, -1,  0] [ 6,  6,  6] -1 */
    18426650, /* 58316 (1527) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
        7672, /* 58317 (1527) [ 0, -1,  0,  0,  0,  1, -1,  0,  0] [ 0,  0,  0]  1 */
       10330, /* 58318 (1527) [ 0,  0,  1, -1,  0,  0,  0,  1,  0] [ 0,  0,  0]  1 */
    18433618, /* 58319 (1527) [ 0,  0,  1, -1,  0,  0,  0,  1,  0] [ 6,  6,  0]  1 */
        3360, /* 58320 (1527) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
     1546084, /* 58321 (1527) [ 0,  0,  1,  1,  0,  0,  0, -1,  0] [ 0,  6,  6]  1 */
       12046, /* 58322 (1527) [ 0,  1,  0,  0,  0,  1, -1,  0,  0] [ 0,  0,  0]  1 */
       12010, /* 58323 (1527) [ 0,  1,  0,  0,  0, -1,  1,  0,  0] [ 0,  0,  0]  1 */
    18435334, /* 58324 (1527) [ 0,  1,  0,  0,  0,  1, -1,  0,  0] [ 6,  6,  0]  1 */
    18426488, /* 58325 (1527) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    17133076, /* 58326 (1527) [ 0,  0, -1, -1,  0,  0,  0, -1,  0] [ 6,  0,  6]  1 */
        3362, /* 58327 (1527) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    35441446, /* 58328 (1527) [ 0,  1,  0,  0,  0,  1, -1,  0,  0] [ 0,  6,  0] -1 */
    35432600, /* 58329 (1527) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  0] -1 */
    52562476, /* 58330 (1527) [ 0,  0, -1, -1,  0,  0,  0, -1,  0] [ 6,  6,  6] -1 */
    52561300, /* 58331 (1527) [ 0, -1,  0,  0,  0,  1,  1,  0,  0] [ 6,  6,  6] -1 */
    35439724, /* 58332 (1527) [ 0,  0,  1, -1,  0,  0,  0, -1,  0] [ 0,  6,  0] -1 */
    18439770, /* 58333 (1527) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
        7618, /* 58334 (1527) [ 0, -1,  0,  0,  0, -1, -1,  0,  0] [ 0,  0,  0]  1 */
    18430906, /* 58335 (1527) [ 0, -1,  0,  0,  0, -1, -1,  0,  0] [ 6,  6,  0]  1 */
     1544632, /* 58336 (1527) [ 0,  0, -1,  1,  0,  0,  0,  1,  0] [ 0,  6,  6]  1 */
    35445882, /* 58337 (1527) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  0] -1 */
    34139188, /* 58338 (1527) [ 0,  0, -1, -1,  0,  0,  0, -1,  0] [ 0,  0,  6] -1 */
     1547284, /* 58339 (1527) [ 0,  1,  0,  0,  0, -1,  1,  0,  0] [ 0,  6,  6]  1 */
    18439608, /* 58340 (1527) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
    35437018, /* 58341 (1527) [ 0, -1,  0,  0,  0, -1, -1,  0,  0] [ 0,  6,  0] -1 */
    18426486, /* 58342 (1527) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
     1551596, /* 58343 (1527) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
    17134540, /* 58344 (1527) [ 0,  0,  1, -1,  0,  0,  0,  1,  0] [ 6,  0,  6]  1 */
     1538636, /* 58345 (1527) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
    35445720, /* 58346 (1527) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  0] -1 */
    17136256, /* 58347 (1527) [ 0,  1,  0,  0,  0,  1, -1,  0,  0] [ 6,  0,  6]  1 */
    52556970, /* 58348 (1527) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    17127410, /* 58349 (1527) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
    17131882, /* 58350 (1527) [ 0, -1,  0,  0,  0,  1, -1,  0,  0] [ 6,  0,  6]  1 */
    51028666, /* 58351 (1527) [ 0,  0,  1, -1,  0,  0,  0,  1,  0] [ 6,  0,  0] -1 */
    35432598, /* 58352 (1527) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  0] -1 */
    51021696, /* 58353 (1527) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  0] -1 */
    52570094, /* 58354 (1527) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    51030346, /* 58355 (1527) [ 0,  1,  0,  0,  0, -1,  1,  0,  0] [ 6,  0,  0] -1 */
    17136202, /* 58356 (1527) [ 0,  1,  0,  0,  0, -1, -1,  0,  0] [ 6,  0,  6]  1 */
     1547338, /* 58357 (1527) [ 0,  1,  0,  0,  0,  1,  1,  0,  0] [ 0,  6,  6]  1 */
        7690, /* 58358 (1527) [ 0, -1,  0,  0,  0,  1,  1,  0,  0] [ 0,  0,  0]  1 */
       10810, /* 58359 (1527) [ 0,  0,  1,  1,  0,  0,  0, -1,  0] [ 0,  0,  0]  1 */
    18430978, /* 58360 (1527) [ 0, -1,  0,  0,  0,  1,  1,  0,  0] [ 6,  6,  0]  1 */
    18432640, /* 58361 (1527) [ 0,  0, -1,  1,  0,  0,  0, -1,  0] [ 6,  6,  0]  1 */
    51021698, /* 58362 (1527) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  0] -1 */
    34146644, /* 58363 (1527) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    52569932, /* 58364 (1527) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    17135026, /* 58365 (1527) [ 0,  0,  1,  1,  0,  0,  0,  1,  0] [ 6,  0,  6]  1 */
        7636, /* 58366 (1527) [ 0, -1,  0,  0,  0, -1,  1,  0,  0] [ 0,  0,  0]  1 */
    18430924, /* 58367 (1527) [ 0, -1,  0,  0,  0, -1,  1,  0,  0] [ 6,  6,  0]  1 */
    34137994, /* 58368 (1527) [ 0, -1,  0,  0,  0,  1, -1,  0,  0] [ 0,  0,  6] -1 */
    52561282, /* 58369 (1527) [ 0, -1,  0,  0,  0,  1, -1,  0,  0] [ 6,  6,  6] -1 */
     1551756, /* 58370 (1527) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
    34133682, /* 58371 (1527) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
    51021536, /* 58372 (1527) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  0] -1 */
     1542892, /* 58373 (1527) [ 0, -1,  0,  0,  0, -1, -1,  0,  0] [ 0,  6,  6]  1 */
    51026008, /* 58374 (1527) [ 0, -1,  0,  0,  0,  1, -1,  0,  0] [ 6,  0,  0] -1 */
    34142314, /* 58375 (1527) [ 0,  1,  0,  0,  0, -1, -1,  0,  0] [ 0,  0,  6] -1 */
    52565602, /* 58376 (1527) [ 0,  1,  0,  0,  0, -1, -1,  0,  0] [ 6,  6,  6] -1 */
    34142386, /* 58377 (1527) [ 0,  1,  0,  0,  0,  1,  1,  0,  0] [ 0,  0,  6] -1 */
    52565674, /* 58378 (1527) [ 0,  1,  0,  0,  0,  1,  1,  0,  0] [ 6,  6,  6] -1 */
     1551594, /* 58379 (1527) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
    34141138, /* 58380 (1527) [ 0,  0,  1,  1,  0,  0,  0,  1,  0] [ 0,  0,  6] -1 */
    52564426, /* 58381 (1527) [ 0,  0,  1,  1,  0,  0,  0,  1,  0] [ 6,  6,  6] -1 */
     1538472, /* 58382 (1527) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
    35438272, /* 58383 (1527) [ 0,  0, -1, -1,  0,  0,  0,  1,  0] [ 0,  6,  0] -1 */
    51034818, /* 58384 (1527) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  0] -1 */
    51029152, /* 58385 (1527) [ 0,  0,  1,  1,  0,  0,  0,  1,  0] [ 6,  0,  0] -1 */
    18432646, /* 58386 (1527) [ 0,  0, -1,  1,  0,  0,  0,  1,  0] [ 6,  6,  0]  1 */
     1542964, /* 58387 (1527) [ 0, -1,  0,  0,  0,  1,  1,  0,  0] [ 0,  6,  6]  1 */
       16322, /* 58388 (1527) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
     1544626, /* 58389 (1527) [ 0,  0, -1,  1,  0,  0,  0, -1,  0] [ 0,  6,  6]  1 */
    51029146, /* 58390 (1527) [ 0,  0,  1,  1,  0,  0,  0, -1,  0] [ 6,  0,  0] -1 */
        3200, /* 58391 (1527) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
        9358, /* 58392 (1527) [ 0,  0, -1,  1,  0,  0,  0,  1,  0] [ 0,  0,  0]  1 */
     1542910, /* 58393 (1527) [ 0, -1,  0,  0,  0, -1,  1,  0,  0] [ 0,  6,  6]  1 */
       16482, /* 58394 (1527) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
       16484, /* 58395 (1528) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    17127570, /* 58396 (1528) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6]  1 */
    17140694, /* 58397 (1528) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
    17134534, /* 58398 (1528) [ 0,  0,  1, -1,  0,  0,  0, -1,  0] [ 6,  0,  6]  1 */
    27705991, /* 58399 (1528) [ 0,  1,  0,  0,  0, -1,  1,  0,  0] [ 9,  9,  3]  1 */
    26406949, /* 58400 (1528) [ 0,  1,  0,  0,  0,  1, -1,  0,  0] [ 9,  3,  9]  1 */
     1538474, /* 58401 (1528) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
     9273891, /* 58402 (1528) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 3,  3,  3]  1 */
     9281023, /* 58403 (1528) [ 0,  0,  1, -1,  0,  0,  0,  1,  0] [ 3,  3,  3]  1 */
    18430960, /* 58404 (1528) [ 0, -1,  0,  0,  0,  1, -1,  0,  0] [ 6,  6,  0]  1 */
       16320, /* 58405 (1528) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    10816297, /* 58406 (1528) [ 0,  0,  1, -1,  0,  0,  0,  1,  0] [ 3,  9,  9]  1 */
    27710303, /* 58407 (1528) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 9,  9,  3]  1 */
    18426648, /* 58408 (1528) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
    17131882, /* 58409 (1528) [ 0, -1,  0,  0,  0,  1, -1,  0,  0] [ 6,  0,  6]  1 */
    26411385, /* 58410 (1528) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 9,  3,  9]  1 */
    17136274, /* 58411 (1528) [ 0,  1,  0,  0,  0,  1,  1,  0,  0] [ 6,  0,  6]  1 */
    27704791, /* 58412 (1528) [ 0,  0,  1,  1,  0,  0,  0, -1,  0] [ 9,  9,  3]  1 */
    26405713, /* 58413 (1528) [ 0,  0,  1,  1,  0,  0,  0, -1,  0] [ 9,  3,  9]  1 */
     9278383, /* 58414 (1528) [ 0, -1,  0,  0,  0,  1,  1,  0,  0] [ 3,  3,  3]  1 */
    26402521, /* 58415 (1528) [ 0, -1,  0,  0,  0, -1, -1,  0,  0] [ 9,  3,  9]  1 */
        7636, /* 58416 (1528) [ 0, -1,  0,  0,  0, -1,  1,  0,  0] [ 0,  0,  0]  1 */
     1542910, /* 58417 (1528) [ 0, -1,  0,  0,  0, -1,  1,  0,  0] [ 0,  6,  6]  1 */
    10816777, /* 58418 (1528) [ 0,  0,  1,  1,  0,  0,  0, -1,  0] [ 3,  9,  9]  1 */
    26404261, /* 58419 (1528) [ 0,  0, -1,  1,  0,  0,  0,  1,  0] [ 9,  3,  9]  1 */
     1544146, /* 58420 (1528) [ 0,  0, -1, -1,  0,  0,  0,  1,  0] [ 0,  6,  6]  1 */
     1544626, /* 58421 (1528) [ 0,  0, -1,  1,  0,  0,  0, -1,  0] [ 0,  6,  6]  1 */
     1547266, /* 58422 (1528) [ 0,  1,  0,  0,  0, -1, -1,  0,  0] [ 0,  6,  6]  1 */
    17136202, /* 58423 (1528) [ 0,  1,  0,  0,  0, -1, -1,  0,  0] [ 6,  0,  6]  1 */
        3200, /* 58424 (1528) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
     1545598, /* 58425 (1528) [ 0,  0,  1, -1,  0,  0,  0, -1,  0] [ 0,  6,  6]  1 */
    18439608, /* 58426 (1528) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
    26405233, /* 58427 (1528) [ 0,  0,  1, -1,  0,  0,  0,  1,  0] [ 9,  3,  9]  1 */
        3360, /* 58428 (1528) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
       10324, /* 58429 (1528) [ 0,  0,  1, -1,  0,  0,  0, -1,  0] [ 0,  0,  0]  1 */
    10817977, /* 58430 (1528) [ 0,  1,  0,  0,  0, -1,  1,  0,  0] [ 3,  9,  9]  1 */
     9282703, /* 58431 (1528) [ 0,  1,  0,  0,  0, -1,  1,  0,  0] [ 3,  3,  3]  1 */
     9279559, /* 58432 (1528) [ 0,  0, -1, -1,  0,  0,  0, -1,  0] [ 3,  3,  3]  1 */
    27702847, /* 58433 (1528) [ 0,  0, -1, -1,  0,  0,  0, -1,  0] [ 9,  9,  3]  1 */
     9287015, /* 58434 (1528) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 3,  3,  3]  1 */
    10822289, /* 58435 (1528) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 3,  9,  9]  1 */
    10818013, /* 58436 (1528) [ 0,  1,  0,  0,  0,  1, -1,  0,  0] [ 3,  9,  9]  1 */
    18439772, /* 58437 (1528) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    26398101, /* 58438 (1528) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 9,  3,  9]  1 */
    17127410, /* 58439 (1528) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
    18426488, /* 58440 (1528) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    26402593, /* 58441 (1528) [ 0, -1,  0,  0,  0,  1,  1,  0,  0] [ 9,  3,  9]  1 */
    18435352, /* 58442 (1528) [ 0,  1,  0,  0,  0,  1,  1,  0,  0] [ 6,  6,  0]  1 */
    10814833, /* 58443 (1528) [ 0,  0, -1, -1,  0,  0,  0, -1,  0] [ 3,  9,  9]  1 */
     9287175, /* 58444 (1528) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 3,  3,  3]  1 */
       10816, /* 58445 (1528) [ 0,  0,  1,  1,  0,  0,  0,  1,  0] [ 0,  0,  0]  1 */
    18434104, /* 58446 (1528) [ 0,  0,  1,  1,  0,  0,  0,  1,  0] [ 6,  6,  0]  1 */
       12064, /* 58447 (1528) [ 0,  1,  0,  0,  0,  1,  1,  0,  0] [ 0,  0,  0]  1 */
    27697343, /* 58448 (1528) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 9,  9,  3]  1 */
     9281503, /* 58449 (1528) [ 0,  0,  1,  1,  0,  0,  0, -1,  0] [ 3,  3,  3]  1 */
     1551758, /* 58450 (1528) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
    17133562, /* 58451 (1528) [ 0,  0, -1,  1,  0,  0,  0, -1,  0] [ 6,  0,  6]  1 */
    17131846, /* 58452 (1528) [ 0, -1,  0,  0,  0, -1,  1,  0,  0] [ 6,  0,  6]  1 */
    18433612, /* 58453 (1528) [ 0,  0,  1, -1,  0,  0,  0, -1,  0] [ 6,  6,  0]  1 */
       11992, /* 58454 (1528) [ 0,  1,  0,  0,  0, -1, -1,  0,  0] [ 0,  0,  0]  1 */
    26411225, /* 58455 (1528) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 9,  3,  9]  1 */
        7672, /* 58456 (1528) [ 0, -1,  0,  0,  0,  1, -1,  0,  0] [ 0,  0,  0]  1 */
     1546090, /* 58457 (1528) [ 0,  0,  1,  1,  0,  0,  0,  1,  0] [ 0,  6,  6]  1 */
    27710463, /* 58458 (1528) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 9,  9,  3]  1 */
     9282739, /* 58459 (1528) [ 0,  1,  0,  0,  0,  1, -1,  0,  0] [ 3,  3,  3]  1 */
    27701671, /* 58460 (1528) [ 0, -1,  0,  0,  0,  1,  1,  0,  0] [ 9,  9,  3]  1 */
    26403769, /* 58461 (1528) [ 0,  0, -1, -1,  0,  0,  0, -1,  0] [ 9,  3,  9]  1 */
        9352, /* 58462 (1528) [ 0,  0, -1,  1,  0,  0,  0, -1,  0] [ 0,  0,  0]  1 */
    10822449, /* 58463 (1528) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 3,  9,  9]  1 */
    18435280, /* 58464 (1528) [ 0,  1,  0,  0,  0, -1, -1,  0,  0] [ 6,  6,  0]  1 */
    27703339, /* 58465 (1528) [ 0,  0, -1,  1,  0,  0,  0,  1,  0] [ 9,  9,  3]  1 */
     9274055, /* 58466 (1528) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 3,  3,  3]  1 */
        8872, /* 58467 (1528) [ 0,  0, -1, -1,  0,  0,  0,  1,  0] [ 0,  0,  0]  1 */
     9278311, /* 58468 (1528) [ 0, -1,  0,  0,  0, -1, -1,  0,  0] [ 3,  3,  3]  1 */
    27701599, /* 58469 (1528) [ 0, -1,  0,  0,  0, -1, -1,  0,  0] [ 9,  9,  3]  1 */
    10809329, /* 58470 (1528) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 3,  9,  9]  1 */
    18432640, /* 58471 (1528) [ 0,  0, -1,  1,  0,  0,  0, -1,  0] [ 6,  6,  0]  1 */
    18430924, /* 58472 (1528) [ 0, -1,  0,  0,  0, -1,  1,  0,  0] [ 6,  6,  0]  1 */
    27697179, /* 58473 (1528) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 9,  9,  3]  1 */
     1551594, /* 58474 (1528) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
     1542946, /* 58475 (1528) [ 0, -1,  0,  0,  0,  1, -1,  0,  0] [ 0,  6,  6]  1 */
    17140530, /* 58476 (1528) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  6]  1 */
    27704311, /* 58477 (1528) [ 0,  0,  1, -1,  0,  0,  0,  1,  0] [ 9,  9,  3]  1 */
    26406913, /* 58478 (1528) [ 0,  1,  0,  0,  0, -1,  1,  0,  0] [ 9,  3,  9]  1 */
     1538634, /* 58479 (1528) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
     1547338, /* 58480 (1528) [ 0,  1,  0,  0,  0,  1,  1,  0,  0] [ 0,  6,  6]  1 */
    17135026, /* 58481 (1528) [ 0,  0,  1,  1,  0,  0,  0,  1,  0] [ 6,  0,  6]  1 */
    18432160, /* 58482 (1528) [ 0,  0, -1, -1,  0,  0,  0,  1,  0] [ 6,  6,  0]  1 */
    17133082, /* 58483 (1528) [ 0,  0, -1, -1,  0,  0,  0,  1,  0] [ 6,  0,  6]  1 */
    10813585, /* 58484 (1528) [ 0, -1,  0,  0,  0, -1, -1,  0,  0] [ 3,  9,  9]  1 */
    10813657, /* 58485 (1528) [ 0, -1,  0,  0,  0,  1,  1,  0,  0] [ 3,  9,  9]  1 */
    10809165, /* 58486 (1528) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 3,  9,  9]  1 */
    26398265, /* 58487 (1528) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 9,  3,  9]  1 */
     9280051, /* 58488 (1528) [ 0,  0, -1,  1,  0,  0,  0,  1,  0] [ 3,  3,  3]  1 */
    10815325, /* 58489 (1528) [ 0,  0, -1,  1,  0,  0,  0,  1,  0] [ 3,  9,  9]  1 */
    27706027, /* 58490 (1528) [ 0,  1,  0,  0,  0,  1, -1,  0,  0] [ 9,  9,  3]  1 */
       16484, /* 58491 (1529) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    61722687, /* 58492 (1529) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 9,  9,  3] -1 */
    44834513, /* 58493 (1529) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 3,  9,  9] -1 */
    44830237, /* 58494 (1529) [ 0,  1,  0,  0,  0,  1, -1,  0,  0] [ 3,  9,  9] -1 */
    17127570, /* 58495 (1529) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6]  1 */
    17140694, /* 58496 (1529) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
    17134534, /* 58497 (1529) [ 0,  0,  1, -1,  0,  0,  0, -1,  0] [ 6,  0,  6]  1 */
    43294963, /* 58498 (1529) [ 0,  1,  0,  0,  0,  1, -1,  0,  0] [ 3,  3,  3] -1 */
    27705991, /* 58499 (1529) [ 0,  1,  0,  0,  0, -1,  1,  0,  0] [ 9,  9,  3]  1 */
    26406949, /* 58500 (1529) [ 0,  1,  0,  0,  0,  1, -1,  0,  0] [ 9,  3,  9]  1 */
     1538474, /* 58501 (1529) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
    52451996, /* 58502 (1529) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
     9273891, /* 58503 (1529) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 3,  3,  3]  1 */
    61713895, /* 58504 (1529) [ 0, -1,  0,  0,  0,  1,  1,  0,  0] [ 9,  9,  3] -1 */
     9281023, /* 58505 (1529) [ 0,  0,  1, -1,  0,  0,  0,  1,  0] [ 3,  3,  3]  1 */
    60410325, /* 58506 (1529) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 9,  3,  9] -1 */
    18430960, /* 58507 (1529) [ 0, -1,  0,  0,  0,  1, -1,  0,  0] [ 6,  6,  0]  1 */
       16320, /* 58508 (1529) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    27710303, /* 58509 (1529) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 9,  9,  3]  1 */
    10816297, /* 58510 (1529) [ 0,  0,  1, -1,  0,  0,  0,  1,  0] [ 3,  9,  9]  1 */
    52438712, /* 58511 (1529) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
    18426648, /* 58512 (1529) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
    17131882, /* 58513 (1529) [ 0, -1,  0,  0,  0,  1, -1,  0,  0] [ 6,  0,  6]  1 */
    26411385, /* 58514 (1529) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 9,  3,  9]  1 */
    17136274, /* 58515 (1529) [ 0,  1,  0,  0,  0,  1,  1,  0,  0] [ 6,  0,  6]  1 */
    27704791, /* 58516 (1529) [ 0,  0,  1,  1,  0,  0,  0, -1,  0] [ 9,  9,  3]  1 */
    52447576, /* 58517 (1529) [ 0,  1,  0,  0,  0,  1,  1,  0,  0] [ 6,  6,  0] -1 */
    43299399, /* 58518 (1529) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 3,  3,  3] -1 */
    26405713, /* 58519 (1529) [ 0,  0,  1,  1,  0,  0,  0, -1,  0] [ 9,  3,  9]  1 */
    34023040, /* 58520 (1529) [ 0,  0,  1,  1,  0,  0,  0,  1,  0] [ 0,  0,  0] -1 */
    52446328, /* 58521 (1529) [ 0,  0,  1,  1,  0,  0,  0,  1,  0] [ 6,  6,  0] -1 */
     9278383, /* 58522 (1529) [ 0, -1,  0,  0,  0,  1,  1,  0,  0] [ 3,  3,  3]  1 */
    26402521, /* 58523 (1529) [ 0, -1,  0,  0,  0, -1, -1,  0,  0] [ 9,  3,  9]  1 */
    52447504, /* 58524 (1529) [ 0,  1,  0,  0,  0, -1, -1,  0,  0] [ 6,  6,  0] -1 */
    43286279, /* 58525 (1529) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 3,  3,  3] -1 */
    34024288, /* 58526 (1529) [ 0,  1,  0,  0,  0,  1,  1,  0,  0] [ 0,  0,  0] -1 */
    61709567, /* 58527 (1529) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 9,  9,  3] -1 */
        7636, /* 58528 (1529) [ 0, -1,  0,  0,  0, -1,  1,  0,  0] [ 0,  0,  0]  1 */
    35563982, /* 58529 (1529) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
    51145786, /* 58530 (1529) [ 0,  0, -1,  1,  0,  0,  0, -1,  0] [ 6,  0,  6] -1 */
    51144070, /* 58531 (1529) [ 0, -1,  0,  0,  0, -1,  1,  0,  0] [ 6,  0,  6] -1 */
    52444864, /* 58532 (1529) [ 0,  0, -1,  1,  0,  0,  0, -1,  0] [ 6,  6,  0] -1 */
    52445836, /* 58533 (1529) [ 0,  0,  1, -1,  0,  0,  0, -1,  0] [ 6,  6,  0] -1 */
    52443148, /* 58534 (1529) [ 0, -1,  0,  0,  0, -1,  1,  0,  0] [ 6,  6,  0] -1 */
    34024216, /* 58535 (1529) [ 0,  1,  0,  0,  0, -1, -1,  0,  0] [ 0,  0,  0] -1 */
     1542910, /* 58536 (1529) [ 0, -1,  0,  0,  0, -1,  1,  0,  0] [ 0,  6,  6]  1 */
    35555170, /* 58537 (1529) [ 0, -1,  0,  0,  0,  1, -1,  0,  0] [ 0,  6,  6] -1 */
    51152754, /* 58538 (1529) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  6] -1 */
    10816777, /* 58539 (1529) [ 0,  0,  1,  1,  0,  0,  0, -1,  0] [ 3,  9,  9]  1 */
    60419137, /* 58540 (1529) [ 0,  1,  0,  0,  0, -1,  1,  0,  0] [ 9,  3,  9] -1 */
    26404261, /* 58541 (1529) [ 0,  0, -1,  1,  0,  0,  0,  1,  0] [ 9,  3,  9]  1 */
    35550858, /* 58542 (1529) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6] -1 */
     1544146, /* 58543 (1529) [ 0,  0, -1, -1,  0,  0,  0,  1,  0] [ 0,  6,  6]  1 */
    60423449, /* 58544 (1529) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 9,  3,  9] -1 */
    35559562, /* 58545 (1529) [ 0,  1,  0,  0,  0,  1,  1,  0,  0] [ 0,  6,  6] -1 */
     1544626, /* 58546 (1529) [ 0,  0, -1,  1,  0,  0,  0, -1,  0] [ 0,  6,  6]  1 */
     1547266, /* 58547 (1529) [ 0,  1,  0,  0,  0, -1, -1,  0,  0] [ 0,  6,  6]  1 */
    34019896, /* 58548 (1529) [ 0, -1,  0,  0,  0,  1, -1,  0,  0] [ 0,  0,  0] -1 */
    17136202, /* 58549 (1529) [ 0,  1,  0,  0,  0, -1, -1,  0,  0] [ 6,  0,  6]  1 */
    35558314, /* 58550 (1529) [ 0,  0,  1,  1,  0,  0,  0,  1,  0] [ 0,  6,  6] -1 */
    52444384, /* 58551 (1529) [ 0,  0, -1, -1,  0,  0,  0,  1,  0] [ 6,  6,  0] -1 */
        3200, /* 58552 (1529) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
     1545598, /* 58553 (1529) [ 0,  0,  1, -1,  0,  0,  0, -1,  0] [ 0,  6,  6]  1 */
    18439608, /* 58554 (1529) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
    26405233, /* 58555 (1529) [ 0,  0,  1, -1,  0,  0,  0,  1,  0] [ 9,  3,  9]  1 */
        3360, /* 58556 (1529) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
       10324, /* 58557 (1529) [ 0,  0,  1, -1,  0,  0,  0, -1,  0] [ 0,  0,  0]  1 */
    10817977, /* 58558 (1529) [ 0,  1,  0,  0,  0, -1,  1,  0,  0] [ 3,  9,  9]  1 */
     9282703, /* 58559 (1529) [ 0,  1,  0,  0,  0, -1,  1,  0,  0] [ 3,  3,  3]  1 */
    44825881, /* 58560 (1529) [ 0, -1,  0,  0,  0,  1,  1,  0,  0] [ 3,  9,  9] -1 */
     9279559, /* 58561 (1529) [ 0,  0, -1, -1,  0,  0,  0, -1,  0] [ 3,  3,  3]  1 */
    27702847, /* 58562 (1529) [ 0,  0, -1, -1,  0,  0,  0, -1,  0] [ 9,  9,  3]  1 */
     9287015, /* 58563 (1529) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 3,  3,  3]  1 */
    10822289, /* 58564 (1529) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 3,  9,  9]  1 */
    10818013, /* 58565 (1529) [ 0,  1,  0,  0,  0,  1, -1,  0,  0] [ 3,  9,  9]  1 */
    18439772, /* 58566 (1529) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    34028708, /* 58567 (1529) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    60415993, /* 58568 (1529) [ 0,  0, -1, -1,  0,  0,  0, -1,  0] [ 9,  3,  9] -1 */
    26398101, /* 58569 (1529) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 9,  3,  9]  1 */
    17127410, /* 58570 (1529) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
    44834673, /* 58571 (1529) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 3,  9,  9] -1 */
    34021576, /* 58572 (1529) [ 0,  0, -1,  1,  0,  0,  0, -1,  0] [ 0,  0,  0] -1 */
    43292275, /* 58573 (1529) [ 0,  0, -1,  1,  0,  0,  0,  1,  0] [ 3,  3,  3] -1 */
    18426488, /* 58574 (1529) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    61715563, /* 58575 (1529) [ 0,  0, -1,  1,  0,  0,  0,  1,  0] [ 9,  9,  3] -1 */
    26402593, /* 58576 (1529) [ 0, -1,  0,  0,  0,  1,  1,  0,  0] [ 9,  3,  9]  1 */
    34021096, /* 58577 (1529) [ 0,  0, -1, -1,  0,  0,  0,  1,  0] [ 0,  0,  0] -1 */
    43290535, /* 58578 (1529) [ 0, -1,  0,  0,  0, -1, -1,  0,  0] [ 3,  3,  3] -1 */
    61713823, /* 58579 (1529) [ 0, -1,  0,  0,  0, -1, -1,  0,  0] [ 9,  9,  3] -1 */
    44821553, /* 58580 (1529) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 3,  9,  9] -1 */
    51152918, /* 58581 (1529) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
    18435352, /* 58582 (1529) [ 0,  1,  0,  0,  0,  1,  1,  0,  0] [ 6,  6,  0]  1 */
    61718215, /* 58583 (1529) [ 0,  1,  0,  0,  0, -1,  1,  0,  0] [ 9,  9,  3] -1 */
    10814833, /* 58584 (1529) [ 0,  0, -1, -1,  0,  0,  0, -1,  0] [ 3,  9,  9]  1 */
     9287175, /* 58585 (1529) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 3,  3,  3]  1 */
    60419173, /* 58586 (1529) [ 0,  1,  0,  0,  0,  1, -1,  0,  0] [ 9,  3,  9] -1 */
       10816, /* 58587 (1529) [ 0,  0,  1,  1,  0,  0,  0,  1,  0] [ 0,  0,  0]  1 */
    18434104, /* 58588 (1529) [ 0,  0,  1,  1,  0,  0,  0,  1,  0] [ 6,  6,  0]  1 */
    43286115, /* 58589 (1529) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 3,  3,  3] -1 */
    61709403, /* 58590 (1529) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 9,  9,  3] -1 */
    35563818, /* 58591 (1529) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  6] -1 */
    43293247, /* 58592 (1529) [ 0,  0,  1, -1,  0,  0,  0,  1,  0] [ 3,  3,  3] -1 */
    61716535, /* 58593 (1529) [ 0,  0,  1, -1,  0,  0,  0,  1,  0] [ 9,  9,  3] -1 */
    52443184, /* 58594 (1529) [ 0, -1,  0,  0,  0,  1, -1,  0,  0] [ 6,  6,  0] -1 */
       12064, /* 58595 (1529) [ 0,  1,  0,  0,  0,  1,  1,  0,  0] [ 0,  0,  0]  1 */
    27697343, /* 58596 (1529) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 9,  9,  3]  1 */
     9281503, /* 58597 (1529) [ 0,  0,  1,  1,  0,  0,  0, -1,  0] [ 3,  3,  3]  1 */
     1551758, /* 58598 (1529) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
    17133562, /* 58599 (1529) [ 0,  0, -1,  1,  0,  0,  0, -1,  0] [ 6,  0,  6]  1 */
    51148498, /* 58600 (1529) [ 0,  1,  0,  0,  0,  1,  1,  0,  0] [ 6,  0,  6] -1 */
    17131846, /* 58601 (1529) [ 0, -1,  0,  0,  0, -1,  1,  0,  0] [ 6,  0,  6]  1 */
    18433612, /* 58602 (1529) [ 0,  0,  1, -1,  0,  0,  0, -1,  0] [ 6,  6,  0]  1 */
       11992, /* 58603 (1529) [ 0,  1,  0,  0,  0, -1, -1,  0,  0] [ 0,  0,  0]  1 */
    51147250, /* 58604 (1529) [ 0,  0,  1,  1,  0,  0,  0,  1,  0] [ 6,  0,  6] -1 */
    60417937, /* 58605 (1529) [ 0,  0,  1,  1,  0,  0,  0, -1,  0] [ 9,  3,  9] -1 */
    51145306, /* 58606 (1529) [ 0,  0, -1, -1,  0,  0,  0,  1,  0] [ 6,  0,  6] -1 */
    44825809, /* 58607 (1529) [ 0, -1,  0,  0,  0, -1, -1,  0,  0] [ 3,  9,  9] -1 */
    26411225, /* 58608 (1529) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 9,  3,  9]  1 */
        7672, /* 58609 (1529) [ 0, -1,  0,  0,  0,  1, -1,  0,  0] [ 0,  0,  0]  1 */
     1546090, /* 58610 (1529) [ 0,  0,  1,  1,  0,  0,  0,  1,  0] [ 0,  6,  6]  1 */
    44821389, /* 58611 (1529) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 3,  9,  9] -1 */
    27710463, /* 58612 (1529) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 9,  9,  3]  1 */
    35555134, /* 58613 (1529) [ 0, -1,  0,  0,  0, -1,  1,  0,  0] [ 0,  6,  6] -1 */
     9282739, /* 58614 (1529) [ 0,  1,  0,  0,  0,  1, -1,  0,  0] [ 3,  3,  3]  1 */
    27701671, /* 58615 (1529) [ 0, -1,  0,  0,  0,  1,  1,  0,  0] [ 9,  9,  3]  1 */
    60410489, /* 58616 (1529) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 9,  3,  9] -1 */
    51148426, /* 58617 (1529) [ 0,  1,  0,  0,  0, -1, -1,  0,  0] [ 6,  0,  6] -1 */
    44827549, /* 58618 (1529) [ 0,  0, -1,  1,  0,  0,  0,  1,  0] [ 3,  9,  9] -1 */
    61718251, /* 58619 (1529) [ 0,  1,  0,  0,  0,  1, -1,  0,  0] [ 9,  9,  3] -1 */
    34015424, /* 58620 (1529) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    51139794, /* 58621 (1529) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6] -1 */
    35557822, /* 58622 (1529) [ 0,  0,  1, -1,  0,  0,  0, -1,  0] [ 0,  6,  6] -1 */
    51146758, /* 58623 (1529) [ 0,  0,  1, -1,  0,  0,  0, -1,  0] [ 6,  0,  6] -1 */
    34015584, /* 58624 (1529) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    44830201, /* 58625 (1529) [ 0,  1,  0,  0,  0, -1,  1,  0,  0] [ 3,  9,  9] -1 */
    26403769, /* 58626 (1529) [ 0,  0, -1, -1,  0,  0,  0, -1,  0] [ 9,  3,  9]  1 */
    35550698, /* 58627 (1529) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
        9352, /* 58628 (1529) [ 0,  0, -1,  1,  0,  0,  0, -1,  0] [ 0,  0,  0]  1 */
    10822449, /* 58629 (1529) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 3,  9,  9]  1 */
    18435280, /* 58630 (1529) [ 0,  1,  0,  0,  0, -1, -1,  0,  0] [ 6,  6,  0]  1 */
    27703339, /* 58631 (1529) [ 0,  0, -1,  1,  0,  0,  0,  1,  0] [ 9,  9,  3]  1 */
    61715071, /* 58632 (1529) [ 0,  0, -1, -1,  0,  0,  0, -1,  0] [ 9,  9,  3] -1 */
    43299239, /* 58633 (1529) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 3,  3,  3] -1 */
     9274055, /* 58634 (1529) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 3,  3,  3]  1 */
        8872, /* 58635 (1529) [ 0,  0, -1, -1,  0,  0,  0,  1,  0] [ 0,  0,  0]  1 */
    34028544, /* 58636 (1529) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
     9278311, /* 58637 (1529) [ 0, -1,  0,  0,  0, -1, -1,  0,  0] [ 3,  3,  3]  1 */
    27701599, /* 58638 (1529) [ 0, -1,  0,  0,  0, -1, -1,  0,  0] [ 9,  9,  3]  1 */
    10809329, /* 58639 (1529) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 3,  9,  9]  1 */
    52438872, /* 58640 (1529) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
    61722527, /* 58641 (1529) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 9,  9,  3] -1 */
    51144106, /* 58642 (1529) [ 0, -1,  0,  0,  0,  1, -1,  0,  0] [ 6,  0,  6] -1 */
    60423609, /* 58643 (1529) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 9,  3,  9] -1 */
    44828521, /* 58644 (1529) [ 0,  0,  1, -1,  0,  0,  0,  1,  0] [ 3,  9,  9] -1 */
    61717015, /* 58645 (1529) [ 0,  0,  1,  1,  0,  0,  0, -1,  0] [ 9,  9,  3] -1 */
    18432640, /* 58646 (1529) [ 0,  0, -1,  1,  0,  0,  0, -1,  0] [ 6,  6,  0]  1 */
    18430924, /* 58647 (1529) [ 0, -1,  0,  0,  0, -1,  1,  0,  0] [ 6,  6,  0]  1 */
    27697179, /* 58648 (1529) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 9,  9,  3]  1 */
     1551594, /* 58649 (1529) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
     1542946, /* 58650 (1529) [ 0, -1,  0,  0,  0,  1, -1,  0,  0] [ 0,  6,  6]  1 */
    17140530, /* 58651 (1529) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  6]  1 */
    27704311, /* 58652 (1529) [ 0,  0,  1, -1,  0,  0,  0,  1,  0] [ 9,  9,  3]  1 */
    51139634, /* 58653 (1529) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
    26406913, /* 58654 (1529) [ 0,  1,  0,  0,  0, -1,  1,  0,  0] [ 9,  3,  9]  1 */
     1538634, /* 58655 (1529) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
    43290607, /* 58656 (1529) [ 0, -1,  0,  0,  0,  1,  1,  0,  0] [ 3,  3,  3] -1 */
    60414745, /* 58657 (1529) [ 0, -1,  0,  0,  0, -1, -1,  0,  0] [ 9,  3,  9] -1 */
    60414817, /* 58658 (1529) [ 0, -1,  0,  0,  0,  1,  1,  0,  0] [ 9,  3,  9] -1 */
     1547338, /* 58659 (1529) [ 0,  1,  0,  0,  0,  1,  1,  0,  0] [ 0,  6,  6]  1 */
    34019860, /* 58660 (1529) [ 0, -1,  0,  0,  0, -1,  1,  0,  0] [ 0,  0,  0] -1 */
    17135026, /* 58661 (1529) [ 0,  0,  1,  1,  0,  0,  0,  1,  0] [ 6,  0,  6]  1 */
    18432160, /* 58662 (1529) [ 0,  0, -1, -1,  0,  0,  0,  1,  0] [ 6,  6,  0]  1 */
    44827057, /* 58663 (1529) [ 0,  0, -1, -1,  0,  0,  0, -1,  0] [ 3,  9,  9] -1 */
    17133082, /* 58664 (1529) [ 0,  0, -1, -1,  0,  0,  0,  1,  0] [ 6,  0,  6]  1 */
    10813585, /* 58665 (1529) [ 0, -1,  0,  0,  0, -1, -1,  0,  0] [ 3,  9,  9]  1 */
    44829001, /* 58666 (1529) [ 0,  0,  1,  1,  0,  0,  0, -1,  0] [ 3,  9,  9] -1 */
    60416485, /* 58667 (1529) [ 0,  0, -1,  1,  0,  0,  0,  1,  0] [ 9,  3,  9] -1 */
    43293727, /* 58668 (1529) [ 0,  0,  1,  1,  0,  0,  0, -1,  0] [ 3,  3,  3] -1 */
    35556370, /* 58669 (1529) [ 0,  0, -1, -1,  0,  0,  0,  1,  0] [ 0,  6,  6] -1 */
    10813657, /* 58670 (1529) [ 0, -1,  0,  0,  0,  1,  1,  0,  0] [ 3,  9,  9]  1 */
    10809165, /* 58671 (1529) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 3,  9,  9]  1 */
    35556850, /* 58672 (1529) [ 0,  0, -1,  1,  0,  0,  0, -1,  0] [ 0,  6,  6] -1 */
    35559490, /* 58673 (1529) [ 0,  1,  0,  0,  0, -1, -1,  0,  0] [ 0,  6,  6] -1 */
    52451832, /* 58674 (1529) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
    60417457, /* 58675 (1529) [ 0,  0,  1, -1,  0,  0,  0,  1,  0] [ 9,  3,  9] -1 */
    26398265, /* 58676 (1529) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 9,  3,  9]  1 */
    34022548, /* 58677 (1529) [ 0,  0,  1, -1,  0,  0,  0, -1,  0] [ 0,  0,  0] -1 */
    43294927, /* 58678 (1529) [ 0,  1,  0,  0,  0, -1,  1,  0,  0] [ 3,  3,  3] -1 */
     9280051, /* 58679 (1529) [ 0,  0, -1,  1,  0,  0,  0,  1,  0] [ 3,  3,  3]  1 */
    43291783, /* 58680 (1529) [ 0,  0, -1, -1,  0,  0,  0, -1,  0] [ 3,  3,  3] -1 */
    10815325, /* 58681 (1529) [ 0,  0, -1,  1,  0,  0,  0,  1,  0] [ 3,  9,  9]  1 */
    27706027, /* 58682 (1529) [ 0,  1,  0,  0,  0,  1, -1,  0,  0] [ 9,  9,  3]  1 */
       16484, /* 58683 (1530) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    61722687, /* 58684 (1530) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 9,  9,  3] -1 */
    44834513, /* 58685 (1530) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 3,  9,  9] -1 */
    44830237, /* 58686 (1530) [ 0,  1,  0,  0,  0,  1, -1,  0,  0] [ 3,  9,  9] -1 */
    17127570, /* 58687 (1530) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6]  1 */
    17140694, /* 58688 (1530) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
    17134534, /* 58689 (1530) [ 0,  0,  1, -1,  0,  0,  0, -1,  0] [ 6,  0,  6]  1 */
    43294963, /* 58690 (1530) [ 0,  1,  0,  0,  0,  1, -1,  0,  0] [ 3,  3,  3] -1 */
     1538474, /* 58691 (1530) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
    61713895, /* 58692 (1530) [ 0, -1,  0,  0,  0,  1,  1,  0,  0] [ 9,  9,  3] -1 */
    60410325, /* 58693 (1530) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 9,  3,  9] -1 */
    18430960, /* 58694 (1530) [ 0, -1,  0,  0,  0,  1, -1,  0,  0] [ 6,  6,  0]  1 */
       16320, /* 58695 (1530) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    18426648, /* 58696 (1530) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
    17131882, /* 58697 (1530) [ 0, -1,  0,  0,  0,  1, -1,  0,  0] [ 6,  0,  6]  1 */
    17136274, /* 58698 (1530) [ 0,  1,  0,  0,  0,  1,  1,  0,  0] [ 6,  0,  6]  1 */
    43299399, /* 58699 (1530) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 3,  3,  3] -1 */
    43286279, /* 58700 (1530) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 3,  3,  3] -1 */
    61709567, /* 58701 (1530) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 9,  9,  3] -1 */
        7636, /* 58702 (1530) [ 0, -1,  0,  0,  0, -1,  1,  0,  0] [ 0,  0,  0]  1 */
     1542910, /* 58703 (1530) [ 0, -1,  0,  0,  0, -1,  1,  0,  0] [ 0,  6,  6]  1 */
    60419137, /* 58704 (1530) [ 0,  1,  0,  0,  0, -1,  1,  0,  0] [ 9,  3,  9] -1 */
     1544146, /* 58705 (1530) [ 0,  0, -1, -1,  0,  0,  0,  1,  0] [ 0,  6,  6]  1 */
    60423449, /* 58706 (1530) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 9,  3,  9] -1 */
     1544626, /* 58707 (1530) [ 0,  0, -1,  1,  0,  0,  0, -1,  0] [ 0,  6,  6]  1 */
     1547266, /* 58708 (1530) [ 0,  1,  0,  0,  0, -1, -1,  0,  0] [ 0,  6,  6]  1 */
    17136202, /* 58709 (1530) [ 0,  1,  0,  0,  0, -1, -1,  0,  0] [ 6,  0,  6]  1 */
        3200, /* 58710 (1530) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
     1545598, /* 58711 (1530) [ 0,  0,  1, -1,  0,  0,  0, -1,  0] [ 0,  6,  6]  1 */
    18439608, /* 58712 (1530) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
        3360, /* 58713 (1530) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
       10324, /* 58714 (1530) [ 0,  0,  1, -1,  0,  0,  0, -1,  0] [ 0,  0,  0]  1 */
    44825881, /* 58715 (1530) [ 0, -1,  0,  0,  0,  1,  1,  0,  0] [ 3,  9,  9] -1 */
    18439772, /* 58716 (1530) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    60415993, /* 58717 (1530) [ 0,  0, -1, -1,  0,  0,  0, -1,  0] [ 9,  3,  9] -1 */
    17127410, /* 58718 (1530) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
    44834673, /* 58719 (1530) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 3,  9,  9] -1 */
    43292275, /* 58720 (1530) [ 0,  0, -1,  1,  0,  0,  0,  1,  0] [ 3,  3,  3] -1 */
    18426488, /* 58721 (1530) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    61715563, /* 58722 (1530) [ 0,  0, -1,  1,  0,  0,  0,  1,  0] [ 9,  9,  3] -1 */
    43290535, /* 58723 (1530) [ 0, -1,  0,  0,  0, -1, -1,  0,  0] [ 3,  3,  3] -1 */
    61713823, /* 58724 (1530) [ 0, -1,  0,  0,  0, -1, -1,  0,  0] [ 9,  9,  3] -1 */
    44821553, /* 58725 (1530) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 3,  9,  9] -1 */
    18435352, /* 58726 (1530) [ 0,  1,  0,  0,  0,  1,  1,  0,  0] [ 6,  6,  0]  1 */
    61718215, /* 58727 (1530) [ 0,  1,  0,  0,  0, -1,  1,  0,  0] [ 9,  9,  3] -1 */
    60419173, /* 58728 (1530) [ 0,  1,  0,  0,  0,  1, -1,  0,  0] [ 9,  3,  9] -1 */
       10816, /* 58729 (1530) [ 0,  0,  1,  1,  0,  0,  0,  1,  0] [ 0,  0,  0]  1 */
    43286115, /* 58730 (1530) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 3,  3,  3] -1 */
    18434104, /* 58731 (1530) [ 0,  0,  1,  1,  0,  0,  0,  1,  0] [ 6,  6,  0]  1 */
    61709403, /* 58732 (1530) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 9,  9,  3] -1 */
    43293247, /* 58733 (1530) [ 0,  0,  1, -1,  0,  0,  0,  1,  0] [ 3,  3,  3] -1 */
    61716535, /* 58734 (1530) [ 0,  0,  1, -1,  0,  0,  0,  1,  0] [ 9,  9,  3] -1 */
       12064, /* 58735 (1530) [ 0,  1,  0,  0,  0,  1,  1,  0,  0] [ 0,  0,  0]  1 */
     1551758, /* 58736 (1530) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
    17133562, /* 58737 (1530) [ 0,  0, -1,  1,  0,  0,  0, -1,  0] [ 6,  0,  6]  1 */
    17131846, /* 58738 (1530) [ 0, -1,  0,  0,  0, -1,  1,  0,  0] [ 6,  0,  6]  1 */
    18433612, /* 58739 (1530) [ 0,  0,  1, -1,  0,  0,  0, -1,  0] [ 6,  6,  0]  1 */
       11992, /* 58740 (1530) [ 0,  1,  0,  0,  0, -1, -1,  0,  0] [ 0,  0,  0]  1 */
    60417937, /* 58741 (1530) [ 0,  0,  1,  1,  0,  0,  0, -1,  0] [ 9,  3,  9] -1 */
    44825809, /* 58742 (1530) [ 0, -1,  0,  0,  0, -1, -1,  0,  0] [ 3,  9,  9] -1 */
        7672, /* 58743 (1530) [ 0, -1,  0,  0,  0,  1, -1,  0,  0] [ 0,  0,  0]  1 */
     1546090, /* 58744 (1530) [ 0,  0,  1,  1,  0,  0,  0,  1,  0] [ 0,  6,  6]  1 */
    44821389, /* 58745 (1530) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 3,  9,  9] -1 */
    60410489, /* 58746 (1530) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 9,  3,  9] -1 */
    44827549, /* 58747 (1530) [ 0,  0, -1,  1,  0,  0,  0,  1,  0] [ 3,  9,  9] -1 */
    61718251, /* 58748 (1530) [ 0,  1,  0,  0,  0,  1, -1,  0,  0] [ 9,  9,  3] -1 */
    44830201, /* 58749 (1530) [ 0,  1,  0,  0,  0, -1,  1,  0,  0] [ 3,  9,  9] -1 */
        9352, /* 58750 (1530) [ 0,  0, -1,  1,  0,  0,  0, -1,  0] [ 0,  0,  0]  1 */
    18435280, /* 58751 (1530) [ 0,  1,  0,  0,  0, -1, -1,  0,  0] [ 6,  6,  0]  1 */
    61715071, /* 58752 (1530) [ 0,  0, -1, -1,  0,  0,  0, -1,  0] [ 9,  9,  3] -1 */
    43299239, /* 58753 (1530) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 3,  3,  3] -1 */
    61722527, /* 58754 (1530) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 9,  9,  3] -1 */
    44828521, /* 58755 (1530) [ 0,  0,  1, -1,  0,  0,  0,  1,  0] [ 3,  9,  9] -1 */
        8872, /* 58756 (1530) [ 0,  0, -1, -1,  0,  0,  0,  1,  0] [ 0,  0,  0]  1 */
    60423609, /* 58757 (1530) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 9,  3,  9] -1 */
    61717015, /* 58758 (1530) [ 0,  0,  1,  1,  0,  0,  0, -1,  0] [ 9,  9,  3] -1 */
    18432640, /* 58759 (1530) [ 0,  0, -1,  1,  0,  0,  0, -1,  0] [ 6,  6,  0]  1 */
    18430924, /* 58760 (1530) [ 0, -1,  0,  0,  0, -1,  1,  0,  0] [ 6,  6,  0]  1 */
     1551594, /* 58761 (1530) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
     1542946, /* 58762 (1530) [ 0, -1,  0,  0,  0,  1, -1,  0,  0] [ 0,  6,  6]  1 */
    17140530, /* 58763 (1530) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  6]  1 */
    43290607, /* 58764 (1530) [ 0, -1,  0,  0,  0,  1,  1,  0,  0] [ 3,  3,  3] -1 */
     1538634, /* 58765 (1530) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
    60414745, /* 58766 (1530) [ 0, -1,  0,  0,  0, -1, -1,  0,  0] [ 9,  3,  9] -1 */
    60414817, /* 58767 (1530) [ 0, -1,  0,  0,  0,  1,  1,  0,  0] [ 9,  3,  9] -1 */
     1547338, /* 58768 (1530) [ 0,  1,  0,  0,  0,  1,  1,  0,  0] [ 0,  6,  6]  1 */
    17135026, /* 58769 (1530) [ 0,  0,  1,  1,  0,  0,  0,  1,  0] [ 6,  0,  6]  1 */
    18432160, /* 58770 (1530) [ 0,  0, -1, -1,  0,  0,  0,  1,  0] [ 6,  6,  0]  1 */
    44827057, /* 58771 (1530) [ 0,  0, -1, -1,  0,  0,  0, -1,  0] [ 3,  9,  9] -1 */
    17133082, /* 58772 (1530) [ 0,  0, -1, -1,  0,  0,  0,  1,  0] [ 6,  0,  6]  1 */
    44829001, /* 58773 (1530) [ 0,  0,  1,  1,  0,  0,  0, -1,  0] [ 3,  9,  9] -1 */
    60416485, /* 58774 (1530) [ 0,  0, -1,  1,  0,  0,  0,  1,  0] [ 9,  3,  9] -1 */
    43293727, /* 58775 (1530) [ 0,  0,  1,  1,  0,  0,  0, -1,  0] [ 3,  3,  3] -1 */
    60417457, /* 58776 (1530) [ 0,  0,  1, -1,  0,  0,  0,  1,  0] [ 9,  3,  9] -1 */
    43294927, /* 58777 (1530) [ 0,  1,  0,  0,  0, -1,  1,  0,  0] [ 3,  3,  3] -1 */
    43291783, /* 58778 (1530) [ 0,  0, -1, -1,  0,  0,  0, -1,  0] [ 3,  3,  3] -1 */
       16484, /* 58779 (1531) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    17127570, /* 58780 (1531) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6]  1 */
    17140694, /* 58781 (1531) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
    17134534, /* 58782 (1531) [ 0,  0,  1, -1,  0,  0,  0, -1,  0] [ 6,  0,  6]  1 */
    27705991, /* 58783 (1531) [ 0,  1,  0,  0,  0, -1,  1,  0,  0] [ 9,  9,  3]  1 */
    61831993, /* 58784 (1531) [ 0, -1,  0,  0,  0,  1,  1,  0,  0] [ 9,  9,  9] -1 */
    26406949, /* 58785 (1531) [ 0,  1,  0,  0,  0,  1, -1,  0,  0] [ 9,  3,  9]  1 */
     1538474, /* 58786 (1531) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
    60296719, /* 58787 (1531) [ 0, -1,  0,  0,  0,  1,  1,  0,  0] [ 9,  3,  3] -1 */
     9273891, /* 58788 (1531) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 3,  3,  3]  1 */
     9281023, /* 58789 (1531) [ 0,  0,  1, -1,  0,  0,  0,  1,  0] [ 3,  3,  3]  1 */
    52556810, /* 58790 (1531) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    18430960, /* 58791 (1531) [ 0, -1,  0,  0,  0,  1, -1,  0,  0] [ 6,  6,  0]  1 */
       16320, /* 58792 (1531) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    27710303, /* 58793 (1531) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 9,  9,  3]  1 */
    10816297, /* 58794 (1531) [ 0,  0,  1, -1,  0,  0,  0,  1,  0] [ 3,  9,  9]  1 */
    18426648, /* 58795 (1531) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
    17131882, /* 58796 (1531) [ 0, -1,  0,  0,  0,  1, -1,  0,  0] [ 6,  0,  6]  1 */
    44708959, /* 58797 (1531) [ 0,  0, -1, -1,  0,  0,  0, -1,  0] [ 3,  9,  3] -1 */
    26411385, /* 58798 (1531) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 9,  3,  9]  1 */
    51034820, /* 58799 (1531) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  0] -1 */
    17136274, /* 58800 (1531) [ 0,  1,  0,  0,  0,  1,  1,  0,  0] [ 6,  0,  6]  1 */
    27704791, /* 58801 (1531) [ 0,  0,  1,  1,  0,  0,  0, -1,  0] [ 9,  9,  3]  1 */
    43417497, /* 58802 (1531) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 3,  3,  9] -1 */
    60298387, /* 58803 (1531) [ 0,  0, -1,  1,  0,  0,  0,  1,  0] [ 9,  3,  3] -1 */
    26405713, /* 58804 (1531) [ 0,  0,  1,  1,  0,  0,  0, -1,  0] [ 9,  3,  9]  1 */
    35438272, /* 58805 (1531) [ 0,  0, -1, -1,  0,  0,  0,  1,  0] [ 0,  6,  0] -1 */
     9278383, /* 58806 (1531) [ 0, -1,  0,  0,  0,  1,  1,  0,  0] [ 3,  3,  3]  1 */
    26402521, /* 58807 (1531) [ 0, -1,  0,  0,  0, -1, -1,  0,  0] [ 9,  3,  9]  1 */
    61831921, /* 58808 (1531) [ 0, -1,  0,  0,  0, -1, -1,  0,  0] [ 9,  9,  9] -1 */
    34142314, /* 58809 (1531) [ 0,  1,  0,  0,  0, -1, -1,  0,  0] [ 0,  0,  6] -1 */
        7636, /* 58810 (1531) [ 0, -1,  0,  0,  0, -1,  1,  0,  0] [ 0,  0,  0]  1 */
    60292227, /* 58811 (1531) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 9,  3,  3] -1 */
    43410373, /* 58812 (1531) [ 0,  0, -1,  1,  0,  0,  0,  1,  0] [ 3,  3,  9] -1 */
    35445884, /* 58813 (1531) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  0] -1 */
    61833661, /* 58814 (1531) [ 0,  0, -1,  1,  0,  0,  0,  1,  0] [ 9,  9,  9] -1 */
    34139194, /* 58815 (1531) [ 0,  0, -1, -1,  0,  0,  0,  1,  0] [ 0,  0,  6] -1 */
    60299359, /* 58816 (1531) [ 0,  0,  1, -1,  0,  0,  0,  1,  0] [ 9,  3,  3] -1 */
    43408633, /* 58817 (1531) [ 0, -1,  0,  0,  0, -1, -1,  0,  0] [ 3,  3,  9] -1 */
     1542910, /* 58818 (1531) [ 0, -1,  0,  0,  0, -1,  1,  0,  0] [ 0,  6,  6]  1 */
    34140646, /* 58819 (1531) [ 0,  0,  1, -1,  0,  0,  0, -1,  0] [ 0,  0,  6] -1 */
    61834633, /* 58820 (1531) [ 0,  0,  1, -1,  0,  0,  0,  1,  0] [ 9,  9,  9] -1 */
    35432760, /* 58821 (1531) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  0] -1 */
    10816777, /* 58822 (1531) [ 0,  0,  1,  1,  0,  0,  0, -1,  0] [ 3,  9,  9]  1 */
    61836313, /* 58823 (1531) [ 0,  1,  0,  0,  0, -1,  1,  0,  0] [ 9,  9,  9] -1 */
    26404261, /* 58824 (1531) [ 0,  0, -1,  1,  0,  0,  0,  1,  0] [ 9,  3,  9]  1 */
     1544146, /* 58825 (1531) [ 0,  0, -1, -1,  0,  0,  0,  1,  0] [ 0,  6,  6]  1 */
    43404213, /* 58826 (1531) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 3,  3,  9] -1 */
     1544626, /* 58827 (1531) [ 0,  0, -1,  1,  0,  0,  0, -1,  0] [ 0,  6,  6]  1 */
     1547266, /* 58828 (1531) [ 0,  1,  0,  0,  0, -1, -1,  0,  0] [ 0,  6,  6]  1 */
    35445720, /* 58829 (1531) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  0] -1 */
    44716415, /* 58830 (1531) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 3,  9,  3] -1 */
    35441464, /* 58831 (1531) [ 0,  1,  0,  0,  0,  1,  1,  0,  0] [ 0,  6,  0] -1 */
    51034656, /* 58832 (1531) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  0] -1 */
    17136202, /* 58833 (1531) [ 0,  1,  0,  0,  0, -1, -1,  0,  0] [ 6,  0,  6]  1 */
    52562482, /* 58834 (1531) [ 0,  0, -1, -1,  0,  0,  0,  1,  0] [ 6,  6,  6] -1 */
    52561282, /* 58835 (1531) [ 0, -1,  0,  0,  0,  1, -1,  0,  0] [ 6,  6,  6] -1 */
    35440216, /* 58836 (1531) [ 0,  0,  1,  1,  0,  0,  0,  1,  0] [ 0,  6,  0] -1 */
        3200, /* 58837 (1531) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    44710903, /* 58838 (1531) [ 0,  0,  1,  1,  0,  0,  0, -1,  0] [ 3,  9,  3] -1 */
     1545598, /* 58839 (1531) [ 0,  0,  1, -1,  0,  0,  0, -1,  0] [ 0,  6,  6]  1 */
    18439608, /* 58840 (1531) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
    26405233, /* 58841 (1531) [ 0,  0,  1, -1,  0,  0,  0,  1,  0] [ 9,  3,  9]  1 */
        3360, /* 58842 (1531) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
       10324, /* 58843 (1531) [ 0,  0,  1, -1,  0,  0,  0, -1,  0] [ 0,  0,  0]  1 */
    10817977, /* 58844 (1531) [ 0,  1,  0,  0,  0, -1,  1,  0,  0] [ 3,  9,  9]  1 */
     9282703, /* 58845 (1531) [ 0,  1,  0,  0,  0, -1,  1,  0,  0] [ 3,  3,  3]  1 */
     9279559, /* 58846 (1531) [ 0,  0, -1, -1,  0,  0,  0, -1,  0] [ 3,  3,  3]  1 */
    27702847, /* 58847 (1531) [ 0,  0, -1, -1,  0,  0,  0, -1,  0] [ 9,  9,  3]  1 */
     9287015, /* 58848 (1531) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 3,  3,  3]  1 */
    10822289, /* 58849 (1531) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 3,  9,  9]  1 */
    10818013, /* 58850 (1531) [ 0,  1,  0,  0,  0,  1, -1,  0,  0] [ 3,  9,  9]  1 */
    34146806, /* 58851 (1531) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    52565602, /* 58852 (1531) [ 0,  1,  0,  0,  0, -1, -1,  0,  0] [ 6,  6,  6] -1 */
    18439772, /* 58853 (1531) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    26398101, /* 58854 (1531) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 9,  3,  9]  1 */
    17127410, /* 58855 (1531) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
    18426488, /* 58856 (1531) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    26402593, /* 58857 (1531) [ 0, -1,  0,  0,  0,  1,  1,  0,  0] [ 9,  3,  9]  1 */
    52562962, /* 58858 (1531) [ 0,  0, -1,  1,  0,  0,  0, -1,  0] [ 6,  6,  6] -1 */
    44712139, /* 58859 (1531) [ 0,  1,  0,  0,  0,  1, -1,  0,  0] [ 3,  9,  3] -1 */
    52563934, /* 58860 (1531) [ 0,  0,  1, -1,  0,  0,  0, -1,  0] [ 6,  6,  6] -1 */
    51021536, /* 58861 (1531) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  0] -1 */
    60296647, /* 58862 (1531) [ 0, -1,  0,  0,  0, -1, -1,  0,  0] [ 9,  3,  3] -1 */
    18435352, /* 58863 (1531) [ 0,  1,  0,  0,  0,  1,  1,  0,  0] [ 6,  6,  0]  1 */
    10814833, /* 58864 (1531) [ 0,  0, -1, -1,  0,  0,  0, -1,  0] [ 3,  9,  9]  1 */
    61827501, /* 58865 (1531) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 9,  9,  9] -1 */
     9287175, /* 58866 (1531) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 3,  3,  3]  1 */
    60297895, /* 58867 (1531) [ 0,  0, -1, -1,  0,  0,  0, -1,  0] [ 9,  3,  3] -1 */
       10816, /* 58868 (1531) [ 0,  0,  1,  1,  0,  0,  0,  1,  0] [ 0,  0,  0]  1 */
    18434104, /* 58869 (1531) [ 0,  0,  1,  1,  0,  0,  0,  1,  0] [ 6,  6,  0]  1 */
    44716575, /* 58870 (1531) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 3,  9,  3] -1 */
    60305351, /* 58871 (1531) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 9,  3,  3] -1 */
    51021696, /* 58872 (1531) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  0] -1 */
    43411345, /* 58873 (1531) [ 0,  0,  1, -1,  0,  0,  0,  1,  0] [ 3,  3,  9] -1 */
    61840625, /* 58874 (1531) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 9,  9,  9] -1 */
    51028660, /* 58875 (1531) [ 0,  0,  1, -1,  0,  0,  0, -1,  0] [ 6,  0,  0] -1 */
    34137994, /* 58876 (1531) [ 0, -1,  0,  0,  0,  1, -1,  0,  0] [ 0,  0,  6] -1 */
       12064, /* 58877 (1531) [ 0,  1,  0,  0,  0,  1,  1,  0,  0] [ 0,  0,  0]  1 */
    27697343, /* 58878 (1531) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 9,  9,  3]  1 */
     9281503, /* 58879 (1531) [ 0,  0,  1,  1,  0,  0,  0, -1,  0] [ 3,  3,  3]  1 */
    60301039, /* 58880 (1531) [ 0,  1,  0,  0,  0, -1,  1,  0,  0] [ 9,  3,  3] -1 */
     1551758, /* 58881 (1531) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
    17133562, /* 58882 (1531) [ 0,  0, -1,  1,  0,  0,  0, -1,  0] [ 6,  0,  6]  1 */
    17131846, /* 58883 (1531) [ 0, -1,  0,  0,  0, -1,  1,  0,  0] [ 6,  0,  6]  1 */
    18433612, /* 58884 (1531) [ 0,  0,  1, -1,  0,  0,  0, -1,  0] [ 6,  6,  0]  1 */
       11992, /* 58885 (1531) [ 0,  1,  0,  0,  0, -1, -1,  0,  0] [ 0,  0,  0]  1 */
    61835113, /* 58886 (1531) [ 0,  0,  1,  1,  0,  0,  0, -1,  0] [ 9,  9,  9] -1 */
    44707783, /* 58887 (1531) [ 0, -1,  0,  0,  0,  1,  1,  0,  0] [ 3,  9,  3] -1 */
    60299839, /* 58888 (1531) [ 0,  0,  1,  1,  0,  0,  0, -1,  0] [ 9,  3,  3] -1 */
    26411225, /* 58889 (1531) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 9,  3,  9]  1 */
        7672, /* 58890 (1531) [ 0, -1,  0,  0,  0,  1, -1,  0,  0] [ 0,  0,  0]  1 */
    51025972, /* 58891 (1531) [ 0, -1,  0,  0,  0, -1,  1,  0,  0] [ 6,  0,  0] -1 */
    43408705, /* 58892 (1531) [ 0, -1,  0,  0,  0,  1,  1,  0,  0] [ 3,  3,  9] -1 */
     1546090, /* 58893 (1531) [ 0,  0,  1,  1,  0,  0,  0,  1,  0] [ 0,  6,  6]  1 */
    27710463, /* 58894 (1531) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 9,  9,  3]  1 */
    51030400, /* 58895 (1531) [ 0,  1,  0,  0,  0,  1,  1,  0,  0] [ 6,  0,  0] -1 */
     9282739, /* 58896 (1531) [ 0,  1,  0,  0,  0,  1, -1,  0,  0] [ 3,  3,  3]  1 */
    34139674, /* 58897 (1531) [ 0,  0, -1,  1,  0,  0,  0, -1,  0] [ 0,  0,  6] -1 */
    27701671, /* 58898 (1531) [ 0, -1,  0,  0,  0,  1,  1,  0,  0] [ 9,  9,  3]  1 */
    51030328, /* 58899 (1531) [ 0,  1,  0,  0,  0, -1, -1,  0,  0] [ 6,  0,  0] -1 */
    51027208, /* 58900 (1531) [ 0,  0, -1, -1,  0,  0,  0,  1,  0] [ 6,  0,  0] -1 */
    60292391, /* 58901 (1531) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 9,  3,  3] -1 */
    44703455, /* 58902 (1531) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 3,  9,  3] -1 */
    61836349, /* 58903 (1531) [ 0,  1,  0,  0,  0,  1, -1,  0,  0] [ 9,  9,  9] -1 */
    34133522, /* 58904 (1531) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    60301075, /* 58905 (1531) [ 0,  1,  0,  0,  0,  1, -1,  0,  0] [ 9,  3,  3] -1 */
    35438752, /* 58906 (1531) [ 0,  0, -1,  1,  0,  0,  0, -1,  0] [ 0,  6,  0] -1 */
    35439724, /* 58907 (1531) [ 0,  0,  1, -1,  0,  0,  0, -1,  0] [ 0,  6,  0] -1 */
    26403769, /* 58908 (1531) [ 0,  0, -1, -1,  0,  0,  0, -1,  0] [ 9,  3,  9]  1 */
        9352, /* 58909 (1531) [ 0,  0, -1,  1,  0,  0,  0, -1,  0] [ 0,  0,  0]  1 */
    10822449, /* 58910 (1531) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 3,  9,  9]  1 */
    61833169, /* 58911 (1531) [ 0,  0, -1, -1,  0,  0,  0, -1,  0] [ 9,  9,  9] -1 */
    43417337, /* 58912 (1531) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 3,  3,  9] -1 */
    18435280, /* 58913 (1531) [ 0,  1,  0,  0,  0, -1, -1,  0,  0] [ 6,  6,  0]  1 */
    27703339, /* 58914 (1531) [ 0,  0, -1,  1,  0,  0,  0,  1,  0] [ 9,  9,  3]  1 */
     9274055, /* 58915 (1531) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 3,  3,  3]  1 */
    51026008, /* 58916 (1531) [ 0, -1,  0,  0,  0,  1, -1,  0,  0] [ 6,  0,  0] -1 */
        8872, /* 58917 (1531) [ 0,  0, -1, -1,  0,  0,  0,  1,  0] [ 0,  0,  0]  1 */
     9278311, /* 58918 (1531) [ 0, -1,  0,  0,  0, -1, -1,  0,  0] [ 3,  3,  3]  1 */
    27701599, /* 58919 (1531) [ 0, -1,  0,  0,  0, -1, -1,  0,  0] [ 9,  9,  3]  1 */
    10809329, /* 58920 (1531) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 3,  9,  9]  1 */
    43413025, /* 58921 (1531) [ 0,  1,  0,  0,  0, -1,  1,  0,  0] [ 3,  3,  9] -1 */
    43409881, /* 58922 (1531) [ 0,  0, -1, -1,  0,  0,  0, -1,  0] [ 3,  3,  9] -1 */
    18432640, /* 58923 (1531) [ 0,  0, -1,  1,  0,  0,  0, -1,  0] [ 6,  6,  0]  1 */
    44707711, /* 58924 (1531) [ 0, -1,  0,  0,  0, -1, -1,  0,  0] [ 3,  9,  3] -1 */
    18430924, /* 58925 (1531) [ 0, -1,  0,  0,  0, -1,  1,  0,  0] [ 6,  6,  0]  1 */
    27697179, /* 58926 (1531) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 9,  9,  3]  1 */
     1551594, /* 58927 (1531) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
    43413061, /* 58928 (1531) [ 0,  1,  0,  0,  0,  1, -1,  0,  0] [ 3,  3,  9] -1 */
     1542946, /* 58929 (1531) [ 0, -1,  0,  0,  0,  1, -1,  0,  0] [ 0,  6,  6]  1 */
    17140530, /* 58930 (1531) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  6]  1 */
    27704311, /* 58931 (1531) [ 0,  0,  1, -1,  0,  0,  0,  1,  0] [ 9,  9,  3]  1 */
    26406913, /* 58932 (1531) [ 0,  1,  0,  0,  0, -1,  1,  0,  0] [ 9,  3,  9]  1 */
    44703291, /* 58933 (1531) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 3,  9,  3] -1 */
     1538634, /* 58934 (1531) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
    52570094, /* 58935 (1531) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
     1547338, /* 58936 (1531) [ 0,  1,  0,  0,  0,  1,  1,  0,  0] [ 0,  6,  6]  1 */
    34137958, /* 58937 (1531) [ 0, -1,  0,  0,  0, -1,  1,  0,  0] [ 0,  0,  6] -1 */
    35437036, /* 58938 (1531) [ 0, -1,  0,  0,  0, -1,  1,  0,  0] [ 0,  6,  0] -1 */
    17135026, /* 58939 (1531) [ 0,  0,  1,  1,  0,  0,  0,  1,  0] [ 6,  0,  6]  1 */
    18432160, /* 58940 (1531) [ 0,  0, -1, -1,  0,  0,  0,  1,  0] [ 6,  6,  0]  1 */
    17133082, /* 58941 (1531) [ 0,  0, -1, -1,  0,  0,  0,  1,  0] [ 6,  0,  6]  1 */
    10813585, /* 58942 (1531) [ 0, -1,  0,  0,  0, -1, -1,  0,  0] [ 3,  9,  9]  1 */
    34142386, /* 58943 (1531) [ 0,  1,  0,  0,  0,  1,  1,  0,  0] [ 0,  0,  6] -1 */
    52565674, /* 58944 (1531) [ 0,  1,  0,  0,  0,  1,  1,  0,  0] [ 6,  6,  6] -1 */
    51027688, /* 58945 (1531) [ 0,  0, -1,  1,  0,  0,  0, -1,  0] [ 6,  0,  0] -1 */
    35441392, /* 58946 (1531) [ 0,  1,  0,  0,  0, -1, -1,  0,  0] [ 0,  6,  0] -1 */
    34141138, /* 58947 (1531) [ 0,  0,  1,  1,  0,  0,  0,  1,  0] [ 0,  0,  6] -1 */
    52564426, /* 58948 (1531) [ 0,  0,  1,  1,  0,  0,  0,  1,  0] [ 6,  6,  6] -1 */
    10809165, /* 58949 (1531) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 3,  9,  9]  1 */
    10813657, /* 58950 (1531) [ 0, -1,  0,  0,  0,  1,  1,  0,  0] [ 3,  9,  9]  1 */
    44709451, /* 58951 (1531) [ 0,  0, -1,  1,  0,  0,  0,  1,  0] [ 3,  9,  3] -1 */
    51029152, /* 58952 (1531) [ 0,  0,  1,  1,  0,  0,  0,  1,  0] [ 6,  0,  0] -1 */
    43404377, /* 58953 (1531) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 3,  3,  9] -1 */
    61827665, /* 58954 (1531) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 9,  9,  9] -1 */
    34133682, /* 58955 (1531) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
    43411825, /* 58956 (1531) [ 0,  0,  1,  1,  0,  0,  0, -1,  0] [ 3,  3,  9] -1 */
    35432600, /* 58957 (1531) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  0] -1 */
    52561246, /* 58958 (1531) [ 0, -1,  0,  0,  0, -1,  1,  0,  0] [ 6,  6,  6] -1 */
    26398265, /* 58959 (1531) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 9,  3,  9]  1 */
    52569930, /* 58960 (1531) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    34146642, /* 58961 (1531) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
    44710423, /* 58962 (1531) [ 0,  0,  1, -1,  0,  0,  0,  1,  0] [ 3,  9,  3] -1 */
    52556970, /* 58963 (1531) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    35437072, /* 58964 (1531) [ 0, -1,  0,  0,  0,  1, -1,  0,  0] [ 0,  6,  0] -1 */
    44712103, /* 58965 (1531) [ 0,  1,  0,  0,  0, -1,  1,  0,  0] [ 3,  9,  3] -1 */
    60305511, /* 58966 (1531) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 9,  3,  3] -1 */
     9280051, /* 58967 (1531) [ 0,  0, -1,  1,  0,  0,  0,  1,  0] [ 3,  3,  3]  1 */
    61840785, /* 58968 (1531) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 9,  9,  9] -1 */
    10815325, /* 58969 (1531) [ 0,  0, -1,  1,  0,  0,  0,  1,  0] [ 3,  9,  9]  1 */
    27706027, /* 58970 (1531) [ 0,  1,  0,  0,  0,  1, -1,  0,  0] [ 9,  9,  3]  1 */
       16484, /* 58971 (1528) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
     8565465, /* 58972 (1528) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 3,  0,  3]  1 */
    17140694, /* 58973 (1528) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
    19201249, /* 58974 (1528) [ 0,  0,  1, -1,  0,  0,  0, -1,  0] [ 6,  9,  3]  1 */
    26997403, /* 58975 (1528) [ 0,  1,  0,  0,  0, -1,  1,  0,  0] [ 9,  6,  3]  1 */
    26347900, /* 58976 (1528) [ 0,  1,  0,  0,  0,  1, -1,  0,  0] [ 9,  3,  6]  1 */
    26339054, /* 58977 (1528) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 9,  3,  6]  1 */
        3198, /* 58978 (1528) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
     8572435, /* 58979 (1528) [ 0,  0,  1, -1,  0,  0,  0,  1,  0] [ 3,  0,  3]  1 */
    10105051, /* 58980 (1528) [ 0, -1,  0,  0,  0,  1, -1,  0,  0] [ 3,  6,  9]  1 */
     2319231, /* 58981 (1528) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  9,  9]  1 */
    10107709, /* 58982 (1528) [ 0,  0,  1, -1,  0,  0,  0,  1,  0] [ 3,  6,  9]  1 */
    27001715, /* 58983 (1528) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 9,  6,  3]  1 */
    10100739, /* 58984 (1528) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 3,  6,  9]  1 */
     8569777, /* 58985 (1528) [ 0, -1,  0,  0,  0,  1, -1,  0,  0] [ 3,  0,  3]  1 */
    26352336, /* 58986 (1528) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 9,  3,  6]  1 */
    17136274, /* 58987 (1528) [ 0,  1,  0,  0,  0,  1,  1,  0,  0] [ 6,  0,  6]  1 */
    27645742, /* 58988 (1528) [ 0,  0,  1,  1,  0,  0,  0, -1,  0] [ 9,  9,  0]  1 */
    26346664, /* 58989 (1528) [ 0,  0,  1,  1,  0,  0,  0, -1,  0] [ 9,  3,  6]  1 */
      775327, /* 58990 (1528) [ 0, -1,  0,  0,  0,  1,  1,  0,  0] [ 0,  3,  3]  1 */
    17131828, /* 58991 (1528) [ 0, -1,  0,  0,  0, -1, -1,  0,  0] [ 6,  0,  6]  1 */
    27642568, /* 58992 (1528) [ 0, -1,  0,  0,  0, -1,  1,  0,  0] [ 9,  9,  0]  1 */
    26343490, /* 58993 (1528) [ 0, -1,  0,  0,  0, -1,  1,  0,  0] [ 9,  3,  6]  1 */
    10757728, /* 58994 (1528) [ 0,  0,  1,  1,  0,  0,  0, -1,  0] [ 3,  9,  6]  1 */
    17901205, /* 58995 (1528) [ 0,  0, -1,  1,  0,  0,  0,  1,  0] [ 6,  3,  9]  1 */
    26344726, /* 58996 (1528) [ 0,  0, -1, -1,  0,  0,  0,  1,  0] [ 9,  3,  6]  1 */
    26994745, /* 58997 (1528) [ 0,  0, -1,  1,  0,  0,  0, -1,  0] [ 9,  6,  3]  1 */
      779629, /* 58998 (1528) [ 0,  1,  0,  0,  0, -1, -1,  0,  0] [ 0,  3,  3]  1 */
    19202917, /* 58999 (1528) [ 0,  1,  0,  0,  0, -1, -1,  0,  0] [ 6,  9,  3]  1 */
    27638132, /* 59000 (1528) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 9,  9,  0]  1 */
      777961, /* 59001 (1528) [ 0,  0,  1, -1,  0,  0,  0, -1,  0] [ 0,  3,  3]  1 */
    17908167, /* 59002 (1528) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  3,  9]  1 */
    25696645, /* 59003 (1528) [ 0,  0,  1, -1,  0,  0,  0,  1,  0] [ 9,  0,  9]  1 */
    25689675, /* 59004 (1528) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 9,  0,  9]  1 */
     2313235, /* 59005 (1528) [ 0,  0,  1, -1,  0,  0,  0, -1,  0] [ 0,  9,  9]  1 */
    10109389, /* 59006 (1528) [ 0,  1,  0,  0,  0, -1,  1,  0,  0] [ 3,  6,  9]  1 */
     8574115, /* 59007 (1528) [ 0,  1,  0,  0,  0, -1,  1,  0,  0] [ 3,  0,  3]  1 */
        8866, /* 59008 (1528) [ 0,  0, -1, -1,  0,  0,  0, -1,  0] [ 0,  0,  0]  1 */
    18432154, /* 59009 (1528) [ 0,  0, -1, -1,  0,  0,  0, -1,  0] [ 6,  6,  0]  1 */
     8578427, /* 59010 (1528) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 3,  0,  3]  1 */
    10113701, /* 59011 (1528) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 3,  6,  9]  1 */
    10758964, /* 59012 (1528) [ 0,  1,  0,  0,  0,  1, -1,  0,  0] [ 3,  9,  6]  1 */
    18439772, /* 59013 (1528) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    17127408, /* 59014 (1528) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  6]  1 */
    10750118, /* 59015 (1528) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 3,  9,  6]  1 */
     9214844, /* 59016 (1528) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 3,  3,  0]  1 */
    17899537, /* 59017 (1528) [ 0, -1,  0,  0,  0,  1,  1,  0,  0] [ 6,  3,  9]  1 */
    18435352, /* 59018 (1528) [ 0,  1,  0,  0,  0,  1,  1,  0,  0] [ 6,  6,  0]  1 */
     1544140, /* 59019 (1528) [ 0,  0, -1, -1,  0,  0,  0, -1,  0] [ 0,  6,  6]  1 */
     9228126, /* 59020 (1528) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 3,  3,  0]  1 */
       10816, /* 59021 (1528) [ 0,  0,  1,  1,  0,  0,  0,  1,  0] [ 0,  0,  0]  1 */
    18434104, /* 59022 (1528) [ 0,  0,  1,  1,  0,  0,  0,  1,  0] [ 6,  6,  0]  1 */
       12064, /* 59023 (1528) [ 0,  1,  0,  0,  0,  1,  1,  0,  0] [ 0,  0,  0]  1 */
    19194287, /* 59024 (1528) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  9,  3]  1 */
     9222454, /* 59025 (1528) [ 0,  0,  1,  1,  0,  0,  0, -1,  0] [ 3,  3,  0]  1 */
     1551758, /* 59026 (1528) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
     8571457, /* 59027 (1528) [ 0,  0, -1,  1,  0,  0,  0, -1,  0] [ 3,  0,  3]  1 */
    10754554, /* 59028 (1528) [ 0, -1,  0,  0,  0, -1,  1,  0,  0] [ 3,  9,  6]  1 */
    17902171, /* 59029 (1528) [ 0,  0,  1, -1,  0,  0,  0, -1,  0] [ 6,  3,  9]  1 */
     2314903, /* 59030 (1528) [ 0,  1,  0,  0,  0, -1, -1,  0,  0] [ 0,  9,  9]  1 */
    25702637, /* 59031 (1528) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 9,  0,  9]  1 */
    25693987, /* 59032 (1528) [ 0, -1,  0,  0,  0,  1, -1,  0,  0] [ 9,  0,  9]  1 */
     1546090, /* 59033 (1528) [ 0,  0,  1,  1,  0,  0,  0,  1,  0] [ 0,  6,  6]  1 */
    27651414, /* 59034 (1528) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 9,  9,  0]  1 */
     9223690, /* 59035 (1528) [ 0,  1,  0,  0,  0,  1, -1,  0,  0] [ 3,  3,  0]  1 */
    19198615, /* 59036 (1528) [ 0, -1,  0,  0,  0,  1,  1,  0,  0] [ 6,  9,  3]  1 */
    17133076, /* 59037 (1528) [ 0,  0, -1, -1,  0,  0,  0, -1,  0] [ 6,  0,  6]  1 */
    25695667, /* 59038 (1528) [ 0,  0, -1,  1,  0,  0,  0, -1,  0] [ 9,  0,  9]  1 */
    10763400, /* 59039 (1528) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 3,  9,  6]  1 */
    17903839, /* 59040 (1528) [ 0,  1,  0,  0,  0, -1, -1,  0,  0] [ 6,  3,  9]  1 */
    19200283, /* 59041 (1528) [ 0,  0, -1,  1,  0,  0,  0,  1,  0] [ 6,  9,  3]  1 */
      770999, /* 59042 (1528) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  3,  3]  1 */
    27643804, /* 59043 (1528) [ 0,  0, -1, -1,  0,  0,  0,  1,  0] [ 9,  9,  0]  1 */
        7618, /* 59044 (1528) [ 0, -1,  0,  0,  0, -1, -1,  0,  0] [ 0,  0,  0]  1 */
    18430906, /* 59045 (1528) [ 0, -1,  0,  0,  0, -1, -1,  0,  0] [ 6,  6,  0]  1 */
     2306273, /* 59046 (1528) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  9,  9]  1 */
    10106731, /* 59047 (1528) [ 0,  0, -1,  1,  0,  0,  0, -1,  0] [ 3,  6,  9]  1 */
     9219280, /* 59048 (1528) [ 0, -1,  0,  0,  0, -1,  1,  0,  0] [ 3,  3,  0]  1 */
    18426486, /* 59049 (1528) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
      783957, /* 59050 (1528) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  3,  3]  1 */
    26993065, /* 59051 (1528) [ 0, -1,  0,  0,  0,  1, -1,  0,  0] [ 9,  6,  3]  1 */
    19207245, /* 59052 (1528) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  9,  3]  1 */
    26995723, /* 59053 (1528) [ 0,  0,  1, -1,  0,  0,  0,  1,  0] [ 9,  6,  3]  1 */
    25698325, /* 59054 (1528) [ 0,  1,  0,  0,  0, -1,  1,  0,  0] [ 9,  0,  9]  1 */
    26988753, /* 59055 (1528) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 9,  6,  3]  1 */
     1547338, /* 59056 (1528) [ 0,  1,  0,  0,  0,  1,  1,  0,  0] [ 0,  6,  6]  1 */
    17135026, /* 59057 (1528) [ 0,  0,  1,  1,  0,  0,  0,  1,  0] [ 6,  0,  6]  1 */
     9220516, /* 59058 (1528) [ 0,  0, -1, -1,  0,  0,  0,  1,  0] [ 3,  3,  0]  1 */
    10755790, /* 59059 (1528) [ 0,  0, -1, -1,  0,  0,  0,  1,  0] [ 3,  9,  6]  1 */
     1542892, /* 59060 (1528) [ 0, -1,  0,  0,  0, -1, -1,  0,  0] [ 0,  6,  6]  1 */
     2310601, /* 59061 (1528) [ 0, -1,  0,  0,  0,  1,  1,  0,  0] [ 0,  9,  9]  1 */
     1538472, /* 59062 (1528) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
    17895209, /* 59063 (1528) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  3,  9]  1 */
      776995, /* 59064 (1528) [ 0,  0, -1,  1,  0,  0,  0,  1,  0] [ 0,  3,  3]  1 */
     2312269, /* 59065 (1528) [ 0,  0, -1,  1,  0,  0,  0,  1,  0] [ 0,  9,  9]  1 */
    27646978, /* 59066 (1528) [ 0,  1,  0,  0,  0,  1, -1,  0,  0] [ 9,  9,  0]  1 */
       16484, /* 59067 (1529) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    61663638, /* 59068 (1529) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 9,  9,  0] -1 */
    44125925, /* 59069 (1529) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 3,  6,  9] -1 */
    44771188, /* 59070 (1529) [ 0,  1,  0,  0,  0,  1, -1,  0,  0] [ 3,  9,  6] -1 */
     8565465, /* 59071 (1529) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 3,  0,  3]  1 */
    17140694, /* 59072 (1529) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
    19201249, /* 59073 (1529) [ 0,  0,  1, -1,  0,  0,  0, -1,  0] [ 6,  9,  3]  1 */
    43235914, /* 59074 (1529) [ 0,  1,  0,  0,  0,  1, -1,  0,  0] [ 3,  3,  0] -1 */
    26997403, /* 59075 (1529) [ 0,  1,  0,  0,  0, -1,  1,  0,  0] [ 9,  6,  3]  1 */
    26347900, /* 59076 (1529) [ 0,  1,  0,  0,  0,  1, -1,  0,  0] [ 9,  3,  6]  1 */
    26339054, /* 59077 (1529) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 9,  3,  6]  1 */
    52451996, /* 59078 (1529) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
        3198, /* 59079 (1529) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    53210839, /* 59080 (1529) [ 0, -1,  0,  0,  0,  1,  1,  0,  0] [ 6,  9,  3] -1 */
     8572435, /* 59081 (1529) [ 0,  0,  1, -1,  0,  0,  0,  1,  0] [ 3,  0,  3]  1 */
    51139632, /* 59082 (1529) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  6] -1 */
    10105051, /* 59083 (1529) [ 0, -1,  0,  0,  0,  1, -1,  0,  0] [ 3,  6,  9]  1 */
     2319231, /* 59084 (1529) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  9,  9]  1 */
    27001715, /* 59085 (1529) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 9,  6,  3]  1 */
    10107709, /* 59086 (1529) [ 0,  0,  1, -1,  0,  0,  0,  1,  0] [ 3,  6,  9]  1 */
    43227068, /* 59087 (1529) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 3,  3,  0] -1 */
    10100739, /* 59088 (1529) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 3,  6,  9]  1 */
     8569777, /* 59089 (1529) [ 0, -1,  0,  0,  0,  1, -1,  0,  0] [ 3,  0,  3]  1 */
    26352336, /* 59090 (1529) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 9,  3,  6]  1 */
    17136274, /* 59091 (1529) [ 0,  1,  0,  0,  0,  1,  1,  0,  0] [ 6,  0,  6]  1 */
    27645742, /* 59092 (1529) [ 0,  0,  1,  1,  0,  0,  0, -1,  0] [ 9,  9,  0]  1 */
    52447576, /* 59093 (1529) [ 0,  1,  0,  0,  0,  1,  1,  0,  0] [ 6,  6,  0] -1 */
    43240350, /* 59094 (1529) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 3,  3,  0] -1 */
    26346664, /* 59095 (1529) [ 0,  0,  1,  1,  0,  0,  0, -1,  0] [ 9,  3,  6]  1 */
    34023040, /* 59096 (1529) [ 0,  0,  1,  1,  0,  0,  0,  1,  0] [ 0,  0,  0] -1 */
    52446328, /* 59097 (1529) [ 0,  0,  1,  1,  0,  0,  0,  1,  0] [ 6,  6,  0] -1 */
      775327, /* 59098 (1529) [ 0, -1,  0,  0,  0,  1,  1,  0,  0] [ 0,  3,  3]  1 */
    17131828, /* 59099 (1529) [ 0, -1,  0,  0,  0, -1, -1,  0,  0] [ 6,  0,  6]  1 */
    51916063, /* 59100 (1529) [ 0,  1,  0,  0,  0, -1, -1,  0,  0] [ 6,  3,  9] -1 */
    34783223, /* 59101 (1529) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  3,  3] -1 */
    34024288, /* 59102 (1529) [ 0,  1,  0,  0,  0,  1,  1,  0,  0] [ 0,  0,  0] -1 */
    53206511, /* 59103 (1529) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  9,  3] -1 */
    27642568, /* 59104 (1529) [ 0, -1,  0,  0,  0, -1,  1,  0,  0] [ 9,  9,  0]  1 */
    35563982, /* 59105 (1529) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
    42583681, /* 59106 (1529) [ 0,  0, -1,  1,  0,  0,  0, -1,  0] [ 3,  0,  3] -1 */
    44766778, /* 59107 (1529) [ 0, -1,  0,  0,  0, -1,  1,  0,  0] [ 3,  9,  6] -1 */
    44118955, /* 59108 (1529) [ 0,  0, -1,  1,  0,  0,  0, -1,  0] [ 3,  6,  9] -1 */
    51914395, /* 59109 (1529) [ 0,  0,  1, -1,  0,  0,  0, -1,  0] [ 6,  3,  9] -1 */
    43231504, /* 59110 (1529) [ 0, -1,  0,  0,  0, -1,  1,  0,  0] [ 3,  3,  0] -1 */
    36327127, /* 59111 (1529) [ 0,  1,  0,  0,  0, -1, -1,  0,  0] [ 0,  9,  9] -1 */
    26343490, /* 59112 (1529) [ 0, -1,  0,  0,  0, -1,  1,  0,  0] [ 9,  3,  6]  1 */
    61005289, /* 59113 (1529) [ 0, -1,  0,  0,  0,  1, -1,  0,  0] [ 9,  6,  3] -1 */
    53219469, /* 59114 (1529) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  9,  3] -1 */
    10757728, /* 59115 (1529) [ 0,  0,  1,  1,  0,  0,  0, -1,  0] [ 3,  9,  6]  1 */
    59710549, /* 59116 (1529) [ 0,  1,  0,  0,  0, -1,  1,  0,  0] [ 9,  0,  9] -1 */
    17901205, /* 59117 (1529) [ 0,  0, -1,  1,  0,  0,  0,  1,  0] [ 6,  3,  9]  1 */
    61000977, /* 59118 (1529) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 9,  6,  3] -1 */
    26344726, /* 59119 (1529) [ 0,  0, -1, -1,  0,  0,  0,  1,  0] [ 9,  3,  6]  1 */
    59714861, /* 59120 (1529) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 9,  0,  9] -1 */
    35559562, /* 59121 (1529) [ 0,  1,  0,  0,  0,  1,  1,  0,  0] [ 0,  6,  6] -1 */
    26994745, /* 59122 (1529) [ 0,  0, -1,  1,  0,  0,  0, -1,  0] [ 9,  6,  3]  1 */
      779629, /* 59123 (1529) [ 0,  1,  0,  0,  0, -1, -1,  0,  0] [ 0,  3,  3]  1 */
    59706211, /* 59124 (1529) [ 0, -1,  0,  0,  0,  1, -1,  0,  0] [ 9,  0,  9] -1 */
    19202917, /* 59125 (1529) [ 0,  1,  0,  0,  0, -1, -1,  0,  0] [ 6,  9,  3]  1 */
    35558314, /* 59126 (1529) [ 0,  0,  1,  1,  0,  0,  0,  1,  0] [ 0,  6,  6] -1 */
    43232740, /* 59127 (1529) [ 0,  0, -1, -1,  0,  0,  0,  1,  0] [ 3,  3,  0] -1 */
    27638132, /* 59128 (1529) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 9,  9,  0]  1 */
      777961, /* 59129 (1529) [ 0,  0,  1, -1,  0,  0,  0, -1,  0] [ 0,  3,  3]  1 */
    17908167, /* 59130 (1529) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  3,  9]  1 */
    25696645, /* 59131 (1529) [ 0,  0,  1, -1,  0,  0,  0,  1,  0] [ 9,  0,  9]  1 */
    25689675, /* 59132 (1529) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 9,  0,  9]  1 */
     2313235, /* 59133 (1529) [ 0,  0,  1, -1,  0,  0,  0, -1,  0] [ 0,  9,  9]  1 */
    10109389, /* 59134 (1529) [ 0,  1,  0,  0,  0, -1,  1,  0,  0] [ 3,  6,  9]  1 */
     8574115, /* 59135 (1529) [ 0,  1,  0,  0,  0, -1,  1,  0,  0] [ 3,  0,  3]  1 */
    36322825, /* 59136 (1529) [ 0, -1,  0,  0,  0,  1,  1,  0,  0] [ 0,  9,  9] -1 */
        8866, /* 59137 (1529) [ 0,  0, -1, -1,  0,  0,  0, -1,  0] [ 0,  0,  0]  1 */
    18432154, /* 59138 (1529) [ 0,  0, -1, -1,  0,  0,  0, -1,  0] [ 6,  6,  0]  1 */
     8578427, /* 59139 (1529) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 3,  0,  3]  1 */
    10113701, /* 59140 (1529) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 3,  6,  9]  1 */
    10758964, /* 59141 (1529) [ 0,  1,  0,  0,  0,  1, -1,  0,  0] [ 3,  9,  6]  1 */
    18439772, /* 59142 (1529) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    34028708, /* 59143 (1529) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    51145300, /* 59144 (1529) [ 0,  0, -1, -1,  0,  0,  0, -1,  0] [ 6,  0,  6] -1 */
    17127408, /* 59145 (1529) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  6]  1 */
    10750118, /* 59146 (1529) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 3,  9,  6]  1 */
    44775624, /* 59147 (1529) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 3,  9,  6] -1 */
    59707891, /* 59148 (1529) [ 0,  0, -1,  1,  0,  0,  0, -1,  0] [ 9,  0,  9] -1 */
    34789219, /* 59149 (1529) [ 0,  0, -1,  1,  0,  0,  0,  1,  0] [ 0,  3,  3] -1 */
     9214844, /* 59150 (1529) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 3,  3,  0]  1 */
    53212507, /* 59151 (1529) [ 0,  0, -1,  1,  0,  0,  0,  1,  0] [ 6,  9,  3] -1 */
    17899537, /* 59152 (1529) [ 0, -1,  0,  0,  0,  1,  1,  0,  0] [ 6,  3,  9]  1 */
    61656028, /* 59153 (1529) [ 0,  0, -1, -1,  0,  0,  0,  1,  0] [ 9,  9,  0] -1 */
    34019842, /* 59154 (1529) [ 0, -1,  0,  0,  0, -1, -1,  0,  0] [ 0,  0,  0] -1 */
    52443130, /* 59155 (1529) [ 0, -1,  0,  0,  0, -1, -1,  0,  0] [ 6,  6,  0] -1 */
    36318497, /* 59156 (1529) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  9,  9] -1 */
    51152918, /* 59157 (1529) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
    18435352, /* 59158 (1529) [ 0,  1,  0,  0,  0,  1,  1,  0,  0] [ 6,  6,  0]  1 */
    61009627, /* 59159 (1529) [ 0,  1,  0,  0,  0, -1,  1,  0,  0] [ 9,  6,  3] -1 */
     1544140, /* 59160 (1529) [ 0,  0, -1, -1,  0,  0,  0, -1,  0] [ 0,  6,  6]  1 */
     9228126, /* 59161 (1529) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 3,  3,  0]  1 */
    60360124, /* 59162 (1529) [ 0,  1,  0,  0,  0,  1, -1,  0,  0] [ 9,  3,  6] -1 */
       10816, /* 59163 (1529) [ 0,  0,  1,  1,  0,  0,  0,  1,  0] [ 0,  0,  0]  1 */
    18434104, /* 59164 (1529) [ 0,  0,  1,  1,  0,  0,  0,  1,  0] [ 6,  6,  0]  1 */
    34015422, /* 59165 (1529) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    52438710, /* 59166 (1529) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
    34796181, /* 59167 (1529) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  3,  3] -1 */
    42584659, /* 59168 (1529) [ 0,  0,  1, -1,  0,  0,  0,  1,  0] [ 3,  0,  3] -1 */
    61007947, /* 59169 (1529) [ 0,  0,  1, -1,  0,  0,  0,  1,  0] [ 9,  6,  3] -1 */
    44117275, /* 59170 (1529) [ 0, -1,  0,  0,  0,  1, -1,  0,  0] [ 3,  6,  9] -1 */
       12064, /* 59171 (1529) [ 0,  1,  0,  0,  0,  1,  1,  0,  0] [ 0,  0,  0]  1 */
    19194287, /* 59172 (1529) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  9,  3]  1 */
     9222454, /* 59173 (1529) [ 0,  0,  1,  1,  0,  0,  0, -1,  0] [ 3,  3,  0]  1 */
     1551758, /* 59174 (1529) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
     8571457, /* 59175 (1529) [ 0,  0, -1,  1,  0,  0,  0, -1,  0] [ 3,  0,  3]  1 */
    51148498, /* 59176 (1529) [ 0,  1,  0,  0,  0,  1,  1,  0,  0] [ 6,  0,  6] -1 */
    10754554, /* 59177 (1529) [ 0, -1,  0,  0,  0, -1,  1,  0,  0] [ 3,  9,  6]  1 */
    17902171, /* 59178 (1529) [ 0,  0,  1, -1,  0,  0,  0, -1,  0] [ 6,  3,  9]  1 */
     2314903, /* 59179 (1529) [ 0,  1,  0,  0,  0, -1, -1,  0,  0] [ 0,  9,  9]  1 */
    51147250, /* 59180 (1529) [ 0,  0,  1,  1,  0,  0,  0,  1,  0] [ 6,  0,  6] -1 */
    60358888, /* 59181 (1529) [ 0,  0,  1,  1,  0,  0,  0, -1,  0] [ 9,  3,  6] -1 */
    44768014, /* 59182 (1529) [ 0,  0, -1, -1,  0,  0,  0,  1,  0] [ 3,  9,  6] -1 */
    35555116, /* 59183 (1529) [ 0, -1,  0,  0,  0, -1, -1,  0,  0] [ 0,  6,  6] -1 */
    25702637, /* 59184 (1529) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 9,  0,  9]  1 */
    25693987, /* 59185 (1529) [ 0, -1,  0,  0,  0,  1, -1,  0,  0] [ 9,  0,  9]  1 */
     1546090, /* 59186 (1529) [ 0,  0,  1,  1,  0,  0,  0,  1,  0] [ 0,  6,  6]  1 */
    35550696, /* 59187 (1529) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  6] -1 */
    27651414, /* 59188 (1529) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 9,  9,  0]  1 */
    60355714, /* 59189 (1529) [ 0, -1,  0,  0,  0, -1,  1,  0,  0] [ 9,  3,  6] -1 */
     9223690, /* 59190 (1529) [ 0,  1,  0,  0,  0,  1, -1,  0,  0] [ 3,  3,  0]  1 */
    19198615, /* 59191 (1529) [ 0, -1,  0,  0,  0,  1,  1,  0,  0] [ 6,  9,  3]  1 */
    51907433, /* 59192 (1529) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  3,  9] -1 */
    53215141, /* 59193 (1529) [ 0,  1,  0,  0,  0, -1, -1,  0,  0] [ 6,  9,  3] -1 */
    36324493, /* 59194 (1529) [ 0,  0, -1,  1,  0,  0,  0,  1,  0] [ 0,  9,  9] -1 */
    61659202, /* 59195 (1529) [ 0,  1,  0,  0,  0,  1, -1,  0,  0] [ 9,  9,  0] -1 */
    61650356, /* 59196 (1529) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 9,  9,  0] -1 */
    42577689, /* 59197 (1529) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 3,  0,  3] -1 */
    34790185, /* 59198 (1529) [ 0,  0,  1, -1,  0,  0,  0, -1,  0] [ 0,  3,  3] -1 */
    53213473, /* 59199 (1529) [ 0,  0,  1, -1,  0,  0,  0, -1,  0] [ 6,  9,  3] -1 */
    59701899, /* 59200 (1529) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 9,  0,  9] -1 */
    44121613, /* 59201 (1529) [ 0,  1,  0,  0,  0, -1,  1,  0,  0] [ 3,  6,  9] -1 */
    17133076, /* 59202 (1529) [ 0,  0, -1, -1,  0,  0,  0, -1,  0] [ 6,  0,  6]  1 */
    60351278, /* 59203 (1529) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 9,  3,  6] -1 */
    25695667, /* 59204 (1529) [ 0,  0, -1,  1,  0,  0,  0, -1,  0] [ 9,  0,  9]  1 */
    10763400, /* 59205 (1529) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 3,  9,  6]  1 */
    17903839, /* 59206 (1529) [ 0,  1,  0,  0,  0, -1, -1,  0,  0] [ 6,  3,  9]  1 */
    19200283, /* 59207 (1529) [ 0,  0, -1,  1,  0,  0,  0,  1,  0] [ 6,  9,  3]  1 */
    52444378, /* 59208 (1529) [ 0,  0, -1, -1,  0,  0,  0, -1,  0] [ 6,  6,  0] -1 */
    42590651, /* 59209 (1529) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 3,  0,  3] -1 */
      770999, /* 59210 (1529) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  3,  3]  1 */
    27643804, /* 59211 (1529) [ 0,  0, -1, -1,  0,  0,  0,  1,  0] [ 9,  9,  0]  1 */
    36331455, /* 59212 (1529) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  9,  9] -1 */
        7618, /* 59213 (1529) [ 0, -1,  0,  0,  0, -1, -1,  0,  0] [ 0,  0,  0]  1 */
    18430906, /* 59214 (1529) [ 0, -1,  0,  0,  0, -1, -1,  0,  0] [ 6,  6,  0]  1 */
     2306273, /* 59215 (1529) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  9,  9]  1 */
    44112963, /* 59216 (1529) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 3,  6,  9] -1 */
    61013939, /* 59217 (1529) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 9,  6,  3] -1 */
    42582001, /* 59218 (1529) [ 0, -1,  0,  0,  0,  1, -1,  0,  0] [ 3,  0,  3] -1 */
    60364560, /* 59219 (1529) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 9,  3,  6] -1 */
    44119933, /* 59220 (1529) [ 0,  0,  1, -1,  0,  0,  0,  1,  0] [ 3,  6,  9] -1 */
    61657966, /* 59221 (1529) [ 0,  0,  1,  1,  0,  0,  0, -1,  0] [ 9,  9,  0] -1 */
    10106731, /* 59222 (1529) [ 0,  0, -1,  1,  0,  0,  0, -1,  0] [ 3,  6,  9]  1 */
     9219280, /* 59223 (1529) [ 0, -1,  0,  0,  0, -1,  1,  0,  0] [ 3,  3,  0]  1 */
    18426486, /* 59224 (1529) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
      783957, /* 59225 (1529) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  3,  3]  1 */
    26993065, /* 59226 (1529) [ 0, -1,  0,  0,  0,  1, -1,  0,  0] [ 9,  6,  3]  1 */
    19207245, /* 59227 (1529) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  9,  3]  1 */
    26995723, /* 59228 (1529) [ 0,  0,  1, -1,  0,  0,  0,  1,  0] [ 9,  6,  3]  1 */
    44762342, /* 59229 (1529) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 3,  9,  6] -1 */
    25698325, /* 59230 (1529) [ 0,  1,  0,  0,  0, -1,  1,  0,  0] [ 9,  0,  9]  1 */
    26988753, /* 59231 (1529) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 9,  6,  3]  1 */
    34787551, /* 59232 (1529) [ 0, -1,  0,  0,  0,  1,  1,  0,  0] [ 0,  3,  3] -1 */
    51144052, /* 59233 (1529) [ 0, -1,  0,  0,  0, -1, -1,  0,  0] [ 6,  0,  6] -1 */
    51911761, /* 59234 (1529) [ 0, -1,  0,  0,  0,  1,  1,  0,  0] [ 6,  3,  9] -1 */
     1547338, /* 59235 (1529) [ 0,  1,  0,  0,  0,  1,  1,  0,  0] [ 0,  6,  6]  1 */
    61654792, /* 59236 (1529) [ 0, -1,  0,  0,  0, -1,  1,  0,  0] [ 9,  9,  0] -1 */
    17135026, /* 59237 (1529) [ 0,  0,  1,  1,  0,  0,  0,  1,  0] [ 6,  0,  6]  1 */
     9220516, /* 59238 (1529) [ 0,  0, -1, -1,  0,  0,  0,  1,  0] [ 3,  3,  0]  1 */
    35556364, /* 59239 (1529) [ 0,  0, -1, -1,  0,  0,  0, -1,  0] [ 0,  6,  6] -1 */
    10755790, /* 59240 (1529) [ 0,  0, -1, -1,  0,  0,  0,  1,  0] [ 3,  9,  6]  1 */
     1542892, /* 59241 (1529) [ 0, -1,  0,  0,  0, -1, -1,  0,  0] [ 0,  6,  6]  1 */
    44769952, /* 59242 (1529) [ 0,  0,  1,  1,  0,  0,  0, -1,  0] [ 3,  9,  6] -1 */
    51913429, /* 59243 (1529) [ 0,  0, -1,  1,  0,  0,  0,  1,  0] [ 6,  3,  9] -1 */
    43234678, /* 59244 (1529) [ 0,  0,  1,  1,  0,  0,  0, -1,  0] [ 3,  3,  0] -1 */
    60356950, /* 59245 (1529) [ 0,  0, -1, -1,  0,  0,  0,  1,  0] [ 9,  3,  6] -1 */
     2310601, /* 59246 (1529) [ 0, -1,  0,  0,  0,  1,  1,  0,  0] [ 0,  9,  9]  1 */
     1538472, /* 59247 (1529) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
    61006969, /* 59248 (1529) [ 0,  0, -1,  1,  0,  0,  0, -1,  0] [ 9,  6,  3] -1 */
    34791853, /* 59249 (1529) [ 0,  1,  0,  0,  0, -1, -1,  0,  0] [ 0,  3,  3] -1 */
    51920391, /* 59250 (1529) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  3,  9] -1 */
    59708869, /* 59251 (1529) [ 0,  0,  1, -1,  0,  0,  0,  1,  0] [ 9,  0,  9] -1 */
    17895209, /* 59252 (1529) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  3,  9]  1 */
    36325459, /* 59253 (1529) [ 0,  0,  1, -1,  0,  0,  0, -1,  0] [ 0,  9,  9] -1 */
    42586339, /* 59254 (1529) [ 0,  1,  0,  0,  0, -1,  1,  0,  0] [ 3,  0,  3] -1 */
      776995, /* 59255 (1529) [ 0,  0, -1,  1,  0,  0,  0,  1,  0] [ 0,  3,  3]  1 */
    34021090, /* 59256 (1529) [ 0,  0, -1, -1,  0,  0,  0, -1,  0] [ 0,  0,  0] -1 */
     2312269, /* 59257 (1529) [ 0,  0, -1,  1,  0,  0,  0,  1,  0] [ 0,  9,  9]  1 */
    27646978, /* 59258 (1529) [ 0,  1,  0,  0,  0,  1, -1,  0,  0] [ 9,  9,  0]  1 */
       16484, /* 59259 (1530) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    61663638, /* 59260 (1530) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 9,  9,  0] -1 */
    44125925, /* 59261 (1530) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 3,  6,  9] -1 */
    44771188, /* 59262 (1530) [ 0,  1,  0,  0,  0,  1, -1,  0,  0] [ 3,  9,  6] -1 */
     8565465, /* 59263 (1530) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 3,  0,  3]  1 */
    17140694, /* 59264 (1530) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
    19201249, /* 59265 (1530) [ 0,  0,  1, -1,  0,  0,  0, -1,  0] [ 6,  9,  3]  1 */
    43235914, /* 59266 (1530) [ 0,  1,  0,  0,  0,  1, -1,  0,  0] [ 3,  3,  0] -1 */
    26339054, /* 59267 (1530) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 9,  3,  6]  1 */
    53210839, /* 59268 (1530) [ 0, -1,  0,  0,  0,  1,  1,  0,  0] [ 6,  9,  3] -1 */
    51139632, /* 59269 (1530) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  6] -1 */
    10105051, /* 59270 (1530) [ 0, -1,  0,  0,  0,  1, -1,  0,  0] [ 3,  6,  9]  1 */
     2319231, /* 59271 (1530) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  9,  9]  1 */
    10100739, /* 59272 (1530) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 3,  6,  9]  1 */
     8569777, /* 59273 (1530) [ 0, -1,  0,  0,  0,  1, -1,  0,  0] [ 3,  0,  3]  1 */
    17136274, /* 59274 (1530) [ 0,  1,  0,  0,  0,  1,  1,  0,  0] [ 6,  0,  6]  1 */
    43240350, /* 59275 (1530) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 3,  3,  0] -1 */
    34783223, /* 59276 (1530) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  3,  3] -1 */
    53206511, /* 59277 (1530) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  9,  3] -1 */
    27642568, /* 59278 (1530) [ 0, -1,  0,  0,  0, -1,  1,  0,  0] [ 9,  9,  0]  1 */
    26343490, /* 59279 (1530) [ 0, -1,  0,  0,  0, -1,  1,  0,  0] [ 9,  3,  6]  1 */
    59710549, /* 59280 (1530) [ 0,  1,  0,  0,  0, -1,  1,  0,  0] [ 9,  0,  9] -1 */
    26344726, /* 59281 (1530) [ 0,  0, -1, -1,  0,  0,  0,  1,  0] [ 9,  3,  6]  1 */
    59714861, /* 59282 (1530) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 9,  0,  9] -1 */
    26994745, /* 59283 (1530) [ 0,  0, -1,  1,  0,  0,  0, -1,  0] [ 9,  6,  3]  1 */
      779629, /* 59284 (1530) [ 0,  1,  0,  0,  0, -1, -1,  0,  0] [ 0,  3,  3]  1 */
    19202917, /* 59285 (1530) [ 0,  1,  0,  0,  0, -1, -1,  0,  0] [ 6,  9,  3]  1 */
    27638132, /* 59286 (1530) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 9,  9,  0]  1 */
      777961, /* 59287 (1530) [ 0,  0,  1, -1,  0,  0,  0, -1,  0] [ 0,  3,  3]  1 */
    17908167, /* 59288 (1530) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  3,  9]  1 */
    25689675, /* 59289 (1530) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 9,  0,  9]  1 */
     2313235, /* 59290 (1530) [ 0,  0,  1, -1,  0,  0,  0, -1,  0] [ 0,  9,  9]  1 */
    36322825, /* 59291 (1530) [ 0, -1,  0,  0,  0,  1,  1,  0,  0] [ 0,  9,  9] -1 */
    18439772, /* 59292 (1530) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    51145300, /* 59293 (1530) [ 0,  0, -1, -1,  0,  0,  0, -1,  0] [ 6,  0,  6] -1 */
    10750118, /* 59294 (1530) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 3,  9,  6]  1 */
    44775624, /* 59295 (1530) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 3,  9,  6] -1 */
    34789219, /* 59296 (1530) [ 0,  0, -1,  1,  0,  0,  0,  1,  0] [ 0,  3,  3] -1 */
     9214844, /* 59297 (1530) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 3,  3,  0]  1 */
    53212507, /* 59298 (1530) [ 0,  0, -1,  1,  0,  0,  0,  1,  0] [ 6,  9,  3] -1 */
    34019842, /* 59299 (1530) [ 0, -1,  0,  0,  0, -1, -1,  0,  0] [ 0,  0,  0] -1 */
    52443130, /* 59300 (1530) [ 0, -1,  0,  0,  0, -1, -1,  0,  0] [ 6,  6,  0] -1 */
    36318497, /* 59301 (1530) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  9,  9] -1 */
    18435352, /* 59302 (1530) [ 0,  1,  0,  0,  0,  1,  1,  0,  0] [ 6,  6,  0]  1 */
    61009627, /* 59303 (1530) [ 0,  1,  0,  0,  0, -1,  1,  0,  0] [ 9,  6,  3] -1 */
    60360124, /* 59304 (1530) [ 0,  1,  0,  0,  0,  1, -1,  0,  0] [ 9,  3,  6] -1 */
       10816, /* 59305 (1530) [ 0,  0,  1,  1,  0,  0,  0,  1,  0] [ 0,  0,  0]  1 */
    34015422, /* 59306 (1530) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    18434104, /* 59307 (1530) [ 0,  0,  1,  1,  0,  0,  0,  1,  0] [ 6,  6,  0]  1 */
    52438710, /* 59308 (1530) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
    42584659, /* 59309 (1530) [ 0,  0,  1, -1,  0,  0,  0,  1,  0] [ 3,  0,  3] -1 */
    61007947, /* 59310 (1530) [ 0,  0,  1, -1,  0,  0,  0,  1,  0] [ 9,  6,  3] -1 */
       12064, /* 59311 (1530) [ 0,  1,  0,  0,  0,  1,  1,  0,  0] [ 0,  0,  0]  1 */
     1551758, /* 59312 (1530) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
     8571457, /* 59313 (1530) [ 0,  0, -1,  1,  0,  0,  0, -1,  0] [ 3,  0,  3]  1 */
    10754554, /* 59314 (1530) [ 0, -1,  0,  0,  0, -1,  1,  0,  0] [ 3,  9,  6]  1 */
    17902171, /* 59315 (1530) [ 0,  0,  1, -1,  0,  0,  0, -1,  0] [ 6,  3,  9]  1 */
     2314903, /* 59316 (1530) [ 0,  1,  0,  0,  0, -1, -1,  0,  0] [ 0,  9,  9]  1 */
    60358888, /* 59317 (1530) [ 0,  0,  1,  1,  0,  0,  0, -1,  0] [ 9,  3,  6] -1 */
    35555116, /* 59318 (1530) [ 0, -1,  0,  0,  0, -1, -1,  0,  0] [ 0,  6,  6] -1 */
    25693987, /* 59319 (1530) [ 0, -1,  0,  0,  0,  1, -1,  0,  0] [ 9,  0,  9]  1 */
     1546090, /* 59320 (1530) [ 0,  0,  1,  1,  0,  0,  0,  1,  0] [ 0,  6,  6]  1 */
    35550696, /* 59321 (1530) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  6] -1 */
    51907433, /* 59322 (1530) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  3,  9] -1 */
    36324493, /* 59323 (1530) [ 0,  0, -1,  1,  0,  0,  0,  1,  0] [ 0,  9,  9] -1 */
    61659202, /* 59324 (1530) [ 0,  1,  0,  0,  0,  1, -1,  0,  0] [ 9,  9,  0] -1 */
    44121613, /* 59325 (1530) [ 0,  1,  0,  0,  0, -1,  1,  0,  0] [ 3,  6,  9] -1 */
    25695667, /* 59326 (1530) [ 0,  0, -1,  1,  0,  0,  0, -1,  0] [ 9,  0,  9]  1 */
    17903839, /* 59327 (1530) [ 0,  1,  0,  0,  0, -1, -1,  0,  0] [ 6,  3,  9]  1 */
    52444378, /* 59328 (1530) [ 0,  0, -1, -1,  0,  0,  0, -1,  0] [ 6,  6,  0] -1 */
    42590651, /* 59329 (1530) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 3,  0,  3] -1 */
    61013939, /* 59330 (1530) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 9,  6,  3] -1 */
    44119933, /* 59331 (1530) [ 0,  0,  1, -1,  0,  0,  0,  1,  0] [ 3,  6,  9] -1 */
    27643804, /* 59332 (1530) [ 0,  0, -1, -1,  0,  0,  0,  1,  0] [ 9,  9,  0]  1 */
    60364560, /* 59333 (1530) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 9,  3,  6] -1 */
    61657966, /* 59334 (1530) [ 0,  0,  1,  1,  0,  0,  0, -1,  0] [ 9,  9,  0] -1 */
    10106731, /* 59335 (1530) [ 0,  0, -1,  1,  0,  0,  0, -1,  0] [ 3,  6,  9]  1 */
     9219280, /* 59336 (1530) [ 0, -1,  0,  0,  0, -1,  1,  0,  0] [ 3,  3,  0]  1 */
      783957, /* 59337 (1530) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  3,  3]  1 */
    26993065, /* 59338 (1530) [ 0, -1,  0,  0,  0,  1, -1,  0,  0] [ 9,  6,  3]  1 */
    19207245, /* 59339 (1530) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  9,  3]  1 */
    34787551, /* 59340 (1530) [ 0, -1,  0,  0,  0,  1,  1,  0,  0] [ 0,  3,  3] -1 */
    26988753, /* 59341 (1530) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 9,  6,  3]  1 */
    51144052, /* 59342 (1530) [ 0, -1,  0,  0,  0, -1, -1,  0,  0] [ 6,  0,  6] -1 */
    51911761, /* 59343 (1530) [ 0, -1,  0,  0,  0,  1,  1,  0,  0] [ 6,  3,  9] -1 */
     1547338, /* 59344 (1530) [ 0,  1,  0,  0,  0,  1,  1,  0,  0] [ 0,  6,  6]  1 */
    17135026, /* 59345 (1530) [ 0,  0,  1,  1,  0,  0,  0,  1,  0] [ 6,  0,  6]  1 */
     9220516, /* 59346 (1530) [ 0,  0, -1, -1,  0,  0,  0,  1,  0] [ 3,  3,  0]  1 */
    35556364, /* 59347 (1530) [ 0,  0, -1, -1,  0,  0,  0, -1,  0] [ 0,  6,  6] -1 */
    10755790, /* 59348 (1530) [ 0,  0, -1, -1,  0,  0,  0,  1,  0] [ 3,  9,  6]  1 */
    44769952, /* 59349 (1530) [ 0,  0,  1,  1,  0,  0,  0, -1,  0] [ 3,  9,  6] -1 */
    51913429, /* 59350 (1530) [ 0,  0, -1,  1,  0,  0,  0,  1,  0] [ 6,  3,  9] -1 */
    43234678, /* 59351 (1530) [ 0,  0,  1,  1,  0,  0,  0, -1,  0] [ 3,  3,  0] -1 */
    59708869, /* 59352 (1530) [ 0,  0,  1, -1,  0,  0,  0,  1,  0] [ 9,  0,  9] -1 */
    42586339, /* 59353 (1530) [ 0,  1,  0,  0,  0, -1,  1,  0,  0] [ 3,  0,  3] -1 */
    34021090, /* 59354 (1530) [ 0,  0, -1, -1,  0,  0,  0, -1,  0] [ 0,  0,  0] -1 */
       16484, /* 59355 (1531) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
     8565465, /* 59356 (1531) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 3,  0,  3]  1 */
    17140694, /* 59357 (1531) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
    19201249, /* 59358 (1531) [ 0,  0,  1, -1,  0,  0,  0, -1,  0] [ 6,  9,  3]  1 */
    26997403, /* 59359 (1531) [ 0,  1,  0,  0,  0, -1,  1,  0,  0] [ 9,  6,  3]  1 */
    53328937, /* 59360 (1531) [ 0, -1,  0,  0,  0,  1,  1,  0,  0] [ 6,  9,  9] -1 */
    26347900, /* 59361 (1531) [ 0,  1,  0,  0,  0,  1, -1,  0,  0] [ 9,  3,  6]  1 */
    26339054, /* 59362 (1531) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 9,  3,  6]  1 */
    51793663, /* 59363 (1531) [ 0, -1,  0,  0,  0,  1,  1,  0,  0] [ 6,  3,  3] -1 */
        3198, /* 59364 (1531) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
     8572435, /* 59365 (1531) [ 0,  0,  1, -1,  0,  0,  0,  1,  0] [ 3,  0,  3]  1 */
    43345166, /* 59366 (1531) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 3,  3,  6] -1 */
    10105051, /* 59367 (1531) [ 0, -1,  0,  0,  0,  1, -1,  0,  0] [ 3,  6,  9]  1 */
     2319231, /* 59368 (1531) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  9,  9]  1 */
    27001715, /* 59369 (1531) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 9,  6,  3]  1 */
    10107709, /* 59370 (1531) [ 0,  0,  1, -1,  0,  0,  0,  1,  0] [ 3,  6,  9]  1 */
    10100739, /* 59371 (1531) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 3,  6,  9]  1 */
     8569777, /* 59372 (1531) [ 0, -1,  0,  0,  0,  1, -1,  0,  0] [ 3,  0,  3]  1 */
    35438266, /* 59373 (1531) [ 0,  0, -1, -1,  0,  0,  0, -1,  0] [ 0,  6,  0] -1 */
    26352336, /* 59374 (1531) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 9,  3,  6]  1 */
    51034820, /* 59375 (1531) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  0] -1 */
    17136274, /* 59376 (1531) [ 0,  1,  0,  0,  0,  1,  1,  0,  0] [ 6,  0,  6]  1 */
    27645742, /* 59377 (1531) [ 0,  0,  1,  1,  0,  0,  0, -1,  0] [ 9,  9,  0]  1 */
    43358448, /* 59378 (1531) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 3,  3,  6] -1 */
    51795331, /* 59379 (1531) [ 0,  0, -1,  1,  0,  0,  0,  1,  0] [ 6,  3,  3] -1 */
    26346664, /* 59380 (1531) [ 0,  0,  1,  1,  0,  0,  0, -1,  0] [ 9,  3,  6]  1 */
    60238852, /* 59381 (1531) [ 0,  0, -1, -1,  0,  0,  0,  1,  0] [ 9,  3,  0] -1 */
      775327, /* 59382 (1531) [ 0, -1,  0,  0,  0,  1,  1,  0,  0] [ 0,  3,  3]  1 */
    17131828, /* 59383 (1531) [ 0, -1,  0,  0,  0, -1, -1,  0,  0] [ 6,  0,  6]  1 */
    52561228, /* 59384 (1531) [ 0, -1,  0,  0,  0, -1, -1,  0,  0] [ 6,  6,  6] -1 */
    36209029, /* 59385 (1531) [ 0,  1,  0,  0,  0, -1, -1,  0,  0] [ 0,  9,  3] -1 */
    27642568, /* 59386 (1531) [ 0, -1,  0,  0,  0, -1,  1,  0,  0] [ 9,  9,  0]  1 */
    51021534, /* 59387 (1531) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  0] -1 */
    34907317, /* 59388 (1531) [ 0,  0, -1,  1,  0,  0,  0,  1,  0] [ 0,  3,  9] -1 */
    35445884, /* 59389 (1531) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  0] -1 */
    53330605, /* 59390 (1531) [ 0,  0, -1,  1,  0,  0,  0,  1,  0] [ 6,  9,  9] -1 */
    61774126, /* 59391 (1531) [ 0,  0, -1, -1,  0,  0,  0,  1,  0] [ 9,  9,  6] -1 */
    59590771, /* 59392 (1531) [ 0,  0,  1, -1,  0,  0,  0,  1,  0] [ 9,  0,  3] -1 */
    34137940, /* 59393 (1531) [ 0, -1,  0,  0,  0, -1, -1,  0,  0] [ 0,  0,  6] -1 */
    26343490, /* 59394 (1531) [ 0, -1,  0,  0,  0, -1,  1,  0,  0] [ 9,  3,  6]  1 */
    36207361, /* 59395 (1531) [ 0,  0,  1, -1,  0,  0,  0, -1,  0] [ 0,  9,  3] -1 */
    61126045, /* 59396 (1531) [ 0,  0,  1, -1,  0,  0,  0,  1,  0] [ 9,  6,  9] -1 */
    61119075, /* 59397 (1531) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 9,  6,  9] -1 */
    10757728, /* 59398 (1531) [ 0,  0,  1,  1,  0,  0,  0, -1,  0] [ 3,  9,  6]  1 */
    61127725, /* 59399 (1531) [ 0,  1,  0,  0,  0, -1,  1,  0,  0] [ 9,  6,  9] -1 */
    17901205, /* 59400 (1531) [ 0,  0, -1,  1,  0,  0,  0,  1,  0] [ 6,  3,  9]  1 */
    26344726, /* 59401 (1531) [ 0,  0, -1, -1,  0,  0,  0,  1,  0] [ 9,  3,  6]  1 */
    34133520, /* 59402 (1531) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
    26994745, /* 59403 (1531) [ 0,  0, -1,  1,  0,  0,  0, -1,  0] [ 9,  6,  3]  1 */
      779629, /* 59404 (1531) [ 0,  1,  0,  0,  0, -1, -1,  0,  0] [ 0,  3,  3]  1 */
    34914279, /* 59405 (1531) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  3,  9] -1 */
    44007827, /* 59406 (1531) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 3,  6,  3] -1 */
    35441464, /* 59407 (1531) [ 0,  1,  0,  0,  0,  1,  1,  0,  0] [ 0,  6,  0] -1 */
    53337567, /* 59408 (1531) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  9,  9] -1 */
    19202917, /* 59409 (1531) [ 0,  1,  0,  0,  0, -1, -1,  0,  0] [ 6,  9,  3]  1 */
    43350838, /* 59410 (1531) [ 0,  0, -1, -1,  0,  0,  0,  1,  0] [ 3,  3,  6] -1 */
    43999177, /* 59411 (1531) [ 0, -1,  0,  0,  0,  1, -1,  0,  0] [ 3,  6,  3] -1 */
    35440216, /* 59412 (1531) [ 0,  0,  1,  1,  0,  0,  0,  1,  0] [ 0,  6,  0] -1 */
    27638132, /* 59413 (1531) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 9,  9,  0]  1 */
    44651854, /* 59414 (1531) [ 0,  0,  1,  1,  0,  0,  0, -1,  0] [ 3,  9,  0] -1 */
      777961, /* 59415 (1531) [ 0,  0,  1, -1,  0,  0,  0, -1,  0] [ 0,  3,  3]  1 */
    17908167, /* 59416 (1531) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  3,  9]  1 */
    25696645, /* 59417 (1531) [ 0,  0,  1, -1,  0,  0,  0,  1,  0] [ 9,  0,  9]  1 */
    25689675, /* 59418 (1531) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 9,  0,  9]  1 */
     2313235, /* 59419 (1531) [ 0,  0,  1, -1,  0,  0,  0, -1,  0] [ 0,  9,  9]  1 */
    10109389, /* 59420 (1531) [ 0,  1,  0,  0,  0, -1,  1,  0,  0] [ 3,  6,  9]  1 */
     8574115, /* 59421 (1531) [ 0,  1,  0,  0,  0, -1,  1,  0,  0] [ 3,  0,  3]  1 */
        8866, /* 59422 (1531) [ 0,  0, -1, -1,  0,  0,  0, -1,  0] [ 0,  0,  0]  1 */
    18432154, /* 59423 (1531) [ 0,  0, -1, -1,  0,  0,  0, -1,  0] [ 6,  6,  0]  1 */
     8578427, /* 59424 (1531) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 3,  0,  3]  1 */
    10113701, /* 59425 (1531) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 3,  6,  9]  1 */
    10758964, /* 59426 (1531) [ 0,  1,  0,  0,  0,  1, -1,  0,  0] [ 3,  9,  6]  1 */
    34146806, /* 59427 (1531) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    51797965, /* 59428 (1531) [ 0,  1,  0,  0,  0, -1, -1,  0,  0] [ 6,  3,  3] -1 */
    18439772, /* 59429 (1531) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    17127408, /* 59430 (1531) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  6]  1 */
    10750118, /* 59431 (1531) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 3,  9,  6]  1 */
     9214844, /* 59432 (1531) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 3,  3,  0]  1 */
    17899537, /* 59433 (1531) [ 0, -1,  0,  0,  0,  1,  1,  0,  0] [ 6,  3,  9]  1 */
    44000857, /* 59434 (1531) [ 0,  0, -1,  1,  0,  0,  0, -1,  0] [ 3,  6,  3] -1 */
    44653090, /* 59435 (1531) [ 0,  1,  0,  0,  0,  1, -1,  0,  0] [ 3,  9,  0] -1 */
    51796297, /* 59436 (1531) [ 0,  0,  1, -1,  0,  0,  0, -1,  0] [ 6,  3,  3] -1 */
    44644244, /* 59437 (1531) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 3,  9,  0] -1 */
    51025954, /* 59438 (1531) [ 0, -1,  0,  0,  0, -1, -1,  0,  0] [ 6,  0,  0] -1 */
    18435352, /* 59439 (1531) [ 0,  1,  0,  0,  0,  1,  1,  0,  0] [ 6,  6,  0]  1 */
     1544140, /* 59440 (1531) [ 0,  0, -1, -1,  0,  0,  0, -1,  0] [ 0,  6,  6]  1 */
    52556808, /* 59441 (1531) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
     9228126, /* 59442 (1531) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 3,  3,  0]  1 */
    51027202, /* 59443 (1531) [ 0,  0, -1, -1,  0,  0,  0, -1,  0] [ 6,  0,  0] -1 */
       10816, /* 59444 (1531) [ 0,  0,  1,  1,  0,  0,  0,  1,  0] [ 0,  0,  0]  1 */
    18434104, /* 59445 (1531) [ 0,  0,  1,  1,  0,  0,  0,  1,  0] [ 6,  6,  0]  1 */
    44657526, /* 59446 (1531) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 3,  9,  0] -1 */
    59596763, /* 59447 (1531) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 9,  0,  3] -1 */
    42695787, /* 59448 (1531) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 3,  0,  9] -1 */
    42702757, /* 59449 (1531) [ 0,  0,  1, -1,  0,  0,  0,  1,  0] [ 3,  0,  9] -1 */
    61132037, /* 59450 (1531) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 9,  6,  9] -1 */
    53331571, /* 59451 (1531) [ 0,  0,  1, -1,  0,  0,  0, -1,  0] [ 6,  9,  9] -1 */
    59588113, /* 59452 (1531) [ 0, -1,  0,  0,  0,  1, -1,  0,  0] [ 9,  0,  3] -1 */
       12064, /* 59453 (1531) [ 0,  1,  0,  0,  0,  1,  1,  0,  0] [ 0,  0,  0]  1 */
    19194287, /* 59454 (1531) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  9,  3]  1 */
     9222454, /* 59455 (1531) [ 0,  0,  1,  1,  0,  0,  0, -1,  0] [ 3,  3,  0]  1 */
    59592451, /* 59456 (1531) [ 0,  1,  0,  0,  0, -1,  1,  0,  0] [ 9,  0,  3] -1 */
     1551758, /* 59457 (1531) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
     8571457, /* 59458 (1531) [ 0,  0, -1,  1,  0,  0,  0, -1,  0] [ 3,  0,  3]  1 */
    10754554, /* 59459 (1531) [ 0, -1,  0,  0,  0, -1,  1,  0,  0] [ 3,  9,  6]  1 */
    17902171, /* 59460 (1531) [ 0,  0,  1, -1,  0,  0,  0, -1,  0] [ 6,  3,  9]  1 */
     2314903, /* 59461 (1531) [ 0,  1,  0,  0,  0, -1, -1,  0,  0] [ 0,  9,  9]  1 */
    61776064, /* 59462 (1531) [ 0,  0,  1,  1,  0,  0,  0, -1,  0] [ 9,  9,  6] -1 */
    36204727, /* 59463 (1531) [ 0, -1,  0,  0,  0,  1,  1,  0,  0] [ 0,  9,  3] -1 */
    60240790, /* 59464 (1531) [ 0,  0,  1,  1,  0,  0,  0, -1,  0] [ 9,  3,  0] -1 */
    25702637, /* 59465 (1531) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 9,  0,  9]  1 */
    25693987, /* 59466 (1531) [ 0, -1,  0,  0,  0,  1, -1,  0,  0] [ 9,  0,  9]  1 */
    44648680, /* 59467 (1531) [ 0, -1,  0,  0,  0, -1,  1,  0,  0] [ 3,  9,  0] -1 */
    34905649, /* 59468 (1531) [ 0, -1,  0,  0,  0,  1,  1,  0,  0] [ 0,  3,  9] -1 */
     1546090, /* 59469 (1531) [ 0,  0,  1,  1,  0,  0,  0,  1,  0] [ 0,  6,  6]  1 */
    27651414, /* 59470 (1531) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 9,  9,  0]  1 */
    51030400, /* 59471 (1531) [ 0,  1,  0,  0,  0,  1,  1,  0,  0] [ 6,  0,  0] -1 */
     9223690, /* 59472 (1531) [ 0,  1,  0,  0,  0,  1, -1,  0,  0] [ 3,  3,  0]  1 */
    59589793, /* 59473 (1531) [ 0,  0, -1,  1,  0,  0,  0, -1,  0] [ 9,  0,  3] -1 */
    19198615, /* 59474 (1531) [ 0, -1,  0,  0,  0,  1,  1,  0,  0] [ 6,  9,  3]  1 */
    53333239, /* 59475 (1531) [ 0,  1,  0,  0,  0, -1, -1,  0,  0] [ 6,  9,  9] -1 */
    44649916, /* 59476 (1531) [ 0,  0, -1, -1,  0,  0,  0,  1,  0] [ 3,  9,  0] -1 */
    51789335, /* 59477 (1531) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  3,  3] -1 */
    36200399, /* 59478 (1531) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  9,  3] -1 */
    61777300, /* 59479 (1531) [ 0,  1,  0,  0,  0,  1, -1,  0,  0] [ 9,  9,  6] -1 */
    61768454, /* 59480 (1531) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 9,  9,  6] -1 */
    60242026, /* 59481 (1531) [ 0,  1,  0,  0,  0,  1, -1,  0,  0] [ 9,  3,  0] -1 */
    61125067, /* 59482 (1531) [ 0,  0, -1,  1,  0,  0,  0, -1,  0] [ 9,  6,  9] -1 */
    34908283, /* 59483 (1531) [ 0,  0,  1, -1,  0,  0,  0, -1,  0] [ 0,  3,  9] -1 */
    17133076, /* 59484 (1531) [ 0,  0, -1, -1,  0,  0,  0, -1,  0] [ 6,  0,  6]  1 */
    25695667, /* 59485 (1531) [ 0,  0, -1,  1,  0,  0,  0, -1,  0] [ 9,  0,  9]  1 */
    10763400, /* 59486 (1531) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 3,  9,  6]  1 */
    52562476, /* 59487 (1531) [ 0,  0, -1, -1,  0,  0,  0, -1,  0] [ 6,  6,  6] -1 */
    42708749, /* 59488 (1531) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 3,  0,  9] -1 */
    17903839, /* 59489 (1531) [ 0,  1,  0,  0,  0, -1, -1,  0,  0] [ 6,  3,  9]  1 */
    19200283, /* 59490 (1531) [ 0,  0, -1,  1,  0,  0,  0,  1,  0] [ 6,  9,  3]  1 */
      770999, /* 59491 (1531) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  3,  3]  1 */
    42700099, /* 59492 (1531) [ 0, -1,  0,  0,  0,  1, -1,  0,  0] [ 3,  0,  9] -1 */
    27643804, /* 59493 (1531) [ 0,  0, -1, -1,  0,  0,  0,  1,  0] [ 9,  9,  0]  1 */
        7618, /* 59494 (1531) [ 0, -1,  0,  0,  0, -1, -1,  0,  0] [ 0,  0,  0]  1 */
    18430906, /* 59495 (1531) [ 0, -1,  0,  0,  0, -1, -1,  0,  0] [ 6,  6,  0]  1 */
     2306273, /* 59496 (1531) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  9,  9]  1 */
    42704437, /* 59497 (1531) [ 0,  1,  0,  0,  0, -1,  1,  0,  0] [ 3,  0,  9] -1 */
    34139188, /* 59498 (1531) [ 0,  0, -1, -1,  0,  0,  0, -1,  0] [ 0,  0,  6] -1 */
    10106731, /* 59499 (1531) [ 0,  0, -1,  1,  0,  0,  0, -1,  0] [ 3,  6,  9]  1 */
    35437018, /* 59500 (1531) [ 0, -1,  0,  0,  0, -1, -1,  0,  0] [ 0,  6,  0] -1 */
     9219280, /* 59501 (1531) [ 0, -1,  0,  0,  0, -1,  1,  0,  0] [ 3,  3,  0]  1 */
    18426486, /* 59502 (1531) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
      783957, /* 59503 (1531) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  3,  3]  1 */
    43354012, /* 59504 (1531) [ 0,  1,  0,  0,  0,  1, -1,  0,  0] [ 3,  3,  6] -1 */
    26993065, /* 59505 (1531) [ 0, -1,  0,  0,  0,  1, -1,  0,  0] [ 9,  6,  3]  1 */
    19207245, /* 59506 (1531) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  9,  3]  1 */
    26995723, /* 59507 (1531) [ 0,  0,  1, -1,  0,  0,  0,  1,  0] [ 9,  6,  3]  1 */
    25698325, /* 59508 (1531) [ 0,  1,  0,  0,  0, -1,  1,  0,  0] [ 9,  0,  9]  1 */
    35432598, /* 59509 (1531) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  0] -1 */
    26988753, /* 59510 (1531) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 9,  6,  3]  1 */
    52570094, /* 59511 (1531) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
     1547338, /* 59512 (1531) [ 0,  1,  0,  0,  0,  1,  1,  0,  0] [ 0,  6,  6]  1 */
    61772890, /* 59513 (1531) [ 0, -1,  0,  0,  0, -1,  1,  0,  0] [ 9,  9,  6] -1 */
    60237616, /* 59514 (1531) [ 0, -1,  0,  0,  0, -1,  1,  0,  0] [ 9,  3,  0] -1 */
    17135026, /* 59515 (1531) [ 0,  0,  1,  1,  0,  0,  0,  1,  0] [ 6,  0,  6]  1 */
     9220516, /* 59516 (1531) [ 0,  0, -1, -1,  0,  0,  0,  1,  0] [ 3,  3,  0]  1 */
    10755790, /* 59517 (1531) [ 0,  0, -1, -1,  0,  0,  0,  1,  0] [ 3,  9,  6]  1 */
     1542892, /* 59518 (1531) [ 0, -1,  0,  0,  0, -1, -1,  0,  0] [ 0,  6,  6]  1 */
    34142386, /* 59519 (1531) [ 0,  1,  0,  0,  0,  1,  1,  0,  0] [ 0,  0,  6] -1 */
    52565674, /* 59520 (1531) [ 0,  1,  0,  0,  0,  1,  1,  0,  0] [ 6,  6,  6] -1 */
    42701779, /* 59521 (1531) [ 0,  0, -1,  1,  0,  0,  0, -1,  0] [ 3,  0,  9] -1 */
    34909951, /* 59522 (1531) [ 0,  1,  0,  0,  0, -1, -1,  0,  0] [ 0,  3,  9] -1 */
    34141138, /* 59523 (1531) [ 0,  0,  1,  1,  0,  0,  0,  1,  0] [ 0,  0,  6] -1 */
    52564426, /* 59524 (1531) [ 0,  0,  1,  1,  0,  0,  0,  1,  0] [ 6,  6,  6] -1 */
     1538472, /* 59525 (1531) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
     2310601, /* 59526 (1531) [ 0, -1,  0,  0,  0,  1,  1,  0,  0] [ 0,  9,  9]  1 */
    36206395, /* 59527 (1531) [ 0,  0, -1,  1,  0,  0,  0,  1,  0] [ 0,  9,  3] -1 */
    51029152, /* 59528 (1531) [ 0,  0,  1,  1,  0,  0,  0,  1,  0] [ 6,  0,  0] -1 */
    34901321, /* 59529 (1531) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  3,  9] -1 */
    53324609, /* 59530 (1531) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  9,  9] -1 */
    59583801, /* 59531 (1531) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 9,  0,  3] -1 */
    43352776, /* 59532 (1531) [ 0,  0,  1,  1,  0,  0,  0, -1,  0] [ 3,  3,  6] -1 */
    60233180, /* 59533 (1531) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 9,  3,  0] -1 */
    43349602, /* 59534 (1531) [ 0, -1,  0,  0,  0, -1,  1,  0,  0] [ 3,  3,  6] -1 */
    17895209, /* 59535 (1531) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  3,  9]  1 */
    51802293, /* 59536 (1531) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  3,  3] -1 */
    36213357, /* 59537 (1531) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  9,  3] -1 */
    44001835, /* 59538 (1531) [ 0,  0,  1, -1,  0,  0,  0,  1,  0] [ 3,  6,  3] -1 */
    43994865, /* 59539 (1531) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 3,  6,  3] -1 */
    61123387, /* 59540 (1531) [ 0, -1,  0,  0,  0,  1, -1,  0,  0] [ 9,  6,  9] -1 */
    44003515, /* 59541 (1531) [ 0,  1,  0,  0,  0, -1,  1,  0,  0] [ 3,  6,  3] -1 */
    60246462, /* 59542 (1531) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 9,  3,  0] -1 */
      776995, /* 59543 (1531) [ 0,  0, -1,  1,  0,  0,  0,  1,  0] [ 0,  3,  3]  1 */
    61781736, /* 59544 (1531) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 9,  9,  6] -1 */
     2312269, /* 59545 (1531) [ 0,  0, -1,  1,  0,  0,  0,  1,  0] [ 0,  9,  9]  1 */
    27646978, /* 59546 (1531) [ 0,  1,  0,  0,  0,  1, -1,  0,  0] [ 9,  9,  0]  1 */
       16484, /* 59547 (1532) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    18557868, /* 59548 (1532) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
    18544584, /* 59549 (1532) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
       16320, /* 59550 (1532) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
        3198, /* 59551 (1532) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    18552196, /* 59552 (1532) [ 0,  0,  1,  1,  0,  0,  0, -1,  0] [ 6,  6,  6]  1 */
    18550252, /* 59553 (1532) [ 0,  0, -1, -1,  0,  0,  0, -1,  0] [ 6,  6,  6]  1 */
        7690, /* 59554 (1532) [ 0, -1,  0,  0,  0,  1,  1,  0,  0] [ 0,  0,  0]  1 */
        8866, /* 59555 (1532) [ 0,  0, -1, -1,  0,  0,  0, -1,  0] [ 0,  0,  0]  1 */
       10810, /* 59556 (1532) [ 0,  0,  1,  1,  0,  0,  0, -1,  0] [ 0,  0,  0]  1 */
    18549022, /* 59557 (1532) [ 0, -1,  0,  0,  0, -1,  1,  0,  0] [ 6,  6,  6]  1 */
    18549076, /* 59558 (1532) [ 0, -1,  0,  0,  0,  1,  1,  0,  0] [ 6,  6,  6]  1 */
    18550738, /* 59559 (1532) [ 0,  0, -1,  1,  0,  0,  0, -1,  0] [ 6,  6,  6]  1 */
        7636, /* 59560 (1532) [ 0, -1,  0,  0,  0, -1,  1,  0,  0] [ 0,  0,  0]  1 */
        9352, /* 59561 (1532) [ 0,  0, -1,  1,  0,  0,  0, -1,  0] [ 0,  0,  0]  1 */
    18544746, /* 59562 (1532) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
    18557870, /* 59563 (1532) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
        8872, /* 59564 (1532) [ 0,  0, -1, -1,  0,  0,  0,  1,  0] [ 0,  0,  0]  1 */
    18551716, /* 59565 (1532) [ 0,  0,  1, -1,  0,  0,  0,  1,  0] [ 6,  6,  6]  1 */
    18550744, /* 59566 (1532) [ 0,  0, -1,  1,  0,  0,  0,  1,  0] [ 6,  6,  6]  1 */
    18553396, /* 59567 (1532) [ 0,  1,  0,  0,  0, -1,  1,  0,  0] [ 6,  6,  6]  1 */
    18550258, /* 59568 (1532) [ 0,  0, -1, -1,  0,  0,  0,  1,  0] [ 6,  6,  6]  1 */
        7672, /* 59569 (1532) [ 0, -1,  0,  0,  0,  1, -1,  0,  0] [ 0,  0,  0]  1 */
       10330, /* 59570 (1532) [ 0,  0,  1, -1,  0,  0,  0,  1,  0] [ 0,  0,  0]  1 */
    18553432, /* 59571 (1532) [ 0,  1,  0,  0,  0,  1, -1,  0,  0] [ 6,  6,  6]  1 */
        3360, /* 59572 (1532) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    18557708, /* 59573 (1532) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    18549058, /* 59574 (1532) [ 0, -1,  0,  0,  0,  1, -1,  0,  0] [ 6,  6,  6]  1 */
    18544748, /* 59575 (1532) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
       12046, /* 59576 (1532) [ 0,  1,  0,  0,  0,  1, -1,  0,  0] [ 0,  0,  0]  1 */
       12010, /* 59577 (1532) [ 0,  1,  0,  0,  0, -1,  1,  0,  0] [ 0,  0,  0]  1 */
       16322, /* 59578 (1532) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    18553378, /* 59579 (1532) [ 0,  1,  0,  0,  0, -1, -1,  0,  0] [ 6,  6,  6]  1 */
       10816, /* 59580 (1532) [ 0,  0,  1,  1,  0,  0,  0,  1,  0] [ 0,  0,  0]  1 */
        3200, /* 59581 (1532) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
        3362, /* 59582 (1532) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
        9358, /* 59583 (1532) [ 0,  0, -1,  1,  0,  0,  0,  1,  0] [ 0,  0,  0]  1 */
    18553450, /* 59584 (1532) [ 0,  1,  0,  0,  0,  1,  1,  0,  0] [ 6,  6,  6]  1 */
       11992, /* 59585 (1532) [ 0,  1,  0,  0,  0, -1, -1,  0,  0] [ 0,  0,  0]  1 */
    18552202, /* 59586 (1532) [ 0,  0,  1,  1,  0,  0,  0,  1,  0] [ 6,  6,  6]  1 */
       12064, /* 59587 (1532) [ 0,  1,  0,  0,  0,  1,  1,  0,  0] [ 0,  0,  0]  1 */
    18544586, /* 59588 (1532) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    18551710, /* 59589 (1532) [ 0,  0,  1, -1,  0,  0,  0, -1,  0] [ 6,  6,  6]  1 */
    18549004, /* 59590 (1532) [ 0, -1,  0,  0,  0, -1, -1,  0,  0] [ 6,  6,  6]  1 */
        7618, /* 59591 (1532) [ 0, -1,  0,  0,  0, -1, -1,  0,  0] [ 0,  0,  0]  1 */
       16482, /* 59592 (1532) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
       10324, /* 59593 (1532) [ 0,  0,  1, -1,  0,  0,  0, -1,  0] [ 0,  0,  0]  1 */
    18557706, /* 59594 (1532) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
       16484, /* 59595 (1533) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    52562962, /* 59596 (1533) [ 0,  0, -1,  1,  0,  0,  0, -1,  0] [ 6,  6,  6] -1 */
       16320, /* 59597 (1533) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
        3198, /* 59598 (1533) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    52562968, /* 59599 (1533) [ 0,  0, -1,  1,  0,  0,  0,  1,  0] [ 6,  6,  6] -1 */
    34019896, /* 59600 (1533) [ 0, -1,  0,  0,  0,  1, -1,  0,  0] [ 0,  0,  0] -1 */
    52565656, /* 59601 (1533) [ 0,  1,  0,  0,  0,  1, -1,  0,  0] [ 6,  6,  6] -1 */
    52565620, /* 59602 (1533) [ 0,  1,  0,  0,  0, -1,  1,  0,  0] [ 6,  6,  6] -1 */
    34015584, /* 59603 (1533) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    34024234, /* 59604 (1533) [ 0,  1,  0,  0,  0, -1,  1,  0,  0] [ 0,  0,  0] -1 */
        9352, /* 59605 (1533) [ 0,  0, -1,  1,  0,  0,  0, -1,  0] [ 0,  0,  0]  1 */
    52556972, /* 59606 (1533) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    18544746, /* 59607 (1533) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
    34023040, /* 59608 (1533) [ 0,  0,  1,  1,  0,  0,  0,  1,  0] [ 0,  0,  0] -1 */
    18557870, /* 59609 (1533) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    52556810, /* 59610 (1533) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
        8872, /* 59611 (1533) [ 0,  0, -1, -1,  0,  0,  0,  1,  0] [ 0,  0,  0]  1 */
    52561228, /* 59612 (1533) [ 0, -1,  0,  0,  0, -1, -1,  0,  0] [ 6,  6,  6] -1 */
    34024288, /* 59613 (1533) [ 0,  1,  0,  0,  0,  1,  1,  0,  0] [ 0,  0,  0] -1 */
    18549058, /* 59614 (1533) [ 0, -1,  0,  0,  0,  1, -1,  0,  0] [ 6,  6,  6]  1 */
    52570092, /* 59615 (1533) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    18553378, /* 59616 (1533) [ 0,  1,  0,  0,  0, -1, -1,  0,  0] [ 6,  6,  6]  1 */
    52564420, /* 59617 (1533) [ 0,  0,  1,  1,  0,  0,  0, -1,  0] [ 6,  6,  6] -1 */
    18552202, /* 59618 (1533) [ 0,  0,  1,  1,  0,  0,  0,  1,  0] [ 6,  6,  6]  1 */
    34023034, /* 59619 (1533) [ 0,  0,  1,  1,  0,  0,  0, -1,  0] [ 0,  0,  0] -1 */
    52561246, /* 59620 (1533) [ 0, -1,  0,  0,  0, -1,  1,  0,  0] [ 6,  6,  6] -1 */
       10324, /* 59621 (1533) [ 0,  0,  1, -1,  0,  0,  0, -1,  0] [ 0,  0,  0]  1 */
    18550252, /* 59622 (1533) [ 0,  0, -1, -1,  0,  0,  0, -1,  0] [ 6,  6,  6]  1 */
        8866, /* 59623 (1533) [ 0,  0, -1, -1,  0,  0,  0, -1,  0] [ 0,  0,  0]  1 */
    52562482, /* 59624 (1533) [ 0,  0, -1, -1,  0,  0,  0,  1,  0] [ 6,  6,  6] -1 */
    34022554, /* 59625 (1533) [ 0,  0,  1, -1,  0,  0,  0,  1,  0] [ 0,  0,  0] -1 */
    34024270, /* 59626 (1533) [ 0,  1,  0,  0,  0,  1, -1,  0,  0] [ 0,  0,  0] -1 */
    34015424, /* 59627 (1533) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    34028708, /* 59628 (1533) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    34021582, /* 59629 (1533) [ 0,  0, -1,  1,  0,  0,  0,  1,  0] [ 0,  0,  0] -1 */
    34015586, /* 59630 (1533) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    18550744, /* 59631 (1533) [ 0,  0, -1,  1,  0,  0,  0,  1,  0] [ 6,  6,  6]  1 */
    34028706, /* 59632 (1533) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    18553396, /* 59633 (1533) [ 0,  1,  0,  0,  0, -1,  1,  0,  0] [ 6,  6,  6]  1 */
    34019842, /* 59634 (1533) [ 0, -1,  0,  0,  0, -1, -1,  0,  0] [ 0,  0,  0] -1 */
    52569930, /* 59635 (1533) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    18557708, /* 59636 (1533) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    18544748, /* 59637 (1533) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    34028544, /* 59638 (1533) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    52556808, /* 59639 (1533) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
       10816, /* 59640 (1533) [ 0,  0,  1,  1,  0,  0,  0,  1,  0] [ 0,  0,  0]  1 */
    34015422, /* 59641 (1533) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    18553450, /* 59642 (1533) [ 0,  1,  0,  0,  0,  1,  1,  0,  0] [ 6,  6,  6]  1 */
       11992, /* 59643 (1533) [ 0,  1,  0,  0,  0, -1, -1,  0,  0] [ 0,  0,  0]  1 */
       12064, /* 59644 (1533) [ 0,  1,  0,  0,  0,  1,  1,  0,  0] [ 0,  0,  0]  1 */
    34019914, /* 59645 (1533) [ 0, -1,  0,  0,  0,  1,  1,  0,  0] [ 0,  0,  0] -1 */
    18557868, /* 59646 (1533) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
    34019860, /* 59647 (1533) [ 0, -1,  0,  0,  0, -1,  1,  0,  0] [ 0,  0,  0] -1 */
    18552196, /* 59648 (1533) [ 0,  0,  1,  1,  0,  0,  0, -1,  0] [ 6,  6,  6]  1 */
    52563940, /* 59649 (1533) [ 0,  0,  1, -1,  0,  0,  0,  1,  0] [ 6,  6,  6] -1 */
    18549076, /* 59650 (1533) [ 0, -1,  0,  0,  0,  1,  1,  0,  0] [ 6,  6,  6]  1 */
    18550738, /* 59651 (1533) [ 0,  0, -1,  1,  0,  0,  0, -1,  0] [ 6,  6,  6]  1 */
    34028546, /* 59652 (1533) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    52563934, /* 59653 (1533) [ 0,  0,  1, -1,  0,  0,  0, -1,  0] [ 6,  6,  6] -1 */
    34022548, /* 59654 (1533) [ 0,  0,  1, -1,  0,  0,  0, -1,  0] [ 0,  0,  0] -1 */
        7672, /* 59655 (1533) [ 0, -1,  0,  0,  0,  1, -1,  0,  0] [ 0,  0,  0]  1 */
       10330, /* 59656 (1533) [ 0,  0,  1, -1,  0,  0,  0,  1,  0] [ 0,  0,  0]  1 */
    18553432, /* 59657 (1533) [ 0,  1,  0,  0,  0,  1, -1,  0,  0] [ 6,  6,  6]  1 */
        3360, /* 59658 (1533) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
       12010, /* 59659 (1533) [ 0,  1,  0,  0,  0, -1,  1,  0,  0] [ 0,  0,  0]  1 */
       12046, /* 59660 (1533) [ 0,  1,  0,  0,  0,  1, -1,  0,  0] [ 0,  0,  0]  1 */
        3362, /* 59661 (1533) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    52562476, /* 59662 (1533) [ 0,  0, -1, -1,  0,  0,  0, -1,  0] [ 6,  6,  6] -1 */
    52561300, /* 59663 (1533) [ 0, -1,  0,  0,  0,  1,  1,  0,  0] [ 6,  6,  6] -1 */
    18544586, /* 59664 (1533) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    18549004, /* 59665 (1533) [ 0, -1,  0,  0,  0, -1, -1,  0,  0] [ 6,  6,  6]  1 */
        7618, /* 59666 (1533) [ 0, -1,  0,  0,  0, -1, -1,  0,  0] [ 0,  0,  0]  1 */
    18557706, /* 59667 (1533) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
    18544584, /* 59668 (1533) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
    34021576, /* 59669 (1533) [ 0,  0, -1,  1,  0,  0,  0, -1,  0] [ 0,  0,  0] -1 */
    52556970, /* 59670 (1533) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    52570094, /* 59671 (1533) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    34021096, /* 59672 (1533) [ 0,  0, -1, -1,  0,  0,  0,  1,  0] [ 0,  0,  0] -1 */
        7690, /* 59673 (1533) [ 0, -1,  0,  0,  0,  1,  1,  0,  0] [ 0,  0,  0]  1 */
       10810, /* 59674 (1533) [ 0,  0,  1,  1,  0,  0,  0, -1,  0] [ 0,  0,  0]  1 */
    18549022, /* 59675 (1533) [ 0, -1,  0,  0,  0, -1,  1,  0,  0] [ 6,  6,  6]  1 */
    52569932, /* 59676 (1533) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
        7636, /* 59677 (1533) [ 0, -1,  0,  0,  0, -1,  1,  0,  0] [ 0,  0,  0]  1 */
    52561282, /* 59678 (1533) [ 0, -1,  0,  0,  0,  1, -1,  0,  0] [ 6,  6,  6] -1 */
    52565602, /* 59679 (1533) [ 0,  1,  0,  0,  0, -1, -1,  0,  0] [ 6,  6,  6] -1 */
    52565674, /* 59680 (1533) [ 0,  1,  0,  0,  0,  1,  1,  0,  0] [ 6,  6,  6] -1 */
    34024216, /* 59681 (1533) [ 0,  1,  0,  0,  0, -1, -1,  0,  0] [ 0,  0,  0] -1 */
    52564426, /* 59682 (1533) [ 0,  0,  1,  1,  0,  0,  0,  1,  0] [ 6,  6,  6] -1 */
    18551716, /* 59683 (1533) [ 0,  0,  1, -1,  0,  0,  0,  1,  0] [ 6,  6,  6]  1 */
    18550258, /* 59684 (1533) [ 0,  0, -1, -1,  0,  0,  0,  1,  0] [ 6,  6,  6]  1 */
       16322, /* 59685 (1533) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
        3200, /* 59686 (1533) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
        9358, /* 59687 (1533) [ 0,  0, -1,  1,  0,  0,  0,  1,  0] [ 0,  0,  0]  1 */
    18551710, /* 59688 (1533) [ 0,  0,  1, -1,  0,  0,  0, -1,  0] [ 6,  6,  6]  1 */
    34021090, /* 59689 (1533) [ 0,  0, -1, -1,  0,  0,  0, -1,  0] [ 0,  0,  0] -1 */
       16482, /* 59690 (1533) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
       16484, /* 59691 (1534) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
       16320, /* 59692 (1534) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    52563940, /* 59693 (1534) [ 0,  0,  1, -1,  0,  0,  0,  1,  0] [ 6,  6,  6] -1 */
    52562968, /* 59694 (1534) [ 0,  0, -1,  1,  0,  0,  0,  1,  0] [ 6,  6,  6] -1 */
    18549022, /* 59695 (1534) [ 0, -1,  0,  0,  0, -1,  1,  0,  0] [ 6,  6,  6]  1 */
    52565656, /* 59696 (1534) [ 0,  1,  0,  0,  0,  1, -1,  0,  0] [ 6,  6,  6] -1 */
    52569932, /* 59697 (1534) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    52565620, /* 59698 (1534) [ 0,  1,  0,  0,  0, -1,  1,  0,  0] [ 6,  6,  6] -1 */
    18550738, /* 59699 (1534) [ 0,  0, -1,  1,  0,  0,  0, -1,  0] [ 6,  6,  6]  1 */
        7636, /* 59700 (1534) [ 0, -1,  0,  0,  0, -1,  1,  0,  0] [ 0,  0,  0]  1 */
    34022554, /* 59701 (1534) [ 0,  0,  1, -1,  0,  0,  0,  1,  0] [ 0,  0,  0] -1 */
    34024234, /* 59702 (1534) [ 0,  1,  0,  0,  0, -1,  1,  0,  0] [ 0,  0,  0] -1 */
        9352, /* 59703 (1534) [ 0,  0, -1,  1,  0,  0,  0, -1,  0] [ 0,  0,  0]  1 */
    52556972, /* 59704 (1534) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    34024270, /* 59705 (1534) [ 0,  1,  0,  0,  0,  1, -1,  0,  0] [ 0,  0,  0] -1 */
    34028546, /* 59706 (1534) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    34021582, /* 59707 (1534) [ 0,  0, -1,  1,  0,  0,  0,  1,  0] [ 0,  0,  0] -1 */
    18544746, /* 59708 (1534) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
    34015586, /* 59709 (1534) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    18557870, /* 59710 (1534) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
        8872, /* 59711 (1534) [ 0,  0, -1, -1,  0,  0,  0,  1,  0] [ 0,  0,  0]  1 */
    52561228, /* 59712 (1534) [ 0, -1,  0,  0,  0, -1, -1,  0,  0] [ 6,  6,  6] -1 */
    34028706, /* 59713 (1534) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    18550258, /* 59714 (1534) [ 0,  0, -1, -1,  0,  0,  0,  1,  0] [ 6,  6,  6]  1 */
    34019842, /* 59715 (1534) [ 0, -1,  0,  0,  0, -1, -1,  0,  0] [ 0,  0,  0] -1 */
        7672, /* 59716 (1534) [ 0, -1,  0,  0,  0,  1, -1,  0,  0] [ 0,  0,  0]  1 */
        3360, /* 59717 (1534) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    52570092, /* 59718 (1534) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    18549058, /* 59719 (1534) [ 0, -1,  0,  0,  0,  1, -1,  0,  0] [ 6,  6,  6]  1 */
    52556808, /* 59720 (1534) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    18553378, /* 59721 (1534) [ 0,  1,  0,  0,  0, -1, -1,  0,  0] [ 6,  6,  6]  1 */
       10816, /* 59722 (1534) [ 0,  0,  1,  1,  0,  0,  0,  1,  0] [ 0,  0,  0]  1 */
    34015422, /* 59723 (1534) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
        3200, /* 59724 (1534) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    18553450, /* 59725 (1534) [ 0,  1,  0,  0,  0,  1,  1,  0,  0] [ 6,  6,  6]  1 */
    52562476, /* 59726 (1534) [ 0,  0, -1, -1,  0,  0,  0, -1,  0] [ 6,  6,  6] -1 */
       11992, /* 59727 (1534) [ 0,  1,  0,  0,  0, -1, -1,  0,  0] [ 0,  0,  0]  1 */
    52564420, /* 59728 (1534) [ 0,  0,  1,  1,  0,  0,  0, -1,  0] [ 6,  6,  6] -1 */
    18552202, /* 59729 (1534) [ 0,  0,  1,  1,  0,  0,  0,  1,  0] [ 6,  6,  6]  1 */
       12064, /* 59730 (1534) [ 0,  1,  0,  0,  0,  1,  1,  0,  0] [ 0,  0,  0]  1 */
    18544586, /* 59731 (1534) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    18551710, /* 59732 (1534) [ 0,  0,  1, -1,  0,  0,  0, -1,  0] [ 6,  6,  6]  1 */
    34023034, /* 59733 (1534) [ 0,  0,  1,  1,  0,  0,  0, -1,  0] [ 0,  0,  0] -1 */
    34019914, /* 59734 (1534) [ 0, -1,  0,  0,  0,  1,  1,  0,  0] [ 0,  0,  0] -1 */
    34021090, /* 59735 (1534) [ 0,  0, -1, -1,  0,  0,  0, -1,  0] [ 0,  0,  0] -1 */
    52561300, /* 59736 (1534) [ 0, -1,  0,  0,  0,  1,  1,  0,  0] [ 6,  6,  6] -1 */
       10324, /* 59737 (1534) [ 0,  0,  1, -1,  0,  0,  0, -1,  0] [ 0,  0,  0]  1 */
    18557706, /* 59738 (1534) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
       16484, /* 59739 (1535) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
     1545604, /* 59740 (1535) [ 0,  0,  1, -1,  0,  0,  0,  1,  0] [ 0,  6,  6]  1 */
     1547284, /* 59741 (1535) [ 0,  1,  0,  0,  0, -1,  1,  0,  0] [ 0,  6,  6]  1 */
    18439608, /* 59742 (1535) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
     1551596, /* 59743 (1535) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
    17133082, /* 59744 (1535) [ 0,  0, -1, -1,  0,  0,  0,  1,  0] [ 6,  0,  6]  1 */
     1542946, /* 59745 (1535) [ 0, -1,  0,  0,  0,  1, -1,  0,  0] [ 0,  6,  6]  1 */
        3198, /* 59746 (1535) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    17136256, /* 59747 (1535) [ 0,  1,  0,  0,  0,  1, -1,  0,  0] [ 6,  0,  6]  1 */
    17127410, /* 59748 (1535) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
        8866, /* 59749 (1535) [ 0,  0, -1, -1,  0,  0,  0, -1,  0] [ 0,  0,  0]  1 */
    18430978, /* 59750 (1535) [ 0, -1,  0,  0,  0,  1,  1,  0,  0] [ 6,  6,  0]  1 */
    17140692, /* 59751 (1535) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6]  1 */
    18426650, /* 59752 (1535) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    17135020, /* 59753 (1535) [ 0,  0,  1,  1,  0,  0,  0, -1,  0] [ 6,  0,  6]  1 */
    18432646, /* 59754 (1535) [ 0,  0, -1,  1,  0,  0,  0,  1,  0] [ 6,  6,  0]  1 */
    18435280, /* 59755 (1535) [ 0,  1,  0,  0,  0, -1, -1,  0,  0] [ 6,  6,  0]  1 */
     1544626, /* 59756 (1535) [ 0,  0, -1,  1,  0,  0,  0, -1,  0] [ 0,  6,  6]  1 */
       10816, /* 59757 (1535) [ 0,  0,  1,  1,  0,  0,  0,  1,  0] [ 0,  0,  0]  1 */
    18433612, /* 59758 (1535) [ 0,  0,  1, -1,  0,  0,  0, -1,  0] [ 6,  6,  0]  1 */
       12064, /* 59759 (1535) [ 0,  1,  0,  0,  0,  1,  1,  0,  0] [ 0,  0,  0]  1 */
    17131846, /* 59760 (1535) [ 0, -1,  0,  0,  0, -1,  1,  0,  0] [ 6,  0,  6]  1 */
        7618, /* 59761 (1535) [ 0, -1,  0,  0,  0, -1, -1,  0,  0] [ 0,  0,  0]  1 */
     1538634, /* 59762 (1535) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
       16484, /* 59763 (1536) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
     1545604, /* 59764 (1536) [ 0,  0,  1, -1,  0,  0,  0,  1,  0] [ 0,  6,  6]  1 */
     1547284, /* 59765 (1536) [ 0,  1,  0,  0,  0, -1,  1,  0,  0] [ 0,  6,  6]  1 */
    18439608, /* 59766 (1536) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
     1551596, /* 59767 (1536) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
    17133082, /* 59768 (1536) [ 0,  0, -1, -1,  0,  0,  0,  1,  0] [ 6,  0,  6]  1 */
     1542946, /* 59769 (1536) [ 0, -1,  0,  0,  0,  1, -1,  0,  0] [ 0,  6,  6]  1 */
        3198, /* 59770 (1536) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    17136256, /* 59771 (1536) [ 0,  1,  0,  0,  0,  1, -1,  0,  0] [ 6,  0,  6]  1 */
    17127410, /* 59772 (1536) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
    51152916, /* 59773 (1536) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6] -1 */
        8866, /* 59774 (1536) [ 0,  0, -1, -1,  0,  0,  0, -1,  0] [ 0,  0,  0]  1 */
    18430978, /* 59775 (1536) [ 0, -1,  0,  0,  0,  1,  1,  0,  0] [ 6,  6,  0]  1 */
    52447504, /* 59776 (1536) [ 0,  1,  0,  0,  0, -1, -1,  0,  0] [ 6,  6,  0] -1 */
    52438874, /* 59777 (1536) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
    51147244, /* 59778 (1536) [ 0,  0,  1,  1,  0,  0,  0, -1,  0] [ 6,  0,  6] -1 */
    52444870, /* 59779 (1536) [ 0,  0, -1,  1,  0,  0,  0,  1,  0] [ 6,  6,  0] -1 */
    35556850, /* 59780 (1536) [ 0,  0, -1,  1,  0,  0,  0, -1,  0] [ 0,  6,  6] -1 */
    34028708, /* 59781 (1536) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    34023040, /* 59782 (1536) [ 0,  0,  1,  1,  0,  0,  0,  1,  0] [ 0,  0,  0] -1 */
    52445836, /* 59783 (1536) [ 0,  0,  1, -1,  0,  0,  0, -1,  0] [ 6,  6,  0] -1 */
    17140692, /* 59784 (1536) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6]  1 */
    34024288, /* 59785 (1536) [ 0,  1,  0,  0,  0,  1,  1,  0,  0] [ 0,  0,  0] -1 */
    51144070, /* 59786 (1536) [ 0, -1,  0,  0,  0, -1,  1,  0,  0] [ 6,  0,  6] -1 */
    18426650, /* 59787 (1536) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    17135020, /* 59788 (1536) [ 0,  0,  1,  1,  0,  0,  0, -1,  0] [ 6,  0,  6]  1 */
    18432646, /* 59789 (1536) [ 0,  0, -1,  1,  0,  0,  0,  1,  0] [ 6,  6,  0]  1 */
    34019842, /* 59790 (1536) [ 0, -1,  0,  0,  0, -1, -1,  0,  0] [ 0,  0,  0] -1 */
    35557828, /* 59791 (1536) [ 0,  0,  1, -1,  0,  0,  0,  1,  0] [ 0,  6,  6] -1 */
    18435280, /* 59792 (1536) [ 0,  1,  0,  0,  0, -1, -1,  0,  0] [ 6,  6,  0]  1 */
    35550858, /* 59793 (1536) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6] -1 */
    35559508, /* 59794 (1536) [ 0,  1,  0,  0,  0, -1,  1,  0,  0] [ 0,  6,  6] -1 */
    52451832, /* 59795 (1536) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
    51145306, /* 59796 (1536) [ 0,  0, -1, -1,  0,  0,  0,  1,  0] [ 6,  0,  6] -1 */
    35563820, /* 59797 (1536) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
     1544626, /* 59798 (1536) [ 0,  0, -1,  1,  0,  0,  0, -1,  0] [ 0,  6,  6]  1 */
       10816, /* 59799 (1536) [ 0,  0,  1,  1,  0,  0,  0,  1,  0] [ 0,  0,  0]  1 */
    34015422, /* 59800 (1536) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    35555170, /* 59801 (1536) [ 0, -1,  0,  0,  0,  1, -1,  0,  0] [ 0,  6,  6] -1 */
    18433612, /* 59802 (1536) [ 0,  0,  1, -1,  0,  0,  0, -1,  0] [ 6,  6,  0]  1 */
    51148480, /* 59803 (1536) [ 0,  1,  0,  0,  0,  1, -1,  0,  0] [ 6,  0,  6] -1 */
    51139634, /* 59804 (1536) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
       12064, /* 59805 (1536) [ 0,  1,  0,  0,  0,  1,  1,  0,  0] [ 0,  0,  0]  1 */
    52443202, /* 59806 (1536) [ 0, -1,  0,  0,  0,  1,  1,  0,  0] [ 6,  6,  0] -1 */
    17131846, /* 59807 (1536) [ 0, -1,  0,  0,  0, -1,  1,  0,  0] [ 6,  0,  6]  1 */
    34021090, /* 59808 (1536) [ 0,  0, -1, -1,  0,  0,  0, -1,  0] [ 0,  0,  0] -1 */
        7618, /* 59809 (1536) [ 0, -1,  0,  0,  0, -1, -1,  0,  0] [ 0,  0,  0]  1 */
     1538634, /* 59810 (1536) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
       16484, /* 59811 (1537) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    18439608, /* 59812 (1537) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
     1542946, /* 59813 (1537) [ 0, -1,  0,  0,  0,  1, -1,  0,  0] [ 0,  6,  6]  1 */
    17133082, /* 59814 (1537) [ 0,  0, -1, -1,  0,  0,  0,  1,  0] [ 6,  0,  6]  1 */
    17127410, /* 59815 (1537) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
    51152916, /* 59816 (1537) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6] -1 */
    52438874, /* 59817 (1537) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
    51147244, /* 59818 (1537) [ 0,  0,  1,  1,  0,  0,  0, -1,  0] [ 6,  0,  6] -1 */
    52444870, /* 59819 (1537) [ 0,  0, -1,  1,  0,  0,  0,  1,  0] [ 6,  6,  0] -1 */
    34019842, /* 59820 (1537) [ 0, -1,  0,  0,  0, -1, -1,  0,  0] [ 0,  0,  0] -1 */
    35557828, /* 59821 (1537) [ 0,  0,  1, -1,  0,  0,  0,  1,  0] [ 0,  6,  6] -1 */
    18435280, /* 59822 (1537) [ 0,  1,  0,  0,  0, -1, -1,  0,  0] [ 6,  6,  0]  1 */
    35559508, /* 59823 (1537) [ 0,  1,  0,  0,  0, -1,  1,  0,  0] [ 0,  6,  6] -1 */
    35563820, /* 59824 (1537) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
     1544626, /* 59825 (1537) [ 0,  0, -1,  1,  0,  0,  0, -1,  0] [ 0,  6,  6]  1 */
    34015422, /* 59826 (1537) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
       10816, /* 59827 (1537) [ 0,  0,  1,  1,  0,  0,  0,  1,  0] [ 0,  0,  0]  1 */
    18433612, /* 59828 (1537) [ 0,  0,  1, -1,  0,  0,  0, -1,  0] [ 6,  6,  0]  1 */
    51148480, /* 59829 (1537) [ 0,  1,  0,  0,  0,  1, -1,  0,  0] [ 6,  0,  6] -1 */
       12064, /* 59830 (1537) [ 0,  1,  0,  0,  0,  1,  1,  0,  0] [ 0,  0,  0]  1 */
    52443202, /* 59831 (1537) [ 0, -1,  0,  0,  0,  1,  1,  0,  0] [ 6,  6,  0] -1 */
    17131846, /* 59832 (1537) [ 0, -1,  0,  0,  0, -1,  1,  0,  0] [ 6,  0,  6]  1 */
    34021090, /* 59833 (1537) [ 0,  0, -1, -1,  0,  0,  0, -1,  0] [ 0,  0,  0] -1 */
     1538634, /* 59834 (1537) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
       16484, /* 59835 (1538) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    35445882, /* 59836 (1538) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  0] -1 */
     1545604, /* 59837 (1538) [ 0,  0,  1, -1,  0,  0,  0,  1,  0] [ 0,  6,  6]  1 */
     1547284, /* 59838 (1538) [ 0,  1,  0,  0,  0, -1,  1,  0,  0] [ 0,  6,  6]  1 */
    18439608, /* 59839 (1538) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
    34138012, /* 59840 (1538) [ 0, -1,  0,  0,  0,  1,  1,  0,  0] [ 0,  0,  6] -1 */
     1551596, /* 59841 (1538) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
    17133082, /* 59842 (1538) [ 0,  0, -1, -1,  0,  0,  0,  1,  0] [ 6,  0,  6]  1 */
     1542946, /* 59843 (1538) [ 0, -1,  0,  0,  0,  1, -1,  0,  0] [ 0,  6,  6]  1 */
    51027688, /* 59844 (1538) [ 0,  0, -1,  1,  0,  0,  0, -1,  0] [ 6,  0,  0] -1 */
        3198, /* 59845 (1538) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    17136256, /* 59846 (1538) [ 0,  1,  0,  0,  0,  1, -1,  0,  0] [ 6,  0,  6]  1 */
    17127410, /* 59847 (1538) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
    51028666, /* 59848 (1538) [ 0,  0,  1, -1,  0,  0,  0,  1,  0] [ 6,  0,  0] -1 */
    51021696, /* 59849 (1538) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  0] -1 */
    52570094, /* 59850 (1538) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    51030346, /* 59851 (1538) [ 0,  1,  0,  0,  0, -1,  1,  0,  0] [ 6,  0,  0] -1 */
        8866, /* 59852 (1538) [ 0,  0, -1, -1,  0,  0,  0, -1,  0] [ 0,  0,  0]  1 */
    51034658, /* 59853 (1538) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  0] -1 */
    18430978, /* 59854 (1538) [ 0, -1,  0,  0,  0,  1,  1,  0,  0] [ 6,  6,  0]  1 */
    35440210, /* 59855 (1538) [ 0,  0,  1,  1,  0,  0,  0, -1,  0] [ 0,  6,  0] -1 */
    34133684, /* 59856 (1538) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    34139680, /* 59857 (1538) [ 0,  0, -1,  1,  0,  0,  0,  1,  0] [ 0,  0,  6] -1 */
    35437036, /* 59858 (1538) [ 0, -1,  0,  0,  0, -1,  1,  0,  0] [ 0,  6,  0] -1 */
    51026008, /* 59859 (1538) [ 0, -1,  0,  0,  0,  1, -1,  0,  0] [ 6,  0,  0] -1 */
    34142314, /* 59860 (1538) [ 0,  1,  0,  0,  0, -1, -1,  0,  0] [ 0,  0,  6] -1 */
    52565674, /* 59861 (1538) [ 0,  1,  0,  0,  0,  1,  1,  0,  0] [ 6,  6,  6] -1 */
    17140692, /* 59862 (1538) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6]  1 */
    52561228, /* 59863 (1538) [ 0, -1,  0,  0,  0, -1, -1,  0,  0] [ 6,  6,  6] -1 */
    52564426, /* 59864 (1538) [ 0,  0,  1,  1,  0,  0,  0,  1,  0] [ 6,  6,  6] -1 */
    34140646, /* 59865 (1538) [ 0,  0,  1, -1,  0,  0,  0, -1,  0] [ 0,  0,  6] -1 */
    35438272, /* 59866 (1538) [ 0,  0, -1, -1,  0,  0,  0,  1,  0] [ 0,  6,  0] -1 */
    18426650, /* 59867 (1538) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    17135020, /* 59868 (1538) [ 0,  0,  1,  1,  0,  0,  0, -1,  0] [ 6,  0,  6]  1 */
    18432646, /* 59869 (1538) [ 0,  0, -1,  1,  0,  0,  0,  1,  0] [ 6,  6,  0]  1 */
    34146642, /* 59870 (1538) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
    18435280, /* 59871 (1538) [ 0,  1,  0,  0,  0, -1, -1,  0,  0] [ 6,  6,  0]  1 */
    52556808, /* 59872 (1538) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
     1544626, /* 59873 (1538) [ 0,  0, -1,  1,  0,  0,  0, -1,  0] [ 0,  6,  6]  1 */
       10816, /* 59874 (1538) [ 0,  0,  1,  1,  0,  0,  0,  1,  0] [ 0,  0,  0]  1 */
    18433612, /* 59875 (1538) [ 0,  0,  1, -1,  0,  0,  0, -1,  0] [ 6,  6,  0]  1 */
    35441446, /* 59876 (1538) [ 0,  1,  0,  0,  0,  1, -1,  0,  0] [ 0,  6,  0] -1 */
    35432600, /* 59877 (1538) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  0] -1 */
    52562476, /* 59878 (1538) [ 0,  0, -1, -1,  0,  0,  0, -1,  0] [ 6,  6,  6] -1 */
       12064, /* 59879 (1538) [ 0,  1,  0,  0,  0,  1,  1,  0,  0] [ 0,  0,  0]  1 */
    17131846, /* 59880 (1538) [ 0, -1,  0,  0,  0, -1,  1,  0,  0] [ 6,  0,  6]  1 */
        7618, /* 59881 (1538) [ 0, -1,  0,  0,  0, -1, -1,  0,  0] [ 0,  0,  0]  1 */
     1538634, /* 59882 (1538) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
       16484, /* 59883 (1539) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
     1545604, /* 59884 (1539) [ 0,  0,  1, -1,  0,  0,  0,  1,  0] [ 0,  6,  6]  1 */
     1547284, /* 59885 (1539) [ 0,  1,  0,  0,  0, -1,  1,  0,  0] [ 0,  6,  6]  1 */
      134418, /* 59886 (1539) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  6]  1 */
    18544584, /* 59887 (1539) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
    18439608, /* 59888 (1539) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
     1551596, /* 59889 (1539) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
    17133082, /* 59890 (1539) [ 0,  0, -1, -1,  0,  0,  0,  1,  0] [ 6,  0,  6]  1 */
     1542946, /* 59891 (1539) [ 0, -1,  0,  0,  0,  1, -1,  0,  0] [ 0,  6,  6]  1 */
     1429222, /* 59892 (1539) [ 0,  1,  0,  0,  0,  1, -1,  0,  0] [ 0,  6,  0]  1 */
        3198, /* 59893 (1539) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
     1420376, /* 59894 (1539) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  0]  1 */
    17136256, /* 59895 (1539) [ 0,  1,  0,  0,  0,  1, -1,  0,  0] [ 6,  0,  6]  1 */
    17127410, /* 59896 (1539) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
    18550252, /* 59897 (1539) [ 0,  0, -1, -1,  0,  0,  0, -1,  0] [ 6,  6,  6]  1 */
        8866, /* 59898 (1539) [ 0,  0, -1, -1,  0,  0,  0, -1,  0] [ 0,  0,  0]  1 */
    18430978, /* 59899 (1539) [ 0, -1,  0,  0,  0,  1,  1,  0,  0] [ 6,  6,  0]  1 */
     1433658, /* 59900 (1539) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  0]  1 */
      125788, /* 59901 (1539) [ 0, -1,  0,  0,  0,  1,  1,  0,  0] [ 0,  0,  6]  1 */
    17015464, /* 59902 (1539) [ 0,  0, -1,  1,  0,  0,  0, -1,  0] [ 6,  0,  0]  1 */
    18557870, /* 59903 (1539) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    17140692, /* 59904 (1539) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6]  1 */
    17016442, /* 59905 (1539) [ 0,  0,  1, -1,  0,  0,  0,  1,  0] [ 6,  0,  0]  1 */
    17009472, /* 59906 (1539) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  0]  1 */
    17018122, /* 59907 (1539) [ 0,  1,  0,  0,  0, -1,  1,  0,  0] [ 6,  0,  0]  1 */
    17022434, /* 59908 (1539) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  0]  1 */
     1427986, /* 59909 (1539) [ 0,  0,  1,  1,  0,  0,  0, -1,  0] [ 0,  6,  0]  1 */
    18426650, /* 59910 (1539) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    17135020, /* 59911 (1539) [ 0,  0,  1,  1,  0,  0,  0, -1,  0] [ 6,  0,  6]  1 */
    18432646, /* 59912 (1539) [ 0,  0, -1,  1,  0,  0,  0,  1,  0] [ 6,  6,  0]  1 */
    18435280, /* 59913 (1539) [ 0,  1,  0,  0,  0, -1, -1,  0,  0] [ 6,  6,  0]  1 */
      121460, /* 59914 (1539) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6]  1 */
     1544626, /* 59915 (1539) [ 0,  0, -1,  1,  0,  0,  0, -1,  0] [ 0,  6,  6]  1 */
       10816, /* 59916 (1539) [ 0,  0,  1,  1,  0,  0,  0,  1,  0] [ 0,  0,  0]  1 */
      127456, /* 59917 (1539) [ 0,  0, -1,  1,  0,  0,  0,  1,  0] [ 0,  0,  6]  1 */
     1424812, /* 59918 (1539) [ 0, -1,  0,  0,  0, -1,  1,  0,  0] [ 0,  6,  0]  1 */
    18433612, /* 59919 (1539) [ 0,  0,  1, -1,  0,  0,  0, -1,  0] [ 6,  6,  0]  1 */
      130090, /* 59920 (1539) [ 0,  1,  0,  0,  0, -1, -1,  0,  0] [ 0,  0,  6]  1 */
        7618, /* 59921 (1539) [ 0, -1,  0,  0,  0, -1, -1,  0,  0] [ 0,  0,  0]  1 */
    17013784, /* 59922 (1539) [ 0, -1,  0,  0,  0,  1, -1,  0,  0] [ 6,  0,  0]  1 */
    18553450, /* 59923 (1539) [ 0,  1,  0,  0,  0,  1,  1,  0,  0] [ 6,  6,  6]  1 */
    18552202, /* 59924 (1539) [ 0,  0,  1,  1,  0,  0,  0,  1,  0] [ 6,  6,  6]  1 */
       12064, /* 59925 (1539) [ 0,  1,  0,  0,  0,  1,  1,  0,  0] [ 0,  0,  0]  1 */
    18549004, /* 59926 (1539) [ 0, -1,  0,  0,  0, -1, -1,  0,  0] [ 6,  6,  6]  1 */
    17131846, /* 59927 (1539) [ 0, -1,  0,  0,  0, -1,  1,  0,  0] [ 6,  0,  6]  1 */
      128422, /* 59928 (1539) [ 0,  0,  1, -1,  0,  0,  0, -1,  0] [ 0,  0,  6]  1 */
     1426048, /* 59929 (1539) [ 0,  0, -1, -1,  0,  0,  0,  1,  0] [ 0,  6,  0]  1 */
     1538634, /* 59930 (1539) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
       16484, /* 59931 (1540) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
      134418, /* 59932 (1540) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  6]  1 */
     1429222, /* 59933 (1540) [ 0,  1,  0,  0,  0,  1, -1,  0,  0] [ 0,  6,  0]  1 */
        3198, /* 59934 (1540) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
     1420376, /* 59935 (1540) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  0]  1 */
    51034658, /* 59936 (1540) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  0] -1 */
     1433658, /* 59937 (1540) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  0]  1 */
    34133684, /* 59938 (1540) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    34023040, /* 59939 (1540) [ 0,  0,  1,  1,  0,  0,  0,  1,  0] [ 0,  0,  0] -1 */
    18557870, /* 59940 (1540) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    52561228, /* 59941 (1540) [ 0, -1,  0,  0,  0, -1, -1,  0,  0] [ 6,  6,  6] -1 */
    34024288, /* 59942 (1540) [ 0,  1,  0,  0,  0,  1,  1,  0,  0] [ 0,  0,  0] -1 */
    17135020, /* 59943 (1540) [ 0,  0,  1,  1,  0,  0,  0, -1,  0] [ 6,  0,  6]  1 */
    35563820, /* 59944 (1540) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
      130090, /* 59945 (1540) [ 0,  1,  0,  0,  0, -1, -1,  0,  0] [ 0,  0,  6]  1 */
     1424812, /* 59946 (1540) [ 0, -1,  0,  0,  0, -1,  1,  0,  0] [ 0,  6,  0]  1 */
    35555170, /* 59947 (1540) [ 0, -1,  0,  0,  0,  1, -1,  0,  0] [ 0,  6,  6] -1 */
    18433612, /* 59948 (1540) [ 0,  0,  1, -1,  0,  0,  0, -1,  0] [ 6,  6,  0]  1 */
    18552202, /* 59949 (1540) [ 0,  0,  1,  1,  0,  0,  0,  1,  0] [ 6,  6,  6]  1 */
    52443202, /* 59950 (1540) [ 0, -1,  0,  0,  0,  1,  1,  0,  0] [ 6,  6,  0] -1 */
    17131846, /* 59951 (1540) [ 0, -1,  0,  0,  0, -1,  1,  0,  0] [ 6,  0,  6]  1 */
      128422, /* 59952 (1540) [ 0,  0,  1, -1,  0,  0,  0, -1,  0] [ 0,  0,  6]  1 */
     1538634, /* 59953 (1540) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
    34138012, /* 59954 (1540) [ 0, -1,  0,  0,  0,  1,  1,  0,  0] [ 0,  0,  6] -1 */
    51027688, /* 59955 (1540) [ 0,  0, -1,  1,  0,  0,  0, -1,  0] [ 6,  0,  0] -1 */
    18550252, /* 59956 (1540) [ 0,  0, -1, -1,  0,  0,  0, -1,  0] [ 6,  6,  6]  1 */
        8866, /* 59957 (1540) [ 0,  0, -1, -1,  0,  0,  0, -1,  0] [ 0,  0,  0]  1 */
    52438874, /* 59958 (1540) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
    35556850, /* 59959 (1540) [ 0,  0, -1,  1,  0,  0,  0, -1,  0] [ 0,  6,  6] -1 */
    34139680, /* 59960 (1540) [ 0,  0, -1,  1,  0,  0,  0,  1,  0] [ 0,  0,  6] -1 */
    34028708, /* 59961 (1540) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    17140692, /* 59962 (1540) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6]  1 */
    17016442, /* 59963 (1540) [ 0,  0,  1, -1,  0,  0,  0,  1,  0] [ 6,  0,  0]  1 */
    17009472, /* 59964 (1540) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  0]  1 */
    17018122, /* 59965 (1540) [ 0,  1,  0,  0,  0, -1,  1,  0,  0] [ 6,  0,  0]  1 */
    34019842, /* 59966 (1540) [ 0, -1,  0,  0,  0, -1, -1,  0,  0] [ 0,  0,  0] -1 */
    34146642, /* 59967 (1540) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
    18435280, /* 59968 (1540) [ 0,  1,  0,  0,  0, -1, -1,  0,  0] [ 6,  6,  0]  1 */
    35559508, /* 59969 (1540) [ 0,  1,  0,  0,  0, -1,  1,  0,  0] [ 0,  6,  6] -1 */
    52451832, /* 59970 (1540) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
    52556808, /* 59971 (1540) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
       10816, /* 59972 (1540) [ 0,  0,  1,  1,  0,  0,  0,  1,  0] [ 0,  0,  0]  1 */
    34015422, /* 59973 (1540) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    17013784, /* 59974 (1540) [ 0, -1,  0,  0,  0,  1, -1,  0,  0] [ 6,  0,  0]  1 */
    51148480, /* 59975 (1540) [ 0,  1,  0,  0,  0,  1, -1,  0,  0] [ 6,  0,  6] -1 */
    18553450, /* 59976 (1540) [ 0,  1,  0,  0,  0,  1,  1,  0,  0] [ 6,  6,  6]  1 */
    51139634, /* 59977 (1540) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
       12064, /* 59978 (1540) [ 0,  1,  0,  0,  0,  1,  1,  0,  0] [ 0,  0,  0]  1 */
     1426048, /* 59979 (1540) [ 0,  0, -1, -1,  0,  0,  0,  1,  0] [ 0,  6,  0]  1 */
     1545604, /* 59980 (1540) [ 0,  0,  1, -1,  0,  0,  0,  1,  0] [ 0,  6,  6]  1 */
     1542946, /* 59981 (1540) [ 0, -1,  0,  0,  0,  1, -1,  0,  0] [ 0,  6,  6]  1 */
    17133082, /* 59982 (1540) [ 0,  0, -1, -1,  0,  0,  0,  1,  0] [ 6,  0,  6]  1 */
    35440210, /* 59983 (1540) [ 0,  0,  1,  1,  0,  0,  0, -1,  0] [ 0,  6,  0] -1 */
      125788, /* 59984 (1540) [ 0, -1,  0,  0,  0,  1,  1,  0,  0] [ 0,  0,  6]  1 */
    52444870, /* 59985 (1540) [ 0,  0, -1,  1,  0,  0,  0,  1,  0] [ 6,  6,  0] -1 */
    17015464, /* 59986 (1540) [ 0,  0, -1,  1,  0,  0,  0, -1,  0] [ 6,  0,  0]  1 */
    35437036, /* 59987 (1540) [ 0, -1,  0,  0,  0, -1,  1,  0,  0] [ 0,  6,  0] -1 */
    34140646, /* 59988 (1540) [ 0,  0,  1, -1,  0,  0,  0, -1,  0] [ 0,  0,  6] -1 */
    17022434, /* 59989 (1540) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  0]  1 */
    18426650, /* 59990 (1540) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
      121460, /* 59991 (1540) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6]  1 */
    35441446, /* 59992 (1540) [ 0,  1,  0,  0,  0,  1, -1,  0,  0] [ 0,  6,  0] -1 */
    35432600, /* 59993 (1540) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  0] -1 */
    52562476, /* 59994 (1540) [ 0,  0, -1, -1,  0,  0,  0, -1,  0] [ 6,  6,  6] -1 */
    18549004, /* 59995 (1540) [ 0, -1,  0,  0,  0, -1, -1,  0,  0] [ 6,  6,  6]  1 */
        7618, /* 59996 (1540) [ 0, -1,  0,  0,  0, -1, -1,  0,  0] [ 0,  0,  0]  1 */
    35445882, /* 59997 (1540) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  0] -1 */
     1547284, /* 59998 (1540) [ 0,  1,  0,  0,  0, -1,  1,  0,  0] [ 0,  6,  6]  1 */
    18439608, /* 59999 (1540) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
    18544584, /* 60000 (1540) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
     1551596, /* 60001 (1540) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
    17136256, /* 60002 (1540) [ 0,  1,  0,  0,  0,  1, -1,  0,  0] [ 6,  0,  6]  1 */
    17127410, /* 60003 (1540) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
    51152916, /* 60004 (1540) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6] -1 */
    51028666, /* 60005 (1540) [ 0,  0,  1, -1,  0,  0,  0,  1,  0] [ 6,  0,  0] -1 */
    51021696, /* 60006 (1540) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  0] -1 */
    52570094, /* 60007 (1540) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    51030346, /* 60008 (1540) [ 0,  1,  0,  0,  0, -1,  1,  0,  0] [ 6,  0,  0] -1 */
    18430978, /* 60009 (1540) [ 0, -1,  0,  0,  0,  1,  1,  0,  0] [ 6,  6,  0]  1 */
    52447504, /* 60010 (1540) [ 0,  1,  0,  0,  0, -1, -1,  0,  0] [ 6,  6,  0] -1 */
    51147244, /* 60011 (1540) [ 0,  0,  1,  1,  0,  0,  0, -1,  0] [ 6,  0,  6] -1 */
    51026008, /* 60012 (1540) [ 0, -1,  0,  0,  0,  1, -1,  0,  0] [ 6,  0,  0] -1 */
    34142314, /* 60013 (1540) [ 0,  1,  0,  0,  0, -1, -1,  0,  0] [ 0,  0,  6] -1 */
    52565674, /* 60014 (1540) [ 0,  1,  0,  0,  0,  1,  1,  0,  0] [ 6,  6,  6] -1 */
    52445836, /* 60015 (1540) [ 0,  0,  1, -1,  0,  0,  0, -1,  0] [ 6,  6,  0] -1 */
    52564426, /* 60016 (1540) [ 0,  0,  1,  1,  0,  0,  0,  1,  0] [ 6,  6,  6] -1 */
    35438272, /* 60017 (1540) [ 0,  0, -1, -1,  0,  0,  0,  1,  0] [ 0,  6,  0] -1 */
     1427986, /* 60018 (1540) [ 0,  0,  1,  1,  0,  0,  0, -1,  0] [ 0,  6,  0]  1 */
    51144070, /* 60019 (1540) [ 0, -1,  0,  0,  0, -1,  1,  0,  0] [ 6,  0,  6] -1 */
    18432646, /* 60020 (1540) [ 0,  0, -1,  1,  0,  0,  0,  1,  0] [ 6,  6,  0]  1 */
    35557828, /* 60021 (1540) [ 0,  0,  1, -1,  0,  0,  0,  1,  0] [ 0,  6,  6] -1 */
    35550858, /* 60022 (1540) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6] -1 */
    51145306, /* 60023 (1540) [ 0,  0, -1, -1,  0,  0,  0,  1,  0] [ 6,  0,  6] -1 */
     1544626, /* 60024 (1540) [ 0,  0, -1,  1,  0,  0,  0, -1,  0] [ 0,  6,  6]  1 */
      127456, /* 60025 (1540) [ 0,  0, -1,  1,  0,  0,  0,  1,  0] [ 0,  0,  6]  1 */
    34021090, /* 60026 (1540) [ 0,  0, -1, -1,  0,  0,  0, -1,  0] [ 0,  0,  0] -1 */
       16484, /* 60027 (1541) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    35445882, /* 60028 (1541) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  0] -1 */
    34138012, /* 60029 (1541) [ 0, -1,  0,  0,  0,  1,  1,  0,  0] [ 0,  0,  6] -1 */
      134418, /* 60030 (1541) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  6]  1 */
    18439608, /* 60031 (1541) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
     1542946, /* 60032 (1541) [ 0, -1,  0,  0,  0,  1, -1,  0,  0] [ 0,  6,  6]  1 */
    17133082, /* 60033 (1541) [ 0,  0, -1, -1,  0,  0,  0,  1,  0] [ 6,  0,  6]  1 */
     1420376, /* 60034 (1541) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  0]  1 */
    17127410, /* 60035 (1541) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
    51152916, /* 60036 (1541) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6] -1 */
    51028666, /* 60037 (1541) [ 0,  0,  1, -1,  0,  0,  0,  1,  0] [ 6,  0,  0] -1 */
    51030346, /* 60038 (1541) [ 0,  1,  0,  0,  0, -1,  1,  0,  0] [ 6,  0,  0] -1 */
    51034658, /* 60039 (1541) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  0] -1 */
    35440210, /* 60040 (1541) [ 0,  0,  1,  1,  0,  0,  0, -1,  0] [ 0,  6,  0] -1 */
    52438874, /* 60041 (1541) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
    51147244, /* 60042 (1541) [ 0,  0,  1,  1,  0,  0,  0, -1,  0] [ 6,  0,  6] -1 */
    52444870, /* 60043 (1541) [ 0,  0, -1,  1,  0,  0,  0,  1,  0] [ 6,  6,  0] -1 */
    17015464, /* 60044 (1541) [ 0,  0, -1,  1,  0,  0,  0, -1,  0] [ 6,  0,  0]  1 */
    34133684, /* 60045 (1541) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    34139680, /* 60046 (1541) [ 0,  0, -1,  1,  0,  0,  0,  1,  0] [ 0,  0,  6] -1 */
    18557870, /* 60047 (1541) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    52561228, /* 60048 (1541) [ 0, -1,  0,  0,  0, -1, -1,  0,  0] [ 6,  6,  6] -1 */
    17009472, /* 60049 (1541) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  0]  1 */
    34019842, /* 60050 (1541) [ 0, -1,  0,  0,  0, -1, -1,  0,  0] [ 0,  0,  0] -1 */
    35557828, /* 60051 (1541) [ 0,  0,  1, -1,  0,  0,  0,  1,  0] [ 0,  6,  6] -1 */
    18435280, /* 60052 (1541) [ 0,  1,  0,  0,  0, -1, -1,  0,  0] [ 6,  6,  0]  1 */
    35559508, /* 60053 (1541) [ 0,  1,  0,  0,  0, -1,  1,  0,  0] [ 0,  6,  6] -1 */
    35563820, /* 60054 (1541) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
    52556808, /* 60055 (1541) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
     1544626, /* 60056 (1541) [ 0,  0, -1,  1,  0,  0,  0, -1,  0] [ 0,  6,  6]  1 */
     1424812, /* 60057 (1541) [ 0, -1,  0,  0,  0, -1,  1,  0,  0] [ 0,  6,  0]  1 */
       10816, /* 60058 (1541) [ 0,  0,  1,  1,  0,  0,  0,  1,  0] [ 0,  0,  0]  1 */
    34015422, /* 60059 (1541) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
      130090, /* 60060 (1541) [ 0,  1,  0,  0,  0, -1, -1,  0,  0] [ 0,  0,  6]  1 */
    18433612, /* 60061 (1541) [ 0,  0,  1, -1,  0,  0,  0, -1,  0] [ 6,  6,  0]  1 */
    17013784, /* 60062 (1541) [ 0, -1,  0,  0,  0,  1, -1,  0,  0] [ 6,  0,  0]  1 */
    35441446, /* 60063 (1541) [ 0,  1,  0,  0,  0,  1, -1,  0,  0] [ 0,  6,  0] -1 */
    51148480, /* 60064 (1541) [ 0,  1,  0,  0,  0,  1, -1,  0,  0] [ 6,  0,  6] -1 */
    18553450, /* 60065 (1541) [ 0,  1,  0,  0,  0,  1,  1,  0,  0] [ 6,  6,  6]  1 */
    52562476, /* 60066 (1541) [ 0,  0, -1, -1,  0,  0,  0, -1,  0] [ 6,  6,  6] -1 */
    18552202, /* 60067 (1541) [ 0,  0,  1,  1,  0,  0,  0,  1,  0] [ 6,  6,  6]  1 */
       12064, /* 60068 (1541) [ 0,  1,  0,  0,  0,  1,  1,  0,  0] [ 0,  0,  0]  1 */
    52443202, /* 60069 (1541) [ 0, -1,  0,  0,  0,  1,  1,  0,  0] [ 6,  6,  0] -1 */
    17131846, /* 60070 (1541) [ 0, -1,  0,  0,  0, -1,  1,  0,  0] [ 6,  0,  6]  1 */
    34021090, /* 60071 (1541) [ 0,  0, -1, -1,  0,  0,  0, -1,  0] [ 0,  0,  0] -1 */
     1426048, /* 60072 (1541) [ 0,  0, -1, -1,  0,  0,  0,  1,  0] [ 0,  6,  0]  1 */
      128422, /* 60073 (1541) [ 0,  0,  1, -1,  0,  0,  0, -1,  0] [ 0,  0,  6]  1 */
     1538634, /* 60074 (1541) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
       16484, /* 60075 (1542) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
        9022, /* 60076 (1542) [ 0,  0, -1,  0, -1,  0, -1,  0,  0] [ 0,  0,  0]  1 */
       16378, /* 60077 (1542) [ 1,  0,  0,  0,  0, -1,  0,  1,  0] [ 0,  0,  0]  1 */
       16320, /* 60078 (1542) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
       12270, /* 60079 (1542) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  0]  1 */
        7410, /* 60080 (1542) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  0]  1 */
        7636, /* 60081 (1542) [ 0, -1,  0,  0,  0, -1,  1,  0,  0] [ 0,  0,  0]  1 */
        9352, /* 60082 (1542) [ 0,  0, -1,  1,  0,  0,  0, -1,  0] [ 0,  0,  0]  1 */
        8872, /* 60083 (1542) [ 0,  0, -1, -1,  0,  0,  0,  1,  0] [ 0,  0,  0]  1 */
       10642, /* 60084 (1542) [ 0,  0,  1,  0,  1,  0, -1,  0,  0] [ 0,  0,  0]  1 */
        7672, /* 60085 (1542) [ 0, -1,  0,  0,  0,  1, -1,  0,  0] [ 0,  0,  0]  1 */
       11786, /* 60086 (1542) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  0]  1 */
        3250, /* 60087 (1542) [-1,  0,  0,  0,  0, -1,  0, -1,  0] [ 0,  0,  0]  1 */
        3360, /* 60088 (1542) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
        7898, /* 60089 (1542) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 0,  0,  0]  1 */
       16426, /* 60090 (1542) [ 1,  0,  0,  0,  0,  1,  0, -1,  0] [ 0,  0,  0]  1 */
        3310, /* 60091 (1542) [-1,  0,  0,  0,  0,  1,  0,  1,  0] [ 0,  0,  0]  1 */
        9202, /* 60092 (1542) [ 0,  0, -1,  0,  1,  0,  1,  0,  0] [ 0,  0,  0]  1 */
       10816, /* 60093 (1542) [ 0,  0,  1,  1,  0,  0,  0,  1,  0] [ 0,  0,  0]  1 */
        3200, /* 60094 (1542) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
       11992, /* 60095 (1542) [ 0,  1,  0,  0,  0, -1, -1,  0,  0] [ 0,  0,  0]  1 */
       12064, /* 60096 (1542) [ 0,  1,  0,  0,  0,  1,  1,  0,  0] [ 0,  0,  0]  1 */
       10498, /* 60097 (1542) [ 0,  0,  1,  0, -1,  0,  1,  0,  0] [ 0,  0,  0]  1 */
       10324, /* 60098 (1542) [ 0,  0,  1, -1,  0,  0,  0, -1,  0] [ 0,  0,  0]  1 */
       16484, /* 60099 (1543) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34019634, /* 60100 (1543) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    34019860, /* 60101 (1543) [ 0, -1,  0,  0,  0, -1,  1,  0,  0] [ 0,  0,  0] -1 */
        9022, /* 60102 (1543) [ 0,  0, -1,  0, -1,  0, -1,  0,  0] [ 0,  0,  0]  1 */
       16378, /* 60103 (1543) [ 1,  0,  0,  0,  0, -1,  0,  1,  0] [ 0,  0,  0]  1 */
       16320, /* 60104 (1543) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    34021576, /* 60105 (1543) [ 0,  0, -1,  1,  0,  0,  0, -1,  0] [ 0,  0,  0] -1 */
       12270, /* 60106 (1543) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    34021096, /* 60107 (1543) [ 0,  0, -1, -1,  0,  0,  0,  1,  0] [ 0,  0,  0] -1 */
    34022866, /* 60108 (1543) [ 0,  0,  1,  0,  1,  0, -1,  0,  0] [ 0,  0,  0] -1 */
    34019896, /* 60109 (1543) [ 0, -1,  0,  0,  0,  1, -1,  0,  0] [ 0,  0,  0] -1 */
    34024010, /* 60110 (1543) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    34015584, /* 60111 (1543) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    34015474, /* 60112 (1543) [-1,  0,  0,  0,  0, -1,  0, -1,  0] [ 0,  0,  0] -1 */
        7410, /* 60113 (1543) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  0]  1 */
        7636, /* 60114 (1543) [ 0, -1,  0,  0,  0, -1,  1,  0,  0] [ 0,  0,  0]  1 */
    34028650, /* 60115 (1543) [ 1,  0,  0,  0,  0,  1,  0, -1,  0] [ 0,  0,  0] -1 */
    34015534, /* 60116 (1543) [-1,  0,  0,  0,  0,  1,  0,  1,  0] [ 0,  0,  0] -1 */
    34020122, /* 60117 (1543) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 0,  0,  0] -1 */
        9352, /* 60118 (1543) [ 0,  0, -1,  1,  0,  0,  0, -1,  0] [ 0,  0,  0]  1 */
    34015424, /* 60119 (1543) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    34021426, /* 60120 (1543) [ 0,  0, -1,  0,  1,  0,  1,  0,  0] [ 0,  0,  0] -1 */
    34028708, /* 60121 (1543) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    34023040, /* 60122 (1543) [ 0,  0,  1,  1,  0,  0,  0,  1,  0] [ 0,  0,  0] -1 */
    34024216, /* 60123 (1543) [ 0,  1,  0,  0,  0, -1, -1,  0,  0] [ 0,  0,  0] -1 */
        8872, /* 60124 (1543) [ 0,  0, -1, -1,  0,  0,  0,  1,  0] [ 0,  0,  0]  1 */
    34024288, /* 60125 (1543) [ 0,  1,  0,  0,  0,  1,  1,  0,  0] [ 0,  0,  0] -1 */
       10642, /* 60126 (1543) [ 0,  0,  1,  0,  1,  0, -1,  0,  0] [ 0,  0,  0]  1 */
    34022548, /* 60127 (1543) [ 0,  0,  1, -1,  0,  0,  0, -1,  0] [ 0,  0,  0] -1 */
        7672, /* 60128 (1543) [ 0, -1,  0,  0,  0,  1, -1,  0,  0] [ 0,  0,  0]  1 */
    34022722, /* 60129 (1543) [ 0,  0,  1,  0, -1,  0,  1,  0,  0] [ 0,  0,  0] -1 */
       11786, /* 60130 (1543) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  0]  1 */
        3360, /* 60131 (1543) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
        7898, /* 60132 (1543) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 0,  0,  0]  1 */
        3250, /* 60133 (1543) [-1,  0,  0,  0,  0, -1,  0, -1,  0] [ 0,  0,  0]  1 */
    34028544, /* 60134 (1543) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
       16426, /* 60135 (1543) [ 1,  0,  0,  0,  0,  1,  0, -1,  0] [ 0,  0,  0]  1 */
        3310, /* 60136 (1543) [-1,  0,  0,  0,  0,  1,  0,  1,  0] [ 0,  0,  0]  1 */
        9202, /* 60137 (1543) [ 0,  0, -1,  0,  1,  0,  1,  0,  0] [ 0,  0,  0]  1 */
    34021246, /* 60138 (1543) [ 0,  0, -1,  0, -1,  0, -1,  0,  0] [ 0,  0,  0] -1 */
       10816, /* 60139 (1543) [ 0,  0,  1,  1,  0,  0,  0,  1,  0] [ 0,  0,  0]  1 */
    34028602, /* 60140 (1543) [ 1,  0,  0,  0,  0, -1,  0,  1,  0] [ 0,  0,  0] -1 */
        3200, /* 60141 (1543) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34024494, /* 60142 (1543) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  0] -1 */
       11992, /* 60143 (1543) [ 0,  1,  0,  0,  0, -1, -1,  0,  0] [ 0,  0,  0]  1 */
       12064, /* 60144 (1543) [ 0,  1,  0,  0,  0,  1,  1,  0,  0] [ 0,  0,  0]  1 */
       10498, /* 60145 (1543) [ 0,  0,  1,  0, -1,  0,  1,  0,  0] [ 0,  0,  0]  1 */
       10324, /* 60146 (1543) [ 0,  0,  1, -1,  0,  0,  0, -1,  0] [ 0,  0,  0]  1 */
       16484, /* 60147 (1544) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34019634, /* 60148 (1544) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  0] -1 */
       16320, /* 60149 (1544) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    34022866, /* 60150 (1544) [ 0,  0,  1,  0,  1,  0, -1,  0,  0] [ 0,  0,  0] -1 */
    34024010, /* 60151 (1544) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    34015474, /* 60152 (1544) [-1,  0,  0,  0,  0, -1,  0, -1,  0] [ 0,  0,  0] -1 */
        7636, /* 60153 (1544) [ 0, -1,  0,  0,  0, -1,  1,  0,  0] [ 0,  0,  0]  1 */
    34028650, /* 60154 (1544) [ 1,  0,  0,  0,  0,  1,  0, -1,  0] [ 0,  0,  0] -1 */
    34015534, /* 60155 (1544) [-1,  0,  0,  0,  0,  1,  0,  1,  0] [ 0,  0,  0] -1 */
    34020122, /* 60156 (1544) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 0,  0,  0] -1 */
        9352, /* 60157 (1544) [ 0,  0, -1,  1,  0,  0,  0, -1,  0] [ 0,  0,  0]  1 */
    34021426, /* 60158 (1544) [ 0,  0, -1,  0,  1,  0,  1,  0,  0] [ 0,  0,  0] -1 */
        8872, /* 60159 (1544) [ 0,  0, -1, -1,  0,  0,  0,  1,  0] [ 0,  0,  0]  1 */
        7672, /* 60160 (1544) [ 0, -1,  0,  0,  0,  1, -1,  0,  0] [ 0,  0,  0]  1 */
    34022722, /* 60161 (1544) [ 0,  0,  1,  0, -1,  0,  1,  0,  0] [ 0,  0,  0] -1 */
        3360, /* 60162 (1544) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    34021246, /* 60163 (1544) [ 0,  0, -1,  0, -1,  0, -1,  0,  0] [ 0,  0,  0] -1 */
    34028602, /* 60164 (1544) [ 1,  0,  0,  0,  0, -1,  0,  1,  0] [ 0,  0,  0] -1 */
       10816, /* 60165 (1544) [ 0,  0,  1,  1,  0,  0,  0,  1,  0] [ 0,  0,  0]  1 */
        3200, /* 60166 (1544) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34024494, /* 60167 (1544) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  0] -1 */
       11992, /* 60168 (1544) [ 0,  1,  0,  0,  0, -1, -1,  0,  0] [ 0,  0,  0]  1 */
       12064, /* 60169 (1544) [ 0,  1,  0,  0,  0,  1,  1,  0,  0] [ 0,  0,  0]  1 */
       10324, /* 60170 (1544) [ 0,  0,  1, -1,  0,  0,  0, -1,  0] [ 0,  0,  0]  1 */
       16484, /* 60171 (1545) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    52562962, /* 60172 (1545) [ 0,  0, -1,  1,  0,  0,  0, -1,  0] [ 6,  6,  6] -1 */
    52561246, /* 60173 (1545) [ 0, -1,  0,  0,  0, -1,  1,  0,  0] [ 6,  6,  6] -1 */
        9022, /* 60174 (1545) [ 0,  0, -1,  0, -1,  0, -1,  0,  0] [ 0,  0,  0]  1 */
       16378, /* 60175 (1545) [ 1,  0,  0,  0,  0, -1,  0,  1,  0] [ 0,  0,  0]  1 */
       16320, /* 60176 (1545) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
       12270, /* 60177 (1545) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    52556970, /* 60178 (1545) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    52570094, /* 60179 (1545) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    52564252, /* 60180 (1545) [ 0,  0,  1,  0,  1,  0, -1,  0,  0] [ 6,  6,  6] -1 */
    52565396, /* 60181 (1545) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    52562482, /* 60182 (1545) [ 0,  0, -1, -1,  0,  0,  0,  1,  0] [ 6,  6,  6] -1 */
    52556860, /* 60183 (1545) [-1,  0,  0,  0,  0, -1,  0, -1,  0] [ 6,  6,  6] -1 */
    52561508, /* 60184 (1545) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    52570036, /* 60185 (1545) [ 1,  0,  0,  0,  0,  1,  0, -1,  0] [ 6,  6,  6] -1 */
    52556920, /* 60186 (1545) [-1,  0,  0,  0,  0,  1,  0,  1,  0] [ 6,  6,  6] -1 */
        7410, /* 60187 (1545) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  0]  1 */
        7636, /* 60188 (1545) [ 0, -1,  0,  0,  0, -1,  1,  0,  0] [ 0,  0,  0]  1 */
    52562812, /* 60189 (1545) [ 0,  0, -1,  0,  1,  0,  1,  0,  0] [ 6,  6,  6] -1 */
    52561282, /* 60190 (1545) [ 0, -1,  0,  0,  0,  1, -1,  0,  0] [ 6,  6,  6] -1 */
        9352, /* 60191 (1545) [ 0,  0, -1,  1,  0,  0,  0, -1,  0] [ 0,  0,  0]  1 */
    52565602, /* 60192 (1545) [ 0,  1,  0,  0,  0, -1, -1,  0,  0] [ 6,  6,  6] -1 */
    52565674, /* 60193 (1545) [ 0,  1,  0,  0,  0,  1,  1,  0,  0] [ 6,  6,  6] -1 */
    52556810, /* 60194 (1545) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
        8872, /* 60195 (1545) [ 0,  0, -1, -1,  0,  0,  0,  1,  0] [ 0,  0,  0]  1 */
    52564426, /* 60196 (1545) [ 0,  0,  1,  1,  0,  0,  0,  1,  0] [ 6,  6,  6] -1 */
    52563934, /* 60197 (1545) [ 0,  0,  1, -1,  0,  0,  0, -1,  0] [ 6,  6,  6] -1 */
       10642, /* 60198 (1545) [ 0,  0,  1,  0,  1,  0, -1,  0,  0] [ 0,  0,  0]  1 */
        7672, /* 60199 (1545) [ 0, -1,  0,  0,  0,  1, -1,  0,  0] [ 0,  0,  0]  1 */
       11786, /* 60200 (1545) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    52569988, /* 60201 (1545) [ 1,  0,  0,  0,  0, -1,  0,  1,  0] [ 6,  6,  6] -1 */
    52569930, /* 60202 (1545) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
        3360, /* 60203 (1545) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
        7898, /* 60204 (1545) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 0,  0,  0]  1 */
        3250, /* 60205 (1545) [-1,  0,  0,  0,  0, -1,  0, -1,  0] [ 0,  0,  0]  1 */
    52565880, /* 60206 (1545) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 6,  6,  6] -1 */
       16426, /* 60207 (1545) [ 1,  0,  0,  0,  0,  1,  0, -1,  0] [ 0,  0,  0]  1 */
        3310, /* 60208 (1545) [-1,  0,  0,  0,  0,  1,  0,  1,  0] [ 0,  0,  0]  1 */
        9202, /* 60209 (1545) [ 0,  0, -1,  0,  1,  0,  1,  0,  0] [ 0,  0,  0]  1 */
    52564108, /* 60210 (1545) [ 0,  0,  1,  0, -1,  0,  1,  0,  0] [ 6,  6,  6] -1 */
       10816, /* 60211 (1545) [ 0,  0,  1,  1,  0,  0,  0,  1,  0] [ 0,  0,  0]  1 */
        3200, /* 60212 (1545) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    52562632, /* 60213 (1545) [ 0,  0, -1,  0, -1,  0, -1,  0,  0] [ 6,  6,  6] -1 */
       11992, /* 60214 (1545) [ 0,  1,  0,  0,  0, -1, -1,  0,  0] [ 0,  0,  0]  1 */
       12064, /* 60215 (1545) [ 0,  1,  0,  0,  0,  1,  1,  0,  0] [ 0,  0,  0]  1 */
    52561020, /* 60216 (1545) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 6,  6,  6] -1 */
       10498, /* 60217 (1545) [ 0,  0,  1,  0, -1,  0,  1,  0,  0] [ 0,  0,  0]  1 */
       10324, /* 60218 (1545) [ 0,  0,  1, -1,  0,  0,  0, -1,  0] [ 0,  0,  0]  1 */
       16484, /* 60219 (1546) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    18557764, /* 60220 (1546) [ 1,  0,  0,  0,  0, -1,  0,  1,  0] [ 6,  6,  6]  1 */
    18551884, /* 60221 (1546) [ 0,  0,  1,  0, -1,  0,  1,  0,  0] [ 6,  6,  6]  1 */
    18553656, /* 60222 (1546) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 6,  6,  6]  1 */
       16320, /* 60223 (1546) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    18550408, /* 60224 (1546) [ 0,  0, -1,  0, -1,  0, -1,  0,  0] [ 6,  6,  6]  1 */
    18548796, /* 60225 (1546) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 6,  6,  6]  1 */
        7636, /* 60226 (1546) [ 0, -1,  0,  0,  0, -1,  1,  0,  0] [ 0,  0,  0]  1 */
        9352, /* 60227 (1546) [ 0,  0, -1,  1,  0,  0,  0, -1,  0] [ 0,  0,  0]  1 */
    18552028, /* 60228 (1546) [ 0,  0,  1,  0,  1,  0, -1,  0,  0] [ 6,  6,  6]  1 */
        8872, /* 60229 (1546) [ 0,  0, -1, -1,  0,  0,  0,  1,  0] [ 0,  0,  0]  1 */
    18553172, /* 60230 (1546) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    18544636, /* 60231 (1546) [-1,  0,  0,  0,  0, -1,  0, -1,  0] [ 6,  6,  6]  1 */
    18557812, /* 60232 (1546) [ 1,  0,  0,  0,  0,  1,  0, -1,  0] [ 6,  6,  6]  1 */
    18544696, /* 60233 (1546) [-1,  0,  0,  0,  0,  1,  0,  1,  0] [ 6,  6,  6]  1 */
    18549284, /* 60234 (1546) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 6,  6,  6]  1 */
        7672, /* 60235 (1546) [ 0, -1,  0,  0,  0,  1, -1,  0,  0] [ 0,  0,  0]  1 */
        3360, /* 60236 (1546) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    18550588, /* 60237 (1546) [ 0,  0, -1,  0,  1,  0,  1,  0,  0] [ 6,  6,  6]  1 */
       10816, /* 60238 (1546) [ 0,  0,  1,  1,  0,  0,  0,  1,  0] [ 0,  0,  0]  1 */
        3200, /* 60239 (1546) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
       11992, /* 60240 (1546) [ 0,  1,  0,  0,  0, -1, -1,  0,  0] [ 0,  0,  0]  1 */
       12064, /* 60241 (1546) [ 0,  1,  0,  0,  0,  1,  1,  0,  0] [ 0,  0,  0]  1 */
       10324, /* 60242 (1546) [ 0,  0,  1, -1,  0,  0,  0, -1,  0] [ 0,  0,  0]  1 */
       16484, /* 60243 (1547) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    18557764, /* 60244 (1547) [ 1,  0,  0,  0,  0, -1,  0,  1,  0] [ 6,  6,  6]  1 */
    34019860, /* 60245 (1547) [ 0, -1,  0,  0,  0, -1,  1,  0,  0] [ 0,  0,  0] -1 */
    18551884, /* 60246 (1547) [ 0,  0,  1,  0, -1,  0,  1,  0,  0] [ 6,  6,  6]  1 */
    18553656, /* 60247 (1547) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 6,  6,  6]  1 */
       16320, /* 60248 (1547) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    34021576, /* 60249 (1547) [ 0,  0, -1,  1,  0,  0,  0, -1,  0] [ 0,  0,  0] -1 */
    18550408, /* 60250 (1547) [ 0,  0, -1,  0, -1,  0, -1,  0,  0] [ 6,  6,  6]  1 */
    52564252, /* 60251 (1547) [ 0,  0,  1,  0,  1,  0, -1,  0,  0] [ 6,  6,  6] -1 */
    34021096, /* 60252 (1547) [ 0,  0, -1, -1,  0,  0,  0,  1,  0] [ 0,  0,  0] -1 */
    52565396, /* 60253 (1547) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    52556860, /* 60254 (1547) [-1,  0,  0,  0,  0, -1,  0, -1,  0] [ 6,  6,  6] -1 */
    52561508, /* 60255 (1547) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    34019896, /* 60256 (1547) [ 0, -1,  0,  0,  0,  1, -1,  0,  0] [ 0,  0,  0] -1 */
    18548796, /* 60257 (1547) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 6,  6,  6]  1 */
    52570036, /* 60258 (1547) [ 1,  0,  0,  0,  0,  1,  0, -1,  0] [ 6,  6,  6] -1 */
    34015584, /* 60259 (1547) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    52556920, /* 60260 (1547) [-1,  0,  0,  0,  0,  1,  0,  1,  0] [ 6,  6,  6] -1 */
        7636, /* 60261 (1547) [ 0, -1,  0,  0,  0, -1,  1,  0,  0] [ 0,  0,  0]  1 */
    52562812, /* 60262 (1547) [ 0,  0, -1,  0,  1,  0,  1,  0,  0] [ 6,  6,  6] -1 */
        9352, /* 60263 (1547) [ 0,  0, -1,  1,  0,  0,  0, -1,  0] [ 0,  0,  0]  1 */
    34015424, /* 60264 (1547) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    34028708, /* 60265 (1547) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    34023040, /* 60266 (1547) [ 0,  0,  1,  1,  0,  0,  0,  1,  0] [ 0,  0,  0] -1 */
    34024216, /* 60267 (1547) [ 0,  1,  0,  0,  0, -1, -1,  0,  0] [ 0,  0,  0] -1 */
    18552028, /* 60268 (1547) [ 0,  0,  1,  0,  1,  0, -1,  0,  0] [ 6,  6,  6]  1 */
        8872, /* 60269 (1547) [ 0,  0, -1, -1,  0,  0,  0,  1,  0] [ 0,  0,  0]  1 */
    18553172, /* 60270 (1547) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    34024288, /* 60271 (1547) [ 0,  1,  0,  0,  0,  1,  1,  0,  0] [ 0,  0,  0] -1 */
    18544636, /* 60272 (1547) [-1,  0,  0,  0,  0, -1,  0, -1,  0] [ 6,  6,  6]  1 */
    34022548, /* 60273 (1547) [ 0,  0,  1, -1,  0,  0,  0, -1,  0] [ 0,  0,  0] -1 */
    18557812, /* 60274 (1547) [ 1,  0,  0,  0,  0,  1,  0, -1,  0] [ 6,  6,  6]  1 */
    18544696, /* 60275 (1547) [-1,  0,  0,  0,  0,  1,  0,  1,  0] [ 6,  6,  6]  1 */
    18549284, /* 60276 (1547) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 6,  6,  6]  1 */
        7672, /* 60277 (1547) [ 0, -1,  0,  0,  0,  1, -1,  0,  0] [ 0,  0,  0]  1 */
    52569988, /* 60278 (1547) [ 1,  0,  0,  0,  0, -1,  0,  1,  0] [ 6,  6,  6] -1 */
        3360, /* 60279 (1547) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    18550588, /* 60280 (1547) [ 0,  0, -1,  0,  1,  0,  1,  0,  0] [ 6,  6,  6]  1 */
    52565880, /* 60281 (1547) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    34028544, /* 60282 (1547) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    52564108, /* 60283 (1547) [ 0,  0,  1,  0, -1,  0,  1,  0,  0] [ 6,  6,  6] -1 */
       10816, /* 60284 (1547) [ 0,  0,  1,  1,  0,  0,  0,  1,  0] [ 0,  0,  0]  1 */
        3200, /* 60285 (1547) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    52562632, /* 60286 (1547) [ 0,  0, -1,  0, -1,  0, -1,  0,  0] [ 6,  6,  6] -1 */
       11992, /* 60287 (1547) [ 0,  1,  0,  0,  0, -1, -1,  0,  0] [ 0,  0,  0]  1 */
       12064, /* 60288 (1547) [ 0,  1,  0,  0,  0,  1,  1,  0,  0] [ 0,  0,  0]  1 */
    52561020, /* 60289 (1547) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 6,  6,  6] -1 */
       10324, /* 60290 (1547) [ 0,  0,  1, -1,  0,  0,  0, -1,  0] [ 0,  0,  0]  1 */
       16484, /* 60291 (1548) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
       16320, /* 60292 (1548) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    52564252, /* 60293 (1548) [ 0,  0,  1,  0,  1,  0, -1,  0,  0] [ 6,  6,  6] -1 */
    52565396, /* 60294 (1548) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    52556860, /* 60295 (1548) [-1,  0,  0,  0,  0, -1,  0, -1,  0] [ 6,  6,  6] -1 */
    52561508, /* 60296 (1548) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    52570036, /* 60297 (1548) [ 1,  0,  0,  0,  0,  1,  0, -1,  0] [ 6,  6,  6] -1 */
    52556920, /* 60298 (1548) [-1,  0,  0,  0,  0,  1,  0,  1,  0] [ 6,  6,  6] -1 */
    52562812, /* 60299 (1548) [ 0,  0, -1,  0,  1,  0,  1,  0,  0] [ 6,  6,  6] -1 */
        7636, /* 60300 (1548) [ 0, -1,  0,  0,  0, -1,  1,  0,  0] [ 0,  0,  0]  1 */
        9352, /* 60301 (1548) [ 0,  0, -1,  1,  0,  0,  0, -1,  0] [ 0,  0,  0]  1 */
        8872, /* 60302 (1548) [ 0,  0, -1, -1,  0,  0,  0,  1,  0] [ 0,  0,  0]  1 */
        7672, /* 60303 (1548) [ 0, -1,  0,  0,  0,  1, -1,  0,  0] [ 0,  0,  0]  1 */
    52569988, /* 60304 (1548) [ 1,  0,  0,  0,  0, -1,  0,  1,  0] [ 6,  6,  6] -1 */
        3360, /* 60305 (1548) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    52565880, /* 60306 (1548) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    52564108, /* 60307 (1548) [ 0,  0,  1,  0, -1,  0,  1,  0,  0] [ 6,  6,  6] -1 */
       10816, /* 60308 (1548) [ 0,  0,  1,  1,  0,  0,  0,  1,  0] [ 0,  0,  0]  1 */
        3200, /* 60309 (1548) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    52562632, /* 60310 (1548) [ 0,  0, -1,  0, -1,  0, -1,  0,  0] [ 6,  6,  6] -1 */
       11992, /* 60311 (1548) [ 0,  1,  0,  0,  0, -1, -1,  0,  0] [ 0,  0,  0]  1 */
       12064, /* 60312 (1548) [ 0,  1,  0,  0,  0,  1,  1,  0,  0] [ 0,  0,  0]  1 */
    52561020, /* 60313 (1548) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 6,  6,  6] -1 */
       10324, /* 60314 (1548) [ 0,  0,  1, -1,  0,  0,  0, -1,  0] [ 0,  0,  0]  1 */
       16484, /* 60315 (1549) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    52562962, /* 60316 (1549) [ 0,  0, -1,  1,  0,  0,  0, -1,  0] [ 6,  6,  6] -1 */
    18557764, /* 60317 (1549) [ 1,  0,  0,  0,  0, -1,  0,  1,  0] [ 6,  6,  6]  1 */
    34019634, /* 60318 (1549) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    18551884, /* 60319 (1549) [ 0,  0,  1,  0, -1,  0,  1,  0,  0] [ 6,  6,  6]  1 */
    18553656, /* 60320 (1549) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 6,  6,  6]  1 */
       16320, /* 60321 (1549) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    52556970, /* 60322 (1549) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    18550408, /* 60323 (1549) [ 0,  0, -1,  0, -1,  0, -1,  0,  0] [ 6,  6,  6]  1 */
    52570094, /* 60324 (1549) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    34022866, /* 60325 (1549) [ 0,  0,  1,  0,  1,  0, -1,  0,  0] [ 0,  0,  0] -1 */
    52562482, /* 60326 (1549) [ 0,  0, -1, -1,  0,  0,  0,  1,  0] [ 6,  6,  6] -1 */
    34024010, /* 60327 (1549) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    18548796, /* 60328 (1549) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 6,  6,  6]  1 */
    34015474, /* 60329 (1549) [-1,  0,  0,  0,  0, -1,  0, -1,  0] [ 0,  0,  0] -1 */
        7636, /* 60330 (1549) [ 0, -1,  0,  0,  0, -1,  1,  0,  0] [ 0,  0,  0]  1 */
    34028650, /* 60331 (1549) [ 1,  0,  0,  0,  0,  1,  0, -1,  0] [ 0,  0,  0] -1 */
    34015534, /* 60332 (1549) [-1,  0,  0,  0,  0,  1,  0,  1,  0] [ 0,  0,  0] -1 */
    34020122, /* 60333 (1549) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 0,  0,  0] -1 */
        9352, /* 60334 (1549) [ 0,  0, -1,  1,  0,  0,  0, -1,  0] [ 0,  0,  0]  1 */
    52561282, /* 60335 (1549) [ 0, -1,  0,  0,  0,  1, -1,  0,  0] [ 6,  6,  6] -1 */
    34021426, /* 60336 (1549) [ 0,  0, -1,  0,  1,  0,  1,  0,  0] [ 0,  0,  0] -1 */
    52565602, /* 60337 (1549) [ 0,  1,  0,  0,  0, -1, -1,  0,  0] [ 6,  6,  6] -1 */
    52565674, /* 60338 (1549) [ 0,  1,  0,  0,  0,  1,  1,  0,  0] [ 6,  6,  6] -1 */
    52556810, /* 60339 (1549) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
        8872, /* 60340 (1549) [ 0,  0, -1, -1,  0,  0,  0,  1,  0] [ 0,  0,  0]  1 */
    18552028, /* 60341 (1549) [ 0,  0,  1,  0,  1,  0, -1,  0,  0] [ 6,  6,  6]  1 */
    52564426, /* 60342 (1549) [ 0,  0,  1,  1,  0,  0,  0,  1,  0] [ 6,  6,  6] -1 */
    18553172, /* 60343 (1549) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    52563934, /* 60344 (1549) [ 0,  0,  1, -1,  0,  0,  0, -1,  0] [ 6,  6,  6] -1 */
    18544636, /* 60345 (1549) [-1,  0,  0,  0,  0, -1,  0, -1,  0] [ 6,  6,  6]  1 */
    18557812, /* 60346 (1549) [ 1,  0,  0,  0,  0,  1,  0, -1,  0] [ 6,  6,  6]  1 */
    18544696, /* 60347 (1549) [-1,  0,  0,  0,  0,  1,  0,  1,  0] [ 6,  6,  6]  1 */
    18549284, /* 60348 (1549) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    34022722, /* 60349 (1549) [ 0,  0,  1,  0, -1,  0,  1,  0,  0] [ 0,  0,  0] -1 */
        7672, /* 60350 (1549) [ 0, -1,  0,  0,  0,  1, -1,  0,  0] [ 0,  0,  0]  1 */
    52569930, /* 60351 (1549) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
        3360, /* 60352 (1549) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    18550588, /* 60353 (1549) [ 0,  0, -1,  0,  1,  0,  1,  0,  0] [ 6,  6,  6]  1 */
    34021246, /* 60354 (1549) [ 0,  0, -1,  0, -1,  0, -1,  0,  0] [ 0,  0,  0] -1 */
    34028602, /* 60355 (1549) [ 1,  0,  0,  0,  0, -1,  0,  1,  0] [ 0,  0,  0] -1 */
       10816, /* 60356 (1549) [ 0,  0,  1,  1,  0,  0,  0,  1,  0] [ 0,  0,  0]  1 */
        3200, /* 60357 (1549) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34024494, /* 60358 (1549) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  0] -1 */
       11992, /* 60359 (1549) [ 0,  1,  0,  0,  0, -1, -1,  0,  0] [ 0,  0,  0]  1 */
       12064, /* 60360 (1549) [ 0,  1,  0,  0,  0,  1,  1,  0,  0] [ 0,  0,  0]  1 */
    52561246, /* 60361 (1549) [ 0, -1,  0,  0,  0, -1,  1,  0,  0] [ 6,  6,  6] -1 */
       10324, /* 60362 (1549) [ 0,  0,  1, -1,  0,  0,  0, -1,  0] [ 0,  0,  0]  1 */
       16484, /* 60363 (1550) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
     1551700, /* 60364 (1550) [ 1,  0,  0,  0,  0,  1,  0, -1,  0] [ 0,  6,  6]  1 */
    17140694, /* 60365 (1550) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
        9022, /* 60366 (1550) [ 0,  0, -1,  0, -1,  0, -1,  0,  0] [ 0,  0,  0]  1 */
    18432310, /* 60367 (1550) [ 0,  0, -1,  0, -1,  0, -1,  0,  0] [ 6,  6,  0]  1 */
       16320, /* 60368 (1550) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    17132108, /* 60369 (1550) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 6,  0,  6]  1 */
     1538524, /* 60370 (1550) [-1,  0,  0,  0,  0, -1,  0, -1,  0] [ 0,  6,  6]  1 */
     1545598, /* 60371 (1550) [ 0,  0,  1, -1,  0,  0,  0, -1,  0] [ 0,  6,  6]  1 */
     1538474, /* 60372 (1550) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
    17136274, /* 60373 (1550) [ 0,  1,  0,  0,  0,  1,  1,  0,  0] [ 6,  0,  6]  1 */
        7410, /* 60374 (1550) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    18430698, /* 60375 (1550) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 6,  6,  0]  1 */
    17134708, /* 60376 (1550) [ 0,  0,  1,  0, -1,  0,  1,  0,  0] [ 6,  0,  6]  1 */
        9352, /* 60377 (1550) [ 0,  0, -1,  1,  0,  0,  0, -1,  0] [ 0,  0,  0]  1 */
     1551652, /* 60378 (1550) [ 1,  0,  0,  0,  0, -1,  0,  1,  0] [ 0,  6,  6]  1 */
     1545772, /* 60379 (1550) [ 0,  0,  1,  0, -1,  0,  1,  0,  0] [ 0,  6,  6]  1 */
    18426648, /* 60380 (1550) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
        8872, /* 60381 (1550) [ 0,  0, -1, -1,  0,  0,  0,  1,  0] [ 0,  0,  0]  1 */
    17136480, /* 60382 (1550) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 6,  0,  6]  1 */
    18432160, /* 60383 (1550) [ 0,  0, -1, -1,  0,  0,  0,  1,  0] [ 6,  6,  0]  1 */
     1544296, /* 60384 (1550) [ 0,  0, -1,  0, -1,  0, -1,  0,  0] [ 0,  6,  6]  1 */
        3250, /* 60385 (1550) [-1,  0,  0,  0,  0, -1,  0, -1,  0] [ 0,  0,  0]  1 */
    18426598, /* 60386 (1550) [-1,  0,  0,  0,  0,  1,  0,  1,  0] [ 6,  6,  0]  1 */
        9202, /* 60387 (1550) [ 0,  0, -1,  0,  1,  0,  1,  0,  0] [ 0,  0,  0]  1 */
    18433612, /* 60388 (1550) [ 0,  0,  1, -1,  0,  0,  0, -1,  0] [ 6,  6,  0]  1 */
    17133562, /* 60389 (1550) [ 0,  0, -1,  1,  0,  0,  0, -1,  0] [ 6,  0,  6]  1 */
     1542684, /* 60390 (1550) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 0,  6,  6]  1 */
    17131846, /* 60391 (1550) [ 0, -1,  0,  0,  0, -1,  1,  0,  0] [ 6,  0,  6]  1 */
       10324, /* 60392 (1550) [ 0,  0,  1, -1,  0,  0,  0, -1,  0] [ 0,  0,  0]  1 */
     1538634, /* 60393 (1550) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
    17134852, /* 60394 (1550) [ 0,  0,  1,  0,  1,  0, -1,  0,  0] [ 6,  0,  6]  1 */
     1544146, /* 60395 (1550) [ 0,  0, -1, -1,  0,  0,  0,  1,  0] [ 0,  6,  6]  1 */
    17135996, /* 60396 (1550) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 6,  0,  6]  1 */
    17140636, /* 60397 (1550) [ 1,  0,  0,  0,  0,  1,  0, -1,  0] [ 6,  0,  6]  1 */
    17134534, /* 60398 (1550) [ 0,  0,  1, -1,  0,  0,  0, -1,  0] [ 6,  0,  6]  1 */
    18439772, /* 60399 (1550) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    17140530, /* 60400 (1550) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  6]  1 */
    17140588, /* 60401 (1550) [ 1,  0,  0,  0,  0, -1,  0,  1,  0] [ 6,  0,  6]  1 */
    18430960, /* 60402 (1550) [ 0, -1,  0,  0,  0,  1, -1,  0,  0] [ 6,  6,  0]  1 */
    18432490, /* 60403 (1550) [ 0,  0, -1,  0,  1,  0,  1,  0,  0] [ 6,  6,  0]  1 */
    17133232, /* 60404 (1550) [ 0,  0, -1,  0, -1,  0, -1,  0,  0] [ 6,  0,  6]  1 */
       11786, /* 60405 (1550) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    18435280, /* 60406 (1550) [ 0,  1,  0,  0,  0, -1, -1,  0,  0] [ 6,  6,  0]  1 */
        7898, /* 60407 (1550) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    18435352, /* 60408 (1550) [ 0,  1,  0,  0,  0,  1,  1,  0,  0] [ 6,  6,  0]  1 */
        3310, /* 60409 (1550) [-1,  0,  0,  0,  0,  1,  0,  1,  0] [ 0,  0,  0]  1 */
       10816, /* 60410 (1550) [ 0,  0,  1,  1,  0,  0,  0,  1,  0] [ 0,  0,  0]  1 */
    18434104, /* 60411 (1550) [ 0,  0,  1,  1,  0,  0,  0,  1,  0] [ 6,  6,  0]  1 */
       11992, /* 60412 (1550) [ 0,  1,  0,  0,  0, -1, -1,  0,  0] [ 0,  0,  0]  1 */
       12064, /* 60413 (1550) [ 0,  1,  0,  0,  0,  1,  1,  0,  0] [ 0,  0,  0]  1 */
     1551758, /* 60414 (1550) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
    17133412, /* 60415 (1550) [ 0,  0, -1,  0,  1,  0,  1,  0,  0] [ 6,  0,  6]  1 */
    17127570, /* 60416 (1550) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6]  1 */
     1542946, /* 60417 (1550) [ 0, -1,  0,  0,  0,  1, -1,  0,  0] [ 0,  6,  6]  1 */
    17133082, /* 60418 (1550) [ 0,  0, -1, -1,  0,  0,  0,  1,  0] [ 6,  0,  6]  1 */
       12270, /* 60419 (1550) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  0]  1 */
     1547266, /* 60420 (1550) [ 0,  1,  0,  0,  0, -1, -1,  0,  0] [ 0,  6,  6]  1 */
       10498, /* 60421 (1550) [ 0,  0,  1,  0, -1,  0,  1,  0,  0] [ 0,  0,  0]  1 */
     1538584, /* 60422 (1550) [-1,  0,  0,  0,  0,  1,  0,  1,  0] [ 0,  6,  6]  1 */
    17127460, /* 60423 (1550) [-1,  0,  0,  0,  0, -1,  0, -1,  0] [ 6,  0,  6]  1 */
     1546090, /* 60424 (1550) [ 0,  0,  1,  1,  0,  0,  0,  1,  0] [ 0,  6,  6]  1 */
    18431186, /* 60425 (1550) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    18433930, /* 60426 (1550) [ 0,  0,  1,  0,  1,  0, -1,  0,  0] [ 6,  6,  0]  1 */
        7672, /* 60427 (1550) [ 0, -1,  0,  0,  0,  1, -1,  0,  0] [ 0,  0,  0]  1 */
        3360, /* 60428 (1550) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    18426488, /* 60429 (1550) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    17131620, /* 60430 (1550) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 6,  0,  6]  1 */
    18435558, /* 60431 (1550) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 6,  6,  0]  1 */
    18439608, /* 60432 (1550) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
     1543172, /* 60433 (1550) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 0,  6,  6]  1 */
     1545916, /* 60434 (1550) [ 0,  0,  1,  0,  1,  0, -1,  0,  0] [ 0,  6,  6]  1 */
       16378, /* 60435 (1550) [ 1,  0,  0,  0,  0, -1,  0,  1,  0] [ 0,  0,  0]  1 */
    17127520, /* 60436 (1550) [-1,  0,  0,  0,  0,  1,  0,  1,  0] [ 6,  0,  6]  1 */
    17127410, /* 60437 (1550) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
    17131882, /* 60438 (1550) [ 0, -1,  0,  0,  0,  1, -1,  0,  0] [ 6,  0,  6]  1 */
    17136202, /* 60439 (1550) [ 0,  1,  0,  0,  0, -1, -1,  0,  0] [ 6,  0,  6]  1 */
     1547338, /* 60440 (1550) [ 0,  1,  0,  0,  0,  1,  1,  0,  0] [ 0,  6,  6]  1 */
    18432640, /* 60441 (1550) [ 0,  0, -1,  1,  0,  0,  0, -1,  0] [ 6,  6,  0]  1 */
    17135026, /* 60442 (1550) [ 0,  0,  1,  1,  0,  0,  0,  1,  0] [ 6,  0,  6]  1 */
        7636, /* 60443 (1550) [ 0, -1,  0,  0,  0, -1,  1,  0,  0] [ 0,  0,  0]  1 */
    18430924, /* 60444 (1550) [ 0, -1,  0,  0,  0, -1,  1,  0,  0] [ 6,  6,  0]  1 */
     1547544, /* 60445 (1550) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 0,  6,  6]  1 */
    18435074, /* 60446 (1550) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 6,  6,  0]  1 */
     1551594, /* 60447 (1550) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
    18439714, /* 60448 (1550) [ 1,  0,  0,  0,  0,  1,  0, -1,  0] [ 6,  6,  0]  1 */
       10642, /* 60449 (1550) [ 0,  0,  1,  0,  1,  0, -1,  0,  0] [ 0,  0,  0]  1 */
    18426538, /* 60450 (1550) [-1,  0,  0,  0,  0, -1,  0, -1,  0] [ 6,  6,  0]  1 */
       16426, /* 60451 (1550) [ 1,  0,  0,  0,  0,  1,  0, -1,  0] [ 0,  0,  0]  1 */
     1544626, /* 60452 (1550) [ 0,  0, -1,  1,  0,  0,  0, -1,  0] [ 0,  6,  6]  1 */
        3200, /* 60453 (1550) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
     1542910, /* 60454 (1550) [ 0, -1,  0,  0,  0, -1,  1,  0,  0] [ 0,  6,  6]  1 */
     1544476, /* 60455 (1550) [ 0,  0, -1,  0,  1,  0,  1,  0,  0] [ 0,  6,  6]  1 */
    18439666, /* 60456 (1550) [ 1,  0,  0,  0,  0, -1,  0,  1,  0] [ 6,  6,  0]  1 */
     1547060, /* 60457 (1550) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 0,  6,  6]  1 */
    18433786, /* 60458 (1550) [ 0,  0,  1,  0, -1,  0,  1,  0,  0] [ 6,  6,  0]  1 */
       16484, /* 60459 (1551) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
     1551700, /* 60460 (1551) [ 1,  0,  0,  0,  0,  1,  0, -1,  0] [ 0,  6,  6]  1 */
    17140694, /* 60461 (1551) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
        9022, /* 60462 (1551) [ 0,  0, -1,  0, -1,  0, -1,  0,  0] [ 0,  0,  0]  1 */
    18432310, /* 60463 (1551) [ 0,  0, -1,  0, -1,  0, -1,  0,  0] [ 6,  6,  0]  1 */
       16320, /* 60464 (1551) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    17132108, /* 60465 (1551) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 6,  0,  6]  1 */
    52451996, /* 60466 (1551) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
     1545598, /* 60467 (1551) [ 0,  0,  1, -1,  0,  0,  0, -1,  0] [ 0,  6,  6]  1 */
    51152754, /* 60468 (1551) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  6] -1 */
     1538524, /* 60469 (1551) [-1,  0,  0,  0,  0, -1,  0, -1,  0] [ 0,  6,  6]  1 */
    52443410, /* 60470 (1551) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 6,  6,  0] -1 */
     1538474, /* 60471 (1551) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
    34019896, /* 60472 (1551) [ 0, -1,  0,  0,  0,  1, -1,  0,  0] [ 0,  0,  0] -1 */
    52443184, /* 60473 (1551) [ 0, -1,  0,  0,  0,  1, -1,  0,  0] [ 6,  6,  0] -1 */
    17136274, /* 60474 (1551) [ 0,  1,  0,  0,  0,  1,  1,  0,  0] [ 6,  0,  6]  1 */
    34015584, /* 60475 (1551) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
        7410, /* 60476 (1551) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    18430698, /* 60477 (1551) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 6,  6,  0]  1 */
    17134708, /* 60478 (1551) [ 0,  0,  1,  0, -1,  0,  1,  0,  0] [ 6,  0,  6]  1 */
    34020122, /* 60479 (1551) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 0,  0,  0] -1 */
        9352, /* 60480 (1551) [ 0,  0, -1,  1,  0,  0,  0, -1,  0] [ 0,  0,  0]  1 */
    52447576, /* 60481 (1551) [ 0,  1,  0,  0,  0,  1,  1,  0,  0] [ 6,  6,  0] -1 */
    51143844, /* 60482 (1551) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 6,  0,  6] -1 */
     1551652, /* 60483 (1551) [ 1,  0,  0,  0,  0, -1,  0,  1,  0] [ 0,  6,  6]  1 */
     1545772, /* 60484 (1551) [ 0,  0,  1,  0, -1,  0,  1,  0,  0] [ 0,  6,  6]  1 */
    34023040, /* 60485 (1551) [ 0,  0,  1,  1,  0,  0,  0,  1,  0] [ 0,  0,  0] -1 */
    52446328, /* 60486 (1551) [ 0,  0,  1,  1,  0,  0,  0,  1,  0] [ 6,  6,  0] -1 */
    18426648, /* 60487 (1551) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
        8872, /* 60488 (1551) [ 0,  0, -1, -1,  0,  0,  0,  1,  0] [ 0,  0,  0]  1 */
    17136480, /* 60489 (1551) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 6,  0,  6]  1 */
    18432160, /* 60490 (1551) [ 0,  0, -1, -1,  0,  0,  0,  1,  0] [ 6,  6,  0]  1 */
     1544296, /* 60491 (1551) [ 0,  0, -1,  0, -1,  0, -1,  0,  0] [ 0,  6,  6]  1 */
    34024288, /* 60492 (1551) [ 0,  1,  0,  0,  0,  1,  1,  0,  0] [ 0,  0,  0] -1 */
    35563982, /* 60493 (1551) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
    52447782, /* 60494 (1551) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 6,  6,  0] -1 */
        3250, /* 60495 (1551) [-1,  0,  0,  0,  0, -1,  0, -1,  0] [ 0,  0,  0]  1 */
    35555396, /* 60496 (1551) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 0,  6,  6] -1 */
    18426598, /* 60497 (1551) [-1,  0,  0,  0,  0,  1,  0,  1,  0] [ 6,  6,  0]  1 */
        9202, /* 60498 (1551) [ 0,  0, -1,  0,  1,  0,  1,  0,  0] [ 0,  0,  0]  1 */
    51139794, /* 60499 (1551) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6] -1 */
    35555170, /* 60500 (1551) [ 0, -1,  0,  0,  0,  1, -1,  0,  0] [ 0,  6,  6] -1 */
    18433612, /* 60501 (1551) [ 0,  0,  1, -1,  0,  0,  0, -1,  0] [ 6,  6,  0]  1 */
    34024494, /* 60502 (1551) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    17133562, /* 60503 (1551) [ 0,  0, -1,  1,  0,  0,  0, -1,  0] [ 6,  0,  6]  1 */
     1542684, /* 60504 (1551) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 0,  6,  6]  1 */
    35559490, /* 60505 (1551) [ 0,  1,  0,  0,  0, -1, -1,  0,  0] [ 0,  6,  6] -1 */
    35559562, /* 60506 (1551) [ 0,  1,  0,  0,  0,  1,  1,  0,  0] [ 0,  6,  6] -1 */
    52444864, /* 60507 (1551) [ 0,  0, -1,  1,  0,  0,  0, -1,  0] [ 6,  6,  0] -1 */
    17131846, /* 60508 (1551) [ 0, -1,  0,  0,  0, -1,  1,  0,  0] [ 6,  0,  6]  1 */
    35558314, /* 60509 (1551) [ 0,  0,  1,  1,  0,  0,  0,  1,  0] [ 0,  6,  6] -1 */
       10324, /* 60510 (1551) [ 0,  0,  1, -1,  0,  0,  0, -1,  0] [ 0,  0,  0]  1 */
     1538634, /* 60511 (1551) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
    17134852, /* 60512 (1551) [ 0,  0,  1,  0,  1,  0, -1,  0,  0] [ 6,  0,  6]  1 */
    52443148, /* 60513 (1551) [ 0, -1,  0,  0,  0, -1,  1,  0,  0] [ 6,  6,  0] -1 */
     1544146, /* 60514 (1551) [ 0,  0, -1, -1,  0,  0,  0,  1,  0] [ 0,  6,  6]  1 */
    17135996, /* 60515 (1551) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 6,  0,  6]  1 */
    17140636, /* 60516 (1551) [ 1,  0,  0,  0,  0,  1,  0, -1,  0] [ 6,  0,  6]  1 */
    52447298, /* 60517 (1551) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 6,  6,  0] -1 */
    17134534, /* 60518 (1551) [ 0,  0,  1, -1,  0,  0,  0, -1,  0] [ 6,  0,  6]  1 */
    34022866, /* 60519 (1551) [ 0,  0,  1,  0,  1,  0, -1,  0,  0] [ 0,  0,  0] -1 */
    52446154, /* 60520 (1551) [ 0,  0,  1,  0,  1,  0, -1,  0,  0] [ 6,  6,  0] -1 */
    34028650, /* 60521 (1551) [ 1,  0,  0,  0,  0,  1,  0, -1,  0] [ 0,  0,  0] -1 */
    35556850, /* 60522 (1551) [ 0,  0, -1,  1,  0,  0,  0, -1,  0] [ 0,  6,  6] -1 */
    18439772, /* 60523 (1551) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    34015424, /* 60524 (1551) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    34028708, /* 60525 (1551) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    17140530, /* 60526 (1551) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  6]  1 */
    52438712, /* 60527 (1551) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
    17140588, /* 60528 (1551) [ 1,  0,  0,  0,  0, -1,  0,  1,  0] [ 6,  0,  6]  1 */
    52451890, /* 60529 (1551) [ 1,  0,  0,  0,  0, -1,  0,  1,  0] [ 6,  6,  0] -1 */
    18430960, /* 60530 (1551) [ 0, -1,  0,  0,  0,  1, -1,  0,  0] [ 6,  6,  0]  1 */
    18432490, /* 60531 (1551) [ 0,  0, -1,  0,  1,  0,  1,  0,  0] [ 6,  6,  0]  1 */
    17133232, /* 60532 (1551) [ 0,  0, -1,  0, -1,  0, -1,  0,  0] [ 6,  0,  6]  1 */
       11786, /* 60533 (1551) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    18435280, /* 60534 (1551) [ 0,  1,  0,  0,  0, -1, -1,  0,  0] [ 6,  6,  0]  1 */
    51152918, /* 60535 (1551) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
        7898, /* 60536 (1551) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    18435352, /* 60537 (1551) [ 0,  1,  0,  0,  0,  1,  1,  0,  0] [ 6,  6,  0]  1 */
    52444534, /* 60538 (1551) [ 0,  0, -1,  0, -1,  0, -1,  0,  0] [ 6,  6,  0] -1 */
    34028544, /* 60539 (1551) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    52451832, /* 60540 (1551) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
        3310, /* 60541 (1551) [-1,  0,  0,  0,  0,  1,  0,  1,  0] [ 0,  0,  0]  1 */
    35558140, /* 60542 (1551) [ 0,  0,  1,  0,  1,  0, -1,  0,  0] [ 0,  6,  6] -1 */
    34028602, /* 60543 (1551) [ 1,  0,  0,  0,  0, -1,  0,  1,  0] [ 0,  0,  0] -1 */
       10816, /* 60544 (1551) [ 0,  0,  1,  1,  0,  0,  0,  1,  0] [ 0,  0,  0]  1 */
    18434104, /* 60545 (1551) [ 0,  0,  1,  1,  0,  0,  0,  1,  0] [ 6,  6,  0]  1 */
    51139744, /* 60546 (1551) [-1,  0,  0,  0,  0,  1,  0,  1,  0] [ 6,  0,  6] -1 */
       11992, /* 60547 (1551) [ 0,  1,  0,  0,  0, -1, -1,  0,  0] [ 0,  0,  0]  1 */
    51139634, /* 60548 (1551) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
    51144106, /* 60549 (1551) [ 0, -1,  0,  0,  0,  1, -1,  0,  0] [ 6,  0,  6] -1 */
       12064, /* 60550 (1551) [ 0,  1,  0,  0,  0,  1,  1,  0,  0] [ 0,  0,  0]  1 */
     1551758, /* 60551 (1551) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
    35550698, /* 60552 (1551) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
    51148426, /* 60553 (1551) [ 0,  1,  0,  0,  0, -1, -1,  0,  0] [ 6,  0,  6] -1 */
    51148498, /* 60554 (1551) [ 0,  1,  0,  0,  0,  1,  1,  0,  0] [ 6,  0,  6] -1 */
    52442922, /* 60555 (1551) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 6,  6,  0] -1 */
    51147250, /* 60556 (1551) [ 0,  0,  1,  1,  0,  0,  0,  1,  0] [ 6,  0,  6] -1 */
    17133412, /* 60557 (1551) [ 0,  0, -1,  0,  1,  0,  1,  0,  0] [ 6,  0,  6]  1 */
    34019860, /* 60558 (1551) [ 0, -1,  0,  0,  0, -1,  1,  0,  0] [ 0,  0,  0] -1 */
    17127570, /* 60559 (1551) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6]  1 */
    35563876, /* 60560 (1551) [ 1,  0,  0,  0,  0, -1,  0,  1,  0] [ 0,  6,  6] -1 */
     1547060, /* 60561 (1551) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 0,  6,  6]  1 */
     1542946, /* 60562 (1551) [ 0, -1,  0,  0,  0,  1, -1,  0,  0] [ 0,  6,  6]  1 */
    17133082, /* 60563 (1551) [ 0,  0, -1, -1,  0,  0,  0,  1,  0] [ 6,  0,  6]  1 */
       12270, /* 60564 (1551) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  0]  1 */
     1547266, /* 60565 (1551) [ 0,  1,  0,  0,  0, -1, -1,  0,  0] [ 0,  6,  6]  1 */
    35559768, /* 60566 (1551) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 0,  6,  6] -1 */
    52444384, /* 60567 (1551) [ 0,  0, -1, -1,  0,  0,  0,  1,  0] [ 6,  6,  0] -1 */
    35556520, /* 60568 (1551) [ 0,  0, -1,  0, -1,  0, -1,  0,  0] [ 0,  6,  6] -1 */
    35563818, /* 60569 (1551) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  6] -1 */
     1538584, /* 60570 (1551) [-1,  0,  0,  0,  0,  1,  0,  1,  0] [ 0,  6,  6]  1 */
    52451938, /* 60571 (1551) [ 1,  0,  0,  0,  0,  1,  0, -1,  0] [ 6,  6,  0] -1 */
    17127460, /* 60572 (1551) [-1,  0,  0,  0,  0, -1,  0, -1,  0] [ 6,  0,  6]  1 */
     1546090, /* 60573 (1551) [ 0,  0,  1,  1,  0,  0,  0,  1,  0] [ 0,  6,  6]  1 */
    34015474, /* 60574 (1551) [-1,  0,  0,  0,  0, -1,  0, -1,  0] [ 0,  0,  0] -1 */
    52438762, /* 60575 (1551) [-1,  0,  0,  0,  0, -1,  0, -1,  0] [ 6,  6,  0] -1 */
    35554908, /* 60576 (1551) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 0,  6,  6] -1 */
    35555134, /* 60577 (1551) [ 0, -1,  0,  0,  0, -1,  1,  0,  0] [ 0,  6,  6] -1 */
    18431186, /* 60578 (1551) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    18433930, /* 60579 (1551) [ 0,  0,  1,  0,  1,  0, -1,  0,  0] [ 6,  6,  0]  1 */
    35556700, /* 60580 (1551) [ 0,  0, -1,  0,  1,  0,  1,  0,  0] [ 0,  6,  6] -1 */
    34022548, /* 60581 (1551) [ 0,  0,  1, -1,  0,  0,  0, -1,  0] [ 0,  0,  0] -1 */
        7672, /* 60582 (1551) [ 0, -1,  0,  0,  0,  1, -1,  0,  0] [ 0,  0,  0]  1 */
    34022722, /* 60583 (1551) [ 0,  0,  1,  0, -1,  0,  1,  0,  0] [ 0,  0,  0] -1 */
    52446010, /* 60584 (1551) [ 0,  0,  1,  0, -1,  0,  1,  0,  0] [ 6,  6,  0] -1 */
    35559284, /* 60585 (1551) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 0,  6,  6] -1 */
    35556370, /* 60586 (1551) [ 0,  0, -1, -1,  0,  0,  0,  1,  0] [ 0,  6,  6] -1 */
        3360, /* 60587 (1551) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    35563924, /* 60588 (1551) [ 1,  0,  0,  0,  0,  1,  0, -1,  0] [ 0,  6,  6] -1 */
    18426488, /* 60589 (1551) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    34021246, /* 60590 (1551) [ 0,  0, -1,  0, -1,  0, -1,  0,  0] [ 0,  0,  0] -1 */
    17131620, /* 60591 (1551) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 6,  0,  6]  1 */
    51144332, /* 60592 (1551) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 6,  0,  6] -1 */
    35550748, /* 60593 (1551) [-1,  0,  0,  0,  0, -1,  0, -1,  0] [ 0,  6,  6] -1 */
    35557822, /* 60594 (1551) [ 0,  0,  1, -1,  0,  0,  0, -1,  0] [ 0,  6,  6] -1 */
    18435558, /* 60595 (1551) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 6,  6,  0]  1 */
    18439608, /* 60596 (1551) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
    34019634, /* 60597 (1551) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  0] -1 */
     1543172, /* 60598 (1551) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 0,  6,  6]  1 */
     1545916, /* 60599 (1551) [ 0,  0,  1,  0,  1,  0, -1,  0,  0] [ 0,  6,  6]  1 */
       16378, /* 60600 (1551) [ 1,  0,  0,  0,  0, -1,  0,  1,  0] [ 0,  0,  0]  1 */
    51146932, /* 60601 (1551) [ 0,  0,  1,  0, -1,  0,  1,  0,  0] [ 6,  0,  6] -1 */
    34021576, /* 60602 (1551) [ 0,  0, -1,  1,  0,  0,  0, -1,  0] [ 0,  0,  0] -1 */
    17127520, /* 60603 (1551) [-1,  0,  0,  0,  0,  1,  0,  1,  0] [ 6,  0,  6]  1 */
    51152812, /* 60604 (1551) [ 1,  0,  0,  0,  0, -1,  0,  1,  0] [ 6,  0,  6] -1 */
    35557996, /* 60605 (1551) [ 0,  0,  1,  0, -1,  0,  1,  0,  0] [ 0,  6,  6] -1 */
    17127410, /* 60606 (1551) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
    17131882, /* 60607 (1551) [ 0, -1,  0,  0,  0,  1, -1,  0,  0] [ 6,  0,  6]  1 */
    52438872, /* 60608 (1551) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
    17136202, /* 60609 (1551) [ 0,  1,  0,  0,  0, -1, -1,  0,  0] [ 6,  0,  6]  1 */
     1547338, /* 60610 (1551) [ 0,  1,  0,  0,  0,  1,  1,  0,  0] [ 0,  6,  6]  1 */
    51148704, /* 60611 (1551) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 6,  0,  6] -1 */
    34021096, /* 60612 (1551) [ 0,  0, -1, -1,  0,  0,  0,  1,  0] [ 0,  0,  0] -1 */
    52444714, /* 60613 (1551) [ 0,  0, -1,  0,  1,  0,  1,  0,  0] [ 6,  6,  0] -1 */
    18432640, /* 60614 (1551) [ 0,  0, -1,  1,  0,  0,  0, -1,  0] [ 6,  6,  0]  1 */
    51145456, /* 60615 (1551) [ 0,  0, -1,  0, -1,  0, -1,  0,  0] [ 6,  0,  6] -1 */
    34024010, /* 60616 (1551) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    52447504, /* 60617 (1551) [ 0,  1,  0,  0,  0, -1, -1,  0,  0] [ 6,  6,  0] -1 */
    17135026, /* 60618 (1551) [ 0,  0,  1,  1,  0,  0,  0,  1,  0] [ 6,  0,  6]  1 */
        7636, /* 60619 (1551) [ 0, -1,  0,  0,  0, -1,  1,  0,  0] [ 0,  0,  0]  1 */
    18430924, /* 60620 (1551) [ 0, -1,  0,  0,  0, -1,  1,  0,  0] [ 6,  6,  0]  1 */
    34015534, /* 60621 (1551) [-1,  0,  0,  0,  0,  1,  0,  1,  0] [ 0,  0,  0] -1 */
    52438822, /* 60622 (1551) [-1,  0,  0,  0,  0,  1,  0,  1,  0] [ 6,  6,  0] -1 */
    34021426, /* 60623 (1551) [ 0,  0, -1,  0,  1,  0,  1,  0,  0] [ 0,  0,  0] -1 */
     1547544, /* 60624 (1551) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 0,  6,  6]  1 */
    18435074, /* 60625 (1551) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    52445836, /* 60626 (1551) [ 0,  0,  1, -1,  0,  0,  0, -1,  0] [ 6,  6,  0] -1 */
    34024216, /* 60627 (1551) [ 0,  1,  0,  0,  0, -1, -1,  0,  0] [ 0,  0,  0] -1 */
     1551594, /* 60628 (1551) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
    51145786, /* 60629 (1551) [ 0,  0, -1,  1,  0,  0,  0, -1,  0] [ 6,  0,  6] -1 */
    18439714, /* 60630 (1551) [ 1,  0,  0,  0,  0,  1,  0, -1,  0] [ 6,  6,  0]  1 */
    51144070, /* 60631 (1551) [ 0, -1,  0,  0,  0, -1,  1,  0,  0] [ 6,  0,  6] -1 */
       10642, /* 60632 (1551) [ 0,  0,  1,  0,  1,  0, -1,  0,  0] [ 0,  0,  0]  1 */
    18426538, /* 60633 (1551) [-1,  0,  0,  0,  0, -1,  0, -1,  0] [ 6,  6,  0]  1 */
    51145636, /* 60634 (1551) [ 0,  0, -1,  0,  1,  0,  1,  0,  0] [ 6,  0,  6] -1 */
    35550858, /* 60635 (1551) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6] -1 */
    51147076, /* 60636 (1551) [ 0,  0,  1,  0,  1,  0, -1,  0,  0] [ 6,  0,  6] -1 */
       16426, /* 60637 (1551) [ 1,  0,  0,  0,  0,  1,  0, -1,  0] [ 0,  0,  0]  1 */
    51148220, /* 60638 (1551) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 6,  0,  6] -1 */
    51145306, /* 60639 (1551) [ 0,  0, -1, -1,  0,  0,  0,  1,  0] [ 6,  0,  6] -1 */
     1544626, /* 60640 (1551) [ 0,  0, -1,  1,  0,  0,  0, -1,  0] [ 0,  6,  6]  1 */
        3200, /* 60641 (1551) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    51152860, /* 60642 (1551) [ 1,  0,  0,  0,  0,  1,  0, -1,  0] [ 6,  0,  6] -1 */
     1542910, /* 60643 (1551) [ 0, -1,  0,  0,  0, -1,  1,  0,  0] [ 0,  6,  6]  1 */
    35550808, /* 60644 (1551) [-1,  0,  0,  0,  0,  1,  0,  1,  0] [ 0,  6,  6] -1 */
    51139684, /* 60645 (1551) [-1,  0,  0,  0,  0, -1,  0, -1,  0] [ 6,  0,  6] -1 */
     1544476, /* 60646 (1551) [ 0,  0, -1,  0,  1,  0,  1,  0,  0] [ 0,  6,  6]  1 */
    51146758, /* 60647 (1551) [ 0,  0,  1, -1,  0,  0,  0, -1,  0] [ 6,  0,  6] -1 */
    18439666, /* 60648 (1551) [ 1,  0,  0,  0,  0, -1,  0,  1,  0] [ 6,  6,  0]  1 */
       10498, /* 60649 (1551) [ 0,  0,  1,  0, -1,  0,  1,  0,  0] [ 0,  0,  0]  1 */
    18433786, /* 60650 (1551) [ 0,  0,  1,  0, -1,  0,  1,  0,  0] [ 6,  6,  0]  1 */
       16484, /* 60651 (1552) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    17140694, /* 60652 (1552) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
       16320, /* 60653 (1552) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
     1545598, /* 60654 (1552) [ 0,  0,  1, -1,  0,  0,  0, -1,  0] [ 0,  6,  6]  1 */
    52443410, /* 60655 (1552) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 6,  6,  0] -1 */
     1538474, /* 60656 (1552) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
    17136274, /* 60657 (1552) [ 0,  1,  0,  0,  0,  1,  1,  0,  0] [ 6,  0,  6]  1 */
    34020122, /* 60658 (1552) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 0,  0,  0] -1 */
        9352, /* 60659 (1552) [ 0,  0, -1,  1,  0,  0,  0, -1,  0] [ 0,  0,  0]  1 */
    51143844, /* 60660 (1552) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 6,  0,  6] -1 */
    18426648, /* 60661 (1552) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
        8872, /* 60662 (1552) [ 0,  0, -1, -1,  0,  0,  0,  1,  0] [ 0,  0,  0]  1 */
    18432160, /* 60663 (1552) [ 0,  0, -1, -1,  0,  0,  0,  1,  0] [ 6,  6,  0]  1 */
    52447782, /* 60664 (1552) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 6,  6,  0] -1 */
    35555396, /* 60665 (1552) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 0,  6,  6] -1 */
    18433612, /* 60666 (1552) [ 0,  0,  1, -1,  0,  0,  0, -1,  0] [ 6,  6,  0]  1 */
    34024494, /* 60667 (1552) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    17133562, /* 60668 (1552) [ 0,  0, -1,  1,  0,  0,  0, -1,  0] [ 6,  0,  6]  1 */
    17131846, /* 60669 (1552) [ 0, -1,  0,  0,  0, -1,  1,  0,  0] [ 6,  0,  6]  1 */
       10324, /* 60670 (1552) [ 0,  0,  1, -1,  0,  0,  0, -1,  0] [ 0,  0,  0]  1 */
     1538634, /* 60671 (1552) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
     1544146, /* 60672 (1552) [ 0,  0, -1, -1,  0,  0,  0,  1,  0] [ 0,  6,  6]  1 */
    52447298, /* 60673 (1552) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 6,  6,  0] -1 */
    17134534, /* 60674 (1552) [ 0,  0,  1, -1,  0,  0,  0, -1,  0] [ 6,  0,  6]  1 */
    34022866, /* 60675 (1552) [ 0,  0,  1,  0,  1,  0, -1,  0,  0] [ 0,  0,  0] -1 */
    52446154, /* 60676 (1552) [ 0,  0,  1,  0,  1,  0, -1,  0,  0] [ 6,  6,  0] -1 */
    34028650, /* 60677 (1552) [ 1,  0,  0,  0,  0,  1,  0, -1,  0] [ 0,  0,  0] -1 */
    18439772, /* 60678 (1552) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    17140530, /* 60679 (1552) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  6]  1 */
    52451890, /* 60680 (1552) [ 1,  0,  0,  0,  0, -1,  0,  1,  0] [ 6,  6,  0] -1 */
    18430960, /* 60681 (1552) [ 0, -1,  0,  0,  0,  1, -1,  0,  0] [ 6,  6,  0]  1 */
    18435280, /* 60682 (1552) [ 0,  1,  0,  0,  0, -1, -1,  0,  0] [ 6,  6,  0]  1 */
    18435352, /* 60683 (1552) [ 0,  1,  0,  0,  0,  1,  1,  0,  0] [ 6,  6,  0]  1 */
    52444534, /* 60684 (1552) [ 0,  0, -1,  0, -1,  0, -1,  0,  0] [ 6,  6,  0] -1 */
    35558140, /* 60685 (1552) [ 0,  0,  1,  0,  1,  0, -1,  0,  0] [ 0,  6,  6] -1 */
    34028602, /* 60686 (1552) [ 1,  0,  0,  0,  0, -1,  0,  1,  0] [ 0,  0,  0] -1 */
       10816, /* 60687 (1552) [ 0,  0,  1,  1,  0,  0,  0,  1,  0] [ 0,  0,  0]  1 */
    18434104, /* 60688 (1552) [ 0,  0,  1,  1,  0,  0,  0,  1,  0] [ 6,  6,  0]  1 */
    51139744, /* 60689 (1552) [-1,  0,  0,  0,  0,  1,  0,  1,  0] [ 6,  0,  6] -1 */
       11992, /* 60690 (1552) [ 0,  1,  0,  0,  0, -1, -1,  0,  0] [ 0,  0,  0]  1 */
       12064, /* 60691 (1552) [ 0,  1,  0,  0,  0,  1,  1,  0,  0] [ 0,  0,  0]  1 */
     1551758, /* 60692 (1552) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
    52442922, /* 60693 (1552) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 6,  6,  0] -1 */
    17127570, /* 60694 (1552) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6]  1 */
    35563876, /* 60695 (1552) [ 1,  0,  0,  0,  0, -1,  0,  1,  0] [ 0,  6,  6] -1 */
     1542946, /* 60696 (1552) [ 0, -1,  0,  0,  0,  1, -1,  0,  0] [ 0,  6,  6]  1 */
    17133082, /* 60697 (1552) [ 0,  0, -1, -1,  0,  0,  0,  1,  0] [ 6,  0,  6]  1 */
     1547266, /* 60698 (1552) [ 0,  1,  0,  0,  0, -1, -1,  0,  0] [ 0,  6,  6]  1 */
    35559768, /* 60699 (1552) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 0,  6,  6] -1 */
    35556520, /* 60700 (1552) [ 0,  0, -1,  0, -1,  0, -1,  0,  0] [ 0,  6,  6] -1 */
    52451938, /* 60701 (1552) [ 1,  0,  0,  0,  0,  1,  0, -1,  0] [ 6,  6,  0] -1 */
     1546090, /* 60702 (1552) [ 0,  0,  1,  1,  0,  0,  0,  1,  0] [ 0,  6,  6]  1 */
    34015474, /* 60703 (1552) [-1,  0,  0,  0,  0, -1,  0, -1,  0] [ 0,  0,  0] -1 */
    52438762, /* 60704 (1552) [-1,  0,  0,  0,  0, -1,  0, -1,  0] [ 6,  6,  0] -1 */
    35554908, /* 60705 (1552) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 0,  6,  6] -1 */
    35556700, /* 60706 (1552) [ 0,  0, -1,  0,  1,  0,  1,  0,  0] [ 0,  6,  6] -1 */
        7672, /* 60707 (1552) [ 0, -1,  0,  0,  0,  1, -1,  0,  0] [ 0,  0,  0]  1 */
    34022722, /* 60708 (1552) [ 0,  0,  1,  0, -1,  0,  1,  0,  0] [ 0,  0,  0] -1 */
    52446010, /* 60709 (1552) [ 0,  0,  1,  0, -1,  0,  1,  0,  0] [ 6,  6,  0] -1 */
    35559284, /* 60710 (1552) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 0,  6,  6] -1 */
        3360, /* 60711 (1552) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    35563924, /* 60712 (1552) [ 1,  0,  0,  0,  0,  1,  0, -1,  0] [ 0,  6,  6] -1 */
    18426488, /* 60713 (1552) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    34021246, /* 60714 (1552) [ 0,  0, -1,  0, -1,  0, -1,  0,  0] [ 0,  0,  0] -1 */
    51144332, /* 60715 (1552) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 6,  0,  6] -1 */
    35550748, /* 60716 (1552) [-1,  0,  0,  0,  0, -1,  0, -1,  0] [ 0,  6,  6] -1 */
    18439608, /* 60717 (1552) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
    34019634, /* 60718 (1552) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    51146932, /* 60719 (1552) [ 0,  0,  1,  0, -1,  0,  1,  0,  0] [ 6,  0,  6] -1 */
    51152812, /* 60720 (1552) [ 1,  0,  0,  0,  0, -1,  0,  1,  0] [ 6,  0,  6] -1 */
    35557996, /* 60721 (1552) [ 0,  0,  1,  0, -1,  0,  1,  0,  0] [ 0,  6,  6] -1 */
    17127410, /* 60722 (1552) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
    17131882, /* 60723 (1552) [ 0, -1,  0,  0,  0,  1, -1,  0,  0] [ 6,  0,  6]  1 */
    17136202, /* 60724 (1552) [ 0,  1,  0,  0,  0, -1, -1,  0,  0] [ 6,  0,  6]  1 */
     1547338, /* 60725 (1552) [ 0,  1,  0,  0,  0,  1,  1,  0,  0] [ 0,  6,  6]  1 */
    51148704, /* 60726 (1552) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 6,  0,  6] -1 */
    52444714, /* 60727 (1552) [ 0,  0, -1,  0,  1,  0,  1,  0,  0] [ 6,  6,  0] -1 */
    18432640, /* 60728 (1552) [ 0,  0, -1,  1,  0,  0,  0, -1,  0] [ 6,  6,  0]  1 */
    51145456, /* 60729 (1552) [ 0,  0, -1,  0, -1,  0, -1,  0,  0] [ 6,  0,  6] -1 */
    34024010, /* 60730 (1552) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    17135026, /* 60731 (1552) [ 0,  0,  1,  1,  0,  0,  0,  1,  0] [ 6,  0,  6]  1 */
        7636, /* 60732 (1552) [ 0, -1,  0,  0,  0, -1,  1,  0,  0] [ 0,  0,  0]  1 */
    18430924, /* 60733 (1552) [ 0, -1,  0,  0,  0, -1,  1,  0,  0] [ 6,  6,  0]  1 */
    34015534, /* 60734 (1552) [-1,  0,  0,  0,  0,  1,  0,  1,  0] [ 0,  0,  0] -1 */
    52438822, /* 60735 (1552) [-1,  0,  0,  0,  0,  1,  0,  1,  0] [ 6,  6,  0] -1 */
    34021426, /* 60736 (1552) [ 0,  0, -1,  0,  1,  0,  1,  0,  0] [ 0,  0,  0] -1 */
     1551594, /* 60737 (1552) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
    51145636, /* 60738 (1552) [ 0,  0, -1,  0,  1,  0,  1,  0,  0] [ 6,  0,  6] -1 */
    51147076, /* 60739 (1552) [ 0,  0,  1,  0,  1,  0, -1,  0,  0] [ 6,  0,  6] -1 */
    51148220, /* 60740 (1552) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 6,  0,  6] -1 */
     1544626, /* 60741 (1552) [ 0,  0, -1,  1,  0,  0,  0, -1,  0] [ 0,  6,  6]  1 */
        3200, /* 60742 (1552) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    51152860, /* 60743 (1552) [ 1,  0,  0,  0,  0,  1,  0, -1,  0] [ 6,  0,  6] -1 */
     1542910, /* 60744 (1552) [ 0, -1,  0,  0,  0, -1,  1,  0,  0] [ 0,  6,  6]  1 */
    35550808, /* 60745 (1552) [-1,  0,  0,  0,  0,  1,  0,  1,  0] [ 0,  6,  6] -1 */
    51139684, /* 60746 (1552) [-1,  0,  0,  0,  0, -1,  0, -1,  0] [ 6,  0,  6] -1 */
       16484, /* 60747 (1553) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    52562962, /* 60748 (1553) [ 0,  0, -1,  1,  0,  0,  0, -1,  0] [ 6,  6,  6] -1 */
     1551700, /* 60749 (1553) [ 1,  0,  0,  0,  0,  1,  0, -1,  0] [ 0,  6,  6]  1 */
    17140694, /* 60750 (1553) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
        9022, /* 60751 (1553) [ 0,  0, -1,  0, -1,  0, -1,  0,  0] [ 0,  0,  0]  1 */
    35439898, /* 60752 (1553) [ 0,  0,  1,  0, -1,  0,  1,  0,  0] [ 0,  6,  0] -1 */
       16320, /* 60753 (1553) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    18432310, /* 60754 (1553) [ 0,  0, -1,  0, -1,  0, -1,  0,  0] [ 6,  6,  0]  1 */
    51028978, /* 60755 (1553) [ 0,  0,  1,  0,  1,  0, -1,  0,  0] [ 6,  0,  0] -1 */
    17132108, /* 60756 (1553) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 6,  0,  6]  1 */
     1538524, /* 60757 (1553) [-1,  0,  0,  0,  0, -1,  0, -1,  0] [ 0,  6,  6]  1 */
     1545598, /* 60758 (1553) [ 0,  0,  1, -1,  0,  0,  0, -1,  0] [ 0,  6,  6]  1 */
     1538474, /* 60759 (1553) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
    51034820, /* 60760 (1553) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  0] -1 */
    17136274, /* 60761 (1553) [ 0,  1,  0,  0,  0,  1,  1,  0,  0] [ 6,  0,  6]  1 */
    34138220, /* 60762 (1553) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 0,  0,  6] -1 */
        7410, /* 60763 (1553) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    18430698, /* 60764 (1553) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 6,  6,  0]  1 */
    17134708, /* 60765 (1553) [ 0,  0,  1,  0, -1,  0,  1,  0,  0] [ 6,  0,  6]  1 */
        9352, /* 60766 (1553) [ 0,  0, -1,  1,  0,  0,  0, -1,  0] [ 0,  0,  0]  1 */
     1551652, /* 60767 (1553) [ 1,  0,  0,  0,  0, -1,  0,  1,  0] [ 0,  6,  6]  1 */
     1545772, /* 60768 (1553) [ 0,  0,  1,  0, -1,  0,  1,  0,  0] [ 0,  6,  6]  1 */
    18426648, /* 60769 (1553) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
    34133522, /* 60770 (1553) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    52556810, /* 60771 (1553) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
        8872, /* 60772 (1553) [ 0,  0, -1, -1,  0,  0,  0,  1,  0] [ 0,  0,  0]  1 */
    17136480, /* 60773 (1553) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 6,  0,  6]  1 */
    18432160, /* 60774 (1553) [ 0,  0, -1, -1,  0,  0,  0,  1,  0] [ 6,  6,  0]  1 */
     1544296, /* 60775 (1553) [ 0,  0, -1,  0, -1,  0, -1,  0,  0] [ 0,  6,  6]  1 */
    51034656, /* 60776 (1553) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  0] -1 */
    35432760, /* 60777 (1553) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  0] -1 */
    51028834, /* 60778 (1553) [ 0,  0,  1,  0, -1,  0,  1,  0,  0] [ 6,  0,  0] -1 */
    35445884, /* 60779 (1553) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  0] -1 */
    52569988, /* 60780 (1553) [ 1,  0,  0,  0,  0, -1,  0,  1,  0] [ 6,  6,  6] -1 */
        3250, /* 60781 (1553) [-1,  0,  0,  0,  0, -1,  0, -1,  0] [ 0,  0,  0]  1 */
    18426598, /* 60782 (1553) [-1,  0,  0,  0,  0,  1,  0,  1,  0] [ 6,  6,  0]  1 */
        9202, /* 60783 (1553) [ 0,  0, -1,  0,  1,  0,  1,  0,  0] [ 0,  0,  0]  1 */
    34142592, /* 60784 (1553) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  6] -1 */
    35432710, /* 60785 (1553) [-1,  0,  0,  0,  0,  1,  0,  1,  0] [ 0,  6,  0] -1 */
    18433612, /* 60786 (1553) [ 0,  0,  1, -1,  0,  0,  0, -1,  0] [ 6,  6,  0]  1 */
    52562632, /* 60787 (1553) [ 0,  0, -1,  0, -1,  0, -1,  0,  0] [ 6,  6,  6] -1 */
    17133562, /* 60788 (1553) [ 0,  0, -1,  1,  0,  0,  0, -1,  0] [ 6,  0,  6]  1 */
     1542684, /* 60789 (1553) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 0,  6,  6]  1 */
    35441392, /* 60790 (1553) [ 0,  1,  0,  0,  0, -1, -1,  0,  0] [ 0,  6,  0] -1 */
    51025972, /* 60791 (1553) [ 0, -1,  0,  0,  0, -1,  1,  0,  0] [ 6,  0,  0] -1 */
    17131846, /* 60792 (1553) [ 0, -1,  0,  0,  0, -1,  1,  0,  0] [ 6,  0,  6]  1 */
    35441464, /* 60793 (1553) [ 0,  1,  0,  0,  0,  1,  1,  0,  0] [ 0,  6,  0] -1 */
    52561246, /* 60794 (1553) [ 0, -1,  0,  0,  0, -1,  1,  0,  0] [ 6,  6,  6] -1 */
       10324, /* 60795 (1553) [ 0,  0,  1, -1,  0,  0,  0, -1,  0] [ 0,  0,  0]  1 */
     1538634, /* 60796 (1553) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
    17134852, /* 60797 (1553) [ 0,  0,  1,  0,  1,  0, -1,  0,  0] [ 6,  0,  6]  1 */
    35440216, /* 60798 (1553) [ 0,  0,  1,  1,  0,  0,  0,  1,  0] [ 0,  6,  0] -1 */
     1544146, /* 60799 (1553) [ 0,  0, -1, -1,  0,  0,  0,  1,  0] [ 0,  6,  6]  1 */
    17135996, /* 60800 (1553) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 6,  0,  6]  1 */
    34139674, /* 60801 (1553) [ 0,  0, -1,  1,  0,  0,  0, -1,  0] [ 0,  0,  6] -1 */
    51027688, /* 60802 (1553) [ 0,  0, -1,  1,  0,  0,  0, -1,  0] [ 6,  0,  0] -1 */
    17140636, /* 60803 (1553) [ 1,  0,  0,  0,  0,  1,  0, -1,  0] [ 6,  0,  6]  1 */
    34137958, /* 60804 (1553) [ 0, -1,  0,  0,  0, -1,  1,  0,  0] [ 0,  0,  6] -1 */
    17134534, /* 60805 (1553) [ 0,  0,  1, -1,  0,  0,  0, -1,  0] [ 6,  0,  6]  1 */
    52564252, /* 60806 (1553) [ 0,  0,  1,  0,  1,  0, -1,  0,  0] [ 6,  6,  6] -1 */
    34140964, /* 60807 (1553) [ 0,  0,  1,  0,  1,  0, -1,  0,  0] [ 0,  0,  6] -1 */
    34142108, /* 60808 (1553) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    52565396, /* 60809 (1553) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    52562482, /* 60810 (1553) [ 0,  0, -1, -1,  0,  0,  0,  1,  0] [ 6,  6,  6] -1 */
    51030122, /* 60811 (1553) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 6,  0,  0] -1 */
    34146748, /* 60812 (1553) [ 1,  0,  0,  0,  0,  1,  0, -1,  0] [ 0,  0,  6] -1 */
    52570036, /* 60813 (1553) [ 1,  0,  0,  0,  0,  1,  0, -1,  0] [ 6,  6,  6] -1 */
    51034762, /* 60814 (1553) [ 1,  0,  0,  0,  0,  1,  0, -1,  0] [ 6,  0,  0] -1 */
    34146806, /* 60815 (1553) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    34133572, /* 60816 (1553) [-1,  0,  0,  0,  0, -1,  0, -1,  0] [ 0,  0,  6] -1 */
    18439772, /* 60817 (1553) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    17140530, /* 60818 (1553) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  6]  1 */
    51028660, /* 60819 (1553) [ 0,  0,  1, -1,  0,  0,  0, -1,  0] [ 6,  0,  0] -1 */
    17140588, /* 60820 (1553) [ 1,  0,  0,  0,  0, -1,  0,  1,  0] [ 6,  0,  6]  1 */
    18430960, /* 60821 (1553) [ 0, -1,  0,  0,  0,  1, -1,  0,  0] [ 6,  6,  0]  1 */
    18432490, /* 60822 (1553) [ 0,  0, -1,  0,  1,  0,  1,  0,  0] [ 6,  6,  0]  1 */
    17133232, /* 60823 (1553) [ 0,  0, -1,  0, -1,  0, -1,  0,  0] [ 6,  0,  6]  1 */
       11786, /* 60824 (1553) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34146642, /* 60825 (1553) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
    52569930, /* 60826 (1553) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    18435280, /* 60827 (1553) [ 0,  1,  0,  0,  0, -1, -1,  0,  0] [ 6,  6,  0]  1 */
        7898, /* 60828 (1553) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    18435352, /* 60829 (1553) [ 0,  1,  0,  0,  0,  1,  1,  0,  0] [ 6,  6,  0]  1 */
    35437072, /* 60830 (1553) [ 0, -1,  0,  0,  0,  1, -1,  0,  0] [ 0,  6,  0] -1 */
    34146700, /* 60831 (1553) [ 1,  0,  0,  0,  0, -1,  0,  1,  0] [ 0,  0,  6] -1 */
        3310, /* 60832 (1553) [-1,  0,  0,  0,  0,  1,  0,  1,  0] [ 0,  0,  0]  1 */
    52564108, /* 60833 (1553) [ 0,  0,  1,  0, -1,  0,  1,  0,  0] [ 6,  6,  6] -1 */
    34140820, /* 60834 (1553) [ 0,  0,  1,  0, -1,  0,  1,  0,  0] [ 0,  0,  6] -1 */
       10816, /* 60835 (1553) [ 0,  0,  1,  1,  0,  0,  0,  1,  0] [ 0,  0,  0]  1 */
    18434104, /* 60836 (1553) [ 0,  0,  1,  1,  0,  0,  0,  1,  0] [ 6,  6,  0]  1 */
    35437298, /* 60837 (1553) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 0,  6,  0] -1 */
    34139344, /* 60838 (1553) [ 0,  0, -1,  0, -1,  0, -1,  0,  0] [ 0,  0,  6] -1 */
       11992, /* 60839 (1553) [ 0,  1,  0,  0,  0, -1, -1,  0,  0] [ 0,  0,  0]  1 */
       12064, /* 60840 (1553) [ 0,  1,  0,  0,  0,  1,  1,  0,  0] [ 0,  0,  0]  1 */
    51025746, /* 60841 (1553) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 6,  0,  0] -1 */
     1551758, /* 60842 (1553) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
    52561020, /* 60843 (1553) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    17133412, /* 60844 (1553) [ 0,  0, -1,  0,  1,  0,  1,  0,  0] [ 6,  0,  6]  1 */
    17127570, /* 60845 (1553) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6]  1 */
     1547060, /* 60846 (1553) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 0,  6,  6]  1 */
     1542946, /* 60847 (1553) [ 0, -1,  0,  0,  0,  1, -1,  0,  0] [ 0,  6,  6]  1 */
    17133082, /* 60848 (1553) [ 0,  0, -1, -1,  0,  0,  0,  1,  0] [ 6,  0,  6]  1 */
       12270, /* 60849 (1553) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    35445778, /* 60850 (1553) [ 1,  0,  0,  0,  0, -1,  0,  1,  0] [ 0,  6,  0] -1 */
     1547266, /* 60851 (1553) [ 0,  1,  0,  0,  0, -1, -1,  0,  0] [ 0,  6,  6]  1 */
    35441670, /* 60852 (1553) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 0,  6,  0] -1 */
     1538584, /* 60853 (1553) [-1,  0,  0,  0,  0,  1,  0,  1,  0] [ 0,  6,  6]  1 */
    51021646, /* 60854 (1553) [-1,  0,  0,  0,  0,  1,  0,  1,  0] [ 6,  0,  0] -1 */
    17127460, /* 60855 (1553) [-1,  0,  0,  0,  0, -1,  0, -1,  0] [ 6,  0,  6]  1 */
    35438422, /* 60856 (1553) [ 0,  0, -1,  0, -1,  0, -1,  0,  0] [ 0,  6,  0] -1 */
     1546090, /* 60857 (1553) [ 0,  0,  1,  1,  0,  0,  0,  1,  0] [ 0,  6,  6]  1 */
    52556860, /* 60858 (1553) [-1,  0,  0,  0,  0, -1,  0, -1,  0] [ 6,  6,  6] -1 */
    51027538, /* 60859 (1553) [ 0,  0, -1,  0,  1,  0,  1,  0,  0] [ 6,  0,  0] -1 */
    35438752, /* 60860 (1553) [ 0,  0, -1,  1,  0,  0,  0, -1,  0] [ 0,  6,  0] -1 */
    34139194, /* 60861 (1553) [ 0,  0, -1, -1,  0,  0,  0,  1,  0] [ 0,  0,  6] -1 */
    51021586, /* 60862 (1553) [-1,  0,  0,  0,  0, -1,  0, -1,  0] [ 6,  0,  0] -1 */
    52562812, /* 60863 (1553) [ 0,  0, -1,  0,  1,  0,  1,  0,  0] [ 6,  6,  6] -1 */
    51030328, /* 60864 (1553) [ 0,  1,  0,  0,  0, -1, -1,  0,  0] [ 6,  0,  0] -1 */
    51027208, /* 60865 (1553) [ 0,  0, -1, -1,  0,  0,  0,  1,  0] [ 6,  0,  0] -1 */
    51030400, /* 60866 (1553) [ 0,  1,  0,  0,  0,  1,  1,  0,  0] [ 6,  0,  0] -1 */
    35437036, /* 60867 (1553) [ 0, -1,  0,  0,  0, -1,  1,  0,  0] [ 0,  6,  0] -1 */
    18431186, /* 60868 (1553) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    52563934, /* 60869 (1553) [ 0,  0,  1, -1,  0,  0,  0, -1,  0] [ 6,  6,  6] -1 */
    18433930, /* 60870 (1553) [ 0,  0,  1,  0,  1,  0, -1,  0,  0] [ 6,  6,  0]  1 */
    34140646, /* 60871 (1553) [ 0,  0,  1, -1,  0,  0,  0, -1,  0] [ 0,  0,  6] -1 */
        7672, /* 60872 (1553) [ 0, -1,  0,  0,  0,  1, -1,  0,  0] [ 0,  0,  0]  1 */
    35438602, /* 60873 (1553) [ 0,  0, -1,  0,  1,  0,  1,  0,  0] [ 0,  6,  0] -1 */
    35440042, /* 60874 (1553) [ 0,  0,  1,  0,  1,  0, -1,  0,  0] [ 0,  6,  0] -1 */
        3360, /* 60875 (1553) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    35441186, /* 60876 (1553) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 0,  6,  0] -1 */
    18426488, /* 60877 (1553) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    35445826, /* 60878 (1553) [ 1,  0,  0,  0,  0,  1,  0, -1,  0] [ 0,  6,  0] -1 */
    17131620, /* 60879 (1553) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 6,  0,  6]  1 */
    35432600, /* 60880 (1553) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  0] -1 */
    35439724, /* 60881 (1553) [ 0,  0,  1, -1,  0,  0,  0, -1,  0] [ 0,  6,  0] -1 */
    18435558, /* 60882 (1553) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 6,  6,  0]  1 */
    34137732, /* 60883 (1553) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  6] -1 */
    18439608, /* 60884 (1553) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
     1543172, /* 60885 (1553) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 0,  6,  6]  1 */
     1545916, /* 60886 (1553) [ 0,  0,  1,  0,  1,  0, -1,  0,  0] [ 0,  6,  6]  1 */
       16378, /* 60887 (1553) [ 1,  0,  0,  0,  0, -1,  0,  1,  0] [ 0,  0,  0]  1 */
    17127520, /* 60888 (1553) [-1,  0,  0,  0,  0,  1,  0,  1,  0] [ 6,  0,  6]  1 */
    35445720, /* 60889 (1553) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  0] -1 */
    52556970, /* 60890 (1553) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    17127410, /* 60891 (1553) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
    17131882, /* 60892 (1553) [ 0, -1,  0,  0,  0,  1, -1,  0,  0] [ 6,  0,  6]  1 */
    51021696, /* 60893 (1553) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  0] -1 */
    52570094, /* 60894 (1553) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    17136202, /* 60895 (1553) [ 0,  1,  0,  0,  0, -1, -1,  0,  0] [ 6,  0,  6]  1 */
     1547338, /* 60896 (1553) [ 0,  1,  0,  0,  0,  1,  1,  0,  0] [ 0,  6,  6]  1 */
    51026234, /* 60897 (1553) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 6,  0,  0] -1 */
    18432640, /* 60898 (1553) [ 0,  0, -1,  1,  0,  0,  0, -1,  0] [ 6,  6,  0]  1 */
    52561508, /* 60899 (1553) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    17135026, /* 60900 (1553) [ 0,  0,  1,  1,  0,  0,  0,  1,  0] [ 6,  0,  6]  1 */
    52556920, /* 60901 (1553) [-1,  0,  0,  0,  0,  1,  0,  1,  0] [ 6,  6,  6] -1 */
        7636, /* 60902 (1553) [ 0, -1,  0,  0,  0, -1,  1,  0,  0] [ 0,  0,  0]  1 */
    34133632, /* 60903 (1553) [-1,  0,  0,  0,  0,  1,  0,  1,  0] [ 0,  0,  6] -1 */
    18430924, /* 60904 (1553) [ 0, -1,  0,  0,  0, -1,  1,  0,  0] [ 6,  6,  0]  1 */
    34137994, /* 60905 (1553) [ 0, -1,  0,  0,  0,  1, -1,  0,  0] [ 0,  0,  6] -1 */
    52561282, /* 60906 (1553) [ 0, -1,  0,  0,  0,  1, -1,  0,  0] [ 6,  6,  6] -1 */
    34139524, /* 60907 (1553) [ 0,  0, -1,  0,  1,  0,  1,  0,  0] [ 0,  0,  6] -1 */
    35436810, /* 60908 (1553) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 0,  6,  0] -1 */
    34133682, /* 60909 (1553) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
    51021536, /* 60910 (1553) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  0] -1 */
    51026008, /* 60911 (1553) [ 0, -1,  0,  0,  0,  1, -1,  0,  0] [ 6,  0,  0] -1 */
    34142314, /* 60912 (1553) [ 0,  1,  0,  0,  0, -1, -1,  0,  0] [ 0,  0,  6] -1 */
    52565602, /* 60913 (1553) [ 0,  1,  0,  0,  0, -1, -1,  0,  0] [ 6,  6,  6] -1 */
     1547544, /* 60914 (1553) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 0,  6,  6]  1 */
    52565674, /* 60915 (1553) [ 0,  1,  0,  0,  0,  1,  1,  0,  0] [ 6,  6,  6] -1 */
    18435074, /* 60916 (1553) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    34142386, /* 60917 (1553) [ 0,  1,  0,  0,  0,  1,  1,  0,  0] [ 0,  0,  6] -1 */
     1551594, /* 60918 (1553) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
    18439714, /* 60919 (1553) [ 1,  0,  0,  0,  0,  1,  0, -1,  0] [ 6,  6,  0]  1 */
    34141138, /* 60920 (1553) [ 0,  0,  1,  1,  0,  0,  0,  1,  0] [ 0,  0,  6] -1 */
    52564426, /* 60921 (1553) [ 0,  0,  1,  1,  0,  0,  0,  1,  0] [ 6,  6,  6] -1 */
    51034714, /* 60922 (1553) [ 1,  0,  0,  0,  0, -1,  0,  1,  0] [ 6,  0,  0] -1 */
    35438272, /* 60923 (1553) [ 0,  0, -1, -1,  0,  0,  0,  1,  0] [ 0,  6,  0] -1 */
    51029152, /* 60924 (1553) [ 0,  0,  1,  1,  0,  0,  0,  1,  0] [ 6,  0,  0] -1 */
       10642, /* 60925 (1553) [ 0,  0,  1,  0,  1,  0, -1,  0,  0] [ 0,  0,  0]  1 */
    18426538, /* 60926 (1553) [-1,  0,  0,  0,  0, -1,  0, -1,  0] [ 6,  6,  0]  1 */
    51030606, /* 60927 (1553) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 6,  0,  0] -1 */
    51027358, /* 60928 (1553) [ 0,  0, -1,  0, -1,  0, -1,  0,  0] [ 6,  0,  0] -1 */
    52565880, /* 60929 (1553) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 6,  6,  6] -1 */
       16426, /* 60930 (1553) [ 1,  0,  0,  0,  0,  1,  0, -1,  0] [ 0,  0,  0]  1 */
    35432650, /* 60931 (1553) [-1,  0,  0,  0,  0, -1,  0, -1,  0] [ 0,  6,  0] -1 */
     1544626, /* 60932 (1553) [ 0,  0, -1,  1,  0,  0,  0, -1,  0] [ 0,  6,  6]  1 */
        3200, /* 60933 (1553) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
     1542910, /* 60934 (1553) [ 0, -1,  0,  0,  0, -1,  1,  0,  0] [ 0,  6,  6]  1 */
     1544476, /* 60935 (1553) [ 0,  0, -1,  0,  1,  0,  1,  0,  0] [ 0,  6,  6]  1 */
    18439666, /* 60936 (1553) [ 1,  0,  0,  0,  0, -1,  0,  1,  0] [ 6,  6,  0]  1 */
       10498, /* 60937 (1553) [ 0,  0,  1,  0, -1,  0,  1,  0,  0] [ 0,  0,  0]  1 */
    18433786, /* 60938 (1553) [ 0,  0,  1,  0, -1,  0,  1,  0,  0] [ 6,  6,  0]  1 */
       16484, /* 60939 (1554) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    26411281, /* 60940 (1554) [ 1,  0,  0,  0,  0, -1,  0,  1,  0] [ 9,  3,  9]  1 */
    26405401, /* 60941 (1554) [ 0,  0,  1,  0, -1,  0,  1,  0,  0] [ 9,  3,  9]  1 */
    17140694, /* 60942 (1554) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
       16320, /* 60943 (1554) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    26403925, /* 60944 (1554) [ 0,  0, -1,  0, -1,  0, -1,  0,  0] [ 9,  3,  9]  1 */
     1545598, /* 60945 (1554) [ 0,  0,  1, -1,  0,  0,  0, -1,  0] [ 0,  6,  6]  1 */
    27701879, /* 60946 (1554) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 9,  9,  3]  1 */
     1538474, /* 60947 (1554) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
    17136274, /* 60948 (1554) [ 0,  1,  0,  0,  0,  1,  1,  0,  0] [ 6,  0,  6]  1 */
        9352, /* 60949 (1554) [ 0,  0, -1,  1,  0,  0,  0, -1,  0] [ 0,  0,  0]  1 */
    26402313, /* 60950 (1554) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 9,  3,  9]  1 */
     9278591, /* 60951 (1554) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 3,  3,  3]  1 */
    18426648, /* 60952 (1554) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
        8872, /* 60953 (1554) [ 0,  0, -1, -1,  0,  0,  0,  1,  0] [ 0,  0,  0]  1 */
    18432160, /* 60954 (1554) [ 0,  0, -1, -1,  0,  0,  0,  1,  0] [ 6,  6,  0]  1 */
    26406689, /* 60955 (1554) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 9,  3,  9]  1 */
    10813865, /* 60956 (1554) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 3,  9,  9]  1 */
    26411329, /* 60957 (1554) [ 1,  0,  0,  0,  0,  1,  0, -1,  0] [ 9,  3,  9]  1 */
    26398213, /* 60958 (1554) [-1,  0,  0,  0,  0,  1,  0,  1,  0] [ 9,  3,  9]  1 */
     9274003, /* 60959 (1554) [-1,  0,  0,  0,  0,  1,  0,  1,  0] [ 3,  3,  3]  1 */
    18433612, /* 60960 (1554) [ 0,  0,  1, -1,  0,  0,  0, -1,  0] [ 6,  6,  0]  1 */
    17133562, /* 60961 (1554) [ 0,  0, -1,  1,  0,  0,  0, -1,  0] [ 6,  0,  6]  1 */
    17131846, /* 60962 (1554) [ 0, -1,  0,  0,  0, -1,  1,  0,  0] [ 6,  0,  6]  1 */
       10324, /* 60963 (1554) [ 0,  0,  1, -1,  0,  0,  0, -1,  0] [ 0,  0,  0]  1 */
     1538634, /* 60964 (1554) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
     1544146, /* 60965 (1554) [ 0,  0, -1, -1,  0,  0,  0,  1,  0] [ 0,  6,  6]  1 */
    17134534, /* 60966 (1554) [ 0,  0,  1, -1,  0,  0,  0, -1,  0] [ 6,  0,  6]  1 */
    18439772, /* 60967 (1554) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    17140530, /* 60968 (1554) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  6]  1 */
    27706251, /* 60969 (1554) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 9,  9,  3]  1 */
    27703003, /* 60970 (1554) [ 0,  0, -1,  0, -1,  0, -1,  0,  0] [ 9,  9,  3]  1 */
    10816609, /* 60971 (1554) [ 0,  0,  1,  0,  1,  0, -1,  0,  0] [ 3,  9,  9]  1 */
    18430960, /* 60972 (1554) [ 0, -1,  0,  0,  0,  1, -1,  0,  0] [ 6,  6,  0]  1 */
    18435280, /* 60973 (1554) [ 0,  1,  0,  0,  0, -1, -1,  0,  0] [ 6,  6,  0]  1 */
    26404105, /* 60974 (1554) [ 0,  0, -1,  0,  1,  0,  1,  0,  0] [ 9,  3,  9]  1 */
    18435352, /* 60975 (1554) [ 0,  1,  0,  0,  0,  1,  1,  0,  0] [ 6,  6,  0]  1 */
       10816, /* 60976 (1554) [ 0,  0,  1,  1,  0,  0,  0,  1,  0] [ 0,  0,  0]  1 */
    18434104, /* 60977 (1554) [ 0,  0,  1,  1,  0,  0,  0,  1,  0] [ 6,  6,  0]  1 */
       11992, /* 60978 (1554) [ 0,  1,  0,  0,  0, -1, -1,  0,  0] [ 0,  0,  0]  1 */
     9281191, /* 60979 (1554) [ 0,  0,  1,  0, -1,  0,  1,  0,  0] [ 3,  3,  3]  1 */
       12064, /* 60980 (1554) [ 0,  1,  0,  0,  0,  1,  1,  0,  0] [ 0,  0,  0]  1 */
    10822345, /* 60981 (1554) [ 1,  0,  0,  0,  0, -1,  0,  1,  0] [ 3,  9,  9]  1 */
     1551758, /* 60982 (1554) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
    10818237, /* 60983 (1554) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 3,  9,  9]  1 */
    10814989, /* 60984 (1554) [ 0,  0, -1,  0, -1,  0, -1,  0,  0] [ 3,  9,  9]  1 */
     9282963, /* 60985 (1554) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 3,  3,  3]  1 */
    17127570, /* 60986 (1554) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6]  1 */
     1542946, /* 60987 (1554) [ 0, -1,  0,  0,  0,  1, -1,  0,  0] [ 0,  6,  6]  1 */
    17133082, /* 60988 (1554) [ 0,  0, -1, -1,  0,  0,  0,  1,  0] [ 6,  0,  6]  1 */
     1547266, /* 60989 (1554) [ 0,  1,  0,  0,  0, -1, -1,  0,  0] [ 0,  6,  6]  1 */
    27704623, /* 60990 (1554) [ 0,  0,  1,  0,  1,  0, -1,  0,  0] [ 9,  9,  3]  1 */
     9278103, /* 60991 (1554) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 3,  3,  3]  1 */
     1546090, /* 60992 (1554) [ 0,  0,  1,  1,  0,  0,  0,  1,  0] [ 0,  6,  6]  1 */
    27704479, /* 60993 (1554) [ 0,  0,  1,  0, -1,  0,  1,  0,  0] [ 9,  9,  3]  1 */
     9282479, /* 60994 (1554) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 3,  3,  3]  1 */
    26402801, /* 60995 (1554) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 9,  3,  9]  1 */
    26405545, /* 60996 (1554) [ 0,  0,  1,  0,  1,  0, -1,  0,  0] [ 9,  3,  9]  1 */
        7672, /* 60997 (1554) [ 0, -1,  0,  0,  0,  1, -1,  0,  0] [ 0,  0,  0]  1 */
     9281335, /* 60998 (1554) [ 0,  0,  1,  0,  1,  0, -1,  0,  0] [ 3,  3,  3]  1 */
        3360, /* 60999 (1554) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    18426488, /* 61000 (1554) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    27701391, /* 61001 (1554) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 9,  9,  3]  1 */
    10816465, /* 61002 (1554) [ 0,  0,  1,  0, -1,  0,  1,  0,  0] [ 3,  9,  9]  1 */
     9287071, /* 61003 (1554) [ 1,  0,  0,  0,  0, -1,  0,  1,  0] [ 3,  3,  3]  1 */
    18439608, /* 61004 (1554) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
    26407173, /* 61005 (1554) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 9,  3,  9]  1 */
     9279715, /* 61006 (1554) [ 0,  0, -1,  0, -1,  0, -1,  0,  0] [ 3,  3,  3]  1 */
    27705767, /* 61007 (1554) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 9,  9,  3]  1 */
    17127410, /* 61008 (1554) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
    17131882, /* 61009 (1554) [ 0, -1,  0,  0,  0,  1, -1,  0,  0] [ 6,  0,  6]  1 */
    27710407, /* 61010 (1554) [ 1,  0,  0,  0,  0,  1,  0, -1,  0] [ 9,  9,  3]  1 */
    27697291, /* 61011 (1554) [-1,  0,  0,  0,  0,  1,  0,  1,  0] [ 9,  9,  3]  1 */
    17136202, /* 61012 (1554) [ 0,  1,  0,  0,  0, -1, -1,  0,  0] [ 6,  0,  6]  1 */
     1547338, /* 61013 (1554) [ 0,  1,  0,  0,  0,  1,  1,  0,  0] [ 0,  6,  6]  1 */
    27703183, /* 61014 (1554) [ 0,  0, -1,  0,  1,  0,  1,  0,  0] [ 9,  9,  3]  1 */
    18432640, /* 61015 (1554) [ 0,  0, -1,  1,  0,  0,  0, -1,  0] [ 6,  6,  0]  1 */
    27697231, /* 61016 (1554) [-1,  0,  0,  0,  0, -1,  0, -1,  0] [ 9,  9,  3]  1 */
    17135026, /* 61017 (1554) [ 0,  0,  1,  1,  0,  0,  0,  1,  0] [ 6,  0,  6]  1 */
    10813377, /* 61018 (1554) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 3,  9,  9]  1 */
        7636, /* 61019 (1554) [ 0, -1,  0,  0,  0, -1,  1,  0,  0] [ 0,  0,  0]  1 */
    18430924, /* 61020 (1554) [ 0, -1,  0,  0,  0, -1,  1,  0,  0] [ 6,  6,  0]  1 */
     9279895, /* 61021 (1554) [ 0,  0, -1,  0,  1,  0,  1,  0,  0] [ 3,  3,  3]  1 */
     1551594, /* 61022 (1554) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
    27710359, /* 61023 (1554) [ 1,  0,  0,  0,  0, -1,  0,  1,  0] [ 9,  9,  3]  1 */
    10817753, /* 61024 (1554) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 3,  9,  9]  1 */
     9287119, /* 61025 (1554) [ 1,  0,  0,  0,  0,  1,  0, -1,  0] [ 3,  3,  3]  1 */
    10822393, /* 61026 (1554) [ 1,  0,  0,  0,  0,  1,  0, -1,  0] [ 3,  9,  9]  1 */
    10809277, /* 61027 (1554) [-1,  0,  0,  0,  0,  1,  0,  1,  0] [ 3,  9,  9]  1 */
    26398153, /* 61028 (1554) [-1,  0,  0,  0,  0, -1,  0, -1,  0] [ 9,  3,  9]  1 */
     9273943, /* 61029 (1554) [-1,  0,  0,  0,  0, -1,  0, -1,  0] [ 3,  3,  3]  1 */
    10815169, /* 61030 (1554) [ 0,  0, -1,  0,  1,  0,  1,  0,  0] [ 3,  9,  9]  1 */
     1544626, /* 61031 (1554) [ 0,  0, -1,  1,  0,  0,  0, -1,  0] [ 0,  6,  6]  1 */
    10809217, /* 61032 (1554) [-1,  0,  0,  0,  0, -1,  0, -1,  0] [ 3,  9,  9]  1 */
        3200, /* 61033 (1554) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
     1542910, /* 61034 (1554) [ 0, -1,  0,  0,  0, -1,  1,  0,  0] [ 0,  6,  6]  1 */
       16484, /* 61035 (1555) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    26411281, /* 61036 (1555) [ 1,  0,  0,  0,  0, -1,  0,  1,  0] [ 9,  3,  9]  1 */
    26405401, /* 61037 (1555) [ 0,  0,  1,  0, -1,  0,  1,  0,  0] [ 9,  3,  9]  1 */
    17140694, /* 61038 (1555) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
       16320, /* 61039 (1555) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    61716703, /* 61040 (1555) [ 0,  0,  1,  0, -1,  0,  1,  0,  0] [ 9,  9,  3] -1 */
    52451996, /* 61041 (1555) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
    26403925, /* 61042 (1555) [ 0,  0, -1,  0, -1,  0, -1,  0,  0] [ 9,  3,  9]  1 */
     1545598, /* 61043 (1555) [ 0,  0,  1, -1,  0,  0,  0, -1,  0] [ 0,  6,  6]  1 */
    51152754, /* 61044 (1555) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  6] -1 */
    27701879, /* 61045 (1555) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 9,  9,  3]  1 */
    61715227, /* 61046 (1555) [ 0,  0, -1,  0, -1,  0, -1,  0,  0] [ 9,  9,  3] -1 */
    44828833, /* 61047 (1555) [ 0,  0,  1,  0,  1,  0, -1,  0,  0] [ 3,  9,  9] -1 */
    60415025, /* 61048 (1555) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 9,  3,  9] -1 */
     1538474, /* 61049 (1555) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
    34019896, /* 61050 (1555) [ 0, -1,  0,  0,  0,  1, -1,  0,  0] [ 0,  0,  0] -1 */
    43293559, /* 61051 (1555) [ 0,  0,  1,  0,  1,  0, -1,  0,  0] [ 3,  3,  3] -1 */
    17136274, /* 61052 (1555) [ 0,  1,  0,  0,  0,  1,  1,  0,  0] [ 6,  0,  6]  1 */
    52443184, /* 61053 (1555) [ 0, -1,  0,  0,  0,  1, -1,  0,  0] [ 6,  6,  0] -1 */
    34015584, /* 61054 (1555) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    52447576, /* 61055 (1555) [ 0,  1,  0,  0,  0,  1,  1,  0,  0] [ 6,  6,  0] -1 */
        9352, /* 61056 (1555) [ 0,  0, -1,  1,  0,  0,  0, -1,  0] [ 0,  0,  0]  1 */
    26402313, /* 61057 (1555) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 9,  3,  9]  1 */
     9278591, /* 61058 (1555) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 3,  3,  3]  1 */
    34023040, /* 61059 (1555) [ 0,  0,  1,  1,  0,  0,  0,  1,  0] [ 0,  0,  0] -1 */
    52446328, /* 61060 (1555) [ 0,  0,  1,  1,  0,  0,  0,  1,  0] [ 6,  6,  0] -1 */
    18426648, /* 61061 (1555) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
    61713615, /* 61062 (1555) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 9,  9,  3] -1 */
        8872, /* 61063 (1555) [ 0,  0, -1, -1,  0,  0,  0,  1,  0] [ 0,  0,  0]  1 */
    18432160, /* 61064 (1555) [ 0,  0, -1, -1,  0,  0,  0,  1,  0] [ 6,  6,  0]  1 */
    43293415, /* 61065 (1555) [ 0,  0,  1,  0, -1,  0,  1,  0,  0] [ 3,  3,  3] -1 */
    34024288, /* 61066 (1555) [ 0,  1,  0,  0,  0,  1,  1,  0,  0] [ 0,  0,  0] -1 */
    44834569, /* 61067 (1555) [ 1,  0,  0,  0,  0, -1,  0,  1,  0] [ 3,  9,  9] -1 */
    44828689, /* 61068 (1555) [ 0,  0,  1,  0, -1,  0,  1,  0,  0] [ 3,  9,  9] -1 */
    35563982, /* 61069 (1555) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
    26406689, /* 61070 (1555) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 9,  3,  9]  1 */
    60419397, /* 61071 (1555) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 9,  3,  9] -1 */
    10813865, /* 61072 (1555) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 3,  9,  9]  1 */
    44827213, /* 61073 (1555) [ 0,  0, -1,  0, -1,  0, -1,  0,  0] [ 3,  9,  9] -1 */
    43295187, /* 61074 (1555) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 3,  3,  3] -1 */
    26411329, /* 61075 (1555) [ 1,  0,  0,  0,  0,  1,  0, -1,  0] [ 9,  3,  9]  1 */
    43291939, /* 61076 (1555) [ 0,  0, -1,  0, -1,  0, -1,  0,  0] [ 3,  3,  3] -1 */
    26398213, /* 61077 (1555) [-1,  0,  0,  0,  0,  1,  0,  1,  0] [ 9,  3,  9]  1 */
    61717991, /* 61078 (1555) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 9,  9,  3] -1 */
    51139794, /* 61079 (1555) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6] -1 */
     9274003, /* 61080 (1555) [-1,  0,  0,  0,  0,  1,  0,  1,  0] [ 3,  3,  3]  1 */
    35555170, /* 61081 (1555) [ 0, -1,  0,  0,  0,  1, -1,  0,  0] [ 0,  6,  6] -1 */
    18433612, /* 61082 (1555) [ 0,  0,  1, -1,  0,  0,  0, -1,  0] [ 6,  6,  0]  1 */
    17133562, /* 61083 (1555) [ 0,  0, -1,  1,  0,  0,  0, -1,  0] [ 6,  0,  6]  1 */
    35559490, /* 61084 (1555) [ 0,  1,  0,  0,  0, -1, -1,  0,  0] [ 0,  6,  6] -1 */
    35559562, /* 61085 (1555) [ 0,  1,  0,  0,  0,  1,  1,  0,  0] [ 0,  6,  6] -1 */
    61715407, /* 61086 (1555) [ 0,  0, -1,  0,  1,  0,  1,  0,  0] [ 9,  9,  3] -1 */
    52444864, /* 61087 (1555) [ 0,  0, -1,  1,  0,  0,  0, -1,  0] [ 6,  6,  0] -1 */
    17131846, /* 61088 (1555) [ 0, -1,  0,  0,  0, -1,  1,  0,  0] [ 6,  0,  6]  1 */
    61716847, /* 61089 (1555) [ 0,  0,  1,  0,  1,  0, -1,  0,  0] [ 9,  9,  3] -1 */
    43290327, /* 61090 (1555) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 3,  3,  3] -1 */
    35558314, /* 61091 (1555) [ 0,  0,  1,  1,  0,  0,  0,  1,  0] [ 0,  6,  6] -1 */
       10324, /* 61092 (1555) [ 0,  0,  1, -1,  0,  0,  0, -1,  0] [ 0,  0,  0]  1 */
     1538634, /* 61093 (1555) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
    44825601, /* 61094 (1555) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 3,  9,  9] -1 */
    52443148, /* 61095 (1555) [ 0, -1,  0,  0,  0, -1,  1,  0,  0] [ 6,  6,  0] -1 */
     1544146, /* 61096 (1555) [ 0,  0, -1, -1,  0,  0,  0,  1,  0] [ 0,  6,  6]  1 */
    43292119, /* 61097 (1555) [ 0,  0, -1,  0,  1,  0,  1,  0,  0] [ 3,  3,  3] -1 */
    43294703, /* 61098 (1555) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 3,  3,  3] -1 */
    17134534, /* 61099 (1555) [ 0,  0,  1, -1,  0,  0,  0, -1,  0] [ 6,  0,  6]  1 */
    61722583, /* 61100 (1555) [ 1,  0,  0,  0,  0, -1,  0,  1,  0] [ 9,  9,  3] -1 */
    43299343, /* 61101 (1555) [ 1,  0,  0,  0,  0,  1,  0, -1,  0] [ 3,  3,  3] -1 */
    60417769, /* 61102 (1555) [ 0,  0,  1,  0,  1,  0, -1,  0,  0] [ 9,  3,  9] -1 */
    43286167, /* 61103 (1555) [-1,  0,  0,  0,  0, -1,  0, -1,  0] [ 3,  3,  3] -1 */
    44827393, /* 61104 (1555) [ 0,  0, -1,  0,  1,  0,  1,  0,  0] [ 3,  9,  9] -1 */
    35556850, /* 61105 (1555) [ 0,  0, -1,  1,  0,  0,  0, -1,  0] [ 0,  6,  6] -1 */
    18439772, /* 61106 (1555) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    34015424, /* 61107 (1555) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    34028708, /* 61108 (1555) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    17140530, /* 61109 (1555) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  6]  1 */
    52438712, /* 61110 (1555) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
    27706251, /* 61111 (1555) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 9,  9,  3]  1 */
    27703003, /* 61112 (1555) [ 0,  0, -1,  0, -1,  0, -1,  0,  0] [ 9,  9,  3]  1 */
    10816609, /* 61113 (1555) [ 0,  0,  1,  0,  1,  0, -1,  0,  0] [ 3,  9,  9]  1 */
    18430960, /* 61114 (1555) [ 0, -1,  0,  0,  0,  1, -1,  0,  0] [ 6,  6,  0]  1 */
    60423505, /* 61115 (1555) [ 1,  0,  0,  0,  0, -1,  0,  1,  0] [ 9,  3,  9] -1 */
    43299295, /* 61116 (1555) [ 1,  0,  0,  0,  0, -1,  0,  1,  0] [ 3,  3,  3] -1 */
    18435280, /* 61117 (1555) [ 0,  1,  0,  0,  0, -1, -1,  0,  0] [ 6,  6,  0]  1 */
    51152918, /* 61118 (1555) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
    26404105, /* 61119 (1555) [ 0,  0, -1,  0,  1,  0,  1,  0,  0] [ 9,  3,  9]  1 */
    18435352, /* 61120 (1555) [ 0,  1,  0,  0,  0,  1,  1,  0,  0] [ 6,  6,  0]  1 */
    34028544, /* 61121 (1555) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    52451832, /* 61122 (1555) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
       10816, /* 61123 (1555) [ 0,  0,  1,  1,  0,  0,  0,  1,  0] [ 0,  0,  0]  1 */
    18434104, /* 61124 (1555) [ 0,  0,  1,  1,  0,  0,  0,  1,  0] [ 6,  6,  0]  1 */
    60416149, /* 61125 (1555) [ 0,  0, -1,  0, -1,  0, -1,  0,  0] [ 9,  3,  9] -1 */
    61714103, /* 61126 (1555) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 9,  9,  3] -1 */
     9281191, /* 61127 (1555) [ 0,  0,  1,  0, -1,  0,  1,  0,  0] [ 3,  3,  3]  1 */
       11992, /* 61128 (1555) [ 0,  1,  0,  0,  0, -1, -1,  0,  0] [ 0,  0,  0]  1 */
       12064, /* 61129 (1555) [ 0,  1,  0,  0,  0,  1,  1,  0,  0] [ 0,  0,  0]  1 */
    51139634, /* 61130 (1555) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
    10822345, /* 61131 (1555) [ 1,  0,  0,  0,  0, -1,  0,  1,  0] [ 3,  9,  9]  1 */
    61709515, /* 61132 (1555) [-1,  0,  0,  0,  0,  1,  0,  1,  0] [ 9,  9,  3] -1 */
    51144106, /* 61133 (1555) [ 0, -1,  0,  0,  0,  1, -1,  0,  0] [ 6,  0,  6] -1 */
     1551758, /* 61134 (1555) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
    35550698, /* 61135 (1555) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
    51148426, /* 61136 (1555) [ 0,  1,  0,  0,  0, -1, -1,  0,  0] [ 6,  0,  6] -1 */
    61722631, /* 61137 (1555) [ 1,  0,  0,  0,  0,  1,  0, -1,  0] [ 9,  9,  3] -1 */
    51148498, /* 61138 (1555) [ 0,  1,  0,  0,  0,  1,  1,  0,  0] [ 6,  0,  6] -1 */
    10818237, /* 61139 (1555) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 3,  9,  9]  1 */
    61709455, /* 61140 (1555) [-1,  0,  0,  0,  0, -1,  0, -1,  0] [ 9,  9,  3] -1 */
    10814989, /* 61141 (1555) [ 0,  0, -1,  0, -1,  0, -1,  0,  0] [ 3,  9,  9]  1 */
     9282963, /* 61142 (1555) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 3,  3,  3]  1 */
    51147250, /* 61143 (1555) [ 0,  0,  1,  1,  0,  0,  0,  1,  0] [ 6,  0,  6] -1 */
    34019860, /* 61144 (1555) [ 0, -1,  0,  0,  0, -1,  1,  0,  0] [ 0,  0,  0] -1 */
    17127570, /* 61145 (1555) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6]  1 */
    60414537, /* 61146 (1555) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 9,  3,  9] -1 */
     1542946, /* 61147 (1555) [ 0, -1,  0,  0,  0,  1, -1,  0,  0] [ 0,  6,  6]  1 */
    17133082, /* 61148 (1555) [ 0,  0, -1, -1,  0,  0,  0,  1,  0] [ 6,  0,  6]  1 */
    43290815, /* 61149 (1555) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 3,  3,  3] -1 */
     1547266, /* 61150 (1555) [ 0,  1,  0,  0,  0, -1, -1,  0,  0] [ 0,  6,  6]  1 */
    52444384, /* 61151 (1555) [ 0,  0, -1, -1,  0,  0,  0,  1,  0] [ 6,  6,  0] -1 */
    35563818, /* 61152 (1555) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  6] -1 */
    27704623, /* 61153 (1555) [ 0,  0,  1,  0,  1,  0, -1,  0,  0] [ 9,  9,  3]  1 */
     9278103, /* 61154 (1555) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 3,  3,  3]  1 */
     1546090, /* 61155 (1555) [ 0,  0,  1,  1,  0,  0,  0,  1,  0] [ 0,  6,  6]  1 */
    44829977, /* 61156 (1555) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 3,  9,  9] -1 */
    44826089, /* 61157 (1555) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 3,  9,  9] -1 */
    44834617, /* 61158 (1555) [ 1,  0,  0,  0,  0,  1,  0, -1,  0] [ 3,  9,  9] -1 */
    44821501, /* 61159 (1555) [-1,  0,  0,  0,  0,  1,  0,  1,  0] [ 3,  9,  9] -1 */
    60410377, /* 61160 (1555) [-1,  0,  0,  0,  0, -1,  0, -1,  0] [ 9,  3,  9] -1 */
    43286227, /* 61161 (1555) [-1,  0,  0,  0,  0,  1,  0,  1,  0] [ 3,  3,  3] -1 */
    44821441, /* 61162 (1555) [-1,  0,  0,  0,  0, -1,  0, -1,  0] [ 3,  9,  9] -1 */
    27704479, /* 61163 (1555) [ 0,  0,  1,  0, -1,  0,  1,  0,  0] [ 9,  9,  3]  1 */
     9282479, /* 61164 (1555) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 3,  3,  3]  1 */
    35555134, /* 61165 (1555) [ 0, -1,  0,  0,  0, -1,  1,  0,  0] [ 0,  6,  6] -1 */
    34022548, /* 61166 (1555) [ 0,  0,  1, -1,  0,  0,  0, -1,  0] [ 0,  0,  0] -1 */
    26402801, /* 61167 (1555) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 9,  3,  9]  1 */
    26405545, /* 61168 (1555) [ 0,  0,  1,  0,  1,  0, -1,  0,  0] [ 9,  3,  9]  1 */
        7672, /* 61169 (1555) [ 0, -1,  0,  0,  0,  1, -1,  0,  0] [ 0,  0,  0]  1 */
     9281335, /* 61170 (1555) [ 0,  0,  1,  0,  1,  0, -1,  0,  0] [ 3,  3,  3]  1 */
    35556370, /* 61171 (1555) [ 0,  0, -1, -1,  0,  0,  0,  1,  0] [ 0,  6,  6] -1 */
        3360, /* 61172 (1555) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    60417625, /* 61173 (1555) [ 0,  0,  1,  0, -1,  0,  1,  0,  0] [ 9,  3,  9] -1 */
    18426488, /* 61174 (1555) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    35557822, /* 61175 (1555) [ 0,  0,  1, -1,  0,  0,  0, -1,  0] [ 0,  6,  6] -1 */
    27701391, /* 61176 (1555) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 9,  9,  3]  1 */
    10816465, /* 61177 (1555) [ 0,  0,  1,  0, -1,  0,  1,  0,  0] [ 3,  9,  9]  1 */
     9287071, /* 61178 (1555) [ 1,  0,  0,  0,  0, -1,  0,  1,  0] [ 3,  3,  3]  1 */
    18439608, /* 61179 (1555) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
    26407173, /* 61180 (1555) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 9,  3,  9]  1 */
    34021576, /* 61181 (1555) [ 0,  0, -1,  1,  0,  0,  0, -1,  0] [ 0,  0,  0] -1 */
     9279715, /* 61182 (1555) [ 0,  0, -1,  0, -1,  0, -1,  0,  0] [ 3,  3,  3]  1 */
    27705767, /* 61183 (1555) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 9,  9,  3]  1 */
    61718475, /* 61184 (1555) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 9,  9,  3] -1 */
    17127410, /* 61185 (1555) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
    17131882, /* 61186 (1555) [ 0, -1,  0,  0,  0,  1, -1,  0,  0] [ 6,  0,  6]  1 */
    27710407, /* 61187 (1555) [ 1,  0,  0,  0,  0,  1,  0, -1,  0] [ 9,  9,  3]  1 */
    52438872, /* 61188 (1555) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
    27697291, /* 61189 (1555) [-1,  0,  0,  0,  0,  1,  0,  1,  0] [ 9,  9,  3]  1 */
    17136202, /* 61190 (1555) [ 0,  1,  0,  0,  0, -1, -1,  0,  0] [ 6,  0,  6]  1 */
     1547338, /* 61191 (1555) [ 0,  1,  0,  0,  0,  1,  1,  0,  0] [ 0,  6,  6]  1 */
    34021096, /* 61192 (1555) [ 0,  0, -1, -1,  0,  0,  0,  1,  0] [ 0,  0,  0] -1 */
    27703183, /* 61193 (1555) [ 0,  0, -1,  0,  1,  0,  1,  0,  0] [ 9,  9,  3]  1 */
    18432640, /* 61194 (1555) [ 0,  0, -1,  1,  0,  0,  0, -1,  0] [ 6,  6,  0]  1 */
    27697231, /* 61195 (1555) [-1,  0,  0,  0,  0, -1,  0, -1,  0] [ 9,  9,  3]  1 */
    52447504, /* 61196 (1555) [ 0,  1,  0,  0,  0, -1, -1,  0,  0] [ 6,  6,  0] -1 */
    60416329, /* 61197 (1555) [ 0,  0, -1,  0,  1,  0,  1,  0,  0] [ 9,  3,  9] -1 */
    17135026, /* 61198 (1555) [ 0,  0,  1,  1,  0,  0,  0,  1,  0] [ 6,  0,  6]  1 */
    10813377, /* 61199 (1555) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 3,  9,  9]  1 */
        7636, /* 61200 (1555) [ 0, -1,  0,  0,  0, -1,  1,  0,  0] [ 0,  0,  0]  1 */
    18430924, /* 61201 (1555) [ 0, -1,  0,  0,  0, -1,  1,  0,  0] [ 6,  6,  0]  1 */
    60418913, /* 61202 (1555) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 9,  3,  9] -1 */
    60423553, /* 61203 (1555) [ 1,  0,  0,  0,  0,  1,  0, -1,  0] [ 9,  3,  9] -1 */
    60410437, /* 61204 (1555) [-1,  0,  0,  0,  0,  1,  0,  1,  0] [ 9,  3,  9] -1 */
    52445836, /* 61205 (1555) [ 0,  0,  1, -1,  0,  0,  0, -1,  0] [ 6,  6,  0] -1 */
    34024216, /* 61206 (1555) [ 0,  1,  0,  0,  0, -1, -1,  0,  0] [ 0,  0,  0] -1 */
     9279895, /* 61207 (1555) [ 0,  0, -1,  0,  1,  0,  1,  0,  0] [ 3,  3,  3]  1 */
     1551594, /* 61208 (1555) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
    51145786, /* 61209 (1555) [ 0,  0, -1,  1,  0,  0,  0, -1,  0] [ 6,  0,  6] -1 */
    27710359, /* 61210 (1555) [ 1,  0,  0,  0,  0, -1,  0,  1,  0] [ 9,  9,  3]  1 */
    10817753, /* 61211 (1555) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 3,  9,  9]  1 */
    44830461, /* 61212 (1555) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 3,  9,  9] -1 */
     9287119, /* 61213 (1555) [ 1,  0,  0,  0,  0,  1,  0, -1,  0] [ 3,  3,  3]  1 */
    51144070, /* 61214 (1555) [ 0, -1,  0,  0,  0, -1,  1,  0,  0] [ 6,  0,  6] -1 */
    10822393, /* 61215 (1555) [ 1,  0,  0,  0,  0,  1,  0, -1,  0] [ 3,  9,  9]  1 */
    35550858, /* 61216 (1555) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6] -1 */
    10809277, /* 61217 (1555) [-1,  0,  0,  0,  0,  1,  0,  1,  0] [ 3,  9,  9]  1 */
    26398153, /* 61218 (1555) [-1,  0,  0,  0,  0, -1,  0, -1,  0] [ 9,  3,  9]  1 */
     9273943, /* 61219 (1555) [-1,  0,  0,  0,  0, -1,  0, -1,  0] [ 3,  3,  3]  1 */
    51145306, /* 61220 (1555) [ 0,  0, -1, -1,  0,  0,  0,  1,  0] [ 6,  0,  6] -1 */
    10815169, /* 61221 (1555) [ 0,  0, -1,  0,  1,  0,  1,  0,  0] [ 3,  9,  9]  1 */
     1544626, /* 61222 (1555) [ 0,  0, -1,  1,  0,  0,  0, -1,  0] [ 0,  6,  6]  1 */
    10809217, /* 61223 (1555) [-1,  0,  0,  0,  0, -1,  0, -1,  0] [ 3,  9,  9]  1 */
        3200, /* 61224 (1555) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
     1542910, /* 61225 (1555) [ 0, -1,  0,  0,  0, -1,  1,  0,  0] [ 0,  6,  6]  1 */
    51146758, /* 61226 (1555) [ 0,  0,  1, -1,  0,  0,  0, -1,  0] [ 6,  0,  6] -1 */
       16484, /* 61227 (1556) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    17140694, /* 61228 (1556) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
       16320, /* 61229 (1556) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    61716703, /* 61230 (1556) [ 0,  0,  1,  0, -1,  0,  1,  0,  0] [ 9,  9,  3] -1 */
     1545598, /* 61231 (1556) [ 0,  0,  1, -1,  0,  0,  0, -1,  0] [ 0,  6,  6]  1 */
    61715227, /* 61232 (1556) [ 0,  0, -1,  0, -1,  0, -1,  0,  0] [ 9,  9,  3] -1 */
    44828833, /* 61233 (1556) [ 0,  0,  1,  0,  1,  0, -1,  0,  0] [ 3,  9,  9] -1 */
    60415025, /* 61234 (1556) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 9,  3,  9] -1 */
     1538474, /* 61235 (1556) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
    43293559, /* 61236 (1556) [ 0,  0,  1,  0,  1,  0, -1,  0,  0] [ 3,  3,  3] -1 */
    17136274, /* 61237 (1556) [ 0,  1,  0,  0,  0,  1,  1,  0,  0] [ 6,  0,  6]  1 */
        9352, /* 61238 (1556) [ 0,  0, -1,  1,  0,  0,  0, -1,  0] [ 0,  0,  0]  1 */
    18426648, /* 61239 (1556) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
    61713615, /* 61240 (1556) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 9,  9,  3] -1 */
        8872, /* 61241 (1556) [ 0,  0, -1, -1,  0,  0,  0,  1,  0] [ 0,  0,  0]  1 */
    18432160, /* 61242 (1556) [ 0,  0, -1, -1,  0,  0,  0,  1,  0] [ 6,  6,  0]  1 */
    43293415, /* 61243 (1556) [ 0,  0,  1,  0, -1,  0,  1,  0,  0] [ 3,  3,  3] -1 */
    44834569, /* 61244 (1556) [ 1,  0,  0,  0,  0, -1,  0,  1,  0] [ 3,  9,  9] -1 */
    44828689, /* 61245 (1556) [ 0,  0,  1,  0, -1,  0,  1,  0,  0] [ 3,  9,  9] -1 */
    60419397, /* 61246 (1556) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 9,  3,  9] -1 */
    44827213, /* 61247 (1556) [ 0,  0, -1,  0, -1,  0, -1,  0,  0] [ 3,  9,  9] -1 */
    43295187, /* 61248 (1556) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 3,  3,  3] -1 */
    43291939, /* 61249 (1556) [ 0,  0, -1,  0, -1,  0, -1,  0,  0] [ 3,  3,  3] -1 */
    61717991, /* 61250 (1556) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 9,  9,  3] -1 */
    18433612, /* 61251 (1556) [ 0,  0,  1, -1,  0,  0,  0, -1,  0] [ 6,  6,  0]  1 */
    17133562, /* 61252 (1556) [ 0,  0, -1,  1,  0,  0,  0, -1,  0] [ 6,  0,  6]  1 */
    61715407, /* 61253 (1556) [ 0,  0, -1,  0,  1,  0,  1,  0,  0] [ 9,  9,  3] -1 */
    61716847, /* 61254 (1556) [ 0,  0,  1,  0,  1,  0, -1,  0,  0] [ 9,  9,  3] -1 */
    17131846, /* 61255 (1556) [ 0, -1,  0,  0,  0, -1,  1,  0,  0] [ 6,  0,  6]  1 */
    43290327, /* 61256 (1556) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 3,  3,  3] -1 */
       10324, /* 61257 (1556) [ 0,  0,  1, -1,  0,  0,  0, -1,  0] [ 0,  0,  0]  1 */
     1538634, /* 61258 (1556) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
    44825601, /* 61259 (1556) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 3,  9,  9] -1 */
     1544146, /* 61260 (1556) [ 0,  0, -1, -1,  0,  0,  0,  1,  0] [ 0,  6,  6]  1 */
    43292119, /* 61261 (1556) [ 0,  0, -1,  0,  1,  0,  1,  0,  0] [ 3,  3,  3] -1 */
    43294703, /* 61262 (1556) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 3,  3,  3] -1 */
    17134534, /* 61263 (1556) [ 0,  0,  1, -1,  0,  0,  0, -1,  0] [ 6,  0,  6]  1 */
    61722583, /* 61264 (1556) [ 1,  0,  0,  0,  0, -1,  0,  1,  0] [ 9,  9,  3] -1 */
    43299343, /* 61265 (1556) [ 1,  0,  0,  0,  0,  1,  0, -1,  0] [ 3,  3,  3] -1 */
    60417769, /* 61266 (1556) [ 0,  0,  1,  0,  1,  0, -1,  0,  0] [ 9,  3,  9] -1 */
    43286167, /* 61267 (1556) [-1,  0,  0,  0,  0, -1,  0, -1,  0] [ 3,  3,  3] -1 */
    44827393, /* 61268 (1556) [ 0,  0, -1,  0,  1,  0,  1,  0,  0] [ 3,  9,  9] -1 */
    18439772, /* 61269 (1556) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    17140530, /* 61270 (1556) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  6]  1 */
    18430960, /* 61271 (1556) [ 0, -1,  0,  0,  0,  1, -1,  0,  0] [ 6,  6,  0]  1 */
    60423505, /* 61272 (1556) [ 1,  0,  0,  0,  0, -1,  0,  1,  0] [ 9,  3,  9] -1 */
    43299295, /* 61273 (1556) [ 1,  0,  0,  0,  0, -1,  0,  1,  0] [ 3,  3,  3] -1 */
    18435280, /* 61274 (1556) [ 0,  1,  0,  0,  0, -1, -1,  0,  0] [ 6,  6,  0]  1 */
    18435352, /* 61275 (1556) [ 0,  1,  0,  0,  0,  1,  1,  0,  0] [ 6,  6,  0]  1 */
       10816, /* 61276 (1556) [ 0,  0,  1,  1,  0,  0,  0,  1,  0] [ 0,  0,  0]  1 */
    18434104, /* 61277 (1556) [ 0,  0,  1,  1,  0,  0,  0,  1,  0] [ 6,  6,  0]  1 */
    60416149, /* 61278 (1556) [ 0,  0, -1,  0, -1,  0, -1,  0,  0] [ 9,  3,  9] -1 */
    61714103, /* 61279 (1556) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 9,  9,  3] -1 */
       11992, /* 61280 (1556) [ 0,  1,  0,  0,  0, -1, -1,  0,  0] [ 0,  0,  0]  1 */
       12064, /* 61281 (1556) [ 0,  1,  0,  0,  0,  1,  1,  0,  0] [ 0,  0,  0]  1 */
    61722631, /* 61282 (1556) [ 1,  0,  0,  0,  0,  1,  0, -1,  0] [ 9,  9,  3] -1 */
    61709515, /* 61283 (1556) [-1,  0,  0,  0,  0,  1,  0,  1,  0] [ 9,  9,  3] -1 */
     1551758, /* 61284 (1556) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
    61709455, /* 61285 (1556) [-1,  0,  0,  0,  0, -1,  0, -1,  0] [ 9,  9,  3] -1 */
    17127570, /* 61286 (1556) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6]  1 */
    60414537, /* 61287 (1556) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 9,  3,  9] -1 */
     1542946, /* 61288 (1556) [ 0, -1,  0,  0,  0,  1, -1,  0,  0] [ 0,  6,  6]  1 */
    17133082, /* 61289 (1556) [ 0,  0, -1, -1,  0,  0,  0,  1,  0] [ 6,  0,  6]  1 */
    43290815, /* 61290 (1556) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 3,  3,  3] -1 */
     1547266, /* 61291 (1556) [ 0,  1,  0,  0,  0, -1, -1,  0,  0] [ 0,  6,  6]  1 */
     1546090, /* 61292 (1556) [ 0,  0,  1,  1,  0,  0,  0,  1,  0] [ 0,  6,  6]  1 */
    44829977, /* 61293 (1556) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 3,  9,  9] -1 */
    44826089, /* 61294 (1556) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 3,  9,  9] -1 */
    44834617, /* 61295 (1556) [ 1,  0,  0,  0,  0,  1,  0, -1,  0] [ 3,  9,  9] -1 */
    44821501, /* 61296 (1556) [-1,  0,  0,  0,  0,  1,  0,  1,  0] [ 3,  9,  9] -1 */
    60410377, /* 61297 (1556) [-1,  0,  0,  0,  0, -1,  0, -1,  0] [ 9,  3,  9] -1 */
    43286227, /* 61298 (1556) [-1,  0,  0,  0,  0,  1,  0,  1,  0] [ 3,  3,  3] -1 */
    44821441, /* 61299 (1556) [-1,  0,  0,  0,  0, -1,  0, -1,  0] [ 3,  9,  9] -1 */
        7672, /* 61300 (1556) [ 0, -1,  0,  0,  0,  1, -1,  0,  0] [ 0,  0,  0]  1 */
        3360, /* 61301 (1556) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    60417625, /* 61302 (1556) [ 0,  0,  1,  0, -1,  0,  1,  0,  0] [ 9,  3,  9] -1 */
    18426488, /* 61303 (1556) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    18439608, /* 61304 (1556) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
    61718475, /* 61305 (1556) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 9,  9,  3] -1 */
    17127410, /* 61306 (1556) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
    17131882, /* 61307 (1556) [ 0, -1,  0,  0,  0,  1, -1,  0,  0] [ 6,  0,  6]  1 */
    17136202, /* 61308 (1556) [ 0,  1,  0,  0,  0, -1, -1,  0,  0] [ 6,  0,  6]  1 */
     1547338, /* 61309 (1556) [ 0,  1,  0,  0,  0,  1,  1,  0,  0] [ 0,  6,  6]  1 */
    18432640, /* 61310 (1556) [ 0,  0, -1,  1,  0,  0,  0, -1,  0] [ 6,  6,  0]  1 */
    60416329, /* 61311 (1556) [ 0,  0, -1,  0,  1,  0,  1,  0,  0] [ 9,  3,  9] -1 */
    17135026, /* 61312 (1556) [ 0,  0,  1,  1,  0,  0,  0,  1,  0] [ 6,  0,  6]  1 */
        7636, /* 61313 (1556) [ 0, -1,  0,  0,  0, -1,  1,  0,  0] [ 0,  0,  0]  1 */
    18430924, /* 61314 (1556) [ 0, -1,  0,  0,  0, -1,  1,  0,  0] [ 6,  6,  0]  1 */
    60418913, /* 61315 (1556) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 9,  3,  9] -1 */
    60423553, /* 61316 (1556) [ 1,  0,  0,  0,  0,  1,  0, -1,  0] [ 9,  3,  9] -1 */
    60410437, /* 61317 (1556) [-1,  0,  0,  0,  0,  1,  0,  1,  0] [ 9,  3,  9] -1 */
     1551594, /* 61318 (1556) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
    44830461, /* 61319 (1556) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 3,  9,  9] -1 */
     1544626, /* 61320 (1556) [ 0,  0, -1,  1,  0,  0,  0, -1,  0] [ 0,  6,  6]  1 */
        3200, /* 61321 (1556) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
     1542910, /* 61322 (1556) [ 0, -1,  0,  0,  0, -1,  1,  0,  0] [ 0,  6,  6]  1 */
       16484, /* 61323 (1557) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    52562962, /* 61324 (1557) [ 0,  0, -1,  1,  0,  0,  0, -1,  0] [ 6,  6,  6] -1 */
    26411281, /* 61325 (1557) [ 1,  0,  0,  0,  0, -1,  0,  1,  0] [ 9,  3,  9]  1 */
    26405401, /* 61326 (1557) [ 0,  0,  1,  0, -1,  0,  1,  0,  0] [ 9,  3,  9]  1 */
    17140694, /* 61327 (1557) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
       16320, /* 61328 (1557) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    26403925, /* 61329 (1557) [ 0,  0, -1,  0, -1,  0, -1,  0,  0] [ 9,  3,  9]  1 */
     1545598, /* 61330 (1557) [ 0,  0,  1, -1,  0,  0,  0, -1,  0] [ 0,  6,  6]  1 */
    27701879, /* 61331 (1557) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 9,  9,  3]  1 */
     1538474, /* 61332 (1557) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
    51034820, /* 61333 (1557) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  0] -1 */
    17136274, /* 61334 (1557) [ 0,  1,  0,  0,  0,  1,  1,  0,  0] [ 6,  0,  6]  1 */
    60296927, /* 61335 (1557) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 9,  3,  3] -1 */
    60292339, /* 61336 (1557) [-1,  0,  0,  0,  0,  1,  0,  1,  0] [ 9,  3,  3] -1 */
        9352, /* 61337 (1557) [ 0,  0, -1,  1,  0,  0,  0, -1,  0] [ 0,  0,  0]  1 */
    26402313, /* 61338 (1557) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 9,  3,  9]  1 */
     9278591, /* 61339 (1557) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 3,  3,  3]  1 */
    61831713, /* 61340 (1557) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 9,  9,  9] -1 */
    18426648, /* 61341 (1557) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
    34133522, /* 61342 (1557) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    52556810, /* 61343 (1557) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
        8872, /* 61344 (1557) [ 0,  0, -1, -1,  0,  0,  0,  1,  0] [ 0,  0,  0]  1 */
    18432160, /* 61345 (1557) [ 0,  0, -1, -1,  0,  0,  0,  1,  0] [ 6,  6,  0]  1 */
    51034656, /* 61346 (1557) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  0] -1 */
    35432760, /* 61347 (1557) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  0] -1 */
    44716471, /* 61348 (1557) [ 1,  0,  0,  0,  0, -1,  0,  1,  0] [ 3,  9,  3] -1 */
    35445884, /* 61349 (1557) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  0] -1 */
    26406689, /* 61350 (1557) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 9,  3,  9]  1 */
    10813865, /* 61351 (1557) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 3,  9,  9]  1 */
    26411329, /* 61352 (1557) [ 1,  0,  0,  0,  0,  1,  0, -1,  0] [ 9,  3,  9]  1 */
    44709115, /* 61353 (1557) [ 0,  0, -1,  0, -1,  0, -1,  0,  0] [ 3,  9,  3] -1 */
    26398213, /* 61354 (1557) [-1,  0,  0,  0,  0,  1,  0,  1,  0] [ 9,  3,  9]  1 */
     9274003, /* 61355 (1557) [-1,  0,  0,  0,  0,  1,  0,  1,  0] [ 3,  3,  3]  1 */
    18433612, /* 61356 (1557) [ 0,  0,  1, -1,  0,  0,  0, -1,  0] [ 6,  6,  0]  1 */
    17133562, /* 61357 (1557) [ 0,  0, -1,  1,  0,  0,  0, -1,  0] [ 6,  0,  6]  1 */
    43404325, /* 61358 (1557) [-1,  0,  0,  0,  0,  1,  0,  1,  0] [ 3,  3,  9] -1 */
    61833505, /* 61359 (1557) [ 0,  0, -1,  0,  1,  0,  1,  0,  0] [ 9,  9,  9] -1 */
    35441392, /* 61360 (1557) [ 0,  1,  0,  0,  0, -1, -1,  0,  0] [ 0,  6,  0] -1 */
    61836089, /* 61361 (1557) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 9,  9,  9] -1 */
    17131846, /* 61362 (1557) [ 0, -1,  0,  0,  0, -1,  1,  0,  0] [ 6,  0,  6]  1 */
    35441464, /* 61363 (1557) [ 0,  1,  0,  0,  0,  1,  1,  0,  0] [ 0,  6,  0] -1 */
    51025972, /* 61364 (1557) [ 0, -1,  0,  0,  0, -1,  1,  0,  0] [ 6,  0,  0] -1 */
    43410217, /* 61365 (1557) [ 0,  0, -1,  0,  1,  0,  1,  0,  0] [ 3,  3,  9] -1 */
    52561246, /* 61366 (1557) [ 0, -1,  0,  0,  0, -1,  1,  0,  0] [ 6,  6,  6] -1 */
    61840729, /* 61367 (1557) [ 1,  0,  0,  0,  0,  1,  0, -1,  0] [ 9,  9,  9] -1 */
       10324, /* 61368 (1557) [ 0,  0,  1, -1,  0,  0,  0, -1,  0] [ 0,  0,  0]  1 */
     1538634, /* 61369 (1557) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
    35440216, /* 61370 (1557) [ 0,  0,  1,  1,  0,  0,  0,  1,  0] [ 0,  6,  0] -1 */
     1544146, /* 61371 (1557) [ 0,  0, -1, -1,  0,  0,  0,  1,  0] [ 0,  6,  6]  1 */
    34139674, /* 61372 (1557) [ 0,  0, -1,  1,  0,  0,  0, -1,  0] [ 0,  0,  6] -1 */
    61827553, /* 61373 (1557) [-1,  0,  0,  0,  0, -1,  0, -1,  0] [ 9,  9,  9] -1 */
    51027688, /* 61374 (1557) [ 0,  0, -1,  1,  0,  0,  0, -1,  0] [ 6,  0,  0] -1 */
    34137958, /* 61375 (1557) [ 0, -1,  0,  0,  0, -1,  1,  0,  0] [ 0,  0,  6] -1 */
    44710735, /* 61376 (1557) [ 0,  0,  1,  0,  1,  0, -1,  0,  0] [ 3,  9,  3] -1 */
    17134534, /* 61377 (1557) [ 0,  0,  1, -1,  0,  0,  0, -1,  0] [ 6,  0,  6]  1 */
    52562482, /* 61378 (1557) [ 0,  0, -1, -1,  0,  0,  0,  1,  0] [ 6,  6,  6] -1 */
    34146806, /* 61379 (1557) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    18439772, /* 61380 (1557) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    17140530, /* 61381 (1557) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  6]  1 */
    51028660, /* 61382 (1557) [ 0,  0,  1, -1,  0,  0,  0, -1,  0] [ 6,  0,  0] -1 */
    27706251, /* 61383 (1557) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 9,  9,  3]  1 */
    27703003, /* 61384 (1557) [ 0,  0, -1,  0, -1,  0, -1,  0,  0] [ 9,  9,  3]  1 */
    10816609, /* 61385 (1557) [ 0,  0,  1,  0,  1,  0, -1,  0,  0] [ 3,  9,  9]  1 */
    18430960, /* 61386 (1557) [ 0, -1,  0,  0,  0,  1, -1,  0,  0] [ 6,  6,  0]  1 */
    34146642, /* 61387 (1557) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
    52569930, /* 61388 (1557) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    26404105, /* 61389 (1557) [ 0,  0, -1,  0,  1,  0,  1,  0,  0] [ 9,  3,  9]  1 */
    18435352, /* 61390 (1557) [ 0,  1,  0,  0,  0,  1,  1,  0,  0] [ 6,  6,  0]  1 */
    44710591, /* 61391 (1557) [ 0,  0,  1,  0, -1,  0,  1,  0,  0] [ 3,  9,  3] -1 */
    18435280, /* 61392 (1557) [ 0,  1,  0,  0,  0, -1, -1,  0,  0] [ 6,  6,  0]  1 */
    35437072, /* 61393 (1557) [ 0, -1,  0,  0,  0,  1, -1,  0,  0] [ 0,  6,  0] -1 */
    60305407, /* 61394 (1557) [ 1,  0,  0,  0,  0, -1,  0,  1,  0] [ 9,  3,  3] -1 */
       10816, /* 61395 (1557) [ 0,  0,  1,  1,  0,  0,  0,  1,  0] [ 0,  0,  0]  1 */
    18434104, /* 61396 (1557) [ 0,  0,  1,  1,  0,  0,  0,  1,  0] [ 6,  6,  0]  1 */
    60301299, /* 61397 (1557) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 9,  3,  3] -1 */
    61832201, /* 61398 (1557) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 9,  9,  9] -1 */
    60298051, /* 61399 (1557) [ 0,  0, -1,  0, -1,  0, -1,  0,  0] [ 9,  3,  3] -1 */
    61827613, /* 61400 (1557) [-1,  0,  0,  0,  0,  1,  0,  1,  0] [ 9,  9,  9] -1 */
     9281191, /* 61401 (1557) [ 0,  0,  1,  0, -1,  0,  1,  0,  0] [ 3,  3,  3]  1 */
    43408913, /* 61402 (1557) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 3,  3,  9] -1 */
       12064, /* 61403 (1557) [ 0,  1,  0,  0,  0,  1,  1,  0,  0] [ 0,  0,  0]  1 */
       11992, /* 61404 (1557) [ 0,  1,  0,  0,  0, -1, -1,  0,  0] [ 0,  0,  0]  1 */
    10822345, /* 61405 (1557) [ 1,  0,  0,  0,  0, -1,  0,  1,  0] [ 3,  9,  9]  1 */
    44707503, /* 61406 (1557) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 3,  9,  3] -1 */
     1551758, /* 61407 (1557) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
    10818237, /* 61408 (1557) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 3,  9,  9]  1 */
    10814989, /* 61409 (1557) [ 0,  0, -1,  0, -1,  0, -1,  0,  0] [ 3,  9,  9]  1 */
     9282963, /* 61410 (1557) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 3,  3,  3]  1 */
    17127570, /* 61411 (1557) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6]  1 */
     1542946, /* 61412 (1557) [ 0, -1,  0,  0,  0,  1, -1,  0,  0] [ 0,  6,  6]  1 */
    17133082, /* 61413 (1557) [ 0,  0, -1, -1,  0,  0,  0,  1,  0] [ 6,  0,  6]  1 */
     1547266, /* 61414 (1557) [ 0,  1,  0,  0,  0, -1, -1,  0,  0] [ 0,  6,  6]  1 */
    43417393, /* 61415 (1557) [ 1,  0,  0,  0,  0, -1,  0,  1,  0] [ 3,  3,  9] -1 */
    61836573, /* 61416 (1557) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 9,  9,  9] -1 */
    27704623, /* 61417 (1557) [ 0,  0,  1,  0,  1,  0, -1,  0,  0] [ 9,  9,  3]  1 */
    60299671, /* 61418 (1557) [ 0,  0,  1,  0,  1,  0, -1,  0,  0] [ 9,  3,  3] -1 */
     9278103, /* 61419 (1557) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 3,  3,  3]  1 */
     1546090, /* 61420 (1557) [ 0,  0,  1,  1,  0,  0,  0,  1,  0] [ 0,  6,  6]  1 */
    43413285, /* 61421 (1557) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 3,  3,  9] -1 */
    44709295, /* 61422 (1557) [ 0,  0, -1,  0,  1,  0,  1,  0,  0] [ 3,  9,  3] -1 */
    35438752, /* 61423 (1557) [ 0,  0, -1,  1,  0,  0,  0, -1,  0] [ 0,  6,  0] -1 */
    43410037, /* 61424 (1557) [ 0,  0, -1,  0, -1,  0, -1,  0,  0] [ 3,  3,  9] -1 */
    34139194, /* 61425 (1557) [ 0,  0, -1, -1,  0,  0,  0,  1,  0] [ 0,  0,  6] -1 */
    44711879, /* 61426 (1557) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 3,  9,  3] -1 */
    51027208, /* 61427 (1557) [ 0,  0, -1, -1,  0,  0,  0,  1,  0] [ 6,  0,  0] -1 */
    51030328, /* 61428 (1557) [ 0,  1,  0,  0,  0, -1, -1,  0,  0] [ 6,  0,  0] -1 */
    51030400, /* 61429 (1557) [ 0,  1,  0,  0,  0,  1,  1,  0,  0] [ 6,  0,  0] -1 */
    35437036, /* 61430 (1557) [ 0, -1,  0,  0,  0, -1,  1,  0,  0] [ 0,  6,  0] -1 */
    44716519, /* 61431 (1557) [ 1,  0,  0,  0,  0,  1,  0, -1,  0] [ 3,  9,  3] -1 */
    27704479, /* 61432 (1557) [ 0,  0,  1,  0, -1,  0,  1,  0,  0] [ 9,  9,  3]  1 */
     9282479, /* 61433 (1557) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 3,  3,  3]  1 */
    34140646, /* 61434 (1557) [ 0,  0,  1, -1,  0,  0,  0, -1,  0] [ 0,  0,  6] -1 */
    52563934, /* 61435 (1557) [ 0,  0,  1, -1,  0,  0,  0, -1,  0] [ 6,  6,  6] -1 */
    26402801, /* 61436 (1557) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 9,  3,  9]  1 */
    26405545, /* 61437 (1557) [ 0,  0,  1,  0,  1,  0, -1,  0,  0] [ 9,  3,  9]  1 */
        7672, /* 61438 (1557) [ 0, -1,  0,  0,  0,  1, -1,  0,  0] [ 0,  0,  0]  1 */
     9281335, /* 61439 (1557) [ 0,  0,  1,  0,  1,  0, -1,  0,  0] [ 3,  3,  3]  1 */
    61834945, /* 61440 (1557) [ 0,  0,  1,  0,  1,  0, -1,  0,  0] [ 9,  9,  9] -1 */
        3360, /* 61441 (1557) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    43411657, /* 61442 (1557) [ 0,  0,  1,  0,  1,  0, -1,  0,  0] [ 3,  3,  9] -1 */
    18426488, /* 61443 (1557) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    60299527, /* 61444 (1557) [ 0,  0,  1,  0, -1,  0,  1,  0,  0] [ 9,  3,  3] -1 */
    43417441, /* 61445 (1557) [ 1,  0,  0,  0,  0,  1,  0, -1,  0] [ 3,  3,  9] -1 */
    35432600, /* 61446 (1557) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  0] -1 */
    27701391, /* 61447 (1557) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 9,  9,  3]  1 */
    35439724, /* 61448 (1557) [ 0,  0,  1, -1,  0,  0,  0, -1,  0] [ 0,  6,  0] -1 */
    10816465, /* 61449 (1557) [ 0,  0,  1,  0, -1,  0,  1,  0,  0] [ 3,  9,  9]  1 */
     9287071, /* 61450 (1557) [ 1,  0,  0,  0,  0, -1,  0,  1,  0] [ 3,  3,  3]  1 */
    60296439, /* 61451 (1557) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 9,  3,  3] -1 */
    18439608, /* 61452 (1557) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
    26407173, /* 61453 (1557) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 9,  3,  9]  1 */
     9279715, /* 61454 (1557) [ 0,  0, -1,  0, -1,  0, -1,  0,  0] [ 3,  3,  3]  1 */
    35445720, /* 61455 (1557) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  0] -1 */
    27705767, /* 61456 (1557) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 9,  9,  3]  1 */
    52556970, /* 61457 (1557) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    17127410, /* 61458 (1557) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
    17131882, /* 61459 (1557) [ 0, -1,  0,  0,  0,  1, -1,  0,  0] [ 6,  0,  6]  1 */
    61840681, /* 61460 (1557) [ 1,  0,  0,  0,  0, -1,  0,  1,  0] [ 9,  9,  9] -1 */
    27710407, /* 61461 (1557) [ 1,  0,  0,  0,  0,  1,  0, -1,  0] [ 9,  9,  3]  1 */
    51021696, /* 61462 (1557) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  0] -1 */
    27697291, /* 61463 (1557) [-1,  0,  0,  0,  0,  1,  0,  1,  0] [ 9,  9,  3]  1 */
    52570094, /* 61464 (1557) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    61834801, /* 61465 (1557) [ 0,  0,  1,  0, -1,  0,  1,  0,  0] [ 9,  9,  9] -1 */
    17136202, /* 61466 (1557) [ 0,  1,  0,  0,  0, -1, -1,  0,  0] [ 6,  0,  6]  1 */
     1547338, /* 61467 (1557) [ 0,  1,  0,  0,  0,  1,  1,  0,  0] [ 0,  6,  6]  1 */
    44707991, /* 61468 (1557) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 3,  9,  3] -1 */
    27703183, /* 61469 (1557) [ 0,  0, -1,  0,  1,  0,  1,  0,  0] [ 9,  9,  3]  1 */
    18432640, /* 61470 (1557) [ 0,  0, -1,  1,  0,  0,  0, -1,  0] [ 6,  6,  0]  1 */
    43411513, /* 61471 (1557) [ 0,  0,  1,  0, -1,  0,  1,  0,  0] [ 3,  3,  9] -1 */
    27697231, /* 61472 (1557) [-1,  0,  0,  0,  0, -1,  0, -1,  0] [ 9,  9,  3]  1 */
    44703403, /* 61473 (1557) [-1,  0,  0,  0,  0,  1,  0,  1,  0] [ 3,  9,  3] -1 */
    61833325, /* 61474 (1557) [ 0,  0, -1,  0, -1,  0, -1,  0,  0] [ 9,  9,  9] -1 */
    60292279, /* 61475 (1557) [-1,  0,  0,  0,  0, -1,  0, -1,  0] [ 9,  3,  3] -1 */
    17135026, /* 61476 (1557) [ 0,  0,  1,  1,  0,  0,  0,  1,  0] [ 6,  0,  6]  1 */
    10813377, /* 61477 (1557) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 3,  9,  9]  1 */
        7636, /* 61478 (1557) [ 0, -1,  0,  0,  0, -1,  1,  0,  0] [ 0,  0,  0]  1 */
    18430924, /* 61479 (1557) [ 0, -1,  0,  0,  0, -1,  1,  0,  0] [ 6,  6,  0]  1 */
    60298231, /* 61480 (1557) [ 0,  0, -1,  0,  1,  0,  1,  0,  0] [ 9,  3,  3] -1 */
    52561282, /* 61481 (1557) [ 0, -1,  0,  0,  0,  1, -1,  0,  0] [ 6,  6,  6] -1 */
    44703343, /* 61482 (1557) [-1,  0,  0,  0,  0, -1,  0, -1,  0] [ 3,  9,  3] -1 */
    34137994, /* 61483 (1557) [ 0, -1,  0,  0,  0,  1, -1,  0,  0] [ 0,  0,  6] -1 */
    34133682, /* 61484 (1557) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
    51021536, /* 61485 (1557) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  0] -1 */
    60300815, /* 61486 (1557) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 9,  3,  3] -1 */
    51026008, /* 61487 (1557) [ 0, -1,  0,  0,  0,  1, -1,  0,  0] [ 6,  0,  0] -1 */
    34142314, /* 61488 (1557) [ 0,  1,  0,  0,  0, -1, -1,  0,  0] [ 0,  0,  6] -1 */
    52565602, /* 61489 (1557) [ 0,  1,  0,  0,  0, -1, -1,  0,  0] [ 6,  6,  6] -1 */
    43408425, /* 61490 (1557) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 3,  3,  9] -1 */
    34142386, /* 61491 (1557) [ 0,  1,  0,  0,  0,  1,  1,  0,  0] [ 0,  0,  6] -1 */
    52565674, /* 61492 (1557) [ 0,  1,  0,  0,  0,  1,  1,  0,  0] [ 6,  6,  6] -1 */
    60305455, /* 61493 (1557) [ 1,  0,  0,  0,  0,  1,  0, -1,  0] [ 9,  3,  3] -1 */
     9279895, /* 61494 (1557) [ 0,  0, -1,  0,  1,  0,  1,  0,  0] [ 3,  3,  3]  1 */
     1551594, /* 61495 (1557) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
    34141138, /* 61496 (1557) [ 0,  0,  1,  1,  0,  0,  0,  1,  0] [ 0,  0,  6] -1 */
    52564426, /* 61497 (1557) [ 0,  0,  1,  1,  0,  0,  0,  1,  0] [ 6,  6,  6] -1 */
    35438272, /* 61498 (1557) [ 0,  0, -1, -1,  0,  0,  0,  1,  0] [ 0,  6,  0] -1 */
    27710359, /* 61499 (1557) [ 1,  0,  0,  0,  0, -1,  0,  1,  0] [ 9,  9,  3]  1 */
    51029152, /* 61500 (1557) [ 0,  0,  1,  1,  0,  0,  0,  1,  0] [ 6,  0,  0] -1 */
    10817753, /* 61501 (1557) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 3,  9,  9]  1 */
     9287119, /* 61502 (1557) [ 1,  0,  0,  0,  0,  1,  0, -1,  0] [ 3,  3,  3]  1 */
    44712363, /* 61503 (1557) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 3,  9,  3] -1 */
    10822393, /* 61504 (1557) [ 1,  0,  0,  0,  0,  1,  0, -1,  0] [ 3,  9,  9]  1 */
    10809277, /* 61505 (1557) [-1,  0,  0,  0,  0,  1,  0,  1,  0] [ 3,  9,  9]  1 */
    26398153, /* 61506 (1557) [-1,  0,  0,  0,  0, -1,  0, -1,  0] [ 9,  3,  9]  1 */
     9273943, /* 61507 (1557) [-1,  0,  0,  0,  0, -1,  0, -1,  0] [ 3,  3,  3]  1 */
    10815169, /* 61508 (1557) [ 0,  0, -1,  0,  1,  0,  1,  0,  0] [ 3,  9,  9]  1 */
     1544626, /* 61509 (1557) [ 0,  0, -1,  1,  0,  0,  0, -1,  0] [ 0,  6,  6]  1 */
    10809217, /* 61510 (1557) [-1,  0,  0,  0,  0, -1,  0, -1,  0] [ 3,  9,  9]  1 */
        3200, /* 61511 (1557) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    43404265, /* 61512 (1557) [-1,  0,  0,  0,  0, -1,  0, -1,  0] [ 3,  3,  9] -1 */
     1542910, /* 61513 (1557) [ 0, -1,  0,  0,  0, -1,  1,  0,  0] [ 0,  6,  6]  1 */
    43412801, /* 61514 (1557) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 3,  3,  9] -1 */
       16484, /* 61515 (1558) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    18557764, /* 61516 (1558) [ 1,  0,  0,  0,  0, -1,  0,  1,  0] [ 6,  6,  6]  1 */
    18551884, /* 61517 (1558) [ 0,  0,  1,  0, -1,  0,  1,  0,  0] [ 6,  6,  6]  1 */
        9022, /* 61518 (1558) [ 0,  0, -1,  0, -1,  0, -1,  0,  0] [ 0,  0,  0]  1 */
    18553656, /* 61519 (1558) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 6,  6,  6]  1 */
       16320, /* 61520 (1558) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
       16378, /* 61521 (1558) [ 1,  0,  0,  0,  0, -1,  0,  1,  0] [ 0,  0,  0]  1 */
       12270, /* 61522 (1558) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    18550408, /* 61523 (1558) [ 0,  0, -1,  0, -1,  0, -1,  0,  0] [ 6,  6,  6]  1 */
    18548796, /* 61524 (1558) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 6,  6,  6]  1 */
    18549022, /* 61525 (1558) [ 0, -1,  0,  0,  0, -1,  1,  0,  0] [ 6,  6,  6]  1 */
        7410, /* 61526 (1558) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    18550738, /* 61527 (1558) [ 0,  0, -1,  1,  0,  0,  0, -1,  0] [ 6,  6,  6]  1 */
        7636, /* 61528 (1558) [ 0, -1,  0,  0,  0, -1,  1,  0,  0] [ 0,  0,  0]  1 */
        9352, /* 61529 (1558) [ 0,  0, -1,  1,  0,  0,  0, -1,  0] [ 0,  0,  0]  1 */
    18544746, /* 61530 (1558) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
    18557870, /* 61531 (1558) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    18552028, /* 61532 (1558) [ 0,  0,  1,  0,  1,  0, -1,  0,  0] [ 6,  6,  6]  1 */
        8872, /* 61533 (1558) [ 0,  0, -1, -1,  0,  0,  0,  1,  0] [ 0,  0,  0]  1 */
    18553172, /* 61534 (1558) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    18544636, /* 61535 (1558) [-1,  0,  0,  0,  0, -1,  0, -1,  0] [ 6,  6,  6]  1 */
       10642, /* 61536 (1558) [ 0,  0,  1,  0,  1,  0, -1,  0,  0] [ 0,  0,  0]  1 */
    18550258, /* 61537 (1558) [ 0,  0, -1, -1,  0,  0,  0,  1,  0] [ 6,  6,  6]  1 */
    18557812, /* 61538 (1558) [ 1,  0,  0,  0,  0,  1,  0, -1,  0] [ 6,  6,  6]  1 */
    18544696, /* 61539 (1558) [-1,  0,  0,  0,  0,  1,  0,  1,  0] [ 6,  6,  6]  1 */
    18549284, /* 61540 (1558) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 6,  6,  6]  1 */
       11786, /* 61541 (1558) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  0]  1 */
        7672, /* 61542 (1558) [ 0, -1,  0,  0,  0,  1, -1,  0,  0] [ 0,  0,  0]  1 */
        3360, /* 61543 (1558) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
        7898, /* 61544 (1558) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 0,  0,  0]  1 */
        3250, /* 61545 (1558) [-1,  0,  0,  0,  0, -1,  0, -1,  0] [ 0,  0,  0]  1 */
    18550588, /* 61546 (1558) [ 0,  0, -1,  0,  1,  0,  1,  0,  0] [ 6,  6,  6]  1 */
       16426, /* 61547 (1558) [ 1,  0,  0,  0,  0,  1,  0, -1,  0] [ 0,  0,  0]  1 */
    18549058, /* 61548 (1558) [ 0, -1,  0,  0,  0,  1, -1,  0,  0] [ 6,  6,  6]  1 */
        3310, /* 61549 (1558) [-1,  0,  0,  0,  0,  1,  0,  1,  0] [ 0,  0,  0]  1 */
        9202, /* 61550 (1558) [ 0,  0, -1,  0,  1,  0,  1,  0,  0] [ 0,  0,  0]  1 */
    18553378, /* 61551 (1558) [ 0,  1,  0,  0,  0, -1, -1,  0,  0] [ 6,  6,  6]  1 */
       10816, /* 61552 (1558) [ 0,  0,  1,  1,  0,  0,  0,  1,  0] [ 0,  0,  0]  1 */
        3200, /* 61553 (1558) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    18553450, /* 61554 (1558) [ 0,  1,  0,  0,  0,  1,  1,  0,  0] [ 6,  6,  6]  1 */
       11992, /* 61555 (1558) [ 0,  1,  0,  0,  0, -1, -1,  0,  0] [ 0,  0,  0]  1 */
    18552202, /* 61556 (1558) [ 0,  0,  1,  1,  0,  0,  0,  1,  0] [ 6,  6,  6]  1 */
       12064, /* 61557 (1558) [ 0,  1,  0,  0,  0,  1,  1,  0,  0] [ 0,  0,  0]  1 */
    18544586, /* 61558 (1558) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    18551710, /* 61559 (1558) [ 0,  0,  1, -1,  0,  0,  0, -1,  0] [ 6,  6,  6]  1 */
       10498, /* 61560 (1558) [ 0,  0,  1,  0, -1,  0,  1,  0,  0] [ 0,  0,  0]  1 */
       10324, /* 61561 (1558) [ 0,  0,  1, -1,  0,  0,  0, -1,  0] [ 0,  0,  0]  1 */
    18557706, /* 61562 (1558) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
       16484, /* 61563 (1559) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    52562962, /* 61564 (1559) [ 0,  0, -1,  1,  0,  0,  0, -1,  0] [ 6,  6,  6] -1 */
        9022, /* 61565 (1559) [ 0,  0, -1,  0, -1,  0, -1,  0,  0] [ 0,  0,  0]  1 */
       16320, /* 61566 (1559) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    34019896, /* 61567 (1559) [ 0, -1,  0,  0,  0,  1, -1,  0,  0] [ 0,  0,  0] -1 */
    18548796, /* 61568 (1559) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 6,  6,  6]  1 */
    34015584, /* 61569 (1559) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
        7410, /* 61570 (1559) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    34020122, /* 61571 (1559) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 0,  0,  0] -1 */
        9352, /* 61572 (1559) [ 0,  0, -1,  1,  0,  0,  0, -1,  0] [ 0,  0,  0]  1 */
    18544746, /* 61573 (1559) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
    34023040, /* 61574 (1559) [ 0,  0,  1,  1,  0,  0,  0,  1,  0] [ 0,  0,  0] -1 */
    18557870, /* 61575 (1559) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    52556810, /* 61576 (1559) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
        8872, /* 61577 (1559) [ 0,  0, -1, -1,  0,  0,  0,  1,  0] [ 0,  0,  0]  1 */
    34024288, /* 61578 (1559) [ 0,  1,  0,  0,  0,  1,  1,  0,  0] [ 0,  0,  0] -1 */
    18544696, /* 61579 (1559) [-1,  0,  0,  0,  0,  1,  0,  1,  0] [ 6,  6,  6]  1 */
    52569988, /* 61580 (1559) [ 1,  0,  0,  0,  0, -1,  0,  1,  0] [ 6,  6,  6] -1 */
        3250, /* 61581 (1559) [-1,  0,  0,  0,  0, -1,  0, -1,  0] [ 0,  0,  0]  1 */
    18549058, /* 61582 (1559) [ 0, -1,  0,  0,  0,  1, -1,  0,  0] [ 6,  6,  6]  1 */
    18550588, /* 61583 (1559) [ 0,  0, -1,  0,  1,  0,  1,  0,  0] [ 6,  6,  6]  1 */
        9202, /* 61584 (1559) [ 0,  0, -1,  0,  1,  0,  1,  0,  0] [ 0,  0,  0]  1 */
    18553378, /* 61585 (1559) [ 0,  1,  0,  0,  0, -1, -1,  0,  0] [ 6,  6,  6]  1 */
    52562632, /* 61586 (1559) [ 0,  0, -1,  0, -1,  0, -1,  0,  0] [ 6,  6,  6] -1 */
    34024494, /* 61587 (1559) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    18552202, /* 61588 (1559) [ 0,  0,  1,  1,  0,  0,  0,  1,  0] [ 6,  6,  6]  1 */
    52561246, /* 61589 (1559) [ 0, -1,  0,  0,  0, -1,  1,  0,  0] [ 6,  6,  6] -1 */
       10324, /* 61590 (1559) [ 0,  0,  1, -1,  0,  0,  0, -1,  0] [ 0,  0,  0]  1 */
    52564252, /* 61591 (1559) [ 0,  0,  1,  0,  1,  0, -1,  0,  0] [ 6,  6,  6] -1 */
    34022866, /* 61592 (1559) [ 0,  0,  1,  0,  1,  0, -1,  0,  0] [ 0,  0,  0] -1 */
    52565396, /* 61593 (1559) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    52562482, /* 61594 (1559) [ 0,  0, -1, -1,  0,  0,  0,  1,  0] [ 6,  6,  6] -1 */
    52570036, /* 61595 (1559) [ 1,  0,  0,  0,  0,  1,  0, -1,  0] [ 6,  6,  6] -1 */
    34028650, /* 61596 (1559) [ 1,  0,  0,  0,  0,  1,  0, -1,  0] [ 0,  0,  0] -1 */
    34015424, /* 61597 (1559) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    34028708, /* 61598 (1559) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    18549284, /* 61599 (1559) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 6,  6,  6]  1 */
       11786, /* 61600 (1559) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    52569930, /* 61601 (1559) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
        7898, /* 61602 (1559) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34028544, /* 61603 (1559) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
        3310, /* 61604 (1559) [-1,  0,  0,  0,  0,  1,  0,  1,  0] [ 0,  0,  0]  1 */
    52564108, /* 61605 (1559) [ 0,  0,  1,  0, -1,  0,  1,  0,  0] [ 6,  6,  6] -1 */
    34028602, /* 61606 (1559) [ 1,  0,  0,  0,  0, -1,  0,  1,  0] [ 0,  0,  0] -1 */
       10816, /* 61607 (1559) [ 0,  0,  1,  1,  0,  0,  0,  1,  0] [ 0,  0,  0]  1 */
    18553450, /* 61608 (1559) [ 0,  1,  0,  0,  0,  1,  1,  0,  0] [ 6,  6,  6]  1 */
       11992, /* 61609 (1559) [ 0,  1,  0,  0,  0, -1, -1,  0,  0] [ 0,  0,  0]  1 */
       12064, /* 61610 (1559) [ 0,  1,  0,  0,  0,  1,  1,  0,  0] [ 0,  0,  0]  1 */
    52561020, /* 61611 (1559) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    34019860, /* 61612 (1559) [ 0, -1,  0,  0,  0, -1,  1,  0,  0] [ 0,  0,  0] -1 */
    18553656, /* 61613 (1559) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 6,  6,  6]  1 */
       12270, /* 61614 (1559) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    52556860, /* 61615 (1559) [-1,  0,  0,  0,  0, -1,  0, -1,  0] [ 6,  6,  6] -1 */
    34015474, /* 61616 (1559) [-1,  0,  0,  0,  0, -1,  0, -1,  0] [ 0,  0,  0] -1 */
    52562812, /* 61617 (1559) [ 0,  0, -1,  0,  1,  0,  1,  0,  0] [ 6,  6,  6] -1 */
    18550738, /* 61618 (1559) [ 0,  0, -1,  1,  0,  0,  0, -1,  0] [ 6,  6,  6]  1 */
    18552028, /* 61619 (1559) [ 0,  0,  1,  0,  1,  0, -1,  0,  0] [ 6,  6,  6]  1 */
    18553172, /* 61620 (1559) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    52563934, /* 61621 (1559) [ 0,  0,  1, -1,  0,  0,  0, -1,  0] [ 6,  6,  6] -1 */
    34022548, /* 61622 (1559) [ 0,  0,  1, -1,  0,  0,  0, -1,  0] [ 0,  0,  0] -1 */
    18557812, /* 61623 (1559) [ 1,  0,  0,  0,  0,  1,  0, -1,  0] [ 6,  6,  6]  1 */
        7672, /* 61624 (1559) [ 0, -1,  0,  0,  0,  1, -1,  0,  0] [ 0,  0,  0]  1 */
    34022722, /* 61625 (1559) [ 0,  0,  1,  0, -1,  0,  1,  0,  0] [ 0,  0,  0] -1 */
        3360, /* 61626 (1559) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    34021246, /* 61627 (1559) [ 0,  0, -1,  0, -1,  0, -1,  0,  0] [ 0,  0,  0] -1 */
    18544586, /* 61628 (1559) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    18557706, /* 61629 (1559) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
    18557764, /* 61630 (1559) [ 1,  0,  0,  0,  0, -1,  0,  1,  0] [ 6,  6,  6]  1 */
    34019634, /* 61631 (1559) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    18551884, /* 61632 (1559) [ 0,  0,  1,  0, -1,  0,  1,  0,  0] [ 6,  6,  6]  1 */
       16378, /* 61633 (1559) [ 1,  0,  0,  0,  0, -1,  0,  1,  0] [ 0,  0,  0]  1 */
    34021576, /* 61634 (1559) [ 0,  0, -1,  1,  0,  0,  0, -1,  0] [ 0,  0,  0] -1 */
    52556970, /* 61635 (1559) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    18550408, /* 61636 (1559) [ 0,  0, -1,  0, -1,  0, -1,  0,  0] [ 6,  6,  6]  1 */
    52570094, /* 61637 (1559) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    34021096, /* 61638 (1559) [ 0,  0, -1, -1,  0,  0,  0,  1,  0] [ 0,  0,  0] -1 */
    52561508, /* 61639 (1559) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    34024010, /* 61640 (1559) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    18549022, /* 61641 (1559) [ 0, -1,  0,  0,  0, -1,  1,  0,  0] [ 6,  6,  6]  1 */
    52556920, /* 61642 (1559) [-1,  0,  0,  0,  0,  1,  0,  1,  0] [ 6,  6,  6] -1 */
        7636, /* 61643 (1559) [ 0, -1,  0,  0,  0, -1,  1,  0,  0] [ 0,  0,  0]  1 */
    34015534, /* 61644 (1559) [-1,  0,  0,  0,  0,  1,  0,  1,  0] [ 0,  0,  0] -1 */
    52561282, /* 61645 (1559) [ 0, -1,  0,  0,  0,  1, -1,  0,  0] [ 6,  6,  6] -1 */
    34021426, /* 61646 (1559) [ 0,  0, -1,  0,  1,  0,  1,  0,  0] [ 0,  0,  0] -1 */
    52565602, /* 61647 (1559) [ 0,  1,  0,  0,  0, -1, -1,  0,  0] [ 6,  6,  6] -1 */
    52565674, /* 61648 (1559) [ 0,  1,  0,  0,  0,  1,  1,  0,  0] [ 6,  6,  6] -1 */
    34024216, /* 61649 (1559) [ 0,  1,  0,  0,  0, -1, -1,  0,  0] [ 0,  0,  0] -1 */
    52564426, /* 61650 (1559) [ 0,  0,  1,  1,  0,  0,  0,  1,  0] [ 6,  6,  6] -1 */
    18544636, /* 61651 (1559) [-1,  0,  0,  0,  0, -1,  0, -1,  0] [ 6,  6,  6]  1 */
       10642, /* 61652 (1559) [ 0,  0,  1,  0,  1,  0, -1,  0,  0] [ 0,  0,  0]  1 */
    18550258, /* 61653 (1559) [ 0,  0, -1, -1,  0,  0,  0,  1,  0] [ 6,  6,  6]  1 */
    52565880, /* 61654 (1559) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 6,  6,  6] -1 */
       16426, /* 61655 (1559) [ 1,  0,  0,  0,  0,  1,  0, -1,  0] [ 0,  0,  0]  1 */
        3200, /* 61656 (1559) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    18551710, /* 61657 (1559) [ 0,  0,  1, -1,  0,  0,  0, -1,  0] [ 6,  6,  6]  1 */
       10498, /* 61658 (1559) [ 0,  0,  1,  0, -1,  0,  1,  0,  0] [ 0,  0,  0]  1 */
       16484, /* 61659 (1560) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34019634, /* 61660 (1560) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  0] -1 */
       16320, /* 61661 (1560) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    52564252, /* 61662 (1560) [ 0,  0,  1,  0,  1,  0, -1,  0,  0] [ 6,  6,  6] -1 */
    34022866, /* 61663 (1560) [ 0,  0,  1,  0,  1,  0, -1,  0,  0] [ 0,  0,  0] -1 */
    52565396, /* 61664 (1560) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    52556860, /* 61665 (1560) [-1,  0,  0,  0,  0, -1,  0, -1,  0] [ 6,  6,  6] -1 */
    52561508, /* 61666 (1560) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    34024010, /* 61667 (1560) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    18549022, /* 61668 (1560) [ 0, -1,  0,  0,  0, -1,  1,  0,  0] [ 6,  6,  6]  1 */
    52570036, /* 61669 (1560) [ 1,  0,  0,  0,  0,  1,  0, -1,  0] [ 6,  6,  6] -1 */
    34015474, /* 61670 (1560) [-1,  0,  0,  0,  0, -1,  0, -1,  0] [ 0,  0,  0] -1 */
    52556920, /* 61671 (1560) [-1,  0,  0,  0,  0,  1,  0,  1,  0] [ 6,  6,  6] -1 */
    18550738, /* 61672 (1560) [ 0,  0, -1,  1,  0,  0,  0, -1,  0] [ 6,  6,  6]  1 */
    34028650, /* 61673 (1560) [ 1,  0,  0,  0,  0,  1,  0, -1,  0] [ 0,  0,  0] -1 */
        7636, /* 61674 (1560) [ 0, -1,  0,  0,  0, -1,  1,  0,  0] [ 0,  0,  0]  1 */
    52562812, /* 61675 (1560) [ 0,  0, -1,  0,  1,  0,  1,  0,  0] [ 6,  6,  6] -1 */
    34015534, /* 61676 (1560) [-1,  0,  0,  0,  0,  1,  0,  1,  0] [ 0,  0,  0] -1 */
    34020122, /* 61677 (1560) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 0,  0,  0] -1 */
        9352, /* 61678 (1560) [ 0,  0, -1,  1,  0,  0,  0, -1,  0] [ 0,  0,  0]  1 */
    34021426, /* 61679 (1560) [ 0,  0, -1,  0,  1,  0,  1,  0,  0] [ 0,  0,  0] -1 */
    18544746, /* 61680 (1560) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
    18557870, /* 61681 (1560) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
        8872, /* 61682 (1560) [ 0,  0, -1, -1,  0,  0,  0,  1,  0] [ 0,  0,  0]  1 */
    18550258, /* 61683 (1560) [ 0,  0, -1, -1,  0,  0,  0,  1,  0] [ 6,  6,  6]  1 */
        7672, /* 61684 (1560) [ 0, -1,  0,  0,  0,  1, -1,  0,  0] [ 0,  0,  0]  1 */
    34022722, /* 61685 (1560) [ 0,  0,  1,  0, -1,  0,  1,  0,  0] [ 0,  0,  0] -1 */
    52569988, /* 61686 (1560) [ 1,  0,  0,  0,  0, -1,  0,  1,  0] [ 6,  6,  6] -1 */
        3360, /* 61687 (1560) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    18549058, /* 61688 (1560) [ 0, -1,  0,  0,  0,  1, -1,  0,  0] [ 6,  6,  6]  1 */
    52565880, /* 61689 (1560) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    52564108, /* 61690 (1560) [ 0,  0,  1,  0, -1,  0,  1,  0,  0] [ 6,  6,  6] -1 */
    34021246, /* 61691 (1560) [ 0,  0, -1,  0, -1,  0, -1,  0,  0] [ 0,  0,  0] -1 */
       10816, /* 61692 (1560) [ 0,  0,  1,  1,  0,  0,  0,  1,  0] [ 0,  0,  0]  1 */
    18553378, /* 61693 (1560) [ 0,  1,  0,  0,  0, -1, -1,  0,  0] [ 6,  6,  6]  1 */
        3200, /* 61694 (1560) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    52562632, /* 61695 (1560) [ 0,  0, -1,  0, -1,  0, -1,  0,  0] [ 6,  6,  6] -1 */
    34024494, /* 61696 (1560) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    34028602, /* 61697 (1560) [ 1,  0,  0,  0,  0, -1,  0,  1,  0] [ 0,  0,  0] -1 */
    18553450, /* 61698 (1560) [ 0,  1,  0,  0,  0,  1,  1,  0,  0] [ 6,  6,  6]  1 */
       11992, /* 61699 (1560) [ 0,  1,  0,  0,  0, -1, -1,  0,  0] [ 0,  0,  0]  1 */
    18552202, /* 61700 (1560) [ 0,  0,  1,  1,  0,  0,  0,  1,  0] [ 6,  6,  6]  1 */
       12064, /* 61701 (1560) [ 0,  1,  0,  0,  0,  1,  1,  0,  0] [ 0,  0,  0]  1 */
    18544586, /* 61702 (1560) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    18551710, /* 61703 (1560) [ 0,  0,  1, -1,  0,  0,  0, -1,  0] [ 6,  6,  6]  1 */
    52561020, /* 61704 (1560) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 6,  6,  6] -1 */
       10324, /* 61705 (1560) [ 0,  0,  1, -1,  0,  0,  0, -1,  0] [ 0,  0,  0]  1 */
    18557706, /* 61706 (1560) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
       16484, /* 61707 (1561) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    18439608, /* 61708 (1561) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
     1542946, /* 61709 (1561) [ 0, -1,  0,  0,  0,  1, -1,  0,  0] [ 0,  6,  6]  1 */
    17133082, /* 61710 (1561) [ 0,  0, -1, -1,  0,  0,  0,  1,  0] [ 6,  0,  6]  1 */
     9279715, /* 61711 (1561) [ 0,  0, -1,  0, -1,  0, -1,  0,  0] [ 3,  3,  3]  1 */
    27705767, /* 61712 (1561) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 9,  9,  3]  1 */
    17127410, /* 61713 (1561) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
     9278103, /* 61714 (1561) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 3,  3,  3]  1 */
    27704479, /* 61715 (1561) [ 0,  0,  1,  0, -1,  0,  1,  0,  0] [ 9,  9,  3]  1 */
    10816609, /* 61716 (1561) [ 0,  0,  1,  0,  1,  0, -1,  0,  0] [ 3,  9,  9]  1 */
    27710359, /* 61717 (1561) [ 1,  0,  0,  0,  0, -1,  0,  1,  0] [ 9,  9,  3]  1 */
    26402801, /* 61718 (1561) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 9,  3,  9]  1 */
    10822393, /* 61719 (1561) [ 1,  0,  0,  0,  0,  1,  0, -1,  0] [ 3,  9,  9]  1 */
    26404105, /* 61720 (1561) [ 0,  0, -1,  0,  1,  0,  1,  0,  0] [ 9,  3,  9]  1 */
    18435280, /* 61721 (1561) [ 0,  1,  0,  0,  0, -1, -1,  0,  0] [ 6,  6,  0]  1 */
     9273943, /* 61722 (1561) [-1,  0,  0,  0,  0, -1,  0, -1,  0] [ 3,  3,  3]  1 */
    26398213, /* 61723 (1561) [-1,  0,  0,  0,  0,  1,  0,  1,  0] [ 9,  3,  9]  1 */
     1544626, /* 61724 (1561) [ 0,  0, -1,  1,  0,  0,  0, -1,  0] [ 0,  6,  6]  1 */
       10816, /* 61725 (1561) [ 0,  0,  1,  1,  0,  0,  0,  1,  0] [ 0,  0,  0]  1 */
    18433612, /* 61726 (1561) [ 0,  0,  1, -1,  0,  0,  0, -1,  0] [ 6,  6,  0]  1 */
       12064, /* 61727 (1561) [ 0,  1,  0,  0,  0,  1,  1,  0,  0] [ 0,  0,  0]  1 */
    17131846, /* 61728 (1561) [ 0, -1,  0,  0,  0, -1,  1,  0,  0] [ 6,  0,  6]  1 */
    10818237, /* 61729 (1561) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 3,  9,  9]  1 */
     1538634, /* 61730 (1561) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
       16484, /* 61731 (1562) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    18439608, /* 61732 (1562) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
     1542946, /* 61733 (1562) [ 0, -1,  0,  0,  0,  1, -1,  0,  0] [ 0,  6,  6]  1 */
    17133082, /* 61734 (1562) [ 0,  0, -1, -1,  0,  0,  0,  1,  0] [ 6,  0,  6]  1 */
     9279715, /* 61735 (1562) [ 0,  0, -1,  0, -1,  0, -1,  0,  0] [ 3,  3,  3]  1 */
    61716703, /* 61736 (1562) [ 0,  0,  1,  0, -1,  0,  1,  0,  0] [ 9,  9,  3] -1 */
    27705767, /* 61737 (1562) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 9,  9,  3]  1 */
    17127410, /* 61738 (1562) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
    61722583, /* 61739 (1562) [ 1,  0,  0,  0,  0, -1,  0,  1,  0] [ 9,  9,  3] -1 */
     9278103, /* 61740 (1562) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 3,  3,  3]  1 */
    44828833, /* 61741 (1562) [ 0,  0,  1,  0,  1,  0, -1,  0,  0] [ 3,  9,  9] -1 */
    60415025, /* 61742 (1562) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 9,  3,  9] -1 */
    52447504, /* 61743 (1562) [ 0,  1,  0,  0,  0, -1, -1,  0,  0] [ 6,  6,  0] -1 */
    60416329, /* 61744 (1562) [ 0,  0, -1,  0,  1,  0,  1,  0,  0] [ 9,  3,  9] -1 */
    44834617, /* 61745 (1562) [ 1,  0,  0,  0,  0,  1,  0, -1,  0] [ 3,  9,  9] -1 */
    43286167, /* 61746 (1562) [-1,  0,  0,  0,  0, -1,  0, -1,  0] [ 3,  3,  3] -1 */
    35556850, /* 61747 (1562) [ 0,  0, -1,  1,  0,  0,  0, -1,  0] [ 0,  6,  6] -1 */
    34028708, /* 61748 (1562) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    60410437, /* 61749 (1562) [-1,  0,  0,  0,  0,  1,  0,  1,  0] [ 9,  3,  9] -1 */
    34023040, /* 61750 (1562) [ 0,  0,  1,  1,  0,  0,  0,  1,  0] [ 0,  0,  0] -1 */
    27704479, /* 61751 (1562) [ 0,  0,  1,  0, -1,  0,  1,  0,  0] [ 9,  9,  3]  1 */
    52445836, /* 61752 (1562) [ 0,  0,  1, -1,  0,  0,  0, -1,  0] [ 6,  6,  0] -1 */
    10816609, /* 61753 (1562) [ 0,  0,  1,  0,  1,  0, -1,  0,  0] [ 3,  9,  9]  1 */
    34024288, /* 61754 (1562) [ 0,  1,  0,  0,  0,  1,  1,  0,  0] [ 0,  0,  0] -1 */
    27710359, /* 61755 (1562) [ 1,  0,  0,  0,  0, -1,  0,  1,  0] [ 9,  9,  3]  1 */
    51144070, /* 61756 (1562) [ 0, -1,  0,  0,  0, -1,  1,  0,  0] [ 6,  0,  6] -1 */
    44830461, /* 61757 (1562) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 3,  9,  9] -1 */
    26402801, /* 61758 (1562) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 9,  3,  9]  1 */
    10822393, /* 61759 (1562) [ 1,  0,  0,  0,  0,  1,  0, -1,  0] [ 3,  9,  9]  1 */
    26404105, /* 61760 (1562) [ 0,  0, -1,  0,  1,  0,  1,  0,  0] [ 9,  3,  9]  1 */
    18435280, /* 61761 (1562) [ 0,  1,  0,  0,  0, -1, -1,  0,  0] [ 6,  6,  0]  1 */
    35550858, /* 61762 (1562) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6] -1 */
    52451832, /* 61763 (1562) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
     9273943, /* 61764 (1562) [-1,  0,  0,  0,  0, -1,  0, -1,  0] [ 3,  3,  3]  1 */
    51145306, /* 61765 (1562) [ 0,  0, -1, -1,  0,  0,  0,  1,  0] [ 6,  0,  6] -1 */
    26398213, /* 61766 (1562) [-1,  0,  0,  0,  0,  1,  0,  1,  0] [ 9,  3,  9]  1 */
     1544626, /* 61767 (1562) [ 0,  0, -1,  1,  0,  0,  0, -1,  0] [ 0,  6,  6]  1 */
       10816, /* 61768 (1562) [ 0,  0,  1,  1,  0,  0,  0,  1,  0] [ 0,  0,  0]  1 */
    61717991, /* 61769 (1562) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 9,  9,  3] -1 */
    43291939, /* 61770 (1562) [ 0,  0, -1,  0, -1,  0, -1,  0,  0] [ 3,  3,  3] -1 */
    18433612, /* 61771 (1562) [ 0,  0,  1, -1,  0,  0,  0, -1,  0] [ 6,  6,  0]  1 */
    35555170, /* 61772 (1562) [ 0, -1,  0,  0,  0,  1, -1,  0,  0] [ 0,  6,  6] -1 */
    51139634, /* 61773 (1562) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
       12064, /* 61774 (1562) [ 0,  1,  0,  0,  0,  1,  1,  0,  0] [ 0,  0,  0]  1 */
    17131846, /* 61775 (1562) [ 0, -1,  0,  0,  0, -1,  1,  0,  0] [ 6,  0,  6]  1 */
    43290327, /* 61776 (1562) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 3,  3,  3] -1 */
    10818237, /* 61777 (1562) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 3,  9,  9]  1 */
     1538634, /* 61778 (1562) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
       16484, /* 61779 (1563) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    18439608, /* 61780 (1563) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
     1542946, /* 61781 (1563) [ 0, -1,  0,  0,  0,  1, -1,  0,  0] [ 0,  6,  6]  1 */
    17133082, /* 61782 (1563) [ 0,  0, -1, -1,  0,  0,  0,  1,  0] [ 6,  0,  6]  1 */
    61716703, /* 61783 (1563) [ 0,  0,  1,  0, -1,  0,  1,  0,  0] [ 9,  9,  3] -1 */
    17127410, /* 61784 (1563) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
    61722583, /* 61785 (1563) [ 1,  0,  0,  0,  0, -1,  0,  1,  0] [ 9,  9,  3] -1 */
    44828833, /* 61786 (1563) [ 0,  0,  1,  0,  1,  0, -1,  0,  0] [ 3,  9,  9] -1 */
    60415025, /* 61787 (1563) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 9,  3,  9] -1 */
    60416329, /* 61788 (1563) [ 0,  0, -1,  0,  1,  0,  1,  0,  0] [ 9,  3,  9] -1 */
    44834617, /* 61789 (1563) [ 1,  0,  0,  0,  0,  1,  0, -1,  0] [ 3,  9,  9] -1 */
    43286167, /* 61790 (1563) [-1,  0,  0,  0,  0, -1,  0, -1,  0] [ 3,  3,  3] -1 */
    60410437, /* 61791 (1563) [-1,  0,  0,  0,  0,  1,  0,  1,  0] [ 9,  3,  9] -1 */
    44830461, /* 61792 (1563) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 3,  9,  9] -1 */
    18435280, /* 61793 (1563) [ 0,  1,  0,  0,  0, -1, -1,  0,  0] [ 6,  6,  0]  1 */
    43291939, /* 61794 (1563) [ 0,  0, -1,  0, -1,  0, -1,  0,  0] [ 3,  3,  3] -1 */
     1544626, /* 61795 (1563) [ 0,  0, -1,  1,  0,  0,  0, -1,  0] [ 0,  6,  6]  1 */
    61717991, /* 61796 (1563) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 9,  9,  3] -1 */
       10816, /* 61797 (1563) [ 0,  0,  1,  1,  0,  0,  0,  1,  0] [ 0,  0,  0]  1 */
    18433612, /* 61798 (1563) [ 0,  0,  1, -1,  0,  0,  0, -1,  0] [ 6,  6,  0]  1 */
       12064, /* 61799 (1563) [ 0,  1,  0,  0,  0,  1,  1,  0,  0] [ 0,  0,  0]  1 */
    17131846, /* 61800 (1563) [ 0, -1,  0,  0,  0, -1,  1,  0,  0] [ 6,  0,  6]  1 */
    43290327, /* 61801 (1563) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 3,  3,  3] -1 */
     1538634, /* 61802 (1563) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
       16484, /* 61803 (1564) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    18439608, /* 61804 (1564) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
    61827553, /* 61805 (1564) [-1,  0,  0,  0,  0, -1,  0, -1,  0] [ 9,  9,  9] -1 */
     1542946, /* 61806 (1564) [ 0, -1,  0,  0,  0,  1, -1,  0,  0] [ 0,  6,  6]  1 */
    17133082, /* 61807 (1564) [ 0,  0, -1, -1,  0,  0,  0,  1,  0] [ 6,  0,  6]  1 */
     9279715, /* 61808 (1564) [ 0,  0, -1,  0, -1,  0, -1,  0,  0] [ 3,  3,  3]  1 */
    51027688, /* 61809 (1564) [ 0,  0, -1,  1,  0,  0,  0, -1,  0] [ 6,  0,  0] -1 */
    27705767, /* 61810 (1564) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 9,  9,  3]  1 */
    17127410, /* 61811 (1564) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
    43417393, /* 61812 (1564) [ 1,  0,  0,  0,  0, -1,  0,  1,  0] [ 3,  3,  9] -1 */
    51021696, /* 61813 (1564) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  0] -1 */
    52570094, /* 61814 (1564) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    60299671, /* 61815 (1564) [ 0,  0,  1,  0,  1,  0, -1,  0,  0] [ 9,  3,  3] -1 */
    44707991, /* 61816 (1564) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 3,  9,  3] -1 */
     9278103, /* 61817 (1564) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 3,  3,  3]  1 */
    43411513, /* 61818 (1564) [ 0,  0,  1,  0, -1,  0,  1,  0,  0] [ 3,  3,  9] -1 */
    44703403, /* 61819 (1564) [-1,  0,  0,  0,  0,  1,  0,  1,  0] [ 3,  9,  3] -1 */
    44709295, /* 61820 (1564) [ 0,  0, -1,  0,  1,  0,  1,  0,  0] [ 3,  9,  3] -1 */
    61833325, /* 61821 (1564) [ 0,  0, -1,  0, -1,  0, -1,  0,  0] [ 9,  9,  9] -1 */
    35437036, /* 61822 (1564) [ 0, -1,  0,  0,  0, -1,  1,  0,  0] [ 0,  6,  0] -1 */
    51026008, /* 61823 (1564) [ 0, -1,  0,  0,  0,  1, -1,  0,  0] [ 6,  0,  0] -1 */
    34142314, /* 61824 (1564) [ 0,  1,  0,  0,  0, -1, -1,  0,  0] [ 0,  0,  6] -1 */
    61831713, /* 61825 (1564) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 9,  9,  9] -1 */
    27704479, /* 61826 (1564) [ 0,  0,  1,  0, -1,  0,  1,  0,  0] [ 9,  9,  3]  1 */
    52565674, /* 61827 (1564) [ 0,  1,  0,  0,  0,  1,  1,  0,  0] [ 6,  6,  6] -1 */
    60305455, /* 61828 (1564) [ 1,  0,  0,  0,  0,  1,  0, -1,  0] [ 9,  3,  3] -1 */
    52564426, /* 61829 (1564) [ 0,  0,  1,  1,  0,  0,  0,  1,  0] [ 6,  6,  6] -1 */
    10816609, /* 61830 (1564) [ 0,  0,  1,  0,  1,  0, -1,  0,  0] [ 3,  9,  9]  1 */
    34140646, /* 61831 (1564) [ 0,  0,  1, -1,  0,  0,  0, -1,  0] [ 0,  0,  6] -1 */
    27710359, /* 61832 (1564) [ 1,  0,  0,  0,  0, -1,  0,  1,  0] [ 9,  9,  3]  1 */
    35438272, /* 61833 (1564) [ 0,  0, -1, -1,  0,  0,  0,  1,  0] [ 0,  6,  0] -1 */
    26402801, /* 61834 (1564) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 9,  3,  9]  1 */
    34146642, /* 61835 (1564) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
    10822393, /* 61836 (1564) [ 1,  0,  0,  0,  0,  1,  0, -1,  0] [ 3,  9,  9]  1 */
    26404105, /* 61837 (1564) [ 0,  0, -1,  0,  1,  0,  1,  0,  0] [ 9,  3,  9]  1 */
    18435280, /* 61838 (1564) [ 0,  1,  0,  0,  0, -1, -1,  0,  0] [ 6,  6,  0]  1 */
     9273943, /* 61839 (1564) [-1,  0,  0,  0,  0, -1,  0, -1,  0] [ 3,  3,  3]  1 */
    26398213, /* 61840 (1564) [-1,  0,  0,  0,  0,  1,  0,  1,  0] [ 9,  3,  9]  1 */
     1544626, /* 61841 (1564) [ 0,  0, -1,  1,  0,  0,  0, -1,  0] [ 0,  6,  6]  1 */
       10816, /* 61842 (1564) [ 0,  0,  1,  1,  0,  0,  0,  1,  0] [ 0,  0,  0]  1 */
    60301299, /* 61843 (1564) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 9,  3,  3] -1 */
    18433612, /* 61844 (1564) [ 0,  0,  1, -1,  0,  0,  0, -1,  0] [ 6,  6,  0]  1 */
    35432600, /* 61845 (1564) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  0] -1 */
       12064, /* 61846 (1564) [ 0,  1,  0,  0,  0,  1,  1,  0,  0] [ 0,  0,  0]  1 */
    43412801, /* 61847 (1564) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 3,  3,  9] -1 */
    17131846, /* 61848 (1564) [ 0, -1,  0,  0,  0, -1,  1,  0,  0] [ 6,  0,  6]  1 */
    10818237, /* 61849 (1564) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 3,  9,  9]  1 */
     1538634, /* 61850 (1564) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
       16484, /* 61851 (1565) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    18439608, /* 61852 (1565) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
     1542946, /* 61853 (1565) [ 0, -1,  0,  0,  0,  1, -1,  0,  0] [ 0,  6,  6]  1 */
    26289075, /* 61854 (1565) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 9,  3,  3]  1 */
    17133082, /* 61855 (1565) [ 0,  0, -1, -1,  0,  0,  0,  1,  0] [ 6,  0,  6]  1 */
    17127410, /* 61856 (1565) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
     9400577, /* 61857 (1565) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 3,  3,  9]  1 */
    27815329, /* 61858 (1565) [-1,  0,  0,  0,  0, -1,  0, -1,  0] [ 9,  9,  9]  1 */
     9405169, /* 61859 (1565) [ 1,  0,  0,  0,  0, -1,  0,  1,  0] [ 3,  3,  9]  1 */
    26287447, /* 61860 (1565) [ 0,  0,  1,  0,  1,  0, -1,  0,  0] [ 9,  3,  3]  1 */
     9399289, /* 61861 (1565) [ 0,  0,  1,  0, -1,  0,  1,  0,  0] [ 3,  3,  9]  1 */
    10691179, /* 61862 (1565) [-1,  0,  0,  0,  0,  1,  0,  1,  0] [ 3,  9,  3]  1 */
    10695767, /* 61863 (1565) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 3,  9,  3]  1 */
    27821101, /* 61864 (1565) [ 0,  0, -1,  0, -1,  0, -1,  0,  0] [ 9,  9,  9]  1 */
    10697071, /* 61865 (1565) [ 0,  0, -1,  0,  1,  0,  1,  0,  0] [ 3,  9,  3]  1 */
    18435280, /* 61866 (1565) [ 0,  1,  0,  0,  0, -1, -1,  0,  0] [ 6,  6,  0]  1 */
     1544626, /* 61867 (1565) [ 0,  0, -1,  1,  0,  0,  0, -1,  0] [ 0,  6,  6]  1 */
    27819489, /* 61868 (1565) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 9,  9,  9]  1 */
       10816, /* 61869 (1565) [ 0,  0,  1,  1,  0,  0,  0,  1,  0] [ 0,  0,  0]  1 */
    18433612, /* 61870 (1565) [ 0,  0,  1, -1,  0,  0,  0, -1,  0] [ 6,  6,  0]  1 */
    26293231, /* 61871 (1565) [ 1,  0,  0,  0,  0,  1,  0, -1,  0] [ 9,  3,  3]  1 */
       12064, /* 61872 (1565) [ 0,  1,  0,  0,  0,  1,  1,  0,  0] [ 0,  0,  0]  1 */
    17131846, /* 61873 (1565) [ 0, -1,  0,  0,  0, -1,  1,  0,  0] [ 6,  0,  6]  1 */
     1538634, /* 61874 (1565) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
       16484, /* 61875 (1566) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    18439608, /* 61876 (1566) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
    61827553, /* 61877 (1566) [-1,  0,  0,  0,  0, -1,  0, -1,  0] [ 9,  9,  9] -1 */
     1542946, /* 61878 (1566) [ 0, -1,  0,  0,  0,  1, -1,  0,  0] [ 0,  6,  6]  1 */
    26289075, /* 61879 (1566) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 9,  3,  3]  1 */
    17133082, /* 61880 (1566) [ 0,  0, -1, -1,  0,  0,  0,  1,  0] [ 6,  0,  6]  1 */
    17127410, /* 61881 (1566) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
    43417393, /* 61882 (1566) [ 1,  0,  0,  0,  0, -1,  0,  1,  0] [ 3,  3,  9] -1 */
     9400577, /* 61883 (1566) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 3,  3,  9]  1 */
    60299671, /* 61884 (1566) [ 0,  0,  1,  0,  1,  0, -1,  0,  0] [ 9,  3,  3] -1 */
    44707991, /* 61885 (1566) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 3,  9,  3] -1 */
    43411513, /* 61886 (1566) [ 0,  0,  1,  0, -1,  0,  1,  0,  0] [ 3,  3,  9] -1 */
    44703403, /* 61887 (1566) [-1,  0,  0,  0,  0,  1,  0,  1,  0] [ 3,  9,  3] -1 */
    44709295, /* 61888 (1566) [ 0,  0, -1,  0,  1,  0,  1,  0,  0] [ 3,  9,  3] -1 */
    52447504, /* 61889 (1566) [ 0,  1,  0,  0,  0, -1, -1,  0,  0] [ 6,  6,  0] -1 */
    61833325, /* 61890 (1566) [ 0,  0, -1,  0, -1,  0, -1,  0,  0] [ 9,  9,  9] -1 */
    27815329, /* 61891 (1566) [-1,  0,  0,  0,  0, -1,  0, -1,  0] [ 9,  9,  9]  1 */
    35556850, /* 61892 (1566) [ 0,  0, -1,  1,  0,  0,  0, -1,  0] [ 0,  6,  6] -1 */
    34028708, /* 61893 (1566) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    61831713, /* 61894 (1566) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 9,  9,  9] -1 */
    34023040, /* 61895 (1566) [ 0,  0,  1,  1,  0,  0,  0,  1,  0] [ 0,  0,  0] -1 */
    60305455, /* 61896 (1566) [ 1,  0,  0,  0,  0,  1,  0, -1,  0] [ 9,  3,  3] -1 */
    52445836, /* 61897 (1566) [ 0,  0,  1, -1,  0,  0,  0, -1,  0] [ 6,  6,  0] -1 */
     9405169, /* 61898 (1566) [ 1,  0,  0,  0,  0, -1,  0,  1,  0] [ 3,  3,  9]  1 */
    26287447, /* 61899 (1566) [ 0,  0,  1,  0,  1,  0, -1,  0,  0] [ 9,  3,  3]  1 */
     9399289, /* 61900 (1566) [ 0,  0,  1,  0, -1,  0,  1,  0,  0] [ 3,  3,  9]  1 */
    34024288, /* 61901 (1566) [ 0,  1,  0,  0,  0,  1,  1,  0,  0] [ 0,  0,  0] -1 */
    10691179, /* 61902 (1566) [-1,  0,  0,  0,  0,  1,  0,  1,  0] [ 3,  9,  3]  1 */
    10695767, /* 61903 (1566) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 3,  9,  3]  1 */
    27821101, /* 61904 (1566) [ 0,  0, -1,  0, -1,  0, -1,  0,  0] [ 9,  9,  9]  1 */
    51144070, /* 61905 (1566) [ 0, -1,  0,  0,  0, -1,  1,  0,  0] [ 6,  0,  6] -1 */
    10697071, /* 61906 (1566) [ 0,  0, -1,  0,  1,  0,  1,  0,  0] [ 3,  9,  3]  1 */
    18435280, /* 61907 (1566) [ 0,  1,  0,  0,  0, -1, -1,  0,  0] [ 6,  6,  0]  1 */
    35550858, /* 61908 (1566) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6] -1 */
    52451832, /* 61909 (1566) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
    51145306, /* 61910 (1566) [ 0,  0, -1, -1,  0,  0,  0,  1,  0] [ 6,  0,  6] -1 */
     1544626, /* 61911 (1566) [ 0,  0, -1,  1,  0,  0,  0, -1,  0] [ 0,  6,  6]  1 */
    27819489, /* 61912 (1566) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 9,  9,  9]  1 */
       10816, /* 61913 (1566) [ 0,  0,  1,  1,  0,  0,  0,  1,  0] [ 0,  0,  0]  1 */
    35555170, /* 61914 (1566) [ 0, -1,  0,  0,  0,  1, -1,  0,  0] [ 0,  6,  6] -1 */
    60301299, /* 61915 (1566) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 9,  3,  3] -1 */
    18433612, /* 61916 (1566) [ 0,  0,  1, -1,  0,  0,  0, -1,  0] [ 6,  6,  0]  1 */
    26293231, /* 61917 (1566) [ 1,  0,  0,  0,  0,  1,  0, -1,  0] [ 9,  3,  3]  1 */
    51139634, /* 61918 (1566) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
       12064, /* 61919 (1566) [ 0,  1,  0,  0,  0,  1,  1,  0,  0] [ 0,  0,  0]  1 */
    43412801, /* 61920 (1566) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 3,  3,  9] -1 */
    17131846, /* 61921 (1566) [ 0, -1,  0,  0,  0, -1,  1,  0,  0] [ 6,  0,  6]  1 */
     1538634, /* 61922 (1566) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
       16484, /* 61923 (1567) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    18439608, /* 61924 (1567) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
    61827553, /* 61925 (1567) [-1,  0,  0,  0,  0, -1,  0, -1,  0] [ 9,  9,  9] -1 */
     1542946, /* 61926 (1567) [ 0, -1,  0,  0,  0,  1, -1,  0,  0] [ 0,  6,  6]  1 */
    17133082, /* 61927 (1567) [ 0,  0, -1, -1,  0,  0,  0,  1,  0] [ 6,  0,  6]  1 */
    17127410, /* 61928 (1567) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
    43417393, /* 61929 (1567) [ 1,  0,  0,  0,  0, -1,  0,  1,  0] [ 3,  3,  9] -1 */
    60299671, /* 61930 (1567) [ 0,  0,  1,  0,  1,  0, -1,  0,  0] [ 9,  3,  3] -1 */
    44707991, /* 61931 (1567) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 3,  9,  3] -1 */
    43411513, /* 61932 (1567) [ 0,  0,  1,  0, -1,  0,  1,  0,  0] [ 3,  3,  9] -1 */
    44703403, /* 61933 (1567) [-1,  0,  0,  0,  0,  1,  0,  1,  0] [ 3,  9,  3] -1 */
    44709295, /* 61934 (1567) [ 0,  0, -1,  0,  1,  0,  1,  0,  0] [ 3,  9,  3] -1 */
    61833325, /* 61935 (1567) [ 0,  0, -1,  0, -1,  0, -1,  0,  0] [ 9,  9,  9] -1 */
    61831713, /* 61936 (1567) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 9,  9,  9] -1 */
    60305455, /* 61937 (1567) [ 1,  0,  0,  0,  0,  1,  0, -1,  0] [ 9,  3,  3] -1 */
    18435280, /* 61938 (1567) [ 0,  1,  0,  0,  0, -1, -1,  0,  0] [ 6,  6,  0]  1 */
     1544626, /* 61939 (1567) [ 0,  0, -1,  1,  0,  0,  0, -1,  0] [ 0,  6,  6]  1 */
       10816, /* 61940 (1567) [ 0,  0,  1,  1,  0,  0,  0,  1,  0] [ 0,  0,  0]  1 */
    60301299, /* 61941 (1567) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 9,  3,  3] -1 */
    18433612, /* 61942 (1567) [ 0,  0,  1, -1,  0,  0,  0, -1,  0] [ 6,  6,  0]  1 */
       12064, /* 61943 (1567) [ 0,  1,  0,  0,  0,  1,  1,  0,  0] [ 0,  0,  0]  1 */
    43412801, /* 61944 (1567) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 3,  3,  9] -1 */
    17131846, /* 61945 (1567) [ 0, -1,  0,  0,  0, -1,  1,  0,  0] [ 6,  0,  6]  1 */
     1538634, /* 61946 (1567) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
       16484, /* 61947 (1568) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    18439608, /* 61948 (1568) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
     1542946, /* 61949 (1568) [ 0, -1,  0,  0,  0,  1, -1,  0,  0] [ 0,  6,  6]  1 */
    26289075, /* 61950 (1568) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 9,  3,  3]  1 */
    17133082, /* 61951 (1568) [ 0,  0, -1, -1,  0,  0,  0,  1,  0] [ 6,  0,  6]  1 */
    51027688, /* 61952 (1568) [ 0,  0, -1,  1,  0,  0,  0, -1,  0] [ 6,  0,  0] -1 */
    61716703, /* 61953 (1568) [ 0,  0,  1,  0, -1,  0,  1,  0,  0] [ 9,  9,  3] -1 */
    17127410, /* 61954 (1568) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
    51021696, /* 61955 (1568) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  0] -1 */
     9400577, /* 61956 (1568) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 3,  3,  9]  1 */
    52570094, /* 61957 (1568) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    61722583, /* 61958 (1568) [ 1,  0,  0,  0,  0, -1,  0,  1,  0] [ 9,  9,  3] -1 */
    44828833, /* 61959 (1568) [ 0,  0,  1,  0,  1,  0, -1,  0,  0] [ 3,  9,  9] -1 */
    60415025, /* 61960 (1568) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 9,  3,  9] -1 */
    60416329, /* 61961 (1568) [ 0,  0, -1,  0,  1,  0,  1,  0,  0] [ 9,  3,  9] -1 */
    44834617, /* 61962 (1568) [ 1,  0,  0,  0,  0,  1,  0, -1,  0] [ 3,  9,  9] -1 */
    27815329, /* 61963 (1568) [-1,  0,  0,  0,  0, -1,  0, -1,  0] [ 9,  9,  9]  1 */
    43286167, /* 61964 (1568) [-1,  0,  0,  0,  0, -1,  0, -1,  0] [ 3,  3,  3] -1 */
    35437036, /* 61965 (1568) [ 0, -1,  0,  0,  0, -1,  1,  0,  0] [ 0,  6,  0] -1 */
    51026008, /* 61966 (1568) [ 0, -1,  0,  0,  0,  1, -1,  0,  0] [ 6,  0,  0] -1 */
    34142314, /* 61967 (1568) [ 0,  1,  0,  0,  0, -1, -1,  0,  0] [ 0,  0,  6] -1 */
    60410437, /* 61968 (1568) [-1,  0,  0,  0,  0,  1,  0,  1,  0] [ 9,  3,  9] -1 */
    52565674, /* 61969 (1568) [ 0,  1,  0,  0,  0,  1,  1,  0,  0] [ 6,  6,  6] -1 */
     9405169, /* 61970 (1568) [ 1,  0,  0,  0,  0, -1,  0,  1,  0] [ 3,  3,  9]  1 */
    26287447, /* 61971 (1568) [ 0,  0,  1,  0,  1,  0, -1,  0,  0] [ 9,  3,  3]  1 */
     9399289, /* 61972 (1568) [ 0,  0,  1,  0, -1,  0,  1,  0,  0] [ 3,  3,  9]  1 */
    52564426, /* 61973 (1568) [ 0,  0,  1,  1,  0,  0,  0,  1,  0] [ 6,  6,  6] -1 */
    34140646, /* 61974 (1568) [ 0,  0,  1, -1,  0,  0,  0, -1,  0] [ 0,  0,  6] -1 */
    35438272, /* 61975 (1568) [ 0,  0, -1, -1,  0,  0,  0,  1,  0] [ 0,  6,  0] -1 */
    10691179, /* 61976 (1568) [-1,  0,  0,  0,  0,  1,  0,  1,  0] [ 3,  9,  3]  1 */
    10695767, /* 61977 (1568) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 3,  9,  3]  1 */
    44830461, /* 61978 (1568) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 3,  9,  9] -1 */
    27821101, /* 61979 (1568) [ 0,  0, -1,  0, -1,  0, -1,  0,  0] [ 9,  9,  9]  1 */
    10697071, /* 61980 (1568) [ 0,  0, -1,  0,  1,  0,  1,  0,  0] [ 3,  9,  3]  1 */
    34146642, /* 61981 (1568) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
    18435280, /* 61982 (1568) [ 0,  1,  0,  0,  0, -1, -1,  0,  0] [ 6,  6,  0]  1 */
    43291939, /* 61983 (1568) [ 0,  0, -1,  0, -1,  0, -1,  0,  0] [ 3,  3,  3] -1 */
     1544626, /* 61984 (1568) [ 0,  0, -1,  1,  0,  0,  0, -1,  0] [ 0,  6,  6]  1 */
    27819489, /* 61985 (1568) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 9,  9,  9]  1 */
       10816, /* 61986 (1568) [ 0,  0,  1,  1,  0,  0,  0,  1,  0] [ 0,  0,  0]  1 */
    61717991, /* 61987 (1568) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 9,  9,  3] -1 */
    18433612, /* 61988 (1568) [ 0,  0,  1, -1,  0,  0,  0, -1,  0] [ 6,  6,  0]  1 */
    35432600, /* 61989 (1568) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  0] -1 */
    26293231, /* 61990 (1568) [ 1,  0,  0,  0,  0,  1,  0, -1,  0] [ 9,  3,  3]  1 */
       12064, /* 61991 (1568) [ 0,  1,  0,  0,  0,  1,  1,  0,  0] [ 0,  0,  0]  1 */
    17131846, /* 61992 (1568) [ 0, -1,  0,  0,  0, -1,  1,  0,  0] [ 6,  0,  6]  1 */
    43290327, /* 61993 (1568) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 3,  3,  3] -1 */
     1538634, /* 61994 (1568) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
       16484, /* 61995 (1569) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
      134418, /* 61996 (1569) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  6]  1 */
    18439608, /* 61997 (1569) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
     1542946, /* 61998 (1569) [ 0, -1,  0,  0,  0,  1, -1,  0,  0] [ 0,  6,  6]  1 */
    26289075, /* 61999 (1569) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 9,  3,  3]  1 */
    17133082, /* 62000 (1569) [ 0,  0, -1, -1,  0,  0,  0,  1,  0] [ 6,  0,  6]  1 */
     9279715, /* 62001 (1569) [ 0,  0, -1,  0, -1,  0, -1,  0,  0] [ 3,  3,  3]  1 */
    27705767, /* 62002 (1569) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 9,  9,  3]  1 */
     1420376, /* 62003 (1569) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  0]  1 */
    17127410, /* 62004 (1569) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
     9400577, /* 62005 (1569) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 3,  3,  9]  1 */
     9278103, /* 62006 (1569) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 3,  3,  3]  1 */
    27815329, /* 62007 (1569) [-1,  0,  0,  0,  0, -1,  0, -1,  0] [ 9,  9,  9]  1 */
    17015464, /* 62008 (1569) [ 0,  0, -1,  1,  0,  0,  0, -1,  0] [ 6,  0,  0]  1 */
    27704479, /* 62009 (1569) [ 0,  0,  1,  0, -1,  0,  1,  0,  0] [ 9,  9,  3]  1 */
    18557870, /* 62010 (1569) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
     9405169, /* 62011 (1569) [ 1,  0,  0,  0,  0, -1,  0,  1,  0] [ 3,  3,  9]  1 */
    17009472, /* 62012 (1569) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  0]  1 */
    26287447, /* 62013 (1569) [ 0,  0,  1,  0,  1,  0, -1,  0,  0] [ 9,  3,  3]  1 */
     9399289, /* 62014 (1569) [ 0,  0,  1,  0, -1,  0,  1,  0,  0] [ 3,  3,  9]  1 */
    10816609, /* 62015 (1569) [ 0,  0,  1,  0,  1,  0, -1,  0,  0] [ 3,  9,  9]  1 */
    27710359, /* 62016 (1569) [ 1,  0,  0,  0,  0, -1,  0,  1,  0] [ 9,  9,  3]  1 */
    10691179, /* 62017 (1569) [-1,  0,  0,  0,  0,  1,  0,  1,  0] [ 3,  9,  3]  1 */
    10695767, /* 62018 (1569) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 3,  9,  3]  1 */
    27821101, /* 62019 (1569) [ 0,  0, -1,  0, -1,  0, -1,  0,  0] [ 9,  9,  9]  1 */
    26402801, /* 62020 (1569) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 9,  3,  9]  1 */
    10697071, /* 62021 (1569) [ 0,  0, -1,  0,  1,  0,  1,  0,  0] [ 3,  9,  3]  1 */
    10822393, /* 62022 (1569) [ 1,  0,  0,  0,  0,  1,  0, -1,  0] [ 3,  9,  9]  1 */
    26404105, /* 62023 (1569) [ 0,  0, -1,  0,  1,  0,  1,  0,  0] [ 9,  3,  9]  1 */
    18435280, /* 62024 (1569) [ 0,  1,  0,  0,  0, -1, -1,  0,  0] [ 6,  6,  0]  1 */
     9273943, /* 62025 (1569) [-1,  0,  0,  0,  0, -1,  0, -1,  0] [ 3,  3,  3]  1 */
    26398213, /* 62026 (1569) [-1,  0,  0,  0,  0,  1,  0,  1,  0] [ 9,  3,  9]  1 */
    27819489, /* 62027 (1569) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 9,  9,  9]  1 */
       10816, /* 62028 (1569) [ 0,  0,  1,  1,  0,  0,  0,  1,  0] [ 0,  0,  0]  1 */
     1544626, /* 62029 (1569) [ 0,  0, -1,  1,  0,  0,  0, -1,  0] [ 0,  6,  6]  1 */
      130090, /* 62030 (1569) [ 0,  1,  0,  0,  0, -1, -1,  0,  0] [ 0,  0,  6]  1 */
    18433612, /* 62031 (1569) [ 0,  0,  1, -1,  0,  0,  0, -1,  0] [ 6,  6,  0]  1 */
    17013784, /* 62032 (1569) [ 0, -1,  0,  0,  0,  1, -1,  0,  0] [ 6,  0,  0]  1 */
     1424812, /* 62033 (1569) [ 0, -1,  0,  0,  0, -1,  1,  0,  0] [ 0,  6,  0]  1 */
    18553450, /* 62034 (1569) [ 0,  1,  0,  0,  0,  1,  1,  0,  0] [ 6,  6,  6]  1 */
    26293231, /* 62035 (1569) [ 1,  0,  0,  0,  0,  1,  0, -1,  0] [ 9,  3,  3]  1 */
    18552202, /* 62036 (1569) [ 0,  0,  1,  1,  0,  0,  0,  1,  0] [ 6,  6,  6]  1 */
       12064, /* 62037 (1569) [ 0,  1,  0,  0,  0,  1,  1,  0,  0] [ 0,  0,  0]  1 */
    17131846, /* 62038 (1569) [ 0, -1,  0,  0,  0, -1,  1,  0,  0] [ 6,  0,  6]  1 */
      128422, /* 62039 (1569) [ 0,  0,  1, -1,  0,  0,  0, -1,  0] [ 0,  0,  6]  1 */
     1426048, /* 62040 (1569) [ 0,  0, -1, -1,  0,  0,  0,  1,  0] [ 0,  6,  0]  1 */
    10818237, /* 62041 (1569) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 3,  9,  9]  1 */
     1538634, /* 62042 (1569) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
       16484, /* 62043 (1570) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
      134418, /* 62044 (1570) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  6]  1 */
    61716703, /* 62045 (1570) [ 0,  0,  1,  0, -1,  0,  1,  0,  0] [ 9,  9,  3] -1 */
     1420376, /* 62046 (1570) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  0]  1 */
    44828833, /* 62047 (1570) [ 0,  0,  1,  0,  1,  0, -1,  0,  0] [ 3,  9,  9] -1 */
    60415025, /* 62048 (1570) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 9,  3,  9] -1 */
    61831713, /* 62049 (1570) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 9,  9,  9] -1 */
    34023040, /* 62050 (1570) [ 0,  0,  1,  1,  0,  0,  0,  1,  0] [ 0,  0,  0] -1 */
    18557870, /* 62051 (1570) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
     9405169, /* 62052 (1570) [ 1,  0,  0,  0,  0, -1,  0,  1,  0] [ 3,  3,  9]  1 */
     9399289, /* 62053 (1570) [ 0,  0,  1,  0, -1,  0,  1,  0,  0] [ 3,  3,  9]  1 */
    34024288, /* 62054 (1570) [ 0,  1,  0,  0,  0,  1,  1,  0,  0] [ 0,  0,  0] -1 */
    10691179, /* 62055 (1570) [-1,  0,  0,  0,  0,  1,  0,  1,  0] [ 3,  9,  3]  1 */
    27821101, /* 62056 (1570) [ 0,  0, -1,  0, -1,  0, -1,  0,  0] [ 9,  9,  9]  1 */
    10697071, /* 62057 (1570) [ 0,  0, -1,  0,  1,  0,  1,  0,  0] [ 3,  9,  3]  1 */
    43291939, /* 62058 (1570) [ 0,  0, -1,  0, -1,  0, -1,  0,  0] [ 3,  3,  3] -1 */
      130090, /* 62059 (1570) [ 0,  1,  0,  0,  0, -1, -1,  0,  0] [ 0,  0,  6]  1 */
    26398213, /* 62060 (1570) [-1,  0,  0,  0,  0,  1,  0,  1,  0] [ 9,  3,  9]  1 */
     1424812, /* 62061 (1570) [ 0, -1,  0,  0,  0, -1,  1,  0,  0] [ 0,  6,  0]  1 */
    61717991, /* 62062 (1570) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 9,  9,  3] -1 */
    35555170, /* 62063 (1570) [ 0, -1,  0,  0,  0,  1, -1,  0,  0] [ 0,  6,  6] -1 */
    18433612, /* 62064 (1570) [ 0,  0,  1, -1,  0,  0,  0, -1,  0] [ 6,  6,  0]  1 */
    18552202, /* 62065 (1570) [ 0,  0,  1,  1,  0,  0,  0,  1,  0] [ 6,  6,  6]  1 */
    17131846, /* 62066 (1570) [ 0, -1,  0,  0,  0, -1,  1,  0,  0] [ 6,  0,  6]  1 */
      128422, /* 62067 (1570) [ 0,  0,  1, -1,  0,  0,  0, -1,  0] [ 0,  0,  6]  1 */
    43290327, /* 62068 (1570) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 3,  3,  3] -1 */
     1538634, /* 62069 (1570) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
    61827553, /* 62070 (1570) [-1,  0,  0,  0,  0, -1,  0, -1,  0] [ 9,  9,  9] -1 */
    51027688, /* 62071 (1570) [ 0,  0, -1,  1,  0,  0,  0, -1,  0] [ 6,  0,  0] -1 */
     9400577, /* 62072 (1570) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 3,  3,  9]  1 */
    61722583, /* 62073 (1570) [ 1,  0,  0,  0,  0, -1,  0,  1,  0] [ 9,  9,  3] -1 */
    43286167, /* 62074 (1570) [-1,  0,  0,  0,  0, -1,  0, -1,  0] [ 3,  3,  3] -1 */
    35556850, /* 62075 (1570) [ 0,  0, -1,  1,  0,  0,  0, -1,  0] [ 0,  6,  6] -1 */
    34028708, /* 62076 (1570) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    17009472, /* 62077 (1570) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  0]  1 */
    10816609, /* 62078 (1570) [ 0,  0,  1,  0,  1,  0, -1,  0,  0] [ 3,  9,  9]  1 */
    10695767, /* 62079 (1570) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 3,  9,  3]  1 */
    34146642, /* 62080 (1570) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
    26404105, /* 62081 (1570) [ 0,  0, -1,  0,  1,  0,  1,  0,  0] [ 9,  3,  9]  1 */
    18435280, /* 62082 (1570) [ 0,  1,  0,  0,  0, -1, -1,  0,  0] [ 6,  6,  0]  1 */
    52451832, /* 62083 (1570) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
    27819489, /* 62084 (1570) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 9,  9,  9]  1 */
       10816, /* 62085 (1570) [ 0,  0,  1,  1,  0,  0,  0,  1,  0] [ 0,  0,  0]  1 */
    17013784, /* 62086 (1570) [ 0, -1,  0,  0,  0,  1, -1,  0,  0] [ 6,  0,  0]  1 */
    60301299, /* 62087 (1570) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 9,  3,  3] -1 */
    18553450, /* 62088 (1570) [ 0,  1,  0,  0,  0,  1,  1,  0,  0] [ 6,  6,  6]  1 */
    26293231, /* 62089 (1570) [ 1,  0,  0,  0,  0,  1,  0, -1,  0] [ 9,  3,  3]  1 */
    51139634, /* 62090 (1570) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
       12064, /* 62091 (1570) [ 0,  1,  0,  0,  0,  1,  1,  0,  0] [ 0,  0,  0]  1 */
     1426048, /* 62092 (1570) [ 0,  0, -1, -1,  0,  0,  0,  1,  0] [ 0,  6,  0]  1 */
    10818237, /* 62093 (1570) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 3,  9,  9]  1 */
     1542946, /* 62094 (1570) [ 0, -1,  0,  0,  0,  1, -1,  0,  0] [ 0,  6,  6]  1 */
    17133082, /* 62095 (1570) [ 0,  0, -1, -1,  0,  0,  0,  1,  0] [ 6,  0,  6]  1 */
    43417393, /* 62096 (1570) [ 1,  0,  0,  0,  0, -1,  0,  1,  0] [ 3,  3,  9] -1 */
    60299671, /* 62097 (1570) [ 0,  0,  1,  0,  1,  0, -1,  0,  0] [ 9,  3,  3] -1 */
     9278103, /* 62098 (1570) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 3,  3,  3]  1 */
    44709295, /* 62099 (1570) [ 0,  0, -1,  0,  1,  0,  1,  0,  0] [ 3,  9,  3] -1 */
    44834617, /* 62100 (1570) [ 1,  0,  0,  0,  0,  1,  0, -1,  0] [ 3,  9,  9] -1 */
    27815329, /* 62101 (1570) [-1,  0,  0,  0,  0, -1,  0, -1,  0] [ 9,  9,  9]  1 */
    17015464, /* 62102 (1570) [ 0,  0, -1,  1,  0,  0,  0, -1,  0] [ 6,  0,  0]  1 */
    35437036, /* 62103 (1570) [ 0, -1,  0,  0,  0, -1,  1,  0,  0] [ 0,  6,  0] -1 */
    27704479, /* 62104 (1570) [ 0,  0,  1,  0, -1,  0,  1,  0,  0] [ 9,  9,  3]  1 */
    34140646, /* 62105 (1570) [ 0,  0,  1, -1,  0,  0,  0, -1,  0] [ 0,  0,  6] -1 */
    26402801, /* 62106 (1570) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 9,  3,  9]  1 */
    35432600, /* 62107 (1570) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  0] -1 */
    18439608, /* 62108 (1570) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
    26289075, /* 62109 (1570) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 9,  3,  3]  1 */
     9279715, /* 62110 (1570) [ 0,  0, -1,  0, -1,  0, -1,  0,  0] [ 3,  3,  3]  1 */
    27705767, /* 62111 (1570) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 9,  9,  3]  1 */
    17127410, /* 62112 (1570) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
    51021696, /* 62113 (1570) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  0] -1 */
    52570094, /* 62114 (1570) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    44707991, /* 62115 (1570) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 3,  9,  3] -1 */
    43411513, /* 62116 (1570) [ 0,  0,  1,  0, -1,  0,  1,  0,  0] [ 3,  3,  9] -1 */
    44703403, /* 62117 (1570) [-1,  0,  0,  0,  0,  1,  0,  1,  0] [ 3,  9,  3] -1 */
    61833325, /* 62118 (1570) [ 0,  0, -1,  0, -1,  0, -1,  0,  0] [ 9,  9,  9] -1 */
    52447504, /* 62119 (1570) [ 0,  1,  0,  0,  0, -1, -1,  0,  0] [ 6,  6,  0] -1 */
    60416329, /* 62120 (1570) [ 0,  0, -1,  0,  1,  0,  1,  0,  0] [ 9,  3,  9] -1 */
    51026008, /* 62121 (1570) [ 0, -1,  0,  0,  0,  1, -1,  0,  0] [ 6,  0,  0] -1 */
    34142314, /* 62122 (1570) [ 0,  1,  0,  0,  0, -1, -1,  0,  0] [ 0,  0,  6] -1 */
    60410437, /* 62123 (1570) [-1,  0,  0,  0,  0,  1,  0,  1,  0] [ 9,  3,  9] -1 */
    52565674, /* 62124 (1570) [ 0,  1,  0,  0,  0,  1,  1,  0,  0] [ 6,  6,  6] -1 */
    60305455, /* 62125 (1570) [ 1,  0,  0,  0,  0,  1,  0, -1,  0] [ 9,  3,  3] -1 */
    52445836, /* 62126 (1570) [ 0,  0,  1, -1,  0,  0,  0, -1,  0] [ 6,  6,  0] -1 */
    26287447, /* 62127 (1570) [ 0,  0,  1,  0,  1,  0, -1,  0,  0] [ 9,  3,  3]  1 */
    52564426, /* 62128 (1570) [ 0,  0,  1,  1,  0,  0,  0,  1,  0] [ 6,  6,  6] -1 */
    35438272, /* 62129 (1570) [ 0,  0, -1, -1,  0,  0,  0,  1,  0] [ 0,  6,  0] -1 */
    27710359, /* 62130 (1570) [ 1,  0,  0,  0,  0, -1,  0,  1,  0] [ 9,  9,  3]  1 */
    51144070, /* 62131 (1570) [ 0, -1,  0,  0,  0, -1,  1,  0,  0] [ 6,  0,  6] -1 */
    44830461, /* 62132 (1570) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 3,  9,  9] -1 */
    10822393, /* 62133 (1570) [ 1,  0,  0,  0,  0,  1,  0, -1,  0] [ 3,  9,  9]  1 */
    35550858, /* 62134 (1570) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6] -1 */
     9273943, /* 62135 (1570) [-1,  0,  0,  0,  0, -1,  0, -1,  0] [ 3,  3,  3]  1 */
    51145306, /* 62136 (1570) [ 0,  0, -1, -1,  0,  0,  0,  1,  0] [ 6,  0,  6] -1 */
     1544626, /* 62137 (1570) [ 0,  0, -1,  1,  0,  0,  0, -1,  0] [ 0,  6,  6]  1 */
    43412801, /* 62138 (1570) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 3,  3,  9] -1 */
       16484, /* 62139 (1571) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
      134418, /* 62140 (1571) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  6]  1 */
    18439608, /* 62141 (1571) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
    61827553, /* 62142 (1571) [-1,  0,  0,  0,  0, -1,  0, -1,  0] [ 9,  9,  9] -1 */
     1542946, /* 62143 (1571) [ 0, -1,  0,  0,  0,  1, -1,  0,  0] [ 0,  6,  6]  1 */
    17133082, /* 62144 (1571) [ 0,  0, -1, -1,  0,  0,  0,  1,  0] [ 6,  0,  6]  1 */
    61716703, /* 62145 (1571) [ 0,  0,  1,  0, -1,  0,  1,  0,  0] [ 9,  9,  3] -1 */
     1420376, /* 62146 (1571) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  0]  1 */
    17127410, /* 62147 (1571) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
    43417393, /* 62148 (1571) [ 1,  0,  0,  0,  0, -1,  0,  1,  0] [ 3,  3,  9] -1 */
    61722583, /* 62149 (1571) [ 1,  0,  0,  0,  0, -1,  0,  1,  0] [ 9,  9,  3] -1 */
    60299671, /* 62150 (1571) [ 0,  0,  1,  0,  1,  0, -1,  0,  0] [ 9,  3,  3] -1 */
    44707991, /* 62151 (1571) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 3,  9,  3] -1 */
    43411513, /* 62152 (1571) [ 0,  0,  1,  0, -1,  0,  1,  0,  0] [ 3,  3,  9] -1 */
    44828833, /* 62153 (1571) [ 0,  0,  1,  0,  1,  0, -1,  0,  0] [ 3,  9,  9] -1 */
    60415025, /* 62154 (1571) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 9,  3,  9] -1 */
    44703403, /* 62155 (1571) [-1,  0,  0,  0,  0,  1,  0,  1,  0] [ 3,  9,  3] -1 */
    44709295, /* 62156 (1571) [ 0,  0, -1,  0,  1,  0,  1,  0,  0] [ 3,  9,  3] -1 */
    61833325, /* 62157 (1571) [ 0,  0, -1,  0, -1,  0, -1,  0,  0] [ 9,  9,  9] -1 */
    60416329, /* 62158 (1571) [ 0,  0, -1,  0,  1,  0,  1,  0,  0] [ 9,  3,  9] -1 */
    44834617, /* 62159 (1571) [ 1,  0,  0,  0,  0,  1,  0, -1,  0] [ 3,  9,  9] -1 */
    43286167, /* 62160 (1571) [-1,  0,  0,  0,  0, -1,  0, -1,  0] [ 3,  3,  3] -1 */
    17015464, /* 62161 (1571) [ 0,  0, -1,  1,  0,  0,  0, -1,  0] [ 6,  0,  0]  1 */
    60410437, /* 62162 (1571) [-1,  0,  0,  0,  0,  1,  0,  1,  0] [ 9,  3,  9] -1 */
    61831713, /* 62163 (1571) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 9,  9,  9] -1 */
    60305455, /* 62164 (1571) [ 1,  0,  0,  0,  0,  1,  0, -1,  0] [ 9,  3,  3] -1 */
    18557870, /* 62165 (1571) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    17009472, /* 62166 (1571) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  0]  1 */
    44830461, /* 62167 (1571) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 3,  9,  9] -1 */
    18435280, /* 62168 (1571) [ 0,  1,  0,  0,  0, -1, -1,  0,  0] [ 6,  6,  0]  1 */
    43291939, /* 62169 (1571) [ 0,  0, -1,  0, -1,  0, -1,  0,  0] [ 3,  3,  3] -1 */
     1544626, /* 62170 (1571) [ 0,  0, -1,  1,  0,  0,  0, -1,  0] [ 0,  6,  6]  1 */
      130090, /* 62171 (1571) [ 0,  1,  0,  0,  0, -1, -1,  0,  0] [ 0,  0,  6]  1 */
       10816, /* 62172 (1571) [ 0,  0,  1,  1,  0,  0,  0,  1,  0] [ 0,  0,  0]  1 */
    17013784, /* 62173 (1571) [ 0, -1,  0,  0,  0,  1, -1,  0,  0] [ 6,  0,  0]  1 */
    60301299, /* 62174 (1571) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 9,  3,  3] -1 */
    18433612, /* 62175 (1571) [ 0,  0,  1, -1,  0,  0,  0, -1,  0] [ 6,  6,  0]  1 */
     1424812, /* 62176 (1571) [ 0, -1,  0,  0,  0, -1,  1,  0,  0] [ 0,  6,  0]  1 */
    61717991, /* 62177 (1571) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 9,  9,  3] -1 */
    18553450, /* 62178 (1571) [ 0,  1,  0,  0,  0,  1,  1,  0,  0] [ 6,  6,  6]  1 */
    18552202, /* 62179 (1571) [ 0,  0,  1,  1,  0,  0,  0,  1,  0] [ 6,  6,  6]  1 */
       12064, /* 62180 (1571) [ 0,  1,  0,  0,  0,  1,  1,  0,  0] [ 0,  0,  0]  1 */
    43412801, /* 62181 (1571) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 3,  3,  9] -1 */
    17131846, /* 62182 (1571) [ 0, -1,  0,  0,  0, -1,  1,  0,  0] [ 6,  0,  6]  1 */
      128422, /* 62183 (1571) [ 0,  0,  1, -1,  0,  0,  0, -1,  0] [ 0,  0,  6]  1 */
     1426048, /* 62184 (1571) [ 0,  0, -1, -1,  0,  0,  0,  1,  0] [ 0,  6,  0]  1 */
    43290327, /* 62185 (1571) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 3,  3,  3] -1 */
     1538634, /* 62186 (1571) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
       16484, /* 62187 (1572) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
       10660, /* 62188 (1572) [ 0,  0,  1,  0,  1,  0,  1,  0,  0] [ 0,  0,  0]  1 */
       16320, /* 62189 (1572) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
       16432, /* 62190 (1572) [ 1,  0,  0,  0,  0,  1,  0,  1,  0] [ 0,  0,  0]  1 */
        9040, /* 62191 (1572) [ 0,  0, -1,  0, -1,  0,  1,  0,  0] [ 0,  0,  0]  1 */
        3256, /* 62192 (1572) [-1,  0,  0,  0,  0, -1,  0,  1,  0] [ 0,  0,  0]  1 */
        9184, /* 62193 (1572) [ 0,  0, -1,  0,  1,  0, -1,  0,  0] [ 0,  0,  0]  1 */
        7636, /* 62194 (1572) [ 0, -1,  0,  0,  0, -1,  1,  0,  0] [ 0,  0,  0]  1 */
        9352, /* 62195 (1572) [ 0,  0, -1,  1,  0,  0,  0, -1,  0] [ 0,  0,  0]  1 */
        8872, /* 62196 (1572) [ 0,  0, -1, -1,  0,  0,  0,  1,  0] [ 0,  0,  0]  1 */
       10480, /* 62197 (1572) [ 0,  0,  1,  0, -1,  0, -1,  0,  0] [ 0,  0,  0]  1 */
       11784, /* 62198 (1572) [ 0,  1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  0]  1 */
        7896, /* 62199 (1572) [ 0, -1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  0]  1 */
       16372, /* 62200 (1572) [ 1,  0,  0,  0,  0, -1,  0, -1,  0] [ 0,  0,  0]  1 */
        7672, /* 62201 (1572) [ 0, -1,  0,  0,  0,  1, -1,  0,  0] [ 0,  0,  0]  1 */
        3360, /* 62202 (1572) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
       10816, /* 62203 (1572) [ 0,  0,  1,  1,  0,  0,  0,  1,  0] [ 0,  0,  0]  1 */
        3200, /* 62204 (1572) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
       12272, /* 62205 (1572) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 0,  0,  0]  1 */
       11992, /* 62206 (1572) [ 0,  1,  0,  0,  0, -1, -1,  0,  0] [ 0,  0,  0]  1 */
        7412, /* 62207 (1572) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  0]  1 */
       12064, /* 62208 (1572) [ 0,  1,  0,  0,  0,  1,  1,  0,  0] [ 0,  0,  0]  1 */
        3304, /* 62209 (1572) [-1,  0,  0,  0,  0,  1,  0, -1,  0] [ 0,  0,  0]  1 */
       10324, /* 62210 (1572) [ 0,  0,  1, -1,  0,  0,  0, -1,  0] [ 0,  0,  0]  1 */
       16484, /* 62211 (1573) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34021408, /* 62212 (1573) [ 0,  0, -1,  0,  1,  0, -1,  0,  0] [ 0,  0,  0] -1 */
       10660, /* 62213 (1573) [ 0,  0,  1,  0,  1,  0,  1,  0,  0] [ 0,  0,  0]  1 */
    34019860, /* 62214 (1573) [ 0, -1,  0,  0,  0, -1,  1,  0,  0] [ 0,  0,  0] -1 */
       16320, /* 62215 (1573) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    34021576, /* 62216 (1573) [ 0,  0, -1,  1,  0,  0,  0, -1,  0] [ 0,  0,  0] -1 */
       16432, /* 62217 (1573) [ 1,  0,  0,  0,  0,  1,  0,  1,  0] [ 0,  0,  0]  1 */
    34021096, /* 62218 (1573) [ 0,  0, -1, -1,  0,  0,  0,  1,  0] [ 0,  0,  0] -1 */
    34022704, /* 62219 (1573) [ 0,  0,  1,  0, -1,  0, -1,  0,  0] [ 0,  0,  0] -1 */
        9040, /* 62220 (1573) [ 0,  0, -1,  0, -1,  0,  1,  0,  0] [ 0,  0,  0]  1 */
    34024008, /* 62221 (1573) [ 0,  1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  0] -1 */
        3256, /* 62222 (1573) [-1,  0,  0,  0,  0, -1,  0,  1,  0] [ 0,  0,  0]  1 */
    34020120, /* 62223 (1573) [ 0, -1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    34019896, /* 62224 (1573) [ 0, -1,  0,  0,  0,  1, -1,  0,  0] [ 0,  0,  0] -1 */
        9184, /* 62225 (1573) [ 0,  0, -1,  0,  1,  0, -1,  0,  0] [ 0,  0,  0]  1 */
    34028596, /* 62226 (1573) [ 1,  0,  0,  0,  0, -1,  0, -1,  0] [ 0,  0,  0] -1 */
    34015584, /* 62227 (1573) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
        7636, /* 62228 (1573) [ 0, -1,  0,  0,  0, -1,  1,  0,  0] [ 0,  0,  0]  1 */
        9352, /* 62229 (1573) [ 0,  0, -1,  1,  0,  0,  0, -1,  0] [ 0,  0,  0]  1 */
    34015424, /* 62230 (1573) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    34028708, /* 62231 (1573) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    34024496, /* 62232 (1573) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    34023040, /* 62233 (1573) [ 0,  0,  1,  1,  0,  0,  0,  1,  0] [ 0,  0,  0] -1 */
    34024216, /* 62234 (1573) [ 0,  1,  0,  0,  0, -1, -1,  0,  0] [ 0,  0,  0] -1 */
        8872, /* 62235 (1573) [ 0,  0, -1, -1,  0,  0,  0,  1,  0] [ 0,  0,  0]  1 */
       10480, /* 62236 (1573) [ 0,  0,  1,  0, -1,  0, -1,  0,  0] [ 0,  0,  0]  1 */
    34015528, /* 62237 (1573) [-1,  0,  0,  0,  0,  1,  0, -1,  0] [ 0,  0,  0] -1 */
       11784, /* 62238 (1573) [ 0,  1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    34019636, /* 62239 (1573) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  0] -1 */
        7896, /* 62240 (1573) [ 0, -1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    34024288, /* 62241 (1573) [ 0,  1,  0,  0,  0,  1,  1,  0,  0] [ 0,  0,  0] -1 */
    34022548, /* 62242 (1573) [ 0,  0,  1, -1,  0,  0,  0, -1,  0] [ 0,  0,  0] -1 */
       16372, /* 62243 (1573) [ 1,  0,  0,  0,  0, -1,  0, -1,  0] [ 0,  0,  0]  1 */
        7672, /* 62244 (1573) [ 0, -1,  0,  0,  0,  1, -1,  0,  0] [ 0,  0,  0]  1 */
    34022884, /* 62245 (1573) [ 0,  0,  1,  0,  1,  0,  1,  0,  0] [ 0,  0,  0] -1 */
        3360, /* 62246 (1573) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    34028544, /* 62247 (1573) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
       10816, /* 62248 (1573) [ 0,  0,  1,  1,  0,  0,  0,  1,  0] [ 0,  0,  0]  1 */
        3200, /* 62249 (1573) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
       12272, /* 62250 (1573) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 0,  0,  0]  1 */
       11992, /* 62251 (1573) [ 0,  1,  0,  0,  0, -1, -1,  0,  0] [ 0,  0,  0]  1 */
    34028656, /* 62252 (1573) [ 1,  0,  0,  0,  0,  1,  0,  1,  0] [ 0,  0,  0] -1 */
        7412, /* 62253 (1573) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  0]  1 */
       12064, /* 62254 (1573) [ 0,  1,  0,  0,  0,  1,  1,  0,  0] [ 0,  0,  0]  1 */
        3304, /* 62255 (1573) [-1,  0,  0,  0,  0,  1,  0, -1,  0] [ 0,  0,  0]  1 */
    34021264, /* 62256 (1573) [ 0,  0, -1,  0, -1,  0,  1,  0,  0] [ 0,  0,  0] -1 */
    34015480, /* 62257 (1573) [-1,  0,  0,  0,  0, -1,  0,  1,  0] [ 0,  0,  0] -1 */
       10324, /* 62258 (1573) [ 0,  0,  1, -1,  0,  0,  0, -1,  0] [ 0,  0,  0]  1 */
       16484, /* 62259 (1574) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34021408, /* 62260 (1574) [ 0,  0, -1,  0,  1,  0, -1,  0,  0] [ 0,  0,  0] -1 */
       16320, /* 62261 (1574) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    34022704, /* 62262 (1574) [ 0,  0,  1,  0, -1,  0, -1,  0,  0] [ 0,  0,  0] -1 */
    34024008, /* 62263 (1574) [ 0,  1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    34020120, /* 62264 (1574) [ 0, -1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    34028596, /* 62265 (1574) [ 1,  0,  0,  0,  0, -1,  0, -1,  0] [ 0,  0,  0] -1 */
        7636, /* 62266 (1574) [ 0, -1,  0,  0,  0, -1,  1,  0,  0] [ 0,  0,  0]  1 */
        9352, /* 62267 (1574) [ 0,  0, -1,  1,  0,  0,  0, -1,  0] [ 0,  0,  0]  1 */
    34024496, /* 62268 (1574) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 0,  0,  0] -1 */
        8872, /* 62269 (1574) [ 0,  0, -1, -1,  0,  0,  0,  1,  0] [ 0,  0,  0]  1 */
    34015528, /* 62270 (1574) [-1,  0,  0,  0,  0,  1,  0, -1,  0] [ 0,  0,  0] -1 */
    34019636, /* 62271 (1574) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  0] -1 */
        7672, /* 62272 (1574) [ 0, -1,  0,  0,  0,  1, -1,  0,  0] [ 0,  0,  0]  1 */
    34022884, /* 62273 (1574) [ 0,  0,  1,  0,  1,  0,  1,  0,  0] [ 0,  0,  0] -1 */
        3360, /* 62274 (1574) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
       10816, /* 62275 (1574) [ 0,  0,  1,  1,  0,  0,  0,  1,  0] [ 0,  0,  0]  1 */
        3200, /* 62276 (1574) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34028656, /* 62277 (1574) [ 1,  0,  0,  0,  0,  1,  0,  1,  0] [ 0,  0,  0] -1 */
       11992, /* 62278 (1574) [ 0,  1,  0,  0,  0, -1, -1,  0,  0] [ 0,  0,  0]  1 */
       12064, /* 62279 (1574) [ 0,  1,  0,  0,  0,  1,  1,  0,  0] [ 0,  0,  0]  1 */
    34021264, /* 62280 (1574) [ 0,  0, -1,  0, -1,  0,  1,  0,  0] [ 0,  0,  0] -1 */
    34015480, /* 62281 (1574) [-1,  0,  0,  0,  0, -1,  0,  1,  0] [ 0,  0,  0] -1 */
       10324, /* 62282 (1574) [ 0,  0,  1, -1,  0,  0,  0, -1,  0] [ 0,  0,  0]  1 */
       16484, /* 62283 (1575) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    52562962, /* 62284 (1575) [ 0,  0, -1,  1,  0,  0,  0, -1,  0] [ 6,  6,  6] -1 */
       10660, /* 62285 (1575) [ 0,  0,  1,  0,  1,  0,  1,  0,  0] [ 0,  0,  0]  1 */
    52561506, /* 62286 (1575) [ 0, -1,  0,  1,  0,  0,  0,  0, -1] [ 6,  6,  6] -1 */
       16320, /* 62287 (1575) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    52556970, /* 62288 (1575) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
       16432, /* 62289 (1575) [ 1,  0,  0,  0,  0,  1,  0,  1,  0] [ 0,  0,  0]  1 */
    52565394, /* 62290 (1575) [ 0,  1,  0, -1,  0,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    52570094, /* 62291 (1575) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    52569982, /* 62292 (1575) [ 1,  0,  0,  0,  0, -1,  0, -1,  0] [ 6,  6,  6] -1 */
        9040, /* 62293 (1575) [ 0,  0, -1,  0, -1,  0,  1,  0,  0] [ 0,  0,  0]  1 */
        3256, /* 62294 (1575) [-1,  0,  0,  0,  0, -1,  0,  1,  0] [ 0,  0,  0]  1 */
    52562482, /* 62295 (1575) [ 0,  0, -1, -1,  0,  0,  0,  1,  0] [ 6,  6,  6] -1 */
        9184, /* 62296 (1575) [ 0,  0, -1,  0,  1,  0, -1,  0,  0] [ 0,  0,  0]  1 */
    52564090, /* 62297 (1575) [ 0,  0,  1,  0, -1,  0, -1,  0,  0] [ 6,  6,  6] -1 */
        7636, /* 62298 (1575) [ 0, -1,  0,  0,  0, -1,  1,  0,  0] [ 0,  0,  0]  1 */
    52561282, /* 62299 (1575) [ 0, -1,  0,  0,  0,  1, -1,  0,  0] [ 6,  6,  6] -1 */
        9352, /* 62300 (1575) [ 0,  0, -1,  1,  0,  0,  0, -1,  0] [ 0,  0,  0]  1 */
    52565882, /* 62301 (1575) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    52565602, /* 62302 (1575) [ 0,  1,  0,  0,  0, -1, -1,  0,  0] [ 6,  6,  6] -1 */
    52565674, /* 62303 (1575) [ 0,  1,  0,  0,  0,  1,  1,  0,  0] [ 6,  6,  6] -1 */
    52556914, /* 62304 (1575) [-1,  0,  0,  0,  0,  1,  0, -1,  0] [ 6,  6,  6] -1 */
    52556810, /* 62305 (1575) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
        8872, /* 62306 (1575) [ 0,  0, -1, -1,  0,  0,  0,  1,  0] [ 0,  0,  0]  1 */
       10480, /* 62307 (1575) [ 0,  0,  1,  0, -1,  0, -1,  0,  0] [ 0,  0,  0]  1 */
       11784, /* 62308 (1575) [ 0,  1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    52564426, /* 62309 (1575) [ 0,  0,  1,  1,  0,  0,  0,  1,  0] [ 6,  6,  6] -1 */
        7896, /* 62310 (1575) [ 0, -1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    52563934, /* 62311 (1575) [ 0,  0,  1, -1,  0,  0,  0, -1,  0] [ 6,  6,  6] -1 */
    52570042, /* 62312 (1575) [ 1,  0,  0,  0,  0,  1,  0,  1,  0] [ 6,  6,  6] -1 */
       16372, /* 62313 (1575) [ 1,  0,  0,  0,  0, -1,  0, -1,  0] [ 0,  0,  0]  1 */
    52564270, /* 62314 (1575) [ 0,  0,  1,  0,  1,  0,  1,  0,  0] [ 6,  6,  6] -1 */
        7672, /* 62315 (1575) [ 0, -1,  0,  0,  0,  1, -1,  0,  0] [ 0,  0,  0]  1 */
    52561022, /* 62316 (1575) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    52569930, /* 62317 (1575) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
        3360, /* 62318 (1575) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    52556866, /* 62319 (1575) [-1,  0,  0,  0,  0, -1,  0,  1,  0] [ 6,  6,  6] -1 */
       10816, /* 62320 (1575) [ 0,  0,  1,  1,  0,  0,  0,  1,  0] [ 0,  0,  0]  1 */
        3200, /* 62321 (1575) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
       12272, /* 62322 (1575) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 0,  0,  0]  1 */
       11992, /* 62323 (1575) [ 0,  1,  0,  0,  0, -1, -1,  0,  0] [ 0,  0,  0]  1 */
        7412, /* 62324 (1575) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  0]  1 */
       12064, /* 62325 (1575) [ 0,  1,  0,  0,  0,  1,  1,  0,  0] [ 0,  0,  0]  1 */
        3304, /* 62326 (1575) [-1,  0,  0,  0,  0,  1,  0, -1,  0] [ 0,  0,  0]  1 */
    52562794, /* 62327 (1575) [ 0,  0, -1,  0,  1,  0, -1,  0,  0] [ 6,  6,  6] -1 */
    52561246, /* 62328 (1575) [ 0, -1,  0,  0,  0, -1,  1,  0,  0] [ 6,  6,  6] -1 */
       10324, /* 62329 (1575) [ 0,  0,  1, -1,  0,  0,  0, -1,  0] [ 0,  0,  0]  1 */
    52562650, /* 62330 (1575) [ 0,  0, -1,  0, -1,  0,  1,  0,  0] [ 6,  6,  6] -1 */
       16484, /* 62331 (1576) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
       10660, /* 62332 (1576) [ 0,  0,  1,  0,  1,  0,  1,  0,  0] [ 0,  0,  0]  1 */
    17140694, /* 62333 (1576) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
     1545754, /* 62334 (1576) [ 0,  0,  1,  0, -1,  0, -1,  0,  0] [ 0,  6,  6]  1 */
       16320, /* 62335 (1576) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
     1538578, /* 62336 (1576) [-1,  0,  0,  0,  0,  1,  0, -1,  0] [ 0,  6,  6]  1 */
    17135994, /* 62337 (1576) [ 0,  1,  0, -1,  0,  0,  0,  0, -1] [ 6,  0,  6]  1 */
     1545598, /* 62338 (1576) [ 0,  0,  1, -1,  0,  0,  0, -1,  0] [ 0,  6,  6]  1 */
       16432, /* 62339 (1576) [ 1,  0,  0,  0,  0,  1,  0,  1,  0] [ 0,  0,  0]  1 */
        3256, /* 62340 (1576) [-1,  0,  0,  0,  0, -1,  0,  1,  0] [ 0,  0,  0]  1 */
     1538474, /* 62341 (1576) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
    17136274, /* 62342 (1576) [ 0,  1,  0,  0,  0,  1,  1,  0,  0] [ 6,  0,  6]  1 */
        9184, /* 62343 (1576) [ 0,  0, -1,  0,  1,  0, -1,  0,  0] [ 0,  0,  0]  1 */
        9352, /* 62344 (1576) [ 0,  0, -1,  1,  0,  0,  0, -1,  0] [ 0,  0,  0]  1 */
    17131622, /* 62345 (1576) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 6,  0,  6]  1 */
    18431184, /* 62346 (1576) [ 0, -1,  0,  1,  0,  0,  0,  0, -1] [ 6,  6,  0]  1 */
    18426648, /* 62347 (1576) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
        8872, /* 62348 (1576) [ 0,  0, -1, -1,  0,  0,  0,  1,  0] [ 0,  0,  0]  1 */
    18432160, /* 62349 (1576) [ 0,  0, -1, -1,  0,  0,  0,  1,  0] [ 6,  6,  0]  1 */
    17140642, /* 62350 (1576) [ 1,  0,  0,  0,  0,  1,  0,  1,  0] [ 6,  0,  6]  1 */
       16372, /* 62351 (1576) [ 1,  0,  0,  0,  0, -1,  0, -1,  0] [ 0,  0,  0]  1 */
    18439660, /* 62352 (1576) [ 1,  0,  0,  0,  0, -1,  0, -1,  0] [ 6,  6,  0]  1 */
    18426592, /* 62353 (1576) [-1,  0,  0,  0,  0,  1,  0, -1,  0] [ 6,  6,  0]  1 */
    18433612, /* 62354 (1576) [ 0,  0,  1, -1,  0,  0,  0, -1,  0] [ 6,  6,  0]  1 */
    17133562, /* 62355 (1576) [ 0,  0, -1,  1,  0,  0,  0, -1,  0] [ 6,  0,  6]  1 */
    17131846, /* 62356 (1576) [ 0, -1,  0,  0,  0, -1,  1,  0,  0] [ 6,  0,  6]  1 */
        3304, /* 62357 (1576) [-1,  0,  0,  0,  0,  1,  0, -1,  0] [ 0,  0,  0]  1 */
     1543170, /* 62358 (1576) [ 0, -1,  0,  1,  0,  0,  0,  0, -1] [ 0,  6,  6]  1 */
       10324, /* 62359 (1576) [ 0,  0,  1, -1,  0,  0,  0, -1,  0] [ 0,  0,  0]  1 */
     1538634, /* 62360 (1576) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
     1544146, /* 62361 (1576) [ 0,  0, -1, -1,  0,  0,  0,  1,  0] [ 0,  6,  6]  1 */
    17134690, /* 62362 (1576) [ 0,  0,  1,  0, -1,  0, -1,  0,  0] [ 6,  0,  6]  1 */
     1551646, /* 62363 (1576) [ 1,  0,  0,  0,  0, -1,  0, -1,  0] [ 0,  6,  6]  1 */
    17127514, /* 62364 (1576) [-1,  0,  0,  0,  0,  1,  0, -1,  0] [ 6,  0,  6]  1 */
    18432472, /* 62365 (1576) [ 0,  0, -1,  0,  1,  0, -1,  0,  0] [ 6,  6,  0]  1 */
    17134534, /* 62366 (1576) [ 0,  0,  1, -1,  0,  0,  0, -1,  0] [ 6,  0,  6]  1 */
    17134870, /* 62367 (1576) [ 0,  0,  1,  0,  1,  0,  1,  0,  0] [ 6,  0,  6]  1 */
    18439772, /* 62368 (1576) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    17140530, /* 62369 (1576) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  6]  1 */
    17127466, /* 62370 (1576) [-1,  0,  0,  0,  0, -1,  0,  1,  0] [ 6,  0,  6]  1 */
        7896, /* 62371 (1576) [ 0, -1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    18430960, /* 62372 (1576) [ 0, -1,  0,  0,  0,  1, -1,  0,  0] [ 6,  6,  0]  1 */
    18435280, /* 62373 (1576) [ 0,  1,  0,  0,  0, -1, -1,  0,  0] [ 6,  6,  0]  1 */
     1544458, /* 62374 (1576) [ 0,  0, -1,  0,  1,  0, -1,  0,  0] [ 0,  6,  6]  1 */
    18435352, /* 62375 (1576) [ 0,  1,  0,  0,  0,  1,  1,  0,  0] [ 6,  6,  0]  1 */
       10816, /* 62376 (1576) [ 0,  0,  1,  1,  0,  0,  0,  1,  0] [ 0,  0,  0]  1 */
    18434104, /* 62377 (1576) [ 0,  0,  1,  1,  0,  0,  0,  1,  0] [ 6,  6,  0]  1 */
    18435560, /* 62378 (1576) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 6,  6,  0]  1 */
       11992, /* 62379 (1576) [ 0,  1,  0,  0,  0, -1, -1,  0,  0] [ 0,  0,  0]  1 */
       12064, /* 62380 (1576) [ 0,  1,  0,  0,  0,  1,  1,  0,  0] [ 0,  0,  0]  1 */
     1551758, /* 62381 (1576) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
    18439720, /* 62382 (1576) [ 1,  0,  0,  0,  0,  1,  0,  1,  0] [ 6,  6,  0]  1 */
    17132106, /* 62383 (1576) [ 0, -1,  0,  1,  0,  0,  0,  0, -1] [ 6,  0,  6]  1 */
    17127570, /* 62384 (1576) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6]  1 */
     1542946, /* 62385 (1576) [ 0, -1,  0,  0,  0,  1, -1,  0,  0] [ 0,  6,  6]  1 */
    17133082, /* 62386 (1576) [ 0,  0, -1, -1,  0,  0,  0,  1,  0] [ 6,  0,  6]  1 */
     1547266, /* 62387 (1576) [ 0,  1,  0,  0,  0, -1, -1,  0,  0] [ 0,  6,  6]  1 */
    17136482, /* 62388 (1576) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 6,  0,  6]  1 */
    17140582, /* 62389 (1576) [ 1,  0,  0,  0,  0, -1,  0, -1,  0] [ 6,  0,  6]  1 */
        9040, /* 62390 (1576) [ 0,  0, -1,  0, -1,  0,  1,  0,  0] [ 0,  0,  0]  1 */
     1547546, /* 62391 (1576) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 0,  6,  6]  1 */
     1546090, /* 62392 (1576) [ 0,  0,  1,  1,  0,  0,  0,  1,  0] [ 0,  6,  6]  1 */
    18432328, /* 62393 (1576) [ 0,  0, -1,  0, -1,  0,  1,  0,  0] [ 6,  6,  0]  1 */
     1551706, /* 62394 (1576) [ 1,  0,  0,  0,  0,  1,  0,  1,  0] [ 0,  6,  6]  1 */
       11784, /* 62395 (1576) [ 0,  1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    18435072, /* 62396 (1576) [ 0,  1,  0, -1,  0,  0,  0,  0, -1] [ 6,  6,  0]  1 */
        7672, /* 62397 (1576) [ 0, -1,  0,  0,  0,  1, -1,  0,  0] [ 0,  0,  0]  1 */
        3360, /* 62398 (1576) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    18426488, /* 62399 (1576) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    17133394, /* 62400 (1576) [ 0,  0, -1,  0,  1,  0, -1,  0,  0] [ 6,  0,  6]  1 */
     1544314, /* 62401 (1576) [ 0,  0, -1,  0, -1,  0,  1,  0,  0] [ 0,  6,  6]  1 */
       12272, /* 62402 (1576) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 0,  0,  0]  1 */
        7412, /* 62403 (1576) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    18430700, /* 62404 (1576) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    18426544, /* 62405 (1576) [-1,  0,  0,  0,  0, -1,  0,  1,  0] [ 6,  6,  0]  1 */
    18433948, /* 62406 (1576) [ 0,  0,  1,  0,  1,  0,  1,  0,  0] [ 6,  6,  0]  1 */
    18439608, /* 62407 (1576) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
     1547058, /* 62408 (1576) [ 0,  1,  0, -1,  0,  0,  0,  0, -1] [ 0,  6,  6]  1 */
    17127410, /* 62409 (1576) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
    17131882, /* 62410 (1576) [ 0, -1,  0,  0,  0,  1, -1,  0,  0] [ 6,  0,  6]  1 */
    17136202, /* 62411 (1576) [ 0,  1,  0,  0,  0, -1, -1,  0,  0] [ 6,  0,  6]  1 */
     1547338, /* 62412 (1576) [ 0,  1,  0,  0,  0,  1,  1,  0,  0] [ 0,  6,  6]  1 */
    18432640, /* 62413 (1576) [ 0,  0, -1,  1,  0,  0,  0, -1,  0] [ 6,  6,  0]  1 */
    17135026, /* 62414 (1576) [ 0,  0,  1,  1,  0,  0,  0,  1,  0] [ 6,  0,  6]  1 */
        7636, /* 62415 (1576) [ 0, -1,  0,  0,  0, -1,  1,  0,  0] [ 0,  0,  0]  1 */
     1542686, /* 62416 (1576) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 0,  6,  6]  1 */
    18430924, /* 62417 (1576) [ 0, -1,  0,  0,  0, -1,  1,  0,  0] [ 6,  6,  0]  1 */
     1538530, /* 62418 (1576) [-1,  0,  0,  0,  0, -1,  0,  1,  0] [ 0,  6,  6]  1 */
     1545934, /* 62419 (1576) [ 0,  0,  1,  0,  1,  0,  1,  0,  0] [ 0,  6,  6]  1 */
     1551594, /* 62420 (1576) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
       10480, /* 62421 (1576) [ 0,  0,  1,  0, -1,  0, -1,  0,  0] [ 0,  0,  0]  1 */
    18433768, /* 62422 (1576) [ 0,  0,  1,  0, -1,  0, -1,  0,  0] [ 6,  6,  0]  1 */
     1544626, /* 62423 (1576) [ 0,  0, -1,  1,  0,  0,  0, -1,  0] [ 0,  6,  6]  1 */
        3200, /* 62424 (1576) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    17133250, /* 62425 (1576) [ 0,  0, -1,  0, -1,  0,  1,  0,  0] [ 6,  0,  6]  1 */
     1542910, /* 62426 (1576) [ 0, -1,  0,  0,  0, -1,  1,  0,  0] [ 0,  6,  6]  1 */
       16484, /* 62427 (1577) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
       10660, /* 62428 (1577) [ 0,  0,  1,  0,  1,  0,  1,  0,  0] [ 0,  0,  0]  1 */
    17140694, /* 62429 (1577) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
     1545754, /* 62430 (1577) [ 0,  0,  1,  0, -1,  0, -1,  0,  0] [ 0,  6,  6]  1 */
       16320, /* 62431 (1577) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
     1538578, /* 62432 (1577) [-1,  0,  0,  0,  0,  1,  0, -1,  0] [ 0,  6,  6]  1 */
    51147094, /* 62433 (1577) [ 0,  0,  1,  0,  1,  0,  1,  0,  0] [ 6,  0,  6] -1 */
    17135994, /* 62434 (1577) [ 0,  1,  0, -1,  0,  0,  0,  0, -1] [ 6,  0,  6]  1 */
    52451996, /* 62435 (1577) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
     1545598, /* 62436 (1577) [ 0,  0,  1, -1,  0,  0,  0, -1,  0] [ 0,  6,  6]  1 */
    51152754, /* 62437 (1577) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  6] -1 */
       16432, /* 62438 (1577) [ 1,  0,  0,  0,  0,  1,  0,  1,  0] [ 0,  0,  0]  1 */
    52447296, /* 62439 (1577) [ 0,  1,  0, -1,  0,  0,  0,  0, -1] [ 6,  6,  0] -1 */
        3256, /* 62440 (1577) [-1,  0,  0,  0,  0, -1,  0,  1,  0] [ 0,  0,  0]  1 */
    34020120, /* 62441 (1577) [ 0, -1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  0] -1 */
     1538474, /* 62442 (1577) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
    34019896, /* 62443 (1577) [ 0, -1,  0,  0,  0,  1, -1,  0,  0] [ 0,  0,  0] -1 */
    52443184, /* 62444 (1577) [ 0, -1,  0,  0,  0,  1, -1,  0,  0] [ 6,  6,  0] -1 */
    17136274, /* 62445 (1577) [ 0,  1,  0,  0,  0,  1,  1,  0,  0] [ 6,  0,  6]  1 */
        9184, /* 62446 (1577) [ 0,  0, -1,  0,  1,  0, -1,  0,  0] [ 0,  0,  0]  1 */
    34015584, /* 62447 (1577) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    35556538, /* 62448 (1577) [ 0,  0, -1,  0, -1,  0,  1,  0,  0] [ 0,  6,  6] -1 */
    52447576, /* 62449 (1577) [ 0,  1,  0,  0,  0,  1,  1,  0,  0] [ 6,  6,  0] -1 */
        9352, /* 62450 (1577) [ 0,  0, -1,  1,  0,  0,  0, -1,  0] [ 0,  0,  0]  1 */
    17131622, /* 62451 (1577) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 6,  0,  6]  1 */
    18431184, /* 62452 (1577) [ 0, -1,  0,  1,  0,  0,  0,  0, -1] [ 6,  6,  0]  1 */
    34024496, /* 62453 (1577) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    34023040, /* 62454 (1577) [ 0,  0,  1,  1,  0,  0,  0,  1,  0] [ 0,  0,  0] -1 */
    52446328, /* 62455 (1577) [ 0,  0,  1,  1,  0,  0,  0,  1,  0] [ 6,  6,  0] -1 */
    52447784, /* 62456 (1577) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 6,  6,  0] -1 */
    18426648, /* 62457 (1577) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
        8872, /* 62458 (1577) [ 0,  0, -1, -1,  0,  0,  0,  1,  0] [ 0,  0,  0]  1 */
    18432160, /* 62459 (1577) [ 0,  0, -1, -1,  0,  0,  0,  1,  0] [ 6,  6,  0]  1 */
    34024288, /* 62460 (1577) [ 0,  1,  0,  0,  0,  1,  1,  0,  0] [ 0,  0,  0] -1 */
    17140642, /* 62461 (1577) [ 1,  0,  0,  0,  0,  1,  0,  1,  0] [ 6,  0,  6]  1 */
    35563982, /* 62462 (1577) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
       16372, /* 62463 (1577) [ 1,  0,  0,  0,  0, -1,  0, -1,  0] [ 0,  0,  0]  1 */
    18439660, /* 62464 (1577) [ 1,  0,  0,  0,  0, -1,  0, -1,  0] [ 6,  6,  0]  1 */
    52451944, /* 62465 (1577) [ 1,  0,  0,  0,  0,  1,  0,  1,  0] [ 6,  6,  0] -1 */
    35559282, /* 62466 (1577) [ 0,  1,  0, -1,  0,  0,  0,  0, -1] [ 0,  6,  6] -1 */
    18426592, /* 62467 (1577) [-1,  0,  0,  0,  0,  1,  0, -1,  0] [ 6,  6,  0]  1 */
    51139794, /* 62468 (1577) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6] -1 */
    35555170, /* 62469 (1577) [ 0, -1,  0,  0,  0,  1, -1,  0,  0] [ 0,  6,  6] -1 */
    18433612, /* 62470 (1577) [ 0,  0,  1, -1,  0,  0,  0, -1,  0] [ 6,  6,  0]  1 */
    17133562, /* 62471 (1577) [ 0,  0, -1,  1,  0,  0,  0, -1,  0] [ 6,  0,  6]  1 */
    35559490, /* 62472 (1577) [ 0,  1,  0,  0,  0, -1, -1,  0,  0] [ 0,  6,  6] -1 */
    35559562, /* 62473 (1577) [ 0,  1,  0,  0,  0,  1,  1,  0,  0] [ 0,  6,  6] -1 */
    51148706, /* 62474 (1577) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 6,  0,  6] -1 */
    52444864, /* 62475 (1577) [ 0,  0, -1,  1,  0,  0,  0, -1,  0] [ 6,  6,  0] -1 */
    17131846, /* 62476 (1577) [ 0, -1,  0,  0,  0, -1,  1,  0,  0] [ 6,  0,  6]  1 */
        3304, /* 62477 (1577) [-1,  0,  0,  0,  0,  1,  0, -1,  0] [ 0,  0,  0]  1 */
     1543170, /* 62478 (1577) [ 0, -1,  0,  1,  0,  0,  0,  0, -1] [ 0,  6,  6]  1 */
    34021264, /* 62479 (1577) [ 0,  0, -1,  0, -1,  0,  1,  0,  0] [ 0,  0,  0] -1 */
    35559770, /* 62480 (1577) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 0,  6,  6] -1 */
    35558314, /* 62481 (1577) [ 0,  0,  1,  1,  0,  0,  0,  1,  0] [ 0,  6,  6] -1 */
       10324, /* 62482 (1577) [ 0,  0,  1, -1,  0,  0,  0, -1,  0] [ 0,  0,  0]  1 */
     1538634, /* 62483 (1577) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
    52443148, /* 62484 (1577) [ 0, -1,  0,  0,  0, -1,  1,  0,  0] [ 6,  6,  0] -1 */
     1544146, /* 62485 (1577) [ 0,  0, -1, -1,  0,  0,  0,  1,  0] [ 0,  6,  6]  1 */
    17134690, /* 62486 (1577) [ 0,  0,  1,  0, -1,  0, -1,  0,  0] [ 6,  0,  6]  1 */
     1551646, /* 62487 (1577) [ 1,  0,  0,  0,  0, -1,  0, -1,  0] [ 0,  6,  6]  1 */
    35563930, /* 62488 (1577) [ 1,  0,  0,  0,  0,  1,  0,  1,  0] [ 0,  6,  6] -1 */
    17127514, /* 62489 (1577) [-1,  0,  0,  0,  0,  1,  0, -1,  0] [ 6,  0,  6]  1 */
    18432472, /* 62490 (1577) [ 0,  0, -1,  0,  1,  0, -1,  0,  0] [ 6,  6,  0]  1 */
    17134534, /* 62491 (1577) [ 0,  0,  1, -1,  0,  0,  0, -1,  0] [ 6,  0,  6]  1 */
    34024008, /* 62492 (1577) [ 0,  1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    35556850, /* 62493 (1577) [ 0,  0, -1,  1,  0,  0,  0, -1,  0] [ 0,  6,  6] -1 */
    17134870, /* 62494 (1577) [ 0,  0,  1,  0,  1,  0,  1,  0,  0] [ 6,  0,  6]  1 */
    18439772, /* 62495 (1577) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    34015424, /* 62496 (1577) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    34028708, /* 62497 (1577) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    17140530, /* 62498 (1577) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  6]  1 */
    51145618, /* 62499 (1577) [ 0,  0, -1,  0,  1,  0, -1,  0,  0] [ 6,  0,  6] -1 */
    52438712, /* 62500 (1577) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
    17127466, /* 62501 (1577) [-1,  0,  0,  0,  0, -1,  0,  1,  0] [ 6,  0,  6]  1 */
    34019636, /* 62502 (1577) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    52442924, /* 62503 (1577) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 6,  6,  0] -1 */
        7896, /* 62504 (1577) [ 0, -1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    18430960, /* 62505 (1577) [ 0, -1,  0,  0,  0,  1, -1,  0,  0] [ 6,  6,  0]  1 */
    52438768, /* 62506 (1577) [-1,  0,  0,  0,  0, -1,  0,  1,  0] [ 6,  6,  0] -1 */
    18435280, /* 62507 (1577) [ 0,  1,  0,  0,  0, -1, -1,  0,  0] [ 6,  6,  0]  1 */
    51152918, /* 62508 (1577) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
     1544458, /* 62509 (1577) [ 0,  0, -1,  0,  1,  0, -1,  0,  0] [ 0,  6,  6]  1 */
    18435352, /* 62510 (1577) [ 0,  1,  0,  0,  0,  1,  1,  0,  0] [ 6,  6,  0]  1 */
    34022884, /* 62511 (1577) [ 0,  0,  1,  0,  1,  0,  1,  0,  0] [ 0,  0,  0] -1 */
    52446172, /* 62512 (1577) [ 0,  0,  1,  0,  1,  0,  1,  0,  0] [ 6,  6,  0] -1 */
    34028544, /* 62513 (1577) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    52451832, /* 62514 (1577) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
    51148218, /* 62515 (1577) [ 0,  1,  0, -1,  0,  0,  0,  0, -1] [ 6,  0,  6] -1 */
       10816, /* 62516 (1577) [ 0,  0,  1,  1,  0,  0,  0,  1,  0] [ 0,  0,  0]  1 */
    18434104, /* 62517 (1577) [ 0,  0,  1,  1,  0,  0,  0,  1,  0] [ 6,  6,  0]  1 */
    18435560, /* 62518 (1577) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 6,  6,  0]  1 */
       11992, /* 62519 (1577) [ 0,  1,  0,  0,  0, -1, -1,  0,  0] [ 0,  0,  0]  1 */
    51139634, /* 62520 (1577) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
    51144106, /* 62521 (1577) [ 0, -1,  0,  0,  0,  1, -1,  0,  0] [ 6,  0,  6] -1 */
       12064, /* 62522 (1577) [ 0,  1,  0,  0,  0,  1,  1,  0,  0] [ 0,  0,  0]  1 */
     1551758, /* 62523 (1577) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
    35550698, /* 62524 (1577) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
    51148426, /* 62525 (1577) [ 0,  1,  0,  0,  0, -1, -1,  0,  0] [ 6,  0,  6] -1 */
    51148498, /* 62526 (1577) [ 0,  1,  0,  0,  0,  1,  1,  0,  0] [ 6,  0,  6] -1 */
    18439720, /* 62527 (1577) [ 1,  0,  0,  0,  0,  1,  0,  1,  0] [ 6,  6,  0]  1 */
    17132106, /* 62528 (1577) [ 0, -1,  0,  1,  0,  0,  0,  0, -1] [ 6,  0,  6]  1 */
    51147250, /* 62529 (1577) [ 0,  0,  1,  1,  0,  0,  0,  1,  0] [ 6,  0,  6] -1 */
    34019860, /* 62530 (1577) [ 0, -1,  0,  0,  0, -1,  1,  0,  0] [ 0,  0,  0] -1 */
    35554910, /* 62531 (1577) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 0,  6,  6] -1 */
    17127570, /* 62532 (1577) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6]  1 */
     1542946, /* 62533 (1577) [ 0, -1,  0,  0,  0,  1, -1,  0,  0] [ 0,  6,  6]  1 */
    17133082, /* 62534 (1577) [ 0,  0, -1, -1,  0,  0,  0,  1,  0] [ 6,  0,  6]  1 */
    52443408, /* 62535 (1577) [ 0, -1,  0,  1,  0,  0,  0,  0, -1] [ 6,  6,  0] -1 */
    35550754, /* 62536 (1577) [-1,  0,  0,  0,  0, -1,  0,  1,  0] [ 0,  6,  6] -1 */
     1547266, /* 62537 (1577) [ 0,  1,  0,  0,  0, -1, -1,  0,  0] [ 0,  6,  6]  1 */
    35558158, /* 62538 (1577) [ 0,  0,  1,  0,  1,  0,  1,  0,  0] [ 0,  6,  6] -1 */
    52444384, /* 62539 (1577) [ 0,  0, -1, -1,  0,  0,  0,  1,  0] [ 6,  6,  0] -1 */
    17136482, /* 62540 (1577) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 6,  0,  6]  1 */
    17140582, /* 62541 (1577) [ 1,  0,  0,  0,  0, -1,  0, -1,  0] [ 6,  0,  6]  1 */
    35563818, /* 62542 (1577) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  6] -1 */
    51152866, /* 62543 (1577) [ 1,  0,  0,  0,  0,  1,  0,  1,  0] [ 6,  0,  6] -1 */
    34022704, /* 62544 (1577) [ 0,  0,  1,  0, -1,  0, -1,  0,  0] [ 0,  0,  0] -1 */
        9040, /* 62545 (1577) [ 0,  0, -1,  0, -1,  0,  1,  0,  0] [ 0,  0,  0]  1 */
     1547546, /* 62546 (1577) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 0,  6,  6]  1 */
     1546090, /* 62547 (1577) [ 0,  0,  1,  1,  0,  0,  0,  1,  0] [ 0,  6,  6]  1 */
    18432328, /* 62548 (1577) [ 0,  0, -1,  0, -1,  0,  1,  0,  0] [ 6,  6,  0]  1 */
    52451884, /* 62549 (1577) [ 1,  0,  0,  0,  0, -1,  0, -1,  0] [ 6,  6,  0] -1 */
    52445992, /* 62550 (1577) [ 0,  0,  1,  0, -1,  0, -1,  0,  0] [ 6,  6,  0] -1 */
     1551706, /* 62551 (1577) [ 1,  0,  0,  0,  0,  1,  0,  1,  0] [ 0,  6,  6]  1 */
    51145474, /* 62552 (1577) [ 0,  0, -1,  0, -1,  0,  1,  0,  0] [ 6,  0,  6] -1 */
    35555134, /* 62553 (1577) [ 0, -1,  0,  0,  0, -1,  1,  0,  0] [ 0,  6,  6] -1 */
    34015528, /* 62554 (1577) [-1,  0,  0,  0,  0,  1,  0, -1,  0] [ 0,  0,  0] -1 */
       11784, /* 62555 (1577) [ 0,  1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    18435072, /* 62556 (1577) [ 0,  1,  0, -1,  0,  0,  0,  0, -1] [ 6,  6,  0]  1 */
    35555394, /* 62557 (1577) [ 0, -1,  0,  1,  0,  0,  0,  0, -1] [ 0,  6,  6] -1 */
    34022548, /* 62558 (1577) [ 0,  0,  1, -1,  0,  0,  0, -1,  0] [ 0,  0,  0] -1 */
        7672, /* 62559 (1577) [ 0, -1,  0,  0,  0,  1, -1,  0,  0] [ 0,  0,  0]  1 */
    35556370, /* 62560 (1577) [ 0,  0, -1, -1,  0,  0,  0,  1,  0] [ 0,  6,  6] -1 */
        3360, /* 62561 (1577) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    35557978, /* 62562 (1577) [ 0,  0,  1,  0, -1,  0, -1,  0,  0] [ 0,  6,  6] -1 */
    18426488, /* 62563 (1577) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    17133394, /* 62564 (1577) [ 0,  0, -1,  0,  1,  0, -1,  0,  0] [ 6,  0,  6]  1 */
    35563870, /* 62565 (1577) [ 1,  0,  0,  0,  0, -1,  0, -1,  0] [ 0,  6,  6] -1 */
     1544314, /* 62566 (1577) [ 0,  0, -1,  0, -1,  0,  1,  0,  0] [ 0,  6,  6]  1 */
    35550802, /* 62567 (1577) [-1,  0,  0,  0,  0,  1,  0, -1,  0] [ 0,  6,  6] -1 */
       12272, /* 62568 (1577) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    35557822, /* 62569 (1577) [ 0,  0,  1, -1,  0,  0,  0, -1,  0] [ 0,  6,  6] -1 */
    52444696, /* 62570 (1577) [ 0,  0, -1,  0,  1,  0, -1,  0,  0] [ 6,  6,  0] -1 */
    34028656, /* 62571 (1577) [ 1,  0,  0,  0,  0,  1,  0,  1,  0] [ 0,  0,  0] -1 */
        7412, /* 62572 (1577) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    18430700, /* 62573 (1577) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    18426544, /* 62574 (1577) [-1,  0,  0,  0,  0, -1,  0,  1,  0] [ 6,  6,  0]  1 */
    34015480, /* 62575 (1577) [-1,  0,  0,  0,  0, -1,  0,  1,  0] [ 0,  0,  0] -1 */
    18433948, /* 62576 (1577) [ 0,  0,  1,  0,  1,  0,  1,  0,  0] [ 6,  6,  0]  1 */
    34021408, /* 62577 (1577) [ 0,  0, -1,  0,  1,  0, -1,  0,  0] [ 0,  0,  0] -1 */
    18439608, /* 62578 (1577) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
     1547058, /* 62579 (1577) [ 0,  1,  0, -1,  0,  0,  0,  0, -1] [ 0,  6,  6]  1 */
    34021576, /* 62580 (1577) [ 0,  0, -1,  1,  0,  0,  0, -1,  0] [ 0,  0,  0] -1 */
    51143846, /* 62581 (1577) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 6,  0,  6] -1 */
    17127410, /* 62582 (1577) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
    17131882, /* 62583 (1577) [ 0, -1,  0,  0,  0,  1, -1,  0,  0] [ 6,  0,  6]  1 */
    51139690, /* 62584 (1577) [-1,  0,  0,  0,  0, -1,  0,  1,  0] [ 6,  0,  6] -1 */
    52438872, /* 62585 (1577) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
    17136202, /* 62586 (1577) [ 0,  1,  0,  0,  0, -1, -1,  0,  0] [ 6,  0,  6]  1 */
     1547338, /* 62587 (1577) [ 0,  1,  0,  0,  0,  1,  1,  0,  0] [ 0,  6,  6]  1 */
    34021096, /* 62588 (1577) [ 0,  0, -1, -1,  0,  0,  0,  1,  0] [ 0,  0,  0] -1 */
    18432640, /* 62589 (1577) [ 0,  0, -1,  1,  0,  0,  0, -1,  0] [ 6,  6,  0]  1 */
    52447504, /* 62590 (1577) [ 0,  1,  0,  0,  0, -1, -1,  0,  0] [ 6,  6,  0] -1 */
    34028596, /* 62591 (1577) [ 1,  0,  0,  0,  0, -1,  0, -1,  0] [ 0,  0,  0] -1 */
    17135026, /* 62592 (1577) [ 0,  0,  1,  1,  0,  0,  0,  1,  0] [ 6,  0,  6]  1 */
    35556682, /* 62593 (1577) [ 0,  0, -1,  0,  1,  0, -1,  0,  0] [ 0,  6,  6] -1 */
        7636, /* 62594 (1577) [ 0, -1,  0,  0,  0, -1,  1,  0,  0] [ 0,  0,  0]  1 */
     1542686, /* 62595 (1577) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 0,  6,  6]  1 */
    18430924, /* 62596 (1577) [ 0, -1,  0,  0,  0, -1,  1,  0,  0] [ 6,  6,  0]  1 */
     1538530, /* 62597 (1577) [-1,  0,  0,  0,  0, -1,  0,  1,  0] [ 0,  6,  6]  1 */
    52438816, /* 62598 (1577) [-1,  0,  0,  0,  0,  1,  0, -1,  0] [ 6,  6,  0] -1 */
     1545934, /* 62599 (1577) [ 0,  0,  1,  0,  1,  0,  1,  0,  0] [ 0,  6,  6]  1 */
    52445836, /* 62600 (1577) [ 0,  0,  1, -1,  0,  0,  0, -1,  0] [ 6,  6,  0] -1 */
    34024216, /* 62601 (1577) [ 0,  1,  0,  0,  0, -1, -1,  0,  0] [ 0,  0,  0] -1 */
     1551594, /* 62602 (1577) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
    51145786, /* 62603 (1577) [ 0,  0, -1,  1,  0,  0,  0, -1,  0] [ 6,  0,  6] -1 */
       10480, /* 62604 (1577) [ 0,  0,  1,  0, -1,  0, -1,  0,  0] [ 0,  0,  0]  1 */
    18433768, /* 62605 (1577) [ 0,  0,  1,  0, -1,  0, -1,  0,  0] [ 6,  6,  0]  1 */
    51144070, /* 62606 (1577) [ 0, -1,  0,  0,  0, -1,  1,  0,  0] [ 6,  0,  6] -1 */
    51144330, /* 62607 (1577) [ 0, -1,  0,  1,  0,  0,  0,  0, -1] [ 6,  0,  6] -1 */
    35550858, /* 62608 (1577) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6] -1 */
    51145306, /* 62609 (1577) [ 0,  0, -1, -1,  0,  0,  0,  1,  0] [ 6,  0,  6] -1 */
     1544626, /* 62610 (1577) [ 0,  0, -1,  1,  0,  0,  0, -1,  0] [ 0,  6,  6]  1 */
        3200, /* 62611 (1577) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    51146914, /* 62612 (1577) [ 0,  0,  1,  0, -1,  0, -1,  0,  0] [ 6,  0,  6] -1 */
    17133250, /* 62613 (1577) [ 0,  0, -1,  0, -1,  0,  1,  0,  0] [ 6,  0,  6]  1 */
    51152806, /* 62614 (1577) [ 1,  0,  0,  0,  0, -1,  0, -1,  0] [ 6,  0,  6] -1 */
     1542910, /* 62615 (1577) [ 0, -1,  0,  0,  0, -1,  1,  0,  0] [ 0,  6,  6]  1 */
    51139738, /* 62616 (1577) [-1,  0,  0,  0,  0,  1,  0, -1,  0] [ 6,  0,  6] -1 */
    52444552, /* 62617 (1577) [ 0,  0, -1,  0, -1,  0,  1,  0,  0] [ 6,  6,  0] -1 */
    51146758, /* 62618 (1577) [ 0,  0,  1, -1,  0,  0,  0, -1,  0] [ 6,  0,  6] -1 */
       16484, /* 62619 (1578) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    17140694, /* 62620 (1578) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
       16320, /* 62621 (1578) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    51147094, /* 62622 (1578) [ 0,  0,  1,  0,  1,  0,  1,  0,  0] [ 6,  0,  6] -1 */
     1545598, /* 62623 (1578) [ 0,  0,  1, -1,  0,  0,  0, -1,  0] [ 0,  6,  6]  1 */
    52447296, /* 62624 (1578) [ 0,  1,  0, -1,  0,  0,  0,  0, -1] [ 6,  6,  0] -1 */
    34020120, /* 62625 (1578) [ 0, -1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  0] -1 */
     1538474, /* 62626 (1578) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
    17136274, /* 62627 (1578) [ 0,  1,  0,  0,  0,  1,  1,  0,  0] [ 6,  0,  6]  1 */
    35556538, /* 62628 (1578) [ 0,  0, -1,  0, -1,  0,  1,  0,  0] [ 0,  6,  6] -1 */
        9352, /* 62629 (1578) [ 0,  0, -1,  1,  0,  0,  0, -1,  0] [ 0,  0,  0]  1 */
    34024496, /* 62630 (1578) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    52447784, /* 62631 (1578) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 6,  6,  0] -1 */
    18426648, /* 62632 (1578) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
        8872, /* 62633 (1578) [ 0,  0, -1, -1,  0,  0,  0,  1,  0] [ 0,  0,  0]  1 */
    18432160, /* 62634 (1578) [ 0,  0, -1, -1,  0,  0,  0,  1,  0] [ 6,  6,  0]  1 */
    52451944, /* 62635 (1578) [ 1,  0,  0,  0,  0,  1,  0,  1,  0] [ 6,  6,  0] -1 */
    35559282, /* 62636 (1578) [ 0,  1,  0, -1,  0,  0,  0,  0, -1] [ 0,  6,  6] -1 */
    18433612, /* 62637 (1578) [ 0,  0,  1, -1,  0,  0,  0, -1,  0] [ 6,  6,  0]  1 */
    17133562, /* 62638 (1578) [ 0,  0, -1,  1,  0,  0,  0, -1,  0] [ 6,  0,  6]  1 */
    51148706, /* 62639 (1578) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 6,  0,  6] -1 */
    17131846, /* 62640 (1578) [ 0, -1,  0,  0,  0, -1,  1,  0,  0] [ 6,  0,  6]  1 */
    34021264, /* 62641 (1578) [ 0,  0, -1,  0, -1,  0,  1,  0,  0] [ 0,  0,  0] -1 */
    35559770, /* 62642 (1578) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 0,  6,  6] -1 */
       10324, /* 62643 (1578) [ 0,  0,  1, -1,  0,  0,  0, -1,  0] [ 0,  0,  0]  1 */
     1538634, /* 62644 (1578) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
     1544146, /* 62645 (1578) [ 0,  0, -1, -1,  0,  0,  0,  1,  0] [ 0,  6,  6]  1 */
    35563930, /* 62646 (1578) [ 1,  0,  0,  0,  0,  1,  0,  1,  0] [ 0,  6,  6] -1 */
    17134534, /* 62647 (1578) [ 0,  0,  1, -1,  0,  0,  0, -1,  0] [ 6,  0,  6]  1 */
    34024008, /* 62648 (1578) [ 0,  1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    18439772, /* 62649 (1578) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    17140530, /* 62650 (1578) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  6]  1 */
    51145618, /* 62651 (1578) [ 0,  0, -1,  0,  1,  0, -1,  0,  0] [ 6,  0,  6] -1 */
    34019636, /* 62652 (1578) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    52442924, /* 62653 (1578) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 6,  6,  0] -1 */
    18430960, /* 62654 (1578) [ 0, -1,  0,  0,  0,  1, -1,  0,  0] [ 6,  6,  0]  1 */
    52438768, /* 62655 (1578) [-1,  0,  0,  0,  0, -1,  0,  1,  0] [ 6,  6,  0] -1 */
    34022884, /* 62656 (1578) [ 0,  0,  1,  0,  1,  0,  1,  0,  0] [ 0,  0,  0] -1 */
    18435280, /* 62657 (1578) [ 0,  1,  0,  0,  0, -1, -1,  0,  0] [ 6,  6,  0]  1 */
    52446172, /* 62658 (1578) [ 0,  0,  1,  0,  1,  0,  1,  0,  0] [ 6,  6,  0] -1 */
    18435352, /* 62659 (1578) [ 0,  1,  0,  0,  0,  1,  1,  0,  0] [ 6,  6,  0]  1 */
    51148218, /* 62660 (1578) [ 0,  1,  0, -1,  0,  0,  0,  0, -1] [ 6,  0,  6] -1 */
       10816, /* 62661 (1578) [ 0,  0,  1,  1,  0,  0,  0,  1,  0] [ 0,  0,  0]  1 */
    18434104, /* 62662 (1578) [ 0,  0,  1,  1,  0,  0,  0,  1,  0] [ 6,  6,  0]  1 */
       11992, /* 62663 (1578) [ 0,  1,  0,  0,  0, -1, -1,  0,  0] [ 0,  0,  0]  1 */
       12064, /* 62664 (1578) [ 0,  1,  0,  0,  0,  1,  1,  0,  0] [ 0,  0,  0]  1 */
     1551758, /* 62665 (1578) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
    35554910, /* 62666 (1578) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 0,  6,  6] -1 */
    17127570, /* 62667 (1578) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6]  1 */
     1542946, /* 62668 (1578) [ 0, -1,  0,  0,  0,  1, -1,  0,  0] [ 0,  6,  6]  1 */
    17133082, /* 62669 (1578) [ 0,  0, -1, -1,  0,  0,  0,  1,  0] [ 6,  0,  6]  1 */
    52443408, /* 62670 (1578) [ 0, -1,  0,  1,  0,  0,  0,  0, -1] [ 6,  6,  0] -1 */
    35550754, /* 62671 (1578) [-1,  0,  0,  0,  0, -1,  0,  1,  0] [ 0,  6,  6] -1 */
     1547266, /* 62672 (1578) [ 0,  1,  0,  0,  0, -1, -1,  0,  0] [ 0,  6,  6]  1 */
    35558158, /* 62673 (1578) [ 0,  0,  1,  0,  1,  0,  1,  0,  0] [ 0,  6,  6] -1 */
    51152866, /* 62674 (1578) [ 1,  0,  0,  0,  0,  1,  0,  1,  0] [ 6,  0,  6] -1 */
    34022704, /* 62675 (1578) [ 0,  0,  1,  0, -1,  0, -1,  0,  0] [ 0,  0,  0] -1 */
    52445992, /* 62676 (1578) [ 0,  0,  1,  0, -1,  0, -1,  0,  0] [ 6,  6,  0] -1 */
     1546090, /* 62677 (1578) [ 0,  0,  1,  1,  0,  0,  0,  1,  0] [ 0,  6,  6]  1 */
    52451884, /* 62678 (1578) [ 1,  0,  0,  0,  0, -1,  0, -1,  0] [ 6,  6,  0] -1 */
    51145474, /* 62679 (1578) [ 0,  0, -1,  0, -1,  0,  1,  0,  0] [ 6,  0,  6] -1 */
    34015528, /* 62680 (1578) [-1,  0,  0,  0,  0,  1,  0, -1,  0] [ 0,  0,  0] -1 */
    35555394, /* 62681 (1578) [ 0, -1,  0,  1,  0,  0,  0,  0, -1] [ 0,  6,  6] -1 */
        7672, /* 62682 (1578) [ 0, -1,  0,  0,  0,  1, -1,  0,  0] [ 0,  0,  0]  1 */
        3360, /* 62683 (1578) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    35557978, /* 62684 (1578) [ 0,  0,  1,  0, -1,  0, -1,  0,  0] [ 0,  6,  6] -1 */
    18426488, /* 62685 (1578) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    35563870, /* 62686 (1578) [ 1,  0,  0,  0,  0, -1,  0, -1,  0] [ 0,  6,  6] -1 */
    35550802, /* 62687 (1578) [-1,  0,  0,  0,  0,  1,  0, -1,  0] [ 0,  6,  6] -1 */
    52444696, /* 62688 (1578) [ 0,  0, -1,  0,  1,  0, -1,  0,  0] [ 6,  6,  0] -1 */
    34028656, /* 62689 (1578) [ 1,  0,  0,  0,  0,  1,  0,  1,  0] [ 0,  0,  0] -1 */
    34015480, /* 62690 (1578) [-1,  0,  0,  0,  0, -1,  0,  1,  0] [ 0,  0,  0] -1 */
    34021408, /* 62691 (1578) [ 0,  0, -1,  0,  1,  0, -1,  0,  0] [ 0,  0,  0] -1 */
    18439608, /* 62692 (1578) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
    51143846, /* 62693 (1578) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 6,  0,  6] -1 */
    17127410, /* 62694 (1578) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
    17131882, /* 62695 (1578) [ 0, -1,  0,  0,  0,  1, -1,  0,  0] [ 6,  0,  6]  1 */
    51139690, /* 62696 (1578) [-1,  0,  0,  0,  0, -1,  0,  1,  0] [ 6,  0,  6] -1 */
    17136202, /* 62697 (1578) [ 0,  1,  0,  0,  0, -1, -1,  0,  0] [ 6,  0,  6]  1 */
     1547338, /* 62698 (1578) [ 0,  1,  0,  0,  0,  1,  1,  0,  0] [ 0,  6,  6]  1 */
    18432640, /* 62699 (1578) [ 0,  0, -1,  1,  0,  0,  0, -1,  0] [ 6,  6,  0]  1 */
    34028596, /* 62700 (1578) [ 1,  0,  0,  0,  0, -1,  0, -1,  0] [ 0,  0,  0] -1 */
    17135026, /* 62701 (1578) [ 0,  0,  1,  1,  0,  0,  0,  1,  0] [ 6,  0,  6]  1 */
    35556682, /* 62702 (1578) [ 0,  0, -1,  0,  1,  0, -1,  0,  0] [ 0,  6,  6] -1 */
        7636, /* 62703 (1578) [ 0, -1,  0,  0,  0, -1,  1,  0,  0] [ 0,  0,  0]  1 */
    18430924, /* 62704 (1578) [ 0, -1,  0,  0,  0, -1,  1,  0,  0] [ 6,  6,  0]  1 */
    52438816, /* 62705 (1578) [-1,  0,  0,  0,  0,  1,  0, -1,  0] [ 6,  6,  0] -1 */
     1551594, /* 62706 (1578) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
    51144330, /* 62707 (1578) [ 0, -1,  0,  1,  0,  0,  0,  0, -1] [ 6,  0,  6] -1 */
     1544626, /* 62708 (1578) [ 0,  0, -1,  1,  0,  0,  0, -1,  0] [ 0,  6,  6]  1 */
        3200, /* 62709 (1578) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    51146914, /* 62710 (1578) [ 0,  0,  1,  0, -1,  0, -1,  0,  0] [ 6,  0,  6] -1 */
    51152806, /* 62711 (1578) [ 1,  0,  0,  0,  0, -1,  0, -1,  0] [ 6,  0,  6] -1 */
     1542910, /* 62712 (1578) [ 0, -1,  0,  0,  0, -1,  1,  0,  0] [ 0,  6,  6]  1 */
    51139738, /* 62713 (1578) [-1,  0,  0,  0,  0,  1,  0, -1,  0] [ 6,  0,  6] -1 */
    52444552, /* 62714 (1578) [ 0,  0, -1,  0, -1,  0,  1,  0,  0] [ 6,  6,  0] -1 */
       16484, /* 62715 (1579) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    52562962, /* 62716 (1579) [ 0,  0, -1,  1,  0,  0,  0, -1,  0] [ 6,  6,  6] -1 */
       10660, /* 62717 (1579) [ 0,  0,  1,  0,  1,  0,  1,  0,  0] [ 0,  0,  0]  1 */
    17140694, /* 62718 (1579) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
     1545754, /* 62719 (1579) [ 0,  0,  1,  0, -1,  0, -1,  0,  0] [ 0,  6,  6]  1 */
    34139362, /* 62720 (1579) [ 0,  0, -1,  0, -1,  0,  1,  0,  0] [ 0,  0,  6] -1 */
       16320, /* 62721 (1579) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
     1538578, /* 62722 (1579) [-1,  0,  0,  0,  0,  1,  0, -1,  0] [ 0,  6,  6]  1 */
    17135994, /* 62723 (1579) [ 0,  1,  0, -1,  0,  0,  0,  0, -1] [ 6,  0,  6]  1 */
     1545598, /* 62724 (1579) [ 0,  0,  1, -1,  0,  0,  0, -1,  0] [ 0,  6,  6]  1 */
       16432, /* 62725 (1579) [ 1,  0,  0,  0,  0,  1,  0,  1,  0] [ 0,  0,  0]  1 */
    52565394, /* 62726 (1579) [ 0,  1,  0, -1,  0,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    51028816, /* 62727 (1579) [ 0,  0,  1,  0, -1,  0, -1,  0,  0] [ 6,  0,  0] -1 */
        3256, /* 62728 (1579) [-1,  0,  0,  0,  0, -1,  0,  1,  0] [ 0,  0,  0]  1 */
     1538474, /* 62729 (1579) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
    51034820, /* 62730 (1579) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  0] -1 */
    17136274, /* 62731 (1579) [ 0,  1,  0,  0,  0,  1,  1,  0,  0] [ 6,  0,  6]  1 */
        9184, /* 62732 (1579) [ 0,  0, -1,  0,  1,  0, -1,  0,  0] [ 0,  0,  0]  1 */
    34142106, /* 62733 (1579) [ 0,  1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  6] -1 */
        9352, /* 62734 (1579) [ 0,  0, -1,  1,  0,  0,  0, -1,  0] [ 0,  0,  0]  1 */
    52565882, /* 62735 (1579) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    17131622, /* 62736 (1579) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 6,  0,  6]  1 */
    35438584, /* 62737 (1579) [ 0,  0, -1,  0,  1,  0, -1,  0,  0] [ 0,  6,  0] -1 */
    18431184, /* 62738 (1579) [ 0, -1,  0,  1,  0,  0,  0,  0, -1] [ 6,  6,  0]  1 */
    18426648, /* 62739 (1579) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
    34133522, /* 62740 (1579) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    52556810, /* 62741 (1579) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
        8872, /* 62742 (1579) [ 0,  0, -1, -1,  0,  0,  0,  1,  0] [ 0,  0,  0]  1 */
    18432160, /* 62743 (1579) [ 0,  0, -1, -1,  0,  0,  0,  1,  0] [ 6,  6,  0]  1 */
    51028996, /* 62744 (1579) [ 0,  0,  1,  0,  1,  0,  1,  0,  0] [ 6,  0,  0] -1 */
    51034656, /* 62745 (1579) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  0] -1 */
    17140642, /* 62746 (1579) [ 1,  0,  0,  0,  0,  1,  0,  1,  0] [ 6,  0,  6]  1 */
    35432760, /* 62747 (1579) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  0] -1 */
    52570042, /* 62748 (1579) [ 1,  0,  0,  0,  0,  1,  0,  1,  0] [ 6,  6,  6] -1 */
       16372, /* 62749 (1579) [ 1,  0,  0,  0,  0, -1,  0, -1,  0] [ 0,  0,  0]  1 */
    18439660, /* 62750 (1579) [ 1,  0,  0,  0,  0, -1,  0, -1,  0] [ 6,  6,  0]  1 */
    34137734, /* 62751 (1579) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    35445884, /* 62752 (1579) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  0] -1 */
    52561022, /* 62753 (1579) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    51034768, /* 62754 (1579) [ 1,  0,  0,  0,  0,  1,  0,  1,  0] [ 6,  0,  0] -1 */
    52556866, /* 62755 (1579) [-1,  0,  0,  0,  0, -1,  0,  1,  0] [ 6,  6,  6] -1 */
    18426592, /* 62756 (1579) [-1,  0,  0,  0,  0,  1,  0, -1,  0] [ 6,  6,  0]  1 */
    51021592, /* 62757 (1579) [-1,  0,  0,  0,  0, -1,  0,  1,  0] [ 6,  0,  0] -1 */
    34140982, /* 62758 (1579) [ 0,  0,  1,  0,  1,  0,  1,  0,  0] [ 0,  0,  6] -1 */
    18433612, /* 62759 (1579) [ 0,  0,  1, -1,  0,  0,  0, -1,  0] [ 6,  6,  0]  1 */
    17133562, /* 62760 (1579) [ 0,  0, -1,  1,  0,  0,  0, -1,  0] [ 6,  0,  6]  1 */
    35441392, /* 62761 (1579) [ 0,  1,  0,  0,  0, -1, -1,  0,  0] [ 0,  6,  0] -1 */
    51025972, /* 62762 (1579) [ 0, -1,  0,  0,  0, -1,  1,  0,  0] [ 6,  0,  0] -1 */
    17131846, /* 62763 (1579) [ 0, -1,  0,  0,  0, -1,  1,  0,  0] [ 6,  0,  6]  1 */
    35441464, /* 62764 (1579) [ 0,  1,  0,  0,  0,  1,  1,  0,  0] [ 0,  6,  0] -1 */
     1543170, /* 62765 (1579) [ 0, -1,  0,  1,  0,  0,  0,  0, -1] [ 0,  6,  6]  1 */
        3304, /* 62766 (1579) [-1,  0,  0,  0,  0,  1,  0, -1,  0] [ 0,  0,  0]  1 */
    52561246, /* 62767 (1579) [ 0, -1,  0,  0,  0, -1,  1,  0,  0] [ 6,  6,  6] -1 */
       10324, /* 62768 (1579) [ 0,  0,  1, -1,  0,  0,  0, -1,  0] [ 0,  0,  0]  1 */
     1538634, /* 62769 (1579) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
    35440216, /* 62770 (1579) [ 0,  0,  1,  1,  0,  0,  0,  1,  0] [ 0,  6,  0] -1 */
     1544146, /* 62771 (1579) [ 0,  0, -1, -1,  0,  0,  0,  1,  0] [ 0,  6,  6]  1 */
    34139674, /* 62772 (1579) [ 0,  0, -1,  1,  0,  0,  0, -1,  0] [ 0,  0,  6] -1 */
    51027688, /* 62773 (1579) [ 0,  0, -1,  1,  0,  0,  0, -1,  0] [ 6,  0,  0] -1 */
    17134690, /* 62774 (1579) [ 0,  0,  1,  0, -1,  0, -1,  0,  0] [ 6,  0,  6]  1 */
     1551646, /* 62775 (1579) [ 1,  0,  0,  0,  0, -1,  0, -1,  0] [ 0,  6,  6]  1 */
    51034708, /* 62776 (1579) [ 1,  0,  0,  0,  0, -1,  0, -1,  0] [ 6,  0,  0] -1 */
    34137958, /* 62777 (1579) [ 0, -1,  0,  0,  0, -1,  1,  0,  0] [ 0,  0,  6] -1 */
    17127514, /* 62778 (1579) [-1,  0,  0,  0,  0,  1,  0, -1,  0] [ 6,  0,  6]  1 */
    18432472, /* 62779 (1579) [ 0,  0, -1,  0,  1,  0, -1,  0,  0] [ 6,  6,  0]  1 */
    17134534, /* 62780 (1579) [ 0,  0,  1, -1,  0,  0,  0, -1,  0] [ 6,  0,  6]  1 */
    52562482, /* 62781 (1579) [ 0,  0, -1, -1,  0,  0,  0,  1,  0] [ 6,  6,  6] -1 */
    35438440, /* 62782 (1579) [ 0,  0, -1,  0, -1,  0,  1,  0,  0] [ 0,  6,  0] -1 */
    34140802, /* 62783 (1579) [ 0,  0,  1,  0, -1,  0, -1,  0,  0] [ 0,  0,  6] -1 */
    52564090, /* 62784 (1579) [ 0,  0,  1,  0, -1,  0, -1,  0,  0] [ 6,  6,  6] -1 */
    34146806, /* 62785 (1579) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    17134870, /* 62786 (1579) [ 0,  0,  1,  0,  1,  0,  1,  0,  0] [ 6,  0,  6]  1 */
    51021640, /* 62787 (1579) [-1,  0,  0,  0,  0,  1,  0, -1,  0] [ 6,  0,  0] -1 */
    18439772, /* 62788 (1579) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    17140530, /* 62789 (1579) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  6]  1 */
    51028660, /* 62790 (1579) [ 0,  0,  1, -1,  0,  0,  0, -1,  0] [ 6,  0,  0] -1 */
    17127466, /* 62791 (1579) [-1,  0,  0,  0,  0, -1,  0,  1,  0] [ 6,  0,  6]  1 */
    51025748, /* 62792 (1579) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 6,  0,  0] -1 */
        7896, /* 62793 (1579) [ 0, -1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    18430960, /* 62794 (1579) [ 0, -1,  0,  0,  0,  1, -1,  0,  0] [ 6,  6,  0]  1 */
    35441184, /* 62795 (1579) [ 0,  1,  0, -1,  0,  0,  0,  0, -1] [ 0,  6,  0] -1 */
    52564270, /* 62796 (1579) [ 0,  0,  1,  0,  1,  0,  1,  0,  0] [ 6,  6,  6] -1 */
    34146642, /* 62797 (1579) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
    52569930, /* 62798 (1579) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
     1544458, /* 62799 (1579) [ 0,  0, -1,  0,  1,  0, -1,  0,  0] [ 0,  6,  6]  1 */
    18435352, /* 62800 (1579) [ 0,  1,  0,  0,  0,  1,  1,  0,  0] [ 6,  6,  0]  1 */
    18435280, /* 62801 (1579) [ 0,  1,  0,  0,  0, -1, -1,  0,  0] [ 6,  6,  0]  1 */
    35437072, /* 62802 (1579) [ 0, -1,  0,  0,  0,  1, -1,  0,  0] [ 0,  6,  0] -1 */
       10816, /* 62803 (1579) [ 0,  0,  1,  1,  0,  0,  0,  1,  0] [ 0,  0,  0]  1 */
    18434104, /* 62804 (1579) [ 0,  0,  1,  1,  0,  0,  0,  1,  0] [ 6,  6,  0]  1 */
    18435560, /* 62805 (1579) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 6,  6,  0]  1 */
       11992, /* 62806 (1579) [ 0,  1,  0,  0,  0, -1, -1,  0,  0] [ 0,  0,  0]  1 */
    35441672, /* 62807 (1579) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 0,  6,  0] -1 */
       12064, /* 62808 (1579) [ 0,  1,  0,  0,  0,  1,  1,  0,  0] [ 0,  0,  0]  1 */
    51027520, /* 62809 (1579) [ 0,  0, -1,  0,  1,  0, -1,  0,  0] [ 6,  0,  0] -1 */
     1551758, /* 62810 (1579) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
    52562794, /* 62811 (1579) [ 0,  0, -1,  0,  1,  0, -1,  0,  0] [ 6,  6,  6] -1 */
    34146754, /* 62812 (1579) [ 1,  0,  0,  0,  0,  1,  0,  1,  0] [ 0,  0,  6] -1 */
    18439720, /* 62813 (1579) [ 1,  0,  0,  0,  0,  1,  0,  1,  0] [ 6,  6,  0]  1 */
    17132106, /* 62814 (1579) [ 0, -1,  0,  1,  0,  0,  0,  0, -1] [ 6,  0,  6]  1 */
    52561506, /* 62815 (1579) [ 0, -1,  0,  1,  0,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    17127570, /* 62816 (1579) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6]  1 */
    35445832, /* 62817 (1579) [ 1,  0,  0,  0,  0,  1,  0,  1,  0] [ 0,  6,  0] -1 */
    51026232, /* 62818 (1579) [ 0, -1,  0,  1,  0,  0,  0,  0, -1] [ 6,  0,  0] -1 */
     1542946, /* 62819 (1579) [ 0, -1,  0,  0,  0,  1, -1,  0,  0] [ 0,  6,  6]  1 */
    17133082, /* 62820 (1579) [ 0,  0, -1, -1,  0,  0,  0,  1,  0] [ 6,  0,  6]  1 */
     1547266, /* 62821 (1579) [ 0,  1,  0,  0,  0, -1, -1,  0,  0] [ 0,  6,  6]  1 */
    35432656, /* 62822 (1579) [-1,  0,  0,  0,  0, -1,  0,  1,  0] [ 0,  6,  0] -1 */
    17136482, /* 62823 (1579) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 6,  0,  6]  1 */
    17140582, /* 62824 (1579) [ 1,  0,  0,  0,  0, -1,  0, -1,  0] [ 6,  0,  6]  1 */
    52569982, /* 62825 (1579) [ 1,  0,  0,  0,  0, -1,  0, -1,  0] [ 6,  6,  6] -1 */
        9040, /* 62826 (1579) [ 0,  0, -1,  0, -1,  0,  1,  0,  0] [ 0,  0,  0]  1 */
     1547546, /* 62827 (1579) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 0,  6,  6]  1 */
     1546090, /* 62828 (1579) [ 0,  0,  1,  1,  0,  0,  0,  1,  0] [ 0,  6,  6]  1 */
    18432328, /* 62829 (1579) [ 0,  0, -1,  0, -1,  0,  1,  0,  0] [ 6,  6,  0]  1 */
    35438752, /* 62830 (1579) [ 0,  0, -1,  1,  0,  0,  0, -1,  0] [ 0,  6,  0] -1 */
    34139194, /* 62831 (1579) [ 0,  0, -1, -1,  0,  0,  0,  1,  0] [ 0,  0,  6] -1 */
    51030328, /* 62832 (1579) [ 0,  1,  0,  0,  0, -1, -1,  0,  0] [ 6,  0,  0] -1 */
    51027208, /* 62833 (1579) [ 0,  0, -1, -1,  0,  0,  0,  1,  0] [ 6,  0,  0] -1 */
    51030400, /* 62834 (1579) [ 0,  1,  0,  0,  0,  1,  1,  0,  0] [ 6,  0,  0] -1 */
    35437036, /* 62835 (1579) [ 0, -1,  0,  0,  0, -1,  1,  0,  0] [ 0,  6,  0] -1 */
    34146694, /* 62836 (1579) [ 1,  0,  0,  0,  0, -1,  0, -1,  0] [ 0,  0,  6] -1 */
     1551706, /* 62837 (1579) [ 1,  0,  0,  0,  0,  1,  0,  1,  0] [ 0,  6,  6]  1 */
    34133626, /* 62838 (1579) [-1,  0,  0,  0,  0,  1,  0, -1,  0] [ 0,  0,  6] -1 */
    52556914, /* 62839 (1579) [-1,  0,  0,  0,  0,  1,  0, -1,  0] [ 6,  6,  6] -1 */
       11784, /* 62840 (1579) [ 0,  1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    18435072, /* 62841 (1579) [ 0,  1,  0, -1,  0,  0,  0,  0, -1] [ 6,  6,  0]  1 */
    52563934, /* 62842 (1579) [ 0,  0,  1, -1,  0,  0,  0, -1,  0] [ 6,  6,  6] -1 */
    34140646, /* 62843 (1579) [ 0,  0,  1, -1,  0,  0,  0, -1,  0] [ 0,  0,  6] -1 */
        7672, /* 62844 (1579) [ 0, -1,  0,  0,  0,  1, -1,  0,  0] [ 0,  0,  0]  1 */
        3360, /* 62845 (1579) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    18426488, /* 62846 (1579) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    17133394, /* 62847 (1579) [ 0,  0, -1,  0,  1,  0, -1,  0,  0] [ 6,  0,  6]  1 */
     1544314, /* 62848 (1579) [ 0,  0, -1,  0, -1,  0,  1,  0,  0] [ 0,  6,  6]  1 */
       12272, /* 62849 (1579) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    35432704, /* 62850 (1579) [-1,  0,  0,  0,  0,  1,  0, -1,  0] [ 0,  6,  0] -1 */
    35432600, /* 62851 (1579) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  0] -1 */
        7412, /* 62852 (1579) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    18430700, /* 62853 (1579) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    35439724, /* 62854 (1579) [ 0,  0,  1, -1,  0,  0,  0, -1,  0] [ 0,  6,  0] -1 */
    34133578, /* 62855 (1579) [-1,  0,  0,  0,  0, -1,  0,  1,  0] [ 0,  0,  6] -1 */
    18426544, /* 62856 (1579) [-1,  0,  0,  0,  0, -1,  0,  1,  0] [ 6,  6,  0]  1 */
    51027376, /* 62857 (1579) [ 0,  0, -1,  0, -1,  0,  1,  0,  0] [ 6,  0,  0] -1 */
    35436812, /* 62858 (1579) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 0,  6,  0] -1 */
    34139506, /* 62859 (1579) [ 0,  0, -1,  0,  1,  0, -1,  0,  0] [ 0,  0,  6] -1 */
    18433948, /* 62860 (1579) [ 0,  0,  1,  0,  1,  0,  1,  0,  0] [ 6,  6,  0]  1 */
    52562650, /* 62861 (1579) [ 0,  0, -1,  0, -1,  0,  1,  0,  0] [ 6,  6,  6] -1 */
    18439608, /* 62862 (1579) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
     1547058, /* 62863 (1579) [ 0,  1,  0, -1,  0,  0,  0,  0, -1] [ 0,  6,  6]  1 */
    51030120, /* 62864 (1579) [ 0,  1,  0, -1,  0,  0,  0,  0, -1] [ 6,  0,  0] -1 */
    35440060, /* 62865 (1579) [ 0,  0,  1,  0,  1,  0,  1,  0,  0] [ 0,  6,  0] -1 */
    35445720, /* 62866 (1579) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  0] -1 */
    52556970, /* 62867 (1579) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    17127410, /* 62868 (1579) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
    17131882, /* 62869 (1579) [ 0, -1,  0,  0,  0,  1, -1,  0,  0] [ 6,  0,  6]  1 */
    51021696, /* 62870 (1579) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  0] -1 */
    52570094, /* 62871 (1579) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    17136202, /* 62872 (1579) [ 0,  1,  0,  0,  0, -1, -1,  0,  0] [ 6,  0,  6]  1 */
     1547338, /* 62873 (1579) [ 0,  1,  0,  0,  0,  1,  1,  0,  0] [ 0,  6,  6]  1 */
    18432640, /* 62874 (1579) [ 0,  0, -1,  1,  0,  0,  0, -1,  0] [ 6,  6,  0]  1 */
    51030608, /* 62875 (1579) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 6,  0,  0] -1 */
    17135026, /* 62876 (1579) [ 0,  0,  1,  1,  0,  0,  0,  1,  0] [ 6,  0,  6]  1 */
        7636, /* 62877 (1579) [ 0, -1,  0,  0,  0, -1,  1,  0,  0] [ 0,  0,  0]  1 */
     1542686, /* 62878 (1579) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 0,  6,  6]  1 */
    18430924, /* 62879 (1579) [ 0, -1,  0,  0,  0, -1,  1,  0,  0] [ 6,  6,  0]  1 */
    34138218, /* 62880 (1579) [ 0, -1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  6] -1 */
    52561282, /* 62881 (1579) [ 0, -1,  0,  0,  0,  1, -1,  0,  0] [ 6,  6,  6] -1 */
    34137994, /* 62882 (1579) [ 0, -1,  0,  0,  0,  1, -1,  0,  0] [ 0,  0,  6] -1 */
    34133682, /* 62883 (1579) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
    51021536, /* 62884 (1579) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  0] -1 */
     1538530, /* 62885 (1579) [-1,  0,  0,  0,  0, -1,  0,  1,  0] [ 0,  6,  6]  1 */
    51026008, /* 62886 (1579) [ 0, -1,  0,  0,  0,  1, -1,  0,  0] [ 6,  0,  0] -1 */
    34142314, /* 62887 (1579) [ 0,  1,  0,  0,  0, -1, -1,  0,  0] [ 0,  0,  6] -1 */
    52565602, /* 62888 (1579) [ 0,  1,  0,  0,  0, -1, -1,  0,  0] [ 6,  6,  6] -1 */
     1545934, /* 62889 (1579) [ 0,  0,  1,  0,  1,  0,  1,  0,  0] [ 0,  6,  6]  1 */
    52565674, /* 62890 (1579) [ 0,  1,  0,  0,  0,  1,  1,  0,  0] [ 6,  6,  6] -1 */
    34142386, /* 62891 (1579) [ 0,  1,  0,  0,  0,  1,  1,  0,  0] [ 0,  0,  6] -1 */
    35437296, /* 62892 (1579) [ 0, -1,  0,  1,  0,  0,  0,  0, -1] [ 0,  6,  0] -1 */
     1551594, /* 62893 (1579) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
       10480, /* 62894 (1579) [ 0,  0,  1,  0, -1,  0, -1,  0,  0] [ 0,  0,  0]  1 */
    34141138, /* 62895 (1579) [ 0,  0,  1,  1,  0,  0,  0,  1,  0] [ 0,  0,  6] -1 */
    52564426, /* 62896 (1579) [ 0,  0,  1,  1,  0,  0,  0,  1,  0] [ 6,  6,  6] -1 */
    18433768, /* 62897 (1579) [ 0,  0,  1,  0, -1,  0, -1,  0,  0] [ 6,  6,  0]  1 */
    34142594, /* 62898 (1579) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    35438272, /* 62899 (1579) [ 0,  0, -1, -1,  0,  0,  0,  1,  0] [ 0,  6,  0] -1 */
    51029152, /* 62900 (1579) [ 0,  0,  1,  1,  0,  0,  0,  1,  0] [ 6,  0,  0] -1 */
    35439880, /* 62901 (1579) [ 0,  0,  1,  0, -1,  0, -1,  0,  0] [ 0,  6,  0] -1 */
    35445772, /* 62902 (1579) [ 1,  0,  0,  0,  0, -1,  0, -1,  0] [ 0,  6,  0] -1 */
     1544626, /* 62903 (1579) [ 0,  0, -1,  1,  0,  0,  0, -1,  0] [ 0,  6,  6]  1 */
        3200, /* 62904 (1579) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    17133250, /* 62905 (1579) [ 0,  0, -1,  0, -1,  0,  1,  0,  0] [ 6,  0,  6]  1 */
     1542910, /* 62906 (1579) [ 0, -1,  0,  0,  0, -1,  1,  0,  0] [ 0,  6,  6]  1 */
       16484, /* 62907 (1580) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    18544642, /* 62908 (1580) [-1,  0,  0,  0,  0, -1,  0,  1,  0] [ 6,  6,  6]  1 */
       10660, /* 62909 (1580) [ 0,  0,  1,  0,  1,  0,  1,  0,  0] [ 0,  0,  0]  1 */
       16320, /* 62910 (1580) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
       16432, /* 62911 (1580) [ 1,  0,  0,  0,  0,  1,  0,  1,  0] [ 0,  0,  0]  1 */
        9040, /* 62912 (1580) [ 0,  0, -1,  0, -1,  0,  1,  0,  0] [ 0,  0,  0]  1 */
        3256, /* 62913 (1580) [-1,  0,  0,  0,  0, -1,  0,  1,  0] [ 0,  0,  0]  1 */
    18550570, /* 62914 (1580) [ 0,  0, -1,  0,  1,  0, -1,  0,  0] [ 6,  6,  6]  1 */
    18549022, /* 62915 (1580) [ 0, -1,  0,  0,  0, -1,  1,  0,  0] [ 6,  6,  6]  1 */
        9184, /* 62916 (1580) [ 0,  0, -1,  0,  1,  0, -1,  0,  0] [ 0,  0,  0]  1 */
    18549282, /* 62917 (1580) [ 0, -1,  0,  1,  0,  0,  0,  0, -1] [ 6,  6,  6]  1 */
    18550738, /* 62918 (1580) [ 0,  0, -1,  1,  0,  0,  0, -1,  0] [ 6,  6,  6]  1 */
        7636, /* 62919 (1580) [ 0, -1,  0,  0,  0, -1,  1,  0,  0] [ 0,  0,  0]  1 */
    18550426, /* 62920 (1580) [ 0,  0, -1,  0, -1,  0,  1,  0,  0] [ 6,  6,  6]  1 */
        9352, /* 62921 (1580) [ 0,  0, -1,  1,  0,  0,  0, -1,  0] [ 0,  0,  0]  1 */
    18544746, /* 62922 (1580) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
    18553170, /* 62923 (1580) [ 0,  1,  0, -1,  0,  0,  0,  0, -1] [ 6,  6,  6]  1 */
    18557870, /* 62924 (1580) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
        8872, /* 62925 (1580) [ 0,  0, -1, -1,  0,  0,  0,  1,  0] [ 0,  0,  0]  1 */
    18557758, /* 62926 (1580) [ 1,  0,  0,  0,  0, -1,  0, -1,  0] [ 6,  6,  6]  1 */
       10480, /* 62927 (1580) [ 0,  0,  1,  0, -1,  0, -1,  0,  0] [ 0,  0,  0]  1 */
       11784, /* 62928 (1580) [ 0,  1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  0]  1 */
        7896, /* 62929 (1580) [ 0, -1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    18550258, /* 62930 (1580) [ 0,  0, -1, -1,  0,  0,  0,  1,  0] [ 6,  6,  6]  1 */
       16372, /* 62931 (1580) [ 1,  0,  0,  0,  0, -1,  0, -1,  0] [ 0,  0,  0]  1 */
    18551866, /* 62932 (1580) [ 0,  0,  1,  0, -1,  0, -1,  0,  0] [ 6,  6,  6]  1 */
        7672, /* 62933 (1580) [ 0, -1,  0,  0,  0,  1, -1,  0,  0] [ 0,  0,  0]  1 */
        3360, /* 62934 (1580) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    18549058, /* 62935 (1580) [ 0, -1,  0,  0,  0,  1, -1,  0,  0] [ 6,  6,  6]  1 */
    18553658, /* 62936 (1580) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    18553378, /* 62937 (1580) [ 0,  1,  0,  0,  0, -1, -1,  0,  0] [ 6,  6,  6]  1 */
       10816, /* 62938 (1580) [ 0,  0,  1,  1,  0,  0,  0,  1,  0] [ 0,  0,  0]  1 */
        3200, /* 62939 (1580) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
       12272, /* 62940 (1580) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    18544690, /* 62941 (1580) [-1,  0,  0,  0,  0,  1,  0, -1,  0] [ 6,  6,  6]  1 */
    18553450, /* 62942 (1580) [ 0,  1,  0,  0,  0,  1,  1,  0,  0] [ 6,  6,  6]  1 */
       11992, /* 62943 (1580) [ 0,  1,  0,  0,  0, -1, -1,  0,  0] [ 0,  0,  0]  1 */
    18552202, /* 62944 (1580) [ 0,  0,  1,  1,  0,  0,  0,  1,  0] [ 6,  6,  6]  1 */
        7412, /* 62945 (1580) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  0]  1 */
       12064, /* 62946 (1580) [ 0,  1,  0,  0,  0,  1,  1,  0,  0] [ 0,  0,  0]  1 */
    18544586, /* 62947 (1580) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    18551710, /* 62948 (1580) [ 0,  0,  1, -1,  0,  0,  0, -1,  0] [ 6,  6,  6]  1 */
        3304, /* 62949 (1580) [-1,  0,  0,  0,  0,  1,  0, -1,  0] [ 0,  0,  0]  1 */
    18557818, /* 62950 (1580) [ 1,  0,  0,  0,  0,  1,  0,  1,  0] [ 6,  6,  6]  1 */
    18552046, /* 62951 (1580) [ 0,  0,  1,  0,  1,  0,  1,  0,  0] [ 6,  6,  6]  1 */
    18548798, /* 62952 (1580) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 6,  6,  6]  1 */
       10324, /* 62953 (1580) [ 0,  0,  1, -1,  0,  0,  0, -1,  0] [ 0,  0,  0]  1 */
    18557706, /* 62954 (1580) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
       16484, /* 62955 (1581) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    52562962, /* 62956 (1581) [ 0,  0, -1,  1,  0,  0,  0, -1,  0] [ 6,  6,  6] -1 */
       10660, /* 62957 (1581) [ 0,  0,  1,  0,  1,  0,  1,  0,  0] [ 0,  0,  0]  1 */
       16320, /* 62958 (1581) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
       16432, /* 62959 (1581) [ 1,  0,  0,  0,  0,  1,  0,  1,  0] [ 0,  0,  0]  1 */
    52565394, /* 62960 (1581) [ 0,  1,  0, -1,  0,  0,  0,  0, -1] [ 6,  6,  6] -1 */
        3256, /* 62961 (1581) [-1,  0,  0,  0,  0, -1,  0,  1,  0] [ 0,  0,  0]  1 */
    34020120, /* 62962 (1581) [ 0, -1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    18550570, /* 62963 (1581) [ 0,  0, -1,  0,  1,  0, -1,  0,  0] [ 6,  6,  6]  1 */
    34019896, /* 62964 (1581) [ 0, -1,  0,  0,  0,  1, -1,  0,  0] [ 0,  0,  0] -1 */
        9184, /* 62965 (1581) [ 0,  0, -1,  0,  1,  0, -1,  0,  0] [ 0,  0,  0]  1 */
    34015584, /* 62966 (1581) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
        9352, /* 62967 (1581) [ 0,  0, -1,  1,  0,  0,  0, -1,  0] [ 0,  0,  0]  1 */
    52565882, /* 62968 (1581) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    18544746, /* 62969 (1581) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
    34024496, /* 62970 (1581) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    34023040, /* 62971 (1581) [ 0,  0,  1,  1,  0,  0,  0,  1,  0] [ 0,  0,  0] -1 */
    18557870, /* 62972 (1581) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    52556810, /* 62973 (1581) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
        8872, /* 62974 (1581) [ 0,  0, -1, -1,  0,  0,  0,  1,  0] [ 0,  0,  0]  1 */
    34024288, /* 62975 (1581) [ 0,  1,  0,  0,  0,  1,  1,  0,  0] [ 0,  0,  0] -1 */
    52570042, /* 62976 (1581) [ 1,  0,  0,  0,  0,  1,  0,  1,  0] [ 6,  6,  6] -1 */
       16372, /* 62977 (1581) [ 1,  0,  0,  0,  0, -1,  0, -1,  0] [ 0,  0,  0]  1 */
    52561022, /* 62978 (1581) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    18549058, /* 62979 (1581) [ 0, -1,  0,  0,  0,  1, -1,  0,  0] [ 6,  6,  6]  1 */
    52556866, /* 62980 (1581) [-1,  0,  0,  0,  0, -1,  0,  1,  0] [ 6,  6,  6] -1 */
    18553378, /* 62981 (1581) [ 0,  1,  0,  0,  0, -1, -1,  0,  0] [ 6,  6,  6]  1 */
    18552202, /* 62982 (1581) [ 0,  0,  1,  1,  0,  0,  0,  1,  0] [ 6,  6,  6]  1 */
        3304, /* 62983 (1581) [-1,  0,  0,  0,  0,  1,  0, -1,  0] [ 0,  0,  0]  1 */
    34021264, /* 62984 (1581) [ 0,  0, -1,  0, -1,  0,  1,  0,  0] [ 0,  0,  0] -1 */
    52561246, /* 62985 (1581) [ 0, -1,  0,  0,  0, -1,  1,  0,  0] [ 6,  6,  6] -1 */
       10324, /* 62986 (1581) [ 0,  0,  1, -1,  0,  0,  0, -1,  0] [ 0,  0,  0]  1 */
    34024008, /* 62987 (1581) [ 0,  1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    52562482, /* 62988 (1581) [ 0,  0, -1, -1,  0,  0,  0,  1,  0] [ 6,  6,  6] -1 */
    52564090, /* 62989 (1581) [ 0,  0,  1,  0, -1,  0, -1,  0,  0] [ 6,  6,  6] -1 */
    18550426, /* 62990 (1581) [ 0,  0, -1,  0, -1,  0,  1,  0,  0] [ 6,  6,  6]  1 */
    34015424, /* 62991 (1581) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    34028708, /* 62992 (1581) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    18553170, /* 62993 (1581) [ 0,  1,  0, -1,  0,  0,  0,  0, -1] [ 6,  6,  6]  1 */
    34019636, /* 62994 (1581) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  0] -1 */
        7896, /* 62995 (1581) [ 0, -1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    52564270, /* 62996 (1581) [ 0,  0,  1,  0,  1,  0,  1,  0,  0] [ 6,  6,  6] -1 */
    34022884, /* 62997 (1581) [ 0,  0,  1,  0,  1,  0,  1,  0,  0] [ 0,  0,  0] -1 */
    52569930, /* 62998 (1581) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    34028544, /* 62999 (1581) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    18553658, /* 63000 (1581) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 6,  6,  6]  1 */
       10816, /* 63001 (1581) [ 0,  0,  1,  1,  0,  0,  0,  1,  0] [ 0,  0,  0]  1 */
    18553450, /* 63002 (1581) [ 0,  1,  0,  0,  0,  1,  1,  0,  0] [ 6,  6,  6]  1 */
       11992, /* 63003 (1581) [ 0,  1,  0,  0,  0, -1, -1,  0,  0] [ 0,  0,  0]  1 */
       12064, /* 63004 (1581) [ 0,  1,  0,  0,  0,  1,  1,  0,  0] [ 0,  0,  0]  1 */
    18557818, /* 63005 (1581) [ 1,  0,  0,  0,  0,  1,  0,  1,  0] [ 6,  6,  6]  1 */
    52562794, /* 63006 (1581) [ 0,  0, -1,  0,  1,  0, -1,  0,  0] [ 6,  6,  6] -1 */
    18548798, /* 63007 (1581) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    18544642, /* 63008 (1581) [-1,  0,  0,  0,  0, -1,  0,  1,  0] [ 6,  6,  6]  1 */
    52561506, /* 63009 (1581) [ 0, -1,  0,  1,  0,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    34019860, /* 63010 (1581) [ 0, -1,  0,  0,  0, -1,  1,  0,  0] [ 0,  0,  0] -1 */
    52569982, /* 63011 (1581) [ 1,  0,  0,  0,  0, -1,  0, -1,  0] [ 6,  6,  6] -1 */
    34022704, /* 63012 (1581) [ 0,  0,  1,  0, -1,  0, -1,  0,  0] [ 0,  0,  0] -1 */
        9040, /* 63013 (1581) [ 0,  0, -1,  0, -1,  0,  1,  0,  0] [ 0,  0,  0]  1 */
    18550738, /* 63014 (1581) [ 0,  0, -1,  1,  0,  0,  0, -1,  0] [ 6,  6,  6]  1 */
    52556914, /* 63015 (1581) [-1,  0,  0,  0,  0,  1,  0, -1,  0] [ 6,  6,  6] -1 */
    34015528, /* 63016 (1581) [-1,  0,  0,  0,  0,  1,  0, -1,  0] [ 0,  0,  0] -1 */
       11784, /* 63017 (1581) [ 0,  1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    52563934, /* 63018 (1581) [ 0,  0,  1, -1,  0,  0,  0, -1,  0] [ 6,  6,  6] -1 */
    34022548, /* 63019 (1581) [ 0,  0,  1, -1,  0,  0,  0, -1,  0] [ 0,  0,  0] -1 */
    18551866, /* 63020 (1581) [ 0,  0,  1,  0, -1,  0, -1,  0,  0] [ 6,  6,  6]  1 */
        7672, /* 63021 (1581) [ 0, -1,  0,  0,  0,  1, -1,  0,  0] [ 0,  0,  0]  1 */
        3360, /* 63022 (1581) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
       12272, /* 63023 (1581) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34028656, /* 63024 (1581) [ 1,  0,  0,  0,  0,  1,  0,  1,  0] [ 0,  0,  0] -1 */
        7412, /* 63025 (1581) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    18544586, /* 63026 (1581) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    18552046, /* 63027 (1581) [ 0,  0,  1,  0,  1,  0,  1,  0,  0] [ 6,  6,  6]  1 */
    34015480, /* 63028 (1581) [-1,  0,  0,  0,  0, -1,  0,  1,  0] [ 0,  0,  0] -1 */
    18557706, /* 63029 (1581) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
    52562650, /* 63030 (1581) [ 0,  0, -1,  0, -1,  0,  1,  0,  0] [ 6,  6,  6] -1 */
    34021408, /* 63031 (1581) [ 0,  0, -1,  0,  1,  0, -1,  0,  0] [ 0,  0,  0] -1 */
    34021576, /* 63032 (1581) [ 0,  0, -1,  1,  0,  0,  0, -1,  0] [ 0,  0,  0] -1 */
    52556970, /* 63033 (1581) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    52570094, /* 63034 (1581) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    34021096, /* 63035 (1581) [ 0,  0, -1, -1,  0,  0,  0,  1,  0] [ 0,  0,  0] -1 */
    18549022, /* 63036 (1581) [ 0, -1,  0,  0,  0, -1,  1,  0,  0] [ 6,  6,  6]  1 */
    34028596, /* 63037 (1581) [ 1,  0,  0,  0,  0, -1,  0, -1,  0] [ 0,  0,  0] -1 */
    18549282, /* 63038 (1581) [ 0, -1,  0,  1,  0,  0,  0,  0, -1] [ 6,  6,  6]  1 */
        7636, /* 63039 (1581) [ 0, -1,  0,  0,  0, -1,  1,  0,  0] [ 0,  0,  0]  1 */
    52561282, /* 63040 (1581) [ 0, -1,  0,  0,  0,  1, -1,  0,  0] [ 6,  6,  6] -1 */
    52565602, /* 63041 (1581) [ 0,  1,  0,  0,  0, -1, -1,  0,  0] [ 6,  6,  6] -1 */
    52565674, /* 63042 (1581) [ 0,  1,  0,  0,  0,  1,  1,  0,  0] [ 6,  6,  6] -1 */
    34024216, /* 63043 (1581) [ 0,  1,  0,  0,  0, -1, -1,  0,  0] [ 0,  0,  0] -1 */
    18557758, /* 63044 (1581) [ 1,  0,  0,  0,  0, -1,  0, -1,  0] [ 6,  6,  6]  1 */
       10480, /* 63045 (1581) [ 0,  0,  1,  0, -1,  0, -1,  0,  0] [ 0,  0,  0]  1 */
    52564426, /* 63046 (1581) [ 0,  0,  1,  1,  0,  0,  0,  1,  0] [ 6,  6,  6] -1 */
    18550258, /* 63047 (1581) [ 0,  0, -1, -1,  0,  0,  0,  1,  0] [ 6,  6,  6]  1 */
        3200, /* 63048 (1581) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    18544690, /* 63049 (1581) [-1,  0,  0,  0,  0,  1,  0, -1,  0] [ 6,  6,  6]  1 */
    18551710, /* 63050 (1581) [ 0,  0,  1, -1,  0,  0,  0, -1,  0] [ 6,  6,  6]  1 */
       16484, /* 63051 (1582) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34021408, /* 63052 (1582) [ 0,  0, -1,  0,  1,  0, -1,  0,  0] [ 0,  0,  0] -1 */
    52561506, /* 63053 (1582) [ 0, -1,  0,  1,  0,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    52562650, /* 63054 (1582) [ 0,  0, -1,  0, -1,  0,  1,  0,  0] [ 6,  6,  6] -1 */
       16320, /* 63055 (1582) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    52565394, /* 63056 (1582) [ 0,  1,  0, -1,  0,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    52569982, /* 63057 (1582) [ 1,  0,  0,  0,  0, -1,  0, -1,  0] [ 6,  6,  6] -1 */
    34022704, /* 63058 (1582) [ 0,  0,  1,  0, -1,  0, -1,  0,  0] [ 0,  0,  0] -1 */
    34024008, /* 63059 (1582) [ 0,  1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    34020120, /* 63060 (1582) [ 0, -1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    18549022, /* 63061 (1582) [ 0, -1,  0,  0,  0, -1,  1,  0,  0] [ 6,  6,  6]  1 */
    34028596, /* 63062 (1582) [ 1,  0,  0,  0,  0, -1,  0, -1,  0] [ 0,  0,  0] -1 */
    52564090, /* 63063 (1582) [ 0,  0,  1,  0, -1,  0, -1,  0,  0] [ 6,  6,  6] -1 */
    18550738, /* 63064 (1582) [ 0,  0, -1,  1,  0,  0,  0, -1,  0] [ 6,  6,  6]  1 */
        7636, /* 63065 (1582) [ 0, -1,  0,  0,  0, -1,  1,  0,  0] [ 0,  0,  0]  1 */
        9352, /* 63066 (1582) [ 0,  0, -1,  1,  0,  0,  0, -1,  0] [ 0,  0,  0]  1 */
    52565882, /* 63067 (1582) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    18544746, /* 63068 (1582) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
    34024496, /* 63069 (1582) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    18557870, /* 63070 (1582) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    52556914, /* 63071 (1582) [-1,  0,  0,  0,  0,  1,  0, -1,  0] [ 6,  6,  6] -1 */
        8872, /* 63072 (1582) [ 0,  0, -1, -1,  0,  0,  0,  1,  0] [ 0,  0,  0]  1 */
    34015528, /* 63073 (1582) [-1,  0,  0,  0,  0,  1,  0, -1,  0] [ 0,  0,  0] -1 */
    34019636, /* 63074 (1582) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    52570042, /* 63075 (1582) [ 1,  0,  0,  0,  0,  1,  0,  1,  0] [ 6,  6,  6] -1 */
    18550258, /* 63076 (1582) [ 0,  0, -1, -1,  0,  0,  0,  1,  0] [ 6,  6,  6]  1 */
    52564270, /* 63077 (1582) [ 0,  0,  1,  0,  1,  0,  1,  0,  0] [ 6,  6,  6] -1 */
        7672, /* 63078 (1582) [ 0, -1,  0,  0,  0,  1, -1,  0,  0] [ 0,  0,  0]  1 */
    52561022, /* 63079 (1582) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    34022884, /* 63080 (1582) [ 0,  0,  1,  0,  1,  0,  1,  0,  0] [ 0,  0,  0] -1 */
        3360, /* 63081 (1582) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    18549058, /* 63082 (1582) [ 0, -1,  0,  0,  0,  1, -1,  0,  0] [ 6,  6,  6]  1 */
    52556866, /* 63083 (1582) [-1,  0,  0,  0,  0, -1,  0,  1,  0] [ 6,  6,  6] -1 */
    18553378, /* 63084 (1582) [ 0,  1,  0,  0,  0, -1, -1,  0,  0] [ 6,  6,  6]  1 */
       10816, /* 63085 (1582) [ 0,  0,  1,  1,  0,  0,  0,  1,  0] [ 0,  0,  0]  1 */
        3200, /* 63086 (1582) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    18553450, /* 63087 (1582) [ 0,  1,  0,  0,  0,  1,  1,  0,  0] [ 6,  6,  6]  1 */
    34028656, /* 63088 (1582) [ 1,  0,  0,  0,  0,  1,  0,  1,  0] [ 0,  0,  0] -1 */
       11992, /* 63089 (1582) [ 0,  1,  0,  0,  0, -1, -1,  0,  0] [ 0,  0,  0]  1 */
    18552202, /* 63090 (1582) [ 0,  0,  1,  1,  0,  0,  0,  1,  0] [ 6,  6,  6]  1 */
       12064, /* 63091 (1582) [ 0,  1,  0,  0,  0,  1,  1,  0,  0] [ 0,  0,  0]  1 */
    18544586, /* 63092 (1582) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    18551710, /* 63093 (1582) [ 0,  0,  1, -1,  0,  0,  0, -1,  0] [ 6,  6,  6]  1 */
    52562794, /* 63094 (1582) [ 0,  0, -1,  0,  1,  0, -1,  0,  0] [ 6,  6,  6] -1 */
    34021264, /* 63095 (1582) [ 0,  0, -1,  0, -1,  0,  1,  0,  0] [ 0,  0,  0] -1 */
    34015480, /* 63096 (1582) [-1,  0,  0,  0,  0, -1,  0,  1,  0] [ 0,  0,  0] -1 */
       10324, /* 63097 (1582) [ 0,  0,  1, -1,  0,  0,  0, -1,  0] [ 0,  0,  0]  1 */
    18557706, /* 63098 (1582) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
       16484, /* 63099 (1583) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    18544642, /* 63100 (1583) [-1,  0,  0,  0,  0, -1,  0,  1,  0] [ 6,  6,  6]  1 */
       16320, /* 63101 (1583) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    18550570, /* 63102 (1583) [ 0,  0, -1,  0,  1,  0, -1,  0,  0] [ 6,  6,  6]  1 */
    18549282, /* 63103 (1583) [ 0, -1,  0,  1,  0,  0,  0,  0, -1] [ 6,  6,  6]  1 */
    18550426, /* 63104 (1583) [ 0,  0, -1,  0, -1,  0,  1,  0,  0] [ 6,  6,  6]  1 */
        7636, /* 63105 (1583) [ 0, -1,  0,  0,  0, -1,  1,  0,  0] [ 0,  0,  0]  1 */
        9352, /* 63106 (1583) [ 0,  0, -1,  1,  0,  0,  0, -1,  0] [ 0,  0,  0]  1 */
    18553170, /* 63107 (1583) [ 0,  1,  0, -1,  0,  0,  0,  0, -1] [ 6,  6,  6]  1 */
        8872, /* 63108 (1583) [ 0,  0, -1, -1,  0,  0,  0,  1,  0] [ 0,  0,  0]  1 */
    18557758, /* 63109 (1583) [ 1,  0,  0,  0,  0, -1,  0, -1,  0] [ 6,  6,  6]  1 */
    18551866, /* 63110 (1583) [ 0,  0,  1,  0, -1,  0, -1,  0,  0] [ 6,  6,  6]  1 */
        7672, /* 63111 (1583) [ 0, -1,  0,  0,  0,  1, -1,  0,  0] [ 0,  0,  0]  1 */
        3360, /* 63112 (1583) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    18553658, /* 63113 (1583) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 6,  6,  6]  1 */
       10816, /* 63114 (1583) [ 0,  0,  1,  1,  0,  0,  0,  1,  0] [ 0,  0,  0]  1 */
        3200, /* 63115 (1583) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    18544690, /* 63116 (1583) [-1,  0,  0,  0,  0,  1,  0, -1,  0] [ 6,  6,  6]  1 */
       11992, /* 63117 (1583) [ 0,  1,  0,  0,  0, -1, -1,  0,  0] [ 0,  0,  0]  1 */
       12064, /* 63118 (1583) [ 0,  1,  0,  0,  0,  1,  1,  0,  0] [ 0,  0,  0]  1 */
    18557818, /* 63119 (1583) [ 1,  0,  0,  0,  0,  1,  0,  1,  0] [ 6,  6,  6]  1 */
    18552046, /* 63120 (1583) [ 0,  0,  1,  0,  1,  0,  1,  0,  0] [ 6,  6,  6]  1 */
    18548798, /* 63121 (1583) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 6,  6,  6]  1 */
       10324, /* 63122 (1583) [ 0,  0,  1, -1,  0,  0,  0, -1,  0] [ 0,  0,  0]  1 */
       16484, /* 63123 (1584) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    18544642, /* 63124 (1584) [-1,  0,  0,  0,  0, -1,  0,  1,  0] [ 6,  6,  6]  1 */
    52561506, /* 63125 (1584) [ 0, -1,  0,  1,  0,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    34019860, /* 63126 (1584) [ 0, -1,  0,  0,  0, -1,  1,  0,  0] [ 0,  0,  0] -1 */
       16320, /* 63127 (1584) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    34021576, /* 63128 (1584) [ 0,  0, -1,  1,  0,  0,  0, -1,  0] [ 0,  0,  0] -1 */
    52565394, /* 63129 (1584) [ 0,  1,  0, -1,  0,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    34021096, /* 63130 (1584) [ 0,  0, -1, -1,  0,  0,  0,  1,  0] [ 0,  0,  0] -1 */
    52569982, /* 63131 (1584) [ 1,  0,  0,  0,  0, -1,  0, -1,  0] [ 6,  6,  6] -1 */
    18550570, /* 63132 (1584) [ 0,  0, -1,  0,  1,  0, -1,  0,  0] [ 6,  6,  6]  1 */
    34019896, /* 63133 (1584) [ 0, -1,  0,  0,  0,  1, -1,  0,  0] [ 0,  0,  0] -1 */
    34015584, /* 63134 (1584) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    52564090, /* 63135 (1584) [ 0,  0,  1,  0, -1,  0, -1,  0,  0] [ 6,  6,  6] -1 */
    18549282, /* 63136 (1584) [ 0, -1,  0,  1,  0,  0,  0,  0, -1] [ 6,  6,  6]  1 */
    18550426, /* 63137 (1584) [ 0,  0, -1,  0, -1,  0,  1,  0,  0] [ 6,  6,  6]  1 */
        7636, /* 63138 (1584) [ 0, -1,  0,  0,  0, -1,  1,  0,  0] [ 0,  0,  0]  1 */
        9352, /* 63139 (1584) [ 0,  0, -1,  1,  0,  0,  0, -1,  0] [ 0,  0,  0]  1 */
    52565882, /* 63140 (1584) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    34015424, /* 63141 (1584) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    34028708, /* 63142 (1584) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    34023040, /* 63143 (1584) [ 0,  0,  1,  1,  0,  0,  0,  1,  0] [ 0,  0,  0] -1 */
    18553170, /* 63144 (1584) [ 0,  1,  0, -1,  0,  0,  0,  0, -1] [ 6,  6,  6]  1 */
    34024216, /* 63145 (1584) [ 0,  1,  0,  0,  0, -1, -1,  0,  0] [ 0,  0,  0] -1 */
    52556914, /* 63146 (1584) [-1,  0,  0,  0,  0,  1,  0, -1,  0] [ 6,  6,  6] -1 */
        8872, /* 63147 (1584) [ 0,  0, -1, -1,  0,  0,  0,  1,  0] [ 0,  0,  0]  1 */
    18557758, /* 63148 (1584) [ 1,  0,  0,  0,  0, -1,  0, -1,  0] [ 6,  6,  6]  1 */
    34024288, /* 63149 (1584) [ 0,  1,  0,  0,  0,  1,  1,  0,  0] [ 0,  0,  0] -1 */
    34022548, /* 63150 (1584) [ 0,  0,  1, -1,  0,  0,  0, -1,  0] [ 0,  0,  0] -1 */
    52570042, /* 63151 (1584) [ 1,  0,  0,  0,  0,  1,  0,  1,  0] [ 6,  6,  6] -1 */
    52564270, /* 63152 (1584) [ 0,  0,  1,  0,  1,  0,  1,  0,  0] [ 6,  6,  6] -1 */
    18551866, /* 63153 (1584) [ 0,  0,  1,  0, -1,  0, -1,  0,  0] [ 6,  6,  6]  1 */
        7672, /* 63154 (1584) [ 0, -1,  0,  0,  0,  1, -1,  0,  0] [ 0,  0,  0]  1 */
    52561022, /* 63155 (1584) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 6,  6,  6] -1 */
        3360, /* 63156 (1584) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    34028544, /* 63157 (1584) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    18553658, /* 63158 (1584) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    52556866, /* 63159 (1584) [-1,  0,  0,  0,  0, -1,  0,  1,  0] [ 6,  6,  6] -1 */
       10816, /* 63160 (1584) [ 0,  0,  1,  1,  0,  0,  0,  1,  0] [ 0,  0,  0]  1 */
        3200, /* 63161 (1584) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    18544690, /* 63162 (1584) [-1,  0,  0,  0,  0,  1,  0, -1,  0] [ 6,  6,  6]  1 */
       11992, /* 63163 (1584) [ 0,  1,  0,  0,  0, -1, -1,  0,  0] [ 0,  0,  0]  1 */
       12064, /* 63164 (1584) [ 0,  1,  0,  0,  0,  1,  1,  0,  0] [ 0,  0,  0]  1 */
    18557818, /* 63165 (1584) [ 1,  0,  0,  0,  0,  1,  0,  1,  0] [ 6,  6,  6]  1 */
    52562794, /* 63166 (1584) [ 0,  0, -1,  0,  1,  0, -1,  0,  0] [ 6,  6,  6] -1 */
    18552046, /* 63167 (1584) [ 0,  0,  1,  0,  1,  0,  1,  0,  0] [ 6,  6,  6]  1 */
    18548798, /* 63168 (1584) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 6,  6,  6]  1 */
       10324, /* 63169 (1584) [ 0,  0,  1, -1,  0,  0,  0, -1,  0] [ 0,  0,  0]  1 */
    52562650, /* 63170 (1584) [ 0,  0, -1,  0, -1,  0,  1,  0,  0] [ 6,  6,  6] -1 */
       16484, /* 63171 (1585) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    52561506, /* 63172 (1585) [ 0, -1,  0,  1,  0,  0,  0,  0, -1] [ 6,  6,  6] -1 */
       16320, /* 63173 (1585) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    52565394, /* 63174 (1585) [ 0,  1,  0, -1,  0,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    52569982, /* 63175 (1585) [ 1,  0,  0,  0,  0, -1,  0, -1,  0] [ 6,  6,  6] -1 */
    52564090, /* 63176 (1585) [ 0,  0,  1,  0, -1,  0, -1,  0,  0] [ 6,  6,  6] -1 */
        7636, /* 63177 (1585) [ 0, -1,  0,  0,  0, -1,  1,  0,  0] [ 0,  0,  0]  1 */
        9352, /* 63178 (1585) [ 0,  0, -1,  1,  0,  0,  0, -1,  0] [ 0,  0,  0]  1 */
    52565882, /* 63179 (1585) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    52556914, /* 63180 (1585) [-1,  0,  0,  0,  0,  1,  0, -1,  0] [ 6,  6,  6] -1 */
        8872, /* 63181 (1585) [ 0,  0, -1, -1,  0,  0,  0,  1,  0] [ 0,  0,  0]  1 */
    52570042, /* 63182 (1585) [ 1,  0,  0,  0,  0,  1,  0,  1,  0] [ 6,  6,  6] -1 */
    52564270, /* 63183 (1585) [ 0,  0,  1,  0,  1,  0,  1,  0,  0] [ 6,  6,  6] -1 */
        7672, /* 63184 (1585) [ 0, -1,  0,  0,  0,  1, -1,  0,  0] [ 0,  0,  0]  1 */
    52561022, /* 63185 (1585) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 6,  6,  6] -1 */
        3360, /* 63186 (1585) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    52556866, /* 63187 (1585) [-1,  0,  0,  0,  0, -1,  0,  1,  0] [ 6,  6,  6] -1 */
       10816, /* 63188 (1585) [ 0,  0,  1,  1,  0,  0,  0,  1,  0] [ 0,  0,  0]  1 */
        3200, /* 63189 (1585) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
       11992, /* 63190 (1585) [ 0,  1,  0,  0,  0, -1, -1,  0,  0] [ 0,  0,  0]  1 */
       12064, /* 63191 (1585) [ 0,  1,  0,  0,  0,  1,  1,  0,  0] [ 0,  0,  0]  1 */
    52562794, /* 63192 (1585) [ 0,  0, -1,  0,  1,  0, -1,  0,  0] [ 6,  6,  6] -1 */
       10324, /* 63193 (1585) [ 0,  0,  1, -1,  0,  0,  0, -1,  0] [ 0,  0,  0]  1 */
    52562650, /* 63194 (1585) [ 0,  0, -1,  0, -1,  0,  1,  0,  0] [ 6,  6,  6] -1 */
       16484, /* 63195 (1586) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    52562962, /* 63196 (1586) [ 0,  0, -1,  1,  0,  0,  0, -1,  0] [ 6,  6,  6] -1 */
    18544642, /* 63197 (1586) [-1,  0,  0,  0,  0, -1,  0,  1,  0] [ 6,  6,  6]  1 */
    34021408, /* 63198 (1586) [ 0,  0, -1,  0,  1,  0, -1,  0,  0] [ 0,  0,  0] -1 */
    52561246, /* 63199 (1586) [ 0, -1,  0,  0,  0, -1,  1,  0,  0] [ 6,  6,  6] -1 */
       16320, /* 63200 (1586) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    52556970, /* 63201 (1586) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    52570094, /* 63202 (1586) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    34022704, /* 63203 (1586) [ 0,  0,  1,  0, -1,  0, -1,  0,  0] [ 0,  0,  0] -1 */
    34024008, /* 63204 (1586) [ 0,  1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    52562482, /* 63205 (1586) [ 0,  0, -1, -1,  0,  0,  0,  1,  0] [ 6,  6,  6] -1 */
    34020120, /* 63206 (1586) [ 0, -1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    18550570, /* 63207 (1586) [ 0,  0, -1,  0,  1,  0, -1,  0,  0] [ 6,  6,  6]  1 */
    34028596, /* 63208 (1586) [ 1,  0,  0,  0,  0, -1,  0, -1,  0] [ 0,  0,  0] -1 */
    18549282, /* 63209 (1586) [ 0, -1,  0,  1,  0,  0,  0,  0, -1] [ 6,  6,  6]  1 */
    18550426, /* 63210 (1586) [ 0,  0, -1,  0, -1,  0,  1,  0,  0] [ 6,  6,  6]  1 */
        7636, /* 63211 (1586) [ 0, -1,  0,  0,  0, -1,  1,  0,  0] [ 0,  0,  0]  1 */
    52561282, /* 63212 (1586) [ 0, -1,  0,  0,  0,  1, -1,  0,  0] [ 6,  6,  6] -1 */
        9352, /* 63213 (1586) [ 0,  0, -1,  1,  0,  0,  0, -1,  0] [ 0,  0,  0]  1 */
    52565602, /* 63214 (1586) [ 0,  1,  0,  0,  0, -1, -1,  0,  0] [ 6,  6,  6] -1 */
    34024496, /* 63215 (1586) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    18553170, /* 63216 (1586) [ 0,  1,  0, -1,  0,  0,  0,  0, -1] [ 6,  6,  6]  1 */
    52565674, /* 63217 (1586) [ 0,  1,  0,  0,  0,  1,  1,  0,  0] [ 6,  6,  6] -1 */
    52556810, /* 63218 (1586) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
        8872, /* 63219 (1586) [ 0,  0, -1, -1,  0,  0,  0,  1,  0] [ 0,  0,  0]  1 */
    18557758, /* 63220 (1586) [ 1,  0,  0,  0,  0, -1,  0, -1,  0] [ 6,  6,  6]  1 */
    34015528, /* 63221 (1586) [-1,  0,  0,  0,  0,  1,  0, -1,  0] [ 0,  0,  0] -1 */
    52564426, /* 63222 (1586) [ 0,  0,  1,  1,  0,  0,  0,  1,  0] [ 6,  6,  6] -1 */
    34019636, /* 63223 (1586) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    52563934, /* 63224 (1586) [ 0,  0,  1, -1,  0,  0,  0, -1,  0] [ 6,  6,  6] -1 */
    18551866, /* 63225 (1586) [ 0,  0,  1,  0, -1,  0, -1,  0,  0] [ 6,  6,  6]  1 */
        7672, /* 63226 (1586) [ 0, -1,  0,  0,  0,  1, -1,  0,  0] [ 0,  0,  0]  1 */
    34022884, /* 63227 (1586) [ 0,  0,  1,  0,  1,  0,  1,  0,  0] [ 0,  0,  0] -1 */
    52569930, /* 63228 (1586) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
        3360, /* 63229 (1586) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    18553658, /* 63230 (1586) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 6,  6,  6]  1 */
       10816, /* 63231 (1586) [ 0,  0,  1,  1,  0,  0,  0,  1,  0] [ 0,  0,  0]  1 */
        3200, /* 63232 (1586) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    18544690, /* 63233 (1586) [-1,  0,  0,  0,  0,  1,  0, -1,  0] [ 6,  6,  6]  1 */
       11992, /* 63234 (1586) [ 0,  1,  0,  0,  0, -1, -1,  0,  0] [ 0,  0,  0]  1 */
    34028656, /* 63235 (1586) [ 1,  0,  0,  0,  0,  1,  0,  1,  0] [ 0,  0,  0] -1 */
       12064, /* 63236 (1586) [ 0,  1,  0,  0,  0,  1,  1,  0,  0] [ 0,  0,  0]  1 */
    18557818, /* 63237 (1586) [ 1,  0,  0,  0,  0,  1,  0,  1,  0] [ 6,  6,  6]  1 */
    18552046, /* 63238 (1586) [ 0,  0,  1,  0,  1,  0,  1,  0,  0] [ 6,  6,  6]  1 */
    34021264, /* 63239 (1586) [ 0,  0, -1,  0, -1,  0,  1,  0,  0] [ 0,  0,  0] -1 */
    34015480, /* 63240 (1586) [-1,  0,  0,  0,  0, -1,  0,  1,  0] [ 0,  0,  0] -1 */
    18548798, /* 63241 (1586) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 6,  6,  6]  1 */
       10324, /* 63242 (1586) [ 0,  0,  1, -1,  0,  0,  0, -1,  0] [ 0,  0,  0]  1 */
       16484, /* 63243 (1587) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    17140694, /* 63244 (1587) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
       16320, /* 63245 (1587) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
     1420480, /* 63246 (1587) [-1,  0,  0,  0,  0,  1,  0, -1,  0] [ 0,  6,  0]  1 */
     1545598, /* 63247 (1587) [ 0,  0,  1, -1,  0,  0,  0, -1,  0] [ 0,  6,  6]  1 */
      121354, /* 63248 (1587) [-1,  0,  0,  0,  0, -1,  0,  1,  0] [ 0,  0,  6]  1 */
    17015152, /* 63249 (1587) [ 0,  0, -1,  0, -1,  0,  1,  0,  0] [ 6,  0,  0]  1 */
     1424588, /* 63250 (1587) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 0,  6,  0]  1 */
     1538474, /* 63251 (1587) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
    18550570, /* 63252 (1587) [ 0,  0, -1,  0,  1,  0, -1,  0,  0] [ 6,  6,  6]  1 */
      127282, /* 63253 (1587) [ 0,  0, -1,  0,  1,  0, -1,  0,  0] [ 0,  0,  6]  1 */
    17136274, /* 63254 (1587) [ 0,  1,  0,  0,  0,  1,  1,  0,  0] [ 6,  0,  6]  1 */
     1427836, /* 63255 (1587) [ 0,  0,  1,  0,  1,  0,  1,  0,  0] [ 0,  6,  0]  1 */
        9352, /* 63256 (1587) [ 0,  0, -1,  1,  0,  0,  0, -1,  0] [ 0,  0,  0]  1 */
    17014008, /* 63257 (1587) [ 0, -1,  0,  1,  0,  0,  0,  0, -1] [ 6,  0,  0]  1 */
    18426648, /* 63258 (1587) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
     1420432, /* 63259 (1587) [-1,  0,  0,  0,  0, -1,  0,  1,  0] [ 0,  6,  0]  1 */
        8872, /* 63260 (1587) [ 0,  0, -1, -1,  0,  0,  0,  1,  0] [ 0,  0,  0]  1 */
    18432160, /* 63261 (1587) [ 0,  0, -1, -1,  0,  0,  0,  1,  0] [ 6,  6,  0]  1 */
    17018384, /* 63262 (1587) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 6,  0,  0]  1 */
      125994, /* 63263 (1587) [ 0, -1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  6]  1 */
    18433612, /* 63264 (1587) [ 0,  0,  1, -1,  0,  0,  0, -1,  0] [ 6,  6,  0]  1 */
    17133562, /* 63265 (1587) [ 0,  0, -1,  1,  0,  0,  0, -1,  0] [ 6,  0,  6]  1 */
      121402, /* 63266 (1587) [-1,  0,  0,  0,  0,  1,  0, -1,  0] [ 0,  0,  6]  1 */
    17131846, /* 63267 (1587) [ 0, -1,  0,  0,  0, -1,  1,  0,  0] [ 6,  0,  6]  1 */
     1427656, /* 63268 (1587) [ 0,  0,  1,  0, -1,  0, -1,  0,  0] [ 0,  6,  0]  1 */
       10324, /* 63269 (1587) [ 0,  0,  1, -1,  0,  0,  0, -1,  0] [ 0,  0,  0]  1 */
     1538634, /* 63270 (1587) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
     1544146, /* 63271 (1587) [ 0,  0, -1, -1,  0,  0,  0,  1,  0] [ 0,  6,  6]  1 */
    17134534, /* 63272 (1587) [ 0,  0,  1, -1,  0,  0,  0, -1,  0] [ 6,  0,  6]  1 */
      127138, /* 63273 (1587) [ 0,  0, -1,  0, -1,  0,  1,  0,  0] [ 0,  0,  6]  1 */
    18550426, /* 63274 (1587) [ 0,  0, -1,  0, -1,  0,  1,  0,  0] [ 6,  6,  6]  1 */
    17017896, /* 63275 (1587) [ 0,  1,  0, -1,  0,  0,  0,  0, -1] [ 6,  0,  0]  1 */
    18439772, /* 63276 (1587) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    17140530, /* 63277 (1587) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  6]  1 */
    18553170, /* 63278 (1587) [ 0,  1,  0, -1,  0,  0,  0,  0, -1] [ 6,  6,  6]  1 */
    17016592, /* 63279 (1587) [ 0,  0,  1,  0, -1,  0, -1,  0,  0] [ 6,  0,  0]  1 */
    18430960, /* 63280 (1587) [ 0, -1,  0,  0,  0,  1, -1,  0,  0] [ 6,  6,  0]  1 */
      129882, /* 63281 (1587) [ 0,  1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  6]  1 */
    18435280, /* 63282 (1587) [ 0,  1,  0,  0,  0, -1, -1,  0,  0] [ 6,  6,  0]  1 */
    18435352, /* 63283 (1587) [ 0,  1,  0,  0,  0,  1,  1,  0,  0] [ 6,  6,  0]  1 */
    18553658, /* 63284 (1587) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 6,  6,  6]  1 */
     1426360, /* 63285 (1587) [ 0,  0, -1,  0,  1,  0, -1,  0,  0] [ 0,  6,  0]  1 */
       10816, /* 63286 (1587) [ 0,  0,  1,  1,  0,  0,  0,  1,  0] [ 0,  0,  0]  1 */
    18434104, /* 63287 (1587) [ 0,  0,  1,  1,  0,  0,  0,  1,  0] [ 6,  6,  0]  1 */
    17016772, /* 63288 (1587) [ 0,  0,  1,  0,  1,  0,  1,  0,  0] [ 6,  0,  0]  1 */
     1425072, /* 63289 (1587) [ 0, -1,  0,  1,  0,  0,  0,  0, -1] [ 0,  6,  0]  1 */
       11992, /* 63290 (1587) [ 0,  1,  0,  0,  0, -1, -1,  0,  0] [ 0,  0,  0]  1 */
       12064, /* 63291 (1587) [ 0,  1,  0,  0,  0,  1,  1,  0,  0] [ 0,  0,  0]  1 */
      130370, /* 63292 (1587) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 0,  0,  6]  1 */
     1551758, /* 63293 (1587) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
    18557818, /* 63294 (1587) [ 1,  0,  0,  0,  0,  1,  0,  1,  0] [ 6,  6,  6]  1 */
      125510, /* 63295 (1587) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  6]  1 */
    18548798, /* 63296 (1587) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    18544642, /* 63297 (1587) [-1,  0,  0,  0,  0, -1,  0,  1,  0] [ 6,  6,  6]  1 */
     1433548, /* 63298 (1587) [ 1,  0,  0,  0,  0, -1,  0, -1,  0] [ 0,  6,  0]  1 */
    17127570, /* 63299 (1587) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6]  1 */
     1542946, /* 63300 (1587) [ 0, -1,  0,  0,  0,  1, -1,  0,  0] [ 0,  6,  6]  1 */
    17133082, /* 63301 (1587) [ 0,  0, -1, -1,  0,  0,  0,  1,  0] [ 6,  0,  6]  1 */
     1547266, /* 63302 (1587) [ 0,  1,  0,  0,  0, -1, -1,  0,  0] [ 0,  6,  6]  1 */
     1546090, /* 63303 (1587) [ 0,  0,  1,  1,  0,  0,  0,  1,  0] [ 0,  6,  6]  1 */
      128578, /* 63304 (1587) [ 0,  0,  1,  0, -1,  0, -1,  0,  0] [ 0,  0,  6]  1 */
    18551866, /* 63305 (1587) [ 0,  0,  1,  0, -1,  0, -1,  0,  0] [ 6,  6,  6]  1 */
        7672, /* 63306 (1587) [ 0, -1,  0,  0,  0,  1, -1,  0,  0] [ 0,  0,  0]  1 */
        3360, /* 63307 (1587) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    18426488, /* 63308 (1587) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    17013524, /* 63309 (1587) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 6,  0,  0]  1 */
    18552046, /* 63310 (1587) [ 0,  0,  1,  0,  1,  0,  1,  0,  0] [ 6,  6,  6]  1 */
    17022544, /* 63311 (1587) [ 1,  0,  0,  0,  0,  1,  0,  1,  0] [ 6,  0,  0]  1 */
    18439608, /* 63312 (1587) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
    17009368, /* 63313 (1587) [-1,  0,  0,  0,  0, -1,  0,  1,  0] [ 6,  0,  0]  1 */
      128758, /* 63314 (1587) [ 0,  0,  1,  0,  1,  0,  1,  0,  0] [ 0,  0,  6]  1 */
    17127410, /* 63315 (1587) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
    17131882, /* 63316 (1587) [ 0, -1,  0,  0,  0,  1, -1,  0,  0] [ 6,  0,  6]  1 */
     1429448, /* 63317 (1587) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 0,  6,  0]  1 */
    17015296, /* 63318 (1587) [ 0,  0, -1,  0,  1,  0, -1,  0,  0] [ 6,  0,  0]  1 */
    17136202, /* 63319 (1587) [ 0,  1,  0,  0,  0, -1, -1,  0,  0] [ 6,  0,  6]  1 */
     1547338, /* 63320 (1587) [ 0,  1,  0,  0,  0,  1,  1,  0,  0] [ 0,  6,  6]  1 */
      134530, /* 63321 (1587) [ 1,  0,  0,  0,  0,  1,  0,  1,  0] [ 0,  0,  6]  1 */
    18432640, /* 63322 (1587) [ 0,  0, -1,  1,  0,  0,  0, -1,  0] [ 6,  6,  0]  1 */
    17135026, /* 63323 (1587) [ 0,  0,  1,  1,  0,  0,  0,  1,  0] [ 6,  0,  6]  1 */
    18549282, /* 63324 (1587) [ 0, -1,  0,  1,  0,  0,  0,  0, -1] [ 6,  6,  6]  1 */
        7636, /* 63325 (1587) [ 0, -1,  0,  0,  0, -1,  1,  0,  0] [ 0,  0,  0]  1 */
    18430924, /* 63326 (1587) [ 0, -1,  0,  0,  0, -1,  1,  0,  0] [ 6,  6,  0]  1 */
     1433608, /* 63327 (1587) [ 1,  0,  0,  0,  0,  1,  0,  1,  0] [ 0,  6,  0]  1 */
    17022484, /* 63328 (1587) [ 1,  0,  0,  0,  0, -1,  0, -1,  0] [ 6,  0,  0]  1 */
     1551594, /* 63329 (1587) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
    18557758, /* 63330 (1587) [ 1,  0,  0,  0,  0, -1,  0, -1,  0] [ 6,  6,  6]  1 */
     1426216, /* 63331 (1587) [ 0,  0, -1,  0, -1,  0,  1,  0,  0] [ 0,  6,  0]  1 */
      134470, /* 63332 (1587) [ 1,  0,  0,  0,  0, -1,  0, -1,  0] [ 0,  0,  6]  1 */
     1544626, /* 63333 (1587) [ 0,  0, -1,  1,  0,  0,  0, -1,  0] [ 0,  6,  6]  1 */
    17009416, /* 63334 (1587) [-1,  0,  0,  0,  0,  1,  0, -1,  0] [ 6,  0,  0]  1 */
        3200, /* 63335 (1587) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    18544690, /* 63336 (1587) [-1,  0,  0,  0,  0,  1,  0, -1,  0] [ 6,  6,  6]  1 */
     1542910, /* 63337 (1587) [ 0, -1,  0,  0,  0, -1,  1,  0,  0] [ 0,  6,  6]  1 */
     1428960, /* 63338 (1587) [ 0,  1,  0, -1,  0,  0,  0,  0, -1] [ 0,  6,  0]  1 */
       16484, /* 63339 (1588) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34139362, /* 63340 (1588) [ 0,  0, -1,  0, -1,  0,  1,  0,  0] [ 0,  0,  6] -1 */
    17140694, /* 63341 (1588) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
       16320, /* 63342 (1588) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    52451996, /* 63343 (1588) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
     1420480, /* 63344 (1588) [-1,  0,  0,  0,  0,  1,  0, -1,  0] [ 0,  6,  0]  1 */
     1545598, /* 63345 (1588) [ 0,  0,  1, -1,  0,  0,  0, -1,  0] [ 0,  6,  6]  1 */
    51152754, /* 63346 (1588) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  6] -1 */
    52565394, /* 63347 (1588) [ 0,  1,  0, -1,  0,  0,  0,  0, -1] [ 6,  6,  6] -1 */
      121354, /* 63348 (1588) [-1,  0,  0,  0,  0, -1,  0,  1,  0] [ 0,  0,  6]  1 */
    51028816, /* 63349 (1588) [ 0,  0,  1,  0, -1,  0, -1,  0,  0] [ 6,  0,  0] -1 */
    17015152, /* 63350 (1588) [ 0,  0, -1,  0, -1,  0,  1,  0,  0] [ 6,  0,  0]  1 */
     1424588, /* 63351 (1588) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 0,  6,  0]  1 */
     1538474, /* 63352 (1588) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
    18550570, /* 63353 (1588) [ 0,  0, -1,  0,  1,  0, -1,  0,  0] [ 6,  6,  6]  1 */
      127282, /* 63354 (1588) [ 0,  0, -1,  0,  1,  0, -1,  0,  0] [ 0,  0,  6]  1 */
    17136274, /* 63355 (1588) [ 0,  1,  0,  0,  0,  1,  1,  0,  0] [ 6,  0,  6]  1 */
    34019896, /* 63356 (1588) [ 0, -1,  0,  0,  0,  1, -1,  0,  0] [ 0,  0,  0] -1 */
    52443184, /* 63357 (1588) [ 0, -1,  0,  0,  0,  1, -1,  0,  0] [ 6,  6,  0] -1 */
    34015584, /* 63358 (1588) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    34142106, /* 63359 (1588) [ 0,  1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  6] -1 */
     1427836, /* 63360 (1588) [ 0,  0,  1,  0,  1,  0,  1,  0,  0] [ 0,  6,  0]  1 */
    52447576, /* 63361 (1588) [ 0,  1,  0,  0,  0,  1,  1,  0,  0] [ 6,  6,  0] -1 */
        9352, /* 63362 (1588) [ 0,  0, -1,  1,  0,  0,  0, -1,  0] [ 0,  0,  0]  1 */
    52565882, /* 63363 (1588) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    35438584, /* 63364 (1588) [ 0,  0, -1,  0,  1,  0, -1,  0,  0] [ 0,  6,  0] -1 */
    17014008, /* 63365 (1588) [ 0, -1,  0,  1,  0,  0,  0,  0, -1] [ 6,  0,  0]  1 */
    34023040, /* 63366 (1588) [ 0,  0,  1,  1,  0,  0,  0,  1,  0] [ 0,  0,  0] -1 */
    52446328, /* 63367 (1588) [ 0,  0,  1,  1,  0,  0,  0,  1,  0] [ 6,  6,  0] -1 */
    18426648, /* 63368 (1588) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
     1420432, /* 63369 (1588) [-1,  0,  0,  0,  0, -1,  0,  1,  0] [ 0,  6,  0]  1 */
        8872, /* 63370 (1588) [ 0,  0, -1, -1,  0,  0,  0,  1,  0] [ 0,  0,  0]  1 */
    18432160, /* 63371 (1588) [ 0,  0, -1, -1,  0,  0,  0,  1,  0] [ 6,  6,  0]  1 */
    51028996, /* 63372 (1588) [ 0,  0,  1,  0,  1,  0,  1,  0,  0] [ 6,  0,  0] -1 */
    34024288, /* 63373 (1588) [ 0,  1,  0,  0,  0,  1,  1,  0,  0] [ 0,  0,  0] -1 */
    35563982, /* 63374 (1588) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
    52570042, /* 63375 (1588) [ 1,  0,  0,  0,  0,  1,  0,  1,  0] [ 6,  6,  6] -1 */
    17018384, /* 63376 (1588) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 6,  0,  0]  1 */
    34137734, /* 63377 (1588) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    52561022, /* 63378 (1588) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 6,  6,  6] -1 */
      125994, /* 63379 (1588) [ 0, -1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  6]  1 */
    51034768, /* 63380 (1588) [ 1,  0,  0,  0,  0,  1,  0,  1,  0] [ 6,  0,  0] -1 */
    52556866, /* 63381 (1588) [-1,  0,  0,  0,  0, -1,  0,  1,  0] [ 6,  6,  6] -1 */
    51139794, /* 63382 (1588) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6] -1 */
    51021592, /* 63383 (1588) [-1,  0,  0,  0,  0, -1,  0,  1,  0] [ 6,  0,  0] -1 */
    34140982, /* 63384 (1588) [ 0,  0,  1,  0,  1,  0,  1,  0,  0] [ 0,  0,  6] -1 */
    35555170, /* 63385 (1588) [ 0, -1,  0,  0,  0,  1, -1,  0,  0] [ 0,  6,  6] -1 */
    18433612, /* 63386 (1588) [ 0,  0,  1, -1,  0,  0,  0, -1,  0] [ 6,  6,  0]  1 */
    17133562, /* 63387 (1588) [ 0,  0, -1,  1,  0,  0,  0, -1,  0] [ 6,  0,  6]  1 */
    35559490, /* 63388 (1588) [ 0,  1,  0,  0,  0, -1, -1,  0,  0] [ 0,  6,  6] -1 */
      121402, /* 63389 (1588) [-1,  0,  0,  0,  0,  1,  0, -1,  0] [ 0,  0,  6]  1 */
    35559562, /* 63390 (1588) [ 0,  1,  0,  0,  0,  1,  1,  0,  0] [ 0,  6,  6] -1 */
    52444864, /* 63391 (1588) [ 0,  0, -1,  1,  0,  0,  0, -1,  0] [ 6,  6,  0] -1 */
    17131846, /* 63392 (1588) [ 0, -1,  0,  0,  0, -1,  1,  0,  0] [ 6,  0,  6]  1 */
     1427656, /* 63393 (1588) [ 0,  0,  1,  0, -1,  0, -1,  0,  0] [ 0,  6,  0]  1 */
    35558314, /* 63394 (1588) [ 0,  0,  1,  1,  0,  0,  0,  1,  0] [ 0,  6,  6] -1 */
       10324, /* 63395 (1588) [ 0,  0,  1, -1,  0,  0,  0, -1,  0] [ 0,  0,  0]  1 */
     1538634, /* 63396 (1588) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
    52443148, /* 63397 (1588) [ 0, -1,  0,  0,  0, -1,  1,  0,  0] [ 6,  6,  0] -1 */
     1544146, /* 63398 (1588) [ 0,  0, -1, -1,  0,  0,  0,  1,  0] [ 0,  6,  6]  1 */
    51034708, /* 63399 (1588) [ 1,  0,  0,  0,  0, -1,  0, -1,  0] [ 6,  0,  0] -1 */
    17134534, /* 63400 (1588) [ 0,  0,  1, -1,  0,  0,  0, -1,  0] [ 6,  0,  6]  1 */
    35438440, /* 63401 (1588) [ 0,  0, -1,  0, -1,  0,  1,  0,  0] [ 0,  6,  0] -1 */
    34140802, /* 63402 (1588) [ 0,  0,  1,  0, -1,  0, -1,  0,  0] [ 0,  0,  6] -1 */
      127138, /* 63403 (1588) [ 0,  0, -1,  0, -1,  0,  1,  0,  0] [ 0,  0,  6]  1 */
    18550426, /* 63404 (1588) [ 0,  0, -1,  0, -1,  0,  1,  0,  0] [ 6,  6,  6]  1 */
    52564090, /* 63405 (1588) [ 0,  0,  1,  0, -1,  0, -1,  0,  0] [ 6,  6,  6] -1 */
    35556850, /* 63406 (1588) [ 0,  0, -1,  1,  0,  0,  0, -1,  0] [ 0,  6,  6] -1 */
    51021640, /* 63407 (1588) [-1,  0,  0,  0,  0,  1,  0, -1,  0] [ 6,  0,  0] -1 */
    17017896, /* 63408 (1588) [ 0,  1,  0, -1,  0,  0,  0,  0, -1] [ 6,  0,  0]  1 */
    18439772, /* 63409 (1588) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    34015424, /* 63410 (1588) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    34028708, /* 63411 (1588) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    17140530, /* 63412 (1588) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  6]  1 */
    52438712, /* 63413 (1588) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
    18553170, /* 63414 (1588) [ 0,  1,  0, -1,  0,  0,  0,  0, -1] [ 6,  6,  6]  1 */
    17016592, /* 63415 (1588) [ 0,  0,  1,  0, -1,  0, -1,  0,  0] [ 6,  0,  0]  1 */
    51025748, /* 63416 (1588) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 6,  0,  0] -1 */
    18430960, /* 63417 (1588) [ 0, -1,  0,  0,  0,  1, -1,  0,  0] [ 6,  6,  0]  1 */
    35441184, /* 63418 (1588) [ 0,  1,  0, -1,  0,  0,  0,  0, -1] [ 0,  6,  0] -1 */
    52564270, /* 63419 (1588) [ 0,  0,  1,  0,  1,  0,  1,  0,  0] [ 6,  6,  6] -1 */
      129882, /* 63420 (1588) [ 0,  1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  6]  1 */
    18435280, /* 63421 (1588) [ 0,  1,  0,  0,  0, -1, -1,  0,  0] [ 6,  6,  0]  1 */
    51152918, /* 63422 (1588) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
    18435352, /* 63423 (1588) [ 0,  1,  0,  0,  0,  1,  1,  0,  0] [ 6,  6,  0]  1 */
    34028544, /* 63424 (1588) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    18553658, /* 63425 (1588) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    52451832, /* 63426 (1588) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
     1426360, /* 63427 (1588) [ 0,  0, -1,  0,  1,  0, -1,  0,  0] [ 0,  6,  0]  1 */
       10816, /* 63428 (1588) [ 0,  0,  1,  1,  0,  0,  0,  1,  0] [ 0,  0,  0]  1 */
    18434104, /* 63429 (1588) [ 0,  0,  1,  1,  0,  0,  0,  1,  0] [ 6,  6,  0]  1 */
    17016772, /* 63430 (1588) [ 0,  0,  1,  0,  1,  0,  1,  0,  0] [ 6,  0,  0]  1 */
     1425072, /* 63431 (1588) [ 0, -1,  0,  1,  0,  0,  0,  0, -1] [ 0,  6,  0]  1 */
       11992, /* 63432 (1588) [ 0,  1,  0,  0,  0, -1, -1,  0,  0] [ 0,  0,  0]  1 */
    51139634, /* 63433 (1588) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
    35441672, /* 63434 (1588) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 0,  6,  0] -1 */
       12064, /* 63435 (1588) [ 0,  1,  0,  0,  0,  1,  1,  0,  0] [ 0,  0,  0]  1 */
    51027520, /* 63436 (1588) [ 0,  0, -1,  0,  1,  0, -1,  0,  0] [ 6,  0,  0] -1 */
    51144106, /* 63437 (1588) [ 0, -1,  0,  0,  0,  1, -1,  0,  0] [ 6,  0,  6] -1 */
      130370, /* 63438 (1588) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 0,  0,  6]  1 */
     1551758, /* 63439 (1588) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
    35550698, /* 63440 (1588) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
    52562794, /* 63441 (1588) [ 0,  0, -1,  0,  1,  0, -1,  0,  0] [ 6,  6,  6] -1 */
    18557818, /* 63442 (1588) [ 1,  0,  0,  0,  0,  1,  0,  1,  0] [ 6,  6,  6]  1 */
    51148498, /* 63443 (1588) [ 0,  1,  0,  0,  0,  1,  1,  0,  0] [ 6,  0,  6] -1 */
      125510, /* 63444 (1588) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  6]  1 */
    18548798, /* 63445 (1588) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    34146754, /* 63446 (1588) [ 1,  0,  0,  0,  0,  1,  0,  1,  0] [ 0,  0,  6] -1 */
    51148426, /* 63447 (1588) [ 0,  1,  0,  0,  0, -1, -1,  0,  0] [ 6,  0,  6] -1 */
    18544642, /* 63448 (1588) [-1,  0,  0,  0,  0, -1,  0,  1,  0] [ 6,  6,  6]  1 */
    51147250, /* 63449 (1588) [ 0,  0,  1,  1,  0,  0,  0,  1,  0] [ 6,  0,  6] -1 */
     1433548, /* 63450 (1588) [ 1,  0,  0,  0,  0, -1,  0, -1,  0] [ 0,  6,  0]  1 */
    34019860, /* 63451 (1588) [ 0, -1,  0,  0,  0, -1,  1,  0,  0] [ 0,  0,  0] -1 */
    17127570, /* 63452 (1588) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6]  1 */
    35445832, /* 63453 (1588) [ 1,  0,  0,  0,  0,  1,  0,  1,  0] [ 0,  6,  0] -1 */
    52561506, /* 63454 (1588) [ 0, -1,  0,  1,  0,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    51026232, /* 63455 (1588) [ 0, -1,  0,  1,  0,  0,  0,  0, -1] [ 6,  0,  0] -1 */
     1542946, /* 63456 (1588) [ 0, -1,  0,  0,  0,  1, -1,  0,  0] [ 0,  6,  6]  1 */
    17133082, /* 63457 (1588) [ 0,  0, -1, -1,  0,  0,  0,  1,  0] [ 6,  0,  6]  1 */
     1547266, /* 63458 (1588) [ 0,  1,  0,  0,  0, -1, -1,  0,  0] [ 0,  6,  6]  1 */
    35432656, /* 63459 (1588) [-1,  0,  0,  0,  0, -1,  0,  1,  0] [ 0,  6,  0] -1 */
    52444384, /* 63460 (1588) [ 0,  0, -1, -1,  0,  0,  0,  1,  0] [ 6,  6,  0] -1 */
    35563818, /* 63461 (1588) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  6] -1 */
    52569982, /* 63462 (1588) [ 1,  0,  0,  0,  0, -1,  0, -1,  0] [ 6,  6,  6] -1 */
     1546090, /* 63463 (1588) [ 0,  0,  1,  1,  0,  0,  0,  1,  0] [ 0,  6,  6]  1 */
    34146694, /* 63464 (1588) [ 1,  0,  0,  0,  0, -1,  0, -1,  0] [ 0,  0,  6] -1 */
    34133626, /* 63465 (1588) [-1,  0,  0,  0,  0,  1,  0, -1,  0] [ 0,  0,  6] -1 */
    52556914, /* 63466 (1588) [-1,  0,  0,  0,  0,  1,  0, -1,  0] [ 6,  6,  6] -1 */
    35555134, /* 63467 (1588) [ 0, -1,  0,  0,  0, -1,  1,  0,  0] [ 0,  6,  6] -1 */
    34022548, /* 63468 (1588) [ 0,  0,  1, -1,  0,  0,  0, -1,  0] [ 0,  0,  0] -1 */
      128578, /* 63469 (1588) [ 0,  0,  1,  0, -1,  0, -1,  0,  0] [ 0,  0,  6]  1 */
    18551866, /* 63470 (1588) [ 0,  0,  1,  0, -1,  0, -1,  0,  0] [ 6,  6,  6]  1 */
        7672, /* 63471 (1588) [ 0, -1,  0,  0,  0,  1, -1,  0,  0] [ 0,  0,  0]  1 */
    35556370, /* 63472 (1588) [ 0,  0, -1, -1,  0,  0,  0,  1,  0] [ 0,  6,  6] -1 */
        3360, /* 63473 (1588) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    18426488, /* 63474 (1588) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    35432704, /* 63475 (1588) [-1,  0,  0,  0,  0,  1,  0, -1,  0] [ 0,  6,  0] -1 */
    35557822, /* 63476 (1588) [ 0,  0,  1, -1,  0,  0,  0, -1,  0] [ 0,  6,  6] -1 */
    17013524, /* 63477 (1588) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 6,  0,  0]  1 */
    34133578, /* 63478 (1588) [-1,  0,  0,  0,  0, -1,  0,  1,  0] [ 0,  0,  6] -1 */
    18552046, /* 63479 (1588) [ 0,  0,  1,  0,  1,  0,  1,  0,  0] [ 6,  6,  6]  1 */
    51027376, /* 63480 (1588) [ 0,  0, -1,  0, -1,  0,  1,  0,  0] [ 6,  0,  0] -1 */
    35436812, /* 63481 (1588) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 0,  6,  0] -1 */
    34139506, /* 63482 (1588) [ 0,  0, -1,  0,  1,  0, -1,  0,  0] [ 0,  0,  6] -1 */
    52562650, /* 63483 (1588) [ 0,  0, -1,  0, -1,  0,  1,  0,  0] [ 6,  6,  6] -1 */
    17022544, /* 63484 (1588) [ 1,  0,  0,  0,  0,  1,  0,  1,  0] [ 6,  0,  0]  1 */
    18439608, /* 63485 (1588) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
    51030120, /* 63486 (1588) [ 0,  1,  0, -1,  0,  0,  0,  0, -1] [ 6,  0,  0] -1 */
    35440060, /* 63487 (1588) [ 0,  0,  1,  0,  1,  0,  1,  0,  0] [ 0,  6,  0] -1 */
    34021576, /* 63488 (1588) [ 0,  0, -1,  1,  0,  0,  0, -1,  0] [ 0,  0,  0] -1 */
    17009368, /* 63489 (1588) [-1,  0,  0,  0,  0, -1,  0,  1,  0] [ 6,  0,  0]  1 */
      128758, /* 63490 (1588) [ 0,  0,  1,  0,  1,  0,  1,  0,  0] [ 0,  0,  6]  1 */
    17127410, /* 63491 (1588) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
    17131882, /* 63492 (1588) [ 0, -1,  0,  0,  0,  1, -1,  0,  0] [ 6,  0,  6]  1 */
     1429448, /* 63493 (1588) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 0,  6,  0]  1 */
    17015296, /* 63494 (1588) [ 0,  0, -1,  0,  1,  0, -1,  0,  0] [ 6,  0,  0]  1 */
    52438872, /* 63495 (1588) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
    17136202, /* 63496 (1588) [ 0,  1,  0,  0,  0, -1, -1,  0,  0] [ 6,  0,  6]  1 */
     1547338, /* 63497 (1588) [ 0,  1,  0,  0,  0,  1,  1,  0,  0] [ 0,  6,  6]  1 */
      134530, /* 63498 (1588) [ 1,  0,  0,  0,  0,  1,  0,  1,  0] [ 0,  0,  6]  1 */
    34021096, /* 63499 (1588) [ 0,  0, -1, -1,  0,  0,  0,  1,  0] [ 0,  0,  0] -1 */
    18432640, /* 63500 (1588) [ 0,  0, -1,  1,  0,  0,  0, -1,  0] [ 6,  6,  0]  1 */
    52447504, /* 63501 (1588) [ 0,  1,  0,  0,  0, -1, -1,  0,  0] [ 6,  6,  0] -1 */
    51030608, /* 63502 (1588) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 6,  0,  0] -1 */
    17135026, /* 63503 (1588) [ 0,  0,  1,  1,  0,  0,  0,  1,  0] [ 6,  0,  6]  1 */
    18549282, /* 63504 (1588) [ 0, -1,  0,  1,  0,  0,  0,  0, -1] [ 6,  6,  6]  1 */
        7636, /* 63505 (1588) [ 0, -1,  0,  0,  0, -1,  1,  0,  0] [ 0,  0,  0]  1 */
    18430924, /* 63506 (1588) [ 0, -1,  0,  0,  0, -1,  1,  0,  0] [ 6,  6,  0]  1 */
     1433608, /* 63507 (1588) [ 1,  0,  0,  0,  0,  1,  0,  1,  0] [ 0,  6,  0]  1 */
    34138218, /* 63508 (1588) [ 0, -1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  6] -1 */
    35437296, /* 63509 (1588) [ 0, -1,  0,  1,  0,  0,  0,  0, -1] [ 0,  6,  0] -1 */
    17022484, /* 63510 (1588) [ 1,  0,  0,  0,  0, -1,  0, -1,  0] [ 6,  0,  0]  1 */
    52445836, /* 63511 (1588) [ 0,  0,  1, -1,  0,  0,  0, -1,  0] [ 6,  6,  0] -1 */
    34024216, /* 63512 (1588) [ 0,  1,  0,  0,  0, -1, -1,  0,  0] [ 0,  0,  0] -1 */
     1551594, /* 63513 (1588) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
    51145786, /* 63514 (1588) [ 0,  0, -1,  1,  0,  0,  0, -1,  0] [ 6,  0,  6] -1 */
    18557758, /* 63515 (1588) [ 1,  0,  0,  0,  0, -1,  0, -1,  0] [ 6,  6,  6]  1 */
    34142594, /* 63516 (1588) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    51144070, /* 63517 (1588) [ 0, -1,  0,  0,  0, -1,  1,  0,  0] [ 6,  0,  6] -1 */
    35439880, /* 63518 (1588) [ 0,  0,  1,  0, -1,  0, -1,  0,  0] [ 0,  6,  0] -1 */
     1426216, /* 63519 (1588) [ 0,  0, -1,  0, -1,  0,  1,  0,  0] [ 0,  6,  0]  1 */
    35445772, /* 63520 (1588) [ 1,  0,  0,  0,  0, -1,  0, -1,  0] [ 0,  6,  0] -1 */
    35550858, /* 63521 (1588) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6] -1 */
      134470, /* 63522 (1588) [ 1,  0,  0,  0,  0, -1,  0, -1,  0] [ 0,  0,  6]  1 */
    51145306, /* 63523 (1588) [ 0,  0, -1, -1,  0,  0,  0,  1,  0] [ 6,  0,  6] -1 */
     1544626, /* 63524 (1588) [ 0,  0, -1,  1,  0,  0,  0, -1,  0] [ 0,  6,  6]  1 */
    17009416, /* 63525 (1588) [-1,  0,  0,  0,  0,  1,  0, -1,  0] [ 6,  0,  0]  1 */
        3200, /* 63526 (1588) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    18544690, /* 63527 (1588) [-1,  0,  0,  0,  0,  1,  0, -1,  0] [ 6,  6,  6]  1 */
     1542910, /* 63528 (1588) [ 0, -1,  0,  0,  0, -1,  1,  0,  0] [ 0,  6,  6]  1 */
    51146758, /* 63529 (1588) [ 0,  0,  1, -1,  0,  0,  0, -1,  0] [ 6,  0,  6] -1 */
     1428960, /* 63530 (1588) [ 0,  1,  0, -1,  0,  0,  0,  0, -1] [ 0,  6,  0]  1 */
       16484, /* 63531 (1589) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34139362, /* 63532 (1589) [ 0,  0, -1,  0, -1,  0,  1,  0,  0] [ 0,  0,  6] -1 */
    17140694, /* 63533 (1589) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
       16320, /* 63534 (1589) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
     1545598, /* 63535 (1589) [ 0,  0,  1, -1,  0,  0,  0, -1,  0] [ 0,  6,  6]  1 */
    52565394, /* 63536 (1589) [ 0,  1,  0, -1,  0,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    51028816, /* 63537 (1589) [ 0,  0,  1,  0, -1,  0, -1,  0,  0] [ 6,  0,  0] -1 */
     1538474, /* 63538 (1589) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
    17136274, /* 63539 (1589) [ 0,  1,  0,  0,  0,  1,  1,  0,  0] [ 6,  0,  6]  1 */
    34142106, /* 63540 (1589) [ 0,  1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  6] -1 */
        9352, /* 63541 (1589) [ 0,  0, -1,  1,  0,  0,  0, -1,  0] [ 0,  0,  0]  1 */
    52565882, /* 63542 (1589) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    35438584, /* 63543 (1589) [ 0,  0, -1,  0,  1,  0, -1,  0,  0] [ 0,  6,  0] -1 */
    18426648, /* 63544 (1589) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
        8872, /* 63545 (1589) [ 0,  0, -1, -1,  0,  0,  0,  1,  0] [ 0,  0,  0]  1 */
    51028996, /* 63546 (1589) [ 0,  0,  1,  0,  1,  0,  1,  0,  0] [ 6,  0,  0] -1 */
    18432160, /* 63547 (1589) [ 0,  0, -1, -1,  0,  0,  0,  1,  0] [ 6,  6,  0]  1 */
    52570042, /* 63548 (1589) [ 1,  0,  0,  0,  0,  1,  0,  1,  0] [ 6,  6,  6] -1 */
    34137734, /* 63549 (1589) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    52561022, /* 63550 (1589) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    51034768, /* 63551 (1589) [ 1,  0,  0,  0,  0,  1,  0,  1,  0] [ 6,  0,  0] -1 */
    52556866, /* 63552 (1589) [-1,  0,  0,  0,  0, -1,  0,  1,  0] [ 6,  6,  6] -1 */
    51021592, /* 63553 (1589) [-1,  0,  0,  0,  0, -1,  0,  1,  0] [ 6,  0,  0] -1 */
    34140982, /* 63554 (1589) [ 0,  0,  1,  0,  1,  0,  1,  0,  0] [ 0,  0,  6] -1 */
    18433612, /* 63555 (1589) [ 0,  0,  1, -1,  0,  0,  0, -1,  0] [ 6,  6,  0]  1 */
    17133562, /* 63556 (1589) [ 0,  0, -1,  1,  0,  0,  0, -1,  0] [ 6,  0,  6]  1 */
    17131846, /* 63557 (1589) [ 0, -1,  0,  0,  0, -1,  1,  0,  0] [ 6,  0,  6]  1 */
       10324, /* 63558 (1589) [ 0,  0,  1, -1,  0,  0,  0, -1,  0] [ 0,  0,  0]  1 */
     1538634, /* 63559 (1589) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
     1544146, /* 63560 (1589) [ 0,  0, -1, -1,  0,  0,  0,  1,  0] [ 0,  6,  6]  1 */
    51034708, /* 63561 (1589) [ 1,  0,  0,  0,  0, -1,  0, -1,  0] [ 6,  0,  0] -1 */
    17134534, /* 63562 (1589) [ 0,  0,  1, -1,  0,  0,  0, -1,  0] [ 6,  0,  6]  1 */
    35438440, /* 63563 (1589) [ 0,  0, -1,  0, -1,  0,  1,  0,  0] [ 0,  6,  0] -1 */
    34140802, /* 63564 (1589) [ 0,  0,  1,  0, -1,  0, -1,  0,  0] [ 0,  0,  6] -1 */
    52564090, /* 63565 (1589) [ 0,  0,  1,  0, -1,  0, -1,  0,  0] [ 6,  6,  6] -1 */
    51021640, /* 63566 (1589) [-1,  0,  0,  0,  0,  1,  0, -1,  0] [ 6,  0,  0] -1 */
    18439772, /* 63567 (1589) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    17140530, /* 63568 (1589) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  6]  1 */
    51025748, /* 63569 (1589) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 6,  0,  0] -1 */
    18430960, /* 63570 (1589) [ 0, -1,  0,  0,  0,  1, -1,  0,  0] [ 6,  6,  0]  1 */
    35441184, /* 63571 (1589) [ 0,  1,  0, -1,  0,  0,  0,  0, -1] [ 0,  6,  0] -1 */
    52564270, /* 63572 (1589) [ 0,  0,  1,  0,  1,  0,  1,  0,  0] [ 6,  6,  6] -1 */
    18435280, /* 63573 (1589) [ 0,  1,  0,  0,  0, -1, -1,  0,  0] [ 6,  6,  0]  1 */
    18435352, /* 63574 (1589) [ 0,  1,  0,  0,  0,  1,  1,  0,  0] [ 6,  6,  0]  1 */
       10816, /* 63575 (1589) [ 0,  0,  1,  1,  0,  0,  0,  1,  0] [ 0,  0,  0]  1 */
    18434104, /* 63576 (1589) [ 0,  0,  1,  1,  0,  0,  0,  1,  0] [ 6,  6,  0]  1 */
       11992, /* 63577 (1589) [ 0,  1,  0,  0,  0, -1, -1,  0,  0] [ 0,  0,  0]  1 */
    35441672, /* 63578 (1589) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 0,  6,  0] -1 */
       12064, /* 63579 (1589) [ 0,  1,  0,  0,  0,  1,  1,  0,  0] [ 0,  0,  0]  1 */
    51027520, /* 63580 (1589) [ 0,  0, -1,  0,  1,  0, -1,  0,  0] [ 6,  0,  0] -1 */
     1551758, /* 63581 (1589) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
    52562794, /* 63582 (1589) [ 0,  0, -1,  0,  1,  0, -1,  0,  0] [ 6,  6,  6] -1 */
    34146754, /* 63583 (1589) [ 1,  0,  0,  0,  0,  1,  0,  1,  0] [ 0,  0,  6] -1 */
    52561506, /* 63584 (1589) [ 0, -1,  0,  1,  0,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    17127570, /* 63585 (1589) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6]  1 */
    35445832, /* 63586 (1589) [ 1,  0,  0,  0,  0,  1,  0,  1,  0] [ 0,  6,  0] -1 */
    51026232, /* 63587 (1589) [ 0, -1,  0,  1,  0,  0,  0,  0, -1] [ 6,  0,  0] -1 */
     1542946, /* 63588 (1589) [ 0, -1,  0,  0,  0,  1, -1,  0,  0] [ 0,  6,  6]  1 */
    17133082, /* 63589 (1589) [ 0,  0, -1, -1,  0,  0,  0,  1,  0] [ 6,  0,  6]  1 */
     1547266, /* 63590 (1589) [ 0,  1,  0,  0,  0, -1, -1,  0,  0] [ 0,  6,  6]  1 */
    35432656, /* 63591 (1589) [-1,  0,  0,  0,  0, -1,  0,  1,  0] [ 0,  6,  0] -1 */
    52569982, /* 63592 (1589) [ 1,  0,  0,  0,  0, -1,  0, -1,  0] [ 6,  6,  6] -1 */
     1546090, /* 63593 (1589) [ 0,  0,  1,  1,  0,  0,  0,  1,  0] [ 0,  6,  6]  1 */
    34146694, /* 63594 (1589) [ 1,  0,  0,  0,  0, -1,  0, -1,  0] [ 0,  0,  6] -1 */
    34133626, /* 63595 (1589) [-1,  0,  0,  0,  0,  1,  0, -1,  0] [ 0,  0,  6] -1 */
    52556914, /* 63596 (1589) [-1,  0,  0,  0,  0,  1,  0, -1,  0] [ 6,  6,  6] -1 */
        7672, /* 63597 (1589) [ 0, -1,  0,  0,  0,  1, -1,  0,  0] [ 0,  0,  0]  1 */
        3360, /* 63598 (1589) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    18426488, /* 63599 (1589) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    35432704, /* 63600 (1589) [-1,  0,  0,  0,  0,  1,  0, -1,  0] [ 0,  6,  0] -1 */
    34133578, /* 63601 (1589) [-1,  0,  0,  0,  0, -1,  0,  1,  0] [ 0,  0,  6] -1 */
    51027376, /* 63602 (1589) [ 0,  0, -1,  0, -1,  0,  1,  0,  0] [ 6,  0,  0] -1 */
    35436812, /* 63603 (1589) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 0,  6,  0] -1 */
    34139506, /* 63604 (1589) [ 0,  0, -1,  0,  1,  0, -1,  0,  0] [ 0,  0,  6] -1 */
    52562650, /* 63605 (1589) [ 0,  0, -1,  0, -1,  0,  1,  0,  0] [ 6,  6,  6] -1 */
    18439608, /* 63606 (1589) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
    51030120, /* 63607 (1589) [ 0,  1,  0, -1,  0,  0,  0,  0, -1] [ 6,  0,  0] -1 */
    35440060, /* 63608 (1589) [ 0,  0,  1,  0,  1,  0,  1,  0,  0] [ 0,  6,  0] -1 */
    17127410, /* 63609 (1589) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
    17131882, /* 63610 (1589) [ 0, -1,  0,  0,  0,  1, -1,  0,  0] [ 6,  0,  6]  1 */
    17136202, /* 63611 (1589) [ 0,  1,  0,  0,  0, -1, -1,  0,  0] [ 6,  0,  6]  1 */
     1547338, /* 63612 (1589) [ 0,  1,  0,  0,  0,  1,  1,  0,  0] [ 0,  6,  6]  1 */
    18432640, /* 63613 (1589) [ 0,  0, -1,  1,  0,  0,  0, -1,  0] [ 6,  6,  0]  1 */
    51030608, /* 63614 (1589) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 6,  0,  0] -1 */
    17135026, /* 63615 (1589) [ 0,  0,  1,  1,  0,  0,  0,  1,  0] [ 6,  0,  6]  1 */
        7636, /* 63616 (1589) [ 0, -1,  0,  0,  0, -1,  1,  0,  0] [ 0,  0,  0]  1 */
    34138218, /* 63617 (1589) [ 0, -1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  6] -1 */
    18430924, /* 63618 (1589) [ 0, -1,  0,  0,  0, -1,  1,  0,  0] [ 6,  6,  0]  1 */
    35437296, /* 63619 (1589) [ 0, -1,  0,  1,  0,  0,  0,  0, -1] [ 0,  6,  0] -1 */
     1551594, /* 63620 (1589) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
    34142594, /* 63621 (1589) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    35439880, /* 63622 (1589) [ 0,  0,  1,  0, -1,  0, -1,  0,  0] [ 0,  6,  0] -1 */
    35445772, /* 63623 (1589) [ 1,  0,  0,  0,  0, -1,  0, -1,  0] [ 0,  6,  0] -1 */
     1544626, /* 63624 (1589) [ 0,  0, -1,  1,  0,  0,  0, -1,  0] [ 0,  6,  6]  1 */
        3200, /* 63625 (1589) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
     1542910, /* 63626 (1589) [ 0, -1,  0,  0,  0, -1,  1,  0,  0] [ 0,  6,  6]  1 */
       16484, /* 63627 (1590) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    52562962, /* 63628 (1590) [ 0,  0, -1,  1,  0,  0,  0, -1,  0] [ 6,  6,  6] -1 */
    17140694, /* 63629 (1590) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
       16320, /* 63630 (1590) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    51147094, /* 63631 (1590) [ 0,  0,  1,  0,  1,  0,  1,  0,  0] [ 6,  0,  6] -1 */
     1420480, /* 63632 (1590) [-1,  0,  0,  0,  0,  1,  0, -1,  0] [ 0,  6,  0]  1 */
     1545598, /* 63633 (1590) [ 0,  0,  1, -1,  0,  0,  0, -1,  0] [ 0,  6,  6]  1 */
    52447296, /* 63634 (1590) [ 0,  1,  0, -1,  0,  0,  0,  0, -1] [ 6,  6,  0] -1 */
      121354, /* 63635 (1590) [-1,  0,  0,  0,  0, -1,  0,  1,  0] [ 0,  0,  6]  1 */
    17015152, /* 63636 (1590) [ 0,  0, -1,  0, -1,  0,  1,  0,  0] [ 6,  0,  0]  1 */
     1424588, /* 63637 (1590) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 0,  6,  0]  1 */
     1538474, /* 63638 (1590) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
    18550570, /* 63639 (1590) [ 0,  0, -1,  0,  1,  0, -1,  0,  0] [ 6,  6,  6]  1 */
      127282, /* 63640 (1590) [ 0,  0, -1,  0,  1,  0, -1,  0,  0] [ 0,  0,  6]  1 */
    51034820, /* 63641 (1590) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  0] -1 */
    17136274, /* 63642 (1590) [ 0,  1,  0,  0,  0,  1,  1,  0,  0] [ 6,  0,  6]  1 */
    34020120, /* 63643 (1590) [ 0, -1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  0] -1 */
     1427836, /* 63644 (1590) [ 0,  0,  1,  0,  1,  0,  1,  0,  0] [ 0,  6,  0]  1 */
    35556538, /* 63645 (1590) [ 0,  0, -1,  0, -1,  0,  1,  0,  0] [ 0,  6,  6] -1 */
        9352, /* 63646 (1590) [ 0,  0, -1,  1,  0,  0,  0, -1,  0] [ 0,  0,  0]  1 */
    17014008, /* 63647 (1590) [ 0, -1,  0,  1,  0,  0,  0,  0, -1] [ 6,  0,  0]  1 */
    34024496, /* 63648 (1590) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    52447784, /* 63649 (1590) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 6,  6,  0] -1 */
    18426648, /* 63650 (1590) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
    34133522, /* 63651 (1590) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    52556810, /* 63652 (1590) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
        8872, /* 63653 (1590) [ 0,  0, -1, -1,  0,  0,  0,  1,  0] [ 0,  0,  0]  1 */
     1420432, /* 63654 (1590) [-1,  0,  0,  0,  0, -1,  0,  1,  0] [ 0,  6,  0]  1 */
    18432160, /* 63655 (1590) [ 0,  0, -1, -1,  0,  0,  0,  1,  0] [ 6,  6,  0]  1 */
    51034656, /* 63656 (1590) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  0] -1 */
    35432760, /* 63657 (1590) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  0] -1 */
    17018384, /* 63658 (1590) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 6,  0,  0]  1 */
    35445884, /* 63659 (1590) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  0] -1 */
      125994, /* 63660 (1590) [ 0, -1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  6]  1 */
    52451944, /* 63661 (1590) [ 1,  0,  0,  0,  0,  1,  0,  1,  0] [ 6,  6,  0] -1 */
    35559282, /* 63662 (1590) [ 0,  1,  0, -1,  0,  0,  0,  0, -1] [ 0,  6,  6] -1 */
    18433612, /* 63663 (1590) [ 0,  0,  1, -1,  0,  0,  0, -1,  0] [ 6,  6,  0]  1 */
    17133562, /* 63664 (1590) [ 0,  0, -1,  1,  0,  0,  0, -1,  0] [ 6,  0,  6]  1 */
      121402, /* 63665 (1590) [-1,  0,  0,  0,  0,  1,  0, -1,  0] [ 0,  0,  6]  1 */
    51148706, /* 63666 (1590) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 6,  0,  6] -1 */
    35441392, /* 63667 (1590) [ 0,  1,  0,  0,  0, -1, -1,  0,  0] [ 0,  6,  0] -1 */
    51025972, /* 63668 (1590) [ 0, -1,  0,  0,  0, -1,  1,  0,  0] [ 6,  0,  0] -1 */
    17131846, /* 63669 (1590) [ 0, -1,  0,  0,  0, -1,  1,  0,  0] [ 6,  0,  6]  1 */
    35441464, /* 63670 (1590) [ 0,  1,  0,  0,  0,  1,  1,  0,  0] [ 0,  6,  0] -1 */
    34021264, /* 63671 (1590) [ 0,  0, -1,  0, -1,  0,  1,  0,  0] [ 0,  0,  0] -1 */
     1427656, /* 63672 (1590) [ 0,  0,  1,  0, -1,  0, -1,  0,  0] [ 0,  6,  0]  1 */
    35559770, /* 63673 (1590) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 0,  6,  6] -1 */
    52561246, /* 63674 (1590) [ 0, -1,  0,  0,  0, -1,  1,  0,  0] [ 6,  6,  6] -1 */
       10324, /* 63675 (1590) [ 0,  0,  1, -1,  0,  0,  0, -1,  0] [ 0,  0,  0]  1 */
     1538634, /* 63676 (1590) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
    35440216, /* 63677 (1590) [ 0,  0,  1,  1,  0,  0,  0,  1,  0] [ 0,  6,  0] -1 */
     1544146, /* 63678 (1590) [ 0,  0, -1, -1,  0,  0,  0,  1,  0] [ 0,  6,  6]  1 */
    34139674, /* 63679 (1590) [ 0,  0, -1,  1,  0,  0,  0, -1,  0] [ 0,  0,  6] -1 */
    51027688, /* 63680 (1590) [ 0,  0, -1,  1,  0,  0,  0, -1,  0] [ 6,  0,  0] -1 */
    34137958, /* 63681 (1590) [ 0, -1,  0,  0,  0, -1,  1,  0,  0] [ 0,  0,  6] -1 */
    35563930, /* 63682 (1590) [ 1,  0,  0,  0,  0,  1,  0,  1,  0] [ 0,  6,  6] -1 */
    17134534, /* 63683 (1590) [ 0,  0,  1, -1,  0,  0,  0, -1,  0] [ 6,  0,  6]  1 */
    34024008, /* 63684 (1590) [ 0,  1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    52562482, /* 63685 (1590) [ 0,  0, -1, -1,  0,  0,  0,  1,  0] [ 6,  6,  6] -1 */
      127138, /* 63686 (1590) [ 0,  0, -1,  0, -1,  0,  1,  0,  0] [ 0,  0,  6]  1 */
    18550426, /* 63687 (1590) [ 0,  0, -1,  0, -1,  0,  1,  0,  0] [ 6,  6,  6]  1 */
    34146806, /* 63688 (1590) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    17017896, /* 63689 (1590) [ 0,  1,  0, -1,  0,  0,  0,  0, -1] [ 6,  0,  0]  1 */
    18439772, /* 63690 (1590) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    17140530, /* 63691 (1590) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  6]  1 */
    51145618, /* 63692 (1590) [ 0,  0, -1,  0,  1,  0, -1,  0,  0] [ 6,  0,  6] -1 */
    18553170, /* 63693 (1590) [ 0,  1,  0, -1,  0,  0,  0,  0, -1] [ 6,  6,  6]  1 */
    51028660, /* 63694 (1590) [ 0,  0,  1, -1,  0,  0,  0, -1,  0] [ 6,  0,  0] -1 */
    17016592, /* 63695 (1590) [ 0,  0,  1,  0, -1,  0, -1,  0,  0] [ 6,  0,  0]  1 */
    34019636, /* 63696 (1590) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    52442924, /* 63697 (1590) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 6,  6,  0] -1 */
    18430960, /* 63698 (1590) [ 0, -1,  0,  0,  0,  1, -1,  0,  0] [ 6,  6,  0]  1 */
    52438768, /* 63699 (1590) [-1,  0,  0,  0,  0, -1,  0,  1,  0] [ 6,  6,  0] -1 */
      129882, /* 63700 (1590) [ 0,  1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  6]  1 */
    34146642, /* 63701 (1590) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
    52569930, /* 63702 (1590) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    18435280, /* 63703 (1590) [ 0,  1,  0,  0,  0, -1, -1,  0,  0] [ 6,  6,  0]  1 */
    18435352, /* 63704 (1590) [ 0,  1,  0,  0,  0,  1,  1,  0,  0] [ 6,  6,  0]  1 */
    34022884, /* 63705 (1590) [ 0,  0,  1,  0,  1,  0,  1,  0,  0] [ 0,  0,  0] -1 */
    52446172, /* 63706 (1590) [ 0,  0,  1,  0,  1,  0,  1,  0,  0] [ 6,  6,  0] -1 */
    35437072, /* 63707 (1590) [ 0, -1,  0,  0,  0,  1, -1,  0,  0] [ 0,  6,  0] -1 */
    18553658, /* 63708 (1590) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 6,  6,  6]  1 */
     1426360, /* 63709 (1590) [ 0,  0, -1,  0,  1,  0, -1,  0,  0] [ 0,  6,  0]  1 */
    51148218, /* 63710 (1590) [ 0,  1,  0, -1,  0,  0,  0,  0, -1] [ 6,  0,  6] -1 */
       10816, /* 63711 (1590) [ 0,  0,  1,  1,  0,  0,  0,  1,  0] [ 0,  0,  0]  1 */
    18434104, /* 63712 (1590) [ 0,  0,  1,  1,  0,  0,  0,  1,  0] [ 6,  6,  0]  1 */
    17016772, /* 63713 (1590) [ 0,  0,  1,  0,  1,  0,  1,  0,  0] [ 6,  0,  0]  1 */
     1425072, /* 63714 (1590) [ 0, -1,  0,  1,  0,  0,  0,  0, -1] [ 0,  6,  0]  1 */
       11992, /* 63715 (1590) [ 0,  1,  0,  0,  0, -1, -1,  0,  0] [ 0,  0,  0]  1 */
       12064, /* 63716 (1590) [ 0,  1,  0,  0,  0,  1,  1,  0,  0] [ 0,  0,  0]  1 */
      130370, /* 63717 (1590) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 0,  0,  6]  1 */
     1551758, /* 63718 (1590) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
    18557818, /* 63719 (1590) [ 1,  0,  0,  0,  0,  1,  0,  1,  0] [ 6,  6,  6]  1 */
      125510, /* 63720 (1590) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  6]  1 */
    18548798, /* 63721 (1590) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    18544642, /* 63722 (1590) [-1,  0,  0,  0,  0, -1,  0,  1,  0] [ 6,  6,  6]  1 */
     1433548, /* 63723 (1590) [ 1,  0,  0,  0,  0, -1,  0, -1,  0] [ 0,  6,  0]  1 */
    17127570, /* 63724 (1590) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6]  1 */
    35554910, /* 63725 (1590) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 0,  6,  6] -1 */
     1542946, /* 63726 (1590) [ 0, -1,  0,  0,  0,  1, -1,  0,  0] [ 0,  6,  6]  1 */
    17133082, /* 63727 (1590) [ 0,  0, -1, -1,  0,  0,  0,  1,  0] [ 6,  0,  6]  1 */
    52443408, /* 63728 (1590) [ 0, -1,  0,  1,  0,  0,  0,  0, -1] [ 6,  6,  0] -1 */
    35550754, /* 63729 (1590) [-1,  0,  0,  0,  0, -1,  0,  1,  0] [ 0,  6,  6] -1 */
     1547266, /* 63730 (1590) [ 0,  1,  0,  0,  0, -1, -1,  0,  0] [ 0,  6,  6]  1 */
    35558158, /* 63731 (1590) [ 0,  0,  1,  0,  1,  0,  1,  0,  0] [ 0,  6,  6] -1 */
    51152866, /* 63732 (1590) [ 1,  0,  0,  0,  0,  1,  0,  1,  0] [ 6,  0,  6] -1 */
    34022704, /* 63733 (1590) [ 0,  0,  1,  0, -1,  0, -1,  0,  0] [ 0,  0,  0] -1 */
    52445992, /* 63734 (1590) [ 0,  0,  1,  0, -1,  0, -1,  0,  0] [ 6,  6,  0] -1 */
     1546090, /* 63735 (1590) [ 0,  0,  1,  1,  0,  0,  0,  1,  0] [ 0,  6,  6]  1 */
    52451884, /* 63736 (1590) [ 1,  0,  0,  0,  0, -1,  0, -1,  0] [ 6,  6,  0] -1 */
    35438752, /* 63737 (1590) [ 0,  0, -1,  1,  0,  0,  0, -1,  0] [ 0,  6,  0] -1 */
    34139194, /* 63738 (1590) [ 0,  0, -1, -1,  0,  0,  0,  1,  0] [ 0,  0,  6] -1 */
    51030328, /* 63739 (1590) [ 0,  1,  0,  0,  0, -1, -1,  0,  0] [ 6,  0,  0] -1 */
    51027208, /* 63740 (1590) [ 0,  0, -1, -1,  0,  0,  0,  1,  0] [ 6,  0,  0] -1 */
    51030400, /* 63741 (1590) [ 0,  1,  0,  0,  0,  1,  1,  0,  0] [ 6,  0,  0] -1 */
    35437036, /* 63742 (1590) [ 0, -1,  0,  0,  0, -1,  1,  0,  0] [ 0,  6,  0] -1 */
    51145474, /* 63743 (1590) [ 0,  0, -1,  0, -1,  0,  1,  0,  0] [ 6,  0,  6] -1 */
    34015528, /* 63744 (1590) [-1,  0,  0,  0,  0,  1,  0, -1,  0] [ 0,  0,  0] -1 */
    34140646, /* 63745 (1590) [ 0,  0,  1, -1,  0,  0,  0, -1,  0] [ 0,  0,  6] -1 */
    52563934, /* 63746 (1590) [ 0,  0,  1, -1,  0,  0,  0, -1,  0] [ 6,  6,  6] -1 */
    35555394, /* 63747 (1590) [ 0, -1,  0,  1,  0,  0,  0,  0, -1] [ 0,  6,  6] -1 */
      128578, /* 63748 (1590) [ 0,  0,  1,  0, -1,  0, -1,  0,  0] [ 0,  0,  6]  1 */
    18551866, /* 63749 (1590) [ 0,  0,  1,  0, -1,  0, -1,  0,  0] [ 6,  6,  6]  1 */
        7672, /* 63750 (1590) [ 0, -1,  0,  0,  0,  1, -1,  0,  0] [ 0,  0,  0]  1 */
        3360, /* 63751 (1590) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    35557978, /* 63752 (1590) [ 0,  0,  1,  0, -1,  0, -1,  0,  0] [ 0,  6,  6] -1 */
    18426488, /* 63753 (1590) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    35563870, /* 63754 (1590) [ 1,  0,  0,  0,  0, -1,  0, -1,  0] [ 0,  6,  6] -1 */
    35550802, /* 63755 (1590) [-1,  0,  0,  0,  0,  1,  0, -1,  0] [ 0,  6,  6] -1 */
    35432600, /* 63756 (1590) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  0] -1 */
    52444696, /* 63757 (1590) [ 0,  0, -1,  0,  1,  0, -1,  0,  0] [ 6,  6,  0] -1 */
    34028656, /* 63758 (1590) [ 1,  0,  0,  0,  0,  1,  0,  1,  0] [ 0,  0,  0] -1 */
    17013524, /* 63759 (1590) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 6,  0,  0]  1 */
    35439724, /* 63760 (1590) [ 0,  0,  1, -1,  0,  0,  0, -1,  0] [ 0,  6,  0] -1 */
    18552046, /* 63761 (1590) [ 0,  0,  1,  0,  1,  0,  1,  0,  0] [ 6,  6,  6]  1 */
    34015480, /* 63762 (1590) [-1,  0,  0,  0,  0, -1,  0,  1,  0] [ 0,  0,  0] -1 */
    17022544, /* 63763 (1590) [ 1,  0,  0,  0,  0,  1,  0,  1,  0] [ 6,  0,  0]  1 */
    34021408, /* 63764 (1590) [ 0,  0, -1,  0,  1,  0, -1,  0,  0] [ 0,  0,  0] -1 */
    18439608, /* 63765 (1590) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
    17009368, /* 63766 (1590) [-1,  0,  0,  0,  0, -1,  0,  1,  0] [ 6,  0,  0]  1 */
    35445720, /* 63767 (1590) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  0] -1 */
    51143846, /* 63768 (1590) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 6,  0,  6] -1 */
      128758, /* 63769 (1590) [ 0,  0,  1,  0,  1,  0,  1,  0,  0] [ 0,  0,  6]  1 */
    52556970, /* 63770 (1590) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    17127410, /* 63771 (1590) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
    17131882, /* 63772 (1590) [ 0, -1,  0,  0,  0,  1, -1,  0,  0] [ 6,  0,  6]  1 */
     1429448, /* 63773 (1590) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 0,  6,  0]  1 */
    17015296, /* 63774 (1590) [ 0,  0, -1,  0,  1,  0, -1,  0,  0] [ 6,  0,  0]  1 */
    51139690, /* 63775 (1590) [-1,  0,  0,  0,  0, -1,  0,  1,  0] [ 6,  0,  6] -1 */
    51021696, /* 63776 (1590) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  0] -1 */
    52570094, /* 63777 (1590) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    17136202, /* 63778 (1590) [ 0,  1,  0,  0,  0, -1, -1,  0,  0] [ 6,  0,  6]  1 */
     1547338, /* 63779 (1590) [ 0,  1,  0,  0,  0,  1,  1,  0,  0] [ 0,  6,  6]  1 */
      134530, /* 63780 (1590) [ 1,  0,  0,  0,  0,  1,  0,  1,  0] [ 0,  0,  6]  1 */
    18432640, /* 63781 (1590) [ 0,  0, -1,  1,  0,  0,  0, -1,  0] [ 6,  6,  0]  1 */
    35556682, /* 63782 (1590) [ 0,  0, -1,  0,  1,  0, -1,  0,  0] [ 0,  6,  6] -1 */
    17135026, /* 63783 (1590) [ 0,  0,  1,  1,  0,  0,  0,  1,  0] [ 6,  0,  6]  1 */
    18549282, /* 63784 (1590) [ 0, -1,  0,  1,  0,  0,  0,  0, -1] [ 6,  6,  6]  1 */
        7636, /* 63785 (1590) [ 0, -1,  0,  0,  0, -1,  1,  0,  0] [ 0,  0,  0]  1 */
    34028596, /* 63786 (1590) [ 1,  0,  0,  0,  0, -1,  0, -1,  0] [ 0,  0,  0] -1 */
     1433608, /* 63787 (1590) [ 1,  0,  0,  0,  0,  1,  0,  1,  0] [ 0,  6,  0]  1 */
    18430924, /* 63788 (1590) [ 0, -1,  0,  0,  0, -1,  1,  0,  0] [ 6,  6,  0]  1 */
    52561282, /* 63789 (1590) [ 0, -1,  0,  0,  0,  1, -1,  0,  0] [ 6,  6,  6] -1 */
    34137994, /* 63790 (1590) [ 0, -1,  0,  0,  0,  1, -1,  0,  0] [ 0,  0,  6] -1 */
    34133682, /* 63791 (1590) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
    51021536, /* 63792 (1590) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  0] -1 */
    51026008, /* 63793 (1590) [ 0, -1,  0,  0,  0,  1, -1,  0,  0] [ 6,  0,  0] -1 */
    52438816, /* 63794 (1590) [-1,  0,  0,  0,  0,  1,  0, -1,  0] [ 6,  6,  0] -1 */
    34142314, /* 63795 (1590) [ 0,  1,  0,  0,  0, -1, -1,  0,  0] [ 0,  0,  6] -1 */
    52565602, /* 63796 (1590) [ 0,  1,  0,  0,  0, -1, -1,  0,  0] [ 6,  6,  6] -1 */
    34142386, /* 63797 (1590) [ 0,  1,  0,  0,  0,  1,  1,  0,  0] [ 0,  0,  6] -1 */
    52565674, /* 63798 (1590) [ 0,  1,  0,  0,  0,  1,  1,  0,  0] [ 6,  6,  6] -1 */
    17022484, /* 63799 (1590) [ 1,  0,  0,  0,  0, -1,  0, -1,  0] [ 6,  0,  0]  1 */
     1551594, /* 63800 (1590) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
    18557758, /* 63801 (1590) [ 1,  0,  0,  0,  0, -1,  0, -1,  0] [ 6,  6,  6]  1 */
    34141138, /* 63802 (1590) [ 0,  0,  1,  1,  0,  0,  0,  1,  0] [ 0,  0,  6] -1 */
    52564426, /* 63803 (1590) [ 0,  0,  1,  1,  0,  0,  0,  1,  0] [ 6,  6,  6] -1 */
    35438272, /* 63804 (1590) [ 0,  0, -1, -1,  0,  0,  0,  1,  0] [ 0,  6,  0] -1 */
    51029152, /* 63805 (1590) [ 0,  0,  1,  1,  0,  0,  0,  1,  0] [ 6,  0,  0] -1 */
    51144330, /* 63806 (1590) [ 0, -1,  0,  1,  0,  0,  0,  0, -1] [ 6,  0,  6] -1 */
     1426216, /* 63807 (1590) [ 0,  0, -1,  0, -1,  0,  1,  0,  0] [ 0,  6,  0]  1 */
      134470, /* 63808 (1590) [ 1,  0,  0,  0,  0, -1,  0, -1,  0] [ 0,  0,  6]  1 */
     1544626, /* 63809 (1590) [ 0,  0, -1,  1,  0,  0,  0, -1,  0] [ 0,  6,  6]  1 */
    17009416, /* 63810 (1590) [-1,  0,  0,  0,  0,  1,  0, -1,  0] [ 6,  0,  0]  1 */
        3200, /* 63811 (1590) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    51146914, /* 63812 (1590) [ 0,  0,  1,  0, -1,  0, -1,  0,  0] [ 6,  0,  6] -1 */
    18544690, /* 63813 (1590) [-1,  0,  0,  0,  0,  1,  0, -1,  0] [ 6,  6,  6]  1 */
    51152806, /* 63814 (1590) [ 1,  0,  0,  0,  0, -1,  0, -1,  0] [ 6,  0,  6] -1 */
     1542910, /* 63815 (1590) [ 0, -1,  0,  0,  0, -1,  1,  0,  0] [ 0,  6,  6]  1 */
    51139738, /* 63816 (1590) [-1,  0,  0,  0,  0,  1,  0, -1,  0] [ 6,  0,  6] -1 */
    52444552, /* 63817 (1590) [ 0,  0, -1,  0, -1,  0,  1,  0,  0] [ 6,  6,  0] -1 */
     1428960, /* 63818 (1590) [ 0,  1,  0, -1,  0,  0,  0,  0, -1] [ 0,  6,  0]  1 */
       16484, /* 63819 (1591) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    26284217, /* 63820 (1591) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 9,  3,  3]  1 */
    10813379, /* 63821 (1591) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 3,  9,  9]  1 */
      134418, /* 63822 (1591) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  6]  1 */
    18439608, /* 63823 (1591) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
     9396687, /* 63824 (1591) [ 0, -1,  0,  1,  0,  0,  0,  0, -1] [ 3,  3,  9]  1 */
     9287125, /* 63825 (1591) [ 1,  0,  0,  0,  0,  1,  0,  1,  0] [ 3,  3,  3]  1 */
    10809223, /* 63826 (1591) [-1,  0,  0,  0,  0, -1,  0,  1,  0] [ 3,  9,  9]  1 */
     1542946, /* 63827 (1591) [ 0, -1,  0,  0,  0,  1, -1,  0,  0] [ 0,  6,  6]  1 */
    27701877, /* 63828 (1591) [ 0, -1,  0,  1,  0,  0,  0,  0, -1] [ 9,  9,  3]  1 */
    17133082, /* 63829 (1591) [ 0,  0, -1, -1,  0,  0,  0,  1,  0] [ 6,  0,  6]  1 */
     1420376, /* 63830 (1591) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  0]  1 */
    17127410, /* 63831 (1591) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
    26280061, /* 63832 (1591) [-1,  0,  0,  0,  0, -1,  0,  1,  0] [ 9,  3,  3]  1 */
    10815007, /* 63833 (1591) [ 0,  0, -1,  0, -1,  0,  1,  0,  0] [ 3,  9,  9]  1 */
     9392095, /* 63834 (1591) [-1,  0,  0,  0,  0,  1,  0, -1,  0] [ 3,  3,  9]  1 */
    27824351, /* 63835 (1591) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 9,  9,  9]  1 */
    26285845, /* 63836 (1591) [ 0,  0, -1,  0, -1,  0,  1,  0,  0] [ 9,  3,  3]  1 */
    27697285, /* 63837 (1591) [-1,  0,  0,  0,  0,  1,  0, -1,  0] [ 9,  9,  3]  1 */
    17015464, /* 63838 (1591) [ 0,  0, -1,  1,  0,  0,  0, -1,  0] [ 6,  0,  0]  1 */
    10699653, /* 63839 (1591) [ 0,  1,  0, -1,  0,  0,  0,  0, -1] [ 3,  9,  3]  1 */
    27822739, /* 63840 (1591) [ 0,  0,  1,  0,  1,  0,  1,  0,  0] [ 9,  9,  9]  1 */
    10704241, /* 63841 (1591) [ 1,  0,  0,  0,  0, -1,  0, -1,  0] [ 3,  9,  3]  1 */
    18557870, /* 63842 (1591) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    17009472, /* 63843 (1591) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  0]  1 */
    10698349, /* 63844 (1591) [ 0,  0,  1,  0, -1,  0, -1,  0,  0] [ 3,  9,  3]  1 */
    26405383, /* 63845 (1591) [ 0,  0,  1,  0, -1,  0, -1,  0,  0] [ 9,  3,  9]  1 */
    26406687, /* 63846 (1591) [ 0,  1,  0, -1,  0,  0,  0,  0, -1] [ 9,  3,  9]  1 */
    18435280, /* 63847 (1591) [ 0,  1,  0,  0,  0, -1, -1,  0,  0] [ 6,  6,  0]  1 */
    26411275, /* 63848 (1591) [ 1,  0,  0,  0,  0, -1,  0, -1,  0] [ 9,  3,  9]  1 */
    27703165, /* 63849 (1591) [ 0,  0, -1,  0,  1,  0, -1,  0,  0] [ 9,  9,  3]  1 */
     9282965, /* 63850 (1591) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 3,  3,  3]  1 */
    27828511, /* 63851 (1591) [ 1,  0,  0,  0,  0,  1,  0,  1,  0] [ 9,  9,  9]  1 */
     1544626, /* 63852 (1591) [ 0,  0, -1,  1,  0,  0,  0, -1,  0] [ 0,  6,  6]  1 */
      130090, /* 63853 (1591) [ 0,  1,  0,  0,  0, -1, -1,  0,  0] [ 0,  0,  6]  1 */
       10816, /* 63854 (1591) [ 0,  0,  1,  1,  0,  0,  0,  1,  0] [ 0,  0,  0]  1 */
    17013784, /* 63855 (1591) [ 0, -1,  0,  0,  0,  1, -1,  0,  0] [ 6,  0,  0]  1 */
     1424812, /* 63856 (1591) [ 0, -1,  0,  0,  0, -1,  1,  0,  0] [ 0,  6,  0]  1 */
     9397975, /* 63857 (1591) [ 0,  0, -1,  0,  1,  0, -1,  0,  0] [ 3,  3,  9]  1 */
    18433612, /* 63858 (1591) [ 0,  0,  1, -1,  0,  0,  0, -1,  0] [ 6,  6,  0]  1 */
    18553450, /* 63859 (1591) [ 0,  1,  0,  0,  0,  1,  1,  0,  0] [ 6,  6,  6]  1 */
    18552202, /* 63860 (1591) [ 0,  0,  1,  1,  0,  0,  0,  1,  0] [ 6,  6,  6]  1 */
       12064, /* 63861 (1591) [ 0,  1,  0,  0,  0,  1,  1,  0,  0] [ 0,  0,  0]  1 */
     9281353, /* 63862 (1591) [ 0,  0,  1,  0,  1,  0,  1,  0,  0] [ 3,  3,  3]  1 */
    17131846, /* 63863 (1591) [ 0, -1,  0,  0,  0, -1,  1,  0,  0] [ 6,  0,  6]  1 */
      128422, /* 63864 (1591) [ 0,  0,  1, -1,  0,  0,  0, -1,  0] [ 0,  0,  6]  1 */
     1426048, /* 63865 (1591) [ 0,  0, -1, -1,  0,  0,  0,  1,  0] [ 0,  6,  0]  1 */
     1538634, /* 63866 (1591) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
       16484, /* 63867 (1592) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    43404319, /* 63868 (1592) [-1,  0,  0,  0,  0,  1,  0, -1,  0] [ 3,  3,  9] -1 */
      134418, /* 63869 (1592) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  6]  1 */
    27701877, /* 63870 (1592) [ 0, -1,  0,  1,  0,  0,  0,  0, -1] [ 9,  9,  3]  1 */
    44711877, /* 63871 (1592) [ 0,  1,  0, -1,  0,  0,  0,  0, -1] [ 3,  9,  3] -1 */
     1420376, /* 63872 (1592) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  0]  1 */
    60418911, /* 63873 (1592) [ 0,  1,  0, -1,  0,  0,  0,  0, -1] [ 9,  3,  9] -1 */
    34023040, /* 63874 (1592) [ 0,  0,  1,  1,  0,  0,  0,  1,  0] [ 0,  0,  0] -1 */
    43410199, /* 63875 (1592) [ 0,  0, -1,  0,  1,  0, -1,  0,  0] [ 3,  3,  9] -1 */
    18557870, /* 63876 (1592) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    34024288, /* 63877 (1592) [ 0,  1,  0,  0,  0,  1,  1,  0,  0] [ 0,  0,  0] -1 */
    43408911, /* 63878 (1592) [ 0, -1,  0,  1,  0,  0,  0,  0, -1] [ 3,  3,  9] -1 */
    26411275, /* 63879 (1592) [ 1,  0,  0,  0,  0, -1,  0, -1,  0] [ 9,  3,  9]  1 */
    27828511, /* 63880 (1592) [ 1,  0,  0,  0,  0,  1,  0,  1,  0] [ 9,  9,  9]  1 */
     9282965, /* 63881 (1592) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 3,  3,  3]  1 */
      130090, /* 63882 (1592) [ 0,  1,  0,  0,  0, -1, -1,  0,  0] [ 0,  0,  6]  1 */
     1424812, /* 63883 (1592) [ 0, -1,  0,  0,  0, -1,  1,  0,  0] [ 0,  6,  0]  1 */
    35555170, /* 63884 (1592) [ 0, -1,  0,  0,  0,  1, -1,  0,  0] [ 0,  6,  6] -1 */
    18433612, /* 63885 (1592) [ 0,  0,  1, -1,  0,  0,  0, -1,  0] [ 6,  6,  0]  1 */
    18552202, /* 63886 (1592) [ 0,  0,  1,  1,  0,  0,  0,  1,  0] [ 6,  6,  6]  1 */
     9281353, /* 63887 (1592) [ 0,  0,  1,  0,  1,  0,  1,  0,  0] [ 3,  3,  3]  1 */
    17131846, /* 63888 (1592) [ 0, -1,  0,  0,  0, -1,  1,  0,  0] [ 6,  0,  6]  1 */
      128422, /* 63889 (1592) [ 0,  0,  1, -1,  0,  0,  0, -1,  0] [ 0,  0,  6]  1 */
     1538634, /* 63890 (1592) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
    26284217, /* 63891 (1592) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 9,  3,  3]  1 */
    60298069, /* 63892 (1592) [ 0,  0, -1,  0, -1,  0,  1,  0,  0] [ 9,  3,  3] -1 */
    61709509, /* 63893 (1592) [-1,  0,  0,  0,  0,  1,  0, -1,  0] [ 9,  9,  3] -1 */
    51027688, /* 63894 (1592) [ 0,  0, -1,  1,  0,  0,  0, -1,  0] [ 6,  0,  0] -1 */
    26280061, /* 63895 (1592) [-1,  0,  0,  0,  0, -1,  0,  1,  0] [ 9,  3,  3]  1 */
    10815007, /* 63896 (1592) [ 0,  0, -1,  0, -1,  0,  1,  0,  0] [ 3,  9,  9]  1 */
    44710573, /* 63897 (1592) [ 0,  0,  1,  0, -1,  0, -1,  0,  0] [ 3,  9,  3] -1 */
     9392095, /* 63898 (1592) [-1,  0,  0,  0,  0,  1,  0, -1,  0] [ 3,  3,  9]  1 */
    61715389, /* 63899 (1592) [ 0,  0, -1,  0,  1,  0, -1,  0,  0] [ 9,  9,  3] -1 */
    35556850, /* 63900 (1592) [ 0,  0, -1,  1,  0,  0,  0, -1,  0] [ 0,  6,  6] -1 */
    10699653, /* 63901 (1592) [ 0,  1,  0, -1,  0,  0,  0,  0, -1] [ 3,  9,  3]  1 */
    34028708, /* 63902 (1592) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    27822739, /* 63903 (1592) [ 0,  0,  1,  0,  1,  0,  1,  0,  0] [ 9,  9,  9]  1 */
    17009472, /* 63904 (1592) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  0]  1 */
    34146642, /* 63905 (1592) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
    18435280, /* 63906 (1592) [ 0,  1,  0,  0,  0, -1, -1,  0,  0] [ 6,  6,  0]  1 */
    44825603, /* 63907 (1592) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 3,  9,  9] -1 */
    52451832, /* 63908 (1592) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
    61714101, /* 63909 (1592) [ 0, -1,  0,  1,  0,  0,  0,  0, -1] [ 9,  9,  3] -1 */
    44821447, /* 63910 (1592) [-1,  0,  0,  0,  0, -1,  0,  1,  0] [ 3,  9,  9] -1 */
       10816, /* 63911 (1592) [ 0,  0,  1,  1,  0,  0,  0,  1,  0] [ 0,  0,  0]  1 */
    17013784, /* 63912 (1592) [ 0, -1,  0,  0,  0,  1, -1,  0,  0] [ 6,  0,  0]  1 */
     9397975, /* 63913 (1592) [ 0,  0, -1,  0,  1,  0, -1,  0,  0] [ 3,  3,  9]  1 */
    18553450, /* 63914 (1592) [ 0,  1,  0,  0,  0,  1,  1,  0,  0] [ 6,  6,  6]  1 */
    51139634, /* 63915 (1592) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
       12064, /* 63916 (1592) [ 0,  1,  0,  0,  0,  1,  1,  0,  0] [ 0,  0,  0]  1 */
     1426048, /* 63917 (1592) [ 0,  0, -1, -1,  0,  0,  0,  1,  0] [ 0,  6,  0]  1 */
     9287125, /* 63918 (1592) [ 1,  0,  0,  0,  0,  1,  0,  1,  0] [ 3,  3,  3]  1 */
    61836575, /* 63919 (1592) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 9,  9,  9] -1 */
     1542946, /* 63920 (1592) [ 0, -1,  0,  0,  0,  1, -1,  0,  0] [ 0,  6,  6]  1 */
    17133082, /* 63921 (1592) [ 0,  0, -1, -1,  0,  0,  0,  1,  0] [ 6,  0,  6]  1 */
    44716465, /* 63922 (1592) [ 1,  0,  0,  0,  0, -1,  0, -1,  0] [ 3,  9,  3] -1 */
    60417607, /* 63923 (1592) [ 0,  0,  1,  0, -1,  0, -1,  0,  0] [ 9,  3,  9] -1 */
    60423499, /* 63924 (1592) [ 1,  0,  0,  0,  0, -1,  0, -1,  0] [ 9,  3,  9] -1 */
    43295189, /* 63925 (1592) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 3,  3,  3] -1 */
    26285845, /* 63926 (1592) [ 0,  0, -1,  0, -1,  0,  1,  0,  0] [ 9,  3,  3]  1 */
    27697285, /* 63927 (1592) [-1,  0,  0,  0,  0,  1,  0, -1,  0] [ 9,  9,  3]  1 */
    17015464, /* 63928 (1592) [ 0,  0, -1,  1,  0,  0,  0, -1,  0] [ 6,  0,  0]  1 */
    35437036, /* 63929 (1592) [ 0, -1,  0,  0,  0, -1,  1,  0,  0] [ 0,  6,  0] -1 */
    34140646, /* 63930 (1592) [ 0,  0,  1, -1,  0,  0,  0, -1,  0] [ 0,  0,  6] -1 */
    10698349, /* 63931 (1592) [ 0,  0,  1,  0, -1,  0, -1,  0,  0] [ 3,  9,  3]  1 */
    26406687, /* 63932 (1592) [ 0,  1,  0, -1,  0,  0,  0,  0, -1] [ 9,  3,  9]  1 */
    35432600, /* 63933 (1592) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  0] -1 */
    60292285, /* 63934 (1592) [-1,  0,  0,  0,  0, -1,  0,  1,  0] [ 9,  3,  3] -1 */
    44827231, /* 63935 (1592) [ 0,  0, -1,  0, -1,  0,  1,  0,  0] [ 3,  9,  9] -1 */
    10813379, /* 63936 (1592) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 3,  9,  9]  1 */
    18439608, /* 63937 (1592) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
     9396687, /* 63938 (1592) [ 0, -1,  0,  1,  0,  0,  0,  0, -1] [ 3,  3,  9]  1 */
    10809223, /* 63939 (1592) [-1,  0,  0,  0,  0, -1,  0,  1,  0] [ 3,  9,  9]  1 */
    61834963, /* 63940 (1592) [ 0,  0,  1,  0,  1,  0,  1,  0,  0] [ 9,  9,  9] -1 */
    17127410, /* 63941 (1592) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
    51021696, /* 63942 (1592) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  0] -1 */
    52570094, /* 63943 (1592) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    52447504, /* 63944 (1592) [ 0,  1,  0,  0,  0, -1, -1,  0,  0] [ 6,  6,  0] -1 */
    27824351, /* 63945 (1592) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 9,  9,  9]  1 */
    61840735, /* 63946 (1592) [ 1,  0,  0,  0,  0,  1,  0,  1,  0] [ 9,  9,  9] -1 */
    51026008, /* 63947 (1592) [ 0, -1,  0,  0,  0,  1, -1,  0,  0] [ 6,  0,  0] -1 */
    34142314, /* 63948 (1592) [ 0,  1,  0,  0,  0, -1, -1,  0,  0] [ 0,  0,  6] -1 */
    52565674, /* 63949 (1592) [ 0,  1,  0,  0,  0,  1,  1,  0,  0] [ 6,  6,  6] -1 */
    10704241, /* 63950 (1592) [ 1,  0,  0,  0,  0, -1,  0, -1,  0] [ 3,  9,  3]  1 */
    52445836, /* 63951 (1592) [ 0,  0,  1, -1,  0,  0,  0, -1,  0] [ 6,  6,  0] -1 */
    52564426, /* 63952 (1592) [ 0,  0,  1,  1,  0,  0,  0,  1,  0] [ 6,  6,  6] -1 */
    43293577, /* 63953 (1592) [ 0,  0,  1,  0,  1,  0,  1,  0,  0] [ 3,  3,  3] -1 */
    35438272, /* 63954 (1592) [ 0,  0, -1, -1,  0,  0,  0,  1,  0] [ 0,  6,  0] -1 */
    51144070, /* 63955 (1592) [ 0, -1,  0,  0,  0, -1,  1,  0,  0] [ 6,  0,  6] -1 */
    26405383, /* 63956 (1592) [ 0,  0,  1,  0, -1,  0, -1,  0,  0] [ 9,  3,  9]  1 */
    35550858, /* 63957 (1592) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6] -1 */
    60296441, /* 63958 (1592) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 9,  3,  3] -1 */
    43299349, /* 63959 (1592) [ 1,  0,  0,  0,  0,  1,  0,  1,  0] [ 3,  3,  3] -1 */
    27703165, /* 63960 (1592) [ 0,  0, -1,  0,  1,  0, -1,  0,  0] [ 9,  9,  3]  1 */
    51145306, /* 63961 (1592) [ 0,  0, -1, -1,  0,  0,  0,  1,  0] [ 6,  0,  6] -1 */
     1544626, /* 63962 (1592) [ 0,  0, -1,  1,  0,  0,  0, -1,  0] [ 0,  6,  6]  1 */
       16484, /* 63963 (1593) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    43404319, /* 63964 (1593) [-1,  0,  0,  0,  0,  1,  0, -1,  0] [ 3,  3,  9] -1 */
      134418, /* 63965 (1593) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  6]  1 */
    18439608, /* 63966 (1593) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
    61836575, /* 63967 (1593) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 9,  9,  9] -1 */
    60298069, /* 63968 (1593) [ 0,  0, -1,  0, -1,  0,  1,  0,  0] [ 9,  3,  3] -1 */
    61709509, /* 63969 (1593) [-1,  0,  0,  0,  0,  1,  0, -1,  0] [ 9,  9,  3] -1 */
    61834963, /* 63970 (1593) [ 0,  0,  1,  0,  1,  0,  1,  0,  0] [ 9,  9,  9] -1 */
    17133082, /* 63971 (1593) [ 0,  0, -1, -1,  0,  0,  0,  1,  0] [ 6,  0,  6]  1 */
     1542946, /* 63972 (1593) [ 0, -1,  0,  0,  0,  1, -1,  0,  0] [ 0,  6,  6]  1 */
    44711877, /* 63973 (1593) [ 0,  1,  0, -1,  0,  0,  0,  0, -1] [ 3,  9,  3] -1 */
     1420376, /* 63974 (1593) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  0]  1 */
    17127410, /* 63975 (1593) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
    44716465, /* 63976 (1593) [ 1,  0,  0,  0,  0, -1,  0, -1,  0] [ 3,  9,  3] -1 */
    60418911, /* 63977 (1593) [ 0,  1,  0, -1,  0,  0,  0,  0, -1] [ 9,  3,  9] -1 */
    44710573, /* 63978 (1593) [ 0,  0,  1,  0, -1,  0, -1,  0,  0] [ 3,  9,  3] -1 */
    60417607, /* 63979 (1593) [ 0,  0,  1,  0, -1,  0, -1,  0,  0] [ 9,  3,  9] -1 */
    60423499, /* 63980 (1593) [ 1,  0,  0,  0,  0, -1,  0, -1,  0] [ 9,  3,  9] -1 */
    61715389, /* 63981 (1593) [ 0,  0, -1,  0,  1,  0, -1,  0,  0] [ 9,  9,  3] -1 */
    43295189, /* 63982 (1593) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 3,  3,  3] -1 */
    17015464, /* 63983 (1593) [ 0,  0, -1,  1,  0,  0,  0, -1,  0] [ 6,  0,  0]  1 */
    61840735, /* 63984 (1593) [ 1,  0,  0,  0,  0,  1,  0,  1,  0] [ 9,  9,  9] -1 */
    43410199, /* 63985 (1593) [ 0,  0, -1,  0,  1,  0, -1,  0,  0] [ 3,  3,  9] -1 */
    18557870, /* 63986 (1593) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    17009472, /* 63987 (1593) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  0]  1 */
    43293577, /* 63988 (1593) [ 0,  0,  1,  0,  1,  0,  1,  0,  0] [ 3,  3,  3] -1 */
    18435280, /* 63989 (1593) [ 0,  1,  0,  0,  0, -1, -1,  0,  0] [ 6,  6,  0]  1 */
    60296441, /* 63990 (1593) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 9,  3,  3] -1 */
    43299349, /* 63991 (1593) [ 1,  0,  0,  0,  0,  1,  0,  1,  0] [ 3,  3,  3] -1 */
    44825603, /* 63992 (1593) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 3,  9,  9] -1 */
    43408911, /* 63993 (1593) [ 0, -1,  0,  1,  0,  0,  0,  0, -1] [ 3,  3,  9] -1 */
    61714101, /* 63994 (1593) [ 0, -1,  0,  1,  0,  0,  0,  0, -1] [ 9,  9,  3] -1 */
     1544626, /* 63995 (1593) [ 0,  0, -1,  1,  0,  0,  0, -1,  0] [ 0,  6,  6]  1 */
    44821447, /* 63996 (1593) [-1,  0,  0,  0,  0, -1,  0,  1,  0] [ 3,  9,  9] -1 */
       10816, /* 63997 (1593) [ 0,  0,  1,  1,  0,  0,  0,  1,  0] [ 0,  0,  0]  1 */
      130090, /* 63998 (1593) [ 0,  1,  0,  0,  0, -1, -1,  0,  0] [ 0,  0,  6]  1 */
    17013784, /* 63999 (1593) [ 0, -1,  0,  0,  0,  1, -1,  0,  0] [ 6,  0,  0]  1 */
    18433612, /* 64000 (1593) [ 0,  0,  1, -1,  0,  0,  0, -1,  0] [ 6,  6,  0]  1 */
     1424812, /* 64001 (1593) [ 0, -1,  0,  0,  0, -1,  1,  0,  0] [ 0,  6,  0]  1 */
    18553450, /* 64002 (1593) [ 0,  1,  0,  0,  0,  1,  1,  0,  0] [ 6,  6,  6]  1 */
    18552202, /* 64003 (1593) [ 0,  0,  1,  1,  0,  0,  0,  1,  0] [ 6,  6,  6]  1 */
       12064, /* 64004 (1593) [ 0,  1,  0,  0,  0,  1,  1,  0,  0] [ 0,  0,  0]  1 */
    60292285, /* 64005 (1593) [-1,  0,  0,  0,  0, -1,  0,  1,  0] [ 9,  3,  3] -1 */
    44827231, /* 64006 (1593) [ 0,  0, -1,  0, -1,  0,  1,  0,  0] [ 3,  9,  9] -1 */
    17131846, /* 64007 (1593) [ 0, -1,  0,  0,  0, -1,  1,  0,  0] [ 6,  0,  6]  1 */
      128422, /* 64008 (1593) [ 0,  0,  1, -1,  0,  0,  0, -1,  0] [ 0,  0,  6]  1 */
     1426048, /* 64009 (1593) [ 0,  0, -1, -1,  0,  0,  0,  1,  0] [ 0,  6,  0]  1 */
     1538634, /* 64010 (1593) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
       16484, /* 64011 (1594) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
       10660, /* 64012 (1594) [ 0,  0,  1,  0,  1,  0,  1,  0,  0] [ 0,  0,  0]  1 */
        9022, /* 64013 (1594) [ 0,  0, -1,  0, -1,  0, -1,  0,  0] [ 0,  0,  0]  1 */
       16378, /* 64014 (1594) [ 1,  0,  0,  0,  0, -1,  0,  1,  0] [ 0,  0,  0]  1 */
       16320, /* 64015 (1594) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
       12270, /* 64016 (1594) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  0]  1 */
        3198, /* 64017 (1594) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
       16432, /* 64018 (1594) [ 1,  0,  0,  0,  0,  1,  0,  1,  0] [ 0,  0,  0]  1 */
       10498, /* 64019 (1594) [ 0,  0,  1,  0, -1,  0,  1,  0,  0] [ 0,  0,  0]  1 */
        7690, /* 64020 (1594) [ 0, -1,  0,  0,  0,  1,  1,  0,  0] [ 0,  0,  0]  1 */
        8866, /* 64021 (1594) [ 0,  0, -1, -1,  0,  0,  0, -1,  0] [ 0,  0,  0]  1 */
       10810, /* 64022 (1594) [ 0,  0,  1,  1,  0,  0,  0, -1,  0] [ 0,  0,  0]  1 */
        3256, /* 64023 (1594) [-1,  0,  0,  0,  0, -1,  0,  1,  0] [ 0,  0,  0]  1 */
        9040, /* 64024 (1594) [ 0,  0, -1,  0, -1,  0,  1,  0,  0] [ 0,  0,  0]  1 */
        9184, /* 64025 (1594) [ 0,  0, -1,  0,  1,  0, -1,  0,  0] [ 0,  0,  0]  1 */
        7410, /* 64026 (1594) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  0]  1 */
        7636, /* 64027 (1594) [ 0, -1,  0,  0,  0, -1,  1,  0,  0] [ 0,  0,  0]  1 */
        9352, /* 64028 (1594) [ 0,  0, -1,  1,  0,  0,  0, -1,  0] [ 0,  0,  0]  1 */
        8872, /* 64029 (1594) [ 0,  0, -1, -1,  0,  0,  0,  1,  0] [ 0,  0,  0]  1 */
       10480, /* 64030 (1594) [ 0,  0,  1,  0, -1,  0, -1,  0,  0] [ 0,  0,  0]  1 */
       11784, /* 64031 (1594) [ 0,  1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  0]  1 */
        7896, /* 64032 (1594) [ 0, -1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  0]  1 */
       10642, /* 64033 (1594) [ 0,  0,  1,  0,  1,  0, -1,  0,  0] [ 0,  0,  0]  1 */
       16372, /* 64034 (1594) [ 1,  0,  0,  0,  0, -1,  0, -1,  0] [ 0,  0,  0]  1 */
        7672, /* 64035 (1594) [ 0, -1,  0,  0,  0,  1, -1,  0,  0] [ 0,  0,  0]  1 */
       10330, /* 64036 (1594) [ 0,  0,  1, -1,  0,  0,  0,  1,  0] [ 0,  0,  0]  1 */
       11786, /* 64037 (1594) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  0]  1 */
        3360, /* 64038 (1594) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
        7898, /* 64039 (1594) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 0,  0,  0]  1 */
        3250, /* 64040 (1594) [-1,  0,  0,  0,  0, -1,  0, -1,  0] [ 0,  0,  0]  1 */
       12010, /* 64041 (1594) [ 0,  1,  0,  0,  0, -1,  1,  0,  0] [ 0,  0,  0]  1 */
       16426, /* 64042 (1594) [ 1,  0,  0,  0,  0,  1,  0, -1,  0] [ 0,  0,  0]  1 */
       12046, /* 64043 (1594) [ 0,  1,  0,  0,  0,  1, -1,  0,  0] [ 0,  0,  0]  1 */
       16322, /* 64044 (1594) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
        3310, /* 64045 (1594) [-1,  0,  0,  0,  0,  1,  0,  1,  0] [ 0,  0,  0]  1 */
        9202, /* 64046 (1594) [ 0,  0, -1,  0,  1,  0,  1,  0,  0] [ 0,  0,  0]  1 */
       10816, /* 64047 (1594) [ 0,  0,  1,  1,  0,  0,  0,  1,  0] [ 0,  0,  0]  1 */
        3200, /* 64048 (1594) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
        3362, /* 64049 (1594) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
        9358, /* 64050 (1594) [ 0,  0, -1,  1,  0,  0,  0,  1,  0] [ 0,  0,  0]  1 */
       12272, /* 64051 (1594) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 0,  0,  0]  1 */
       11992, /* 64052 (1594) [ 0,  1,  0,  0,  0, -1, -1,  0,  0] [ 0,  0,  0]  1 */
        7412, /* 64053 (1594) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  0]  1 */
       12064, /* 64054 (1594) [ 0,  1,  0,  0,  0,  1,  1,  0,  0] [ 0,  0,  0]  1 */
        3304, /* 64055 (1594) [-1,  0,  0,  0,  0,  1,  0, -1,  0] [ 0,  0,  0]  1 */
        7618, /* 64056 (1594) [ 0, -1,  0,  0,  0, -1, -1,  0,  0] [ 0,  0,  0]  1 */
       16482, /* 64057 (1594) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
       10324, /* 64058 (1594) [ 0,  0,  1, -1,  0,  0,  0, -1,  0] [ 0,  0,  0]  1 */
       16484, /* 64059 (1595) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
       10660, /* 64060 (1595) [ 0,  0,  1,  0,  1,  0,  1,  0,  0] [ 0,  0,  0]  1 */
        9022, /* 64061 (1595) [ 0,  0, -1,  0, -1,  0, -1,  0,  0] [ 0,  0,  0]  1 */
       16320, /* 64062 (1595) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
        3198, /* 64063 (1595) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
       16432, /* 64064 (1595) [ 1,  0,  0,  0,  0,  1,  0,  1,  0] [ 0,  0,  0]  1 */
        3256, /* 64065 (1595) [-1,  0,  0,  0,  0, -1,  0,  1,  0] [ 0,  0,  0]  1 */
    34020120, /* 64066 (1595) [ 0, -1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    34019896, /* 64067 (1595) [ 0, -1,  0,  0,  0,  1, -1,  0,  0] [ 0,  0,  0] -1 */
        9184, /* 64068 (1595) [ 0,  0, -1,  0,  1,  0, -1,  0,  0] [ 0,  0,  0]  1 */
    34015584, /* 64069 (1595) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
        7410, /* 64070 (1595) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    34024234, /* 64071 (1595) [ 0,  1,  0,  0,  0, -1,  1,  0,  0] [ 0,  0,  0] -1 */
    34020122, /* 64072 (1595) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 0,  0,  0] -1 */
        9352, /* 64073 (1595) [ 0,  0, -1,  1,  0,  0,  0, -1,  0] [ 0,  0,  0]  1 */
    34024496, /* 64074 (1595) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    34023040, /* 64075 (1595) [ 0,  0,  1,  1,  0,  0,  0,  1,  0] [ 0,  0,  0] -1 */
        8872, /* 64076 (1595) [ 0,  0, -1, -1,  0,  0,  0,  1,  0] [ 0,  0,  0]  1 */
    34024288, /* 64077 (1595) [ 0,  1,  0,  0,  0,  1,  1,  0,  0] [ 0,  0,  0] -1 */
       16372, /* 64078 (1595) [ 1,  0,  0,  0,  0, -1,  0, -1,  0] [ 0,  0,  0]  1 */
        3250, /* 64079 (1595) [-1,  0,  0,  0,  0, -1,  0, -1,  0] [ 0,  0,  0]  1 */
        9202, /* 64080 (1595) [ 0,  0, -1,  0,  1,  0,  1,  0,  0] [ 0,  0,  0]  1 */
    34024494, /* 64081 (1595) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    34023034, /* 64082 (1595) [ 0,  0,  1,  1,  0,  0,  0, -1,  0] [ 0,  0,  0] -1 */
        3304, /* 64083 (1595) [-1,  0,  0,  0,  0,  1,  0, -1,  0] [ 0,  0,  0]  1 */
    34021264, /* 64084 (1595) [ 0,  0, -1,  0, -1,  0,  1,  0,  0] [ 0,  0,  0] -1 */
       10324, /* 64085 (1595) [ 0,  0,  1, -1,  0,  0,  0, -1,  0] [ 0,  0,  0]  1 */
        8866, /* 64086 (1595) [ 0,  0, -1, -1,  0,  0,  0, -1,  0] [ 0,  0,  0]  1 */
    34024008, /* 64087 (1595) [ 0,  1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    34022866, /* 64088 (1595) [ 0,  0,  1,  0,  1,  0, -1,  0,  0] [ 0,  0,  0] -1 */
    34022554, /* 64089 (1595) [ 0,  0,  1, -1,  0,  0,  0,  1,  0] [ 0,  0,  0] -1 */
    34028650, /* 64090 (1595) [ 1,  0,  0,  0,  0,  1,  0, -1,  0] [ 0,  0,  0] -1 */
    34024270, /* 64091 (1595) [ 0,  1,  0,  0,  0,  1, -1,  0,  0] [ 0,  0,  0] -1 */
    34015424, /* 64092 (1595) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    34028708, /* 64093 (1595) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    34021582, /* 64094 (1595) [ 0,  0, -1,  1,  0,  0,  0,  1,  0] [ 0,  0,  0] -1 */
    34015586, /* 64095 (1595) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    34019636, /* 64096 (1595) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  0] -1 */
        7896, /* 64097 (1595) [ 0, -1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    34028706, /* 64098 (1595) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    34019842, /* 64099 (1595) [ 0, -1,  0,  0,  0, -1, -1,  0,  0] [ 0,  0,  0] -1 */
       11786, /* 64100 (1595) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34022884, /* 64101 (1595) [ 0,  0,  1,  0,  1,  0,  1,  0,  0] [ 0,  0,  0] -1 */
        7898, /* 64102 (1595) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34028544, /* 64103 (1595) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
        3310, /* 64104 (1595) [-1,  0,  0,  0,  0,  1,  0,  1,  0] [ 0,  0,  0]  1 */
    34028602, /* 64105 (1595) [ 1,  0,  0,  0,  0, -1,  0,  1,  0] [ 0,  0,  0] -1 */
       10816, /* 64106 (1595) [ 0,  0,  1,  1,  0,  0,  0,  1,  0] [ 0,  0,  0]  1 */
    34015422, /* 64107 (1595) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
       11992, /* 64108 (1595) [ 0,  1,  0,  0,  0, -1, -1,  0,  0] [ 0,  0,  0]  1 */
       12064, /* 64109 (1595) [ 0,  1,  0,  0,  0,  1,  1,  0,  0] [ 0,  0,  0]  1 */
    34019914, /* 64110 (1595) [ 0, -1,  0,  0,  0,  1,  1,  0,  0] [ 0,  0,  0] -1 */
    34019860, /* 64111 (1595) [ 0, -1,  0,  0,  0, -1,  1,  0,  0] [ 0,  0,  0] -1 */
       12270, /* 64112 (1595) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  0]  1 */
       10498, /* 64113 (1595) [ 0,  0,  1,  0, -1,  0,  1,  0,  0] [ 0,  0,  0]  1 */
    34022704, /* 64114 (1595) [ 0,  0,  1,  0, -1,  0, -1,  0,  0] [ 0,  0,  0] -1 */
        9040, /* 64115 (1595) [ 0,  0, -1,  0, -1,  0,  1,  0,  0] [ 0,  0,  0]  1 */
    34015474, /* 64116 (1595) [-1,  0,  0,  0,  0, -1,  0, -1,  0] [ 0,  0,  0] -1 */
    34028546, /* 64117 (1595) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    34015528, /* 64118 (1595) [-1,  0,  0,  0,  0,  1,  0, -1,  0] [ 0,  0,  0] -1 */
       11784, /* 64119 (1595) [ 0,  1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    34022548, /* 64120 (1595) [ 0,  0,  1, -1,  0,  0,  0, -1,  0] [ 0,  0,  0] -1 */
        7672, /* 64121 (1595) [ 0, -1,  0,  0,  0,  1, -1,  0,  0] [ 0,  0,  0]  1 */
    34022722, /* 64122 (1595) [ 0,  0,  1,  0, -1,  0,  1,  0,  0] [ 0,  0,  0] -1 */
       10330, /* 64123 (1595) [ 0,  0,  1, -1,  0,  0,  0,  1,  0] [ 0,  0,  0]  1 */
        3360, /* 64124 (1595) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
       12010, /* 64125 (1595) [ 0,  1,  0,  0,  0, -1,  1,  0,  0] [ 0,  0,  0]  1 */
       12046, /* 64126 (1595) [ 0,  1,  0,  0,  0,  1, -1,  0,  0] [ 0,  0,  0]  1 */
    34021246, /* 64127 (1595) [ 0,  0, -1,  0, -1,  0, -1,  0,  0] [ 0,  0,  0] -1 */
        3362, /* 64128 (1595) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
       12272, /* 64129 (1595) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34028656, /* 64130 (1595) [ 1,  0,  0,  0,  0,  1,  0,  1,  0] [ 0,  0,  0] -1 */
        7412, /* 64131 (1595) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  0]  1 */
        7618, /* 64132 (1595) [ 0, -1,  0,  0,  0, -1, -1,  0,  0] [ 0,  0,  0]  1 */
    34015480, /* 64133 (1595) [-1,  0,  0,  0,  0, -1,  0,  1,  0] [ 0,  0,  0] -1 */
    34021408, /* 64134 (1595) [ 0,  0, -1,  0,  1,  0, -1,  0,  0] [ 0,  0,  0] -1 */
    34019634, /* 64135 (1595) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  0] -1 */
       16378, /* 64136 (1595) [ 1,  0,  0,  0,  0, -1,  0,  1,  0] [ 0,  0,  0]  1 */
    34021576, /* 64137 (1595) [ 0,  0, -1,  1,  0,  0,  0, -1,  0] [ 0,  0,  0] -1 */
        7690, /* 64138 (1595) [ 0, -1,  0,  0,  0,  1,  1,  0,  0] [ 0,  0,  0]  1 */
    34021096, /* 64139 (1595) [ 0,  0, -1, -1,  0,  0,  0,  1,  0] [ 0,  0,  0] -1 */
       10810, /* 64140 (1595) [ 0,  0,  1,  1,  0,  0,  0, -1,  0] [ 0,  0,  0]  1 */
    34024010, /* 64141 (1595) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    34028596, /* 64142 (1595) [ 1,  0,  0,  0,  0, -1,  0, -1,  0] [ 0,  0,  0] -1 */
        7636, /* 64143 (1595) [ 0, -1,  0,  0,  0, -1,  1,  0,  0] [ 0,  0,  0]  1 */
    34015534, /* 64144 (1595) [-1,  0,  0,  0,  0,  1,  0,  1,  0] [ 0,  0,  0] -1 */
    34021426, /* 64145 (1595) [ 0,  0, -1,  0,  1,  0,  1,  0,  0] [ 0,  0,  0] -1 */
    34024216, /* 64146 (1595) [ 0,  1,  0,  0,  0, -1, -1,  0,  0] [ 0,  0,  0] -1 */
       10480, /* 64147 (1595) [ 0,  0,  1,  0, -1,  0, -1,  0,  0] [ 0,  0,  0]  1 */
       10642, /* 64148 (1595) [ 0,  0,  1,  0,  1,  0, -1,  0,  0] [ 0,  0,  0]  1 */
       16426, /* 64149 (1595) [ 1,  0,  0,  0,  0,  1,  0, -1,  0] [ 0,  0,  0]  1 */
       16322, /* 64150 (1595) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
        3200, /* 64151 (1595) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
        9358, /* 64152 (1595) [ 0,  0, -1,  1,  0,  0,  0,  1,  0] [ 0,  0,  0]  1 */
    34021090, /* 64153 (1595) [ 0,  0, -1, -1,  0,  0,  0, -1,  0] [ 0,  0,  0] -1 */
       16482, /* 64154 (1595) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
       16484, /* 64155 (1596) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
       10660, /* 64156 (1596) [ 0,  0,  1,  0,  1,  0,  1,  0,  0] [ 0,  0,  0]  1 */
    34019634, /* 64157 (1596) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  0] -1 */
       16320, /* 64158 (1596) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
       16432, /* 64159 (1596) [ 1,  0,  0,  0,  0,  1,  0,  1,  0] [ 0,  0,  0]  1 */
        9040, /* 64160 (1596) [ 0,  0, -1,  0, -1,  0,  1,  0,  0] [ 0,  0,  0]  1 */
    34022866, /* 64161 (1596) [ 0,  0,  1,  0,  1,  0, -1,  0,  0] [ 0,  0,  0] -1 */
        3256, /* 64162 (1596) [-1,  0,  0,  0,  0, -1,  0,  1,  0] [ 0,  0,  0]  1 */
    34024010, /* 64163 (1596) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    34015474, /* 64164 (1596) [-1,  0,  0,  0,  0, -1,  0, -1,  0] [ 0,  0,  0] -1 */
        9184, /* 64165 (1596) [ 0,  0, -1,  0,  1,  0, -1,  0,  0] [ 0,  0,  0]  1 */
        7636, /* 64166 (1596) [ 0, -1,  0,  0,  0, -1,  1,  0,  0] [ 0,  0,  0]  1 */
    34028650, /* 64167 (1596) [ 1,  0,  0,  0,  0,  1,  0, -1,  0] [ 0,  0,  0] -1 */
    34022554, /* 64168 (1596) [ 0,  0,  1, -1,  0,  0,  0,  1,  0] [ 0,  0,  0] -1 */
    34024234, /* 64169 (1596) [ 0,  1,  0,  0,  0, -1,  1,  0,  0] [ 0,  0,  0] -1 */
    34015534, /* 64170 (1596) [-1,  0,  0,  0,  0,  1,  0,  1,  0] [ 0,  0,  0] -1 */
    34020122, /* 64171 (1596) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 0,  0,  0] -1 */
        9352, /* 64172 (1596) [ 0,  0, -1,  1,  0,  0,  0, -1,  0] [ 0,  0,  0]  1 */
    34024270, /* 64173 (1596) [ 0,  1,  0,  0,  0,  1, -1,  0,  0] [ 0,  0,  0] -1 */
    34028546, /* 64174 (1596) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    34021426, /* 64175 (1596) [ 0,  0, -1,  0,  1,  0,  1,  0,  0] [ 0,  0,  0] -1 */
    34021582, /* 64176 (1596) [ 0,  0, -1,  1,  0,  0,  0,  1,  0] [ 0,  0,  0] -1 */
    34015586, /* 64177 (1596) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
        8872, /* 64178 (1596) [ 0,  0, -1, -1,  0,  0,  0,  1,  0] [ 0,  0,  0]  1 */
       10480, /* 64179 (1596) [ 0,  0,  1,  0, -1,  0, -1,  0,  0] [ 0,  0,  0]  1 */
       11784, /* 64180 (1596) [ 0,  1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  0]  1 */
        7896, /* 64181 (1596) [ 0, -1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    34028706, /* 64182 (1596) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
       16372, /* 64183 (1596) [ 1,  0,  0,  0,  0, -1,  0, -1,  0] [ 0,  0,  0]  1 */
    34019842, /* 64184 (1596) [ 0, -1,  0,  0,  0, -1, -1,  0,  0] [ 0,  0,  0] -1 */
        7672, /* 64185 (1596) [ 0, -1,  0,  0,  0,  1, -1,  0,  0] [ 0,  0,  0]  1 */
    34022722, /* 64186 (1596) [ 0,  0,  1,  0, -1,  0,  1,  0,  0] [ 0,  0,  0] -1 */
        3360, /* 64187 (1596) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    34021246, /* 64188 (1596) [ 0,  0, -1,  0, -1,  0, -1,  0,  0] [ 0,  0,  0] -1 */
    34028602, /* 64189 (1596) [ 1,  0,  0,  0,  0, -1,  0,  1,  0] [ 0,  0,  0] -1 */
    34015422, /* 64190 (1596) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
       10816, /* 64191 (1596) [ 0,  0,  1,  1,  0,  0,  0,  1,  0] [ 0,  0,  0]  1 */
        3200, /* 64192 (1596) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34024494, /* 64193 (1596) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  0] -1 */
       12272, /* 64194 (1596) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 0,  0,  0]  1 */
       11992, /* 64195 (1596) [ 0,  1,  0,  0,  0, -1, -1,  0,  0] [ 0,  0,  0]  1 */
        7412, /* 64196 (1596) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  0]  1 */
       12064, /* 64197 (1596) [ 0,  1,  0,  0,  0,  1,  1,  0,  0] [ 0,  0,  0]  1 */
    34023034, /* 64198 (1596) [ 0,  0,  1,  1,  0,  0,  0, -1,  0] [ 0,  0,  0] -1 */
        3304, /* 64199 (1596) [-1,  0,  0,  0,  0,  1,  0, -1,  0] [ 0,  0,  0]  1 */
    34019914, /* 64200 (1596) [ 0, -1,  0,  0,  0,  1,  1,  0,  0] [ 0,  0,  0] -1 */
    34021090, /* 64201 (1596) [ 0,  0, -1, -1,  0,  0,  0, -1,  0] [ 0,  0,  0] -1 */
       10324, /* 64202 (1596) [ 0,  0,  1, -1,  0,  0,  0, -1,  0] [ 0,  0,  0]  1 */
       16484, /* 64203 (1597) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34021408, /* 64204 (1597) [ 0,  0, -1,  0,  1,  0, -1,  0,  0] [ 0,  0,  0] -1 */
    34019634, /* 64205 (1597) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  0] -1 */
       16320, /* 64206 (1597) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
        3198, /* 64207 (1597) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
        7690, /* 64208 (1597) [ 0, -1,  0,  0,  0,  1,  1,  0,  0] [ 0,  0,  0]  1 */
        8866, /* 64209 (1597) [ 0,  0, -1, -1,  0,  0,  0, -1,  0] [ 0,  0,  0]  1 */
    34022704, /* 64210 (1597) [ 0,  0,  1,  0, -1,  0, -1,  0,  0] [ 0,  0,  0] -1 */
       10810, /* 64211 (1597) [ 0,  0,  1,  1,  0,  0,  0, -1,  0] [ 0,  0,  0]  1 */
    34024008, /* 64212 (1597) [ 0,  1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    34022866, /* 64213 (1597) [ 0,  0,  1,  0,  1,  0, -1,  0,  0] [ 0,  0,  0] -1 */
    34020120, /* 64214 (1597) [ 0, -1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    34024010, /* 64215 (1597) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    34028596, /* 64216 (1597) [ 1,  0,  0,  0,  0, -1,  0, -1,  0] [ 0,  0,  0] -1 */
    34015474, /* 64217 (1597) [-1,  0,  0,  0,  0, -1,  0, -1,  0] [ 0,  0,  0] -1 */
        7636, /* 64218 (1597) [ 0, -1,  0,  0,  0, -1,  1,  0,  0] [ 0,  0,  0]  1 */
    34028650, /* 64219 (1597) [ 1,  0,  0,  0,  0,  1,  0, -1,  0] [ 0,  0,  0] -1 */
    34015534, /* 64220 (1597) [-1,  0,  0,  0,  0,  1,  0,  1,  0] [ 0,  0,  0] -1 */
    34020122, /* 64221 (1597) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 0,  0,  0] -1 */
        9352, /* 64222 (1597) [ 0,  0, -1,  1,  0,  0,  0, -1,  0] [ 0,  0,  0]  1 */
    34021426, /* 64223 (1597) [ 0,  0, -1,  0,  1,  0,  1,  0,  0] [ 0,  0,  0] -1 */
    34024496, /* 64224 (1597) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 0,  0,  0] -1 */
        8872, /* 64225 (1597) [ 0,  0, -1, -1,  0,  0,  0,  1,  0] [ 0,  0,  0]  1 */
    34015528, /* 64226 (1597) [-1,  0,  0,  0,  0,  1,  0, -1,  0] [ 0,  0,  0] -1 */
    34019636, /* 64227 (1597) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  0] -1 */
        7672, /* 64228 (1597) [ 0, -1,  0,  0,  0,  1, -1,  0,  0] [ 0,  0,  0]  1 */
    34022722, /* 64229 (1597) [ 0,  0,  1,  0, -1,  0,  1,  0,  0] [ 0,  0,  0] -1 */
       10330, /* 64230 (1597) [ 0,  0,  1, -1,  0,  0,  0,  1,  0] [ 0,  0,  0]  1 */
    34022884, /* 64231 (1597) [ 0,  0,  1,  0,  1,  0,  1,  0,  0] [ 0,  0,  0] -1 */
        3360, /* 64232 (1597) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
       12010, /* 64233 (1597) [ 0,  1,  0,  0,  0, -1,  1,  0,  0] [ 0,  0,  0]  1 */
       12046, /* 64234 (1597) [ 0,  1,  0,  0,  0,  1, -1,  0,  0] [ 0,  0,  0]  1 */
       16322, /* 64235 (1597) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34021246, /* 64236 (1597) [ 0,  0, -1,  0, -1,  0, -1,  0,  0] [ 0,  0,  0] -1 */
    34028602, /* 64237 (1597) [ 1,  0,  0,  0,  0, -1,  0,  1,  0] [ 0,  0,  0] -1 */
       10816, /* 64238 (1597) [ 0,  0,  1,  1,  0,  0,  0,  1,  0] [ 0,  0,  0]  1 */
        3200, /* 64239 (1597) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
        3362, /* 64240 (1597) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34024494, /* 64241 (1597) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  0] -1 */
        9358, /* 64242 (1597) [ 0,  0, -1,  1,  0,  0,  0,  1,  0] [ 0,  0,  0]  1 */
       11992, /* 64243 (1597) [ 0,  1,  0,  0,  0, -1, -1,  0,  0] [ 0,  0,  0]  1 */
    34028656, /* 64244 (1597) [ 1,  0,  0,  0,  0,  1,  0,  1,  0] [ 0,  0,  0] -1 */
       12064, /* 64245 (1597) [ 0,  1,  0,  0,  0,  1,  1,  0,  0] [ 0,  0,  0]  1 */
        7618, /* 64246 (1597) [ 0, -1,  0,  0,  0, -1, -1,  0,  0] [ 0,  0,  0]  1 */
    34021264, /* 64247 (1597) [ 0,  0, -1,  0, -1,  0,  1,  0,  0] [ 0,  0,  0] -1 */
    34015480, /* 64248 (1597) [-1,  0,  0,  0,  0, -1,  0,  1,  0] [ 0,  0,  0] -1 */
       16482, /* 64249 (1597) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
       10324, /* 64250 (1597) [ 0,  0,  1, -1,  0,  0,  0, -1,  0] [ 0,  0,  0]  1 */
       16484, /* 64251 (1598) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34021408, /* 64252 (1598) [ 0,  0, -1,  0,  1,  0, -1,  0,  0] [ 0,  0,  0] -1 */
        9022, /* 64253 (1598) [ 0,  0, -1,  0, -1,  0, -1,  0,  0] [ 0,  0,  0]  1 */
       16378, /* 64254 (1598) [ 1,  0,  0,  0,  0, -1,  0,  1,  0] [ 0,  0,  0]  1 */
       16320, /* 64255 (1598) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
       12270, /* 64256 (1598) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    34022704, /* 64257 (1598) [ 0,  0,  1,  0, -1,  0, -1,  0,  0] [ 0,  0,  0] -1 */
    34024008, /* 64258 (1598) [ 0,  1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    34020120, /* 64259 (1598) [ 0, -1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    34028596, /* 64260 (1598) [ 1,  0,  0,  0,  0, -1,  0, -1,  0] [ 0,  0,  0] -1 */
        7410, /* 64261 (1598) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    34022554, /* 64262 (1598) [ 0,  0,  1, -1,  0,  0,  0,  1,  0] [ 0,  0,  0] -1 */
        7636, /* 64263 (1598) [ 0, -1,  0,  0,  0, -1,  1,  0,  0] [ 0,  0,  0]  1 */
    34024234, /* 64264 (1598) [ 0,  1,  0,  0,  0, -1,  1,  0,  0] [ 0,  0,  0] -1 */
        9352, /* 64265 (1598) [ 0,  0, -1,  1,  0,  0,  0, -1,  0] [ 0,  0,  0]  1 */
    34024270, /* 64266 (1598) [ 0,  1,  0,  0,  0,  1, -1,  0,  0] [ 0,  0,  0] -1 */
    34028546, /* 64267 (1598) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    34021582, /* 64268 (1598) [ 0,  0, -1,  1,  0,  0,  0,  1,  0] [ 0,  0,  0] -1 */
    34024496, /* 64269 (1598) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    34015586, /* 64270 (1598) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
        8872, /* 64271 (1598) [ 0,  0, -1, -1,  0,  0,  0,  1,  0] [ 0,  0,  0]  1 */
    34015528, /* 64272 (1598) [-1,  0,  0,  0,  0,  1,  0, -1,  0] [ 0,  0,  0] -1 */
    34019636, /* 64273 (1598) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    34028706, /* 64274 (1598) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
       10642, /* 64275 (1598) [ 0,  0,  1,  0,  1,  0, -1,  0,  0] [ 0,  0,  0]  1 */
    34019842, /* 64276 (1598) [ 0, -1,  0,  0,  0, -1, -1,  0,  0] [ 0,  0,  0] -1 */
        7672, /* 64277 (1598) [ 0, -1,  0,  0,  0,  1, -1,  0,  0] [ 0,  0,  0]  1 */
       11786, /* 64278 (1598) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34022884, /* 64279 (1598) [ 0,  0,  1,  0,  1,  0,  1,  0,  0] [ 0,  0,  0] -1 */
        3360, /* 64280 (1598) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
        7898, /* 64281 (1598) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 0,  0,  0]  1 */
        3250, /* 64282 (1598) [-1,  0,  0,  0,  0, -1,  0, -1,  0] [ 0,  0,  0]  1 */
       16426, /* 64283 (1598) [ 1,  0,  0,  0,  0,  1,  0, -1,  0] [ 0,  0,  0]  1 */
        3310, /* 64284 (1598) [-1,  0,  0,  0,  0,  1,  0,  1,  0] [ 0,  0,  0]  1 */
        9202, /* 64285 (1598) [ 0,  0, -1,  0,  1,  0,  1,  0,  0] [ 0,  0,  0]  1 */
       10816, /* 64286 (1598) [ 0,  0,  1,  1,  0,  0,  0,  1,  0] [ 0,  0,  0]  1 */
    34015422, /* 64287 (1598) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
        3200, /* 64288 (1598) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
       11992, /* 64289 (1598) [ 0,  1,  0,  0,  0, -1, -1,  0,  0] [ 0,  0,  0]  1 */
    34028656, /* 64290 (1598) [ 1,  0,  0,  0,  0,  1,  0,  1,  0] [ 0,  0,  0] -1 */
       12064, /* 64291 (1598) [ 0,  1,  0,  0,  0,  1,  1,  0,  0] [ 0,  0,  0]  1 */
    34023034, /* 64292 (1598) [ 0,  0,  1,  1,  0,  0,  0, -1,  0] [ 0,  0,  0] -1 */
    34019914, /* 64293 (1598) [ 0, -1,  0,  0,  0,  1,  1,  0,  0] [ 0,  0,  0] -1 */
    34021090, /* 64294 (1598) [ 0,  0, -1, -1,  0,  0,  0, -1,  0] [ 0,  0,  0] -1 */
    34021264, /* 64295 (1598) [ 0,  0, -1,  0, -1,  0,  1,  0,  0] [ 0,  0,  0] -1 */
    34015480, /* 64296 (1598) [-1,  0,  0,  0,  0, -1,  0,  1,  0] [ 0,  0,  0] -1 */
       10498, /* 64297 (1598) [ 0,  0,  1,  0, -1,  0,  1,  0,  0] [ 0,  0,  0]  1 */
       10324, /* 64298 (1598) [ 0,  0,  1, -1,  0,  0,  0, -1,  0] [ 0,  0,  0]  1 */
       16484, /* 64299 (1599) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    52562962, /* 64300 (1599) [ 0,  0, -1,  1,  0,  0,  0, -1,  0] [ 6,  6,  6] -1 */
       10660, /* 64301 (1599) [ 0,  0,  1,  0,  1,  0,  1,  0,  0] [ 0,  0,  0]  1 */
        9022, /* 64302 (1599) [ 0,  0, -1,  0, -1,  0, -1,  0,  0] [ 0,  0,  0]  1 */
       16320, /* 64303 (1599) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
        3198, /* 64304 (1599) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
       16432, /* 64305 (1599) [ 1,  0,  0,  0,  0,  1,  0,  1,  0] [ 0,  0,  0]  1 */
    52565394, /* 64306 (1599) [ 0,  1,  0, -1,  0,  0,  0,  0, -1] [ 6,  6,  6] -1 */
        3256, /* 64307 (1599) [-1,  0,  0,  0,  0, -1,  0,  1,  0] [ 0,  0,  0]  1 */
    52562968, /* 64308 (1599) [ 0,  0, -1,  1,  0,  0,  0,  1,  0] [ 6,  6,  6] -1 */
    52565620, /* 64309 (1599) [ 0,  1,  0,  0,  0, -1,  1,  0,  0] [ 6,  6,  6] -1 */
    52565656, /* 64310 (1599) [ 0,  1,  0,  0,  0,  1, -1,  0,  0] [ 6,  6,  6] -1 */
        9184, /* 64311 (1599) [ 0,  0, -1,  0,  1,  0, -1,  0,  0] [ 0,  0,  0]  1 */
        7410, /* 64312 (1599) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  0]  1 */
        9352, /* 64313 (1599) [ 0,  0, -1,  1,  0,  0,  0, -1,  0] [ 0,  0,  0]  1 */
    52556972, /* 64314 (1599) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    52565882, /* 64315 (1599) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    52556810, /* 64316 (1599) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
        8872, /* 64317 (1599) [ 0,  0, -1, -1,  0,  0,  0,  1,  0] [ 0,  0,  0]  1 */
    52561228, /* 64318 (1599) [ 0, -1,  0,  0,  0, -1, -1,  0,  0] [ 6,  6,  6] -1 */
    52570042, /* 64319 (1599) [ 1,  0,  0,  0,  0,  1,  0,  1,  0] [ 6,  6,  6] -1 */
       16372, /* 64320 (1599) [ 1,  0,  0,  0,  0, -1,  0, -1,  0] [ 0,  0,  0]  1 */
    52561022, /* 64321 (1599) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    52569988, /* 64322 (1599) [ 1,  0,  0,  0,  0, -1,  0,  1,  0] [ 6,  6,  6] -1 */
        3250, /* 64323 (1599) [-1,  0,  0,  0,  0, -1,  0, -1,  0] [ 0,  0,  0]  1 */
    52570092, /* 64324 (1599) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    52556866, /* 64325 (1599) [-1,  0,  0,  0,  0, -1,  0,  1,  0] [ 6,  6,  6] -1 */
        9202, /* 64326 (1599) [ 0,  0, -1,  0,  1,  0,  1,  0,  0] [ 0,  0,  0]  1 */
    52562632, /* 64327 (1599) [ 0,  0, -1,  0, -1,  0, -1,  0,  0] [ 6,  6,  6] -1 */
    52564420, /* 64328 (1599) [ 0,  0,  1,  1,  0,  0,  0, -1,  0] [ 6,  6,  6] -1 */
        3304, /* 64329 (1599) [-1,  0,  0,  0,  0,  1,  0, -1,  0] [ 0,  0,  0]  1 */
    52561246, /* 64330 (1599) [ 0, -1,  0,  0,  0, -1,  1,  0,  0] [ 6,  6,  6] -1 */
       10324, /* 64331 (1599) [ 0,  0,  1, -1,  0,  0,  0, -1,  0] [ 0,  0,  0]  1 */
    52564252, /* 64332 (1599) [ 0,  0,  1,  0,  1,  0, -1,  0,  0] [ 6,  6,  6] -1 */
        8866, /* 64333 (1599) [ 0,  0, -1, -1,  0,  0,  0, -1,  0] [ 0,  0,  0]  1 */
    52565396, /* 64334 (1599) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    52562482, /* 64335 (1599) [ 0,  0, -1, -1,  0,  0,  0,  1,  0] [ 6,  6,  6] -1 */
    52570036, /* 64336 (1599) [ 1,  0,  0,  0,  0,  1,  0, -1,  0] [ 6,  6,  6] -1 */
    52564090, /* 64337 (1599) [ 0,  0,  1,  0, -1,  0, -1,  0,  0] [ 6,  6,  6] -1 */
        7896, /* 64338 (1599) [ 0, -1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    52564270, /* 64339 (1599) [ 0,  0,  1,  0,  1,  0,  1,  0,  0] [ 6,  6,  6] -1 */
       11786, /* 64340 (1599) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    52569930, /* 64341 (1599) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
        7898, /* 64342 (1599) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    52556808, /* 64343 (1599) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
        3310, /* 64344 (1599) [-1,  0,  0,  0,  0,  1,  0,  1,  0] [ 0,  0,  0]  1 */
    52564108, /* 64345 (1599) [ 0,  0,  1,  0, -1,  0,  1,  0,  0] [ 6,  6,  6] -1 */
       10816, /* 64346 (1599) [ 0,  0,  1,  1,  0,  0,  0,  1,  0] [ 0,  0,  0]  1 */
       11992, /* 64347 (1599) [ 0,  1,  0,  0,  0, -1, -1,  0,  0] [ 0,  0,  0]  1 */
       12064, /* 64348 (1599) [ 0,  1,  0,  0,  0,  1,  1,  0,  0] [ 0,  0,  0]  1 */
    52562794, /* 64349 (1599) [ 0,  0, -1,  0,  1,  0, -1,  0,  0] [ 6,  6,  6] -1 */
    52561020, /* 64350 (1599) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    52561506, /* 64351 (1599) [ 0, -1,  0,  1,  0,  0,  0,  0, -1] [ 6,  6,  6] -1 */
       12270, /* 64352 (1599) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  0]  1 */
       10498, /* 64353 (1599) [ 0,  0,  1,  0, -1,  0,  1,  0,  0] [ 0,  0,  0]  1 */
    52569982, /* 64354 (1599) [ 1,  0,  0,  0,  0, -1,  0, -1,  0] [ 6,  6,  6] -1 */
        9040, /* 64355 (1599) [ 0,  0, -1,  0, -1,  0,  1,  0,  0] [ 0,  0,  0]  1 */
    52563940, /* 64356 (1599) [ 0,  0,  1, -1,  0,  0,  0,  1,  0] [ 6,  6,  6] -1 */
    52556860, /* 64357 (1599) [-1,  0,  0,  0,  0, -1,  0, -1,  0] [ 6,  6,  6] -1 */
    52562812, /* 64358 (1599) [ 0,  0, -1,  0,  1,  0,  1,  0,  0] [ 6,  6,  6] -1 */
    52556914, /* 64359 (1599) [-1,  0,  0,  0,  0,  1,  0, -1,  0] [ 6,  6,  6] -1 */
       11784, /* 64360 (1599) [ 0,  1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    52563934, /* 64361 (1599) [ 0,  0,  1, -1,  0,  0,  0, -1,  0] [ 6,  6,  6] -1 */
        7672, /* 64362 (1599) [ 0, -1,  0,  0,  0,  1, -1,  0,  0] [ 0,  0,  0]  1 */
       10330, /* 64363 (1599) [ 0,  0,  1, -1,  0,  0,  0,  1,  0] [ 0,  0,  0]  1 */
        3360, /* 64364 (1599) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
       12010, /* 64365 (1599) [ 0,  1,  0,  0,  0, -1,  1,  0,  0] [ 0,  0,  0]  1 */
       12046, /* 64366 (1599) [ 0,  1,  0,  0,  0,  1, -1,  0,  0] [ 0,  0,  0]  1 */
        3362, /* 64367 (1599) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
       12272, /* 64368 (1599) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    52562476, /* 64369 (1599) [ 0,  0, -1, -1,  0,  0,  0, -1,  0] [ 6,  6,  6] -1 */
    52561300, /* 64370 (1599) [ 0, -1,  0,  0,  0,  1,  1,  0,  0] [ 6,  6,  6] -1 */
        7412, /* 64371 (1599) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  0]  1 */
        7618, /* 64372 (1599) [ 0, -1,  0,  0,  0, -1, -1,  0,  0] [ 0,  0,  0]  1 */
    52562650, /* 64373 (1599) [ 0,  0, -1,  0, -1,  0,  1,  0,  0] [ 6,  6,  6] -1 */
       16378, /* 64374 (1599) [ 1,  0,  0,  0,  0, -1,  0,  1,  0] [ 0,  0,  0]  1 */
    52556970, /* 64375 (1599) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    52570094, /* 64376 (1599) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
        7690, /* 64377 (1599) [ 0, -1,  0,  0,  0,  1,  1,  0,  0] [ 0,  0,  0]  1 */
       10810, /* 64378 (1599) [ 0,  0,  1,  1,  0,  0,  0, -1,  0] [ 0,  0,  0]  1 */
    52561508, /* 64379 (1599) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    52569932, /* 64380 (1599) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    52556920, /* 64381 (1599) [-1,  0,  0,  0,  0,  1,  0,  1,  0] [ 6,  6,  6] -1 */
        7636, /* 64382 (1599) [ 0, -1,  0,  0,  0, -1,  1,  0,  0] [ 0,  0,  0]  1 */
    52561282, /* 64383 (1599) [ 0, -1,  0,  0,  0,  1, -1,  0,  0] [ 6,  6,  6] -1 */
    52565602, /* 64384 (1599) [ 0,  1,  0,  0,  0, -1, -1,  0,  0] [ 6,  6,  6] -1 */
    52565674, /* 64385 (1599) [ 0,  1,  0,  0,  0,  1,  1,  0,  0] [ 6,  6,  6] -1 */
       10480, /* 64386 (1599) [ 0,  0,  1,  0, -1,  0, -1,  0,  0] [ 0,  0,  0]  1 */
    52564426, /* 64387 (1599) [ 0,  0,  1,  1,  0,  0,  0,  1,  0] [ 6,  6,  6] -1 */
       10642, /* 64388 (1599) [ 0,  0,  1,  0,  1,  0, -1,  0,  0] [ 0,  0,  0]  1 */
    52565880, /* 64389 (1599) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 6,  6,  6] -1 */
       16426, /* 64390 (1599) [ 1,  0,  0,  0,  0,  1,  0, -1,  0] [ 0,  0,  0]  1 */
       16322, /* 64391 (1599) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
        3200, /* 64392 (1599) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
        9358, /* 64393 (1599) [ 0,  0, -1,  1,  0,  0,  0,  1,  0] [ 0,  0,  0]  1 */
       16482, /* 64394 (1599) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
       16484, /* 64395 (1600) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
       11786, /* 64396 (1600) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  0]  1 */
        3360, /* 64397 (1600) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
       12270, /* 64398 (1600) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    18551716, /* 64399 (1600) [ 0,  0,  1, -1,  0,  0,  0,  1,  0] [ 6,  6,  6]  1 */
    18553396, /* 64400 (1600) [ 0,  1,  0,  0,  0, -1,  1,  0,  0] [ 6,  6,  6]  1 */
    18544748, /* 64401 (1600) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    18544690, /* 64402 (1600) [-1,  0,  0,  0,  0,  1,  0, -1,  0] [ 6,  6,  6]  1 */
    18544584, /* 64403 (1600) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
       10324, /* 64404 (1600) [ 0,  0,  1, -1,  0,  0,  0, -1,  0] [ 0,  0,  0]  1 */
       11992, /* 64405 (1600) [ 0,  1,  0,  0,  0, -1, -1,  0,  0] [ 0,  0,  0]  1 */
        9022, /* 64406 (1600) [ 0,  0, -1,  0, -1,  0, -1,  0,  0] [ 0,  0,  0]  1 */
        7672, /* 64407 (1600) [ 0, -1,  0,  0,  0,  1, -1,  0,  0] [ 0,  0,  0]  1 */
    18557708, /* 64408 (1600) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    18552196, /* 64409 (1600) [ 0,  0,  1,  1,  0,  0,  0, -1,  0] [ 6,  6,  6]  1 */
    18544642, /* 64410 (1600) [-1,  0,  0,  0,  0, -1,  0,  1,  0] [ 6,  6,  6]  1 */
    18550252, /* 64411 (1600) [ 0,  0, -1, -1,  0,  0,  0, -1,  0] [ 6,  6,  6]  1 */
        7410, /* 64412 (1600) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    18550426, /* 64413 (1600) [ 0,  0, -1,  0, -1,  0,  1,  0,  0] [ 6,  6,  6]  1 */
        7636, /* 64414 (1600) [ 0, -1,  0,  0,  0, -1,  1,  0,  0] [ 0,  0,  0]  1 */
       10498, /* 64415 (1600) [ 0,  0,  1,  0, -1,  0,  1,  0,  0] [ 0,  0,  0]  1 */
    18553170, /* 64416 (1600) [ 0,  1,  0, -1,  0,  0,  0,  0, -1] [ 6,  6,  6]  1 */
       16378, /* 64417 (1600) [ 1,  0,  0,  0,  0, -1,  0,  1,  0] [ 0,  0,  0]  1 */
    18557758, /* 64418 (1600) [ 1,  0,  0,  0,  0, -1,  0, -1,  0] [ 6,  6,  6]  1 */
       16320, /* 64419 (1600) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
       10642, /* 64420 (1600) [ 0,  0,  1,  0,  1,  0, -1,  0,  0] [ 0,  0,  0]  1 */
        8872, /* 64421 (1600) [ 0,  0, -1, -1,  0,  0,  0,  1,  0] [ 0,  0,  0]  1 */
    18551866, /* 64422 (1600) [ 0,  0,  1,  0, -1,  0, -1,  0,  0] [ 6,  6,  6]  1 */
        7898, /* 64423 (1600) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    18552046, /* 64424 (1600) [ 0,  0,  1,  0,  1,  0,  1,  0,  0] [ 6,  6,  6]  1 */
        3250, /* 64425 (1600) [-1,  0,  0,  0,  0, -1,  0, -1,  0] [ 0,  0,  0]  1 */
        3310, /* 64426 (1600) [-1,  0,  0,  0,  0,  1,  0,  1,  0] [ 0,  0,  0]  1 */
        9202, /* 64427 (1600) [ 0,  0, -1,  0,  1,  0,  1,  0,  0] [ 0,  0,  0]  1 */
       16426, /* 64428 (1600) [ 1,  0,  0,  0,  0,  1,  0, -1,  0] [ 0,  0,  0]  1 */
    18549076, /* 64429 (1600) [ 0, -1,  0,  0,  0,  1,  1,  0,  0] [ 6,  6,  6]  1 */
    18553658, /* 64430 (1600) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    18550570, /* 64431 (1600) [ 0,  0, -1,  0,  1,  0, -1,  0,  0] [ 6,  6,  6]  1 */
        3200, /* 64432 (1600) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    18553432, /* 64433 (1600) [ 0,  1,  0,  0,  0,  1, -1,  0,  0] [ 6,  6,  6]  1 */
       10816, /* 64434 (1600) [ 0,  0,  1,  1,  0,  0,  0,  1,  0] [ 0,  0,  0]  1 */
        9352, /* 64435 (1600) [ 0,  0, -1,  1,  0,  0,  0, -1,  0] [ 0,  0,  0]  1 */
    18549282, /* 64436 (1600) [ 0, -1,  0,  1,  0,  0,  0,  0, -1] [ 6,  6,  6]  1 */
       12064, /* 64437 (1600) [ 0,  1,  0,  0,  0,  1,  1,  0,  0] [ 0,  0,  0]  1 */
    18557868, /* 64438 (1600) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
    18557818, /* 64439 (1600) [ 1,  0,  0,  0,  0,  1,  0,  1,  0] [ 6,  6,  6]  1 */
    18549004, /* 64440 (1600) [ 0, -1,  0,  0,  0, -1, -1,  0,  0] [ 6,  6,  6]  1 */
    18548798, /* 64441 (1600) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    18550744, /* 64442 (1600) [ 0,  0, -1,  1,  0,  0,  0,  1,  0] [ 6,  6,  6]  1 */
       16484, /* 64443 (1601) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
       11786, /* 64444 (1601) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    52562650, /* 64445 (1601) [ 0,  0, -1,  0, -1,  0,  1,  0,  0] [ 6,  6,  6] -1 */
    34022722, /* 64446 (1601) [ 0,  0,  1,  0, -1,  0,  1,  0,  0] [ 0,  0,  0] -1 */
    18553396, /* 64447 (1601) [ 0,  1,  0,  0,  0, -1,  1,  0,  0] [ 6,  6,  6]  1 */
    18544690, /* 64448 (1601) [-1,  0,  0,  0,  0,  1,  0, -1,  0] [ 6,  6,  6]  1 */
    18544584, /* 64449 (1601) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
       10324, /* 64450 (1601) [ 0,  0,  1, -1,  0,  0,  0, -1,  0] [ 0,  0,  0]  1 */
    18557708, /* 64451 (1601) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    18544642, /* 64452 (1601) [-1,  0,  0,  0,  0, -1,  0,  1,  0] [ 6,  6,  6]  1 */
    52564090, /* 64453 (1601) [ 0,  0,  1,  0, -1,  0, -1,  0,  0] [ 6,  6,  6] -1 */
        7410, /* 64454 (1601) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    52565882, /* 64455 (1601) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    52562794, /* 64456 (1601) [ 0,  0, -1,  0,  1,  0, -1,  0,  0] [ 6,  6,  6] -1 */
    34023040, /* 64457 (1601) [ 0,  0,  1,  1,  0,  0,  0,  1,  0] [ 0,  0,  0] -1 */
       16378, /* 64458 (1601) [ 1,  0,  0,  0,  0, -1,  0,  1,  0] [ 0,  0,  0]  1 */
        8872, /* 64459 (1601) [ 0,  0, -1, -1,  0,  0,  0,  1,  0] [ 0,  0,  0]  1 */
        7898, /* 64460 (1601) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34024288, /* 64461 (1601) [ 0,  1,  0,  0,  0,  1,  1,  0,  0] [ 0,  0,  0] -1 */
        3310, /* 64462 (1601) [-1,  0,  0,  0,  0,  1,  0,  1,  0] [ 0,  0,  0]  1 */
    52570042, /* 64463 (1601) [ 1,  0,  0,  0,  0,  1,  0,  1,  0] [ 6,  6,  6] -1 */
    52561022, /* 64464 (1601) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    52563940, /* 64465 (1601) [ 0,  0,  1, -1,  0,  0,  0,  1,  0] [ 6,  6,  6] -1 */
    34015584, /* 64466 (1601) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    34024494, /* 64467 (1601) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    34021246, /* 64468 (1601) [ 0,  0, -1,  0, -1,  0, -1,  0,  0] [ 0,  0,  0] -1 */
        9352, /* 64469 (1601) [ 0,  0, -1,  1,  0,  0,  0, -1,  0] [ 0,  0,  0]  1 */
    34024216, /* 64470 (1601) [ 0,  1,  0,  0,  0, -1, -1,  0,  0] [ 0,  0,  0] -1 */
    52564420, /* 64471 (1601) [ 0,  0,  1,  1,  0,  0,  0, -1,  0] [ 6,  6,  6] -1 */
    34019860, /* 64472 (1601) [ 0, -1,  0,  0,  0, -1,  1,  0,  0] [ 0,  0,  0] -1 */
    52569982, /* 64473 (1601) [ 1,  0,  0,  0,  0, -1,  0, -1,  0] [ 6,  6,  6] -1 */
    34022866, /* 64474 (1601) [ 0,  0,  1,  0,  1,  0, -1,  0,  0] [ 0,  0,  0] -1 */
    18550252, /* 64475 (1601) [ 0,  0, -1, -1,  0,  0,  0, -1,  0] [ 6,  6,  6]  1 */
    34028650, /* 64476 (1601) [ 1,  0,  0,  0,  0,  1,  0, -1,  0] [ 0,  0,  0] -1 */
    18550426, /* 64477 (1601) [ 0,  0, -1,  0, -1,  0,  1,  0,  0] [ 6,  6,  6]  1 */
    52561300, /* 64478 (1601) [ 0, -1,  0,  0,  0,  1,  1,  0,  0] [ 6,  6,  6] -1 */
       10498, /* 64479 (1601) [ 0,  0,  1,  0, -1,  0,  1,  0,  0] [ 0,  0,  0]  1 */
    52565656, /* 64480 (1601) [ 0,  1,  0,  0,  0,  1, -1,  0,  0] [ 6,  6,  6] -1 */
    18553170, /* 64481 (1601) [ 0,  1,  0, -1,  0,  0,  0,  0, -1] [ 6,  6,  6]  1 */
    34015424, /* 64482 (1601) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    34028708, /* 64483 (1601) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    18551866, /* 64484 (1601) [ 0,  0,  1,  0, -1,  0, -1,  0,  0] [ 6,  6,  6]  1 */
    52570092, /* 64485 (1601) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    52561228, /* 64486 (1601) [ 0, -1,  0,  0,  0, -1, -1,  0,  0] [ 6,  6,  6] -1 */
    52564270, /* 64487 (1601) [ 0,  0,  1,  0,  1,  0,  1,  0,  0] [ 6,  6,  6] -1 */
    52562968, /* 64488 (1601) [ 0,  0, -1,  1,  0,  0,  0,  1,  0] [ 6,  6,  6] -1 */
    18553658, /* 64489 (1601) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    18550570, /* 64490 (1601) [ 0,  0, -1,  0,  1,  0, -1,  0,  0] [ 6,  6,  6]  1 */
       10816, /* 64491 (1601) [ 0,  0,  1,  1,  0,  0,  0,  1,  0] [ 0,  0,  0]  1 */
    52556808, /* 64492 (1601) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    52569932, /* 64493 (1601) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    52556972, /* 64494 (1601) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    18549282, /* 64495 (1601) [ 0, -1,  0,  1,  0,  0,  0,  0, -1] [ 6,  6,  6]  1 */
    34019896, /* 64496 (1601) [ 0, -1,  0,  0,  0,  1, -1,  0,  0] [ 0,  0,  0] -1 */
       12064, /* 64497 (1601) [ 0,  1,  0,  0,  0,  1,  1,  0,  0] [ 0,  0,  0]  1 */
    18557818, /* 64498 (1601) [ 1,  0,  0,  0,  0,  1,  0,  1,  0] [ 6,  6,  6]  1 */
    34019634, /* 64499 (1601) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    18548798, /* 64500 (1601) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 6,  6,  6]  1 */
        3360, /* 64501 (1601) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
       12270, /* 64502 (1601) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    34028602, /* 64503 (1601) [ 1,  0,  0,  0,  0, -1,  0,  1,  0] [ 0,  0,  0] -1 */
       11992, /* 64504 (1601) [ 0,  1,  0,  0,  0, -1, -1,  0,  0] [ 0,  0,  0]  1 */
    34021096, /* 64505 (1601) [ 0,  0, -1, -1,  0,  0,  0,  1,  0] [ 0,  0,  0] -1 */
    18552196, /* 64506 (1601) [ 0,  0,  1,  1,  0,  0,  0, -1,  0] [ 6,  6,  6]  1 */
    34028544, /* 64507 (1601) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    34015534, /* 64508 (1601) [-1,  0,  0,  0,  0,  1,  0,  1,  0] [ 0,  0,  0] -1 */
    34015474, /* 64509 (1601) [-1,  0,  0,  0,  0, -1,  0, -1,  0] [ 0,  0,  0] -1 */
    34021426, /* 64510 (1601) [ 0,  0, -1,  0,  1,  0,  1,  0,  0] [ 0,  0,  0] -1 */
       10642, /* 64511 (1601) [ 0,  0,  1,  0,  1,  0, -1,  0,  0] [ 0,  0,  0]  1 */
    34024010, /* 64512 (1601) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    18553432, /* 64513 (1601) [ 0,  1,  0,  0,  0,  1, -1,  0,  0] [ 6,  6,  6]  1 */
        3200, /* 64514 (1601) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    52565620, /* 64515 (1601) [ 0,  1,  0,  0,  0, -1,  1,  0,  0] [ 6,  6,  6] -1 */
    52556914, /* 64516 (1601) [-1,  0,  0,  0,  0,  1,  0, -1,  0] [ 6,  6,  6] -1 */
    34022548, /* 64517 (1601) [ 0,  0,  1, -1,  0,  0,  0, -1,  0] [ 0,  0,  0] -1 */
    52556866, /* 64518 (1601) [-1,  0,  0,  0,  0, -1,  0,  1,  0] [ 6,  6,  6] -1 */
    18557868, /* 64519 (1601) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
    18552046, /* 64520 (1601) [ 0,  0,  1,  0,  1,  0,  1,  0,  0] [ 6,  6,  6]  1 */
    18549004, /* 64521 (1601) [ 0, -1,  0,  0,  0, -1, -1,  0,  0] [ 6,  6,  6]  1 */
    18550744, /* 64522 (1601) [ 0,  0, -1,  1,  0,  0,  0,  1,  0] [ 6,  6,  6]  1 */
    52565394, /* 64523 (1601) [ 0,  1,  0, -1,  0,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    18551716, /* 64524 (1601) [ 0,  0,  1, -1,  0,  0,  0,  1,  0] [ 6,  6,  6]  1 */
    18544748, /* 64525 (1601) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
        9022, /* 64526 (1601) [ 0,  0, -1,  0, -1,  0, -1,  0,  0] [ 0,  0,  0]  1 */
        7672, /* 64527 (1601) [ 0, -1,  0,  0,  0,  1, -1,  0,  0] [ 0,  0,  0]  1 */
    34020122, /* 64528 (1601) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 0,  0,  0] -1 */
        7636, /* 64529 (1601) [ 0, -1,  0,  0,  0, -1,  1,  0,  0] [ 0,  0,  0]  1 */
    52561506, /* 64530 (1601) [ 0, -1,  0,  1,  0,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    18557758, /* 64531 (1601) [ 1,  0,  0,  0,  0, -1,  0, -1,  0] [ 6,  6,  6]  1 */
       16320, /* 64532 (1601) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    34021576, /* 64533 (1601) [ 0,  0, -1,  1,  0,  0,  0, -1,  0] [ 0,  0,  0] -1 */
        3250, /* 64534 (1601) [-1,  0,  0,  0,  0, -1,  0, -1,  0] [ 0,  0,  0]  1 */
        9202, /* 64535 (1601) [ 0,  0, -1,  0,  1,  0,  1,  0,  0] [ 0,  0,  0]  1 */
       16426, /* 64536 (1601) [ 1,  0,  0,  0,  0,  1,  0, -1,  0] [ 0,  0,  0]  1 */
    18549076, /* 64537 (1601) [ 0, -1,  0,  0,  0,  1,  1,  0,  0] [ 6,  6,  6]  1 */
    52562476, /* 64538 (1601) [ 0,  0, -1, -1,  0,  0,  0, -1,  0] [ 6,  6,  6] -1 */
       16484, /* 64539 (1602) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
        3360, /* 64540 (1602) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    34022722, /* 64541 (1602) [ 0,  0,  1,  0, -1,  0,  1,  0,  0] [ 0,  0,  0] -1 */
    34028602, /* 64542 (1602) [ 1,  0,  0,  0,  0, -1,  0,  1,  0] [ 0,  0,  0] -1 */
    18544690, /* 64543 (1602) [-1,  0,  0,  0,  0,  1,  0, -1,  0] [ 6,  6,  6]  1 */
       10324, /* 64544 (1602) [ 0,  0,  1, -1,  0,  0,  0, -1,  0] [ 0,  0,  0]  1 */
       11992, /* 64545 (1602) [ 0,  1,  0,  0,  0, -1, -1,  0,  0] [ 0,  0,  0]  1 */
        7672, /* 64546 (1602) [ 0, -1,  0,  0,  0,  1, -1,  0,  0] [ 0,  0,  0]  1 */
    34022866, /* 64547 (1602) [ 0,  0,  1,  0,  1,  0, -1,  0,  0] [ 0,  0,  0] -1 */
    18544642, /* 64548 (1602) [-1,  0,  0,  0,  0, -1,  0,  1,  0] [ 6,  6,  6]  1 */
    34015534, /* 64549 (1602) [-1,  0,  0,  0,  0,  1,  0,  1,  0] [ 0,  0,  0] -1 */
    34020122, /* 64550 (1602) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    34015474, /* 64551 (1602) [-1,  0,  0,  0,  0, -1,  0, -1,  0] [ 0,  0,  0] -1 */
    34021426, /* 64552 (1602) [ 0,  0, -1,  0,  1,  0,  1,  0,  0] [ 0,  0,  0] -1 */
    34028650, /* 64553 (1602) [ 1,  0,  0,  0,  0,  1,  0, -1,  0] [ 0,  0,  0] -1 */
    18550426, /* 64554 (1602) [ 0,  0, -1,  0, -1,  0,  1,  0,  0] [ 6,  6,  6]  1 */
        7636, /* 64555 (1602) [ 0, -1,  0,  0,  0, -1,  1,  0,  0] [ 0,  0,  0]  1 */
    52561300, /* 64556 (1602) [ 0, -1,  0,  0,  0,  1,  1,  0,  0] [ 6,  6,  6] -1 */
    52565656, /* 64557 (1602) [ 0,  1,  0,  0,  0,  1, -1,  0,  0] [ 6,  6,  6] -1 */
    18553170, /* 64558 (1602) [ 0,  1,  0, -1,  0,  0,  0,  0, -1] [ 6,  6,  6]  1 */
    18557758, /* 64559 (1602) [ 1,  0,  0,  0,  0, -1,  0, -1,  0] [ 6,  6,  6]  1 */
       16320, /* 64560 (1602) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
        8872, /* 64561 (1602) [ 0,  0, -1, -1,  0,  0,  0,  1,  0] [ 0,  0,  0]  1 */
    18551866, /* 64562 (1602) [ 0,  0,  1,  0, -1,  0, -1,  0,  0] [ 6,  6,  6]  1 */
    52570092, /* 64563 (1602) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    52561228, /* 64564 (1602) [ 0, -1,  0,  0,  0, -1, -1,  0,  0] [ 6,  6,  6] -1 */
    52562968, /* 64565 (1602) [ 0,  0, -1,  1,  0,  0,  0,  1,  0] [ 6,  6,  6] -1 */
    34024010, /* 64566 (1602) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    18553658, /* 64567 (1602) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    18550570, /* 64568 (1602) [ 0,  0, -1,  0,  1,  0, -1,  0,  0] [ 6,  6,  6]  1 */
        3200, /* 64569 (1602) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34024494, /* 64570 (1602) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    52563940, /* 64571 (1602) [ 0,  0,  1, -1,  0,  0,  0,  1,  0] [ 6,  6,  6] -1 */
    52556808, /* 64572 (1602) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
       10816, /* 64573 (1602) [ 0,  0,  1,  1,  0,  0,  0,  1,  0] [ 0,  0,  0]  1 */
    52565620, /* 64574 (1602) [ 0,  1,  0,  0,  0, -1,  1,  0,  0] [ 6,  6,  6] -1 */
    34021246, /* 64575 (1602) [ 0,  0, -1,  0, -1,  0, -1,  0,  0] [ 0,  0,  0] -1 */
    52556972, /* 64576 (1602) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    52569932, /* 64577 (1602) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
        9352, /* 64578 (1602) [ 0,  0, -1,  1,  0,  0,  0, -1,  0] [ 0,  0,  0]  1 */
    18549282, /* 64579 (1602) [ 0, -1,  0,  1,  0,  0,  0,  0, -1] [ 6,  6,  6]  1 */
    18548798, /* 64580 (1602) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 6,  6,  6]  1 */
       12064, /* 64581 (1602) [ 0,  1,  0,  0,  0,  1,  1,  0,  0] [ 0,  0,  0]  1 */
    52564420, /* 64582 (1602) [ 0,  0,  1,  1,  0,  0,  0, -1,  0] [ 6,  6,  6] -1 */
    18557818, /* 64583 (1602) [ 1,  0,  0,  0,  0,  1,  0,  1,  0] [ 6,  6,  6]  1 */
    52562476, /* 64584 (1602) [ 0,  0, -1, -1,  0,  0,  0, -1,  0] [ 6,  6,  6] -1 */
    18552046, /* 64585 (1602) [ 0,  0,  1,  0,  1,  0,  1,  0,  0] [ 6,  6,  6]  1 */
    34019634, /* 64586 (1602) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  0] -1 */
       16484, /* 64587 (1603) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    52562650, /* 64588 (1603) [ 0,  0, -1,  0, -1,  0,  1,  0,  0] [ 6,  6,  6] -1 */
        3360, /* 64589 (1603) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    52565394, /* 64590 (1603) [ 0,  1,  0, -1,  0,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    34022722, /* 64591 (1603) [ 0,  0,  1,  0, -1,  0,  1,  0,  0] [ 0,  0,  0] -1 */
    18551716, /* 64592 (1603) [ 0,  0,  1, -1,  0,  0,  0,  1,  0] [ 6,  6,  6]  1 */
    18553396, /* 64593 (1603) [ 0,  1,  0,  0,  0, -1,  1,  0,  0] [ 6,  6,  6]  1 */
    18544748, /* 64594 (1603) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    34028602, /* 64595 (1603) [ 1,  0,  0,  0,  0, -1,  0,  1,  0] [ 0,  0,  0] -1 */
    18544584, /* 64596 (1603) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
       10324, /* 64597 (1603) [ 0,  0,  1, -1,  0,  0,  0, -1,  0] [ 0,  0,  0]  1 */
    52569982, /* 64598 (1603) [ 1,  0,  0,  0,  0, -1,  0, -1,  0] [ 6,  6,  6] -1 */
       11992, /* 64599 (1603) [ 0,  1,  0,  0,  0, -1, -1,  0,  0] [ 0,  0,  0]  1 */
        7672, /* 64600 (1603) [ 0, -1,  0,  0,  0,  1, -1,  0,  0] [ 0,  0,  0]  1 */
    18557708, /* 64601 (1603) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    18552196, /* 64602 (1603) [ 0,  0,  1,  1,  0,  0,  0, -1,  0] [ 6,  6,  6]  1 */
    34022866, /* 64603 (1603) [ 0,  0,  1,  0,  1,  0, -1,  0,  0] [ 0,  0,  0] -1 */
    18550252, /* 64604 (1603) [ 0,  0, -1, -1,  0,  0,  0, -1,  0] [ 6,  6,  6]  1 */
    34015534, /* 64605 (1603) [-1,  0,  0,  0,  0,  1,  0,  1,  0] [ 0,  0,  0] -1 */
    34020122, /* 64606 (1603) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    52564090, /* 64607 (1603) [ 0,  0,  1,  0, -1,  0, -1,  0,  0] [ 6,  6,  6] -1 */
    34015474, /* 64608 (1603) [-1,  0,  0,  0,  0, -1,  0, -1,  0] [ 0,  0,  0] -1 */
    34021426, /* 64609 (1603) [ 0,  0, -1,  0,  1,  0,  1,  0,  0] [ 0,  0,  0] -1 */
    34028650, /* 64610 (1603) [ 1,  0,  0,  0,  0,  1,  0, -1,  0] [ 0,  0,  0] -1 */
        7636, /* 64611 (1603) [ 0, -1,  0,  0,  0, -1,  1,  0,  0] [ 0,  0,  0]  1 */
    52565882, /* 64612 (1603) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    52562794, /* 64613 (1603) [ 0,  0, -1,  0,  1,  0, -1,  0,  0] [ 6,  6,  6] -1 */
    52561506, /* 64614 (1603) [ 0, -1,  0,  1,  0,  0,  0,  0, -1] [ 6,  6,  6] -1 */
       16320, /* 64615 (1603) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
        8872, /* 64616 (1603) [ 0,  0, -1, -1,  0,  0,  0,  1,  0] [ 0,  0,  0]  1 */
    52570042, /* 64617 (1603) [ 1,  0,  0,  0,  0,  1,  0,  1,  0] [ 6,  6,  6] -1 */
    52564270, /* 64618 (1603) [ 0,  0,  1,  0,  1,  0,  1,  0,  0] [ 6,  6,  6] -1 */
    52561022, /* 64619 (1603) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    34024010, /* 64620 (1603) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    18549076, /* 64621 (1603) [ 0, -1,  0,  0,  0,  1,  1,  0,  0] [ 6,  6,  6]  1 */
    18553432, /* 64622 (1603) [ 0,  1,  0,  0,  0,  1, -1,  0,  0] [ 6,  6,  6]  1 */
        3200, /* 64623 (1603) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34024494, /* 64624 (1603) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  0] -1 */
       10816, /* 64625 (1603) [ 0,  0,  1,  1,  0,  0,  0,  1,  0] [ 0,  0,  0]  1 */
    34021246, /* 64626 (1603) [ 0,  0, -1,  0, -1,  0, -1,  0,  0] [ 0,  0,  0] -1 */
        9352, /* 64627 (1603) [ 0,  0, -1,  1,  0,  0,  0, -1,  0] [ 0,  0,  0]  1 */
    52556914, /* 64628 (1603) [-1,  0,  0,  0,  0,  1,  0, -1,  0] [ 6,  6,  6] -1 */
       12064, /* 64629 (1603) [ 0,  1,  0,  0,  0,  1,  1,  0,  0] [ 0,  0,  0]  1 */
    52556866, /* 64630 (1603) [-1,  0,  0,  0,  0, -1,  0,  1,  0] [ 6,  6,  6] -1 */
    18557868, /* 64631 (1603) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
    18549004, /* 64632 (1603) [ 0, -1,  0,  0,  0, -1, -1,  0,  0] [ 6,  6,  6]  1 */
    34019634, /* 64633 (1603) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    18550744, /* 64634 (1603) [ 0,  0, -1,  1,  0,  0,  0,  1,  0] [ 6,  6,  6]  1 */
       16484, /* 64635 (1604) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
       11786, /* 64636 (1604) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    52562650, /* 64637 (1604) [ 0,  0, -1,  0, -1,  0,  1,  0,  0] [ 6,  6,  6] -1 */
        3360, /* 64638 (1604) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
       12270, /* 64639 (1604) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    52565394, /* 64640 (1604) [ 0,  1,  0, -1,  0,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    52569982, /* 64641 (1604) [ 1,  0,  0,  0,  0, -1,  0, -1,  0] [ 6,  6,  6] -1 */
       10324, /* 64642 (1604) [ 0,  0,  1, -1,  0,  0,  0, -1,  0] [ 0,  0,  0]  1 */
       11992, /* 64643 (1604) [ 0,  1,  0,  0,  0, -1, -1,  0,  0] [ 0,  0,  0]  1 */
        9022, /* 64644 (1604) [ 0,  0, -1,  0, -1,  0, -1,  0,  0] [ 0,  0,  0]  1 */
        7672, /* 64645 (1604) [ 0, -1,  0,  0,  0,  1, -1,  0,  0] [ 0,  0,  0]  1 */
    52564090, /* 64646 (1604) [ 0,  0,  1,  0, -1,  0, -1,  0,  0] [ 6,  6,  6] -1 */
        7410, /* 64647 (1604) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  0]  1 */
        7636, /* 64648 (1604) [ 0, -1,  0,  0,  0, -1,  1,  0,  0] [ 0,  0,  0]  1 */
       10498, /* 64649 (1604) [ 0,  0,  1,  0, -1,  0,  1,  0,  0] [ 0,  0,  0]  1 */
    52561300, /* 64650 (1604) [ 0, -1,  0,  0,  0,  1,  1,  0,  0] [ 6,  6,  6] -1 */
    52565656, /* 64651 (1604) [ 0,  1,  0,  0,  0,  1, -1,  0,  0] [ 6,  6,  6] -1 */
    52565882, /* 64652 (1604) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    52562794, /* 64653 (1604) [ 0,  0, -1,  0,  1,  0, -1,  0,  0] [ 6,  6,  6] -1 */
       16378, /* 64654 (1604) [ 1,  0,  0,  0,  0, -1,  0,  1,  0] [ 0,  0,  0]  1 */
    52561506, /* 64655 (1604) [ 0, -1,  0,  1,  0,  0,  0,  0, -1] [ 6,  6,  6] -1 */
       16320, /* 64656 (1604) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
       10642, /* 64657 (1604) [ 0,  0,  1,  0,  1,  0, -1,  0,  0] [ 0,  0,  0]  1 */
        8872, /* 64658 (1604) [ 0,  0, -1, -1,  0,  0,  0,  1,  0] [ 0,  0,  0]  1 */
        7898, /* 64659 (1604) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 0,  0,  0]  1 */
        3250, /* 64660 (1604) [-1,  0,  0,  0,  0, -1,  0, -1,  0] [ 0,  0,  0]  1 */
        3310, /* 64661 (1604) [-1,  0,  0,  0,  0,  1,  0,  1,  0] [ 0,  0,  0]  1 */
    52570092, /* 64662 (1604) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
        9202, /* 64663 (1604) [ 0,  0, -1,  0,  1,  0,  1,  0,  0] [ 0,  0,  0]  1 */
    52570042, /* 64664 (1604) [ 1,  0,  0,  0,  0,  1,  0,  1,  0] [ 6,  6,  6] -1 */
    52561228, /* 64665 (1604) [ 0, -1,  0,  0,  0, -1, -1,  0,  0] [ 6,  6,  6] -1 */
    52564270, /* 64666 (1604) [ 0,  0,  1,  0,  1,  0,  1,  0,  0] [ 6,  6,  6] -1 */
    52561022, /* 64667 (1604) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    52562968, /* 64668 (1604) [ 0,  0, -1,  1,  0,  0,  0,  1,  0] [ 6,  6,  6] -1 */
       16426, /* 64669 (1604) [ 1,  0,  0,  0,  0,  1,  0, -1,  0] [ 0,  0,  0]  1 */
    52563940, /* 64670 (1604) [ 0,  0,  1, -1,  0,  0,  0,  1,  0] [ 6,  6,  6] -1 */
        3200, /* 64671 (1604) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    52556808, /* 64672 (1604) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
       10816, /* 64673 (1604) [ 0,  0,  1,  1,  0,  0,  0,  1,  0] [ 0,  0,  0]  1 */
    52565620, /* 64674 (1604) [ 0,  1,  0,  0,  0, -1,  1,  0,  0] [ 6,  6,  6] -1 */
    52569932, /* 64675 (1604) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    52556972, /* 64676 (1604) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
        9352, /* 64677 (1604) [ 0,  0, -1,  1,  0,  0,  0, -1,  0] [ 0,  0,  0]  1 */
    52556914, /* 64678 (1604) [-1,  0,  0,  0,  0,  1,  0, -1,  0] [ 6,  6,  6] -1 */
       12064, /* 64679 (1604) [ 0,  1,  0,  0,  0,  1,  1,  0,  0] [ 0,  0,  0]  1 */
    52564420, /* 64680 (1604) [ 0,  0,  1,  1,  0,  0,  0, -1,  0] [ 6,  6,  6] -1 */
    52556866, /* 64681 (1604) [-1,  0,  0,  0,  0, -1,  0,  1,  0] [ 6,  6,  6] -1 */
    52562476, /* 64682 (1604) [ 0,  0, -1, -1,  0,  0,  0, -1,  0] [ 6,  6,  6] -1 */
       16484, /* 64683 (1605) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
       11786, /* 64684 (1605) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    18553396, /* 64685 (1605) [ 0,  1,  0,  0,  0, -1,  1,  0,  0] [ 6,  6,  6]  1 */
    18544690, /* 64686 (1605) [-1,  0,  0,  0,  0,  1,  0, -1,  0] [ 6,  6,  6]  1 */
    18544584, /* 64687 (1605) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
       10324, /* 64688 (1605) [ 0,  0,  1, -1,  0,  0,  0, -1,  0] [ 0,  0,  0]  1 */
    18557708, /* 64689 (1605) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    18544642, /* 64690 (1605) [-1,  0,  0,  0,  0, -1,  0,  1,  0] [ 6,  6,  6]  1 */
    34021582, /* 64691 (1605) [ 0,  0, -1,  1,  0,  0,  0,  1,  0] [ 0,  0,  0] -1 */
        7410, /* 64692 (1605) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    34024496, /* 64693 (1605) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 0,  0,  0] -1 */
       16378, /* 64694 (1605) [ 1,  0,  0,  0,  0, -1,  0,  1,  0] [ 0,  0,  0]  1 */
    34024270, /* 64695 (1605) [ 0,  1,  0,  0,  0,  1, -1,  0,  0] [ 0,  0,  0] -1 */
    52556810, /* 64696 (1605) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    34019842, /* 64697 (1605) [ 0, -1,  0,  0,  0, -1, -1,  0,  0] [ 0,  0,  0] -1 */
        8872, /* 64698 (1605) [ 0,  0, -1, -1,  0,  0,  0,  1,  0] [ 0,  0,  0]  1 */
        7898, /* 64699 (1605) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34022554, /* 64700 (1605) [ 0,  0,  1, -1,  0,  0,  0,  1,  0] [ 0,  0,  0] -1 */
    52569930, /* 64701 (1605) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    52556970, /* 64702 (1605) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
        3310, /* 64703 (1605) [-1,  0,  0,  0,  0,  1,  0,  1,  0] [ 0,  0,  0]  1 */
    52565880, /* 64704 (1605) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    34028706, /* 64705 (1605) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    52561508, /* 64706 (1605) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    34024008, /* 64707 (1605) [ 0,  1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  0] -1 */
        9352, /* 64708 (1605) [ 0,  0, -1,  1,  0,  0,  0, -1,  0] [ 0,  0,  0]  1 */
    34023034, /* 64709 (1605) [ 0,  0,  1,  1,  0,  0,  0, -1,  0] [ 0,  0,  0] -1 */
    34019914, /* 64710 (1605) [ 0, -1,  0,  0,  0,  1,  1,  0,  0] [ 0,  0,  0] -1 */
    52561246, /* 64711 (1605) [ 0, -1,  0,  0,  0, -1,  1,  0,  0] [ 6,  6,  6] -1 */
    18550252, /* 64712 (1605) [ 0,  0, -1, -1,  0,  0,  0, -1,  0] [ 6,  6,  6]  1 */
    52564252, /* 64713 (1605) [ 0,  0,  1,  0,  1,  0, -1,  0,  0] [ 6,  6,  6] -1 */
    18550426, /* 64714 (1605) [ 0,  0, -1,  0, -1,  0,  1,  0,  0] [ 6,  6,  6]  1 */
       10498, /* 64715 (1605) [ 0,  0,  1,  0, -1,  0,  1,  0,  0] [ 0,  0,  0]  1 */
    18553170, /* 64716 (1605) [ 0,  1,  0, -1,  0,  0,  0,  0, -1] [ 6,  6,  6]  1 */
    34021408, /* 64717 (1605) [ 0,  0, -1,  0,  1,  0, -1,  0,  0] [ 0,  0,  0] -1 */
    52563934, /* 64718 (1605) [ 0,  0,  1, -1,  0,  0,  0, -1,  0] [ 6,  6,  6] -1 */
    18551866, /* 64719 (1605) [ 0,  0,  1,  0, -1,  0, -1,  0,  0] [ 6,  6,  6]  1 */
    34019636, /* 64720 (1605) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    34015480, /* 64721 (1605) [-1,  0,  0,  0,  0, -1,  0,  1,  0] [ 0,  0,  0] -1 */
    34028546, /* 64722 (1605) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    34022884, /* 64723 (1605) [ 0,  0,  1,  0,  1,  0,  1,  0,  0] [ 0,  0,  0] -1 */
    52561282, /* 64724 (1605) [ 0, -1,  0,  0,  0,  1, -1,  0,  0] [ 6,  6,  6] -1 */
    18553658, /* 64725 (1605) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    34015422, /* 64726 (1605) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    18550570, /* 64727 (1605) [ 0,  0, -1,  0,  1,  0, -1,  0,  0] [ 6,  6,  6]  1 */
    34024234, /* 64728 (1605) [ 0,  1,  0,  0,  0, -1,  1,  0,  0] [ 0,  0,  0] -1 */
       10816, /* 64729 (1605) [ 0,  0,  1,  1,  0,  0,  0,  1,  0] [ 0,  0,  0]  1 */
    18549282, /* 64730 (1605) [ 0, -1,  0,  1,  0,  0,  0,  0, -1] [ 6,  6,  6]  1 */
       12064, /* 64731 (1605) [ 0,  1,  0,  0,  0,  1,  1,  0,  0] [ 0,  0,  0]  1 */
    18557818, /* 64732 (1605) [ 1,  0,  0,  0,  0,  1,  0,  1,  0] [ 6,  6,  6]  1 */
    18548798, /* 64733 (1605) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 6,  6,  6]  1 */
        3360, /* 64734 (1605) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
       12270, /* 64735 (1605) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  0]  1 */
       11992, /* 64736 (1605) [ 0,  1,  0,  0,  0, -1, -1,  0,  0] [ 0,  0,  0]  1 */
    18552196, /* 64737 (1605) [ 0,  0,  1,  1,  0,  0,  0, -1,  0] [ 6,  6,  6]  1 */
    52570036, /* 64738 (1605) [ 1,  0,  0,  0,  0,  1,  0, -1,  0] [ 6,  6,  6] -1 */
    52562962, /* 64739 (1605) [ 0,  0, -1,  1,  0,  0,  0, -1,  0] [ 6,  6,  6] -1 */
    52562482, /* 64740 (1605) [ 0,  0, -1, -1,  0,  0,  0,  1,  0] [ 6,  6,  6] -1 */
    52556860, /* 64741 (1605) [-1,  0,  0,  0,  0, -1,  0, -1,  0] [ 6,  6,  6] -1 */
    52565602, /* 64742 (1605) [ 0,  1,  0,  0,  0, -1, -1,  0,  0] [ 6,  6,  6] -1 */
       10642, /* 64743 (1605) [ 0,  0,  1,  0,  1,  0, -1,  0,  0] [ 0,  0,  0]  1 */
    52562812, /* 64744 (1605) [ 0,  0, -1,  0,  1,  0,  1,  0,  0] [ 6,  6,  6] -1 */
    18553432, /* 64745 (1605) [ 0,  1,  0,  0,  0,  1, -1,  0,  0] [ 6,  6,  6]  1 */
    34022704, /* 64746 (1605) [ 0,  0,  1,  0, -1,  0, -1,  0,  0] [ 0,  0,  0] -1 */
        3200, /* 64747 (1605) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    52562632, /* 64748 (1605) [ 0,  0, -1,  0, -1,  0, -1,  0,  0] [ 6,  6,  6] -1 */
    34028596, /* 64749 (1605) [ 1,  0,  0,  0,  0, -1,  0, -1,  0] [ 0,  0,  0] -1 */
    34021090, /* 64750 (1605) [ 0,  0, -1, -1,  0,  0,  0, -1,  0] [ 0,  0,  0] -1 */
    34028656, /* 64751 (1605) [ 1,  0,  0,  0,  0,  1,  0,  1,  0] [ 0,  0,  0] -1 */
    18557868, /* 64752 (1605) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
    18552046, /* 64753 (1605) [ 0,  0,  1,  0,  1,  0,  1,  0,  0] [ 6,  6,  6]  1 */
    18549004, /* 64754 (1605) [ 0, -1,  0,  0,  0, -1, -1,  0,  0] [ 6,  6,  6]  1 */
    18550744, /* 64755 (1605) [ 0,  0, -1,  1,  0,  0,  0,  1,  0] [ 6,  6,  6]  1 */
    52561020, /* 64756 (1605) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    52564108, /* 64757 (1605) [ 0,  0,  1,  0, -1,  0,  1,  0,  0] [ 6,  6,  6] -1 */
    18551716, /* 64758 (1605) [ 0,  0,  1, -1,  0,  0,  0,  1,  0] [ 6,  6,  6]  1 */
    18544748, /* 64759 (1605) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    52569988, /* 64760 (1605) [ 1,  0,  0,  0,  0, -1,  0,  1,  0] [ 6,  6,  6] -1 */
        9022, /* 64761 (1605) [ 0,  0, -1,  0, -1,  0, -1,  0,  0] [ 0,  0,  0]  1 */
        7672, /* 64762 (1605) [ 0, -1,  0,  0,  0,  1, -1,  0,  0] [ 0,  0,  0]  1 */
    52570094, /* 64763 (1605) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    34015586, /* 64764 (1605) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
        7636, /* 64765 (1605) [ 0, -1,  0,  0,  0, -1,  1,  0,  0] [ 0,  0,  0]  1 */
    52565674, /* 64766 (1605) [ 0,  1,  0,  0,  0,  1,  1,  0,  0] [ 6,  6,  6] -1 */
    18557758, /* 64767 (1605) [ 1,  0,  0,  0,  0, -1,  0, -1,  0] [ 6,  6,  6]  1 */
       16320, /* 64768 (1605) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    52564426, /* 64769 (1605) [ 0,  0,  1,  1,  0,  0,  0,  1,  0] [ 6,  6,  6] -1 */
        3250, /* 64770 (1605) [-1,  0,  0,  0,  0, -1,  0, -1,  0] [ 0,  0,  0]  1 */
        9202, /* 64771 (1605) [ 0,  0, -1,  0,  1,  0,  1,  0,  0] [ 0,  0,  0]  1 */
    34020120, /* 64772 (1605) [ 0, -1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  0] -1 */
       16426, /* 64773 (1605) [ 1,  0,  0,  0,  0,  1,  0, -1,  0] [ 0,  0,  0]  1 */
    18549076, /* 64774 (1605) [ 0, -1,  0,  0,  0,  1,  1,  0,  0] [ 6,  6,  6]  1 */
    52565396, /* 64775 (1605) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    34015528, /* 64776 (1605) [-1,  0,  0,  0,  0,  1,  0, -1,  0] [ 0,  0,  0] -1 */
    52556920, /* 64777 (1605) [-1,  0,  0,  0,  0,  1,  0,  1,  0] [ 6,  6,  6] -1 */
    34021264, /* 64778 (1605) [ 0,  0, -1,  0, -1,  0,  1,  0,  0] [ 0,  0,  0] -1 */
       16484, /* 64779 (1600) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
     1428962, /* 64780 (1600) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 0,  6,  0]  1 */
    17127570, /* 64781 (1600) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6]  1 */
      130368, /* 64782 (1600) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  6]  1 */
    17134540, /* 64783 (1600) [ 0,  0,  1, -1,  0,  0,  0,  1,  0] [ 6,  0,  6]  1 */
    17136220, /* 64784 (1600) [ 0,  1,  0,  0,  0, -1,  1,  0,  0] [ 6,  0,  6]  1 */
     1538636, /* 64785 (1600) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
     1420480, /* 64786 (1600) [-1,  0,  0,  0,  0,  1,  0, -1,  0] [ 0,  6,  0]  1 */
        3198, /* 64787 (1600) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
     1545598, /* 64788 (1600) [ 0,  0,  1, -1,  0,  0,  0, -1,  0] [ 0,  6,  6]  1 */
     1547266, /* 64789 (1600) [ 0,  1,  0,  0,  0, -1, -1,  0,  0] [ 0,  6,  6]  1 */
    18550408, /* 64790 (1600) [ 0,  0, -1,  0, -1,  0, -1,  0,  0] [ 6,  6,  6]  1 */
    17131882, /* 64791 (1600) [ 0, -1,  0,  0,  0,  1, -1,  0,  0] [ 6,  0,  6]  1 */
    17140532, /* 64792 (1600) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
    18434098, /* 64793 (1600) [ 0,  0,  1,  1,  0,  0,  0, -1,  0] [ 6,  6,  0]  1 */
      121354, /* 64794 (1600) [-1,  0,  0,  0,  0, -1,  0,  1,  0] [ 0,  0,  6]  1 */
        8866, /* 64795 (1600) [ 0,  0, -1, -1,  0,  0,  0, -1,  0] [ 0,  0,  0]  1 */
    18548796, /* 64796 (1600) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 6,  6,  6]  1 */
      127138, /* 64797 (1600) [ 0,  0, -1,  0, -1,  0,  1,  0,  0] [ 0,  0,  6]  1 */
    18430924, /* 64798 (1600) [ 0, -1,  0,  0,  0, -1,  1,  0,  0] [ 6,  6,  0]  1 */
     1427674, /* 64799 (1600) [ 0,  0,  1,  0, -1,  0,  1,  0,  0] [ 0,  6,  0]  1 */
    17017896, /* 64800 (1600) [ 0,  1,  0, -1,  0,  0,  0,  0, -1] [ 6,  0,  0]  1 */
     1433554, /* 64801 (1600) [ 1,  0,  0,  0,  0, -1,  0,  1,  0] [ 0,  6,  0]  1 */
    17022484, /* 64802 (1600) [ 1,  0,  0,  0,  0, -1,  0, -1,  0] [ 6,  0,  0]  1 */
     1551594, /* 64803 (1600) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
      128740, /* 64804 (1600) [ 0,  0,  1,  0,  1,  0, -1,  0,  0] [ 0,  0,  6]  1 */
    18432160, /* 64805 (1600) [ 0,  0, -1, -1,  0,  0,  0,  1,  0] [ 6,  6,  0]  1 */
    17016592, /* 64806 (1600) [ 0,  0,  1,  0, -1,  0, -1,  0,  0] [ 6,  0,  0]  1 */
    17014010, /* 64807 (1600) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 6,  0,  0]  1 */
    18552046, /* 64808 (1600) [ 0,  0,  1,  0,  1,  0,  1,  0,  0] [ 6,  6,  6]  1 */
    18544636, /* 64809 (1600) [-1,  0,  0,  0,  0, -1,  0, -1,  0] [ 6,  6,  6]  1 */
    17009422, /* 64810 (1600) [-1,  0,  0,  0,  0,  1,  0,  1,  0] [ 6,  0,  0]  1 */
    17015314, /* 64811 (1600) [ 0,  0, -1,  0,  1,  0,  1,  0,  0] [ 6,  0,  0]  1 */
      134524, /* 64812 (1600) [ 1,  0,  0,  0,  0,  1,  0, -1,  0] [ 0,  0,  6]  1 */
     1542964, /* 64813 (1600) [ 0, -1,  0,  0,  0,  1,  1,  0,  0] [ 0,  6,  6]  1 */
    18553658, /* 64814 (1600) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 6,  6,  6]  1 */
     1426360, /* 64815 (1600) [ 0,  0, -1,  0,  1,  0, -1,  0,  0] [ 0,  6,  0]  1 */
    18426488, /* 64816 (1600) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    18435334, /* 64817 (1600) [ 0,  1,  0,  0,  0,  1, -1,  0,  0] [ 6,  6,  0]  1 */
       10816, /* 64818 (1600) [ 0,  0,  1,  1,  0,  0,  0,  1,  0] [ 0,  0,  0]  1 */
    17133562, /* 64819 (1600) [ 0,  0, -1,  1,  0,  0,  0, -1,  0] [ 6,  0,  6]  1 */
     1425072, /* 64820 (1600) [ 0, -1,  0,  1,  0,  0,  0,  0, -1] [ 0,  6,  0]  1 */
       12064, /* 64821 (1600) [ 0,  1,  0,  0,  0,  1,  1,  0,  0] [ 0,  0,  0]  1 */
    18439770, /* 64822 (1600) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
    18557818, /* 64823 (1600) [ 1,  0,  0,  0,  0,  1,  0,  1,  0] [ 6,  6,  6]  1 */
        7618, /* 64824 (1600) [ 0, -1,  0,  0,  0, -1, -1,  0,  0] [ 0,  0,  0]  1 */
      125510, /* 64825 (1600) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  6]  1 */
     1544632, /* 64826 (1600) [ 0,  0, -1,  1,  0,  0,  0,  1,  0] [ 0,  6,  6]  1 */
       16484, /* 64827 (1601) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
     1428962, /* 64828 (1601) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 0,  6,  0]  1 */
    34139362, /* 64829 (1601) [ 0,  0, -1,  0, -1,  0,  1,  0,  0] [ 0,  0,  6] -1 */
    35439898, /* 64830 (1601) [ 0,  0,  1,  0, -1,  0,  1,  0,  0] [ 0,  6,  0] -1 */
    17136220, /* 64831 (1601) [ 0,  1,  0,  0,  0, -1,  1,  0,  0] [ 6,  0,  6]  1 */
     1420480, /* 64832 (1601) [-1,  0,  0,  0,  0,  1,  0, -1,  0] [ 0,  6,  0]  1 */
        3198, /* 64833 (1601) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
     1545598, /* 64834 (1601) [ 0,  0,  1, -1,  0,  0,  0, -1,  0] [ 0,  6,  6]  1 */
    17140532, /* 64835 (1601) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
      121354, /* 64836 (1601) [-1,  0,  0,  0,  0, -1,  0,  1,  0] [ 0,  0,  6]  1 */
    51028816, /* 64837 (1601) [ 0,  0,  1,  0, -1,  0, -1,  0,  0] [ 6,  0,  0] -1 */
    18548796, /* 64838 (1601) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 6,  6,  6]  1 */
    52565882, /* 64839 (1601) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    35438584, /* 64840 (1601) [ 0,  0, -1,  0,  1,  0, -1,  0,  0] [ 0,  6,  0] -1 */
    34023040, /* 64841 (1601) [ 0,  0,  1,  1,  0,  0,  0,  1,  0] [ 0,  0,  0] -1 */
     1433554, /* 64842 (1601) [ 1,  0,  0,  0,  0, -1,  0,  1,  0] [ 0,  6,  0]  1 */
    18432160, /* 64843 (1601) [ 0,  0, -1, -1,  0,  0,  0,  1,  0] [ 6,  6,  0]  1 */
    17014010, /* 64844 (1601) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 6,  0,  0]  1 */
    34024288, /* 64845 (1601) [ 0,  1,  0,  0,  0,  1,  1,  0,  0] [ 0,  0,  0] -1 */
    17009422, /* 64846 (1601) [-1,  0,  0,  0,  0,  1,  0,  1,  0] [ 6,  0,  0]  1 */
    52570042, /* 64847 (1601) [ 1,  0,  0,  0,  0,  1,  0,  1,  0] [ 6,  6,  6] -1 */
    34137734, /* 64848 (1601) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    51146764, /* 64849 (1601) [ 0,  0,  1, -1,  0,  0,  0,  1,  0] [ 6,  0,  6] -1 */
    51139794, /* 64850 (1601) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6] -1 */
    34142592, /* 64851 (1601) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  6] -1 */
    52562632, /* 64852 (1601) [ 0,  0, -1,  0, -1,  0, -1,  0,  0] [ 6,  6,  6] -1 */
    17133562, /* 64853 (1601) [ 0,  0, -1,  1,  0,  0,  0, -1,  0] [ 6,  0,  6]  1 */
    35559490, /* 64854 (1601) [ 0,  1,  0,  0,  0, -1, -1,  0,  0] [ 0,  6,  6] -1 */
    52446322, /* 64855 (1601) [ 0,  0,  1,  1,  0,  0,  0, -1,  0] [ 6,  6,  0] -1 */
    52443148, /* 64856 (1601) [ 0, -1,  0,  0,  0, -1,  1,  0,  0] [ 6,  6,  0] -1 */
    51034708, /* 64857 (1601) [ 1,  0,  0,  0,  0, -1,  0, -1,  0] [ 6,  0,  0] -1 */
    34140964, /* 64858 (1601) [ 0,  0,  1,  0,  1,  0, -1,  0,  0] [ 0,  0,  6] -1 */
        8866, /* 64859 (1601) [ 0,  0, -1, -1,  0,  0,  0, -1,  0] [ 0,  0,  0]  1 */
    34146748, /* 64860 (1601) [ 1,  0,  0,  0,  0,  1,  0, -1,  0] [ 0,  0,  6] -1 */
      127138, /* 64861 (1601) [ 0,  0, -1,  0, -1,  0,  1,  0,  0] [ 0,  0,  6]  1 */
    35555188, /* 64862 (1601) [ 0, -1,  0,  0,  0,  1,  1,  0,  0] [ 0,  6,  6] -1 */
     1427674, /* 64863 (1601) [ 0,  0,  1,  0, -1,  0,  1,  0,  0] [ 0,  6,  0]  1 */
    52447558, /* 64864 (1601) [ 0,  1,  0,  0,  0,  1, -1,  0,  0] [ 6,  6,  0] -1 */
    17017896, /* 64865 (1601) [ 0,  1,  0, -1,  0,  0,  0,  0, -1] [ 6,  0,  0]  1 */
    52438712, /* 64866 (1601) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
    34028708, /* 64867 (1601) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    17016592, /* 64868 (1601) [ 0,  0,  1,  0, -1,  0, -1,  0,  0] [ 6,  0,  0]  1 */
    52451994, /* 64869 (1601) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
    34019842, /* 64870 (1601) [ 0, -1,  0,  0,  0, -1, -1,  0,  0] [ 0,  0,  0] -1 */
    52564270, /* 64871 (1601) [ 0,  0,  1,  0,  1,  0,  1,  0,  0] [ 6,  6,  6] -1 */
    35556856, /* 64872 (1601) [ 0,  0, -1,  1,  0,  0,  0,  1,  0] [ 0,  6,  6] -1 */
    18553658, /* 64873 (1601) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 6,  6,  6]  1 */
     1426360, /* 64874 (1601) [ 0,  0, -1,  0,  1,  0, -1,  0,  0] [ 0,  6,  0]  1 */
       10816, /* 64875 (1601) [ 0,  0,  1,  1,  0,  0,  0,  1,  0] [ 0,  0,  0]  1 */
    34015422, /* 64876 (1601) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    51152756, /* 64877 (1601) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
    35550860, /* 64878 (1601) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
     1425072, /* 64879 (1601) [ 0, -1,  0,  1,  0,  0,  0,  0, -1] [ 0,  6,  0]  1 */
    51144106, /* 64880 (1601) [ 0, -1,  0,  0,  0,  1, -1,  0,  0] [ 6,  0,  6] -1 */
       12064, /* 64881 (1601) [ 0,  1,  0,  0,  0,  1,  1,  0,  0] [ 0,  0,  0]  1 */
    18557818, /* 64882 (1601) [ 1,  0,  0,  0,  0,  1,  0,  1,  0] [ 6,  6,  6]  1 */
    52561020, /* 64883 (1601) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 6,  6,  6] -1 */
      125510, /* 64884 (1601) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  6]  1 */
    17127570, /* 64885 (1601) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6]  1 */
      130368, /* 64886 (1601) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  6]  1 */
    35445778, /* 64887 (1601) [ 1,  0,  0,  0,  0, -1,  0,  1,  0] [ 0,  6,  0] -1 */
     1547266, /* 64888 (1601) [ 0,  1,  0,  0,  0, -1, -1,  0,  0] [ 0,  6,  6]  1 */
    52444384, /* 64889 (1601) [ 0,  0, -1, -1,  0,  0,  0,  1,  0] [ 6,  6,  0] -1 */
    18434098, /* 64890 (1601) [ 0,  0,  1,  1,  0,  0,  0, -1,  0] [ 6,  6,  0]  1 */
    35563818, /* 64891 (1601) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  6] -1 */
    51021646, /* 64892 (1601) [-1,  0,  0,  0,  0,  1,  0,  1,  0] [ 6,  0,  0] -1 */
    52556860, /* 64893 (1601) [-1,  0,  0,  0,  0, -1,  0, -1,  0] [ 6,  6,  6] -1 */
    51027538, /* 64894 (1601) [ 0,  0, -1,  0,  1,  0,  1,  0,  0] [ 6,  0,  0] -1 */
      128740, /* 64895 (1601) [ 0,  0,  1,  0,  1,  0, -1,  0,  0] [ 0,  0,  6]  1 */
    35441186, /* 64896 (1601) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 0,  6,  0] -1 */
    18435334, /* 64897 (1601) [ 0,  1,  0,  0,  0,  1, -1,  0,  0] [ 6,  6,  0]  1 */
    18426488, /* 64898 (1601) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    51148444, /* 64899 (1601) [ 0,  1,  0,  0,  0, -1,  1,  0,  0] [ 6,  0,  6] -1 */
    35432704, /* 64900 (1601) [-1,  0,  0,  0,  0,  1,  0, -1,  0] [ 0,  6,  0] -1 */
    35557822, /* 64901 (1601) [ 0,  0,  1, -1,  0,  0,  0, -1,  0] [ 0,  6,  6] -1 */
    34133578, /* 64902 (1601) [-1,  0,  0,  0,  0, -1,  0,  1,  0] [ 0,  0,  6] -1 */
    18439770, /* 64903 (1601) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
    18552046, /* 64904 (1601) [ 0,  0,  1,  0,  1,  0,  1,  0,  0] [ 6,  6,  6]  1 */
        7618, /* 64905 (1601) [ 0, -1,  0,  0,  0, -1, -1,  0,  0] [ 0,  0,  0]  1 */
     1544632, /* 64906 (1601) [ 0,  0, -1,  1,  0,  0,  0,  1,  0] [ 0,  6,  6]  1 */
    51030120, /* 64907 (1601) [ 0,  1,  0, -1,  0,  0,  0,  0, -1] [ 6,  0,  0] -1 */
    17134540, /* 64908 (1601) [ 0,  0,  1, -1,  0,  0,  0,  1,  0] [ 6,  0,  6]  1 */
     1538636, /* 64909 (1601) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
    18550408, /* 64910 (1601) [ 0,  0, -1,  0, -1,  0, -1,  0,  0] [ 6,  6,  6]  1 */
    17131882, /* 64911 (1601) [ 0, -1,  0,  0,  0,  1, -1,  0,  0] [ 6,  0,  6]  1 */
    51026234, /* 64912 (1601) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 6,  0,  0] -1 */
    18430924, /* 64913 (1601) [ 0, -1,  0,  0,  0, -1,  1,  0,  0] [ 6,  6,  0]  1 */
    35437296, /* 64914 (1601) [ 0, -1,  0,  1,  0,  0,  0,  0, -1] [ 0,  6,  0] -1 */
    17022484, /* 64915 (1601) [ 1,  0,  0,  0,  0, -1,  0, -1,  0] [ 6,  0,  0]  1 */
     1551594, /* 64916 (1601) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
    51145786, /* 64917 (1601) [ 0,  0, -1,  1,  0,  0,  0, -1,  0] [ 6,  0,  6] -1 */
    18544636, /* 64918 (1601) [-1,  0,  0,  0,  0, -1,  0, -1,  0] [ 6,  6,  6]  1 */
    17015314, /* 64919 (1601) [ 0,  0, -1,  0,  1,  0,  1,  0,  0] [ 6,  0,  0]  1 */
      134524, /* 64920 (1601) [ 1,  0,  0,  0,  0,  1,  0, -1,  0] [ 0,  0,  6]  1 */
     1542964, /* 64921 (1601) [ 0, -1,  0,  0,  0,  1,  1,  0,  0] [ 0,  6,  6]  1 */
    34021090, /* 64922 (1601) [ 0,  0, -1, -1,  0,  0,  0, -1,  0] [ 0,  0,  0] -1 */
       16484, /* 64923 (1602) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    17127570, /* 64924 (1602) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6]  1 */
    35439898, /* 64925 (1602) [ 0,  0,  1,  0, -1,  0,  1,  0,  0] [ 0,  6,  0] -1 */
    35445778, /* 64926 (1602) [ 1,  0,  0,  0,  0, -1,  0,  1,  0] [ 0,  6,  0] -1 */
     1420480, /* 64927 (1602) [-1,  0,  0,  0,  0,  1,  0, -1,  0] [ 0,  6,  0]  1 */
     1545598, /* 64928 (1602) [ 0,  0,  1, -1,  0,  0,  0, -1,  0] [ 0,  6,  6]  1 */
     1547266, /* 64929 (1602) [ 0,  1,  0,  0,  0, -1, -1,  0,  0] [ 0,  6,  6]  1 */
    17131882, /* 64930 (1602) [ 0, -1,  0,  0,  0,  1, -1,  0,  0] [ 6,  0,  6]  1 */
    34140964, /* 64931 (1602) [ 0,  0,  1,  0,  1,  0, -1,  0,  0] [ 0,  0,  6] -1 */
      121354, /* 64932 (1602) [-1,  0,  0,  0,  0, -1,  0,  1,  0] [ 0,  0,  6]  1 */
    51021646, /* 64933 (1602) [-1,  0,  0,  0,  0,  1,  0,  1,  0] [ 6,  0,  0] -1 */
    51026234, /* 64934 (1602) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 6,  0,  0] -1 */
    52556860, /* 64935 (1602) [-1,  0,  0,  0,  0, -1,  0, -1,  0] [ 6,  6,  6] -1 */
    51027538, /* 64936 (1602) [ 0,  0, -1,  0,  1,  0,  1,  0,  0] [ 6,  0,  0] -1 */
    34146748, /* 64937 (1602) [ 1,  0,  0,  0,  0,  1,  0, -1,  0] [ 0,  0,  6] -1 */
      127138, /* 64938 (1602) [ 0,  0, -1,  0, -1,  0,  1,  0,  0] [ 0,  0,  6]  1 */
    18430924, /* 64939 (1602) [ 0, -1,  0,  0,  0, -1,  1,  0,  0] [ 6,  6,  0]  1 */
    35555188, /* 64940 (1602) [ 0, -1,  0,  0,  0,  1,  1,  0,  0] [ 0,  6,  6] -1 */
    52447558, /* 64941 (1602) [ 0,  1,  0,  0,  0,  1, -1,  0,  0] [ 6,  6,  0] -1 */
    17017896, /* 64942 (1602) [ 0,  1,  0, -1,  0,  0,  0,  0, -1] [ 6,  0,  0]  1 */
    17022484, /* 64943 (1602) [ 1,  0,  0,  0,  0, -1,  0, -1,  0] [ 6,  0,  0]  1 */
     1551594, /* 64944 (1602) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
    18432160, /* 64945 (1602) [ 0,  0, -1, -1,  0,  0,  0,  1,  0] [ 6,  6,  0]  1 */
    17016592, /* 64946 (1602) [ 0,  0,  1,  0, -1,  0, -1,  0,  0] [ 6,  0,  0]  1 */
    52451994, /* 64947 (1602) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
    34019842, /* 64948 (1602) [ 0, -1,  0,  0,  0, -1, -1,  0,  0] [ 0,  0,  0] -1 */
    35556856, /* 64949 (1602) [ 0,  0, -1,  1,  0,  0,  0,  1,  0] [ 0,  6,  6] -1 */
    35441186, /* 64950 (1602) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 0,  6,  0] -1 */
    18553658, /* 64951 (1602) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 6,  6,  6]  1 */
     1426360, /* 64952 (1602) [ 0,  0, -1,  0,  1,  0, -1,  0,  0] [ 0,  6,  0]  1 */
    18426488, /* 64953 (1602) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    34142592, /* 64954 (1602) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  6] -1 */
    51146764, /* 64955 (1602) [ 0,  0,  1, -1,  0,  0,  0,  1,  0] [ 6,  0,  6] -1 */
    34015422, /* 64956 (1602) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
       10816, /* 64957 (1602) [ 0,  0,  1,  1,  0,  0,  0,  1,  0] [ 0,  0,  0]  1 */
    51148444, /* 64958 (1602) [ 0,  1,  0,  0,  0, -1,  1,  0,  0] [ 6,  0,  6] -1 */
    52562632, /* 64959 (1602) [ 0,  0, -1,  0, -1,  0, -1,  0,  0] [ 6,  6,  6] -1 */
    35550860, /* 64960 (1602) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
    51152756, /* 64961 (1602) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
    17133562, /* 64962 (1602) [ 0,  0, -1,  1,  0,  0,  0, -1,  0] [ 6,  0,  6]  1 */
     1425072, /* 64963 (1602) [ 0, -1,  0,  1,  0,  0,  0,  0, -1] [ 0,  6,  0]  1 */
      125510, /* 64964 (1602) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  6]  1 */
       12064, /* 64965 (1602) [ 0,  1,  0,  0,  0,  1,  1,  0,  0] [ 0,  0,  0]  1 */
    52446322, /* 64966 (1602) [ 0,  0,  1,  1,  0,  0,  0, -1,  0] [ 6,  6,  0] -1 */
    18557818, /* 64967 (1602) [ 1,  0,  0,  0,  0,  1,  0,  1,  0] [ 6,  6,  6]  1 */
    34021090, /* 64968 (1602) [ 0,  0, -1, -1,  0,  0,  0, -1,  0] [ 0,  0,  0] -1 */
    18552046, /* 64969 (1602) [ 0,  0,  1,  0,  1,  0,  1,  0,  0] [ 6,  6,  6]  1 */
    52561020, /* 64970 (1602) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 6,  6,  6] -1 */
       16484, /* 64971 (1603) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34139362, /* 64972 (1603) [ 0,  0, -1,  0, -1,  0,  1,  0,  0] [ 0,  0,  6] -1 */
    17127570, /* 64973 (1603) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6]  1 */
    51030120, /* 64974 (1603) [ 0,  1,  0, -1,  0,  0,  0,  0, -1] [ 6,  0,  0] -1 */
    35439898, /* 64975 (1603) [ 0,  0,  1,  0, -1,  0,  1,  0,  0] [ 0,  6,  0] -1 */
    17134540, /* 64976 (1603) [ 0,  0,  1, -1,  0,  0,  0,  1,  0] [ 6,  0,  6]  1 */
    17136220, /* 64977 (1603) [ 0,  1,  0,  0,  0, -1,  1,  0,  0] [ 6,  0,  6]  1 */
     1538636, /* 64978 (1603) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
    35445778, /* 64979 (1603) [ 1,  0,  0,  0,  0, -1,  0,  1,  0] [ 0,  6,  0] -1 */
        3198, /* 64980 (1603) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
     1545598, /* 64981 (1603) [ 0,  0,  1, -1,  0,  0,  0, -1,  0] [ 0,  6,  6]  1 */
    51034708, /* 64982 (1603) [ 1,  0,  0,  0,  0, -1,  0, -1,  0] [ 6,  0,  0] -1 */
     1547266, /* 64983 (1603) [ 0,  1,  0,  0,  0, -1, -1,  0,  0] [ 0,  6,  6]  1 */
    17131882, /* 64984 (1603) [ 0, -1,  0,  0,  0,  1, -1,  0,  0] [ 6,  0,  6]  1 */
    17140532, /* 64985 (1603) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
    18434098, /* 64986 (1603) [ 0,  0,  1,  1,  0,  0,  0, -1,  0] [ 6,  6,  0]  1 */
    34140964, /* 64987 (1603) [ 0,  0,  1,  0,  1,  0, -1,  0,  0] [ 0,  0,  6] -1 */
        8866, /* 64988 (1603) [ 0,  0, -1, -1,  0,  0,  0, -1,  0] [ 0,  0,  0]  1 */
    51021646, /* 64989 (1603) [-1,  0,  0,  0,  0,  1,  0,  1,  0] [ 6,  0,  0] -1 */
    51026234, /* 64990 (1603) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 6,  0,  0] -1 */
    51028816, /* 64991 (1603) [ 0,  0,  1,  0, -1,  0, -1,  0,  0] [ 6,  0,  0] -1 */
    52556860, /* 64992 (1603) [-1,  0,  0,  0,  0, -1,  0, -1,  0] [ 6,  6,  6] -1 */
    51027538, /* 64993 (1603) [ 0,  0, -1,  0,  1,  0,  1,  0,  0] [ 6,  0,  0] -1 */
    34146748, /* 64994 (1603) [ 1,  0,  0,  0,  0,  1,  0, -1,  0] [ 0,  0,  6] -1 */
    18430924, /* 64995 (1603) [ 0, -1,  0,  0,  0, -1,  1,  0,  0] [ 6,  6,  0]  1 */
    52565882, /* 64996 (1603) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    35438584, /* 64997 (1603) [ 0,  0, -1,  0,  1,  0, -1,  0,  0] [ 0,  6,  0] -1 */
    35437296, /* 64998 (1603) [ 0, -1,  0,  1,  0,  0,  0,  0, -1] [ 0,  6,  0] -1 */
     1551594, /* 64999 (1603) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
    18432160, /* 65000 (1603) [ 0,  0, -1, -1,  0,  0,  0,  1,  0] [ 6,  6,  0]  1 */
    52570042, /* 65001 (1603) [ 1,  0,  0,  0,  0,  1,  0,  1,  0] [ 6,  6,  6] -1 */
    52564270, /* 65002 (1603) [ 0,  0,  1,  0,  1,  0,  1,  0,  0] [ 6,  6,  6] -1 */
    34137734, /* 65003 (1603) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    35441186, /* 65004 (1603) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 0,  6,  0] -1 */
     1542964, /* 65005 (1603) [ 0, -1,  0,  0,  0,  1,  1,  0,  0] [ 0,  6,  6]  1 */
    18435334, /* 65006 (1603) [ 0,  1,  0,  0,  0,  1, -1,  0,  0] [ 6,  6,  0]  1 */
    18426488, /* 65007 (1603) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    34142592, /* 65008 (1603) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  6] -1 */
       10816, /* 65009 (1603) [ 0,  0,  1,  1,  0,  0,  0,  1,  0] [ 0,  0,  0]  1 */
    52562632, /* 65010 (1603) [ 0,  0, -1,  0, -1,  0, -1,  0,  0] [ 6,  6,  6] -1 */
    17133562, /* 65011 (1603) [ 0,  0, -1,  1,  0,  0,  0, -1,  0] [ 6,  0,  6]  1 */
    35432704, /* 65012 (1603) [-1,  0,  0,  0,  0,  1,  0, -1,  0] [ 0,  6,  0] -1 */
       12064, /* 65013 (1603) [ 0,  1,  0,  0,  0,  1,  1,  0,  0] [ 0,  0,  0]  1 */
    34133578, /* 65014 (1603) [-1,  0,  0,  0,  0, -1,  0,  1,  0] [ 0,  0,  6] -1 */
    18439770, /* 65015 (1603) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
        7618, /* 65016 (1603) [ 0, -1,  0,  0,  0, -1, -1,  0,  0] [ 0,  0,  0]  1 */
    52561020, /* 65017 (1603) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 6,  6,  6] -1 */
     1544632, /* 65018 (1603) [ 0,  0, -1,  1,  0,  0,  0,  1,  0] [ 0,  6,  6]  1 */
       16484, /* 65019 (1604) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
     1428962, /* 65020 (1604) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 0,  6,  0]  1 */
    34139362, /* 65021 (1604) [ 0,  0, -1,  0, -1,  0,  1,  0,  0] [ 0,  0,  6] -1 */
    17127570, /* 65022 (1604) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6]  1 */
      130368, /* 65023 (1604) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  6]  1 */
    51030120, /* 65024 (1604) [ 0,  1,  0, -1,  0,  0,  0,  0, -1] [ 6,  0,  0] -1 */
    51034708, /* 65025 (1604) [ 1,  0,  0,  0,  0, -1,  0, -1,  0] [ 6,  0,  0] -1 */
     1545598, /* 65026 (1604) [ 0,  0,  1, -1,  0,  0,  0, -1,  0] [ 0,  6,  6]  1 */
     1547266, /* 65027 (1604) [ 0,  1,  0,  0,  0, -1, -1,  0,  0] [ 0,  6,  6]  1 */
    18550408, /* 65028 (1604) [ 0,  0, -1,  0, -1,  0, -1,  0,  0] [ 6,  6,  6]  1 */
    17131882, /* 65029 (1604) [ 0, -1,  0,  0,  0,  1, -1,  0,  0] [ 6,  0,  6]  1 */
    51028816, /* 65030 (1604) [ 0,  0,  1,  0, -1,  0, -1,  0,  0] [ 6,  0,  0] -1 */
    18548796, /* 65031 (1604) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 6,  6,  6]  1 */
    18430924, /* 65032 (1604) [ 0, -1,  0,  0,  0, -1,  1,  0,  0] [ 6,  6,  0]  1 */
     1427674, /* 65033 (1604) [ 0,  0,  1,  0, -1,  0,  1,  0,  0] [ 0,  6,  0]  1 */
    35555188, /* 65034 (1604) [ 0, -1,  0,  0,  0,  1,  1,  0,  0] [ 0,  6,  6] -1 */
    52447558, /* 65035 (1604) [ 0,  1,  0,  0,  0,  1, -1,  0,  0] [ 6,  6,  0] -1 */
    52565882, /* 65036 (1604) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    35438584, /* 65037 (1604) [ 0,  0, -1,  0,  1,  0, -1,  0,  0] [ 0,  6,  0] -1 */
     1433554, /* 65038 (1604) [ 1,  0,  0,  0,  0, -1,  0,  1,  0] [ 0,  6,  0]  1 */
    35437296, /* 65039 (1604) [ 0, -1,  0,  1,  0,  0,  0,  0, -1] [ 0,  6,  0] -1 */
     1551594, /* 65040 (1604) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
      128740, /* 65041 (1604) [ 0,  0,  1,  0,  1,  0, -1,  0,  0] [ 0,  0,  6]  1 */
    18432160, /* 65042 (1604) [ 0,  0, -1, -1,  0,  0,  0,  1,  0] [ 6,  6,  0]  1 */
    17014010, /* 65043 (1604) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 6,  0,  0]  1 */
    18544636, /* 65044 (1604) [-1,  0,  0,  0,  0, -1,  0, -1,  0] [ 6,  6,  6]  1 */
    17009422, /* 65045 (1604) [-1,  0,  0,  0,  0,  1,  0,  1,  0] [ 6,  0,  0]  1 */
    52451994, /* 65046 (1604) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
    17015314, /* 65047 (1604) [ 0,  0, -1,  0,  1,  0,  1,  0,  0] [ 6,  0,  0]  1 */
    52570042, /* 65048 (1604) [ 1,  0,  0,  0,  0,  1,  0,  1,  0] [ 6,  6,  6] -1 */
    34019842, /* 65049 (1604) [ 0, -1,  0,  0,  0, -1, -1,  0,  0] [ 0,  0,  0] -1 */
    52564270, /* 65050 (1604) [ 0,  0,  1,  0,  1,  0,  1,  0,  0] [ 6,  6,  6] -1 */
    34137734, /* 65051 (1604) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    35556856, /* 65052 (1604) [ 0,  0, -1,  1,  0,  0,  0,  1,  0] [ 0,  6,  6] -1 */
      134524, /* 65053 (1604) [ 1,  0,  0,  0,  0,  1,  0, -1,  0] [ 0,  0,  6]  1 */
    51146764, /* 65054 (1604) [ 0,  0,  1, -1,  0,  0,  0,  1,  0] [ 6,  0,  6] -1 */
    18426488, /* 65055 (1604) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    34015422, /* 65056 (1604) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
       10816, /* 65057 (1604) [ 0,  0,  1,  1,  0,  0,  0,  1,  0] [ 0,  0,  0]  1 */
    51148444, /* 65058 (1604) [ 0,  1,  0,  0,  0, -1,  1,  0,  0] [ 6,  0,  6] -1 */
    51152756, /* 65059 (1604) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
    35550860, /* 65060 (1604) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
    17133562, /* 65061 (1604) [ 0,  0, -1,  1,  0,  0,  0, -1,  0] [ 6,  0,  6]  1 */
    35432704, /* 65062 (1604) [-1,  0,  0,  0,  0,  1,  0, -1,  0] [ 0,  6,  0] -1 */
       12064, /* 65063 (1604) [ 0,  1,  0,  0,  0,  1,  1,  0,  0] [ 0,  0,  0]  1 */
    52446322, /* 65064 (1604) [ 0,  0,  1,  1,  0,  0,  0, -1,  0] [ 6,  6,  0] -1 */
    34133578, /* 65065 (1604) [-1,  0,  0,  0,  0, -1,  0,  1,  0] [ 0,  0,  6] -1 */
    34021090, /* 65066 (1604) [ 0,  0, -1, -1,  0,  0,  0, -1,  0] [ 0,  0,  0] -1 */
       16484, /* 65067 (1605) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
     1428962, /* 65068 (1605) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 0,  6,  0]  1 */
    17136220, /* 65069 (1605) [ 0,  1,  0,  0,  0, -1,  1,  0,  0] [ 6,  0,  6]  1 */
     1420480, /* 65070 (1605) [-1,  0,  0,  0,  0,  1,  0, -1,  0] [ 0,  6,  0]  1 */
        3198, /* 65071 (1605) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
     1545598, /* 65072 (1605) [ 0,  0,  1, -1,  0,  0,  0, -1,  0] [ 0,  6,  6]  1 */
    17140532, /* 65073 (1605) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
      121354, /* 65074 (1605) [-1,  0,  0,  0,  0, -1,  0,  1,  0] [ 0,  0,  6]  1 */
    51027694, /* 65075 (1605) [ 0,  0, -1,  1,  0,  0,  0,  1,  0] [ 6,  0,  0] -1 */
    18548796, /* 65076 (1605) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 6,  6,  6]  1 */
    34024496, /* 65077 (1605) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 0,  0,  0] -1 */
     1433554, /* 65078 (1605) [ 1,  0,  0,  0,  0, -1,  0,  1,  0] [ 0,  6,  0]  1 */
    34142368, /* 65079 (1605) [ 0,  1,  0,  0,  0,  1, -1,  0,  0] [ 0,  0,  6] -1 */
    34133522, /* 65080 (1605) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    52561228, /* 65081 (1605) [ 0, -1,  0,  0,  0, -1, -1,  0,  0] [ 6,  6,  6] -1 */
    18432160, /* 65082 (1605) [ 0,  0, -1, -1,  0,  0,  0,  1,  0] [ 6,  6,  0]  1 */
    17014010, /* 65083 (1605) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 6,  0,  0]  1 */
    35439730, /* 65084 (1605) [ 0,  0,  1, -1,  0,  0,  0,  1,  0] [ 0,  6,  0] -1 */
    51034656, /* 65085 (1605) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  0] -1 */
    35432760, /* 65086 (1605) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  0] -1 */
    17009422, /* 65087 (1605) [-1,  0,  0,  0,  0,  1,  0,  1,  0] [ 6,  0,  0]  1 */
    52447782, /* 65088 (1605) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 6,  6,  0] -1 */
    34146804, /* 65089 (1605) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
    35555396, /* 65090 (1605) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 0,  6,  6] -1 */
    35559282, /* 65091 (1605) [ 0,  1,  0, -1,  0,  0,  0,  0, -1] [ 0,  6,  6] -1 */
    17133562, /* 65092 (1605) [ 0,  0, -1,  1,  0,  0,  0, -1,  0] [ 6,  0,  6]  1 */
    34141132, /* 65093 (1605) [ 0,  0,  1,  1,  0,  0,  0, -1,  0] [ 0,  0,  6] -1 */
    51026026, /* 65094 (1605) [ 0, -1,  0,  0,  0,  1,  1,  0,  0] [ 6,  0,  0] -1 */
    34137958, /* 65095 (1605) [ 0, -1,  0,  0,  0, -1,  1,  0,  0] [ 0,  0,  6] -1 */
        8866, /* 65096 (1605) [ 0,  0, -1, -1,  0,  0,  0, -1,  0] [ 0,  0,  0]  1 */
    52446154, /* 65097 (1605) [ 0,  0,  1,  0,  1,  0, -1,  0,  0] [ 6,  6,  0] -1 */
      127138, /* 65098 (1605) [ 0,  0, -1,  0, -1,  0,  1,  0,  0] [ 0,  0,  6]  1 */
     1427674, /* 65099 (1605) [ 0,  0,  1,  0, -1,  0,  1,  0,  0] [ 0,  6,  0]  1 */
    17017896, /* 65100 (1605) [ 0,  1,  0, -1,  0,  0,  0,  0, -1] [ 6,  0,  0]  1 */
    51145618, /* 65101 (1605) [ 0,  0, -1,  0,  1,  0, -1,  0,  0] [ 6,  0,  6] -1 */
    51028660, /* 65102 (1605) [ 0,  0,  1, -1,  0,  0,  0, -1,  0] [ 6,  0,  0] -1 */
    17016592, /* 65103 (1605) [ 0,  0,  1,  0, -1,  0, -1,  0,  0] [ 6,  0,  0]  1 */
    52442924, /* 65104 (1605) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 6,  6,  0] -1 */
    52438768, /* 65105 (1605) [-1,  0,  0,  0,  0, -1,  0,  1,  0] [ 6,  6,  0] -1 */
    35445722, /* 65106 (1605) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  0] -1 */
    34022884, /* 65107 (1605) [ 0,  0,  1,  0,  1,  0,  1,  0,  0] [ 0,  0,  0] -1 */
    35437072, /* 65108 (1605) [ 0, -1,  0,  0,  0,  1, -1,  0,  0] [ 0,  6,  0] -1 */
    18553658, /* 65109 (1605) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    52556808, /* 65110 (1605) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
     1426360, /* 65111 (1605) [ 0,  0, -1,  0,  1,  0, -1,  0,  0] [ 0,  6,  0]  1 */
    35441410, /* 65112 (1605) [ 0,  1,  0,  0,  0, -1,  1,  0,  0] [ 0,  6,  0] -1 */
       10816, /* 65113 (1605) [ 0,  0,  1,  1,  0,  0,  0,  1,  0] [ 0,  0,  0]  1 */
     1425072, /* 65114 (1605) [ 0, -1,  0,  1,  0,  0,  0,  0, -1] [ 0,  6,  0]  1 */
       12064, /* 65115 (1605) [ 0,  1,  0,  0,  0,  1,  1,  0,  0] [ 0,  0,  0]  1 */
    18557818, /* 65116 (1605) [ 1,  0,  0,  0,  0,  1,  0,  1,  0] [ 6,  6,  6]  1 */
      125510, /* 65117 (1605) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  6]  1 */
    17127570, /* 65118 (1605) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6]  1 */
      130368, /* 65119 (1605) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  6]  1 */
     1547266, /* 65120 (1605) [ 0,  1,  0,  0,  0, -1, -1,  0,  0] [ 0,  6,  6]  1 */
    18434098, /* 65121 (1605) [ 0,  0,  1,  1,  0,  0,  0, -1,  0] [ 6,  6,  0]  1 */
    52451938, /* 65122 (1605) [ 1,  0,  0,  0,  0,  1,  0, -1,  0] [ 6,  6,  0] -1 */
    35438752, /* 65123 (1605) [ 0,  0, -1,  1,  0,  0,  0, -1,  0] [ 0,  6,  0] -1 */
    34139194, /* 65124 (1605) [ 0,  0, -1, -1,  0,  0,  0,  1,  0] [ 0,  0,  6] -1 */
    34015474, /* 65125 (1605) [-1,  0,  0,  0,  0, -1,  0, -1,  0] [ 0,  0,  0] -1 */
    51030328, /* 65126 (1605) [ 0,  1,  0,  0,  0, -1, -1,  0,  0] [ 6,  0,  0] -1 */
      128740, /* 65127 (1605) [ 0,  0,  1,  0,  1,  0, -1,  0,  0] [ 0,  0,  6]  1 */
    35556700, /* 65128 (1605) [ 0,  0, -1,  0,  1,  0,  1,  0,  0] [ 0,  6,  6] -1 */
    18435334, /* 65129 (1605) [ 0,  1,  0,  0,  0,  1, -1,  0,  0] [ 6,  6,  0]  1 */
    35557978, /* 65130 (1605) [ 0,  0,  1,  0, -1,  0, -1,  0,  0] [ 0,  6,  6] -1 */
    18426488, /* 65131 (1605) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    34021246, /* 65132 (1605) [ 0,  0, -1,  0, -1,  0, -1,  0,  0] [ 0,  0,  0] -1 */
    35563870, /* 65133 (1605) [ 1,  0,  0,  0,  0, -1,  0, -1,  0] [ 0,  6,  6] -1 */
    52562476, /* 65134 (1605) [ 0,  0, -1, -1,  0,  0,  0, -1,  0] [ 6,  6,  6] -1 */
    34028656, /* 65135 (1605) [ 1,  0,  0,  0,  0,  1,  0,  1,  0] [ 0,  0,  0] -1 */
    18439770, /* 65136 (1605) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
    18552046, /* 65137 (1605) [ 0,  0,  1,  0,  1,  0,  1,  0,  0] [ 6,  6,  6]  1 */
        7618, /* 65138 (1605) [ 0, -1,  0,  0,  0, -1, -1,  0,  0] [ 0,  0,  0]  1 */
     1544632, /* 65139 (1605) [ 0,  0, -1,  1,  0,  0,  0,  1,  0] [ 0,  6,  6]  1 */
    34019634, /* 65140 (1605) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    51146932, /* 65141 (1605) [ 0,  0,  1,  0, -1,  0,  1,  0,  0] [ 6,  0,  6] -1 */
    17134540, /* 65142 (1605) [ 0,  0,  1, -1,  0,  0,  0,  1,  0] [ 6,  0,  6]  1 */
     1538636, /* 65143 (1605) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
    51152812, /* 65144 (1605) [ 1,  0,  0,  0,  0, -1,  0,  1,  0] [ 6,  0,  6] -1 */
    18550408, /* 65145 (1605) [ 0,  0, -1,  0, -1,  0, -1,  0,  0] [ 6,  6,  6]  1 */
    17131882, /* 65146 (1605) [ 0, -1,  0,  0,  0,  1, -1,  0,  0] [ 6,  0,  6]  1 */
    52570094, /* 65147 (1605) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    51021698, /* 65148 (1605) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  0] -1 */
    18430924, /* 65149 (1605) [ 0, -1,  0,  0,  0, -1,  1,  0,  0] [ 6,  6,  0]  1 */
    52565674, /* 65150 (1605) [ 0,  1,  0,  0,  0,  1,  1,  0,  0] [ 6,  6,  6] -1 */
    17022484, /* 65151 (1605) [ 1,  0,  0,  0,  0, -1,  0, -1,  0] [ 6,  0,  0]  1 */
     1551594, /* 65152 (1605) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
    52564426, /* 65153 (1605) [ 0,  0,  1,  1,  0,  0,  0,  1,  0] [ 6,  6,  6] -1 */
    18544636, /* 65154 (1605) [-1,  0,  0,  0,  0, -1,  0, -1,  0] [ 6,  6,  6]  1 */
    17015314, /* 65155 (1605) [ 0,  0, -1,  0,  1,  0,  1,  0,  0] [ 6,  0,  0]  1 */
    51144330, /* 65156 (1605) [ 0, -1,  0,  1,  0,  0,  0,  0, -1] [ 6,  0,  6] -1 */
      134524, /* 65157 (1605) [ 1,  0,  0,  0,  0,  1,  0, -1,  0] [ 0,  0,  6]  1 */
     1542964, /* 65158 (1605) [ 0, -1,  0,  0,  0,  1,  1,  0,  0] [ 0,  6,  6]  1 */
    51148220, /* 65159 (1605) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 6,  0,  6] -1 */
    51139738, /* 65160 (1605) [-1,  0,  0,  0,  0,  1,  0, -1,  0] [ 6,  0,  6] -1 */
    35550808, /* 65161 (1605) [-1,  0,  0,  0,  0,  1,  0,  1,  0] [ 0,  6,  6] -1 */
    52444552, /* 65162 (1605) [ 0,  0, -1,  0, -1,  0,  1,  0,  0] [ 6,  6,  0] -1 */
       16484, /* 65163 (1606) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    18544642, /* 65164 (1606) [-1,  0,  0,  0,  0, -1,  0,  1,  0] [ 6,  6,  6]  1 */
    18557764, /* 65165 (1606) [ 1,  0,  0,  0,  0, -1,  0,  1,  0] [ 6,  6,  6]  1 */
    18551884, /* 65166 (1606) [ 0,  0,  1,  0, -1,  0,  1,  0,  0] [ 6,  6,  6]  1 */
    18553656, /* 65167 (1606) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 6,  6,  6]  1 */
       16320, /* 65168 (1606) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
       16482, /* 65169 (1606) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
        3198, /* 65170 (1606) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    18550408, /* 65171 (1606) [ 0,  0, -1,  0, -1,  0, -1,  0,  0] [ 6,  6,  6]  1 */
        7690, /* 65172 (1606) [ 0, -1,  0,  0,  0,  1,  1,  0,  0] [ 0,  0,  0]  1 */
        8866, /* 65173 (1606) [ 0,  0, -1, -1,  0,  0,  0, -1,  0] [ 0,  0,  0]  1 */
       10810, /* 65174 (1606) [ 0,  0,  1,  1,  0,  0,  0, -1,  0] [ 0,  0,  0]  1 */
    18550570, /* 65175 (1606) [ 0,  0, -1,  0,  1,  0, -1,  0,  0] [ 6,  6,  6]  1 */
    18548796, /* 65176 (1606) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 6,  6,  6]  1 */
    18549282, /* 65177 (1606) [ 0, -1,  0,  1,  0,  0,  0,  0, -1] [ 6,  6,  6]  1 */
        7636, /* 65178 (1606) [ 0, -1,  0,  0,  0, -1,  1,  0,  0] [ 0,  0,  0]  1 */
    18550426, /* 65179 (1606) [ 0,  0, -1,  0, -1,  0,  1,  0,  0] [ 6,  6,  6]  1 */
        9352, /* 65180 (1606) [ 0,  0, -1,  1,  0,  0,  0, -1,  0] [ 0,  0,  0]  1 */
    18553170, /* 65181 (1606) [ 0,  1,  0, -1,  0,  0,  0,  0, -1] [ 6,  6,  6]  1 */
    18552028, /* 65182 (1606) [ 0,  0,  1,  0,  1,  0, -1,  0,  0] [ 6,  6,  6]  1 */
        8872, /* 65183 (1606) [ 0,  0, -1, -1,  0,  0,  0,  1,  0] [ 0,  0,  0]  1 */
    18557758, /* 65184 (1606) [ 1,  0,  0,  0,  0, -1,  0, -1,  0] [ 6,  6,  6]  1 */
    18553172, /* 65185 (1606) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    18552046, /* 65186 (1606) [ 0,  0,  1,  0,  1,  0,  1,  0,  0] [ 6,  6,  6]  1 */
    18544636, /* 65187 (1606) [-1,  0,  0,  0,  0, -1,  0, -1,  0] [ 6,  6,  6]  1 */
    18557812, /* 65188 (1606) [ 1,  0,  0,  0,  0,  1,  0, -1,  0] [ 6,  6,  6]  1 */
    18551866, /* 65189 (1606) [ 0,  0,  1,  0, -1,  0, -1,  0,  0] [ 6,  6,  6]  1 */
    18544696, /* 65190 (1606) [-1,  0,  0,  0,  0,  1,  0,  1,  0] [ 6,  6,  6]  1 */
    18549284, /* 65191 (1606) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 6,  6,  6]  1 */
       10330, /* 65192 (1606) [ 0,  0,  1, -1,  0,  0,  0,  1,  0] [ 0,  0,  0]  1 */
        7672, /* 65193 (1606) [ 0, -1,  0,  0,  0,  1, -1,  0,  0] [ 0,  0,  0]  1 */
        3360, /* 65194 (1606) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    18550588, /* 65195 (1606) [ 0,  0, -1,  0,  1,  0,  1,  0,  0] [ 6,  6,  6]  1 */
       12010, /* 65196 (1606) [ 0,  1,  0,  0,  0, -1,  1,  0,  0] [ 0,  0,  0]  1 */
       12046, /* 65197 (1606) [ 0,  1,  0,  0,  0,  1, -1,  0,  0] [ 0,  0,  0]  1 */
    18553658, /* 65198 (1606) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 6,  6,  6]  1 */
       16322, /* 65199 (1606) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
       10816, /* 65200 (1606) [ 0,  0,  1,  1,  0,  0,  0,  1,  0] [ 0,  0,  0]  1 */
        3200, /* 65201 (1606) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
        3362, /* 65202 (1606) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
        9358, /* 65203 (1606) [ 0,  0, -1,  1,  0,  0,  0,  1,  0] [ 0,  0,  0]  1 */
    18544690, /* 65204 (1606) [-1,  0,  0,  0,  0,  1,  0, -1,  0] [ 6,  6,  6]  1 */
       11992, /* 65205 (1606) [ 0,  1,  0,  0,  0, -1, -1,  0,  0] [ 0,  0,  0]  1 */
       12064, /* 65206 (1606) [ 0,  1,  0,  0,  0,  1,  1,  0,  0] [ 0,  0,  0]  1 */
    18557818, /* 65207 (1606) [ 1,  0,  0,  0,  0,  1,  0,  1,  0] [ 6,  6,  6]  1 */
        7618, /* 65208 (1606) [ 0, -1,  0,  0,  0, -1, -1,  0,  0] [ 0,  0,  0]  1 */
    18548798, /* 65209 (1606) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 6,  6,  6]  1 */
       10324, /* 65210 (1606) [ 0,  0,  1, -1,  0,  0,  0, -1,  0] [ 0,  0,  0]  1 */
       16484, /* 65211 (1607) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
       16320, /* 65212 (1607) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
        3198, /* 65213 (1607) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    52565394, /* 65214 (1607) [ 0,  1,  0, -1,  0,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    18550570, /* 65215 (1607) [ 0,  0, -1,  0,  1,  0, -1,  0,  0] [ 6,  6,  6]  1 */
    34019896, /* 65216 (1607) [ 0, -1,  0,  0,  0,  1, -1,  0,  0] [ 0,  0,  0] -1 */
    18548796, /* 65217 (1607) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 6,  6,  6]  1 */
    34015584, /* 65218 (1607) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    34024234, /* 65219 (1607) [ 0,  1,  0,  0,  0, -1,  1,  0,  0] [ 0,  0,  0] -1 */
        9352, /* 65220 (1607) [ 0,  0, -1,  1,  0,  0,  0, -1,  0] [ 0,  0,  0]  1 */
    52565882, /* 65221 (1607) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    34023040, /* 65222 (1607) [ 0,  0,  1,  1,  0,  0,  0,  1,  0] [ 0,  0,  0] -1 */
        8872, /* 65223 (1607) [ 0,  0, -1, -1,  0,  0,  0,  1,  0] [ 0,  0,  0]  1 */
    34024288, /* 65224 (1607) [ 0,  1,  0,  0,  0,  1,  1,  0,  0] [ 0,  0,  0] -1 */
    52570042, /* 65225 (1607) [ 1,  0,  0,  0,  0,  1,  0,  1,  0] [ 6,  6,  6] -1 */
    18544696, /* 65226 (1607) [-1,  0,  0,  0,  0,  1,  0,  1,  0] [ 6,  6,  6]  1 */
    52561022, /* 65227 (1607) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    52569988, /* 65228 (1607) [ 1,  0,  0,  0,  0, -1,  0,  1,  0] [ 6,  6,  6] -1 */
    18550588, /* 65229 (1607) [ 0,  0, -1,  0,  1,  0,  1,  0,  0] [ 6,  6,  6]  1 */
    52556866, /* 65230 (1607) [-1,  0,  0,  0,  0, -1,  0,  1,  0] [ 6,  6,  6] -1 */
    52562632, /* 65231 (1607) [ 0,  0, -1,  0, -1,  0, -1,  0,  0] [ 6,  6,  6] -1 */
    34023034, /* 65232 (1607) [ 0,  0,  1,  1,  0,  0,  0, -1,  0] [ 0,  0,  0] -1 */
       10324, /* 65233 (1607) [ 0,  0,  1, -1,  0,  0,  0, -1,  0] [ 0,  0,  0]  1 */
    52564252, /* 65234 (1607) [ 0,  0,  1,  0,  1,  0, -1,  0,  0] [ 6,  6,  6] -1 */
        8866, /* 65235 (1607) [ 0,  0, -1, -1,  0,  0,  0, -1,  0] [ 0,  0,  0]  1 */
    52565396, /* 65236 (1607) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    52570036, /* 65237 (1607) [ 1,  0,  0,  0,  0,  1,  0, -1,  0] [ 6,  6,  6] -1 */
    52564090, /* 65238 (1607) [ 0,  0,  1,  0, -1,  0, -1,  0,  0] [ 6,  6,  6] -1 */
    18550426, /* 65239 (1607) [ 0,  0, -1,  0, -1,  0,  1,  0,  0] [ 6,  6,  6]  1 */
    34022554, /* 65240 (1607) [ 0,  0,  1, -1,  0,  0,  0,  1,  0] [ 0,  0,  0] -1 */
    34024270, /* 65241 (1607) [ 0,  1,  0,  0,  0,  1, -1,  0,  0] [ 0,  0,  0] -1 */
    34015424, /* 65242 (1607) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    34028708, /* 65243 (1607) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    34021582, /* 65244 (1607) [ 0,  0, -1,  1,  0,  0,  0,  1,  0] [ 0,  0,  0] -1 */
    18553170, /* 65245 (1607) [ 0,  1,  0, -1,  0,  0,  0,  0, -1] [ 6,  6,  6]  1 */
    34015586, /* 65246 (1607) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    34028706, /* 65247 (1607) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    34019842, /* 65248 (1607) [ 0, -1,  0,  0,  0, -1, -1,  0,  0] [ 0,  0,  0] -1 */
    52564270, /* 65249 (1607) [ 0,  0,  1,  0,  1,  0,  1,  0,  0] [ 6,  6,  6] -1 */
    18549284, /* 65250 (1607) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    34028544, /* 65251 (1607) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    18553658, /* 65252 (1607) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    52564108, /* 65253 (1607) [ 0,  0,  1,  0, -1,  0,  1,  0,  0] [ 6,  6,  6] -1 */
       10816, /* 65254 (1607) [ 0,  0,  1,  1,  0,  0,  0,  1,  0] [ 0,  0,  0]  1 */
    34015422, /* 65255 (1607) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
       11992, /* 65256 (1607) [ 0,  1,  0,  0,  0, -1, -1,  0,  0] [ 0,  0,  0]  1 */
       12064, /* 65257 (1607) [ 0,  1,  0,  0,  0,  1,  1,  0,  0] [ 0,  0,  0]  1 */
    18557818, /* 65258 (1607) [ 1,  0,  0,  0,  0,  1,  0,  1,  0] [ 6,  6,  6]  1 */
    52562794, /* 65259 (1607) [ 0,  0, -1,  0,  1,  0, -1,  0,  0] [ 6,  6,  6] -1 */
    34019914, /* 65260 (1607) [ 0, -1,  0,  0,  0,  1,  1,  0,  0] [ 0,  0,  0] -1 */
    52561020, /* 65261 (1607) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    18548798, /* 65262 (1607) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    18544642, /* 65263 (1607) [-1,  0,  0,  0,  0, -1,  0,  1,  0] [ 6,  6,  6]  1 */
    52561506, /* 65264 (1607) [ 0, -1,  0,  1,  0,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    34019860, /* 65265 (1607) [ 0, -1,  0,  0,  0, -1,  1,  0,  0] [ 0,  0,  0] -1 */
    18553656, /* 65266 (1607) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 6,  6,  6]  1 */
    52569982, /* 65267 (1607) [ 1,  0,  0,  0,  0, -1,  0, -1,  0] [ 6,  6,  6] -1 */
    52556860, /* 65268 (1607) [-1,  0,  0,  0,  0, -1,  0, -1,  0] [ 6,  6,  6] -1 */
    52562812, /* 65269 (1607) [ 0,  0, -1,  0,  1,  0,  1,  0,  0] [ 6,  6,  6] -1 */
    34028546, /* 65270 (1607) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    52556914, /* 65271 (1607) [-1,  0,  0,  0,  0,  1,  0, -1,  0] [ 6,  6,  6] -1 */
    18552028, /* 65272 (1607) [ 0,  0,  1,  0,  1,  0, -1,  0,  0] [ 6,  6,  6]  1 */
    18553172, /* 65273 (1607) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    34022548, /* 65274 (1607) [ 0,  0,  1, -1,  0,  0,  0, -1,  0] [ 0,  0,  0] -1 */
    18557812, /* 65275 (1607) [ 1,  0,  0,  0,  0,  1,  0, -1,  0] [ 6,  6,  6]  1 */
    18551866, /* 65276 (1607) [ 0,  0,  1,  0, -1,  0, -1,  0,  0] [ 6,  6,  6]  1 */
        7672, /* 65277 (1607) [ 0, -1,  0,  0,  0,  1, -1,  0,  0] [ 0,  0,  0]  1 */
       10330, /* 65278 (1607) [ 0,  0,  1, -1,  0,  0,  0,  1,  0] [ 0,  0,  0]  1 */
        3360, /* 65279 (1607) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
       12010, /* 65280 (1607) [ 0,  1,  0,  0,  0, -1,  1,  0,  0] [ 0,  0,  0]  1 */
       12046, /* 65281 (1607) [ 0,  1,  0,  0,  0,  1, -1,  0,  0] [ 0,  0,  0]  1 */
        3362, /* 65282 (1607) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    18552046, /* 65283 (1607) [ 0,  0,  1,  0,  1,  0,  1,  0,  0] [ 6,  6,  6]  1 */
        7618, /* 65284 (1607) [ 0, -1,  0,  0,  0, -1, -1,  0,  0] [ 0,  0,  0]  1 */
    52562650, /* 65285 (1607) [ 0,  0, -1,  0, -1,  0,  1,  0,  0] [ 6,  6,  6] -1 */
    18557764, /* 65286 (1607) [ 1,  0,  0,  0,  0, -1,  0,  1,  0] [ 6,  6,  6]  1 */
    18551884, /* 65287 (1607) [ 0,  0,  1,  0, -1,  0,  1,  0,  0] [ 6,  6,  6]  1 */
    34021576, /* 65288 (1607) [ 0,  0, -1,  1,  0,  0,  0, -1,  0] [ 0,  0,  0] -1 */
    18550408, /* 65289 (1607) [ 0,  0, -1,  0, -1,  0, -1,  0,  0] [ 6,  6,  6]  1 */
        7690, /* 65290 (1607) [ 0, -1,  0,  0,  0,  1,  1,  0,  0] [ 0,  0,  0]  1 */
    34021096, /* 65291 (1607) [ 0,  0, -1, -1,  0,  0,  0,  1,  0] [ 0,  0,  0] -1 */
       10810, /* 65292 (1607) [ 0,  0,  1,  1,  0,  0,  0, -1,  0] [ 0,  0,  0]  1 */
    52561508, /* 65293 (1607) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    52556920, /* 65294 (1607) [-1,  0,  0,  0,  0,  1,  0,  1,  0] [ 6,  6,  6] -1 */
        7636, /* 65295 (1607) [ 0, -1,  0,  0,  0, -1,  1,  0,  0] [ 0,  0,  0]  1 */
    18549282, /* 65296 (1607) [ 0, -1,  0,  1,  0,  0,  0,  0, -1] [ 6,  6,  6]  1 */
    34024216, /* 65297 (1607) [ 0,  1,  0,  0,  0, -1, -1,  0,  0] [ 0,  0,  0] -1 */
    18557758, /* 65298 (1607) [ 1,  0,  0,  0,  0, -1,  0, -1,  0] [ 6,  6,  6]  1 */
    18544636, /* 65299 (1607) [-1,  0,  0,  0,  0, -1,  0, -1,  0] [ 6,  6,  6]  1 */
    52565880, /* 65300 (1607) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 6,  6,  6] -1 */
       16322, /* 65301 (1607) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
        3200, /* 65302 (1607) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
        9358, /* 65303 (1607) [ 0,  0, -1,  1,  0,  0,  0,  1,  0] [ 0,  0,  0]  1 */
    18544690, /* 65304 (1607) [-1,  0,  0,  0,  0,  1,  0, -1,  0] [ 6,  6,  6]  1 */
    34021090, /* 65305 (1607) [ 0,  0, -1, -1,  0,  0,  0, -1,  0] [ 0,  0,  0] -1 */
       16482, /* 65306 (1607) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
       16484, /* 65307 (1608) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    18544642, /* 65308 (1608) [-1,  0,  0,  0,  0, -1,  0,  1,  0] [ 6,  6,  6]  1 */
       16320, /* 65309 (1608) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    52564252, /* 65310 (1608) [ 0,  0,  1,  0,  1,  0, -1,  0,  0] [ 6,  6,  6] -1 */
    52565396, /* 65311 (1608) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    52556860, /* 65312 (1608) [-1,  0,  0,  0,  0, -1,  0, -1,  0] [ 6,  6,  6] -1 */
    52561508, /* 65313 (1608) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    18550570, /* 65314 (1608) [ 0,  0, -1,  0,  1,  0, -1,  0,  0] [ 6,  6,  6]  1 */
    52570036, /* 65315 (1608) [ 1,  0,  0,  0,  0,  1,  0, -1,  0] [ 6,  6,  6] -1 */
    52556920, /* 65316 (1608) [-1,  0,  0,  0,  0,  1,  0,  1,  0] [ 6,  6,  6] -1 */
    52562812, /* 65317 (1608) [ 0,  0, -1,  0,  1,  0,  1,  0,  0] [ 6,  6,  6] -1 */
    34022554, /* 65318 (1608) [ 0,  0,  1, -1,  0,  0,  0,  1,  0] [ 0,  0,  0] -1 */
        7636, /* 65319 (1608) [ 0, -1,  0,  0,  0, -1,  1,  0,  0] [ 0,  0,  0]  1 */
    18549282, /* 65320 (1608) [ 0, -1,  0,  1,  0,  0,  0,  0, -1] [ 6,  6,  6]  1 */
    18550426, /* 65321 (1608) [ 0,  0, -1,  0, -1,  0,  1,  0,  0] [ 6,  6,  6]  1 */
    34024234, /* 65322 (1608) [ 0,  1,  0,  0,  0, -1,  1,  0,  0] [ 0,  0,  0] -1 */
        9352, /* 65323 (1608) [ 0,  0, -1,  1,  0,  0,  0, -1,  0] [ 0,  0,  0]  1 */
    34024270, /* 65324 (1608) [ 0,  1,  0,  0,  0,  1, -1,  0,  0] [ 0,  0,  0] -1 */
    34028546, /* 65325 (1608) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    34021582, /* 65326 (1608) [ 0,  0, -1,  1,  0,  0,  0,  1,  0] [ 0,  0,  0] -1 */
    34019914, /* 65327 (1608) [ 0, -1,  0,  0,  0,  1,  1,  0,  0] [ 0,  0,  0] -1 */
    18553170, /* 65328 (1608) [ 0,  1,  0, -1,  0,  0,  0,  0, -1] [ 6,  6,  6]  1 */
    34015586, /* 65329 (1608) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
        8872, /* 65330 (1608) [ 0,  0, -1, -1,  0,  0,  0,  1,  0] [ 0,  0,  0]  1 */
    18557758, /* 65331 (1608) [ 1,  0,  0,  0,  0, -1,  0, -1,  0] [ 6,  6,  6]  1 */
    34028706, /* 65332 (1608) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    34019842, /* 65333 (1608) [ 0, -1,  0,  0,  0, -1, -1,  0,  0] [ 0,  0,  0] -1 */
    18551866, /* 65334 (1608) [ 0,  0,  1,  0, -1,  0, -1,  0,  0] [ 6,  6,  6]  1 */
        7672, /* 65335 (1608) [ 0, -1,  0,  0,  0,  1, -1,  0,  0] [ 0,  0,  0]  1 */
    52569988, /* 65336 (1608) [ 1,  0,  0,  0,  0, -1,  0,  1,  0] [ 6,  6,  6] -1 */
        3360, /* 65337 (1608) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    52565880, /* 65338 (1608) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    18553658, /* 65339 (1608) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    52564108, /* 65340 (1608) [ 0,  0,  1,  0, -1,  0,  1,  0,  0] [ 6,  6,  6] -1 */
    34015422, /* 65341 (1608) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
       10816, /* 65342 (1608) [ 0,  0,  1,  1,  0,  0,  0,  1,  0] [ 0,  0,  0]  1 */
        3200, /* 65343 (1608) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    52562632, /* 65344 (1608) [ 0,  0, -1,  0, -1,  0, -1,  0,  0] [ 6,  6,  6] -1 */
    18544690, /* 65345 (1608) [-1,  0,  0,  0,  0,  1,  0, -1,  0] [ 6,  6,  6]  1 */
       11992, /* 65346 (1608) [ 0,  1,  0,  0,  0, -1, -1,  0,  0] [ 0,  0,  0]  1 */
       12064, /* 65347 (1608) [ 0,  1,  0,  0,  0,  1,  1,  0,  0] [ 0,  0,  0]  1 */
    34023034, /* 65348 (1608) [ 0,  0,  1,  1,  0,  0,  0, -1,  0] [ 0,  0,  0] -1 */
    18557818, /* 65349 (1608) [ 1,  0,  0,  0,  0,  1,  0,  1,  0] [ 6,  6,  6]  1 */
    34021090, /* 65350 (1608) [ 0,  0, -1, -1,  0,  0,  0, -1,  0] [ 0,  0,  0] -1 */
    18552046, /* 65351 (1608) [ 0,  0,  1,  0,  1,  0,  1,  0,  0] [ 6,  6,  6]  1 */
    52561020, /* 65352 (1608) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    18548798, /* 65353 (1608) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 6,  6,  6]  1 */
       10324, /* 65354 (1608) [ 0,  0,  1, -1,  0,  0,  0, -1,  0] [ 0,  0,  0]  1 */
       16484, /* 65355 (1609) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    52561506, /* 65356 (1609) [ 0, -1,  0,  1,  0,  0,  0,  0, -1] [ 6,  6,  6] -1 */
       16320, /* 65357 (1609) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
        3198, /* 65358 (1609) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    52565394, /* 65359 (1609) [ 0,  1,  0, -1,  0,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    52564252, /* 65360 (1609) [ 0,  0,  1,  0,  1,  0, -1,  0,  0] [ 6,  6,  6] -1 */
        7690, /* 65361 (1609) [ 0, -1,  0,  0,  0,  1,  1,  0,  0] [ 0,  0,  0]  1 */
    52569982, /* 65362 (1609) [ 1,  0,  0,  0,  0, -1,  0, -1,  0] [ 6,  6,  6] -1 */
        8866, /* 65363 (1609) [ 0,  0, -1, -1,  0,  0,  0, -1,  0] [ 0,  0,  0]  1 */
       10810, /* 65364 (1609) [ 0,  0,  1,  1,  0,  0,  0, -1,  0] [ 0,  0,  0]  1 */
    52565396, /* 65365 (1609) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    52556860, /* 65366 (1609) [-1,  0,  0,  0,  0, -1,  0, -1,  0] [ 6,  6,  6] -1 */
    52561508, /* 65367 (1609) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    52570036, /* 65368 (1609) [ 1,  0,  0,  0,  0,  1,  0, -1,  0] [ 6,  6,  6] -1 */
    52564090, /* 65369 (1609) [ 0,  0,  1,  0, -1,  0, -1,  0,  0] [ 6,  6,  6] -1 */
    52556920, /* 65370 (1609) [-1,  0,  0,  0,  0,  1,  0,  1,  0] [ 6,  6,  6] -1 */
    52562812, /* 65371 (1609) [ 0,  0, -1,  0,  1,  0,  1,  0,  0] [ 6,  6,  6] -1 */
        7636, /* 65372 (1609) [ 0, -1,  0,  0,  0, -1,  1,  0,  0] [ 0,  0,  0]  1 */
        9352, /* 65373 (1609) [ 0,  0, -1,  1,  0,  0,  0, -1,  0] [ 0,  0,  0]  1 */
    52565882, /* 65374 (1609) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    52556914, /* 65375 (1609) [-1,  0,  0,  0,  0,  1,  0, -1,  0] [ 6,  6,  6] -1 */
        8872, /* 65376 (1609) [ 0,  0, -1, -1,  0,  0,  0,  1,  0] [ 0,  0,  0]  1 */
    52570042, /* 65377 (1609) [ 1,  0,  0,  0,  0,  1,  0,  1,  0] [ 6,  6,  6] -1 */
    52564270, /* 65378 (1609) [ 0,  0,  1,  0,  1,  0,  1,  0,  0] [ 6,  6,  6] -1 */
        7672, /* 65379 (1609) [ 0, -1,  0,  0,  0,  1, -1,  0,  0] [ 0,  0,  0]  1 */
    52561022, /* 65380 (1609) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 6,  6,  6] -1 */
       10330, /* 65381 (1609) [ 0,  0,  1, -1,  0,  0,  0,  1,  0] [ 0,  0,  0]  1 */
    52569988, /* 65382 (1609) [ 1,  0,  0,  0,  0, -1,  0,  1,  0] [ 6,  6,  6] -1 */
        3360, /* 65383 (1609) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    52565880, /* 65384 (1609) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    52556866, /* 65385 (1609) [-1,  0,  0,  0,  0, -1,  0,  1,  0] [ 6,  6,  6] -1 */
       12010, /* 65386 (1609) [ 0,  1,  0,  0,  0, -1,  1,  0,  0] [ 0,  0,  0]  1 */
       16322, /* 65387 (1609) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
       12046, /* 65388 (1609) [ 0,  1,  0,  0,  0,  1, -1,  0,  0] [ 0,  0,  0]  1 */
    52564108, /* 65389 (1609) [ 0,  0,  1,  0, -1,  0,  1,  0,  0] [ 6,  6,  6] -1 */
       10816, /* 65390 (1609) [ 0,  0,  1,  1,  0,  0,  0,  1,  0] [ 0,  0,  0]  1 */
        3200, /* 65391 (1609) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    52562632, /* 65392 (1609) [ 0,  0, -1,  0, -1,  0, -1,  0,  0] [ 6,  6,  6] -1 */
        3362, /* 65393 (1609) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
        9358, /* 65394 (1609) [ 0,  0, -1,  1,  0,  0,  0,  1,  0] [ 0,  0,  0]  1 */
       11992, /* 65395 (1609) [ 0,  1,  0,  0,  0, -1, -1,  0,  0] [ 0,  0,  0]  1 */
       12064, /* 65396 (1609) [ 0,  1,  0,  0,  0,  1,  1,  0,  0] [ 0,  0,  0]  1 */
    52562794, /* 65397 (1609) [ 0,  0, -1,  0,  1,  0, -1,  0,  0] [ 6,  6,  6] -1 */
        7618, /* 65398 (1609) [ 0, -1,  0,  0,  0, -1, -1,  0,  0] [ 0,  0,  0]  1 */
    52561020, /* 65399 (1609) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 6,  6,  6] -1 */
       16482, /* 65400 (1609) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
       10324, /* 65401 (1609) [ 0,  0,  1, -1,  0,  0,  0, -1,  0] [ 0,  0,  0]  1 */
    52562650, /* 65402 (1609) [ 0,  0, -1,  0, -1,  0,  1,  0,  0] [ 6,  6,  6] -1 */
       16484, /* 65403 (1610) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    18557764, /* 65404 (1610) [ 1,  0,  0,  0,  0, -1,  0,  1,  0] [ 6,  6,  6]  1 */
    52561506, /* 65405 (1610) [ 0, -1,  0,  1,  0,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    18551884, /* 65406 (1610) [ 0,  0,  1,  0, -1,  0,  1,  0,  0] [ 6,  6,  6]  1 */
    18553656, /* 65407 (1610) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 6,  6,  6]  1 */
       16320, /* 65408 (1610) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    18550408, /* 65409 (1610) [ 0,  0, -1,  0, -1,  0, -1,  0,  0] [ 6,  6,  6]  1 */
    52565394, /* 65410 (1610) [ 0,  1,  0, -1,  0,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    52569982, /* 65411 (1610) [ 1,  0,  0,  0,  0, -1,  0, -1,  0] [ 6,  6,  6] -1 */
    18548796, /* 65412 (1610) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 6,  6,  6]  1 */
    52564090, /* 65413 (1610) [ 0,  0,  1,  0, -1,  0, -1,  0,  0] [ 6,  6,  6] -1 */
        7636, /* 65414 (1610) [ 0, -1,  0,  0,  0, -1,  1,  0,  0] [ 0,  0,  0]  1 */
    34022554, /* 65415 (1610) [ 0,  0,  1, -1,  0,  0,  0,  1,  0] [ 0,  0,  0] -1 */
    34024234, /* 65416 (1610) [ 0,  1,  0,  0,  0, -1,  1,  0,  0] [ 0,  0,  0] -1 */
        9352, /* 65417 (1610) [ 0,  0, -1,  1,  0,  0,  0, -1,  0] [ 0,  0,  0]  1 */
    34024270, /* 65418 (1610) [ 0,  1,  0,  0,  0,  1, -1,  0,  0] [ 0,  0,  0] -1 */
    52565882, /* 65419 (1610) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    34028546, /* 65420 (1610) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    34021582, /* 65421 (1610) [ 0,  0, -1,  1,  0,  0,  0,  1,  0] [ 0,  0,  0] -1 */
    34015586, /* 65422 (1610) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    52556914, /* 65423 (1610) [-1,  0,  0,  0,  0,  1,  0, -1,  0] [ 6,  6,  6] -1 */
    18552028, /* 65424 (1610) [ 0,  0,  1,  0,  1,  0, -1,  0,  0] [ 6,  6,  6]  1 */
        8872, /* 65425 (1610) [ 0,  0, -1, -1,  0,  0,  0,  1,  0] [ 0,  0,  0]  1 */
    18553172, /* 65426 (1610) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    18544636, /* 65427 (1610) [-1,  0,  0,  0,  0, -1,  0, -1,  0] [ 6,  6,  6]  1 */
    34028706, /* 65428 (1610) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    52562794, /* 65429 (1610) [ 0,  0, -1,  0,  1,  0, -1,  0,  0] [ 6,  6,  6] -1 */
    18557812, /* 65430 (1610) [ 1,  0,  0,  0,  0,  1,  0, -1,  0] [ 6,  6,  6]  1 */
    34019842, /* 65431 (1610) [ 0, -1,  0,  0,  0, -1, -1,  0,  0] [ 0,  0,  0] -1 */
    52570042, /* 65432 (1610) [ 1,  0,  0,  0,  0,  1,  0,  1,  0] [ 6,  6,  6] -1 */
    18544696, /* 65433 (1610) [-1,  0,  0,  0,  0,  1,  0,  1,  0] [ 6,  6,  6]  1 */
    18549284, /* 65434 (1610) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    52561022, /* 65435 (1610) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 6,  6,  6] -1 */
        7672, /* 65436 (1610) [ 0, -1,  0,  0,  0,  1, -1,  0,  0] [ 0,  0,  0]  1 */
    52564270, /* 65437 (1610) [ 0,  0,  1,  0,  1,  0,  1,  0,  0] [ 6,  6,  6] -1 */
        3360, /* 65438 (1610) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    18550588, /* 65439 (1610) [ 0,  0, -1,  0,  1,  0,  1,  0,  0] [ 6,  6,  6]  1 */
    52556866, /* 65440 (1610) [-1,  0,  0,  0,  0, -1,  0,  1,  0] [ 6,  6,  6] -1 */
    34015422, /* 65441 (1610) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
       10816, /* 65442 (1610) [ 0,  0,  1,  1,  0,  0,  0,  1,  0] [ 0,  0,  0]  1 */
        3200, /* 65443 (1610) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
       11992, /* 65444 (1610) [ 0,  1,  0,  0,  0, -1, -1,  0,  0] [ 0,  0,  0]  1 */
       12064, /* 65445 (1610) [ 0,  1,  0,  0,  0,  1,  1,  0,  0] [ 0,  0,  0]  1 */
    34023034, /* 65446 (1610) [ 0,  0,  1,  1,  0,  0,  0, -1,  0] [ 0,  0,  0] -1 */
    34019914, /* 65447 (1610) [ 0, -1,  0,  0,  0,  1,  1,  0,  0] [ 0,  0,  0] -1 */
    34021090, /* 65448 (1610) [ 0,  0, -1, -1,  0,  0,  0, -1,  0] [ 0,  0,  0] -1 */
       10324, /* 65449 (1610) [ 0,  0,  1, -1,  0,  0,  0, -1,  0] [ 0,  0,  0]  1 */
    52562650, /* 65450 (1610) [ 0,  0, -1,  0, -1,  0,  1,  0,  0] [ 6,  6,  6] -1 */
       16484, /* 65451 (1611) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    52562962, /* 65452 (1611) [ 0,  0, -1,  1,  0,  0,  0, -1,  0] [ 6,  6,  6] -1 */
       16320, /* 65453 (1611) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
        3198, /* 65454 (1611) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    52562968, /* 65455 (1611) [ 0,  0, -1,  1,  0,  0,  0,  1,  0] [ 6,  6,  6] -1 */
    34020120, /* 65456 (1611) [ 0, -1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    18550570, /* 65457 (1611) [ 0,  0, -1,  0,  1,  0, -1,  0,  0] [ 6,  6,  6]  1 */
    18548796, /* 65458 (1611) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 6,  6,  6]  1 */
    52565620, /* 65459 (1611) [ 0,  1,  0,  0,  0, -1,  1,  0,  0] [ 6,  6,  6] -1 */
    52565656, /* 65460 (1611) [ 0,  1,  0,  0,  0,  1, -1,  0,  0] [ 6,  6,  6] -1 */
    34020122, /* 65461 (1611) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 0,  0,  0] -1 */
        9352, /* 65462 (1611) [ 0,  0, -1,  1,  0,  0,  0, -1,  0] [ 0,  0,  0]  1 */
    52556972, /* 65463 (1611) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    34024496, /* 65464 (1611) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    52556810, /* 65465 (1611) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
        8872, /* 65466 (1611) [ 0,  0, -1, -1,  0,  0,  0,  1,  0] [ 0,  0,  0]  1 */
    52561228, /* 65467 (1611) [ 0, -1,  0,  0,  0, -1, -1,  0,  0] [ 6,  6,  6] -1 */
    18544696, /* 65468 (1611) [-1,  0,  0,  0,  0,  1,  0,  1,  0] [ 6,  6,  6]  1 */
    52570092, /* 65469 (1611) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    18550588, /* 65470 (1611) [ 0,  0, -1,  0,  1,  0,  1,  0,  0] [ 6,  6,  6]  1 */
    34024494, /* 65471 (1611) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    52564420, /* 65472 (1611) [ 0,  0,  1,  1,  0,  0,  0, -1,  0] [ 6,  6,  6] -1 */
    34021264, /* 65473 (1611) [ 0,  0, -1,  0, -1,  0,  1,  0,  0] [ 0,  0,  0] -1 */
    52561246, /* 65474 (1611) [ 0, -1,  0,  0,  0, -1,  1,  0,  0] [ 6,  6,  6] -1 */
       10324, /* 65475 (1611) [ 0,  0,  1, -1,  0,  0,  0, -1,  0] [ 0,  0,  0]  1 */
        8866, /* 65476 (1611) [ 0,  0, -1, -1,  0,  0,  0, -1,  0] [ 0,  0,  0]  1 */
    34024008, /* 65477 (1611) [ 0,  1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    52562482, /* 65478 (1611) [ 0,  0, -1, -1,  0,  0,  0,  1,  0] [ 6,  6,  6] -1 */
    34022866, /* 65479 (1611) [ 0,  0,  1,  0,  1,  0, -1,  0,  0] [ 0,  0,  0] -1 */
    18550426, /* 65480 (1611) [ 0,  0, -1,  0, -1,  0,  1,  0,  0] [ 6,  6,  6]  1 */
    34028650, /* 65481 (1611) [ 1,  0,  0,  0,  0,  1,  0, -1,  0] [ 0,  0,  0] -1 */
    18553170, /* 65482 (1611) [ 0,  1,  0, -1,  0,  0,  0,  0, -1] [ 6,  6,  6]  1 */
    34019636, /* 65483 (1611) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    18549284, /* 65484 (1611) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    34022884, /* 65485 (1611) [ 0,  0,  1,  0,  1,  0,  1,  0,  0] [ 0,  0,  0] -1 */
    52569930, /* 65486 (1611) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    18553658, /* 65487 (1611) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    52556808, /* 65488 (1611) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    34028602, /* 65489 (1611) [ 1,  0,  0,  0,  0, -1,  0,  1,  0] [ 0,  0,  0] -1 */
       10816, /* 65490 (1611) [ 0,  0,  1,  1,  0,  0,  0,  1,  0] [ 0,  0,  0]  1 */
       11992, /* 65491 (1611) [ 0,  1,  0,  0,  0, -1, -1,  0,  0] [ 0,  0,  0]  1 */
       12064, /* 65492 (1611) [ 0,  1,  0,  0,  0,  1,  1,  0,  0] [ 0,  0,  0]  1 */
    18557818, /* 65493 (1611) [ 1,  0,  0,  0,  0,  1,  0,  1,  0] [ 6,  6,  6]  1 */
    18548798, /* 65494 (1611) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    18544642, /* 65495 (1611) [-1,  0,  0,  0,  0, -1,  0,  1,  0] [ 6,  6,  6]  1 */
    18553656, /* 65496 (1611) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 6,  6,  6]  1 */
    34022704, /* 65497 (1611) [ 0,  0,  1,  0, -1,  0, -1,  0,  0] [ 0,  0,  0] -1 */
    52563940, /* 65498 (1611) [ 0,  0,  1, -1,  0,  0,  0,  1,  0] [ 6,  6,  6] -1 */
    34015474, /* 65499 (1611) [-1,  0,  0,  0,  0, -1,  0, -1,  0] [ 0,  0,  0] -1 */
    18552028, /* 65500 (1611) [ 0,  0,  1,  0,  1,  0, -1,  0,  0] [ 6,  6,  6]  1 */
    34015528, /* 65501 (1611) [-1,  0,  0,  0,  0,  1,  0, -1,  0] [ 0,  0,  0] -1 */
    18553172, /* 65502 (1611) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    52563934, /* 65503 (1611) [ 0,  0,  1, -1,  0,  0,  0, -1,  0] [ 6,  6,  6] -1 */
    18557812, /* 65504 (1611) [ 1,  0,  0,  0,  0,  1,  0, -1,  0] [ 6,  6,  6]  1 */
    18551866, /* 65505 (1611) [ 0,  0,  1,  0, -1,  0, -1,  0,  0] [ 6,  6,  6]  1 */
        7672, /* 65506 (1611) [ 0, -1,  0,  0,  0,  1, -1,  0,  0] [ 0,  0,  0]  1 */
    34022722, /* 65507 (1611) [ 0,  0,  1,  0, -1,  0,  1,  0,  0] [ 0,  0,  0] -1 */
       10330, /* 65508 (1611) [ 0,  0,  1, -1,  0,  0,  0,  1,  0] [ 0,  0,  0]  1 */
        3360, /* 65509 (1611) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
       12010, /* 65510 (1611) [ 0,  1,  0,  0,  0, -1,  1,  0,  0] [ 0,  0,  0]  1 */
       12046, /* 65511 (1611) [ 0,  1,  0,  0,  0,  1, -1,  0,  0] [ 0,  0,  0]  1 */
    34021246, /* 65512 (1611) [ 0,  0, -1,  0, -1,  0, -1,  0,  0] [ 0,  0,  0] -1 */
        3362, /* 65513 (1611) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    52562476, /* 65514 (1611) [ 0,  0, -1, -1,  0,  0,  0, -1,  0] [ 6,  6,  6] -1 */
    52561300, /* 65515 (1611) [ 0, -1,  0,  0,  0,  1,  1,  0,  0] [ 6,  6,  6] -1 */
    34028656, /* 65516 (1611) [ 1,  0,  0,  0,  0,  1,  0,  1,  0] [ 0,  0,  0] -1 */
    18552046, /* 65517 (1611) [ 0,  0,  1,  0,  1,  0,  1,  0,  0] [ 6,  6,  6]  1 */
        7618, /* 65518 (1611) [ 0, -1,  0,  0,  0, -1, -1,  0,  0] [ 0,  0,  0]  1 */
    34015480, /* 65519 (1611) [-1,  0,  0,  0,  0, -1,  0,  1,  0] [ 0,  0,  0] -1 */
    34021408, /* 65520 (1611) [ 0,  0, -1,  0,  1,  0, -1,  0,  0] [ 0,  0,  0] -1 */
    18557764, /* 65521 (1611) [ 1,  0,  0,  0,  0, -1,  0,  1,  0] [ 6,  6,  6]  1 */
    34019634, /* 65522 (1611) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    18551884, /* 65523 (1611) [ 0,  0,  1,  0, -1,  0,  1,  0,  0] [ 6,  6,  6]  1 */
    52556970, /* 65524 (1611) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    18550408, /* 65525 (1611) [ 0,  0, -1,  0, -1,  0, -1,  0,  0] [ 6,  6,  6]  1 */
    52570094, /* 65526 (1611) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
        7690, /* 65527 (1611) [ 0, -1,  0,  0,  0,  1,  1,  0,  0] [ 0,  0,  0]  1 */
       10810, /* 65528 (1611) [ 0,  0,  1,  1,  0,  0,  0, -1,  0] [ 0,  0,  0]  1 */
    34024010, /* 65529 (1611) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    34028596, /* 65530 (1611) [ 1,  0,  0,  0,  0, -1,  0, -1,  0] [ 0,  0,  0] -1 */
    52569932, /* 65531 (1611) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    18549282, /* 65532 (1611) [ 0, -1,  0,  1,  0,  0,  0,  0, -1] [ 6,  6,  6]  1 */
        7636, /* 65533 (1611) [ 0, -1,  0,  0,  0, -1,  1,  0,  0] [ 0,  0,  0]  1 */
    34015534, /* 65534 (1611) [-1,  0,  0,  0,  0,  1,  0,  1,  0] [ 0,  0,  0] -1 */
    52561282, /* 65535 (1611) [ 0, -1,  0,  0,  0,  1, -1,  0,  0] [ 6,  6,  6] -1 */
    34021426, /* 65536 (1611) [ 0,  0, -1,  0,  1,  0,  1,  0,  0] [ 0,  0,  0] -1 */
    52565602, /* 65537 (1611) [ 0,  1,  0,  0,  0, -1, -1,  0,  0] [ 6,  6,  6] -1 */
    52565674, /* 65538 (1611) [ 0,  1,  0,  0,  0,  1,  1,  0,  0] [ 6,  6,  6] -1 */
    18557758, /* 65539 (1611) [ 1,  0,  0,  0,  0, -1,  0, -1,  0] [ 6,  6,  6]  1 */
    52564426, /* 65540 (1611) [ 0,  0,  1,  1,  0,  0,  0,  1,  0] [ 6,  6,  6] -1 */
    18544636, /* 65541 (1611) [-1,  0,  0,  0,  0, -1,  0, -1,  0] [ 6,  6,  6]  1 */
       16322, /* 65542 (1611) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
        3200, /* 65543 (1611) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
        9358, /* 65544 (1611) [ 0,  0, -1,  1,  0,  0,  0,  1,  0] [ 0,  0,  0]  1 */
    18544690, /* 65545 (1611) [-1,  0,  0,  0,  0,  1,  0, -1,  0] [ 6,  6,  6]  1 */
       16482, /* 65546 (1611) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
       16484, /* 65547 (1612) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
        7896, /* 65548 (1612) [ 0, -1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    18553172, /* 65549 (1612) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 6,  6,  6]  1 */
       10480, /* 65550 (1612) [ 0,  0,  1,  0, -1,  0, -1,  0,  0] [ 0,  0,  0]  1 */
       10660, /* 65551 (1612) [ 0,  0,  1,  0,  1,  0,  1,  0,  0] [ 0,  0,  0]  1 */
    18549284, /* 65552 (1612) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 6,  6,  6]  1 */
       11784, /* 65553 (1612) [ 0,  1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  0]  1 */
        3360, /* 65554 (1612) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    18550408, /* 65555 (1612) [ 0,  0, -1,  0, -1,  0, -1,  0,  0] [ 6,  6,  6]  1 */
    18551716, /* 65556 (1612) [ 0,  0,  1, -1,  0,  0,  0,  1,  0] [ 6,  6,  6]  1 */
    18553396, /* 65557 (1612) [ 0,  1,  0,  0,  0, -1,  1,  0,  0] [ 6,  6,  6]  1 */
    18544748, /* 65558 (1612) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
       16372, /* 65559 (1612) [ 1,  0,  0,  0,  0, -1,  0, -1,  0] [ 0,  0,  0]  1 */
    18544584, /* 65560 (1612) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
       10324, /* 65561 (1612) [ 0,  0,  1, -1,  0,  0,  0, -1,  0] [ 0,  0,  0]  1 */
        3304, /* 65562 (1612) [-1,  0,  0,  0,  0,  1,  0, -1,  0] [ 0,  0,  0]  1 */
       11992, /* 65563 (1612) [ 0,  1,  0,  0,  0, -1, -1,  0,  0] [ 0,  0,  0]  1 */
        7672, /* 65564 (1612) [ 0, -1,  0,  0,  0,  1, -1,  0,  0] [ 0,  0,  0]  1 */
    18557708, /* 65565 (1612) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
       16432, /* 65566 (1612) [ 1,  0,  0,  0,  0,  1,  0,  1,  0] [ 0,  0,  0]  1 */
    18552196, /* 65567 (1612) [ 0,  0,  1,  1,  0,  0,  0, -1,  0] [ 6,  6,  6]  1 */
    18544696, /* 65568 (1612) [-1,  0,  0,  0,  0,  1,  0,  1,  0] [ 6,  6,  6]  1 */
    18550252, /* 65569 (1612) [ 0,  0, -1, -1,  0,  0,  0, -1,  0] [ 6,  6,  6]  1 */
        9040, /* 65570 (1612) [ 0,  0, -1,  0, -1,  0,  1,  0,  0] [ 0,  0,  0]  1 */
    18548796, /* 65571 (1612) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 6,  6,  6]  1 */
        7636, /* 65572 (1612) [ 0, -1,  0,  0,  0, -1,  1,  0,  0] [ 0,  0,  0]  1 */
    18551884, /* 65573 (1612) [ 0,  0,  1,  0, -1,  0,  1,  0,  0] [ 6,  6,  6]  1 */
    18557764, /* 65574 (1612) [ 1,  0,  0,  0,  0, -1,  0,  1,  0] [ 6,  6,  6]  1 */
       16320, /* 65575 (1612) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
        8872, /* 65576 (1612) [ 0,  0, -1, -1,  0,  0,  0,  1,  0] [ 0,  0,  0]  1 */
    18557812, /* 65577 (1612) [ 1,  0,  0,  0,  0,  1,  0, -1,  0] [ 6,  6,  6]  1 */
    18552028, /* 65578 (1612) [ 0,  0,  1,  0,  1,  0, -1,  0,  0] [ 6,  6,  6]  1 */
    18544636, /* 65579 (1612) [-1,  0,  0,  0,  0, -1,  0, -1,  0] [ 6,  6,  6]  1 */
    18549076, /* 65580 (1612) [ 0, -1,  0,  0,  0,  1,  1,  0,  0] [ 6,  6,  6]  1 */
    18553432, /* 65581 (1612) [ 0,  1,  0,  0,  0,  1, -1,  0,  0] [ 6,  6,  6]  1 */
        3200, /* 65582 (1612) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
        9184, /* 65583 (1612) [ 0,  0, -1,  0,  1,  0, -1,  0,  0] [ 0,  0,  0]  1 */
       10816, /* 65584 (1612) [ 0,  0,  1,  1,  0,  0,  0,  1,  0] [ 0,  0,  0]  1 */
        3256, /* 65585 (1612) [-1,  0,  0,  0,  0, -1,  0,  1,  0] [ 0,  0,  0]  1 */
        9352, /* 65586 (1612) [ 0,  0, -1,  1,  0,  0,  0, -1,  0] [ 0,  0,  0]  1 */
       12272, /* 65587 (1612) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 0,  0,  0]  1 */
       12064, /* 65588 (1612) [ 0,  1,  0,  0,  0,  1,  1,  0,  0] [ 0,  0,  0]  1 */
        7412, /* 65589 (1612) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    18550588, /* 65590 (1612) [ 0,  0, -1,  0,  1,  0,  1,  0,  0] [ 6,  6,  6]  1 */
    18557868, /* 65591 (1612) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
    18549004, /* 65592 (1612) [ 0, -1,  0,  0,  0, -1, -1,  0,  0] [ 6,  6,  6]  1 */
    18550744, /* 65593 (1612) [ 0,  0, -1,  1,  0,  0,  0,  1,  0] [ 6,  6,  6]  1 */
    18553656, /* 65594 (1612) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 6,  6,  6]  1 */
       16484, /* 65595 (1613) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
       10660, /* 65596 (1613) [ 0,  0,  1,  0,  1,  0,  1,  0,  0] [ 0,  0,  0]  1 */
       10480, /* 65597 (1613) [ 0,  0,  1,  0, -1,  0, -1,  0,  0] [ 0,  0,  0]  1 */
    18550408, /* 65598 (1613) [ 0,  0, -1,  0, -1,  0, -1,  0,  0] [ 6,  6,  6]  1 */
    18553396, /* 65599 (1613) [ 0,  1,  0,  0,  0, -1,  1,  0,  0] [ 6,  6,  6]  1 */
    18544584, /* 65600 (1613) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
       10324, /* 65601 (1613) [ 0,  0,  1, -1,  0,  0,  0, -1,  0] [ 0,  0,  0]  1 */
    18557708, /* 65602 (1613) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
       16432, /* 65603 (1613) [ 1,  0,  0,  0,  0,  1,  0,  1,  0] [ 0,  0,  0]  1 */
    18548796, /* 65604 (1613) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 6,  6,  6]  1 */
    18551884, /* 65605 (1613) [ 0,  0,  1,  0, -1,  0,  1,  0,  0] [ 6,  6,  6]  1 */
    34024496, /* 65606 (1613) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    34023040, /* 65607 (1613) [ 0,  0,  1,  1,  0,  0,  0,  1,  0] [ 0,  0,  0] -1 */
        8872, /* 65608 (1613) [ 0,  0, -1, -1,  0,  0,  0,  1,  0] [ 0,  0,  0]  1 */
    34024288, /* 65609 (1613) [ 0,  1,  0,  0,  0,  1,  1,  0,  0] [ 0,  0,  0] -1 */
    52565880, /* 65610 (1613) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    18544636, /* 65611 (1613) [-1,  0,  0,  0,  0, -1,  0, -1,  0] [ 6,  6,  6]  1 */
    52561508, /* 65612 (1613) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    34024008, /* 65613 (1613) [ 0,  1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    52563940, /* 65614 (1613) [ 0,  0,  1, -1,  0,  0,  0,  1,  0] [ 6,  6,  6] -1 */
    34015584, /* 65615 (1613) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
        9352, /* 65616 (1613) [ 0,  0, -1,  1,  0,  0,  0, -1,  0] [ 0,  0,  0]  1 */
    34024216, /* 65617 (1613) [ 0,  1,  0,  0,  0, -1, -1,  0,  0] [ 0,  0,  0] -1 */
    52564420, /* 65618 (1613) [ 0,  0,  1,  1,  0,  0,  0, -1,  0] [ 6,  6,  6] -1 */
    34019860, /* 65619 (1613) [ 0, -1,  0,  0,  0, -1,  1,  0,  0] [ 0,  0,  0] -1 */
    18553172, /* 65620 (1613) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 6,  6,  6]  1 */
       16372, /* 65621 (1613) [ 1,  0,  0,  0,  0, -1,  0, -1,  0] [ 0,  0,  0]  1 */
        3304, /* 65622 (1613) [-1,  0,  0,  0,  0,  1,  0, -1,  0] [ 0,  0,  0]  1 */
    18550252, /* 65623 (1613) [ 0,  0, -1, -1,  0,  0,  0, -1,  0] [ 6,  6,  6]  1 */
    52564252, /* 65624 (1613) [ 0,  0,  1,  0,  1,  0, -1,  0,  0] [ 6,  6,  6] -1 */
    52561300, /* 65625 (1613) [ 0, -1,  0,  0,  0,  1,  1,  0,  0] [ 6,  6,  6] -1 */
    52565656, /* 65626 (1613) [ 0,  1,  0,  0,  0,  1, -1,  0,  0] [ 6,  6,  6] -1 */
    34015424, /* 65627 (1613) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    34028708, /* 65628 (1613) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    34021408, /* 65629 (1613) [ 0,  0, -1,  0,  1,  0, -1,  0,  0] [ 0,  0,  0] -1 */
    18557764, /* 65630 (1613) [ 1,  0,  0,  0,  0, -1,  0,  1,  0] [ 6,  6,  6]  1 */
    34019636, /* 65631 (1613) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    52570092, /* 65632 (1613) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    52561228, /* 65633 (1613) [ 0, -1,  0,  0,  0, -1, -1,  0,  0] [ 6,  6,  6] -1 */
    34015480, /* 65634 (1613) [-1,  0,  0,  0,  0, -1,  0,  1,  0] [ 0,  0,  0] -1 */
    52562968, /* 65635 (1613) [ 0,  0, -1,  1,  0,  0,  0,  1,  0] [ 6,  6,  6] -1 */
    34022884, /* 65636 (1613) [ 0,  0,  1,  0,  1,  0,  1,  0,  0] [ 0,  0,  0] -1 */
       10816, /* 65637 (1613) [ 0,  0,  1,  1,  0,  0,  0,  1,  0] [ 0,  0,  0]  1 */
    52556808, /* 65638 (1613) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    52569932, /* 65639 (1613) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    52556972, /* 65640 (1613) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    34019896, /* 65641 (1613) [ 0, -1,  0,  0,  0,  1, -1,  0,  0] [ 0,  0,  0] -1 */
       12064, /* 65642 (1613) [ 0,  1,  0,  0,  0,  1,  1,  0,  0] [ 0,  0,  0]  1 */
        7896, /* 65643 (1613) [ 0, -1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  0]  1 */
        3360, /* 65644 (1613) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
       11992, /* 65645 (1613) [ 0,  1,  0,  0,  0, -1, -1,  0,  0] [ 0,  0,  0]  1 */
    34021096, /* 65646 (1613) [ 0,  0, -1, -1,  0,  0,  0,  1,  0] [ 0,  0,  0] -1 */
    18552196, /* 65647 (1613) [ 0,  0,  1,  1,  0,  0,  0, -1,  0] [ 6,  6,  6]  1 */
    34028544, /* 65648 (1613) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    18544696, /* 65649 (1613) [-1,  0,  0,  0,  0,  1,  0,  1,  0] [ 6,  6,  6]  1 */
    52570036, /* 65650 (1613) [ 1,  0,  0,  0,  0,  1,  0, -1,  0] [ 6,  6,  6] -1 */
        9040, /* 65651 (1613) [ 0,  0, -1,  0, -1,  0,  1,  0,  0] [ 0,  0,  0]  1 */
    52556860, /* 65652 (1613) [-1,  0,  0,  0,  0, -1,  0, -1,  0] [ 6,  6,  6] -1 */
    18552028, /* 65653 (1613) [ 0,  0,  1,  0,  1,  0, -1,  0,  0] [ 6,  6,  6]  1 */
    52562812, /* 65654 (1613) [ 0,  0, -1,  0,  1,  0,  1,  0,  0] [ 6,  6,  6] -1 */
    18553432, /* 65655 (1613) [ 0,  1,  0,  0,  0,  1, -1,  0,  0] [ 6,  6,  6]  1 */
    34022704, /* 65656 (1613) [ 0,  0,  1,  0, -1,  0, -1,  0,  0] [ 0,  0,  0] -1 */
        3200, /* 65657 (1613) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
        9184, /* 65658 (1613) [ 0,  0, -1,  0,  1,  0, -1,  0,  0] [ 0,  0,  0]  1 */
    34028596, /* 65659 (1613) [ 1,  0,  0,  0,  0, -1,  0, -1,  0] [ 0,  0,  0] -1 */
    52562632, /* 65660 (1613) [ 0,  0, -1,  0, -1,  0, -1,  0,  0] [ 6,  6,  6] -1 */
    52565620, /* 65661 (1613) [ 0,  1,  0,  0,  0, -1,  1,  0,  0] [ 6,  6,  6] -1 */
       12272, /* 65662 (1613) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34022548, /* 65663 (1613) [ 0,  0,  1, -1,  0,  0,  0, -1,  0] [ 0,  0,  0] -1 */
    34028656, /* 65664 (1613) [ 1,  0,  0,  0,  0,  1,  0,  1,  0] [ 0,  0,  0] -1 */
        7412, /* 65665 (1613) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    18557868, /* 65666 (1613) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
        3256, /* 65667 (1613) [-1,  0,  0,  0,  0, -1,  0,  1,  0] [ 0,  0,  0]  1 */
    18549004, /* 65668 (1613) [ 0, -1,  0,  0,  0, -1, -1,  0,  0] [ 6,  6,  6]  1 */
    18550744, /* 65669 (1613) [ 0,  0, -1,  1,  0,  0,  0,  1,  0] [ 6,  6,  6]  1 */
    18553656, /* 65670 (1613) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 6,  6,  6]  1 */
    52561020, /* 65671 (1613) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    18549284, /* 65672 (1613) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 6,  6,  6]  1 */
       11784, /* 65673 (1613) [ 0,  1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    52564108, /* 65674 (1613) [ 0,  0,  1,  0, -1,  0,  1,  0,  0] [ 6,  6,  6] -1 */
    18551716, /* 65675 (1613) [ 0,  0,  1, -1,  0,  0,  0,  1,  0] [ 6,  6,  6]  1 */
    18544748, /* 65676 (1613) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    52569988, /* 65677 (1613) [ 1,  0,  0,  0,  0, -1,  0,  1,  0] [ 6,  6,  6] -1 */
        7672, /* 65678 (1613) [ 0, -1,  0,  0,  0,  1, -1,  0,  0] [ 0,  0,  0]  1 */
        7636, /* 65679 (1613) [ 0, -1,  0,  0,  0, -1,  1,  0,  0] [ 0,  0,  0]  1 */
       16320, /* 65680 (1613) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    34021576, /* 65681 (1613) [ 0,  0, -1,  1,  0,  0,  0, -1,  0] [ 0,  0,  0] -1 */
    18557812, /* 65682 (1613) [ 1,  0,  0,  0,  0,  1,  0, -1,  0] [ 6,  6,  6]  1 */
    34020120, /* 65683 (1613) [ 0, -1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    18549076, /* 65684 (1613) [ 0, -1,  0,  0,  0,  1,  1,  0,  0] [ 6,  6,  6]  1 */
    52565396, /* 65685 (1613) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    34015528, /* 65686 (1613) [-1,  0,  0,  0,  0,  1,  0, -1,  0] [ 0,  0,  0] -1 */
    52556920, /* 65687 (1613) [-1,  0,  0,  0,  0,  1,  0,  1,  0] [ 6,  6,  6] -1 */
    34021264, /* 65688 (1613) [ 0,  0, -1,  0, -1,  0,  1,  0,  0] [ 0,  0,  0] -1 */
    18550588, /* 65689 (1613) [ 0,  0, -1,  0,  1,  0,  1,  0,  0] [ 6,  6,  6]  1 */
    52562476, /* 65690 (1613) [ 0,  0, -1, -1,  0,  0,  0, -1,  0] [ 6,  6,  6] -1 */
       16484, /* 65691 (1614) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
        7896, /* 65692 (1614) [ 0, -1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  0]  1 */
       10660, /* 65693 (1614) [ 0,  0,  1,  0,  1,  0,  1,  0,  0] [ 0,  0,  0]  1 */
       10480, /* 65694 (1614) [ 0,  0,  1,  0, -1,  0, -1,  0,  0] [ 0,  0,  0]  1 */
    52561020, /* 65695 (1614) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 6,  6,  6] -1 */
       11784, /* 65696 (1614) [ 0,  1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  0]  1 */
        3360, /* 65697 (1614) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    52564108, /* 65698 (1614) [ 0,  0,  1,  0, -1,  0,  1,  0,  0] [ 6,  6,  6] -1 */
       16372, /* 65699 (1614) [ 1,  0,  0,  0,  0, -1,  0, -1,  0] [ 0,  0,  0]  1 */
    52569988, /* 65700 (1614) [ 1,  0,  0,  0,  0, -1,  0,  1,  0] [ 6,  6,  6] -1 */
       10324, /* 65701 (1614) [ 0,  0,  1, -1,  0,  0,  0, -1,  0] [ 0,  0,  0]  1 */
        3304, /* 65702 (1614) [-1,  0,  0,  0,  0,  1,  0, -1,  0] [ 0,  0,  0]  1 */
       11992, /* 65703 (1614) [ 0,  1,  0,  0,  0, -1, -1,  0,  0] [ 0,  0,  0]  1 */
        7672, /* 65704 (1614) [ 0, -1,  0,  0,  0,  1, -1,  0,  0] [ 0,  0,  0]  1 */
       16432, /* 65705 (1614) [ 1,  0,  0,  0,  0,  1,  0,  1,  0] [ 0,  0,  0]  1 */
    52570036, /* 65706 (1614) [ 1,  0,  0,  0,  0,  1,  0, -1,  0] [ 6,  6,  6] -1 */
        9040, /* 65707 (1614) [ 0,  0, -1,  0, -1,  0,  1,  0,  0] [ 0,  0,  0]  1 */
    52564252, /* 65708 (1614) [ 0,  0,  1,  0,  1,  0, -1,  0,  0] [ 6,  6,  6] -1 */
    52556860, /* 65709 (1614) [-1,  0,  0,  0,  0, -1,  0, -1,  0] [ 6,  6,  6] -1 */
        7636, /* 65710 (1614) [ 0, -1,  0,  0,  0, -1,  1,  0,  0] [ 0,  0,  0]  1 */
    52561300, /* 65711 (1614) [ 0, -1,  0,  0,  0,  1,  1,  0,  0] [ 6,  6,  6] -1 */
    52565656, /* 65712 (1614) [ 0,  1,  0,  0,  0,  1, -1,  0,  0] [ 6,  6,  6] -1 */
       16320, /* 65713 (1614) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
        8872, /* 65714 (1614) [ 0,  0, -1, -1,  0,  0,  0,  1,  0] [ 0,  0,  0]  1 */
    52562812, /* 65715 (1614) [ 0,  0, -1,  0,  1,  0,  1,  0,  0] [ 6,  6,  6] -1 */
    52570092, /* 65716 (1614) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    52565880, /* 65717 (1614) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    52561228, /* 65718 (1614) [ 0, -1,  0,  0,  0, -1, -1,  0,  0] [ 6,  6,  6] -1 */
    52562968, /* 65719 (1614) [ 0,  0, -1,  1,  0,  0,  0,  1,  0] [ 6,  6,  6] -1 */
    52561508, /* 65720 (1614) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    52565396, /* 65721 (1614) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    52563940, /* 65722 (1614) [ 0,  0,  1, -1,  0,  0,  0,  1,  0] [ 6,  6,  6] -1 */
        3200, /* 65723 (1614) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
        9184, /* 65724 (1614) [ 0,  0, -1,  0,  1,  0, -1,  0,  0] [ 0,  0,  0]  1 */
    52562632, /* 65725 (1614) [ 0,  0, -1,  0, -1,  0, -1,  0,  0] [ 6,  6,  6] -1 */
       10816, /* 65726 (1614) [ 0,  0,  1,  1,  0,  0,  0,  1,  0] [ 0,  0,  0]  1 */
    52556808, /* 65727 (1614) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    52565620, /* 65728 (1614) [ 0,  1,  0,  0,  0, -1,  1,  0,  0] [ 6,  6,  6] -1 */
    52569932, /* 65729 (1614) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    52556972, /* 65730 (1614) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
        9352, /* 65731 (1614) [ 0,  0, -1,  1,  0,  0,  0, -1,  0] [ 0,  0,  0]  1 */
       12272, /* 65732 (1614) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    52556920, /* 65733 (1614) [-1,  0,  0,  0,  0,  1,  0,  1,  0] [ 6,  6,  6] -1 */
       12064, /* 65734 (1614) [ 0,  1,  0,  0,  0,  1,  1,  0,  0] [ 0,  0,  0]  1 */
        7412, /* 65735 (1614) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    52564420, /* 65736 (1614) [ 0,  0,  1,  1,  0,  0,  0, -1,  0] [ 6,  6,  6] -1 */
    52562476, /* 65737 (1614) [ 0,  0, -1, -1,  0,  0,  0, -1,  0] [ 6,  6,  6] -1 */
        3256, /* 65738 (1614) [-1,  0,  0,  0,  0, -1,  0,  1,  0] [ 0,  0,  0]  1 */
       16484, /* 65739 (1615) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    52561020, /* 65740 (1615) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 6,  6,  6] -1 */
        3360, /* 65741 (1615) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    52564108, /* 65742 (1615) [ 0,  0,  1,  0, -1,  0,  1,  0,  0] [ 6,  6,  6] -1 */
    18551716, /* 65743 (1615) [ 0,  0,  1, -1,  0,  0,  0,  1,  0] [ 6,  6,  6]  1 */
    18553396, /* 65744 (1615) [ 0,  1,  0,  0,  0, -1,  1,  0,  0] [ 6,  6,  6]  1 */
    18544748, /* 65745 (1615) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    18544584, /* 65746 (1615) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
       10324, /* 65747 (1615) [ 0,  0,  1, -1,  0,  0,  0, -1,  0] [ 0,  0,  0]  1 */
    52569988, /* 65748 (1615) [ 1,  0,  0,  0,  0, -1,  0,  1,  0] [ 6,  6,  6] -1 */
       11992, /* 65749 (1615) [ 0,  1,  0,  0,  0, -1, -1,  0,  0] [ 0,  0,  0]  1 */
        7672, /* 65750 (1615) [ 0, -1,  0,  0,  0,  1, -1,  0,  0] [ 0,  0,  0]  1 */
    18557708, /* 65751 (1615) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    18552196, /* 65752 (1615) [ 0,  0,  1,  1,  0,  0,  0, -1,  0] [ 6,  6,  6]  1 */
    18550252, /* 65753 (1615) [ 0,  0, -1, -1,  0,  0,  0, -1,  0] [ 6,  6,  6]  1 */
    52570036, /* 65754 (1615) [ 1,  0,  0,  0,  0,  1,  0, -1,  0] [ 6,  6,  6] -1 */
    52564252, /* 65755 (1615) [ 0,  0,  1,  0,  1,  0, -1,  0,  0] [ 6,  6,  6] -1 */
    52556860, /* 65756 (1615) [-1,  0,  0,  0,  0, -1,  0, -1,  0] [ 6,  6,  6] -1 */
        7636, /* 65757 (1615) [ 0, -1,  0,  0,  0, -1,  1,  0,  0] [ 0,  0,  0]  1 */
    34021408, /* 65758 (1615) [ 0,  0, -1,  0,  1,  0, -1,  0,  0] [ 0,  0,  0] -1 */
    34024496, /* 65759 (1615) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 0,  0,  0] -1 */
       16320, /* 65760 (1615) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
        8872, /* 65761 (1615) [ 0,  0, -1, -1,  0,  0,  0,  1,  0] [ 0,  0,  0]  1 */
    34019636, /* 65762 (1615) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    52562812, /* 65763 (1615) [ 0,  0, -1,  0,  1,  0,  1,  0,  0] [ 6,  6,  6] -1 */
    52565880, /* 65764 (1615) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    34015480, /* 65765 (1615) [-1,  0,  0,  0,  0, -1,  0,  1,  0] [ 0,  0,  0] -1 */
    34020120, /* 65766 (1615) [ 0, -1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    34022884, /* 65767 (1615) [ 0,  0,  1,  0,  1,  0,  1,  0,  0] [ 0,  0,  0] -1 */
    34024008, /* 65768 (1615) [ 0,  1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    52561508, /* 65769 (1615) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    18549076, /* 65770 (1615) [ 0, -1,  0,  0,  0,  1,  1,  0,  0] [ 6,  6,  6]  1 */
    52565396, /* 65771 (1615) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    34022704, /* 65772 (1615) [ 0,  0,  1,  0, -1,  0, -1,  0,  0] [ 0,  0,  0] -1 */
        3200, /* 65773 (1615) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    52562632, /* 65774 (1615) [ 0,  0, -1,  0, -1,  0, -1,  0,  0] [ 6,  6,  6] -1 */
    34028596, /* 65775 (1615) [ 1,  0,  0,  0,  0, -1,  0, -1,  0] [ 0,  0,  0] -1 */
       10816, /* 65776 (1615) [ 0,  0,  1,  1,  0,  0,  0,  1,  0] [ 0,  0,  0]  1 */
    18553432, /* 65777 (1615) [ 0,  1,  0,  0,  0,  1, -1,  0,  0] [ 6,  6,  6]  1 */
        9352, /* 65778 (1615) [ 0,  0, -1,  1,  0,  0,  0, -1,  0] [ 0,  0,  0]  1 */
    34015528, /* 65779 (1615) [-1,  0,  0,  0,  0,  1,  0, -1,  0] [ 0,  0,  0] -1 */
    34028656, /* 65780 (1615) [ 1,  0,  0,  0,  0,  1,  0,  1,  0] [ 0,  0,  0] -1 */
    52556920, /* 65781 (1615) [-1,  0,  0,  0,  0,  1,  0,  1,  0] [ 6,  6,  6] -1 */
       12064, /* 65782 (1615) [ 0,  1,  0,  0,  0,  1,  1,  0,  0] [ 0,  0,  0]  1 */
    34021264, /* 65783 (1615) [ 0,  0, -1,  0, -1,  0,  1,  0,  0] [ 0,  0,  0] -1 */
    18557868, /* 65784 (1615) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
    18549004, /* 65785 (1615) [ 0, -1,  0,  0,  0, -1, -1,  0,  0] [ 6,  6,  6]  1 */
    18550744, /* 65786 (1615) [ 0,  0, -1,  1,  0,  0,  0,  1,  0] [ 6,  6,  6]  1 */
       16484, /* 65787 (1616) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    18553172, /* 65788 (1616) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    18549284, /* 65789 (1616) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 6,  6,  6]  1 */
        3360, /* 65790 (1616) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    18550408, /* 65791 (1616) [ 0,  0, -1,  0, -1,  0, -1,  0,  0] [ 6,  6,  6]  1 */
       10324, /* 65792 (1616) [ 0,  0,  1, -1,  0,  0,  0, -1,  0] [ 0,  0,  0]  1 */
       11992, /* 65793 (1616) [ 0,  1,  0,  0,  0, -1, -1,  0,  0] [ 0,  0,  0]  1 */
        7672, /* 65794 (1616) [ 0, -1,  0,  0,  0,  1, -1,  0,  0] [ 0,  0,  0]  1 */
    18544696, /* 65795 (1616) [-1,  0,  0,  0,  0,  1,  0,  1,  0] [ 6,  6,  6]  1 */
    18548796, /* 65796 (1616) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 6,  6,  6]  1 */
        7636, /* 65797 (1616) [ 0, -1,  0,  0,  0, -1,  1,  0,  0] [ 0,  0,  0]  1 */
    52561300, /* 65798 (1616) [ 0, -1,  0,  0,  0,  1,  1,  0,  0] [ 6,  6,  6] -1 */
    18551884, /* 65799 (1616) [ 0,  0,  1,  0, -1,  0,  1,  0,  0] [ 6,  6,  6]  1 */
    52565656, /* 65800 (1616) [ 0,  1,  0,  0,  0,  1, -1,  0,  0] [ 6,  6,  6] -1 */
    34021408, /* 65801 (1616) [ 0,  0, -1,  0,  1,  0, -1,  0,  0] [ 0,  0,  0] -1 */
    34024496, /* 65802 (1616) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    18557764, /* 65803 (1616) [ 1,  0,  0,  0,  0, -1,  0,  1,  0] [ 6,  6,  6]  1 */
       16320, /* 65804 (1616) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
        8872, /* 65805 (1616) [ 0,  0, -1, -1,  0,  0,  0,  1,  0] [ 0,  0,  0]  1 */
    18557812, /* 65806 (1616) [ 1,  0,  0,  0,  0,  1,  0, -1,  0] [ 6,  6,  6]  1 */
    34019636, /* 65807 (1616) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    18552028, /* 65808 (1616) [ 0,  0,  1,  0,  1,  0, -1,  0,  0] [ 6,  6,  6]  1 */
    52570092, /* 65809 (1616) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    52561228, /* 65810 (1616) [ 0, -1,  0,  0,  0, -1, -1,  0,  0] [ 6,  6,  6] -1 */
    34020120, /* 65811 (1616) [ 0, -1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    34015480, /* 65812 (1616) [-1,  0,  0,  0,  0, -1,  0,  1,  0] [ 0,  0,  0] -1 */
    52562968, /* 65813 (1616) [ 0,  0, -1,  1,  0,  0,  0,  1,  0] [ 6,  6,  6] -1 */
    34022884, /* 65814 (1616) [ 0,  0,  1,  0,  1,  0,  1,  0,  0] [ 0,  0,  0] -1 */
    18544636, /* 65815 (1616) [-1,  0,  0,  0,  0, -1,  0, -1,  0] [ 6,  6,  6]  1 */
    34024008, /* 65816 (1616) [ 0,  1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    52563940, /* 65817 (1616) [ 0,  0,  1, -1,  0,  0,  0,  1,  0] [ 6,  6,  6] -1 */
    34022704, /* 65818 (1616) [ 0,  0,  1,  0, -1,  0, -1,  0,  0] [ 0,  0,  0] -1 */
        3200, /* 65819 (1616) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34028596, /* 65820 (1616) [ 1,  0,  0,  0,  0, -1,  0, -1,  0] [ 0,  0,  0] -1 */
    52556808, /* 65821 (1616) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
       10816, /* 65822 (1616) [ 0,  0,  1,  1,  0,  0,  0,  1,  0] [ 0,  0,  0]  1 */
    52565620, /* 65823 (1616) [ 0,  1,  0,  0,  0, -1,  1,  0,  0] [ 6,  6,  6] -1 */
    52569932, /* 65824 (1616) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    52556972, /* 65825 (1616) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
        9352, /* 65826 (1616) [ 0,  0, -1,  1,  0,  0,  0, -1,  0] [ 0,  0,  0]  1 */
    34015528, /* 65827 (1616) [-1,  0,  0,  0,  0,  1,  0, -1,  0] [ 0,  0,  0] -1 */
    34028656, /* 65828 (1616) [ 1,  0,  0,  0,  0,  1,  0,  1,  0] [ 0,  0,  0] -1 */
       12064, /* 65829 (1616) [ 0,  1,  0,  0,  0,  1,  1,  0,  0] [ 0,  0,  0]  1 */
    52564420, /* 65830 (1616) [ 0,  0,  1,  1,  0,  0,  0, -1,  0] [ 6,  6,  6] -1 */
    18550588, /* 65831 (1616) [ 0,  0, -1,  0,  1,  0,  1,  0,  0] [ 6,  6,  6]  1 */
    34021264, /* 65832 (1616) [ 0,  0, -1,  0, -1,  0,  1,  0,  0] [ 0,  0,  0] -1 */
    52562476, /* 65833 (1616) [ 0,  0, -1, -1,  0,  0,  0, -1,  0] [ 6,  6,  6] -1 */
    18553656, /* 65834 (1616) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 6,  6,  6]  1 */
       16484, /* 65835 (1617) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
       10660, /* 65836 (1617) [ 0,  0,  1,  0,  1,  0,  1,  0,  0] [ 0,  0,  0]  1 */
       10480, /* 65837 (1617) [ 0,  0,  1,  0, -1,  0, -1,  0,  0] [ 0,  0,  0]  1 */
    52562650, /* 65838 (1617) [ 0,  0, -1,  0, -1,  0,  1,  0,  0] [ 6,  6,  6] -1 */
    34022722, /* 65839 (1617) [ 0,  0,  1,  0, -1,  0,  1,  0,  0] [ 0,  0,  0] -1 */
    18550408, /* 65840 (1617) [ 0,  0, -1,  0, -1,  0, -1,  0,  0] [ 6,  6,  6]  1 */
    18553396, /* 65841 (1617) [ 0,  1,  0,  0,  0, -1,  1,  0,  0] [ 6,  6,  6]  1 */
    18544584, /* 65842 (1617) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
       10324, /* 65843 (1617) [ 0,  0,  1, -1,  0,  0,  0, -1,  0] [ 0,  0,  0]  1 */
    18557708, /* 65844 (1617) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
       16432, /* 65845 (1617) [ 1,  0,  0,  0,  0,  1,  0,  1,  0] [ 0,  0,  0]  1 */
    52564090, /* 65846 (1617) [ 0,  0,  1,  0, -1,  0, -1,  0,  0] [ 6,  6,  6] -1 */
    34021582, /* 65847 (1617) [ 0,  0, -1,  1,  0,  0,  0,  1,  0] [ 0,  0,  0] -1 */
    18548796, /* 65848 (1617) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 6,  6,  6]  1 */
    18551884, /* 65849 (1617) [ 0,  0,  1,  0, -1,  0,  1,  0,  0] [ 6,  6,  6]  1 */
    52565882, /* 65850 (1617) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    52562794, /* 65851 (1617) [ 0,  0, -1,  0,  1,  0, -1,  0,  0] [ 6,  6,  6] -1 */
    34024270, /* 65852 (1617) [ 0,  1,  0,  0,  0,  1, -1,  0,  0] [ 0,  0,  0] -1 */
    52556810, /* 65853 (1617) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
        8872, /* 65854 (1617) [ 0,  0, -1, -1,  0,  0,  0,  1,  0] [ 0,  0,  0]  1 */
    34019842, /* 65855 (1617) [ 0, -1,  0,  0,  0, -1, -1,  0,  0] [ 0,  0,  0] -1 */
    34022554, /* 65856 (1617) [ 0,  0,  1, -1,  0,  0,  0,  1,  0] [ 0,  0,  0] -1 */
    52569930, /* 65857 (1617) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    52556970, /* 65858 (1617) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    52570042, /* 65859 (1617) [ 1,  0,  0,  0,  0,  1,  0,  1,  0] [ 6,  6,  6] -1 */
    52561022, /* 65860 (1617) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    18544636, /* 65861 (1617) [-1,  0,  0,  0,  0, -1,  0, -1,  0] [ 6,  6,  6]  1 */
    34028706, /* 65862 (1617) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    34024494, /* 65863 (1617) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    34021246, /* 65864 (1617) [ 0,  0, -1,  0, -1,  0, -1,  0,  0] [ 0,  0,  0] -1 */
        9352, /* 65865 (1617) [ 0,  0, -1,  1,  0,  0,  0, -1,  0] [ 0,  0,  0]  1 */
    34023034, /* 65866 (1617) [ 0,  0,  1,  1,  0,  0,  0, -1,  0] [ 0,  0,  0] -1 */
    18553172, /* 65867 (1617) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    34019914, /* 65868 (1617) [ 0, -1,  0,  0,  0,  1,  1,  0,  0] [ 0,  0,  0] -1 */
       16372, /* 65869 (1617) [ 1,  0,  0,  0,  0, -1,  0, -1,  0] [ 0,  0,  0]  1 */
    52569982, /* 65870 (1617) [ 1,  0,  0,  0,  0, -1,  0, -1,  0] [ 6,  6,  6] -1 */
    52561246, /* 65871 (1617) [ 0, -1,  0,  0,  0, -1,  1,  0,  0] [ 6,  6,  6] -1 */
        3304, /* 65872 (1617) [-1,  0,  0,  0,  0,  1,  0, -1,  0] [ 0,  0,  0]  1 */
    34022866, /* 65873 (1617) [ 0,  0,  1,  0,  1,  0, -1,  0,  0] [ 0,  0,  0] -1 */
    18550252, /* 65874 (1617) [ 0,  0, -1, -1,  0,  0,  0, -1,  0] [ 6,  6,  6]  1 */
    34028650, /* 65875 (1617) [ 1,  0,  0,  0,  0,  1,  0, -1,  0] [ 0,  0,  0] -1 */
    52563934, /* 65876 (1617) [ 0,  0,  1, -1,  0,  0,  0, -1,  0] [ 6,  6,  6] -1 */
    18557764, /* 65877 (1617) [ 1,  0,  0,  0,  0, -1,  0,  1,  0] [ 6,  6,  6]  1 */
    52564270, /* 65878 (1617) [ 0,  0,  1,  0,  1,  0,  1,  0,  0] [ 6,  6,  6] -1 */
    34028546, /* 65879 (1617) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    52561282, /* 65880 (1617) [ 0, -1,  0,  0,  0,  1, -1,  0,  0] [ 6,  6,  6] -1 */
    34015422, /* 65881 (1617) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    34024234, /* 65882 (1617) [ 0,  1,  0,  0,  0, -1,  1,  0,  0] [ 0,  0,  0] -1 */
       10816, /* 65883 (1617) [ 0,  0,  1,  1,  0,  0,  0,  1,  0] [ 0,  0,  0]  1 */
       12064, /* 65884 (1617) [ 0,  1,  0,  0,  0,  1,  1,  0,  0] [ 0,  0,  0]  1 */
    34019634, /* 65885 (1617) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  0] -1 */
        7896, /* 65886 (1617) [ 0, -1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  0]  1 */
        3360, /* 65887 (1617) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    34028602, /* 65888 (1617) [ 1,  0,  0,  0,  0, -1,  0,  1,  0] [ 0,  0,  0] -1 */
       11992, /* 65889 (1617) [ 0,  1,  0,  0,  0, -1, -1,  0,  0] [ 0,  0,  0]  1 */
    18552196, /* 65890 (1617) [ 0,  0,  1,  1,  0,  0,  0, -1,  0] [ 6,  6,  6]  1 */
    18544696, /* 65891 (1617) [-1,  0,  0,  0,  0,  1,  0,  1,  0] [ 6,  6,  6]  1 */
    34015534, /* 65892 (1617) [-1,  0,  0,  0,  0,  1,  0,  1,  0] [ 0,  0,  0] -1 */
        9040, /* 65893 (1617) [ 0,  0, -1,  0, -1,  0,  1,  0,  0] [ 0,  0,  0]  1 */
    34015474, /* 65894 (1617) [-1,  0,  0,  0,  0, -1,  0, -1,  0] [ 0,  0,  0] -1 */
    34021426, /* 65895 (1617) [ 0,  0, -1,  0,  1,  0,  1,  0,  0] [ 0,  0,  0] -1 */
    52562962, /* 65896 (1617) [ 0,  0, -1,  1,  0,  0,  0, -1,  0] [ 6,  6,  6] -1 */
    52562482, /* 65897 (1617) [ 0,  0, -1, -1,  0,  0,  0,  1,  0] [ 6,  6,  6] -1 */
    52565602, /* 65898 (1617) [ 0,  1,  0,  0,  0, -1, -1,  0,  0] [ 6,  6,  6] -1 */
    18552028, /* 65899 (1617) [ 0,  0,  1,  0,  1,  0, -1,  0,  0] [ 6,  6,  6]  1 */
    34024010, /* 65900 (1617) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    18553432, /* 65901 (1617) [ 0,  1,  0,  0,  0,  1, -1,  0,  0] [ 6,  6,  6]  1 */
        3200, /* 65902 (1617) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
        9184, /* 65903 (1617) [ 0,  0, -1,  0,  1,  0, -1,  0,  0] [ 0,  0,  0]  1 */
       12272, /* 65904 (1617) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    52556914, /* 65905 (1617) [-1,  0,  0,  0,  0,  1,  0, -1,  0] [ 6,  6,  6] -1 */
    34021090, /* 65906 (1617) [ 0,  0, -1, -1,  0,  0,  0, -1,  0] [ 0,  0,  0] -1 */
        7412, /* 65907 (1617) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    52556866, /* 65908 (1617) [-1,  0,  0,  0,  0, -1,  0,  1,  0] [ 6,  6,  6] -1 */
    18557868, /* 65909 (1617) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
        3256, /* 65910 (1617) [-1,  0,  0,  0,  0, -1,  0,  1,  0] [ 0,  0,  0]  1 */
    18549004, /* 65911 (1617) [ 0, -1,  0,  0,  0, -1, -1,  0,  0] [ 6,  6,  6]  1 */
    18550744, /* 65912 (1617) [ 0,  0, -1,  1,  0,  0,  0,  1,  0] [ 6,  6,  6]  1 */
    18553656, /* 65913 (1617) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 6,  6,  6]  1 */
    18549284, /* 65914 (1617) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 6,  6,  6]  1 */
       11784, /* 65915 (1617) [ 0,  1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    52565394, /* 65916 (1617) [ 0,  1,  0, -1,  0,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    18551716, /* 65917 (1617) [ 0,  0,  1, -1,  0,  0,  0,  1,  0] [ 6,  6,  6]  1 */
    18544748, /* 65918 (1617) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
        7672, /* 65919 (1617) [ 0, -1,  0,  0,  0,  1, -1,  0,  0] [ 0,  0,  0]  1 */
    52570094, /* 65920 (1617) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    34020122, /* 65921 (1617) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    34015586, /* 65922 (1617) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
        7636, /* 65923 (1617) [ 0, -1,  0,  0,  0, -1,  1,  0,  0] [ 0,  0,  0]  1 */
    52565674, /* 65924 (1617) [ 0,  1,  0,  0,  0,  1,  1,  0,  0] [ 6,  6,  6] -1 */
    52561506, /* 65925 (1617) [ 0, -1,  0,  1,  0,  0,  0,  0, -1] [ 6,  6,  6] -1 */
       16320, /* 65926 (1617) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    18557812, /* 65927 (1617) [ 1,  0,  0,  0,  0,  1,  0, -1,  0] [ 6,  6,  6]  1 */
    52564426, /* 65928 (1617) [ 0,  0,  1,  1,  0,  0,  0,  1,  0] [ 6,  6,  6] -1 */
    18549076, /* 65929 (1617) [ 0, -1,  0,  0,  0,  1,  1,  0,  0] [ 6,  6,  6]  1 */
    18550588, /* 65930 (1617) [ 0,  0, -1,  0,  1,  0,  1,  0,  0] [ 6,  6,  6]  1 */
       16484, /* 65931 (1612) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    17132106, /* 65932 (1612) [ 0, -1,  0,  1,  0,  0,  0,  0, -1] [ 6,  0,  6]  1 */
    17135996, /* 65933 (1612) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 6,  0,  6]  1 */
     1545754, /* 65934 (1612) [ 0,  0,  1,  0, -1,  0, -1,  0,  0] [ 0,  6,  6]  1 */
       10660, /* 65935 (1612) [ 0,  0,  1,  0,  1,  0,  1,  0,  0] [ 0,  0,  0]  1 */
     1543172, /* 65936 (1612) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 0,  6,  6]  1 */
     1547058, /* 65937 (1612) [ 0,  1,  0, -1,  0,  0,  0,  0, -1] [ 0,  6,  6]  1 */
    17127570, /* 65938 (1612) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6]  1 */
        9022, /* 65939 (1612) [ 0,  0, -1,  0, -1,  0, -1,  0,  0] [ 0,  0,  0]  1 */
    17134540, /* 65940 (1612) [ 0,  0,  1, -1,  0,  0,  0,  1,  0] [ 6,  0,  6]  1 */
    17136220, /* 65941 (1612) [ 0,  1,  0,  0,  0, -1,  1,  0,  0] [ 6,  0,  6]  1 */
     1538636, /* 65942 (1612) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
     1551646, /* 65943 (1612) [ 1,  0,  0,  0,  0, -1,  0, -1,  0] [ 0,  6,  6]  1 */
        3198, /* 65944 (1612) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
     1545598, /* 65945 (1612) [ 0,  0,  1, -1,  0,  0,  0, -1,  0] [ 0,  6,  6]  1 */
    17127514, /* 65946 (1612) [-1,  0,  0,  0,  0,  1,  0, -1,  0] [ 6,  0,  6]  1 */
     1547266, /* 65947 (1612) [ 0,  1,  0,  0,  0, -1, -1,  0,  0] [ 0,  6,  6]  1 */
    17131882, /* 65948 (1612) [ 0, -1,  0,  0,  0,  1, -1,  0,  0] [ 6,  0,  6]  1 */
    17140532, /* 65949 (1612) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
       16432, /* 65950 (1612) [ 1,  0,  0,  0,  0,  1,  0,  1,  0] [ 0,  0,  0]  1 */
    18434098, /* 65951 (1612) [ 0,  0,  1,  1,  0,  0,  0, -1,  0] [ 6,  6,  0]  1 */
     1538584, /* 65952 (1612) [-1,  0,  0,  0,  0,  1,  0,  1,  0] [ 0,  6,  6]  1 */
        8866, /* 65953 (1612) [ 0,  0, -1, -1,  0,  0,  0, -1,  0] [ 0,  0,  0]  1 */
    18432328, /* 65954 (1612) [ 0,  0, -1,  0, -1,  0,  1,  0,  0] [ 6,  6,  0]  1 */
        7410, /* 65955 (1612) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    18430924, /* 65956 (1612) [ 0, -1,  0,  0,  0, -1,  1,  0,  0] [ 6,  6,  0]  1 */
    17134708, /* 65957 (1612) [ 0,  0,  1,  0, -1,  0,  1,  0,  0] [ 6,  0,  6]  1 */
    17140588, /* 65958 (1612) [ 1,  0,  0,  0,  0, -1,  0,  1,  0] [ 6,  0,  6]  1 */
     1551594, /* 65959 (1612) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
    18432160, /* 65960 (1612) [ 0,  0, -1, -1,  0,  0,  0,  1,  0] [ 6,  6,  0]  1 */
    18439714, /* 65961 (1612) [ 1,  0,  0,  0,  0,  1,  0, -1,  0] [ 6,  6,  0]  1 */
    18433930, /* 65962 (1612) [ 0,  0,  1,  0,  1,  0, -1,  0,  0] [ 6,  6,  0]  1 */
        3250, /* 65963 (1612) [-1,  0,  0,  0,  0, -1,  0, -1,  0] [ 0,  0,  0]  1 */
     1542964, /* 65964 (1612) [ 0, -1,  0,  0,  0,  1,  1,  0,  0] [ 0,  6,  6]  1 */
    18435334, /* 65965 (1612) [ 0,  1,  0,  0,  0,  1, -1,  0,  0] [ 6,  6,  0]  1 */
    18426488, /* 65966 (1612) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    17133394, /* 65967 (1612) [ 0,  0, -1,  0,  1,  0, -1,  0,  0] [ 6,  0,  6]  1 */
       10816, /* 65968 (1612) [ 0,  0,  1,  1,  0,  0,  0,  1,  0] [ 0,  0,  0]  1 */
    18426544, /* 65969 (1612) [-1,  0,  0,  0,  0, -1,  0,  1,  0] [ 6,  6,  0]  1 */
    17133562, /* 65970 (1612) [ 0,  0, -1,  1,  0,  0,  0, -1,  0] [ 6,  0,  6]  1 */
       12272, /* 65971 (1612) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 0,  0,  0]  1 */
       12064, /* 65972 (1612) [ 0,  1,  0,  0,  0,  1,  1,  0,  0] [ 0,  0,  0]  1 */
    18430700, /* 65973 (1612) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 6,  6,  0]  1 */
     1544476, /* 65974 (1612) [ 0,  0, -1,  0,  1,  0,  1,  0,  0] [ 0,  6,  6]  1 */
    18439770, /* 65975 (1612) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
        7618, /* 65976 (1612) [ 0, -1,  0,  0,  0, -1, -1,  0,  0] [ 0,  0,  0]  1 */
     1544632, /* 65977 (1612) [ 0,  0, -1,  1,  0,  0,  0,  1,  0] [ 0,  6,  6]  1 */
    18435558, /* 65978 (1612) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 6,  6,  0]  1 */
       16484, /* 65979 (1613) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
       10660, /* 65980 (1613) [ 0,  0,  1,  0,  1,  0,  1,  0,  0] [ 0,  0,  0]  1 */
     1545754, /* 65981 (1613) [ 0,  0,  1,  0, -1,  0, -1,  0,  0] [ 0,  6,  6]  1 */
        9022, /* 65982 (1613) [ 0,  0, -1,  0, -1,  0, -1,  0,  0] [ 0,  0,  0]  1 */
    17136220, /* 65983 (1613) [ 0,  1,  0,  0,  0, -1,  1,  0,  0] [ 6,  0,  6]  1 */
        3198, /* 65984 (1613) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
     1545598, /* 65985 (1613) [ 0,  0,  1, -1,  0,  0,  0, -1,  0] [ 0,  6,  6]  1 */
    17140532, /* 65986 (1613) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
       16432, /* 65987 (1613) [ 1,  0,  0,  0,  0,  1,  0,  1,  0] [ 0,  0,  0]  1 */
        7410, /* 65988 (1613) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    17134708, /* 65989 (1613) [ 0,  0,  1,  0, -1,  0,  1,  0,  0] [ 6,  0,  6]  1 */
    34024496, /* 65990 (1613) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    34023040, /* 65991 (1613) [ 0,  0,  1,  1,  0,  0,  0,  1,  0] [ 0,  0,  0] -1 */
    18432160, /* 65992 (1613) [ 0,  0, -1, -1,  0,  0,  0,  1,  0] [ 6,  6,  0]  1 */
    34024288, /* 65993 (1613) [ 0,  1,  0,  0,  0,  1,  1,  0,  0] [ 0,  0,  0] -1 */
    52447782, /* 65994 (1613) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 6,  6,  0] -1 */
        3250, /* 65995 (1613) [-1,  0,  0,  0,  0, -1,  0, -1,  0] [ 0,  0,  0]  1 */
    35555396, /* 65996 (1613) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 0,  6,  6] -1 */
    35559282, /* 65997 (1613) [ 0,  1,  0, -1,  0,  0,  0,  0, -1] [ 0,  6,  6] -1 */
    51146764, /* 65998 (1613) [ 0,  0,  1, -1,  0,  0,  0,  1,  0] [ 6,  0,  6] -1 */
    51139794, /* 65999 (1613) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6] -1 */
    17133562, /* 66000 (1613) [ 0,  0, -1,  1,  0,  0,  0, -1,  0] [ 6,  0,  6]  1 */
    35559490, /* 66001 (1613) [ 0,  1,  0,  0,  0, -1, -1,  0,  0] [ 0,  6,  6] -1 */
    52446322, /* 66002 (1613) [ 0,  0,  1,  1,  0,  0,  0, -1,  0] [ 6,  6,  0] -1 */
    52443148, /* 66003 (1613) [ 0, -1,  0,  0,  0, -1,  1,  0,  0] [ 6,  6,  0] -1 */
    17135996, /* 66004 (1613) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 6,  0,  6]  1 */
     1551646, /* 66005 (1613) [ 1,  0,  0,  0,  0, -1,  0, -1,  0] [ 0,  6,  6]  1 */
    17127514, /* 66006 (1613) [-1,  0,  0,  0,  0,  1,  0, -1,  0] [ 6,  0,  6]  1 */
        8866, /* 66007 (1613) [ 0,  0, -1, -1,  0,  0,  0, -1,  0] [ 0,  0,  0]  1 */
    52446154, /* 66008 (1613) [ 0,  0,  1,  0,  1,  0, -1,  0,  0] [ 6,  6,  0] -1 */
    35555188, /* 66009 (1613) [ 0, -1,  0,  0,  0,  1,  1,  0,  0] [ 0,  6,  6] -1 */
    52447558, /* 66010 (1613) [ 0,  1,  0,  0,  0,  1, -1,  0,  0] [ 6,  6,  0] -1 */
    52438712, /* 66011 (1613) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
    34028708, /* 66012 (1613) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    51145618, /* 66013 (1613) [ 0,  0, -1,  0,  1,  0, -1,  0,  0] [ 6,  0,  6] -1 */
    17140588, /* 66014 (1613) [ 1,  0,  0,  0,  0, -1,  0,  1,  0] [ 6,  0,  6]  1 */
    52442924, /* 66015 (1613) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 6,  6,  0] -1 */
    52451994, /* 66016 (1613) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
    34019842, /* 66017 (1613) [ 0, -1,  0,  0,  0, -1, -1,  0,  0] [ 0,  0,  0] -1 */
    52438768, /* 66018 (1613) [-1,  0,  0,  0,  0, -1,  0,  1,  0] [ 6,  6,  0] -1 */
    35556856, /* 66019 (1613) [ 0,  0, -1,  1,  0,  0,  0,  1,  0] [ 0,  6,  6] -1 */
    34022884, /* 66020 (1613) [ 0,  0,  1,  0,  1,  0,  1,  0,  0] [ 0,  0,  0] -1 */
       10816, /* 66021 (1613) [ 0,  0,  1,  1,  0,  0,  0,  1,  0] [ 0,  0,  0]  1 */
    34015422, /* 66022 (1613) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    51152756, /* 66023 (1613) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
    35550860, /* 66024 (1613) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
    51144106, /* 66025 (1613) [ 0, -1,  0,  0,  0,  1, -1,  0,  0] [ 6,  0,  6] -1 */
       12064, /* 66026 (1613) [ 0,  1,  0,  0,  0,  1,  1,  0,  0] [ 0,  0,  0]  1 */
    17132106, /* 66027 (1613) [ 0, -1,  0,  1,  0,  0,  0,  0, -1] [ 6,  0,  6]  1 */
    17127570, /* 66028 (1613) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6]  1 */
     1547266, /* 66029 (1613) [ 0,  1,  0,  0,  0, -1, -1,  0,  0] [ 0,  6,  6]  1 */
    52444384, /* 66030 (1613) [ 0,  0, -1, -1,  0,  0,  0,  1,  0] [ 6,  6,  0] -1 */
    18434098, /* 66031 (1613) [ 0,  0,  1,  1,  0,  0,  0, -1,  0] [ 6,  6,  0]  1 */
    35563818, /* 66032 (1613) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  6] -1 */
     1538584, /* 66033 (1613) [-1,  0,  0,  0,  0,  1,  0,  1,  0] [ 0,  6,  6]  1 */
    52451938, /* 66034 (1613) [ 1,  0,  0,  0,  0,  1,  0, -1,  0] [ 6,  6,  0] -1 */
    18432328, /* 66035 (1613) [ 0,  0, -1,  0, -1,  0,  1,  0,  0] [ 6,  6,  0]  1 */
    34015474, /* 66036 (1613) [-1,  0,  0,  0,  0, -1,  0, -1,  0] [ 0,  0,  0] -1 */
    18433930, /* 66037 (1613) [ 0,  0,  1,  0,  1,  0, -1,  0,  0] [ 6,  6,  0]  1 */
    35556700, /* 66038 (1613) [ 0,  0, -1,  0,  1,  0,  1,  0,  0] [ 0,  6,  6] -1 */
    18435334, /* 66039 (1613) [ 0,  1,  0,  0,  0,  1, -1,  0,  0] [ 6,  6,  0]  1 */
    35557978, /* 66040 (1613) [ 0,  0,  1,  0, -1,  0, -1,  0,  0] [ 0,  6,  6] -1 */
    18426488, /* 66041 (1613) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    17133394, /* 66042 (1613) [ 0,  0, -1,  0,  1,  0, -1,  0,  0] [ 6,  0,  6]  1 */
    35563870, /* 66043 (1613) [ 1,  0,  0,  0,  0, -1,  0, -1,  0] [ 0,  6,  6] -1 */
    34021246, /* 66044 (1613) [ 0,  0, -1,  0, -1,  0, -1,  0,  0] [ 0,  0,  0] -1 */
    51148444, /* 66045 (1613) [ 0,  1,  0,  0,  0, -1,  1,  0,  0] [ 6,  0,  6] -1 */
       12272, /* 66046 (1613) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    35557822, /* 66047 (1613) [ 0,  0,  1, -1,  0,  0,  0, -1,  0] [ 0,  6,  6] -1 */
    34028656, /* 66048 (1613) [ 1,  0,  0,  0,  0,  1,  0,  1,  0] [ 0,  0,  0] -1 */
    18430700, /* 66049 (1613) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    18439770, /* 66050 (1613) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
    18426544, /* 66051 (1613) [-1,  0,  0,  0,  0, -1,  0,  1,  0] [ 6,  6,  0]  1 */
        7618, /* 66052 (1613) [ 0, -1,  0,  0,  0, -1, -1,  0,  0] [ 0,  0,  0]  1 */
     1544632, /* 66053 (1613) [ 0,  0, -1,  1,  0,  0,  0,  1,  0] [ 0,  6,  6]  1 */
    18435558, /* 66054 (1613) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 6,  6,  0]  1 */
    34019634, /* 66055 (1613) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  0] -1 */
     1543172, /* 66056 (1613) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 0,  6,  6]  1 */
     1547058, /* 66057 (1613) [ 0,  1,  0, -1,  0,  0,  0,  0, -1] [ 0,  6,  6]  1 */
    51146932, /* 66058 (1613) [ 0,  0,  1,  0, -1,  0,  1,  0,  0] [ 6,  0,  6] -1 */
    17134540, /* 66059 (1613) [ 0,  0,  1, -1,  0,  0,  0,  1,  0] [ 6,  0,  6]  1 */
     1538636, /* 66060 (1613) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
    51152812, /* 66061 (1613) [ 1,  0,  0,  0,  0, -1,  0,  1,  0] [ 6,  0,  6] -1 */
    17131882, /* 66062 (1613) [ 0, -1,  0,  0,  0,  1, -1,  0,  0] [ 6,  0,  6]  1 */
    18430924, /* 66063 (1613) [ 0, -1,  0,  0,  0, -1,  1,  0,  0] [ 6,  6,  0]  1 */
     1551594, /* 66064 (1613) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
    51145786, /* 66065 (1613) [ 0,  0, -1,  1,  0,  0,  0, -1,  0] [ 6,  0,  6] -1 */
    18439714, /* 66066 (1613) [ 1,  0,  0,  0,  0,  1,  0, -1,  0] [ 6,  6,  0]  1 */
    51144330, /* 66067 (1613) [ 0, -1,  0,  1,  0,  0,  0,  0, -1] [ 6,  0,  6] -1 */
     1542964, /* 66068 (1613) [ 0, -1,  0,  0,  0,  1,  1,  0,  0] [ 0,  6,  6]  1 */
    51148220, /* 66069 (1613) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 6,  0,  6] -1 */
    51139738, /* 66070 (1613) [-1,  0,  0,  0,  0,  1,  0, -1,  0] [ 6,  0,  6] -1 */
    35550808, /* 66071 (1613) [-1,  0,  0,  0,  0,  1,  0,  1,  0] [ 0,  6,  6] -1 */
    52444552, /* 66072 (1613) [ 0,  0, -1,  0, -1,  0,  1,  0,  0] [ 6,  6,  0] -1 */
     1544476, /* 66073 (1613) [ 0,  0, -1,  0,  1,  0,  1,  0,  0] [ 0,  6,  6]  1 */
    34021090, /* 66074 (1613) [ 0,  0, -1, -1,  0,  0,  0, -1,  0] [ 0,  0,  0] -1 */
       16484, /* 66075 (1614) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    17132106, /* 66076 (1614) [ 0, -1,  0,  1,  0,  0,  0,  0, -1] [ 6,  0,  6]  1 */
       10660, /* 66077 (1614) [ 0,  0,  1,  0,  1,  0,  1,  0,  0] [ 0,  0,  0]  1 */
     1545754, /* 66078 (1614) [ 0,  0,  1,  0, -1,  0, -1,  0,  0] [ 0,  6,  6]  1 */
    34019634, /* 66079 (1614) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  0] -1 */
     1547058, /* 66080 (1614) [ 0,  1,  0, -1,  0,  0,  0,  0, -1] [ 0,  6,  6]  1 */
    17127570, /* 66081 (1614) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6]  1 */
    51146932, /* 66082 (1614) [ 0,  0,  1,  0, -1,  0,  1,  0,  0] [ 6,  0,  6] -1 */
     1551646, /* 66083 (1614) [ 1,  0,  0,  0,  0, -1,  0, -1,  0] [ 0,  6,  6]  1 */
    51152812, /* 66084 (1614) [ 1,  0,  0,  0,  0, -1,  0,  1,  0] [ 6,  0,  6] -1 */
     1545598, /* 66085 (1614) [ 0,  0,  1, -1,  0,  0,  0, -1,  0] [ 0,  6,  6]  1 */
    17127514, /* 66086 (1614) [-1,  0,  0,  0,  0,  1,  0, -1,  0] [ 6,  0,  6]  1 */
     1547266, /* 66087 (1614) [ 0,  1,  0,  0,  0, -1, -1,  0,  0] [ 0,  6,  6]  1 */
    17131882, /* 66088 (1614) [ 0, -1,  0,  0,  0,  1, -1,  0,  0] [ 6,  0,  6]  1 */
       16432, /* 66089 (1614) [ 1,  0,  0,  0,  0,  1,  0,  1,  0] [ 0,  0,  0]  1 */
    52451938, /* 66090 (1614) [ 1,  0,  0,  0,  0,  1,  0, -1,  0] [ 6,  6,  0] -1 */
    18432328, /* 66091 (1614) [ 0,  0, -1,  0, -1,  0,  1,  0,  0] [ 6,  6,  0]  1 */
    52446154, /* 66092 (1614) [ 0,  0,  1,  0,  1,  0, -1,  0,  0] [ 6,  6,  0] -1 */
    34015474, /* 66093 (1614) [-1,  0,  0,  0,  0, -1,  0, -1,  0] [ 0,  0,  0] -1 */
    18430924, /* 66094 (1614) [ 0, -1,  0,  0,  0, -1,  1,  0,  0] [ 6,  6,  0]  1 */
    35555188, /* 66095 (1614) [ 0, -1,  0,  0,  0,  1,  1,  0,  0] [ 0,  6,  6] -1 */
    52447558, /* 66096 (1614) [ 0,  1,  0,  0,  0,  1, -1,  0,  0] [ 6,  6,  0] -1 */
     1551594, /* 66097 (1614) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
    18432160, /* 66098 (1614) [ 0,  0, -1, -1,  0,  0,  0,  1,  0] [ 6,  6,  0]  1 */
    35556700, /* 66099 (1614) [ 0,  0, -1,  0,  1,  0,  1,  0,  0] [ 0,  6,  6] -1 */
    52451994, /* 66100 (1614) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
    52447782, /* 66101 (1614) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 6,  6,  0] -1 */
    34019842, /* 66102 (1614) [ 0, -1,  0,  0,  0, -1, -1,  0,  0] [ 0,  0,  0] -1 */
    35556856, /* 66103 (1614) [ 0,  0, -1,  1,  0,  0,  0,  1,  0] [ 0,  6,  6] -1 */
    35555396, /* 66104 (1614) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 0,  6,  6] -1 */
    51148220, /* 66105 (1614) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 6,  0,  6] -1 */
    51146764, /* 66106 (1614) [ 0,  0,  1, -1,  0,  0,  0,  1,  0] [ 6,  0,  6] -1 */
    18426488, /* 66107 (1614) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    17133394, /* 66108 (1614) [ 0,  0, -1,  0,  1,  0, -1,  0,  0] [ 6,  0,  6]  1 */
    34021246, /* 66109 (1614) [ 0,  0, -1,  0, -1,  0, -1,  0,  0] [ 0,  0,  0] -1 */
       10816, /* 66110 (1614) [ 0,  0,  1,  1,  0,  0,  0,  1,  0] [ 0,  0,  0]  1 */
    34015422, /* 66111 (1614) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    51148444, /* 66112 (1614) [ 0,  1,  0,  0,  0, -1,  1,  0,  0] [ 6,  0,  6] -1 */
    51152756, /* 66113 (1614) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
    35550860, /* 66114 (1614) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
    17133562, /* 66115 (1614) [ 0,  0, -1,  1,  0,  0,  0, -1,  0] [ 6,  0,  6]  1 */
       12272, /* 66116 (1614) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    35550808, /* 66117 (1614) [-1,  0,  0,  0,  0,  1,  0,  1,  0] [ 0,  6,  6] -1 */
       12064, /* 66118 (1614) [ 0,  1,  0,  0,  0,  1,  1,  0,  0] [ 0,  0,  0]  1 */
    18430700, /* 66119 (1614) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    52446322, /* 66120 (1614) [ 0,  0,  1,  1,  0,  0,  0, -1,  0] [ 6,  6,  0] -1 */
    34021090, /* 66121 (1614) [ 0,  0, -1, -1,  0,  0,  0, -1,  0] [ 0,  0,  0] -1 */
    18426544, /* 66122 (1614) [-1,  0,  0,  0,  0, -1,  0,  1,  0] [ 6,  6,  0]  1 */
       16484, /* 66123 (1615) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34019634, /* 66124 (1615) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    17127570, /* 66125 (1615) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6]  1 */
    51146932, /* 66126 (1615) [ 0,  0,  1,  0, -1,  0,  1,  0,  0] [ 6,  0,  6] -1 */
    17134540, /* 66127 (1615) [ 0,  0,  1, -1,  0,  0,  0,  1,  0] [ 6,  0,  6]  1 */
    17136220, /* 66128 (1615) [ 0,  1,  0,  0,  0, -1,  1,  0,  0] [ 6,  0,  6]  1 */
     1538636, /* 66129 (1615) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
        3198, /* 66130 (1615) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
     1545598, /* 66131 (1615) [ 0,  0,  1, -1,  0,  0,  0, -1,  0] [ 0,  6,  6]  1 */
    51152812, /* 66132 (1615) [ 1,  0,  0,  0,  0, -1,  0,  1,  0] [ 6,  0,  6] -1 */
     1547266, /* 66133 (1615) [ 0,  1,  0,  0,  0, -1, -1,  0,  0] [ 0,  6,  6]  1 */
    17131882, /* 66134 (1615) [ 0, -1,  0,  0,  0,  1, -1,  0,  0] [ 6,  0,  6]  1 */
    17140532, /* 66135 (1615) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
    18434098, /* 66136 (1615) [ 0,  0,  1,  1,  0,  0,  0, -1,  0] [ 6,  6,  0]  1 */
        8866, /* 66137 (1615) [ 0,  0, -1, -1,  0,  0,  0, -1,  0] [ 0,  0,  0]  1 */
    52451938, /* 66138 (1615) [ 1,  0,  0,  0,  0,  1,  0, -1,  0] [ 6,  6,  0] -1 */
    52446154, /* 66139 (1615) [ 0,  0,  1,  0,  1,  0, -1,  0,  0] [ 6,  6,  0] -1 */
    34015474, /* 66140 (1615) [-1,  0,  0,  0,  0, -1,  0, -1,  0] [ 0,  0,  0] -1 */
    18430924, /* 66141 (1615) [ 0, -1,  0,  0,  0, -1,  1,  0,  0] [ 6,  6,  0]  1 */
    51145618, /* 66142 (1615) [ 0,  0, -1,  0,  1,  0, -1,  0,  0] [ 6,  0,  6] -1 */
    34024496, /* 66143 (1615) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 0,  0,  0] -1 */
     1551594, /* 66144 (1615) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
    18432160, /* 66145 (1615) [ 0,  0, -1, -1,  0,  0,  0,  1,  0] [ 6,  6,  0]  1 */
    52442924, /* 66146 (1615) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 6,  6,  0] -1 */
    35556700, /* 66147 (1615) [ 0,  0, -1,  0,  1,  0,  1,  0,  0] [ 0,  6,  6] -1 */
    52447782, /* 66148 (1615) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 6,  6,  0] -1 */
    52438768, /* 66149 (1615) [-1,  0,  0,  0,  0, -1,  0,  1,  0] [ 6,  6,  0] -1 */
    51144330, /* 66150 (1615) [ 0, -1,  0,  1,  0,  0,  0,  0, -1] [ 6,  0,  6] -1 */
    34022884, /* 66151 (1615) [ 0,  0,  1,  0,  1,  0,  1,  0,  0] [ 0,  0,  0] -1 */
    35559282, /* 66152 (1615) [ 0,  1,  0, -1,  0,  0,  0,  0, -1] [ 0,  6,  6] -1 */
    35555396, /* 66153 (1615) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 0,  6,  6] -1 */
     1542964, /* 66154 (1615) [ 0, -1,  0,  0,  0,  1,  1,  0,  0] [ 0,  6,  6]  1 */
    51148220, /* 66155 (1615) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 6,  0,  6] -1 */
    35557978, /* 66156 (1615) [ 0,  0,  1,  0, -1,  0, -1,  0,  0] [ 0,  6,  6] -1 */
    18426488, /* 66157 (1615) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    34021246, /* 66158 (1615) [ 0,  0, -1,  0, -1,  0, -1,  0,  0] [ 0,  0,  0] -1 */
    35563870, /* 66159 (1615) [ 1,  0,  0,  0,  0, -1,  0, -1,  0] [ 0,  6,  6] -1 */
       10816, /* 66160 (1615) [ 0,  0,  1,  1,  0,  0,  0,  1,  0] [ 0,  0,  0]  1 */
    18435334, /* 66161 (1615) [ 0,  1,  0,  0,  0,  1, -1,  0,  0] [ 6,  6,  0]  1 */
    17133562, /* 66162 (1615) [ 0,  0, -1,  1,  0,  0,  0, -1,  0] [ 6,  0,  6]  1 */
    51139738, /* 66163 (1615) [-1,  0,  0,  0,  0,  1,  0, -1,  0] [ 6,  0,  6] -1 */
    34028656, /* 66164 (1615) [ 1,  0,  0,  0,  0,  1,  0,  1,  0] [ 0,  0,  0] -1 */
    35550808, /* 66165 (1615) [-1,  0,  0,  0,  0,  1,  0,  1,  0] [ 0,  6,  6] -1 */
       12064, /* 66166 (1615) [ 0,  1,  0,  0,  0,  1,  1,  0,  0] [ 0,  0,  0]  1 */
    52444552, /* 66167 (1615) [ 0,  0, -1,  0, -1,  0,  1,  0,  0] [ 6,  6,  0] -1 */
    18439770, /* 66168 (1615) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
        7618, /* 66169 (1615) [ 0, -1,  0,  0,  0, -1, -1,  0,  0] [ 0,  0,  0]  1 */
     1544632, /* 66170 (1615) [ 0,  0, -1,  1,  0,  0,  0,  1,  0] [ 0,  6,  6]  1 */
       16484, /* 66171 (1616) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    17135996, /* 66172 (1616) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 6,  0,  6]  1 */
     1543172, /* 66173 (1616) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 0,  6,  6]  1 */
    17127570, /* 66174 (1616) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6]  1 */
        9022, /* 66175 (1616) [ 0,  0, -1,  0, -1,  0, -1,  0,  0] [ 0,  0,  0]  1 */
     1545598, /* 66176 (1616) [ 0,  0,  1, -1,  0,  0,  0, -1,  0] [ 0,  6,  6]  1 */
     1547266, /* 66177 (1616) [ 0,  1,  0,  0,  0, -1, -1,  0,  0] [ 0,  6,  6]  1 */
    17131882, /* 66178 (1616) [ 0, -1,  0,  0,  0,  1, -1,  0,  0] [ 6,  0,  6]  1 */
     1538584, /* 66179 (1616) [-1,  0,  0,  0,  0,  1,  0,  1,  0] [ 0,  6,  6]  1 */
        7410, /* 66180 (1616) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    18430924, /* 66181 (1616) [ 0, -1,  0,  0,  0, -1,  1,  0,  0] [ 6,  6,  0]  1 */
    35555188, /* 66182 (1616) [ 0, -1,  0,  0,  0,  1,  1,  0,  0] [ 0,  6,  6] -1 */
    17134708, /* 66183 (1616) [ 0,  0,  1,  0, -1,  0,  1,  0,  0] [ 6,  0,  6]  1 */
    52447558, /* 66184 (1616) [ 0,  1,  0,  0,  0,  1, -1,  0,  0] [ 6,  6,  0] -1 */
    51145618, /* 66185 (1616) [ 0,  0, -1,  0,  1,  0, -1,  0,  0] [ 6,  0,  6] -1 */
    34024496, /* 66186 (1616) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    17140588, /* 66187 (1616) [ 1,  0,  0,  0,  0, -1,  0,  1,  0] [ 6,  0,  6]  1 */
     1551594, /* 66188 (1616) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
    18432160, /* 66189 (1616) [ 0,  0, -1, -1,  0,  0,  0,  1,  0] [ 6,  6,  0]  1 */
    18439714, /* 66190 (1616) [ 1,  0,  0,  0,  0,  1,  0, -1,  0] [ 6,  6,  0]  1 */
    52442924, /* 66191 (1616) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 6,  6,  0] -1 */
    18433930, /* 66192 (1616) [ 0,  0,  1,  0,  1,  0, -1,  0,  0] [ 6,  6,  0]  1 */
    52451994, /* 66193 (1616) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
    34019842, /* 66194 (1616) [ 0, -1,  0,  0,  0, -1, -1,  0,  0] [ 0,  0,  0] -1 */
    51144330, /* 66195 (1616) [ 0, -1,  0,  1,  0,  0,  0,  0, -1] [ 6,  0,  6] -1 */
    52438768, /* 66196 (1616) [-1,  0,  0,  0,  0, -1,  0,  1,  0] [ 6,  6,  0] -1 */
    35556856, /* 66197 (1616) [ 0,  0, -1,  1,  0,  0,  0,  1,  0] [ 0,  6,  6] -1 */
    34022884, /* 66198 (1616) [ 0,  0,  1,  0,  1,  0,  1,  0,  0] [ 0,  0,  0] -1 */
        3250, /* 66199 (1616) [-1,  0,  0,  0,  0, -1,  0, -1,  0] [ 0,  0,  0]  1 */
    35559282, /* 66200 (1616) [ 0,  1,  0, -1,  0,  0,  0,  0, -1] [ 0,  6,  6] -1 */
    51146764, /* 66201 (1616) [ 0,  0,  1, -1,  0,  0,  0,  1,  0] [ 6,  0,  6] -1 */
    35557978, /* 66202 (1616) [ 0,  0,  1,  0, -1,  0, -1,  0,  0] [ 0,  6,  6] -1 */
    18426488, /* 66203 (1616) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    35563870, /* 66204 (1616) [ 1,  0,  0,  0,  0, -1,  0, -1,  0] [ 0,  6,  6] -1 */
    34015422, /* 66205 (1616) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
       10816, /* 66206 (1616) [ 0,  0,  1,  1,  0,  0,  0,  1,  0] [ 0,  0,  0]  1 */
    51148444, /* 66207 (1616) [ 0,  1,  0,  0,  0, -1,  1,  0,  0] [ 6,  0,  6] -1 */
    51152756, /* 66208 (1616) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
    35550860, /* 66209 (1616) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
    17133562, /* 66210 (1616) [ 0,  0, -1,  1,  0,  0,  0, -1,  0] [ 6,  0,  6]  1 */
    51139738, /* 66211 (1616) [-1,  0,  0,  0,  0,  1,  0, -1,  0] [ 6,  0,  6] -1 */
    34028656, /* 66212 (1616) [ 1,  0,  0,  0,  0,  1,  0,  1,  0] [ 0,  0,  0] -1 */
       12064, /* 66213 (1616) [ 0,  1,  0,  0,  0,  1,  1,  0,  0] [ 0,  0,  0]  1 */
    52446322, /* 66214 (1616) [ 0,  0,  1,  1,  0,  0,  0, -1,  0] [ 6,  6,  0] -1 */
     1544476, /* 66215 (1616) [ 0,  0, -1,  0,  1,  0,  1,  0,  0] [ 0,  6,  6]  1 */
    52444552, /* 66216 (1616) [ 0,  0, -1,  0, -1,  0,  1,  0,  0] [ 6,  6,  0] -1 */
    34021090, /* 66217 (1616) [ 0,  0, -1, -1,  0,  0,  0, -1,  0] [ 0,  0,  0] -1 */
    18435558, /* 66218 (1616) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 6,  6,  0]  1 */
       16484, /* 66219 (1617) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
       10660, /* 66220 (1617) [ 0,  0,  1,  0,  1,  0,  1,  0,  0] [ 0,  0,  0]  1 */
     1545754, /* 66221 (1617) [ 0,  0,  1,  0, -1,  0, -1,  0,  0] [ 0,  6,  6]  1 */
    34139362, /* 66222 (1617) [ 0,  0, -1,  0, -1,  0,  1,  0,  0] [ 0,  0,  6] -1 */
    35439898, /* 66223 (1617) [ 0,  0,  1,  0, -1,  0,  1,  0,  0] [ 0,  6,  0] -1 */
        9022, /* 66224 (1617) [ 0,  0, -1,  0, -1,  0, -1,  0,  0] [ 0,  0,  0]  1 */
    17136220, /* 66225 (1617) [ 0,  1,  0,  0,  0, -1,  1,  0,  0] [ 6,  0,  6]  1 */
        3198, /* 66226 (1617) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
     1545598, /* 66227 (1617) [ 0,  0,  1, -1,  0,  0,  0, -1,  0] [ 0,  6,  6]  1 */
    17140532, /* 66228 (1617) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
       16432, /* 66229 (1617) [ 1,  0,  0,  0,  0,  1,  0,  1,  0] [ 0,  0,  0]  1 */
    51028816, /* 66230 (1617) [ 0,  0,  1,  0, -1,  0, -1,  0,  0] [ 6,  0,  0] -1 */
    51027694, /* 66231 (1617) [ 0,  0, -1,  1,  0,  0,  0,  1,  0] [ 6,  0,  0] -1 */
        7410, /* 66232 (1617) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    17134708, /* 66233 (1617) [ 0,  0,  1,  0, -1,  0,  1,  0,  0] [ 6,  0,  6]  1 */
    52565882, /* 66234 (1617) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    35438584, /* 66235 (1617) [ 0,  0, -1,  0,  1,  0, -1,  0,  0] [ 0,  6,  0] -1 */
    34142368, /* 66236 (1617) [ 0,  1,  0,  0,  0,  1, -1,  0,  0] [ 0,  0,  6] -1 */
    34133522, /* 66237 (1617) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    18432160, /* 66238 (1617) [ 0,  0, -1, -1,  0,  0,  0,  1,  0] [ 6,  6,  0]  1 */
    52561228, /* 66239 (1617) [ 0, -1,  0,  0,  0, -1, -1,  0,  0] [ 6,  6,  6] -1 */
    35439730, /* 66240 (1617) [ 0,  0,  1, -1,  0,  0,  0,  1,  0] [ 0,  6,  0] -1 */
    51034656, /* 66241 (1617) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  0] -1 */
    35432760, /* 66242 (1617) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  0] -1 */
    52570042, /* 66243 (1617) [ 1,  0,  0,  0,  0,  1,  0,  1,  0] [ 6,  6,  6] -1 */
    34137734, /* 66244 (1617) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  6] -1 */
        3250, /* 66245 (1617) [-1,  0,  0,  0,  0, -1,  0, -1,  0] [ 0,  0,  0]  1 */
    34146804, /* 66246 (1617) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
    34142592, /* 66247 (1617) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  6] -1 */
    52562632, /* 66248 (1617) [ 0,  0, -1,  0, -1,  0, -1,  0,  0] [ 6,  6,  6] -1 */
    17133562, /* 66249 (1617) [ 0,  0, -1,  1,  0,  0,  0, -1,  0] [ 6,  0,  6]  1 */
    34141132, /* 66250 (1617) [ 0,  0,  1,  1,  0,  0,  0, -1,  0] [ 0,  0,  6] -1 */
    17135996, /* 66251 (1617) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 6,  0,  6]  1 */
    51026026, /* 66252 (1617) [ 0, -1,  0,  0,  0,  1,  1,  0,  0] [ 6,  0,  0] -1 */
     1551646, /* 66253 (1617) [ 1,  0,  0,  0,  0, -1,  0, -1,  0] [ 0,  6,  6]  1 */
    51034708, /* 66254 (1617) [ 1,  0,  0,  0,  0, -1,  0, -1,  0] [ 6,  0,  0] -1 */
    34137958, /* 66255 (1617) [ 0, -1,  0,  0,  0, -1,  1,  0,  0] [ 0,  0,  6] -1 */
    17127514, /* 66256 (1617) [-1,  0,  0,  0,  0,  1,  0, -1,  0] [ 6,  0,  6]  1 */
    34140964, /* 66257 (1617) [ 0,  0,  1,  0,  1,  0, -1,  0,  0] [ 0,  0,  6] -1 */
        8866, /* 66258 (1617) [ 0,  0, -1, -1,  0,  0,  0, -1,  0] [ 0,  0,  0]  1 */
    34146748, /* 66259 (1617) [ 1,  0,  0,  0,  0,  1,  0, -1,  0] [ 0,  0,  6] -1 */
    51028660, /* 66260 (1617) [ 0,  0,  1, -1,  0,  0,  0, -1,  0] [ 6,  0,  0] -1 */
    17140588, /* 66261 (1617) [ 1,  0,  0,  0,  0, -1,  0,  1,  0] [ 6,  0,  6]  1 */
    52564270, /* 66262 (1617) [ 0,  0,  1,  0,  1,  0,  1,  0,  0] [ 6,  6,  6] -1 */
    35445722, /* 66263 (1617) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  0] -1 */
    35437072, /* 66264 (1617) [ 0, -1,  0,  0,  0,  1, -1,  0,  0] [ 0,  6,  0] -1 */
    52556808, /* 66265 (1617) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    35441410, /* 66266 (1617) [ 0,  1,  0,  0,  0, -1,  1,  0,  0] [ 0,  6,  0] -1 */
       10816, /* 66267 (1617) [ 0,  0,  1,  1,  0,  0,  0,  1,  0] [ 0,  0,  0]  1 */
       12064, /* 66268 (1617) [ 0,  1,  0,  0,  0,  1,  1,  0,  0] [ 0,  0,  0]  1 */
    52561020, /* 66269 (1617) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    17132106, /* 66270 (1617) [ 0, -1,  0,  1,  0,  0,  0,  0, -1] [ 6,  0,  6]  1 */
    17127570, /* 66271 (1617) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6]  1 */
    35445778, /* 66272 (1617) [ 1,  0,  0,  0,  0, -1,  0,  1,  0] [ 0,  6,  0] -1 */
     1547266, /* 66273 (1617) [ 0,  1,  0,  0,  0, -1, -1,  0,  0] [ 0,  6,  6]  1 */
    18434098, /* 66274 (1617) [ 0,  0,  1,  1,  0,  0,  0, -1,  0] [ 6,  6,  0]  1 */
     1538584, /* 66275 (1617) [-1,  0,  0,  0,  0,  1,  0,  1,  0] [ 0,  6,  6]  1 */
    51021646, /* 66276 (1617) [-1,  0,  0,  0,  0,  1,  0,  1,  0] [ 6,  0,  0] -1 */
    18432328, /* 66277 (1617) [ 0,  0, -1,  0, -1,  0,  1,  0,  0] [ 6,  6,  0]  1 */
    52556860, /* 66278 (1617) [-1,  0,  0,  0,  0, -1,  0, -1,  0] [ 6,  6,  6] -1 */
    51027538, /* 66279 (1617) [ 0,  0, -1,  0,  1,  0,  1,  0,  0] [ 6,  0,  0] -1 */
    35438752, /* 66280 (1617) [ 0,  0, -1,  1,  0,  0,  0, -1,  0] [ 0,  6,  0] -1 */
    34139194, /* 66281 (1617) [ 0,  0, -1, -1,  0,  0,  0,  1,  0] [ 0,  0,  6] -1 */
    51030328, /* 66282 (1617) [ 0,  1,  0,  0,  0, -1, -1,  0,  0] [ 6,  0,  0] -1 */
    18433930, /* 66283 (1617) [ 0,  0,  1,  0,  1,  0, -1,  0,  0] [ 6,  6,  0]  1 */
    35441186, /* 66284 (1617) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 0,  6,  0] -1 */
    18435334, /* 66285 (1617) [ 0,  1,  0,  0,  0,  1, -1,  0,  0] [ 6,  6,  0]  1 */
    18426488, /* 66286 (1617) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    17133394, /* 66287 (1617) [ 0,  0, -1,  0,  1,  0, -1,  0,  0] [ 6,  0,  6]  1 */
       12272, /* 66288 (1617) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    35432704, /* 66289 (1617) [-1,  0,  0,  0,  0,  1,  0, -1,  0] [ 0,  6,  0] -1 */
    52562476, /* 66290 (1617) [ 0,  0, -1, -1,  0,  0,  0, -1,  0] [ 6,  6,  6] -1 */
    18430700, /* 66291 (1617) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    34133578, /* 66292 (1617) [-1,  0,  0,  0,  0, -1,  0,  1,  0] [ 0,  0,  6] -1 */
    18439770, /* 66293 (1617) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
    18426544, /* 66294 (1617) [-1,  0,  0,  0,  0, -1,  0,  1,  0] [ 6,  6,  0]  1 */
        7618, /* 66295 (1617) [ 0, -1,  0,  0,  0, -1, -1,  0,  0] [ 0,  0,  0]  1 */
     1544632, /* 66296 (1617) [ 0,  0, -1,  1,  0,  0,  0,  1,  0] [ 0,  6,  6]  1 */
    18435558, /* 66297 (1617) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 6,  6,  0]  1 */
     1543172, /* 66298 (1617) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 0,  6,  6]  1 */
     1547058, /* 66299 (1617) [ 0,  1,  0, -1,  0,  0,  0,  0, -1] [ 0,  6,  6]  1 */
    51030120, /* 66300 (1617) [ 0,  1,  0, -1,  0,  0,  0,  0, -1] [ 6,  0,  0] -1 */
    17134540, /* 66301 (1617) [ 0,  0,  1, -1,  0,  0,  0,  1,  0] [ 6,  0,  6]  1 */
     1538636, /* 66302 (1617) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
    17131882, /* 66303 (1617) [ 0, -1,  0,  0,  0,  1, -1,  0,  0] [ 6,  0,  6]  1 */
    52570094, /* 66304 (1617) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    51026234, /* 66305 (1617) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 6,  0,  0] -1 */
    51021698, /* 66306 (1617) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  0] -1 */
    18430924, /* 66307 (1617) [ 0, -1,  0,  0,  0, -1,  1,  0,  0] [ 6,  6,  0]  1 */
    52565674, /* 66308 (1617) [ 0,  1,  0,  0,  0,  1,  1,  0,  0] [ 6,  6,  6] -1 */
    35437296, /* 66309 (1617) [ 0, -1,  0,  1,  0,  0,  0,  0, -1] [ 0,  6,  0] -1 */
     1551594, /* 66310 (1617) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
    18439714, /* 66311 (1617) [ 1,  0,  0,  0,  0,  1,  0, -1,  0] [ 6,  6,  0]  1 */
    52564426, /* 66312 (1617) [ 0,  0,  1,  1,  0,  0,  0,  1,  0] [ 6,  6,  6] -1 */
     1542964, /* 66313 (1617) [ 0, -1,  0,  0,  0,  1,  1,  0,  0] [ 0,  6,  6]  1 */
     1544476, /* 66314 (1617) [ 0,  0, -1,  0,  1,  0,  1,  0,  0] [ 0,  6,  6]  1 */
       16484, /* 66315 (1618) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
     1551700, /* 66316 (1618) [ 1,  0,  0,  0,  0,  1,  0, -1,  0] [ 0,  6,  6]  1 */
       10660, /* 66317 (1618) [ 0,  0,  1,  0,  1,  0,  1,  0,  0] [ 0,  0,  0]  1 */
    17140694, /* 66318 (1618) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
    17133568, /* 66319 (1618) [ 0,  0, -1,  1,  0,  0,  0,  1,  0] [ 6,  0,  6]  1 */
     1545754, /* 66320 (1618) [ 0,  0,  1,  0, -1,  0, -1,  0,  0] [ 0,  6,  6]  1 */
        9022, /* 66321 (1618) [ 0,  0, -1,  0, -1,  0, -1,  0,  0] [ 0,  0,  0]  1 */
    18432310, /* 66322 (1618) [ 0,  0, -1,  0, -1,  0, -1,  0,  0] [ 6,  6,  0]  1 */
       16320, /* 66323 (1618) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    17136220, /* 66324 (1618) [ 0,  1,  0,  0,  0, -1,  1,  0,  0] [ 6,  0,  6]  1 */
     1538578, /* 66325 (1618) [-1,  0,  0,  0,  0,  1,  0, -1,  0] [ 0,  6,  6]  1 */
    17132108, /* 66326 (1618) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 6,  0,  6]  1 */
        3198, /* 66327 (1618) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
     1545598, /* 66328 (1618) [ 0,  0,  1, -1,  0,  0,  0, -1,  0] [ 0,  6,  6]  1 */
    17135994, /* 66329 (1618) [ 0,  1,  0, -1,  0,  0,  0,  0, -1] [ 6,  0,  6]  1 */
     1538524, /* 66330 (1618) [-1,  0,  0,  0,  0, -1,  0, -1,  0] [ 0,  6,  6]  1 */
       16432, /* 66331 (1618) [ 1,  0,  0,  0,  0,  1,  0,  1,  0] [ 0,  0,  0]  1 */
    17140532, /* 66332 (1618) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
        3256, /* 66333 (1618) [-1,  0,  0,  0,  0, -1,  0,  1,  0] [ 0,  0,  0]  1 */
     1538474, /* 66334 (1618) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
    17136274, /* 66335 (1618) [ 0,  1,  0,  0,  0,  1,  1,  0,  0] [ 6,  0,  6]  1 */
        9184, /* 66336 (1618) [ 0,  0, -1,  0,  1,  0, -1,  0,  0] [ 0,  0,  0]  1 */
        7410, /* 66337 (1618) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    18430698, /* 66338 (1618) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 6,  6,  0]  1 */
    17134708, /* 66339 (1618) [ 0,  0,  1,  0, -1,  0,  1,  0,  0] [ 6,  0,  6]  1 */
        9352, /* 66340 (1618) [ 0,  0, -1,  1,  0,  0,  0, -1,  0] [ 0,  0,  0]  1 */
     1551652, /* 66341 (1618) [ 1,  0,  0,  0,  0, -1,  0,  1,  0] [ 0,  6,  6]  1 */
    17131622, /* 66342 (1618) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 6,  0,  6]  1 */
    18431184, /* 66343 (1618) [ 0, -1,  0,  1,  0,  0,  0,  0, -1] [ 6,  6,  0]  1 */
     1545772, /* 66344 (1618) [ 0,  0,  1,  0, -1,  0,  1,  0,  0] [ 0,  6,  6]  1 */
    17131828, /* 66345 (1618) [ 0, -1,  0,  0,  0, -1, -1,  0,  0] [ 6,  0,  6]  1 */
    18426648, /* 66346 (1618) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
        8872, /* 66347 (1618) [ 0,  0, -1, -1,  0,  0,  0,  1,  0] [ 0,  0,  0]  1 */
    17136480, /* 66348 (1618) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 6,  0,  6]  1 */
    18432160, /* 66349 (1618) [ 0,  0, -1, -1,  0,  0,  0,  1,  0] [ 6,  6,  0]  1 */
     1544296, /* 66350 (1618) [ 0,  0, -1,  0, -1,  0, -1,  0,  0] [ 0,  6,  6]  1 */
    17140642, /* 66351 (1618) [ 1,  0,  0,  0,  0,  1,  0,  1,  0] [ 6,  0,  6]  1 */
    17135020, /* 66352 (1618) [ 0,  0,  1,  1,  0,  0,  0, -1,  0] [ 6,  0,  6]  1 */
       16372, /* 66353 (1618) [ 1,  0,  0,  0,  0, -1,  0, -1,  0] [ 0,  0,  0]  1 */
    18439660, /* 66354 (1618) [ 1,  0,  0,  0,  0, -1,  0, -1,  0] [ 6,  6,  0]  1 */
        3250, /* 66355 (1618) [-1,  0,  0,  0,  0, -1,  0, -1,  0] [ 0,  0,  0]  1 */
    18426598, /* 66356 (1618) [-1,  0,  0,  0,  0,  1,  0,  1,  0] [ 6,  6,  0]  1 */
    18426592, /* 66357 (1618) [-1,  0,  0,  0,  0,  1,  0, -1,  0] [ 6,  6,  0]  1 */
        9202, /* 66358 (1618) [ 0,  0, -1,  0,  1,  0,  1,  0,  0] [ 0,  0,  0]  1 */
    17131900, /* 66359 (1618) [ 0, -1,  0,  0,  0,  1,  1,  0,  0] [ 6,  0,  6]  1 */
    18433612, /* 66360 (1618) [ 0,  0,  1, -1,  0,  0,  0, -1,  0] [ 6,  6,  0]  1 */
    17133562, /* 66361 (1618) [ 0,  0, -1,  1,  0,  0,  0, -1,  0] [ 6,  0,  6]  1 */
     1542684, /* 66362 (1618) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 0,  6,  6]  1 */
    17131846, /* 66363 (1618) [ 0, -1,  0,  0,  0, -1,  1,  0,  0] [ 6,  0,  6]  1 */
        3304, /* 66364 (1618) [-1,  0,  0,  0,  0,  1,  0, -1,  0] [ 0,  0,  0]  1 */
     1543170, /* 66365 (1618) [ 0, -1,  0,  1,  0,  0,  0,  0, -1] [ 0,  6,  6]  1 */
       10324, /* 66366 (1618) [ 0,  0,  1, -1,  0,  0,  0, -1,  0] [ 0,  0,  0]  1 */
     1538634, /* 66367 (1618) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
    17134852, /* 66368 (1618) [ 0,  0,  1,  0,  1,  0, -1,  0,  0] [ 6,  0,  6]  1 */
     1544146, /* 66369 (1618) [ 0,  0, -1, -1,  0,  0,  0,  1,  0] [ 0,  6,  6]  1 */
    17135996, /* 66370 (1618) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 6,  0,  6]  1 */
    17140636, /* 66371 (1618) [ 1,  0,  0,  0,  0,  1,  0, -1,  0] [ 6,  0,  6]  1 */
    17134690, /* 66372 (1618) [ 0,  0,  1,  0, -1,  0, -1,  0,  0] [ 6,  0,  6]  1 */
     1551646, /* 66373 (1618) [ 1,  0,  0,  0,  0, -1,  0, -1,  0] [ 0,  6,  6]  1 */
    17127514, /* 66374 (1618) [-1,  0,  0,  0,  0,  1,  0, -1,  0] [ 6,  0,  6]  1 */
    18432472, /* 66375 (1618) [ 0,  0, -1,  0,  1,  0, -1,  0,  0] [ 6,  6,  0]  1 */
    17134534, /* 66376 (1618) [ 0,  0,  1, -1,  0,  0,  0, -1,  0] [ 6,  0,  6]  1 */
        8866, /* 66377 (1618) [ 0,  0, -1, -1,  0,  0,  0, -1,  0] [ 0,  0,  0]  1 */
    17127572, /* 66378 (1618) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
    18432154, /* 66379 (1618) [ 0,  0, -1, -1,  0,  0,  0, -1,  0] [ 6,  6,  0]  1 */
    17134870, /* 66380 (1618) [ 0,  0,  1,  0,  1,  0,  1,  0,  0] [ 6,  0,  6]  1 */
    18439772, /* 66381 (1618) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    17140530, /* 66382 (1618) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  6]  1 */
    17140588, /* 66383 (1618) [ 1,  0,  0,  0,  0, -1,  0,  1,  0] [ 6,  0,  6]  1 */
    17127408, /* 66384 (1618) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  6]  1 */
    17140692, /* 66385 (1618) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6]  1 */
    17127466, /* 66386 (1618) [-1,  0,  0,  0,  0, -1,  0,  1,  0] [ 6,  0,  6]  1 */
    18439610, /* 66387 (1618) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
        7896, /* 66388 (1618) [ 0, -1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    18430960, /* 66389 (1618) [ 0, -1,  0,  0,  0,  1, -1,  0,  0] [ 6,  6,  0]  1 */
    18432490, /* 66390 (1618) [ 0,  0, -1,  0,  1,  0,  1,  0,  0] [ 6,  6,  0]  1 */
    17133232, /* 66391 (1618) [ 0,  0, -1,  0, -1,  0, -1,  0,  0] [ 6,  0,  6]  1 */
       11786, /* 66392 (1618) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    18435280, /* 66393 (1618) [ 0,  1,  0,  0,  0, -1, -1,  0,  0] [ 6,  6,  0]  1 */
     1544458, /* 66394 (1618) [ 0,  0, -1,  0,  1,  0, -1,  0,  0] [ 0,  6,  6]  1 */
        7898, /* 66395 (1618) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    18435352, /* 66396 (1618) [ 0,  1,  0,  0,  0,  1,  1,  0,  0] [ 6,  6,  0]  1 */
     1544140, /* 66397 (1618) [ 0,  0, -1, -1,  0,  0,  0, -1,  0] [ 0,  6,  6]  1 */
        3310, /* 66398 (1618) [-1,  0,  0,  0,  0,  1,  0,  1,  0] [ 0,  0,  0]  1 */
       10816, /* 66399 (1618) [ 0,  0,  1,  1,  0,  0,  0,  1,  0] [ 0,  0,  0]  1 */
    18434104, /* 66400 (1618) [ 0,  0,  1,  1,  0,  0,  0,  1,  0] [ 6,  6,  0]  1 */
    18435560, /* 66401 (1618) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 6,  6,  0]  1 */
       11992, /* 66402 (1618) [ 0,  1,  0,  0,  0, -1, -1,  0,  0] [ 0,  0,  0]  1 */
       12064, /* 66403 (1618) [ 0,  1,  0,  0,  0,  1,  1,  0,  0] [ 0,  0,  0]  1 */
     1551758, /* 66404 (1618) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
    18439720, /* 66405 (1618) [ 1,  0,  0,  0,  0,  1,  0,  1,  0] [ 6,  6,  0]  1 */
    17132106, /* 66406 (1618) [ 0, -1,  0,  1,  0,  0,  0,  0, -1] [ 6,  0,  6]  1 */
     1545604, /* 66407 (1618) [ 0,  0,  1, -1,  0,  0,  0,  1,  0] [ 0,  6,  6]  1 */
    17133412, /* 66408 (1618) [ 0,  0, -1,  0,  1,  0,  1,  0,  0] [ 6,  0,  6]  1 */
    17127570, /* 66409 (1618) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6]  1 */
     1547320, /* 66410 (1618) [ 0,  1,  0,  0,  0,  1, -1,  0,  0] [ 0,  6,  6]  1 */
     1547060, /* 66411 (1618) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 0,  6,  6]  1 */
     1542946, /* 66412 (1618) [ 0, -1,  0,  0,  0,  1, -1,  0,  0] [ 0,  6,  6]  1 */
    17133082, /* 66413 (1618) [ 0,  0, -1, -1,  0,  0,  0,  1,  0] [ 6,  0,  6]  1 */
       12270, /* 66414 (1618) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  0]  1 */
     1547266, /* 66415 (1618) [ 0,  1,  0,  0,  0, -1, -1,  0,  0] [ 0,  6,  6]  1 */
    17136482, /* 66416 (1618) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 6,  0,  6]  1 */
    17140582, /* 66417 (1618) [ 1,  0,  0,  0,  0, -1,  0, -1,  0] [ 6,  0,  6]  1 */
    18434098, /* 66418 (1618) [ 0,  0,  1,  1,  0,  0,  0, -1,  0] [ 6,  6,  0]  1 */
       10498, /* 66419 (1618) [ 0,  0,  1,  0, -1,  0,  1,  0,  0] [ 0,  0,  0]  1 */
     1538584, /* 66420 (1618) [-1,  0,  0,  0,  0,  1,  0,  1,  0] [ 0,  6,  6]  1 */
    17127460, /* 66421 (1618) [-1,  0,  0,  0,  0, -1,  0, -1,  0] [ 6,  0,  6]  1 */
     1547546, /* 66422 (1618) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 0,  6,  6]  1 */
     1546090, /* 66423 (1618) [ 0,  0,  1,  1,  0,  0,  0,  1,  0] [ 0,  6,  6]  1 */
        9040, /* 66424 (1618) [ 0,  0, -1,  0, -1,  0,  1,  0,  0] [ 0,  0,  0]  1 */
    18432328, /* 66425 (1618) [ 0,  0, -1,  0, -1,  0,  1,  0,  0] [ 6,  6,  0]  1 */
     1551706, /* 66426 (1618) [ 1,  0,  0,  0,  0,  1,  0,  1,  0] [ 0,  6,  6]  1 */
    18435298, /* 66427 (1618) [ 0,  1,  0,  0,  0, -1,  1,  0,  0] [ 6,  6,  0]  1 */
       11784, /* 66428 (1618) [ 0,  1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    18431186, /* 66429 (1618) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    18435072, /* 66430 (1618) [ 0,  1,  0, -1,  0,  0,  0,  0, -1] [ 6,  6,  0]  1 */
    18433930, /* 66431 (1618) [ 0,  0,  1,  0,  1,  0, -1,  0,  0] [ 6,  6,  0]  1 */
    18426650, /* 66432 (1618) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
        7672, /* 66433 (1618) [ 0, -1,  0,  0,  0,  1, -1,  0,  0] [ 0,  0,  0]  1 */
       10330, /* 66434 (1618) [ 0,  0,  1, -1,  0,  0,  0,  1,  0] [ 0,  0,  0]  1 */
    18433618, /* 66435 (1618) [ 0,  0,  1, -1,  0,  0,  0,  1,  0] [ 6,  6,  0]  1 */
        3360, /* 66436 (1618) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
     1546084, /* 66437 (1618) [ 0,  0,  1,  1,  0,  0,  0, -1,  0] [ 0,  6,  6]  1 */
       12010, /* 66438 (1618) [ 0,  1,  0,  0,  0, -1,  1,  0,  0] [ 0,  0,  0]  1 */
       12046, /* 66439 (1618) [ 0,  1,  0,  0,  0,  1, -1,  0,  0] [ 0,  0,  0]  1 */
    18435334, /* 66440 (1618) [ 0,  1,  0,  0,  0,  1, -1,  0,  0] [ 6,  6,  0]  1 */
    18426488, /* 66441 (1618) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    17133394, /* 66442 (1618) [ 0,  0, -1,  0,  1,  0, -1,  0,  0] [ 6,  0,  6]  1 */
     1544314, /* 66443 (1618) [ 0,  0, -1,  0, -1,  0,  1,  0,  0] [ 0,  6,  6]  1 */
    17131620, /* 66444 (1618) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 6,  0,  6]  1 */
    17133076, /* 66445 (1618) [ 0,  0, -1, -1,  0,  0,  0, -1,  0] [ 6,  0,  6]  1 */
        3362, /* 66446 (1618) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
       12272, /* 66447 (1618) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 0,  0,  0]  1 */
        7412, /* 66448 (1618) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    18430700, /* 66449 (1618) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    18439770, /* 66450 (1618) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
        7618, /* 66451 (1618) [ 0, -1,  0,  0,  0, -1, -1,  0,  0] [ 0,  0,  0]  1 */
    18430906, /* 66452 (1618) [ 0, -1,  0,  0,  0, -1, -1,  0,  0] [ 6,  6,  0]  1 */
    18426544, /* 66453 (1618) [-1,  0,  0,  0,  0, -1,  0,  1,  0] [ 6,  6,  0]  1 */
     1544632, /* 66454 (1618) [ 0,  0, -1,  1,  0,  0,  0,  1,  0] [ 0,  6,  6]  1 */
    18435558, /* 66455 (1618) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 6,  6,  0]  1 */
    18433948, /* 66456 (1618) [ 0,  0,  1,  0,  1,  0,  1,  0,  0] [ 6,  6,  0]  1 */
     1547284, /* 66457 (1618) [ 0,  1,  0,  0,  0, -1,  1,  0,  0] [ 0,  6,  6]  1 */
    18439608, /* 66458 (1618) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
     1543172, /* 66459 (1618) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 0,  6,  6]  1 */
     1547058, /* 66460 (1618) [ 0,  1,  0, -1,  0,  0,  0,  0, -1] [ 0,  6,  6]  1 */
     1545916, /* 66461 (1618) [ 0,  0,  1,  0,  1,  0, -1,  0,  0] [ 0,  6,  6]  1 */
       16378, /* 66462 (1618) [ 1,  0,  0,  0,  0, -1,  0,  1,  0] [ 0,  0,  0]  1 */
    18426486, /* 66463 (1618) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
    17134540, /* 66464 (1618) [ 0,  0,  1, -1,  0,  0,  0,  1,  0] [ 6,  0,  6]  1 */
     1551596, /* 66465 (1618) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
     1538636, /* 66466 (1618) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
    17127520, /* 66467 (1618) [-1,  0,  0,  0,  0,  1,  0,  1,  0] [ 6,  0,  6]  1 */
    17136256, /* 66468 (1618) [ 0,  1,  0,  0,  0,  1, -1,  0,  0] [ 6,  0,  6]  1 */
    17127410, /* 66469 (1618) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
    17131882, /* 66470 (1618) [ 0, -1,  0,  0,  0,  1, -1,  0,  0] [ 6,  0,  6]  1 */
    17136202, /* 66471 (1618) [ 0,  1,  0,  0,  0, -1, -1,  0,  0] [ 6,  0,  6]  1 */
     1547338, /* 66472 (1618) [ 0,  1,  0,  0,  0,  1,  1,  0,  0] [ 0,  6,  6]  1 */
        7690, /* 66473 (1618) [ 0, -1,  0,  0,  0,  1,  1,  0,  0] [ 0,  0,  0]  1 */
       10810, /* 66474 (1618) [ 0,  0,  1,  1,  0,  0,  0, -1,  0] [ 0,  0,  0]  1 */
    18430978, /* 66475 (1618) [ 0, -1,  0,  0,  0,  1,  1,  0,  0] [ 6,  6,  0]  1 */
    18432640, /* 66476 (1618) [ 0,  0, -1,  1,  0,  0,  0, -1,  0] [ 6,  6,  0]  1 */
    17135026, /* 66477 (1618) [ 0,  0,  1,  1,  0,  0,  0,  1,  0] [ 6,  0,  6]  1 */
        7636, /* 66478 (1618) [ 0, -1,  0,  0,  0, -1,  1,  0,  0] [ 0,  0,  0]  1 */
     1542686, /* 66479 (1618) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 0,  6,  6]  1 */
    18430924, /* 66480 (1618) [ 0, -1,  0,  0,  0, -1,  1,  0,  0] [ 6,  6,  0]  1 */
     1551756, /* 66481 (1618) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
     1538530, /* 66482 (1618) [-1,  0,  0,  0,  0, -1,  0,  1,  0] [ 0,  6,  6]  1 */
     1542892, /* 66483 (1618) [ 0, -1,  0,  0,  0, -1, -1,  0,  0] [ 0,  6,  6]  1 */
     1547544, /* 66484 (1618) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 0,  6,  6]  1 */
    18435074, /* 66485 (1618) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 6,  6,  0]  1 */
     1545934, /* 66486 (1618) [ 0,  0,  1,  0,  1,  0,  1,  0,  0] [ 0,  6,  6]  1 */
     1551594, /* 66487 (1618) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
    18439714, /* 66488 (1618) [ 1,  0,  0,  0,  0,  1,  0, -1,  0] [ 6,  6,  0]  1 */
       10480, /* 66489 (1618) [ 0,  0,  1,  0, -1,  0, -1,  0,  0] [ 0,  0,  0]  1 */
    18433768, /* 66490 (1618) [ 0,  0,  1,  0, -1,  0, -1,  0,  0] [ 6,  6,  0]  1 */
     1538472, /* 66491 (1618) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
       10642, /* 66492 (1618) [ 0,  0,  1,  0,  1,  0, -1,  0,  0] [ 0,  0,  0]  1 */
    18432646, /* 66493 (1618) [ 0,  0, -1,  1,  0,  0,  0,  1,  0] [ 6,  6,  0]  1 */
    18426538, /* 66494 (1618) [-1,  0,  0,  0,  0, -1,  0, -1,  0] [ 6,  6,  0]  1 */
       16426, /* 66495 (1618) [ 1,  0,  0,  0,  0,  1,  0, -1,  0] [ 0,  0,  0]  1 */
     1542964, /* 66496 (1618) [ 0, -1,  0,  0,  0,  1,  1,  0,  0] [ 0,  6,  6]  1 */
       16322, /* 66497 (1618) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
     1544626, /* 66498 (1618) [ 0,  0, -1,  1,  0,  0,  0, -1,  0] [ 0,  6,  6]  1 */
        3200, /* 66499 (1618) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
        9358, /* 66500 (1618) [ 0,  0, -1,  1,  0,  0,  0,  1,  0] [ 0,  0,  0]  1 */
    17133250, /* 66501 (1618) [ 0,  0, -1,  0, -1,  0,  1,  0,  0] [ 6,  0,  6]  1 */
     1542910, /* 66502 (1618) [ 0, -1,  0,  0,  0, -1,  1,  0,  0] [ 0,  6,  6]  1 */
     1544476, /* 66503 (1618) [ 0,  0, -1,  0,  1,  0,  1,  0,  0] [ 0,  6,  6]  1 */
    18439666, /* 66504 (1618) [ 1,  0,  0,  0,  0, -1,  0,  1,  0] [ 6,  6,  0]  1 */
       16482, /* 66505 (1618) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    18433786, /* 66506 (1618) [ 0,  0,  1,  0, -1,  0,  1,  0,  0] [ 6,  6,  0]  1 */
       16484, /* 66507 (1619) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    17140694, /* 66508 (1619) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
        9022, /* 66509 (1619) [ 0,  0, -1,  0, -1,  0, -1,  0,  0] [ 0,  0,  0]  1 */
    18432310, /* 66510 (1619) [ 0,  0, -1,  0, -1,  0, -1,  0,  0] [ 6,  6,  0]  1 */
     1538578, /* 66511 (1619) [-1,  0,  0,  0,  0,  1,  0, -1,  0] [ 0,  6,  6]  1 */
    17136220, /* 66512 (1619) [ 0,  1,  0,  0,  0, -1,  1,  0,  0] [ 6,  0,  6]  1 */
    52451996, /* 66513 (1619) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
        3198, /* 66514 (1619) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
     1545598, /* 66515 (1619) [ 0,  0,  1, -1,  0,  0,  0, -1,  0] [ 0,  6,  6]  1 */
     1538524, /* 66516 (1619) [-1,  0,  0,  0,  0, -1,  0, -1,  0] [ 0,  6,  6]  1 */
    34019896, /* 66517 (1619) [ 0, -1,  0,  0,  0,  1, -1,  0,  0] [ 0,  0,  0] -1 */
    52443184, /* 66518 (1619) [ 0, -1,  0,  0,  0,  1, -1,  0,  0] [ 6,  6,  0] -1 */
    17136274, /* 66519 (1619) [ 0,  1,  0,  0,  0,  1,  1,  0,  0] [ 6,  0,  6]  1 */
    35556538, /* 66520 (1619) [ 0,  0, -1,  0, -1,  0,  1,  0,  0] [ 0,  6,  6] -1 */
    34020122, /* 66521 (1619) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    52447576, /* 66522 (1619) [ 0,  1,  0,  0,  0,  1,  1,  0,  0] [ 6,  6,  0] -1 */
    17131622, /* 66523 (1619) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 6,  0,  6]  1 */
    34024496, /* 66524 (1619) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    52447784, /* 66525 (1619) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 6,  6,  0] -1 */
        8872, /* 66526 (1619) [ 0,  0, -1, -1,  0,  0,  0,  1,  0] [ 0,  0,  0]  1 */
    18432160, /* 66527 (1619) [ 0,  0, -1, -1,  0,  0,  0,  1,  0] [ 6,  6,  0]  1 */
       16372, /* 66528 (1619) [ 1,  0,  0,  0,  0, -1,  0, -1,  0] [ 0,  0,  0]  1 */
    18439660, /* 66529 (1619) [ 1,  0,  0,  0,  0, -1,  0, -1,  0] [ 6,  6,  0]  1 */
    51146764, /* 66530 (1619) [ 0,  0,  1, -1,  0,  0,  0,  1,  0] [ 6,  0,  6] -1 */
    34024494, /* 66531 (1619) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    17133562, /* 66532 (1619) [ 0,  0, -1,  1,  0,  0,  0, -1,  0] [ 6,  0,  6]  1 */
     1542684, /* 66533 (1619) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 0,  6,  6]  1 */
    34023034, /* 66534 (1619) [ 0,  0,  1,  1,  0,  0,  0, -1,  0] [ 0,  0,  0] -1 */
    52446322, /* 66535 (1619) [ 0,  0,  1,  1,  0,  0,  0, -1,  0] [ 6,  6,  0] -1 */
    52444864, /* 66536 (1619) [ 0,  0, -1,  1,  0,  0,  0, -1,  0] [ 6,  6,  0] -1 */
     1543170, /* 66537 (1619) [ 0, -1,  0,  1,  0,  0,  0,  0, -1] [ 0,  6,  6]  1 */
    17127514, /* 66538 (1619) [-1,  0,  0,  0,  0,  1,  0, -1,  0] [ 6,  0,  6]  1 */
    17134534, /* 66539 (1619) [ 0,  0,  1, -1,  0,  0,  0, -1,  0] [ 6,  0,  6]  1 */
    34022866, /* 66540 (1619) [ 0,  0,  1,  0,  1,  0, -1,  0,  0] [ 0,  0,  0] -1 */
    52446154, /* 66541 (1619) [ 0,  0,  1,  0,  1,  0, -1,  0,  0] [ 6,  6,  0] -1 */
    18439772, /* 66542 (1619) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    51145618, /* 66543 (1619) [ 0,  0, -1,  0,  1,  0, -1,  0,  0] [ 6,  0,  6] -1 */
    34015586, /* 66544 (1619) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    17140692, /* 66545 (1619) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6]  1 */
    17127466, /* 66546 (1619) [-1,  0,  0,  0,  0, -1,  0,  1,  0] [ 6,  0,  6]  1 */
    18430960, /* 66547 (1619) [ 0, -1,  0,  0,  0,  1, -1,  0,  0] [ 6,  6,  0]  1 */
    34028706, /* 66548 (1619) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    52451994, /* 66549 (1619) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
    34019842, /* 66550 (1619) [ 0, -1,  0,  0,  0, -1, -1,  0,  0] [ 0,  0,  0] -1 */
    52443130, /* 66551 (1619) [ 0, -1,  0,  0,  0, -1, -1,  0,  0] [ 6,  6,  0] -1 */
    52438768, /* 66552 (1619) [-1,  0,  0,  0,  0, -1,  0,  1,  0] [ 6,  6,  0] -1 */
    18435280, /* 66553 (1619) [ 0,  1,  0,  0,  0, -1, -1,  0,  0] [ 6,  6,  0]  1 */
     1544458, /* 66554 (1619) [ 0,  0, -1,  0,  1,  0, -1,  0,  0] [ 0,  6,  6]  1 */
        7898, /* 66555 (1619) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    18435352, /* 66556 (1619) [ 0,  1,  0,  0,  0,  1,  1,  0,  0] [ 6,  6,  0]  1 */
    18435560, /* 66557 (1619) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    51139744, /* 66558 (1619) [-1,  0,  0,  0,  0,  1,  0,  1,  0] [ 6,  0,  6] -1 */
    51139634, /* 66559 (1619) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
    35550698, /* 66560 (1619) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
    52442922, /* 66561 (1619) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 6,  6,  0] -1 */
    17132106, /* 66562 (1619) [ 0, -1,  0,  1,  0,  0,  0,  0, -1] [ 6,  0,  6]  1 */
    52443408, /* 66563 (1619) [ 0, -1,  0,  1,  0,  0,  0,  0, -1] [ 6,  6,  0] -1 */
       12270, /* 66564 (1619) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    35556520, /* 66565 (1619) [ 0,  0, -1,  0, -1,  0, -1,  0,  0] [ 0,  6,  6] -1 */
    18434098, /* 66566 (1619) [ 0,  0,  1,  1,  0,  0,  0, -1,  0] [ 6,  6,  0]  1 */
    35550696, /* 66567 (1619) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  6] -1 */
    34028546, /* 66568 (1619) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    18431186, /* 66569 (1619) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    18433930, /* 66570 (1619) [ 0,  0,  1,  0,  1,  0, -1,  0,  0] [ 6,  6,  0]  1 */
    35556370, /* 66571 (1619) [ 0,  0, -1, -1,  0,  0,  0,  1,  0] [ 0,  6,  6] -1 */
    35563924, /* 66572 (1619) [ 1,  0,  0,  0,  0,  1,  0, -1,  0] [ 0,  6,  6] -1 */
    17133394, /* 66573 (1619) [ 0,  0, -1,  0,  1,  0, -1,  0,  0] [ 6,  0,  6]  1 */
    35563870, /* 66574 (1619) [ 1,  0,  0,  0,  0, -1,  0, -1,  0] [ 0,  6,  6] -1 */
    17131620, /* 66575 (1619) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 6,  0,  6]  1 */
        3362, /* 66576 (1619) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    52444696, /* 66577 (1619) [ 0,  0, -1,  0,  1,  0, -1,  0,  0] [ 6,  6,  0] -1 */
    18439770, /* 66578 (1619) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
        7618, /* 66579 (1619) [ 0, -1,  0,  0,  0, -1, -1,  0,  0] [ 0,  0,  0]  1 */
    18430906, /* 66580 (1619) [ 0, -1,  0,  0,  0, -1, -1,  0,  0] [ 6,  6,  0]  1 */
    18426544, /* 66581 (1619) [-1,  0,  0,  0,  0, -1,  0,  1,  0] [ 6,  6,  0]  1 */
    18435558, /* 66582 (1619) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 6,  6,  0]  1 */
     1547058, /* 66583 (1619) [ 0,  1,  0, -1,  0,  0,  0,  0, -1] [ 0,  6,  6]  1 */
    51146932, /* 66584 (1619) [ 0,  0,  1,  0, -1,  0,  1,  0,  0] [ 6,  0,  6] -1 */
    17127520, /* 66585 (1619) [-1,  0,  0,  0,  0,  1,  0,  1,  0] [ 6,  0,  6]  1 */
    35557996, /* 66586 (1619) [ 0,  0,  1,  0, -1,  0,  1,  0,  0] [ 0,  6,  6] -1 */
    17127410, /* 66587 (1619) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
    52438872, /* 66588 (1619) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
    51145456, /* 66589 (1619) [ 0,  0, -1,  0, -1,  0, -1,  0,  0] [ 6,  0,  6] -1 */
    34021426, /* 66590 (1619) [ 0,  0, -1,  0,  1,  0,  1,  0,  0] [ 0,  0,  0] -1 */
    51144124, /* 66591 (1619) [ 0, -1,  0,  0,  0,  1,  1,  0,  0] [ 6,  0,  6] -1 */
     1538472, /* 66592 (1619) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
     1542964, /* 66593 (1619) [ 0, -1,  0,  0,  0,  1,  1,  0,  0] [ 0,  6,  6]  1 */
       16322, /* 66594 (1619) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    51145306, /* 66595 (1619) [ 0,  0, -1, -1,  0,  0,  0,  1,  0] [ 6,  0,  6] -1 */
    51152860, /* 66596 (1619) [ 1,  0,  0,  0,  0,  1,  0, -1,  0] [ 6,  0,  6] -1 */
        9358, /* 66597 (1619) [ 0,  0, -1,  1,  0,  0,  0,  1,  0] [ 0,  0,  0]  1 */
    51152806, /* 66598 (1619) [ 1,  0,  0,  0,  0, -1,  0, -1,  0] [ 6,  0,  6] -1 */
    34021090, /* 66599 (1619) [ 0,  0, -1, -1,  0,  0,  0, -1,  0] [ 0,  0,  0] -1 */
     1551700, /* 66600 (1619) [ 1,  0,  0,  0,  0,  1,  0, -1,  0] [ 0,  6,  6]  1 */
       10660, /* 66601 (1619) [ 0,  0,  1,  0,  1,  0,  1,  0,  0] [ 0,  0,  0]  1 */
       16320, /* 66602 (1619) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    17135994, /* 66603 (1619) [ 0,  1,  0, -1,  0,  0,  0,  0, -1] [ 6,  0,  6]  1 */
    51139632, /* 66604 (1619) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  6] -1 */
    52447296, /* 66605 (1619) [ 0,  1,  0, -1,  0,  0,  0,  0, -1] [ 6,  6,  0] -1 */
    34015584, /* 66606 (1619) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    34024234, /* 66607 (1619) [ 0,  1,  0,  0,  0, -1,  1,  0,  0] [ 0,  0,  0] -1 */
    17134708, /* 66608 (1619) [ 0,  0,  1,  0, -1,  0,  1,  0,  0] [ 6,  0,  6]  1 */
     1551652, /* 66609 (1619) [ 1,  0,  0,  0,  0, -1,  0,  1,  0] [ 0,  6,  6]  1 */
     1545772, /* 66610 (1619) [ 0,  0,  1,  0, -1,  0,  1,  0,  0] [ 0,  6,  6]  1 */
    18426648, /* 66611 (1619) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
    34024288, /* 66612 (1619) [ 0,  1,  0,  0,  0,  1,  1,  0,  0] [ 0,  0,  0] -1 */
    17140642, /* 66613 (1619) [ 1,  0,  0,  0,  0,  1,  0,  1,  0] [ 6,  0,  6]  1 */
    52451944, /* 66614 (1619) [ 1,  0,  0,  0,  0,  1,  0,  1,  0] [ 6,  6,  0] -1 */
    35555396, /* 66615 (1619) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 0,  6,  6] -1 */
    35563820, /* 66616 (1619) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
        9202, /* 66617 (1619) [ 0,  0, -1,  0,  1,  0,  1,  0,  0] [ 0,  0,  0]  1 */
    17131900, /* 66618 (1619) [ 0, -1,  0,  0,  0,  1,  1,  0,  0] [ 6,  0,  6]  1 */
    52443202, /* 66619 (1619) [ 0, -1,  0,  0,  0,  1,  1,  0,  0] [ 6,  6,  0] -1 */
    35558314, /* 66620 (1619) [ 0,  0,  1,  1,  0,  0,  0,  1,  0] [ 0,  6,  6] -1 */
    17140636, /* 66621 (1619) [ 1,  0,  0,  0,  0,  1,  0, -1,  0] [ 6,  0,  6]  1 */
    52447522, /* 66622 (1619) [ 0,  1,  0,  0,  0, -1,  1,  0,  0] [ 6,  6,  0] -1 */
        8866, /* 66623 (1619) [ 0,  0, -1, -1,  0,  0,  0, -1,  0] [ 0,  0,  0]  1 */
    18432154, /* 66624 (1619) [ 0,  0, -1, -1,  0,  0,  0, -1,  0] [ 6,  6,  0]  1 */
    34024270, /* 66625 (1619) [ 0,  1,  0,  0,  0,  1, -1,  0,  0] [ 0,  0,  0] -1 */
    52447558, /* 66626 (1619) [ 0,  1,  0,  0,  0,  1, -1,  0,  0] [ 6,  6,  0] -1 */
    34028708, /* 66627 (1619) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    17140588, /* 66628 (1619) [ 1,  0,  0,  0,  0, -1,  0,  1,  0] [ 6,  0,  6]  1 */
    17127408, /* 66629 (1619) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  6]  1 */
    34019636, /* 66630 (1619) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    52442924, /* 66631 (1619) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 6,  6,  0] -1 */
    52451890, /* 66632 (1619) [ 1,  0,  0,  0,  0, -1,  0,  1,  0] [ 6,  6,  0] -1 */
    18432490, /* 66633 (1619) [ 0,  0, -1,  0,  1,  0,  1,  0,  0] [ 6,  6,  0]  1 */
       11786, /* 66634 (1619) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    35556856, /* 66635 (1619) [ 0,  0, -1,  1,  0,  0,  0,  1,  0] [ 0,  6,  6] -1 */
    51152756, /* 66636 (1619) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
    35550860, /* 66637 (1619) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
       11992, /* 66638 (1619) [ 0,  1,  0,  0,  0, -1, -1,  0,  0] [ 0,  0,  0]  1 */
       12064, /* 66639 (1619) [ 0,  1,  0,  0,  0,  1,  1,  0,  0] [ 0,  0,  0]  1 */
    18439720, /* 66640 (1619) [ 1,  0,  0,  0,  0,  1,  0,  1,  0] [ 6,  6,  0]  1 */
     1545604, /* 66641 (1619) [ 0,  0,  1, -1,  0,  0,  0,  1,  0] [ 0,  6,  6]  1 */
    51147250, /* 66642 (1619) [ 0,  0,  1,  1,  0,  0,  0,  1,  0] [ 6,  0,  6] -1 */
    35558158, /* 66643 (1619) [ 0,  0,  1,  0,  1,  0,  1,  0,  0] [ 0,  6,  6] -1 */
    35563818, /* 66644 (1619) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  6] -1 */
     1538584, /* 66645 (1619) [-1,  0,  0,  0,  0,  1,  0,  1,  0] [ 0,  6,  6]  1 */
    17127460, /* 66646 (1619) [-1,  0,  0,  0,  0, -1,  0, -1,  0] [ 6,  0,  6]  1 */
     1546090, /* 66647 (1619) [ 0,  0,  1,  1,  0,  0,  0,  1,  0] [ 0,  6,  6]  1 */
    34015474, /* 66648 (1619) [-1,  0,  0,  0,  0, -1,  0, -1,  0] [ 0,  0,  0] -1 */
    52438762, /* 66649 (1619) [-1,  0,  0,  0,  0, -1,  0, -1,  0] [ 6,  6,  0] -1 */
    51145474, /* 66650 (1619) [ 0,  0, -1,  0, -1,  0,  1,  0,  0] [ 6,  0,  6] -1 */
    18435298, /* 66651 (1619) [ 0,  1,  0,  0,  0, -1,  1,  0,  0] [ 6,  6,  0]  1 */
    35555134, /* 66652 (1619) [ 0, -1,  0,  0,  0, -1,  1,  0,  0] [ 0,  6,  6] -1 */
    34015528, /* 66653 (1619) [-1,  0,  0,  0,  0,  1,  0, -1,  0] [ 0,  0,  0] -1 */
    35556700, /* 66654 (1619) [ 0,  0, -1,  0,  1,  0,  1,  0,  0] [ 0,  6,  6] -1 */
    34022548, /* 66655 (1619) [ 0,  0,  1, -1,  0,  0,  0, -1,  0] [ 0,  0,  0] -1 */
        7672, /* 66656 (1619) [ 0, -1,  0,  0,  0,  1, -1,  0,  0] [ 0,  0,  0]  1 */
    35559284, /* 66657 (1619) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 0,  6,  6] -1 */
       12046, /* 66658 (1619) [ 0,  1,  0,  0,  0,  1, -1,  0,  0] [ 0,  0,  0]  1 */
    18435334, /* 66659 (1619) [ 0,  1,  0,  0,  0,  1, -1,  0,  0] [ 6,  6,  0]  1 */
    51145792, /* 66660 (1619) [ 0,  0, -1,  1,  0,  0,  0,  1,  0] [ 6,  0,  6] -1 */
     1544314, /* 66661 (1619) [ 0,  0, -1,  0, -1,  0,  1,  0,  0] [ 0,  6,  6]  1 */
    35557978, /* 66662 (1619) [ 0,  0,  1,  0, -1,  0, -1,  0,  0] [ 0,  6,  6] -1 */
       12272, /* 66663 (1619) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 0,  0,  0]  1 */
        7412, /* 66664 (1619) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    51139796, /* 66665 (1619) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
    18430700, /* 66666 (1619) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    34015480, /* 66667 (1619) [-1,  0,  0,  0,  0, -1,  0,  1,  0] [ 0,  0,  0] -1 */
     1544632, /* 66668 (1619) [ 0,  0, -1,  1,  0,  0,  0,  1,  0] [ 0,  6,  6]  1 */
    34021408, /* 66669 (1619) [ 0,  0, -1,  0,  1,  0, -1,  0,  0] [ 0,  0,  0] -1 */
    34019634, /* 66670 (1619) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    17134540, /* 66671 (1619) [ 0,  0,  1, -1,  0,  0,  0,  1,  0] [ 6,  0,  6]  1 */
    34021576, /* 66672 (1619) [ 0,  0, -1,  1,  0,  0,  0, -1,  0] [ 0,  0,  0] -1 */
     1538636, /* 66673 (1619) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
       10810, /* 66674 (1619) [ 0,  0,  1,  1,  0,  0,  0, -1,  0] [ 0,  0,  0]  1 */
    18432640, /* 66675 (1619) [ 0,  0, -1,  1,  0,  0,  0, -1,  0] [ 6,  6,  0]  1 */
    17135026, /* 66676 (1619) [ 0,  0,  1,  1,  0,  0,  0,  1,  0] [ 6,  0,  6]  1 */
    35556364, /* 66677 (1619) [ 0,  0, -1, -1,  0,  0,  0, -1,  0] [ 0,  6,  6] -1 */
    34015534, /* 66678 (1619) [-1,  0,  0,  0,  0,  1,  0,  1,  0] [ 0,  0,  0] -1 */
    52438822, /* 66679 (1619) [-1,  0,  0,  0,  0,  1,  0,  1,  0] [ 6,  6,  0] -1 */
    52438816, /* 66680 (1619) [-1,  0,  0,  0,  0,  1,  0, -1,  0] [ 6,  6,  0] -1 */
     1545934, /* 66681 (1619) [ 0,  0,  1,  0,  1,  0,  1,  0,  0] [ 0,  6,  6]  1 */
    52445836, /* 66682 (1619) [ 0,  0,  1, -1,  0,  0,  0, -1,  0] [ 6,  6,  0] -1 */
     1551594, /* 66683 (1619) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
    51144070, /* 66684 (1619) [ 0, -1,  0,  0,  0, -1,  1,  0,  0] [ 6,  0,  6] -1 */
       10642, /* 66685 (1619) [ 0,  0,  1,  0,  1,  0, -1,  0,  0] [ 0,  0,  0]  1 */
    18426538, /* 66686 (1619) [-1,  0,  0,  0,  0, -1,  0, -1,  0] [ 6,  6,  0]  1 */
    51145636, /* 66687 (1619) [ 0,  0, -1,  0,  1,  0,  1,  0,  0] [ 6,  0,  6] -1 */
    35559544, /* 66688 (1619) [ 0,  1,  0,  0,  0,  1, -1,  0,  0] [ 0,  6,  6] -1 */
    51148220, /* 66689 (1619) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 6,  0,  6] -1 */
    51146914, /* 66690 (1619) [ 0,  0,  1,  0, -1,  0, -1,  0,  0] [ 6,  0,  6] -1 */
    17133250, /* 66691 (1619) [ 0,  0, -1,  0, -1,  0,  1,  0,  0] [ 6,  0,  6]  1 */
     1542910, /* 66692 (1619) [ 0, -1,  0,  0,  0, -1,  1,  0,  0] [ 0,  6,  6]  1 */
    52444552, /* 66693 (1619) [ 0,  0, -1,  0, -1,  0,  1,  0,  0] [ 6,  6,  0] -1 */
     1544476, /* 66694 (1619) [ 0,  0, -1,  0,  1,  0,  1,  0,  0] [ 0,  6,  6]  1 */
     1547060, /* 66695 (1619) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 0,  6,  6]  1 */
       16482, /* 66696 (1619) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    17133568, /* 66697 (1619) [ 0,  0, -1,  1,  0,  0,  0,  1,  0] [ 6,  0,  6]  1 */
     1545754, /* 66698 (1619) [ 0,  0,  1,  0, -1,  0, -1,  0,  0] [ 0,  6,  6]  1 */
    51147094, /* 66699 (1619) [ 0,  0,  1,  0,  1,  0,  1,  0,  0] [ 6,  0,  6] -1 */
    51152754, /* 66700 (1619) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  6] -1 */
        3256, /* 66701 (1619) [-1,  0,  0,  0,  0, -1,  0,  1,  0] [ 0,  0,  0]  1 */
    34020120, /* 66702 (1619) [ 0, -1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  0] -1 */
     1538474, /* 66703 (1619) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
    52445842, /* 66704 (1619) [ 0,  0,  1, -1,  0,  0,  0,  1,  0] [ 6,  6,  0] -1 */
        9184, /* 66705 (1619) [ 0,  0, -1,  0,  1,  0, -1,  0,  0] [ 0,  0,  0]  1 */
        7410, /* 66706 (1619) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    18430698, /* 66707 (1619) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 6,  6,  0]  1 */
        9352, /* 66708 (1619) [ 0,  0, -1,  1,  0,  0,  0, -1,  0] [ 0,  0,  0]  1 */
    18431184, /* 66709 (1619) [ 0, -1,  0,  1,  0,  0,  0,  0, -1] [ 6,  6,  0]  1 */
     1544296, /* 66710 (1619) [ 0,  0, -1,  0, -1,  0, -1,  0,  0] [ 0,  6,  6]  1 */
    35563982, /* 66711 (1619) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
    18426598, /* 66712 (1619) [-1,  0,  0,  0,  0,  1,  0,  1,  0] [ 6,  6,  0]  1 */
    18426592, /* 66713 (1619) [-1,  0,  0,  0,  0,  1,  0, -1,  0] [ 6,  6,  0]  1 */
    35555170, /* 66714 (1619) [ 0, -1,  0,  0,  0,  1, -1,  0,  0] [ 0,  6,  6] -1 */
    18433612, /* 66715 (1619) [ 0,  0,  1, -1,  0,  0,  0, -1,  0] [ 6,  6,  0]  1 */
    35559490, /* 66716 (1619) [ 0,  1,  0,  0,  0, -1, -1,  0,  0] [ 0,  6,  6] -1 */
    35559562, /* 66717 (1619) [ 0,  1,  0,  0,  0,  1,  1,  0,  0] [ 0,  6,  6] -1 */
    51148706, /* 66718 (1619) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 6,  0,  6] -1 */
    17131846, /* 66719 (1619) [ 0, -1,  0,  0,  0, -1,  1,  0,  0] [ 6,  0,  6]  1 */
    35559770, /* 66720 (1619) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 0,  6,  6] -1 */
    52443148, /* 66721 (1619) [ 0, -1,  0,  0,  0, -1,  1,  0,  0] [ 6,  6,  0] -1 */
     1544146, /* 66722 (1619) [ 0,  0, -1, -1,  0,  0,  0,  1,  0] [ 0,  6,  6]  1 */
    17135996, /* 66723 (1619) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 6,  0,  6]  1 */
    17134690, /* 66724 (1619) [ 0,  0,  1,  0, -1,  0, -1,  0,  0] [ 6,  0,  6]  1 */
    52447298, /* 66725 (1619) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 6,  6,  0] -1 */
     1551646, /* 66726 (1619) [ 1,  0,  0,  0,  0, -1,  0, -1,  0] [ 0,  6,  6]  1 */
    18432472, /* 66727 (1619) [ 0,  0, -1,  0,  1,  0, -1,  0,  0] [ 6,  6,  0]  1 */
    34024008, /* 66728 (1619) [ 0,  1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    34028650, /* 66729 (1619) [ 1,  0,  0,  0,  0,  1,  0, -1,  0] [ 0,  0,  0] -1 */
    35558308, /* 66730 (1619) [ 0,  0,  1,  1,  0,  0,  0, -1,  0] [ 0,  6,  6] -1 */
    35556850, /* 66731 (1619) [ 0,  0, -1,  1,  0,  0,  0, -1,  0] [ 0,  6,  6] -1 */
    17134870, /* 66732 (1619) [ 0,  0,  1,  0,  1,  0,  1,  0,  0] [ 6,  0,  6]  1 */
    34015424, /* 66733 (1619) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    52438712, /* 66734 (1619) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
    17140530, /* 66735 (1619) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  6]  1 */
        7896, /* 66736 (1619) [ 0, -1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    17133232, /* 66737 (1619) [ 0,  0, -1,  0, -1,  0, -1,  0,  0] [ 6,  0,  6]  1 */
    51152918, /* 66738 (1619) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
    52444534, /* 66739 (1619) [ 0,  0, -1,  0, -1,  0, -1,  0,  0] [ 6,  6,  0] -1 */
    35558140, /* 66740 (1619) [ 0,  0,  1,  0,  1,  0, -1,  0,  0] [ 0,  6,  6] -1 */
    34028602, /* 66741 (1619) [ 1,  0,  0,  0,  0, -1,  0,  1,  0] [ 0,  0,  0] -1 */
    34015422, /* 66742 (1619) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    52438710, /* 66743 (1619) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
    51144106, /* 66744 (1619) [ 0, -1,  0,  0,  0,  1, -1,  0,  0] [ 6,  0,  6] -1 */
     1551758, /* 66745 (1619) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
    51148426, /* 66746 (1619) [ 0,  1,  0,  0,  0, -1, -1,  0,  0] [ 6,  0,  6] -1 */
    34019914, /* 66747 (1619) [ 0, -1,  0,  0,  0,  1,  1,  0,  0] [ 0,  0,  0] -1 */
    51148498, /* 66748 (1619) [ 0,  1,  0,  0,  0,  1,  1,  0,  0] [ 6,  0,  6] -1 */
     1542946, /* 66749 (1619) [ 0, -1,  0,  0,  0,  1, -1,  0,  0] [ 0,  6,  6]  1 */
    17133082, /* 66750 (1619) [ 0,  0, -1, -1,  0,  0,  0,  1,  0] [ 6,  0,  6]  1 */
    35563980, /* 66751 (1619) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6] -1 */
    35550754, /* 66752 (1619) [-1,  0,  0,  0,  0, -1,  0,  1,  0] [ 0,  6,  6] -1 */
    35555116, /* 66753 (1619) [ 0, -1,  0,  0,  0, -1, -1,  0,  0] [ 0,  6,  6] -1 */
     1547266, /* 66754 (1619) [ 0,  1,  0,  0,  0, -1, -1,  0,  0] [ 0,  6,  6]  1 */
    35559768, /* 66755 (1619) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 0,  6,  6] -1 */
    52444384, /* 66756 (1619) [ 0,  0, -1, -1,  0,  0,  0,  1,  0] [ 6,  6,  0] -1 */
    17136482, /* 66757 (1619) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 6,  0,  6]  1 */
    17140582, /* 66758 (1619) [ 1,  0,  0,  0,  0, -1,  0, -1,  0] [ 6,  0,  6]  1 */
    52451938, /* 66759 (1619) [ 1,  0,  0,  0,  0,  1,  0, -1,  0] [ 6,  6,  0] -1 */
     1547546, /* 66760 (1619) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 0,  6,  6]  1 */
    52451884, /* 66761 (1619) [ 1,  0,  0,  0,  0, -1,  0, -1,  0] [ 6,  6,  0] -1 */
    35554908, /* 66762 (1619) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 0,  6,  6] -1 */
       11784, /* 66763 (1619) [ 0,  1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    18435072, /* 66764 (1619) [ 0,  1,  0, -1,  0,  0,  0,  0, -1] [ 6,  6,  0]  1 */
    35555394, /* 66765 (1619) [ 0, -1,  0,  1,  0,  0,  0,  0, -1] [ 0,  6,  6] -1 */
    34022722, /* 66766 (1619) [ 0,  0,  1,  0, -1,  0,  1,  0,  0] [ 0,  0,  0] -1 */
    52446010, /* 66767 (1619) [ 0,  0,  1,  0, -1,  0,  1,  0,  0] [ 6,  6,  0] -1 */
        3360, /* 66768 (1619) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
     1546084, /* 66769 (1619) [ 0,  0,  1,  1,  0,  0,  0, -1,  0] [ 0,  6,  6]  1 */
       12010, /* 66770 (1619) [ 0,  1,  0,  0,  0, -1,  1,  0,  0] [ 0,  0,  0]  1 */
    18426488, /* 66771 (1619) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    51144332, /* 66772 (1619) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 6,  0,  6] -1 */
    34028656, /* 66773 (1619) [ 1,  0,  0,  0,  0,  1,  0,  1,  0] [ 0,  0,  0] -1 */
     1543172, /* 66774 (1619) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 0,  6,  6]  1 */
     1545916, /* 66775 (1619) [ 0,  0,  1,  0,  1,  0, -1,  0,  0] [ 0,  6,  6]  1 */
       16378, /* 66776 (1619) [ 1,  0,  0,  0,  0, -1,  0,  1,  0] [ 0,  0,  0]  1 */
    18426486, /* 66777 (1619) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
     1551596, /* 66778 (1619) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
    17131882, /* 66779 (1619) [ 0, -1,  0,  0,  0,  1, -1,  0,  0] [ 6,  0,  6]  1 */
    51152916, /* 66780 (1619) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6] -1 */
    51139690, /* 66781 (1619) [-1,  0,  0,  0,  0, -1,  0,  1,  0] [ 6,  0,  6] -1 */
    51144052, /* 66782 (1619) [ 0, -1,  0,  0,  0, -1, -1,  0,  0] [ 6,  0,  6] -1 */
    17136202, /* 66783 (1619) [ 0,  1,  0,  0,  0, -1, -1,  0,  0] [ 6,  0,  6]  1 */
    51148704, /* 66784 (1619) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 6,  0,  6] -1 */
        7690, /* 66785 (1619) [ 0, -1,  0,  0,  0,  1,  1,  0,  0] [ 0,  0,  0]  1 */
    18430978, /* 66786 (1619) [ 0, -1,  0,  0,  0,  1,  1,  0,  0] [ 6,  6,  0]  1 */
    52447504, /* 66787 (1619) [ 0,  1,  0,  0,  0, -1, -1,  0,  0] [ 6,  6,  0] -1 */
    51147244, /* 66788 (1619) [ 0,  0,  1,  1,  0,  0,  0, -1,  0] [ 6,  0,  6] -1 */
    35556682, /* 66789 (1619) [ 0,  0, -1,  0,  1,  0, -1,  0,  0] [ 0,  6,  6] -1 */
     1551756, /* 66790 (1619) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
     1538530, /* 66791 (1619) [-1,  0,  0,  0,  0, -1,  0,  1,  0] [ 0,  6,  6]  1 */
     1542892, /* 66792 (1619) [ 0, -1,  0,  0,  0, -1, -1,  0,  0] [ 0,  6,  6]  1 */
     1547544, /* 66793 (1619) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 0,  6,  6]  1 */
    18439714, /* 66794 (1619) [ 1,  0,  0,  0,  0,  1,  0, -1,  0] [ 6,  6,  0]  1 */
    51144330, /* 66795 (1619) [ 0, -1,  0,  1,  0,  0,  0,  0, -1] [ 6,  0,  6] -1 */
    35550858, /* 66796 (1619) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6] -1 */
    51147076, /* 66797 (1619) [ 0,  0,  1,  0,  1,  0, -1,  0,  0] [ 6,  0,  6] -1 */
    18439666, /* 66798 (1619) [ 1,  0,  0,  0,  0, -1,  0,  1,  0] [ 6,  6,  0]  1 */
       10498, /* 66799 (1619) [ 0,  0,  1,  0, -1,  0,  1,  0,  0] [ 0,  0,  0]  1 */
    18433786, /* 66800 (1619) [ 0,  0,  1,  0, -1,  0,  1,  0,  0] [ 6,  6,  0]  1 */
    17132108, /* 66801 (1619) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 6,  0,  6]  1 */
       16432, /* 66802 (1619) [ 1,  0,  0,  0,  0,  1,  0,  1,  0] [ 0,  0,  0]  1 */
    17140532, /* 66803 (1619) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
    52443410, /* 66804 (1619) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 6,  6,  0] -1 */
    52451834, /* 66805 (1619) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
    51143844, /* 66806 (1619) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 6,  0,  6] -1 */
    34023040, /* 66807 (1619) [ 0,  0,  1,  1,  0,  0,  0,  1,  0] [ 0,  0,  0] -1 */
    52446328, /* 66808 (1619) [ 0,  0,  1,  1,  0,  0,  0,  1,  0] [ 6,  6,  0] -1 */
    17131828, /* 66809 (1619) [ 0, -1,  0,  0,  0, -1, -1,  0,  0] [ 6,  0,  6]  1 */
    17136480, /* 66810 (1619) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 6,  0,  6]  1 */
    52447782, /* 66811 (1619) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 6,  6,  0] -1 */
    17135020, /* 66812 (1619) [ 0,  0,  1,  1,  0,  0,  0, -1,  0] [ 6,  0,  6]  1 */
        3250, /* 66813 (1619) [-1,  0,  0,  0,  0, -1,  0, -1,  0] [ 0,  0,  0]  1 */
    35559282, /* 66814 (1619) [ 0,  1,  0, -1,  0,  0,  0,  0, -1] [ 0,  6,  6] -1 */
    51139794, /* 66815 (1619) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6] -1 */
        3304, /* 66816 (1619) [-1,  0,  0,  0,  0,  1,  0, -1,  0] [ 0,  0,  0]  1 */
    34021264, /* 66817 (1619) [ 0,  0, -1,  0, -1,  0,  1,  0,  0] [ 0,  0,  0] -1 */
       10324, /* 66818 (1619) [ 0,  0,  1, -1,  0,  0,  0, -1,  0] [ 0,  0,  0]  1 */
     1538634, /* 66819 (1619) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
    17134852, /* 66820 (1619) [ 0,  0,  1,  0,  1,  0, -1,  0,  0] [ 6,  0,  6]  1 */
    35563930, /* 66821 (1619) [ 1,  0,  0,  0,  0,  1,  0,  1,  0] [ 0,  6,  6] -1 */
    17127572, /* 66822 (1619) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
    52438874, /* 66823 (1619) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
    34022554, /* 66824 (1619) [ 0,  0,  1, -1,  0,  0,  0,  1,  0] [ 0,  0,  0] -1 */
    35555188, /* 66825 (1619) [ 0, -1,  0,  0,  0,  1,  1,  0,  0] [ 0,  6,  6] -1 */
    34021582, /* 66826 (1619) [ 0,  0, -1,  1,  0,  0,  0,  1,  0] [ 0,  0,  0] -1 */
    51145300, /* 66827 (1619) [ 0,  0, -1, -1,  0,  0,  0, -1,  0] [ 6,  0,  6] -1 */
    18439610, /* 66828 (1619) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    34022884, /* 66829 (1619) [ 0,  0,  1,  0,  1,  0,  1,  0,  0] [ 0,  0,  0] -1 */
    52446172, /* 66830 (1619) [ 0,  0,  1,  0,  1,  0,  1,  0,  0] [ 6,  6,  0] -1 */
    35559508, /* 66831 (1619) [ 0,  1,  0,  0,  0, -1,  1,  0,  0] [ 0,  6,  6] -1 */
    34028544, /* 66832 (1619) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
     1544140, /* 66833 (1619) [ 0,  0, -1, -1,  0,  0,  0, -1,  0] [ 0,  6,  6]  1 */
    52451832, /* 66834 (1619) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
        3310, /* 66835 (1619) [-1,  0,  0,  0,  0,  1,  0,  1,  0] [ 0,  0,  0]  1 */
    51148218, /* 66836 (1619) [ 0,  1,  0, -1,  0,  0,  0,  0, -1] [ 6,  0,  6] -1 */
       10816, /* 66837 (1619) [ 0,  0,  1,  1,  0,  0,  0,  1,  0] [ 0,  0,  0]  1 */
    18434104, /* 66838 (1619) [ 0,  0,  1,  1,  0,  0,  0,  1,  0] [ 6,  6,  0]  1 */
    51148480, /* 66839 (1619) [ 0,  1,  0,  0,  0,  1, -1,  0,  0] [ 6,  0,  6] -1 */
    17133412, /* 66840 (1619) [ 0,  0, -1,  0,  1,  0,  1,  0,  0] [ 6,  0,  6]  1 */
    34019860, /* 66841 (1619) [ 0, -1,  0,  0,  0, -1,  1,  0,  0] [ 0,  0,  0] -1 */
    17127570, /* 66842 (1619) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6]  1 */
    35554910, /* 66843 (1619) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 0,  6,  6] -1 */
     1547320, /* 66844 (1619) [ 0,  1,  0,  0,  0,  1, -1,  0,  0] [ 0,  6,  6]  1 */
    35563876, /* 66845 (1619) [ 1,  0,  0,  0,  0, -1,  0,  1,  0] [ 0,  6,  6] -1 */
    51152866, /* 66846 (1619) [ 1,  0,  0,  0,  0,  1,  0,  1,  0] [ 6,  0,  6] -1 */
    34022704, /* 66847 (1619) [ 0,  0,  1,  0, -1,  0, -1,  0,  0] [ 0,  0,  0] -1 */
        9040, /* 66848 (1619) [ 0,  0, -1,  0, -1,  0,  1,  0,  0] [ 0,  0,  0]  1 */
    18432328, /* 66849 (1619) [ 0,  0, -1,  0, -1,  0,  1,  0,  0] [ 6,  6,  0]  1 */
    52445992, /* 66850 (1619) [ 0,  0,  1,  0, -1,  0, -1,  0,  0] [ 6,  6,  0] -1 */
    52444870, /* 66851 (1619) [ 0,  0, -1,  1,  0,  0,  0,  1,  0] [ 6,  6,  0] -1 */
     1551706, /* 66852 (1619) [ 1,  0,  0,  0,  0,  1,  0,  1,  0] [ 0,  6,  6]  1 */
    18426650, /* 66853 (1619) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
       10330, /* 66854 (1619) [ 0,  0,  1, -1,  0,  0,  0,  1,  0] [ 0,  0,  0]  1 */
    18433618, /* 66855 (1619) [ 0,  0,  1, -1,  0,  0,  0,  1,  0] [ 6,  6,  0]  1 */
    34021246, /* 66856 (1619) [ 0,  0, -1,  0, -1,  0, -1,  0,  0] [ 0,  0,  0] -1 */
    35550802, /* 66857 (1619) [-1,  0,  0,  0,  0,  1,  0, -1,  0] [ 0,  6,  6] -1 */
    51148444, /* 66858 (1619) [ 0,  1,  0,  0,  0, -1,  1,  0,  0] [ 6,  0,  6] -1 */
    17133076, /* 66859 (1619) [ 0,  0, -1, -1,  0,  0,  0, -1,  0] [ 6,  0,  6]  1 */
    35550748, /* 66860 (1619) [-1,  0,  0,  0,  0, -1,  0, -1,  0] [ 0,  6,  6] -1 */
    35557822, /* 66861 (1619) [ 0,  0,  1, -1,  0,  0,  0, -1,  0] [ 0,  6,  6] -1 */
    52444378, /* 66862 (1619) [ 0,  0, -1, -1,  0,  0,  0, -1,  0] [ 6,  6,  0] -1 */
    18433948, /* 66863 (1619) [ 0,  0,  1,  0,  1,  0,  1,  0,  0] [ 6,  6,  0]  1 */
     1547284, /* 66864 (1619) [ 0,  1,  0,  0,  0, -1,  1,  0,  0] [ 0,  6,  6]  1 */
    18439608, /* 66865 (1619) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
    51143846, /* 66866 (1619) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 6,  0,  6] -1 */
    17136256, /* 66867 (1619) [ 0,  1,  0,  0,  0,  1, -1,  0,  0] [ 6,  0,  6]  1 */
    51152812, /* 66868 (1619) [ 1,  0,  0,  0,  0, -1,  0,  1,  0] [ 6,  0,  6] -1 */
    34021096, /* 66869 (1619) [ 0,  0, -1, -1,  0,  0,  0,  1,  0] [ 0,  0,  0] -1 */
     1547338, /* 66870 (1619) [ 0,  1,  0,  0,  0,  1,  1,  0,  0] [ 0,  6,  6]  1 */
    52444714, /* 66871 (1619) [ 0,  0, -1,  0,  1,  0,  1,  0,  0] [ 6,  6,  0] -1 */
    34024010, /* 66872 (1619) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    34028596, /* 66873 (1619) [ 1,  0,  0,  0,  0, -1,  0, -1,  0] [ 0,  0,  0] -1 */
        7636, /* 66874 (1619) [ 0, -1,  0,  0,  0, -1,  1,  0,  0] [ 0,  0,  0]  1 */
     1542686, /* 66875 (1619) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 0,  6,  6]  1 */
    18430924, /* 66876 (1619) [ 0, -1,  0,  0,  0, -1,  1,  0,  0] [ 6,  6,  0]  1 */
    18435074, /* 66877 (1619) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    34024216, /* 66878 (1619) [ 0,  1,  0,  0,  0, -1, -1,  0,  0] [ 0,  0,  0] -1 */
    51145786, /* 66879 (1619) [ 0,  0, -1,  1,  0,  0,  0, -1,  0] [ 6,  0,  6] -1 */
       10480, /* 66880 (1619) [ 0,  0,  1,  0, -1,  0, -1,  0,  0] [ 0,  0,  0]  1 */
    18433768, /* 66881 (1619) [ 0,  0,  1,  0, -1,  0, -1,  0,  0] [ 6,  6,  0]  1 */
    18432646, /* 66882 (1619) [ 0,  0, -1,  1,  0,  0,  0,  1,  0] [ 6,  6,  0]  1 */
    35557828, /* 66883 (1619) [ 0,  0,  1, -1,  0,  0,  0,  1,  0] [ 0,  6,  6] -1 */
       16426, /* 66884 (1619) [ 1,  0,  0,  0,  0,  1,  0, -1,  0] [ 0,  0,  0]  1 */
     1544626, /* 66885 (1619) [ 0,  0, -1,  1,  0,  0,  0, -1,  0] [ 0,  6,  6]  1 */
        3200, /* 66886 (1619) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    51139738, /* 66887 (1619) [-1,  0,  0,  0,  0,  1,  0, -1,  0] [ 6,  0,  6] -1 */
    35550808, /* 66888 (1619) [-1,  0,  0,  0,  0,  1,  0,  1,  0] [ 0,  6,  6] -1 */
    51139684, /* 66889 (1619) [-1,  0,  0,  0,  0, -1,  0, -1,  0] [ 6,  0,  6] -1 */
    51146758, /* 66890 (1619) [ 0,  0,  1, -1,  0,  0,  0, -1,  0] [ 6,  0,  6] -1 */
       16484, /* 66891 (1620) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
       10660, /* 66892 (1620) [ 0,  0,  1,  0,  1,  0,  1,  0,  0] [ 0,  0,  0]  1 */
    17140694, /* 66893 (1620) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
     1545754, /* 66894 (1620) [ 0,  0,  1,  0, -1,  0, -1,  0,  0] [ 0,  6,  6]  1 */
       16320, /* 66895 (1620) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
     1538578, /* 66896 (1620) [-1,  0,  0,  0,  0,  1,  0, -1,  0] [ 0,  6,  6]  1 */
    17135994, /* 66897 (1620) [ 0,  1,  0, -1,  0,  0,  0,  0, -1] [ 6,  0,  6]  1 */
     1545598, /* 66898 (1620) [ 0,  0,  1, -1,  0,  0,  0, -1,  0] [ 0,  6,  6]  1 */
       16432, /* 66899 (1620) [ 1,  0,  0,  0,  0,  1,  0,  1,  0] [ 0,  0,  0]  1 */
    51139632, /* 66900 (1620) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  6] -1 */
    52443410, /* 66901 (1620) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 6,  6,  0] -1 */
    52451834, /* 66902 (1620) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
        3256, /* 66903 (1620) [-1,  0,  0,  0,  0, -1,  0,  1,  0] [ 0,  0,  0]  1 */
     1538474, /* 66904 (1620) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
    17136274, /* 66905 (1620) [ 0,  1,  0,  0,  0,  1,  1,  0,  0] [ 6,  0,  6]  1 */
    52445842, /* 66906 (1620) [ 0,  0,  1, -1,  0,  0,  0,  1,  0] [ 6,  6,  0] -1 */
        9184, /* 66907 (1620) [ 0,  0, -1,  0,  1,  0, -1,  0,  0] [ 0,  0,  0]  1 */
    34024234, /* 66908 (1620) [ 0,  1,  0,  0,  0, -1,  1,  0,  0] [ 0,  0,  0] -1 */
    34020122, /* 66909 (1620) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 0,  0,  0] -1 */
        9352, /* 66910 (1620) [ 0,  0, -1,  1,  0,  0,  0, -1,  0] [ 0,  0,  0]  1 */
    51143844, /* 66911 (1620) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 6,  0,  6] -1 */
    17131622, /* 66912 (1620) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 6,  0,  6]  1 */
    18431184, /* 66913 (1620) [ 0, -1,  0,  1,  0,  0,  0,  0, -1] [ 6,  6,  0]  1 */
    18426648, /* 66914 (1620) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
        8872, /* 66915 (1620) [ 0,  0, -1, -1,  0,  0,  0,  1,  0] [ 0,  0,  0]  1 */
    18432160, /* 66916 (1620) [ 0,  0, -1, -1,  0,  0,  0,  1,  0] [ 6,  6,  0]  1 */
    17140642, /* 66917 (1620) [ 1,  0,  0,  0,  0,  1,  0,  1,  0] [ 6,  0,  6]  1 */
    52447782, /* 66918 (1620) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 6,  6,  0] -1 */
       16372, /* 66919 (1620) [ 1,  0,  0,  0,  0, -1,  0, -1,  0] [ 0,  0,  0]  1 */
    18439660, /* 66920 (1620) [ 1,  0,  0,  0,  0, -1,  0, -1,  0] [ 6,  6,  0]  1 */
    35555396, /* 66921 (1620) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 0,  6,  6] -1 */
    51146764, /* 66922 (1620) [ 0,  0,  1, -1,  0,  0,  0,  1,  0] [ 6,  0,  6] -1 */
    35563820, /* 66923 (1620) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
    18426592, /* 66924 (1620) [-1,  0,  0,  0,  0,  1,  0, -1,  0] [ 6,  6,  0]  1 */
    18433612, /* 66925 (1620) [ 0,  0,  1, -1,  0,  0,  0, -1,  0] [ 6,  6,  0]  1 */
    34024494, /* 66926 (1620) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    17133562, /* 66927 (1620) [ 0,  0, -1,  1,  0,  0,  0, -1,  0] [ 6,  0,  6]  1 */
    52443202, /* 66928 (1620) [ 0, -1,  0,  0,  0,  1,  1,  0,  0] [ 6,  6,  0] -1 */
    34023034, /* 66929 (1620) [ 0,  0,  1,  1,  0,  0,  0, -1,  0] [ 0,  0,  0] -1 */
    52446322, /* 66930 (1620) [ 0,  0,  1,  1,  0,  0,  0, -1,  0] [ 6,  6,  0] -1 */
    17131846, /* 66931 (1620) [ 0, -1,  0,  0,  0, -1,  1,  0,  0] [ 6,  0,  6]  1 */
        3304, /* 66932 (1620) [-1,  0,  0,  0,  0,  1,  0, -1,  0] [ 0,  0,  0]  1 */
     1543170, /* 66933 (1620) [ 0, -1,  0,  1,  0,  0,  0,  0, -1] [ 0,  6,  6]  1 */
       10324, /* 66934 (1620) [ 0,  0,  1, -1,  0,  0,  0, -1,  0] [ 0,  0,  0]  1 */
     1538634, /* 66935 (1620) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
     1544146, /* 66936 (1620) [ 0,  0, -1, -1,  0,  0,  0,  1,  0] [ 0,  6,  6]  1 */
    17134690, /* 66937 (1620) [ 0,  0,  1,  0, -1,  0, -1,  0,  0] [ 6,  0,  6]  1 */
    52447298, /* 66938 (1620) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 6,  6,  0] -1 */
     1551646, /* 66939 (1620) [ 1,  0,  0,  0,  0, -1,  0, -1,  0] [ 0,  6,  6]  1 */
    17127514, /* 66940 (1620) [-1,  0,  0,  0,  0,  1,  0, -1,  0] [ 6,  0,  6]  1 */
    18432472, /* 66941 (1620) [ 0,  0, -1,  0,  1,  0, -1,  0,  0] [ 6,  6,  0]  1 */
    17134534, /* 66942 (1620) [ 0,  0,  1, -1,  0,  0,  0, -1,  0] [ 6,  0,  6]  1 */
    52447522, /* 66943 (1620) [ 0,  1,  0,  0,  0, -1,  1,  0,  0] [ 6,  6,  0] -1 */
    34022866, /* 66944 (1620) [ 0,  0,  1,  0,  1,  0, -1,  0,  0] [ 0,  0,  0] -1 */
    52446154, /* 66945 (1620) [ 0,  0,  1,  0,  1,  0, -1,  0,  0] [ 6,  6,  0] -1 */
    52438874, /* 66946 (1620) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
    34028650, /* 66947 (1620) [ 1,  0,  0,  0,  0,  1,  0, -1,  0] [ 0,  0,  0] -1 */
    34022554, /* 66948 (1620) [ 0,  0,  1, -1,  0,  0,  0,  1,  0] [ 0,  0,  0] -1 */
    35555188, /* 66949 (1620) [ 0, -1,  0,  0,  0,  1,  1,  0,  0] [ 0,  6,  6] -1 */
    35558308, /* 66950 (1620) [ 0,  0,  1,  1,  0,  0,  0, -1,  0] [ 0,  6,  6] -1 */
    34024270, /* 66951 (1620) [ 0,  1,  0,  0,  0,  1, -1,  0,  0] [ 0,  0,  0] -1 */
    17134870, /* 66952 (1620) [ 0,  0,  1,  0,  1,  0,  1,  0,  0] [ 6,  0,  6]  1 */
    52447558, /* 66953 (1620) [ 0,  1,  0,  0,  0,  1, -1,  0,  0] [ 6,  6,  0] -1 */
    18439772, /* 66954 (1620) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    34021582, /* 66955 (1620) [ 0,  0, -1,  1,  0,  0,  0,  1,  0] [ 0,  0,  0] -1 */
    17140530, /* 66956 (1620) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  6]  1 */
    51145300, /* 66957 (1620) [ 0,  0, -1, -1,  0,  0,  0, -1,  0] [ 6,  0,  6] -1 */
    34015586, /* 66958 (1620) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    17127466, /* 66959 (1620) [-1,  0,  0,  0,  0, -1,  0,  1,  0] [ 6,  0,  6]  1 */
        7896, /* 66960 (1620) [ 0, -1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    52451890, /* 66961 (1620) [ 1,  0,  0,  0,  0, -1,  0,  1,  0] [ 6,  6,  0] -1 */
    34028706, /* 66962 (1620) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    52451994, /* 66963 (1620) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
    18430960, /* 66964 (1620) [ 0, -1,  0,  0,  0,  1, -1,  0,  0] [ 6,  6,  0]  1 */
    34019842, /* 66965 (1620) [ 0, -1,  0,  0,  0, -1, -1,  0,  0] [ 0,  0,  0] -1 */
    52443130, /* 66966 (1620) [ 0, -1,  0,  0,  0, -1, -1,  0,  0] [ 6,  6,  0] -1 */
    35556856, /* 66967 (1620) [ 0,  0, -1,  1,  0,  0,  0,  1,  0] [ 0,  6,  6] -1 */
    18435280, /* 66968 (1620) [ 0,  1,  0,  0,  0, -1, -1,  0,  0] [ 6,  6,  0]  1 */
     1544458, /* 66969 (1620) [ 0,  0, -1,  0,  1,  0, -1,  0,  0] [ 0,  6,  6]  1 */
    18435352, /* 66970 (1620) [ 0,  1,  0,  0,  0,  1,  1,  0,  0] [ 6,  6,  0]  1 */
    52444534, /* 66971 (1620) [ 0,  0, -1,  0, -1,  0, -1,  0,  0] [ 6,  6,  0] -1 */
    35559508, /* 66972 (1620) [ 0,  1,  0,  0,  0, -1,  1,  0,  0] [ 0,  6,  6] -1 */
    35558140, /* 66973 (1620) [ 0,  0,  1,  0,  1,  0, -1,  0,  0] [ 0,  6,  6] -1 */
    34028602, /* 66974 (1620) [ 1,  0,  0,  0,  0, -1,  0,  1,  0] [ 0,  0,  0] -1 */
       10816, /* 66975 (1620) [ 0,  0,  1,  1,  0,  0,  0,  1,  0] [ 0,  0,  0]  1 */
    34015422, /* 66976 (1620) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    18434104, /* 66977 (1620) [ 0,  0,  1,  1,  0,  0,  0,  1,  0] [ 6,  6,  0]  1 */
    52438710, /* 66978 (1620) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
    35550860, /* 66979 (1620) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
    51139744, /* 66980 (1620) [-1,  0,  0,  0,  0,  1,  0,  1,  0] [ 6,  0,  6] -1 */
    18435560, /* 66981 (1620) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    51152756, /* 66982 (1620) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
    51148480, /* 66983 (1620) [ 0,  1,  0,  0,  0,  1, -1,  0,  0] [ 6,  0,  6] -1 */
       11992, /* 66984 (1620) [ 0,  1,  0,  0,  0, -1, -1,  0,  0] [ 0,  0,  0]  1 */
       12064, /* 66985 (1620) [ 0,  1,  0,  0,  0,  1,  1,  0,  0] [ 0,  0,  0]  1 */
     1551758, /* 66986 (1620) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
    34019914, /* 66987 (1620) [ 0, -1,  0,  0,  0,  1,  1,  0,  0] [ 0,  0,  0] -1 */
    18439720, /* 66988 (1620) [ 1,  0,  0,  0,  0,  1,  0,  1,  0] [ 6,  6,  0]  1 */
    52442922, /* 66989 (1620) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 6,  6,  0] -1 */
    17132106, /* 66990 (1620) [ 0, -1,  0,  1,  0,  0,  0,  0, -1] [ 6,  0,  6]  1 */
    17127570, /* 66991 (1620) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6]  1 */
    35563876, /* 66992 (1620) [ 1,  0,  0,  0,  0, -1,  0,  1,  0] [ 0,  6,  6] -1 */
     1542946, /* 66993 (1620) [ 0, -1,  0,  0,  0,  1, -1,  0,  0] [ 0,  6,  6]  1 */
    35563980, /* 66994 (1620) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6] -1 */
    17133082, /* 66995 (1620) [ 0,  0, -1, -1,  0,  0,  0,  1,  0] [ 6,  0,  6]  1 */
    35555116, /* 66996 (1620) [ 0, -1,  0,  0,  0, -1, -1,  0,  0] [ 0,  6,  6] -1 */
     1547266, /* 66997 (1620) [ 0,  1,  0,  0,  0, -1, -1,  0,  0] [ 0,  6,  6]  1 */
    35559768, /* 66998 (1620) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 0,  6,  6] -1 */
    17136482, /* 66999 (1620) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 6,  0,  6]  1 */
    35556520, /* 67000 (1620) [ 0,  0, -1,  0, -1,  0, -1,  0,  0] [ 0,  6,  6] -1 */
    17140582, /* 67001 (1620) [ 1,  0,  0,  0,  0, -1,  0, -1,  0] [ 6,  0,  6]  1 */
    52451938, /* 67002 (1620) [ 1,  0,  0,  0,  0,  1,  0, -1,  0] [ 6,  6,  0] -1 */
        9040, /* 67003 (1620) [ 0,  0, -1,  0, -1,  0,  1,  0,  0] [ 0,  0,  0]  1 */
     1547546, /* 67004 (1620) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 0,  6,  6]  1 */
     1546090, /* 67005 (1620) [ 0,  0,  1,  1,  0,  0,  0,  1,  0] [ 0,  6,  6]  1 */
    35550696, /* 67006 (1620) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  6] -1 */
    18432328, /* 67007 (1620) [ 0,  0, -1,  0, -1,  0,  1,  0,  0] [ 6,  6,  0]  1 */
    52444870, /* 67008 (1620) [ 0,  0, -1,  1,  0,  0,  0,  1,  0] [ 6,  6,  0] -1 */
    34015474, /* 67009 (1620) [-1,  0,  0,  0,  0, -1,  0, -1,  0] [ 0,  0,  0] -1 */
    52438762, /* 67010 (1620) [-1,  0,  0,  0,  0, -1,  0, -1,  0] [ 6,  6,  0] -1 */
    34028546, /* 67011 (1620) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
     1551706, /* 67012 (1620) [ 1,  0,  0,  0,  0,  1,  0,  1,  0] [ 0,  6,  6]  1 */
    35554908, /* 67013 (1620) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 0,  6,  6] -1 */
       11784, /* 67014 (1620) [ 0,  1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    18435072, /* 67015 (1620) [ 0,  1,  0, -1,  0,  0,  0,  0, -1] [ 6,  6,  0]  1 */
    35556700, /* 67016 (1620) [ 0,  0, -1,  0,  1,  0,  1,  0,  0] [ 0,  6,  6] -1 */
        7672, /* 67017 (1620) [ 0, -1,  0,  0,  0,  1, -1,  0,  0] [ 0,  0,  0]  1 */
    34022722, /* 67018 (1620) [ 0,  0,  1,  0, -1,  0,  1,  0,  0] [ 0,  0,  0] -1 */
    52446010, /* 67019 (1620) [ 0,  0,  1,  0, -1,  0,  1,  0,  0] [ 6,  6,  0] -1 */
    35559284, /* 67020 (1620) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 0,  6,  6] -1 */
        3360, /* 67021 (1620) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    35563924, /* 67022 (1620) [ 1,  0,  0,  0,  0,  1,  0, -1,  0] [ 0,  6,  6] -1 */
    51145792, /* 67023 (1620) [ 0,  0, -1,  1,  0,  0,  0,  1,  0] [ 6,  0,  6] -1 */
    18426488, /* 67024 (1620) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    34021246, /* 67025 (1620) [ 0,  0, -1,  0, -1,  0, -1,  0,  0] [ 0,  0,  0] -1 */
    17133394, /* 67026 (1620) [ 0,  0, -1,  0,  1,  0, -1,  0,  0] [ 6,  0,  6]  1 */
     1544314, /* 67027 (1620) [ 0,  0, -1,  0, -1,  0,  1,  0,  0] [ 0,  6,  6]  1 */
    51148444, /* 67028 (1620) [ 0,  1,  0,  0,  0, -1,  1,  0,  0] [ 6,  0,  6] -1 */
    51144332, /* 67029 (1620) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 6,  0,  6] -1 */
       12272, /* 67030 (1620) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    35550748, /* 67031 (1620) [-1,  0,  0,  0,  0, -1,  0, -1,  0] [ 0,  6,  6] -1 */
        7412, /* 67032 (1620) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    51139796, /* 67033 (1620) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
    52444378, /* 67034 (1620) [ 0,  0, -1, -1,  0,  0,  0, -1,  0] [ 6,  6,  0] -1 */
    18430700, /* 67035 (1620) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    18426544, /* 67036 (1620) [-1,  0,  0,  0,  0, -1,  0,  1,  0] [ 6,  6,  0]  1 */
    18433948, /* 67037 (1620) [ 0,  0,  1,  0,  1,  0,  1,  0,  0] [ 6,  6,  0]  1 */
    18439608, /* 67038 (1620) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
    34019634, /* 67039 (1620) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  0] -1 */
     1547058, /* 67040 (1620) [ 0,  1,  0, -1,  0,  0,  0,  0, -1] [ 0,  6,  6]  1 */
    51146932, /* 67041 (1620) [ 0,  0,  1,  0, -1,  0,  1,  0,  0] [ 6,  0,  6] -1 */
    51152812, /* 67042 (1620) [ 1,  0,  0,  0,  0, -1,  0,  1,  0] [ 6,  0,  6] -1 */
    35557996, /* 67043 (1620) [ 0,  0,  1,  0, -1,  0,  1,  0,  0] [ 0,  6,  6] -1 */
    17127410, /* 67044 (1620) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
    51152916, /* 67045 (1620) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6] -1 */
    17131882, /* 67046 (1620) [ 0, -1,  0,  0,  0,  1, -1,  0,  0] [ 6,  0,  6]  1 */
    51144052, /* 67047 (1620) [ 0, -1,  0,  0,  0, -1, -1,  0,  0] [ 6,  0,  6] -1 */
    17136202, /* 67048 (1620) [ 0,  1,  0,  0,  0, -1, -1,  0,  0] [ 6,  0,  6]  1 */
     1547338, /* 67049 (1620) [ 0,  1,  0,  0,  0,  1,  1,  0,  0] [ 0,  6,  6]  1 */
    51148704, /* 67050 (1620) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 6,  0,  6] -1 */
    52444714, /* 67051 (1620) [ 0,  0, -1,  0,  1,  0,  1,  0,  0] [ 6,  6,  0] -1 */
    18432640, /* 67052 (1620) [ 0,  0, -1,  1,  0,  0,  0, -1,  0] [ 6,  6,  0]  1 */
    51145456, /* 67053 (1620) [ 0,  0, -1,  0, -1,  0, -1,  0,  0] [ 6,  0,  6] -1 */
    34024010, /* 67054 (1620) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    51147244, /* 67055 (1620) [ 0,  0,  1,  1,  0,  0,  0, -1,  0] [ 6,  0,  6] -1 */
    17135026, /* 67056 (1620) [ 0,  0,  1,  1,  0,  0,  0,  1,  0] [ 6,  0,  6]  1 */
        7636, /* 67057 (1620) [ 0, -1,  0,  0,  0, -1,  1,  0,  0] [ 0,  0,  0]  1 */
     1542686, /* 67058 (1620) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 0,  6,  6]  1 */
    35556364, /* 67059 (1620) [ 0,  0, -1, -1,  0,  0,  0, -1,  0] [ 0,  6,  6] -1 */
    18430924, /* 67060 (1620) [ 0, -1,  0,  0,  0, -1,  1,  0,  0] [ 6,  6,  0]  1 */
    34015534, /* 67061 (1620) [-1,  0,  0,  0,  0,  1,  0,  1,  0] [ 0,  0,  0] -1 */
    52438822, /* 67062 (1620) [-1,  0,  0,  0,  0,  1,  0,  1,  0] [ 6,  6,  0] -1 */
     1538530, /* 67063 (1620) [-1,  0,  0,  0,  0, -1,  0,  1,  0] [ 0,  6,  6]  1 */
    34021426, /* 67064 (1620) [ 0,  0, -1,  0,  1,  0,  1,  0,  0] [ 0,  0,  0] -1 */
     1545934, /* 67065 (1620) [ 0,  0,  1,  0,  1,  0,  1,  0,  0] [ 0,  6,  6]  1 */
    51144124, /* 67066 (1620) [ 0, -1,  0,  0,  0,  1,  1,  0,  0] [ 6,  0,  6] -1 */
     1551594, /* 67067 (1620) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
       10480, /* 67068 (1620) [ 0,  0,  1,  0, -1,  0, -1,  0,  0] [ 0,  0,  0]  1 */
    18433768, /* 67069 (1620) [ 0,  0,  1,  0, -1,  0, -1,  0,  0] [ 6,  6,  0]  1 */
    35557828, /* 67070 (1620) [ 0,  0,  1, -1,  0,  0,  0,  1,  0] [ 0,  6,  6] -1 */
    51145636, /* 67071 (1620) [ 0,  0, -1,  0,  1,  0,  1,  0,  0] [ 6,  0,  6] -1 */
    51147076, /* 67072 (1620) [ 0,  0,  1,  0,  1,  0, -1,  0,  0] [ 6,  0,  6] -1 */
    35559544, /* 67073 (1620) [ 0,  1,  0,  0,  0,  1, -1,  0,  0] [ 0,  6,  6] -1 */
    51148220, /* 67074 (1620) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 6,  0,  6] -1 */
     1544626, /* 67075 (1620) [ 0,  0, -1,  1,  0,  0,  0, -1,  0] [ 0,  6,  6]  1 */
        3200, /* 67076 (1620) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    51152860, /* 67077 (1620) [ 1,  0,  0,  0,  0,  1,  0, -1,  0] [ 6,  0,  6] -1 */
    17133250, /* 67078 (1620) [ 0,  0, -1,  0, -1,  0,  1,  0,  0] [ 6,  0,  6]  1 */
     1542910, /* 67079 (1620) [ 0, -1,  0,  0,  0, -1,  1,  0,  0] [ 0,  6,  6]  1 */
    35550808, /* 67080 (1620) [-1,  0,  0,  0,  0,  1,  0,  1,  0] [ 0,  6,  6] -1 */
    51139684, /* 67081 (1620) [-1,  0,  0,  0,  0, -1,  0, -1,  0] [ 6,  0,  6] -1 */
    34021090, /* 67082 (1620) [ 0,  0, -1, -1,  0,  0,  0, -1,  0] [ 0,  0,  0] -1 */
       16484, /* 67083 (1621) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    17140694, /* 67084 (1621) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
    17133568, /* 67085 (1621) [ 0,  0, -1,  1,  0,  0,  0,  1,  0] [ 6,  0,  6]  1 */
       16320, /* 67086 (1621) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    17136220, /* 67087 (1621) [ 0,  1,  0,  0,  0, -1,  1,  0,  0] [ 6,  0,  6]  1 */
    51147094, /* 67088 (1621) [ 0,  0,  1,  0,  1,  0,  1,  0,  0] [ 6,  0,  6] -1 */
        3198, /* 67089 (1621) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
     1545598, /* 67090 (1621) [ 0,  0,  1, -1,  0,  0,  0, -1,  0] [ 0,  6,  6]  1 */
    17140532, /* 67091 (1621) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
    52443410, /* 67092 (1621) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 6,  6,  0] -1 */
    52447296, /* 67093 (1621) [ 0,  1,  0, -1,  0,  0,  0,  0, -1] [ 6,  6,  0] -1 */
    34020120, /* 67094 (1621) [ 0, -1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  0] -1 */
     1538474, /* 67095 (1621) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
    17136274, /* 67096 (1621) [ 0,  1,  0,  0,  0,  1,  1,  0,  0] [ 6,  0,  6]  1 */
    35556538, /* 67097 (1621) [ 0,  0, -1,  0, -1,  0,  1,  0,  0] [ 0,  6,  6] -1 */
    34020122, /* 67098 (1621) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 0,  0,  0] -1 */
        9352, /* 67099 (1621) [ 0,  0, -1,  1,  0,  0,  0, -1,  0] [ 0,  0,  0]  1 */
    51143844, /* 67100 (1621) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 6,  0,  6] -1 */
    34024496, /* 67101 (1621) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    52447784, /* 67102 (1621) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 6,  6,  0] -1 */
    17131828, /* 67103 (1621) [ 0, -1,  0,  0,  0, -1, -1,  0,  0] [ 6,  0,  6]  1 */
    18426648, /* 67104 (1621) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
        8872, /* 67105 (1621) [ 0,  0, -1, -1,  0,  0,  0,  1,  0] [ 0,  0,  0]  1 */
    18432160, /* 67106 (1621) [ 0,  0, -1, -1,  0,  0,  0,  1,  0] [ 6,  6,  0]  1 */
    52447782, /* 67107 (1621) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 6,  6,  0] -1 */
    17135020, /* 67108 (1621) [ 0,  0,  1,  1,  0,  0,  0, -1,  0] [ 6,  0,  6]  1 */
    52451944, /* 67109 (1621) [ 1,  0,  0,  0,  0,  1,  0,  1,  0] [ 6,  6,  0] -1 */
    35555396, /* 67110 (1621) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 0,  6,  6] -1 */
    35559282, /* 67111 (1621) [ 0,  1,  0, -1,  0,  0,  0,  0, -1] [ 0,  6,  6] -1 */
    17131900, /* 67112 (1621) [ 0, -1,  0,  0,  0,  1,  1,  0,  0] [ 6,  0,  6]  1 */
    18433612, /* 67113 (1621) [ 0,  0,  1, -1,  0,  0,  0, -1,  0] [ 6,  6,  0]  1 */
    34024494, /* 67114 (1621) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    17133562, /* 67115 (1621) [ 0,  0, -1,  1,  0,  0,  0, -1,  0] [ 6,  0,  6]  1 */
    51148706, /* 67116 (1621) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 6,  0,  6] -1 */
    17131846, /* 67117 (1621) [ 0, -1,  0,  0,  0, -1,  1,  0,  0] [ 6,  0,  6]  1 */
    34021264, /* 67118 (1621) [ 0,  0, -1,  0, -1,  0,  1,  0,  0] [ 0,  0,  0] -1 */
    35559770, /* 67119 (1621) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 0,  6,  6] -1 */
       10324, /* 67120 (1621) [ 0,  0,  1, -1,  0,  0,  0, -1,  0] [ 0,  0,  0]  1 */
     1538634, /* 67121 (1621) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
     1544146, /* 67122 (1621) [ 0,  0, -1, -1,  0,  0,  0,  1,  0] [ 0,  6,  6]  1 */
    52447298, /* 67123 (1621) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 6,  6,  0] -1 */
    35563930, /* 67124 (1621) [ 1,  0,  0,  0,  0,  1,  0,  1,  0] [ 0,  6,  6] -1 */
    17134534, /* 67125 (1621) [ 0,  0,  1, -1,  0,  0,  0, -1,  0] [ 6,  0,  6]  1 */
        8866, /* 67126 (1621) [ 0,  0, -1, -1,  0,  0,  0, -1,  0] [ 0,  0,  0]  1 */
    17127572, /* 67127 (1621) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
    18432154, /* 67128 (1621) [ 0,  0, -1, -1,  0,  0,  0, -1,  0] [ 6,  6,  0]  1 */
    34024008, /* 67129 (1621) [ 0,  1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    34022866, /* 67130 (1621) [ 0,  0,  1,  0,  1,  0, -1,  0,  0] [ 0,  0,  0] -1 */
    52446154, /* 67131 (1621) [ 0,  0,  1,  0,  1,  0, -1,  0,  0] [ 6,  6,  0] -1 */
    34028650, /* 67132 (1621) [ 1,  0,  0,  0,  0,  1,  0, -1,  0] [ 0,  0,  0] -1 */
    18439772, /* 67133 (1621) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    17140530, /* 67134 (1621) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  6]  1 */
    51145618, /* 67135 (1621) [ 0,  0, -1,  0,  1,  0, -1,  0,  0] [ 6,  0,  6] -1 */
    17127408, /* 67136 (1621) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  6]  1 */
    17140692, /* 67137 (1621) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6]  1 */
    18439610, /* 67138 (1621) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    34019636, /* 67139 (1621) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    52442924, /* 67140 (1621) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 6,  6,  0] -1 */
    52451890, /* 67141 (1621) [ 1,  0,  0,  0,  0, -1,  0,  1,  0] [ 6,  6,  0] -1 */
    18430960, /* 67142 (1621) [ 0, -1,  0,  0,  0,  1, -1,  0,  0] [ 6,  6,  0]  1 */
    52438768, /* 67143 (1621) [-1,  0,  0,  0,  0, -1,  0,  1,  0] [ 6,  6,  0] -1 */
    18435280, /* 67144 (1621) [ 0,  1,  0,  0,  0, -1, -1,  0,  0] [ 6,  6,  0]  1 */
    34022884, /* 67145 (1621) [ 0,  0,  1,  0,  1,  0,  1,  0,  0] [ 0,  0,  0] -1 */
    52446172, /* 67146 (1621) [ 0,  0,  1,  0,  1,  0,  1,  0,  0] [ 6,  6,  0] -1 */
    18435352, /* 67147 (1621) [ 0,  1,  0,  0,  0,  1,  1,  0,  0] [ 6,  6,  0]  1 */
    52444534, /* 67148 (1621) [ 0,  0, -1,  0, -1,  0, -1,  0,  0] [ 6,  6,  0] -1 */
     1544140, /* 67149 (1621) [ 0,  0, -1, -1,  0,  0,  0, -1,  0] [ 0,  6,  6]  1 */
    35558140, /* 67150 (1621) [ 0,  0,  1,  0,  1,  0, -1,  0,  0] [ 0,  6,  6] -1 */
    34028602, /* 67151 (1621) [ 1,  0,  0,  0,  0, -1,  0,  1,  0] [ 0,  0,  0] -1 */
    51148218, /* 67152 (1621) [ 0,  1,  0, -1,  0,  0,  0,  0, -1] [ 6,  0,  6] -1 */
       10816, /* 67153 (1621) [ 0,  0,  1,  1,  0,  0,  0,  1,  0] [ 0,  0,  0]  1 */
    18434104, /* 67154 (1621) [ 0,  0,  1,  1,  0,  0,  0,  1,  0] [ 6,  6,  0]  1 */
    51139744, /* 67155 (1621) [-1,  0,  0,  0,  0,  1,  0,  1,  0] [ 6,  0,  6] -1 */
       11992, /* 67156 (1621) [ 0,  1,  0,  0,  0, -1, -1,  0,  0] [ 0,  0,  0]  1 */
       12064, /* 67157 (1621) [ 0,  1,  0,  0,  0,  1,  1,  0,  0] [ 0,  0,  0]  1 */
     1551758, /* 67158 (1621) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
    52442922, /* 67159 (1621) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 6,  6,  0] -1 */
     1545604, /* 67160 (1621) [ 0,  0,  1, -1,  0,  0,  0,  1,  0] [ 0,  6,  6]  1 */
    35554910, /* 67161 (1621) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 0,  6,  6] -1 */
    17127570, /* 67162 (1621) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6]  1 */
     1547320, /* 67163 (1621) [ 0,  1,  0,  0,  0,  1, -1,  0,  0] [ 0,  6,  6]  1 */
    35563876, /* 67164 (1621) [ 1,  0,  0,  0,  0, -1,  0,  1,  0] [ 0,  6,  6] -1 */
     1542946, /* 67165 (1621) [ 0, -1,  0,  0,  0,  1, -1,  0,  0] [ 0,  6,  6]  1 */
    17133082, /* 67166 (1621) [ 0,  0, -1, -1,  0,  0,  0,  1,  0] [ 6,  0,  6]  1 */
    52443408, /* 67167 (1621) [ 0, -1,  0,  1,  0,  0,  0,  0, -1] [ 6,  6,  0] -1 */
    35550754, /* 67168 (1621) [-1,  0,  0,  0,  0, -1,  0,  1,  0] [ 0,  6,  6] -1 */
     1547266, /* 67169 (1621) [ 0,  1,  0,  0,  0, -1, -1,  0,  0] [ 0,  6,  6]  1 */
    35559768, /* 67170 (1621) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 0,  6,  6] -1 */
    35558158, /* 67171 (1621) [ 0,  0,  1,  0,  1,  0,  1,  0,  0] [ 0,  6,  6] -1 */
    35556520, /* 67172 (1621) [ 0,  0, -1,  0, -1,  0, -1,  0,  0] [ 0,  6,  6] -1 */
    18434098, /* 67173 (1621) [ 0,  0,  1,  1,  0,  0,  0, -1,  0] [ 6,  6,  0]  1 */
    51152866, /* 67174 (1621) [ 1,  0,  0,  0,  0,  1,  0,  1,  0] [ 6,  0,  6] -1 */
    52451938, /* 67175 (1621) [ 1,  0,  0,  0,  0,  1,  0, -1,  0] [ 6,  6,  0] -1 */
    34022704, /* 67176 (1621) [ 0,  0,  1,  0, -1,  0, -1,  0,  0] [ 0,  0,  0] -1 */
    52445992, /* 67177 (1621) [ 0,  0,  1,  0, -1,  0, -1,  0,  0] [ 6,  6,  0] -1 */
     1546090, /* 67178 (1621) [ 0,  0,  1,  1,  0,  0,  0,  1,  0] [ 0,  6,  6]  1 */
    52451884, /* 67179 (1621) [ 1,  0,  0,  0,  0, -1,  0, -1,  0] [ 6,  6,  0] -1 */
    34015474, /* 67180 (1621) [-1,  0,  0,  0,  0, -1,  0, -1,  0] [ 0,  0,  0] -1 */
    52438762, /* 67181 (1621) [-1,  0,  0,  0,  0, -1,  0, -1,  0] [ 6,  6,  0] -1 */
    35554908, /* 67182 (1621) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 0,  6,  6] -1 */
    51145474, /* 67183 (1621) [ 0,  0, -1,  0, -1,  0,  1,  0,  0] [ 6,  0,  6] -1 */
    18435298, /* 67184 (1621) [ 0,  1,  0,  0,  0, -1,  1,  0,  0] [ 6,  6,  0]  1 */
    34015528, /* 67185 (1621) [-1,  0,  0,  0,  0,  1,  0, -1,  0] [ 0,  0,  0] -1 */
    35555394, /* 67186 (1621) [ 0, -1,  0,  1,  0,  0,  0,  0, -1] [ 0,  6,  6] -1 */
    35556700, /* 67187 (1621) [ 0,  0, -1,  0,  1,  0,  1,  0,  0] [ 0,  6,  6] -1 */
    18426650, /* 67188 (1621) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
        7672, /* 67189 (1621) [ 0, -1,  0,  0,  0,  1, -1,  0,  0] [ 0,  0,  0]  1 */
    34022722, /* 67190 (1621) [ 0,  0,  1,  0, -1,  0,  1,  0,  0] [ 0,  0,  0] -1 */
    52446010, /* 67191 (1621) [ 0,  0,  1,  0, -1,  0,  1,  0,  0] [ 6,  6,  0] -1 */
       10330, /* 67192 (1621) [ 0,  0,  1, -1,  0,  0,  0,  1,  0] [ 0,  0,  0]  1 */
    35559284, /* 67193 (1621) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 0,  6,  6] -1 */
        3360, /* 67194 (1621) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    18433618, /* 67195 (1621) [ 0,  0,  1, -1,  0,  0,  0,  1,  0] [ 6,  6,  0]  1 */
     1546084, /* 67196 (1621) [ 0,  0,  1,  1,  0,  0,  0, -1,  0] [ 0,  6,  6]  1 */
       12010, /* 67197 (1621) [ 0,  1,  0,  0,  0, -1,  1,  0,  0] [ 0,  0,  0]  1 */
    35563924, /* 67198 (1621) [ 1,  0,  0,  0,  0,  1,  0, -1,  0] [ 0,  6,  6] -1 */
       12046, /* 67199 (1621) [ 0,  1,  0,  0,  0,  1, -1,  0,  0] [ 0,  0,  0]  1 */
    35557978, /* 67200 (1621) [ 0,  0,  1,  0, -1,  0, -1,  0,  0] [ 0,  6,  6] -1 */
    18426488, /* 67201 (1621) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    34021246, /* 67202 (1621) [ 0,  0, -1,  0, -1,  0, -1,  0,  0] [ 0,  0,  0] -1 */
    35563870, /* 67203 (1621) [ 1,  0,  0,  0,  0, -1,  0, -1,  0] [ 0,  6,  6] -1 */
    18435334, /* 67204 (1621) [ 0,  1,  0,  0,  0,  1, -1,  0,  0] [ 6,  6,  0]  1 */
    35550802, /* 67205 (1621) [-1,  0,  0,  0,  0,  1,  0, -1,  0] [ 0,  6,  6] -1 */
    17133076, /* 67206 (1621) [ 0,  0, -1, -1,  0,  0,  0, -1,  0] [ 6,  0,  6]  1 */
        3362, /* 67207 (1621) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    51144332, /* 67208 (1621) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 6,  0,  6] -1 */
    35550748, /* 67209 (1621) [-1,  0,  0,  0,  0, -1,  0, -1,  0] [ 0,  6,  6] -1 */
    52444696, /* 67210 (1621) [ 0,  0, -1,  0,  1,  0, -1,  0,  0] [ 6,  6,  0] -1 */
    34028656, /* 67211 (1621) [ 1,  0,  0,  0,  0,  1,  0,  1,  0] [ 0,  0,  0] -1 */
    18439770, /* 67212 (1621) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
        7618, /* 67213 (1621) [ 0, -1,  0,  0,  0, -1, -1,  0,  0] [ 0,  0,  0]  1 */
    18430906, /* 67214 (1621) [ 0, -1,  0,  0,  0, -1, -1,  0,  0] [ 6,  6,  0]  1 */
    34015480, /* 67215 (1621) [-1,  0,  0,  0,  0, -1,  0,  1,  0] [ 0,  0,  0] -1 */
     1544632, /* 67216 (1621) [ 0,  0, -1,  1,  0,  0,  0,  1,  0] [ 0,  6,  6]  1 */
     1547284, /* 67217 (1621) [ 0,  1,  0,  0,  0, -1,  1,  0,  0] [ 0,  6,  6]  1 */
    34021408, /* 67218 (1621) [ 0,  0, -1,  0,  1,  0, -1,  0,  0] [ 0,  0,  0] -1 */
    18439608, /* 67219 (1621) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
    34019634, /* 67220 (1621) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    51146932, /* 67221 (1621) [ 0,  0,  1,  0, -1,  0,  1,  0,  0] [ 6,  0,  6] -1 */
    18426486, /* 67222 (1621) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
    17134540, /* 67223 (1621) [ 0,  0,  1, -1,  0,  0,  0,  1,  0] [ 6,  0,  6]  1 */
     1551596, /* 67224 (1621) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
     1538636, /* 67225 (1621) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
    51143846, /* 67226 (1621) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 6,  0,  6] -1 */
    17136256, /* 67227 (1621) [ 0,  1,  0,  0,  0,  1, -1,  0,  0] [ 6,  0,  6]  1 */
    51152812, /* 67228 (1621) [ 1,  0,  0,  0,  0, -1,  0,  1,  0] [ 6,  0,  6] -1 */
    35557996, /* 67229 (1621) [ 0,  0,  1,  0, -1,  0,  1,  0,  0] [ 0,  6,  6] -1 */
    17127410, /* 67230 (1621) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
    17131882, /* 67231 (1621) [ 0, -1,  0,  0,  0,  1, -1,  0,  0] [ 6,  0,  6]  1 */
    51139690, /* 67232 (1621) [-1,  0,  0,  0,  0, -1,  0,  1,  0] [ 6,  0,  6] -1 */
    17136202, /* 67233 (1621) [ 0,  1,  0,  0,  0, -1, -1,  0,  0] [ 6,  0,  6]  1 */
     1547338, /* 67234 (1621) [ 0,  1,  0,  0,  0,  1,  1,  0,  0] [ 0,  6,  6]  1 */
    51148704, /* 67235 (1621) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 6,  0,  6] -1 */
       10810, /* 67236 (1621) [ 0,  0,  1,  1,  0,  0,  0, -1,  0] [ 0,  0,  0]  1 */
    52444714, /* 67237 (1621) [ 0,  0, -1,  0,  1,  0,  1,  0,  0] [ 6,  6,  0] -1 */
    18432640, /* 67238 (1621) [ 0,  0, -1,  1,  0,  0,  0, -1,  0] [ 6,  6,  0]  1 */
    51145456, /* 67239 (1621) [ 0,  0, -1,  0, -1,  0, -1,  0,  0] [ 6,  0,  6] -1 */
        7690, /* 67240 (1621) [ 0, -1,  0,  0,  0,  1,  1,  0,  0] [ 0,  0,  0]  1 */
    18430978, /* 67241 (1621) [ 0, -1,  0,  0,  0,  1,  1,  0,  0] [ 6,  6,  0]  1 */
    34024010, /* 67242 (1621) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    34028596, /* 67243 (1621) [ 1,  0,  0,  0,  0, -1,  0, -1,  0] [ 0,  0,  0] -1 */
    17135026, /* 67244 (1621) [ 0,  0,  1,  1,  0,  0,  0,  1,  0] [ 6,  0,  6]  1 */
    35556682, /* 67245 (1621) [ 0,  0, -1,  0,  1,  0, -1,  0,  0] [ 0,  6,  6] -1 */
        7636, /* 67246 (1621) [ 0, -1,  0,  0,  0, -1,  1,  0,  0] [ 0,  0,  0]  1 */
    18430924, /* 67247 (1621) [ 0, -1,  0,  0,  0, -1,  1,  0,  0] [ 6,  6,  0]  1 */
    34015534, /* 67248 (1621) [-1,  0,  0,  0,  0,  1,  0,  1,  0] [ 0,  0,  0] -1 */
    52438822, /* 67249 (1621) [-1,  0,  0,  0,  0,  1,  0,  1,  0] [ 6,  6,  0] -1 */
     1551756, /* 67250 (1621) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
     1542892, /* 67251 (1621) [ 0, -1,  0,  0,  0, -1, -1,  0,  0] [ 0,  6,  6]  1 */
    34021426, /* 67252 (1621) [ 0,  0, -1,  0,  1,  0,  1,  0,  0] [ 0,  0,  0] -1 */
    52438816, /* 67253 (1621) [-1,  0,  0,  0,  0,  1,  0, -1,  0] [ 6,  6,  0] -1 */
     1551594, /* 67254 (1621) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
     1538472, /* 67255 (1621) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
    18432646, /* 67256 (1621) [ 0,  0, -1,  1,  0,  0,  0,  1,  0] [ 6,  6,  0]  1 */
    51144330, /* 67257 (1621) [ 0, -1,  0,  1,  0,  0,  0,  0, -1] [ 6,  0,  6] -1 */
    51145636, /* 67258 (1621) [ 0,  0, -1,  0,  1,  0,  1,  0,  0] [ 6,  0,  6] -1 */
    51147076, /* 67259 (1621) [ 0,  0,  1,  0,  1,  0, -1,  0,  0] [ 6,  0,  6] -1 */
     1542964, /* 67260 (1621) [ 0, -1,  0,  0,  0,  1,  1,  0,  0] [ 0,  6,  6]  1 */
    51148220, /* 67261 (1621) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 6,  0,  6] -1 */
       16322, /* 67262 (1621) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
     1544626, /* 67263 (1621) [ 0,  0, -1,  1,  0,  0,  0, -1,  0] [ 0,  6,  6]  1 */
        3200, /* 67264 (1621) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    51152860, /* 67265 (1621) [ 1,  0,  0,  0,  0,  1,  0, -1,  0] [ 6,  0,  6] -1 */
        9358, /* 67266 (1621) [ 0,  0, -1,  1,  0,  0,  0,  1,  0] [ 0,  0,  0]  1 */
    51146914, /* 67267 (1621) [ 0,  0,  1,  0, -1,  0, -1,  0,  0] [ 6,  0,  6] -1 */
    51152806, /* 67268 (1621) [ 1,  0,  0,  0,  0, -1,  0, -1,  0] [ 6,  0,  6] -1 */
     1542910, /* 67269 (1621) [ 0, -1,  0,  0,  0, -1,  1,  0,  0] [ 0,  6,  6]  1 */
    51139738, /* 67270 (1621) [-1,  0,  0,  0,  0,  1,  0, -1,  0] [ 6,  0,  6] -1 */
    35550808, /* 67271 (1621) [-1,  0,  0,  0,  0,  1,  0,  1,  0] [ 0,  6,  6] -1 */
    51139684, /* 67272 (1621) [-1,  0,  0,  0,  0, -1,  0, -1,  0] [ 6,  0,  6] -1 */
    52444552, /* 67273 (1621) [ 0,  0, -1,  0, -1,  0,  1,  0,  0] [ 6,  6,  0] -1 */
       16482, /* 67274 (1621) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
       16484, /* 67275 (1622) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
     1551700, /* 67276 (1622) [ 1,  0,  0,  0,  0,  1,  0, -1,  0] [ 0,  6,  6]  1 */
    17140694, /* 67277 (1622) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
        9022, /* 67278 (1622) [ 0,  0, -1,  0, -1,  0, -1,  0,  0] [ 0,  0,  0]  1 */
    18432310, /* 67279 (1622) [ 0,  0, -1,  0, -1,  0, -1,  0,  0] [ 6,  6,  0]  1 */
       16320, /* 67280 (1622) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    51147094, /* 67281 (1622) [ 0,  0,  1,  0,  1,  0,  1,  0,  0] [ 6,  0,  6] -1 */
    17132108, /* 67282 (1622) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 6,  0,  6]  1 */
     1538524, /* 67283 (1622) [-1,  0,  0,  0,  0, -1,  0, -1,  0] [ 0,  6,  6]  1 */
     1545598, /* 67284 (1622) [ 0,  0,  1, -1,  0,  0,  0, -1,  0] [ 0,  6,  6]  1 */
    51139632, /* 67285 (1622) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  6] -1 */
    52447296, /* 67286 (1622) [ 0,  1,  0, -1,  0,  0,  0,  0, -1] [ 6,  6,  0] -1 */
    52451834, /* 67287 (1622) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
    34020120, /* 67288 (1622) [ 0, -1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  0] -1 */
     1538474, /* 67289 (1622) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
    17136274, /* 67290 (1622) [ 0,  1,  0,  0,  0,  1,  1,  0,  0] [ 6,  0,  6]  1 */
    52445842, /* 67291 (1622) [ 0,  0,  1, -1,  0,  0,  0,  1,  0] [ 6,  6,  0] -1 */
        7410, /* 67292 (1622) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    18430698, /* 67293 (1622) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 6,  6,  0]  1 */
    34024234, /* 67294 (1622) [ 0,  1,  0,  0,  0, -1,  1,  0,  0] [ 0,  0,  0] -1 */
    17134708, /* 67295 (1622) [ 0,  0,  1,  0, -1,  0,  1,  0,  0] [ 6,  0,  6]  1 */
    35556538, /* 67296 (1622) [ 0,  0, -1,  0, -1,  0,  1,  0,  0] [ 0,  6,  6] -1 */
        9352, /* 67297 (1622) [ 0,  0, -1,  1,  0,  0,  0, -1,  0] [ 0,  0,  0]  1 */
     1551652, /* 67298 (1622) [ 1,  0,  0,  0,  0, -1,  0,  1,  0] [ 0,  6,  6]  1 */
     1545772, /* 67299 (1622) [ 0,  0,  1,  0, -1,  0,  1,  0,  0] [ 0,  6,  6]  1 */
    34024496, /* 67300 (1622) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    52447784, /* 67301 (1622) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 6,  6,  0] -1 */
    18426648, /* 67302 (1622) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
        8872, /* 67303 (1622) [ 0,  0, -1, -1,  0,  0,  0,  1,  0] [ 0,  0,  0]  1 */
    17136480, /* 67304 (1622) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 6,  0,  6]  1 */
    18432160, /* 67305 (1622) [ 0,  0, -1, -1,  0,  0,  0,  1,  0] [ 6,  6,  0]  1 */
     1544296, /* 67306 (1622) [ 0,  0, -1,  0, -1,  0, -1,  0,  0] [ 0,  6,  6]  1 */
    52451944, /* 67307 (1622) [ 1,  0,  0,  0,  0,  1,  0,  1,  0] [ 6,  6,  0] -1 */
        3250, /* 67308 (1622) [-1,  0,  0,  0,  0, -1,  0, -1,  0] [ 0,  0,  0]  1 */
    35559282, /* 67309 (1622) [ 0,  1,  0, -1,  0,  0,  0,  0, -1] [ 0,  6,  6] -1 */
    18426598, /* 67310 (1622) [-1,  0,  0,  0,  0,  1,  0,  1,  0] [ 6,  6,  0]  1 */
    51146764, /* 67311 (1622) [ 0,  0,  1, -1,  0,  0,  0,  1,  0] [ 6,  0,  6] -1 */
    35563820, /* 67312 (1622) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
        9202, /* 67313 (1622) [ 0,  0, -1,  0,  1,  0,  1,  0,  0] [ 0,  0,  0]  1 */
    18433612, /* 67314 (1622) [ 0,  0,  1, -1,  0,  0,  0, -1,  0] [ 6,  6,  0]  1 */
    17133562, /* 67315 (1622) [ 0,  0, -1,  1,  0,  0,  0, -1,  0] [ 6,  0,  6]  1 */
     1542684, /* 67316 (1622) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 0,  6,  6]  1 */
    52443202, /* 67317 (1622) [ 0, -1,  0,  0,  0,  1,  1,  0,  0] [ 6,  6,  0] -1 */
    51148706, /* 67318 (1622) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 6,  0,  6] -1 */
    34023034, /* 67319 (1622) [ 0,  0,  1,  1,  0,  0,  0, -1,  0] [ 0,  0,  0] -1 */
    52446322, /* 67320 (1622) [ 0,  0,  1,  1,  0,  0,  0, -1,  0] [ 6,  6,  0] -1 */
    17131846, /* 67321 (1622) [ 0, -1,  0,  0,  0, -1,  1,  0,  0] [ 6,  0,  6]  1 */
    34021264, /* 67322 (1622) [ 0,  0, -1,  0, -1,  0,  1,  0,  0] [ 0,  0,  0] -1 */
    35559770, /* 67323 (1622) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 0,  6,  6] -1 */
       10324, /* 67324 (1622) [ 0,  0,  1, -1,  0,  0,  0, -1,  0] [ 0,  0,  0]  1 */
     1538634, /* 67325 (1622) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
    17134852, /* 67326 (1622) [ 0,  0,  1,  0,  1,  0, -1,  0,  0] [ 6,  0,  6]  1 */
     1544146, /* 67327 (1622) [ 0,  0, -1, -1,  0,  0,  0,  1,  0] [ 0,  6,  6]  1 */
    17135996, /* 67328 (1622) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 6,  0,  6]  1 */
    17140636, /* 67329 (1622) [ 1,  0,  0,  0,  0,  1,  0, -1,  0] [ 6,  0,  6]  1 */
    35563930, /* 67330 (1622) [ 1,  0,  0,  0,  0,  1,  0,  1,  0] [ 0,  6,  6] -1 */
    17134534, /* 67331 (1622) [ 0,  0,  1, -1,  0,  0,  0, -1,  0] [ 6,  0,  6]  1 */
    52447522, /* 67332 (1622) [ 0,  1,  0,  0,  0, -1,  1,  0,  0] [ 6,  6,  0] -1 */
    34024008, /* 67333 (1622) [ 0,  1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    52438874, /* 67334 (1622) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
    34022554, /* 67335 (1622) [ 0,  0,  1, -1,  0,  0,  0,  1,  0] [ 0,  0,  0] -1 */
    35555188, /* 67336 (1622) [ 0, -1,  0,  0,  0,  1,  1,  0,  0] [ 0,  6,  6] -1 */
    35558308, /* 67337 (1622) [ 0,  0,  1,  1,  0,  0,  0, -1,  0] [ 0,  6,  6] -1 */
    34024270, /* 67338 (1622) [ 0,  1,  0,  0,  0,  1, -1,  0,  0] [ 0,  0,  0] -1 */
    52447558, /* 67339 (1622) [ 0,  1,  0,  0,  0,  1, -1,  0,  0] [ 6,  6,  0] -1 */
    18439772, /* 67340 (1622) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    34021582, /* 67341 (1622) [ 0,  0, -1,  1,  0,  0,  0,  1,  0] [ 0,  0,  0] -1 */
    17140530, /* 67342 (1622) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  6]  1 */
    51145618, /* 67343 (1622) [ 0,  0, -1,  0,  1,  0, -1,  0,  0] [ 6,  0,  6] -1 */
    51145300, /* 67344 (1622) [ 0,  0, -1, -1,  0,  0,  0, -1,  0] [ 6,  0,  6] -1 */
    34015586, /* 67345 (1622) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    17140588, /* 67346 (1622) [ 1,  0,  0,  0,  0, -1,  0,  1,  0] [ 6,  0,  6]  1 */
    34019636, /* 67347 (1622) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    52442924, /* 67348 (1622) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 6,  6,  0] -1 */
    34028706, /* 67349 (1622) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    52451994, /* 67350 (1622) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
    18432490, /* 67351 (1622) [ 0,  0, -1,  0,  1,  0,  1,  0,  0] [ 6,  6,  0]  1 */
    17133232, /* 67352 (1622) [ 0,  0, -1,  0, -1,  0, -1,  0,  0] [ 6,  0,  6]  1 */
    34019842, /* 67353 (1622) [ 0, -1,  0,  0,  0, -1, -1,  0,  0] [ 0,  0,  0] -1 */
    18430960, /* 67354 (1622) [ 0, -1,  0,  0,  0,  1, -1,  0,  0] [ 6,  6,  0]  1 */
    52443130, /* 67355 (1622) [ 0, -1,  0,  0,  0, -1, -1,  0,  0] [ 6,  6,  0] -1 */
    52438768, /* 67356 (1622) [-1,  0,  0,  0,  0, -1,  0,  1,  0] [ 6,  6,  0] -1 */
       11786, /* 67357 (1622) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    35556856, /* 67358 (1622) [ 0,  0, -1,  1,  0,  0,  0,  1,  0] [ 0,  6,  6] -1 */
    18435280, /* 67359 (1622) [ 0,  1,  0,  0,  0, -1, -1,  0,  0] [ 6,  6,  0]  1 */
    34022884, /* 67360 (1622) [ 0,  0,  1,  0,  1,  0,  1,  0,  0] [ 0,  0,  0] -1 */
        7898, /* 67361 (1622) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    18435352, /* 67362 (1622) [ 0,  1,  0,  0,  0,  1,  1,  0,  0] [ 6,  6,  0]  1 */
    35559508, /* 67363 (1622) [ 0,  1,  0,  0,  0, -1,  1,  0,  0] [ 0,  6,  6] -1 */
    52446172, /* 67364 (1622) [ 0,  0,  1,  0,  1,  0,  1,  0,  0] [ 6,  6,  0] -1 */
        3310, /* 67365 (1622) [-1,  0,  0,  0,  0,  1,  0,  1,  0] [ 0,  0,  0]  1 */
    51148218, /* 67366 (1622) [ 0,  1,  0, -1,  0,  0,  0,  0, -1] [ 6,  0,  6] -1 */
       10816, /* 67367 (1622) [ 0,  0,  1,  1,  0,  0,  0,  1,  0] [ 0,  0,  0]  1 */
    34015422, /* 67368 (1622) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    18434104, /* 67369 (1622) [ 0,  0,  1,  1,  0,  0,  0,  1,  0] [ 6,  6,  0]  1 */
    52438710, /* 67370 (1622) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
    35550860, /* 67371 (1622) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
    51152756, /* 67372 (1622) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
    51148480, /* 67373 (1622) [ 0,  1,  0,  0,  0,  1, -1,  0,  0] [ 6,  0,  6] -1 */
       11992, /* 67374 (1622) [ 0,  1,  0,  0,  0, -1, -1,  0,  0] [ 0,  0,  0]  1 */
       12064, /* 67375 (1622) [ 0,  1,  0,  0,  0,  1,  1,  0,  0] [ 0,  0,  0]  1 */
     1551758, /* 67376 (1622) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
    34019914, /* 67377 (1622) [ 0, -1,  0,  0,  0,  1,  1,  0,  0] [ 0,  0,  0] -1 */
    17133412, /* 67378 (1622) [ 0,  0, -1,  0,  1,  0,  1,  0,  0] [ 6,  0,  6]  1 */
    35554910, /* 67379 (1622) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 0,  6,  6] -1 */
    17127570, /* 67380 (1622) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6]  1 */
     1547060, /* 67381 (1622) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 0,  6,  6]  1 */
    35563980, /* 67382 (1622) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6] -1 */
     1542946, /* 67383 (1622) [ 0, -1,  0,  0,  0,  1, -1,  0,  0] [ 0,  6,  6]  1 */
       12270, /* 67384 (1622) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    17133082, /* 67385 (1622) [ 0,  0, -1, -1,  0,  0,  0,  1,  0] [ 6,  0,  6]  1 */
    35555116, /* 67386 (1622) [ 0, -1,  0,  0,  0, -1, -1,  0,  0] [ 0,  6,  6] -1 */
    35550754, /* 67387 (1622) [-1,  0,  0,  0,  0, -1,  0,  1,  0] [ 0,  6,  6] -1 */
    52443408, /* 67388 (1622) [ 0, -1,  0,  1,  0,  0,  0,  0, -1] [ 6,  6,  0] -1 */
     1547266, /* 67389 (1622) [ 0,  1,  0,  0,  0, -1, -1,  0,  0] [ 0,  6,  6]  1 */
    35558158, /* 67390 (1622) [ 0,  0,  1,  0,  1,  0,  1,  0,  0] [ 0,  6,  6] -1 */
    51152866, /* 67391 (1622) [ 1,  0,  0,  0,  0,  1,  0,  1,  0] [ 6,  0,  6] -1 */
     1538584, /* 67392 (1622) [-1,  0,  0,  0,  0,  1,  0,  1,  0] [ 0,  6,  6]  1 */
    34022704, /* 67393 (1622) [ 0,  0,  1,  0, -1,  0, -1,  0,  0] [ 0,  0,  0] -1 */
    17127460, /* 67394 (1622) [-1,  0,  0,  0,  0, -1,  0, -1,  0] [ 6,  0,  6]  1 */
    52445992, /* 67395 (1622) [ 0,  0,  1,  0, -1,  0, -1,  0,  0] [ 6,  6,  0] -1 */
     1546090, /* 67396 (1622) [ 0,  0,  1,  1,  0,  0,  0,  1,  0] [ 0,  6,  6]  1 */
    35550696, /* 67397 (1622) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  6] -1 */
    52451884, /* 67398 (1622) [ 1,  0,  0,  0,  0, -1,  0, -1,  0] [ 6,  6,  0] -1 */
    52444870, /* 67399 (1622) [ 0,  0, -1,  1,  0,  0,  0,  1,  0] [ 6,  6,  0] -1 */
    34028546, /* 67400 (1622) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    51145474, /* 67401 (1622) [ 0,  0, -1,  0, -1,  0,  1,  0,  0] [ 6,  0,  6] -1 */
    34015528, /* 67402 (1622) [-1,  0,  0,  0,  0,  1,  0, -1,  0] [ 0,  0,  0] -1 */
    18431186, /* 67403 (1622) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    18433930, /* 67404 (1622) [ 0,  0,  1,  0,  1,  0, -1,  0,  0] [ 6,  6,  0]  1 */
    35555394, /* 67405 (1622) [ 0, -1,  0,  1,  0,  0,  0,  0, -1] [ 0,  6,  6] -1 */
        7672, /* 67406 (1622) [ 0, -1,  0,  0,  0,  1, -1,  0,  0] [ 0,  0,  0]  1 */
        3360, /* 67407 (1622) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    51145792, /* 67408 (1622) [ 0,  0, -1,  1,  0,  0,  0,  1,  0] [ 6,  0,  6] -1 */
    18426488, /* 67409 (1622) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    35557978, /* 67410 (1622) [ 0,  0,  1,  0, -1,  0, -1,  0,  0] [ 0,  6,  6] -1 */
    35563870, /* 67411 (1622) [ 1,  0,  0,  0,  0, -1,  0, -1,  0] [ 0,  6,  6] -1 */
    35550802, /* 67412 (1622) [-1,  0,  0,  0,  0,  1,  0, -1,  0] [ 0,  6,  6] -1 */
    17131620, /* 67413 (1622) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 6,  0,  6]  1 */
    51148444, /* 67414 (1622) [ 0,  1,  0,  0,  0, -1,  1,  0,  0] [ 6,  0,  6] -1 */
    52444696, /* 67415 (1622) [ 0,  0, -1,  0,  1,  0, -1,  0,  0] [ 6,  6,  0] -1 */
    34028656, /* 67416 (1622) [ 1,  0,  0,  0,  0,  1,  0,  1,  0] [ 0,  0,  0] -1 */
    51139796, /* 67417 (1622) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
    52444378, /* 67418 (1622) [ 0,  0, -1, -1,  0,  0,  0, -1,  0] [ 6,  6,  0] -1 */
    34015480, /* 67419 (1622) [-1,  0,  0,  0,  0, -1,  0,  1,  0] [ 0,  0,  0] -1 */
    18435558, /* 67420 (1622) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 6,  6,  0]  1 */
    34021408, /* 67421 (1622) [ 0,  0, -1,  0,  1,  0, -1,  0,  0] [ 0,  0,  0] -1 */
    18439608, /* 67422 (1622) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
     1543172, /* 67423 (1622) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 0,  6,  6]  1 */
     1545916, /* 67424 (1622) [ 0,  0,  1,  0,  1,  0, -1,  0,  0] [ 0,  6,  6]  1 */
       16378, /* 67425 (1622) [ 1,  0,  0,  0,  0, -1,  0,  1,  0] [ 0,  0,  0]  1 */
    17127520, /* 67426 (1622) [-1,  0,  0,  0,  0,  1,  0,  1,  0] [ 6,  0,  6]  1 */
    51143846, /* 67427 (1622) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 6,  0,  6] -1 */
    17127410, /* 67428 (1622) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
    51152916, /* 67429 (1622) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6] -1 */
    17131882, /* 67430 (1622) [ 0, -1,  0,  0,  0,  1, -1,  0,  0] [ 6,  0,  6]  1 */
    51139690, /* 67431 (1622) [-1,  0,  0,  0,  0, -1,  0,  1,  0] [ 6,  0,  6] -1 */
    51144052, /* 67432 (1622) [ 0, -1,  0,  0,  0, -1, -1,  0,  0] [ 6,  0,  6] -1 */
    17136202, /* 67433 (1622) [ 0,  1,  0,  0,  0, -1, -1,  0,  0] [ 6,  0,  6]  1 */
     1547338, /* 67434 (1622) [ 0,  1,  0,  0,  0,  1,  1,  0,  0] [ 0,  6,  6]  1 */
    18432640, /* 67435 (1622) [ 0,  0, -1,  1,  0,  0,  0, -1,  0] [ 6,  6,  0]  1 */
    51147244, /* 67436 (1622) [ 0,  0,  1,  1,  0,  0,  0, -1,  0] [ 6,  0,  6] -1 */
    34028596, /* 67437 (1622) [ 1,  0,  0,  0,  0, -1,  0, -1,  0] [ 0,  0,  0] -1 */
    17135026, /* 67438 (1622) [ 0,  0,  1,  1,  0,  0,  0,  1,  0] [ 6,  0,  6]  1 */
    35556682, /* 67439 (1622) [ 0,  0, -1,  0,  1,  0, -1,  0,  0] [ 0,  6,  6] -1 */
        7636, /* 67440 (1622) [ 0, -1,  0,  0,  0, -1,  1,  0,  0] [ 0,  0,  0]  1 */
    18430924, /* 67441 (1622) [ 0, -1,  0,  0,  0, -1,  1,  0,  0] [ 6,  6,  0]  1 */
    35556364, /* 67442 (1622) [ 0,  0, -1, -1,  0,  0,  0, -1,  0] [ 0,  6,  6] -1 */
    52438816, /* 67443 (1622) [-1,  0,  0,  0,  0,  1,  0, -1,  0] [ 6,  6,  0] -1 */
     1547544, /* 67444 (1622) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 0,  6,  6]  1 */
    18435074, /* 67445 (1622) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    51144124, /* 67446 (1622) [ 0, -1,  0,  0,  0,  1,  1,  0,  0] [ 6,  0,  6] -1 */
     1551594, /* 67447 (1622) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
    18439714, /* 67448 (1622) [ 1,  0,  0,  0,  0,  1,  0, -1,  0] [ 6,  6,  0]  1 */
       10642, /* 67449 (1622) [ 0,  0,  1,  0,  1,  0, -1,  0,  0] [ 0,  0,  0]  1 */
    18426538, /* 67450 (1622) [-1,  0,  0,  0,  0, -1,  0, -1,  0] [ 6,  6,  0]  1 */
    51144330, /* 67451 (1622) [ 0, -1,  0,  1,  0,  0,  0,  0, -1] [ 6,  0,  6] -1 */
    35557828, /* 67452 (1622) [ 0,  0,  1, -1,  0,  0,  0,  1,  0] [ 0,  6,  6] -1 */
    35559544, /* 67453 (1622) [ 0,  1,  0,  0,  0,  1, -1,  0,  0] [ 0,  6,  6] -1 */
       16426, /* 67454 (1622) [ 1,  0,  0,  0,  0,  1,  0, -1,  0] [ 0,  0,  0]  1 */
     1544626, /* 67455 (1622) [ 0,  0, -1,  1,  0,  0,  0, -1,  0] [ 0,  6,  6]  1 */
        3200, /* 67456 (1622) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    51146914, /* 67457 (1622) [ 0,  0,  1,  0, -1,  0, -1,  0,  0] [ 6,  0,  6] -1 */
    51152806, /* 67458 (1622) [ 1,  0,  0,  0,  0, -1,  0, -1,  0] [ 6,  0,  6] -1 */
     1542910, /* 67459 (1622) [ 0, -1,  0,  0,  0, -1,  1,  0,  0] [ 0,  6,  6]  1 */
    51139738, /* 67460 (1622) [-1,  0,  0,  0,  0,  1,  0, -1,  0] [ 6,  0,  6] -1 */
    52444552, /* 67461 (1622) [ 0,  0, -1,  0, -1,  0,  1,  0,  0] [ 6,  6,  0] -1 */
     1544476, /* 67462 (1622) [ 0,  0, -1,  0,  1,  0,  1,  0,  0] [ 0,  6,  6]  1 */
    34021090, /* 67463 (1622) [ 0,  0, -1, -1,  0,  0,  0, -1,  0] [ 0,  0,  0] -1 */
    18439666, /* 67464 (1622) [ 1,  0,  0,  0,  0, -1,  0,  1,  0] [ 6,  6,  0]  1 */
       10498, /* 67465 (1622) [ 0,  0,  1,  0, -1,  0,  1,  0,  0] [ 0,  0,  0]  1 */
    18433786, /* 67466 (1622) [ 0,  0,  1,  0, -1,  0,  1,  0,  0] [ 6,  6,  0]  1 */
       16484, /* 67467 (1623) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    17140694, /* 67468 (1623) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
        9022, /* 67469 (1623) [ 0,  0, -1,  0, -1,  0, -1,  0,  0] [ 0,  0,  0]  1 */
    18432310, /* 67470 (1623) [ 0,  0, -1,  0, -1,  0, -1,  0,  0] [ 6,  6,  0]  1 */
     1538578, /* 67471 (1623) [-1,  0,  0,  0,  0,  1,  0, -1,  0] [ 0,  6,  6]  1 */
    17136220, /* 67472 (1623) [ 0,  1,  0,  0,  0, -1,  1,  0,  0] [ 6,  0,  6]  1 */
    51028978, /* 67473 (1623) [ 0,  0,  1,  0,  1,  0, -1,  0,  0] [ 6,  0,  0] -1 */
     1538524, /* 67474 (1623) [-1,  0,  0,  0,  0, -1,  0, -1,  0] [ 0,  6,  6]  1 */
        3198, /* 67475 (1623) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
     1545598, /* 67476 (1623) [ 0,  0,  1, -1,  0,  0,  0, -1,  0] [ 0,  6,  6]  1 */
    52565394, /* 67477 (1623) [ 0,  1,  0, -1,  0,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    17136274, /* 67478 (1623) [ 0,  1,  0,  0,  0,  1,  1,  0,  0] [ 6,  0,  6]  1 */
    52565620, /* 67479 (1623) [ 0,  1,  0,  0,  0, -1,  1,  0,  0] [ 6,  6,  6] -1 */
    34142332, /* 67480 (1623) [ 0,  1,  0,  0,  0, -1,  1,  0,  0] [ 0,  0,  6] -1 */
    17131622, /* 67481 (1623) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 6,  0,  6]  1 */
    34142368, /* 67482 (1623) [ 0,  1,  0,  0,  0,  1, -1,  0,  0] [ 0,  0,  6] -1 */
        8872, /* 67483 (1623) [ 0,  0, -1, -1,  0,  0,  0,  1,  0] [ 0,  0,  0]  1 */
    18432160, /* 67484 (1623) [ 0,  0, -1, -1,  0,  0,  0,  1,  0] [ 6,  6,  0]  1 */
    35432760, /* 67485 (1623) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  0] -1 */
    52570042, /* 67486 (1623) [ 1,  0,  0,  0,  0,  1,  0,  1,  0] [ 6,  6,  6] -1 */
       16372, /* 67487 (1623) [ 1,  0,  0,  0,  0, -1,  0, -1,  0] [ 0,  0,  0]  1 */
    18439660, /* 67488 (1623) [ 1,  0,  0,  0,  0, -1,  0, -1,  0] [ 6,  6,  0]  1 */
    34137734, /* 67489 (1623) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    52561022, /* 67490 (1623) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    52569988, /* 67491 (1623) [ 1,  0,  0,  0,  0, -1,  0,  1,  0] [ 6,  6,  6] -1 */
    51021592, /* 67492 (1623) [-1,  0,  0,  0,  0, -1,  0,  1,  0] [ 6,  0,  0] -1 */
    17133562, /* 67493 (1623) [ 0,  0, -1,  1,  0,  0,  0, -1,  0] [ 6,  0,  6]  1 */
     1542684, /* 67494 (1623) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 0,  6,  6]  1 */
     1543170, /* 67495 (1623) [ 0, -1,  0,  1,  0,  0,  0,  0, -1] [ 0,  6,  6]  1 */
    34139674, /* 67496 (1623) [ 0,  0, -1,  1,  0,  0,  0, -1,  0] [ 0,  0,  6] -1 */
    17127514, /* 67497 (1623) [-1,  0,  0,  0,  0,  1,  0, -1,  0] [ 6,  0,  6]  1 */
    17134534, /* 67498 (1623) [ 0,  0,  1, -1,  0,  0,  0, -1,  0] [ 6,  0,  6]  1 */
    34146806, /* 67499 (1623) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    34133572, /* 67500 (1623) [-1,  0,  0,  0,  0, -1,  0, -1,  0] [ 0,  0,  6] -1 */
    18439772, /* 67501 (1623) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    17140692, /* 67502 (1623) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6]  1 */
    17127466, /* 67503 (1623) [-1,  0,  0,  0,  0, -1,  0,  1,  0] [ 6,  0,  6]  1 */
    18430960, /* 67504 (1623) [ 0, -1,  0,  0,  0,  1, -1,  0,  0] [ 6,  6,  0]  1 */
    35441184, /* 67505 (1623) [ 0,  1,  0, -1,  0,  0,  0,  0, -1] [ 0,  6,  0] -1 */
    51025954, /* 67506 (1623) [ 0, -1,  0,  0,  0, -1, -1,  0,  0] [ 6,  0,  0] -1 */
    18435280, /* 67507 (1623) [ 0,  1,  0,  0,  0, -1, -1,  0,  0] [ 6,  6,  0]  1 */
     1544458, /* 67508 (1623) [ 0,  0, -1,  0,  1,  0, -1,  0,  0] [ 0,  6,  6]  1 */
        7898, /* 67509 (1623) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    18435352, /* 67510 (1623) [ 0,  1,  0,  0,  0,  1,  1,  0,  0] [ 6,  6,  0]  1 */
    35441410, /* 67511 (1623) [ 0,  1,  0,  0,  0, -1,  1,  0,  0] [ 0,  6,  0] -1 */
    18435560, /* 67512 (1623) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    17132106, /* 67513 (1623) [ 0, -1,  0,  1,  0,  0,  0,  0, -1] [ 6,  0,  6]  1 */
    35445832, /* 67514 (1623) [ 1,  0,  0,  0,  0,  1,  0,  1,  0] [ 0,  6,  0] -1 */
    51026232, /* 67515 (1623) [ 0, -1,  0,  1,  0,  0,  0,  0, -1] [ 6,  0,  0] -1 */
       12270, /* 67516 (1623) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    35445778, /* 67517 (1623) [ 1,  0,  0,  0,  0, -1,  0,  1,  0] [ 0,  6,  0] -1 */
    18434098, /* 67518 (1623) [ 0,  0,  1,  1,  0,  0,  0, -1,  0] [ 6,  6,  0]  1 */
    52563940, /* 67519 (1623) [ 0,  0,  1, -1,  0,  0,  0,  1,  0] [ 6,  6,  6] -1 */
    35437090, /* 67520 (1623) [ 0, -1,  0,  0,  0,  1,  1,  0,  0] [ 0,  6,  0] -1 */
    52556860, /* 67521 (1623) [-1,  0,  0,  0,  0, -1,  0, -1,  0] [ 6,  6,  6] -1 */
    51027538, /* 67522 (1623) [ 0,  0, -1,  0,  1,  0,  1,  0,  0] [ 6,  0,  0] -1 */
    34133626, /* 67523 (1623) [-1,  0,  0,  0,  0,  1,  0, -1,  0] [ 0,  0,  6] -1 */
    52556914, /* 67524 (1623) [-1,  0,  0,  0,  0,  1,  0, -1,  0] [ 6,  6,  6] -1 */
    18431186, /* 67525 (1623) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    52563934, /* 67526 (1623) [ 0,  0,  1, -1,  0,  0,  0, -1,  0] [ 6,  6,  6] -1 */
    18433930, /* 67527 (1623) [ 0,  0,  1,  0,  1,  0, -1,  0,  0] [ 6,  6,  0]  1 */
    34140646, /* 67528 (1623) [ 0,  0,  1, -1,  0,  0,  0, -1,  0] [ 0,  0,  6] -1 */
    17133394, /* 67529 (1623) [ 0,  0, -1,  0,  1,  0, -1,  0,  0] [ 6,  0,  6]  1 */
    17131620, /* 67530 (1623) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 6,  0,  6]  1 */
        3362, /* 67531 (1623) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    35441446, /* 67532 (1623) [ 0,  1,  0,  0,  0,  1, -1,  0,  0] [ 0,  6,  0] -1 */
    35432704, /* 67533 (1623) [-1,  0,  0,  0,  0,  1,  0, -1,  0] [ 0,  6,  0] -1 */
    35439724, /* 67534 (1623) [ 0,  0,  1, -1,  0,  0,  0, -1,  0] [ 0,  6,  0] -1 */
    34133578, /* 67535 (1623) [-1,  0,  0,  0,  0, -1,  0,  1,  0] [ 0,  0,  6] -1 */
    18439770, /* 67536 (1623) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
        7618, /* 67537 (1623) [ 0, -1,  0,  0,  0, -1, -1,  0,  0] [ 0,  0,  0]  1 */
    18430906, /* 67538 (1623) [ 0, -1,  0,  0,  0, -1, -1,  0,  0] [ 6,  6,  0]  1 */
    18426544, /* 67539 (1623) [-1,  0,  0,  0,  0, -1,  0,  1,  0] [ 6,  6,  0]  1 */
    35436812, /* 67540 (1623) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 0,  6,  0] -1 */
    34139506, /* 67541 (1623) [ 0,  0, -1,  0,  1,  0, -1,  0,  0] [ 0,  0,  6] -1 */
    18435558, /* 67542 (1623) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 6,  6,  0]  1 */
    52562650, /* 67543 (1623) [ 0,  0, -1,  0, -1,  0,  1,  0,  0] [ 6,  6,  6] -1 */
    34137732, /* 67544 (1623) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  6] -1 */
     1547058, /* 67545 (1623) [ 0,  1,  0, -1,  0,  0,  0,  0, -1] [ 0,  6,  6]  1 */
    51030120, /* 67546 (1623) [ 0,  1,  0, -1,  0,  0,  0,  0, -1] [ 6,  0,  0] -1 */
    17127520, /* 67547 (1623) [-1,  0,  0,  0,  0,  1,  0,  1,  0] [ 6,  0,  6]  1 */
    17127410, /* 67548 (1623) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
    51021696, /* 67549 (1623) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  0] -1 */
    51030346, /* 67550 (1623) [ 0,  1,  0,  0,  0, -1,  1,  0,  0] [ 6,  0,  0] -1 */
    34133632, /* 67551 (1623) [-1,  0,  0,  0,  0,  1,  0,  1,  0] [ 0,  0,  6] -1 */
    52556920, /* 67552 (1623) [-1,  0,  0,  0,  0,  1,  0,  1,  0] [ 6,  6,  6] -1 */
    34138218, /* 67553 (1623) [ 0, -1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  6] -1 */
    51034714, /* 67554 (1623) [ 1,  0,  0,  0,  0, -1,  0,  1,  0] [ 6,  0,  0] -1 */
     1538472, /* 67555 (1623) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
     1542964, /* 67556 (1623) [ 0, -1,  0,  0,  0,  1,  1,  0,  0] [ 0,  6,  6]  1 */
       16322, /* 67557 (1623) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    35432650, /* 67558 (1623) [-1,  0,  0,  0,  0, -1,  0, -1,  0] [ 0,  6,  0] -1 */
        9358, /* 67559 (1623) [ 0,  0, -1,  1,  0,  0,  0,  1,  0] [ 0,  0,  0]  1 */
     1551700, /* 67560 (1623) [ 1,  0,  0,  0,  0,  1,  0, -1,  0] [ 0,  6,  6]  1 */
       10660, /* 67561 (1623) [ 0,  0,  1,  0,  1,  0,  1,  0,  0] [ 0,  0,  0]  1 */
       16320, /* 67562 (1623) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    17135994, /* 67563 (1623) [ 0,  1,  0, -1,  0,  0,  0,  0, -1] [ 6,  0,  6]  1 */
    51030382, /* 67564 (1623) [ 0,  1,  0,  0,  0,  1, -1,  0,  0] [ 6,  0,  0] -1 */
    51034820, /* 67565 (1623) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  0] -1 */
    34142106, /* 67566 (1623) [ 0,  1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  6] -1 */
    17134708, /* 67567 (1623) [ 0,  0,  1,  0, -1,  0,  1,  0,  0] [ 6,  0,  6]  1 */
     1551652, /* 67568 (1623) [ 1,  0,  0,  0,  0, -1,  0,  1,  0] [ 0,  6,  6]  1 */
    35438584, /* 67569 (1623) [ 0,  0, -1,  0,  1,  0, -1,  0,  0] [ 0,  6,  0] -1 */
     1545772, /* 67570 (1623) [ 0,  0,  1,  0, -1,  0,  1,  0,  0] [ 0,  6,  6]  1 */
    18426648, /* 67571 (1623) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
    34133522, /* 67572 (1623) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    52556810, /* 67573 (1623) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    35439730, /* 67574 (1623) [ 0,  0,  1, -1,  0,  0,  0,  1,  0] [ 0,  6,  0] -1 */
    17140642, /* 67575 (1623) [ 1,  0,  0,  0,  0,  1,  0,  1,  0] [ 6,  0,  6]  1 */
    51034768, /* 67576 (1623) [ 1,  0,  0,  0,  0,  1,  0,  1,  0] [ 6,  0,  0] -1 */
        9202, /* 67577 (1623) [ 0,  0, -1,  0,  1,  0,  1,  0,  0] [ 0,  0,  0]  1 */
    35432710, /* 67578 (1623) [-1,  0,  0,  0,  0,  1,  0,  1,  0] [ 0,  6,  0] -1 */
    52562632, /* 67579 (1623) [ 0,  0, -1,  0, -1,  0, -1,  0,  0] [ 6,  6,  6] -1 */
    17131900, /* 67580 (1623) [ 0, -1,  0,  0,  0,  1,  1,  0,  0] [ 6,  0,  6]  1 */
    34133520, /* 67581 (1623) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
    52561246, /* 67582 (1623) [ 0, -1,  0,  0,  0, -1,  1,  0,  0] [ 6,  6,  6] -1 */
    34138012, /* 67583 (1623) [ 0, -1,  0,  0,  0,  1,  1,  0,  0] [ 0,  0,  6] -1 */
    51027688, /* 67584 (1623) [ 0,  0, -1,  1,  0,  0,  0, -1,  0] [ 6,  0,  0] -1 */
    17140636, /* 67585 (1623) [ 1,  0,  0,  0,  0,  1,  0, -1,  0] [ 6,  0,  6]  1 */
        8866, /* 67586 (1623) [ 0,  0, -1, -1,  0,  0,  0, -1,  0] [ 0,  0,  0]  1 */
    18432154, /* 67587 (1623) [ 0,  0, -1, -1,  0,  0,  0, -1,  0] [ 6,  6,  0]  1 */
    52562482, /* 67588 (1623) [ 0,  0, -1, -1,  0,  0,  0,  1,  0] [ 6,  6,  6] -1 */
    35438440, /* 67589 (1623) [ 0,  0, -1,  0, -1,  0,  1,  0,  0] [ 0,  6,  0] -1 */
    34146748, /* 67590 (1623) [ 1,  0,  0,  0,  0,  1,  0, -1,  0] [ 0,  0,  6] -1 */
    52570036, /* 67591 (1623) [ 1,  0,  0,  0,  0,  1,  0, -1,  0] [ 6,  6,  6] -1 */
    51021640, /* 67592 (1623) [-1,  0,  0,  0,  0,  1,  0, -1,  0] [ 6,  0,  0] -1 */
    51028660, /* 67593 (1623) [ 0,  0,  1, -1,  0,  0,  0, -1,  0] [ 6,  0,  0] -1 */
    17140588, /* 67594 (1623) [ 1,  0,  0,  0,  0, -1,  0,  1,  0] [ 6,  0,  6]  1 */
    17127408, /* 67595 (1623) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  6]  1 */
    51025748, /* 67596 (1623) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 6,  0,  0] -1 */
    18432490, /* 67597 (1623) [ 0,  0, -1,  0,  1,  0,  1,  0,  0] [ 6,  6,  0]  1 */
       11786, /* 67598 (1623) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34146700, /* 67599 (1623) [ 1,  0,  0,  0,  0, -1,  0,  1,  0] [ 0,  0,  6] -1 */
    52556808, /* 67600 (1623) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    34140820, /* 67601 (1623) [ 0,  0,  1,  0, -1,  0,  1,  0,  0] [ 0,  0,  6] -1 */
    52564108, /* 67602 (1623) [ 0,  0,  1,  0, -1,  0,  1,  0,  0] [ 6,  6,  6] -1 */
       11992, /* 67603 (1623) [ 0,  1,  0,  0,  0, -1, -1,  0,  0] [ 0,  0,  0]  1 */
       12064, /* 67604 (1623) [ 0,  1,  0,  0,  0,  1,  1,  0,  0] [ 0,  0,  0]  1 */
    51027520, /* 67605 (1623) [ 0,  0, -1,  0,  1,  0, -1,  0,  0] [ 6,  0,  0] -1 */
    51025746, /* 67606 (1623) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 6,  0,  0] -1 */
    34146754, /* 67607 (1623) [ 1,  0,  0,  0,  0,  1,  0,  1,  0] [ 0,  0,  6] -1 */
    18439720, /* 67608 (1623) [ 1,  0,  0,  0,  0,  1,  0,  1,  0] [ 6,  6,  0]  1 */
     1545604, /* 67609 (1623) [ 0,  0,  1, -1,  0,  0,  0,  1,  0] [ 0,  6,  6]  1 */
     1538584, /* 67610 (1623) [-1,  0,  0,  0,  0,  1,  0,  1,  0] [ 0,  6,  6]  1 */
    35438422, /* 67611 (1623) [ 0,  0, -1,  0, -1,  0, -1,  0,  0] [ 0,  6,  0] -1 */
    51021646, /* 67612 (1623) [-1,  0,  0,  0,  0,  1,  0,  1,  0] [ 6,  0,  0] -1 */
    17127460, /* 67613 (1623) [-1,  0,  0,  0,  0, -1,  0, -1,  0] [ 6,  0,  6]  1 */
     1546090, /* 67614 (1623) [ 0,  0,  1,  1,  0,  0,  0,  1,  0] [ 0,  6,  6]  1 */
    52569982, /* 67615 (1623) [ 1,  0,  0,  0,  0, -1,  0, -1,  0] [ 6,  6,  6] -1 */
    51021586, /* 67616 (1623) [-1,  0,  0,  0,  0, -1,  0, -1,  0] [ 6,  0,  0] -1 */
    35437036, /* 67617 (1623) [ 0, -1,  0,  0,  0, -1,  1,  0,  0] [ 0,  6,  0] -1 */
    18435298, /* 67618 (1623) [ 0,  1,  0,  0,  0, -1,  1,  0,  0] [ 6,  6,  0]  1 */
        7672, /* 67619 (1623) [ 0, -1,  0,  0,  0,  1, -1,  0,  0] [ 0,  0,  0]  1 */
       12046, /* 67620 (1623) [ 0,  1,  0,  0,  0,  1, -1,  0,  0] [ 0,  0,  0]  1 */
    18435334, /* 67621 (1623) [ 0,  1,  0,  0,  0,  1, -1,  0,  0] [ 6,  6,  0]  1 */
     1544314, /* 67622 (1623) [ 0,  0, -1,  0, -1,  0,  1,  0,  0] [ 0,  6,  6]  1 */
    35445826, /* 67623 (1623) [ 1,  0,  0,  0,  0,  1,  0, -1,  0] [ 0,  6,  0] -1 */
       12272, /* 67624 (1623) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    35432600, /* 67625 (1623) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  0] -1 */
        7412, /* 67626 (1623) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    18430700, /* 67627 (1623) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 6,  6,  0]  1 */
     1544632, /* 67628 (1623) [ 0,  0, -1,  1,  0,  0,  0,  1,  0] [ 0,  6,  6]  1 */
    17134540, /* 67629 (1623) [ 0,  0,  1, -1,  0,  0,  0,  1,  0] [ 6,  0,  6]  1 */
     1538636, /* 67630 (1623) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
    51028666, /* 67631 (1623) [ 0,  0,  1, -1,  0,  0,  0,  1,  0] [ 6,  0,  0] -1 */
    35432598, /* 67632 (1623) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  0] -1 */
       10810, /* 67633 (1623) [ 0,  0,  1,  1,  0,  0,  0, -1,  0] [ 0,  0,  0]  1 */
    18432640, /* 67634 (1623) [ 0,  0, -1,  1,  0,  0,  0, -1,  0] [ 6,  6,  0]  1 */
    52561508, /* 67635 (1623) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    34146644, /* 67636 (1623) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    52569932, /* 67637 (1623) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    17135026, /* 67638 (1623) [ 0,  0,  1,  1,  0,  0,  0,  1,  0] [ 6,  0,  6]  1 */
    51021536, /* 67639 (1623) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  0] -1 */
     1545934, /* 67640 (1623) [ 0,  0,  1,  0,  1,  0,  1,  0,  0] [ 0,  6,  6]  1 */
     1551594, /* 67641 (1623) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
    34141138, /* 67642 (1623) [ 0,  0,  1,  1,  0,  0,  0,  1,  0] [ 0,  0,  6] -1 */
    52564426, /* 67643 (1623) [ 0,  0,  1,  1,  0,  0,  0,  1,  0] [ 6,  6,  6] -1 */
    35438272, /* 67644 (1623) [ 0,  0, -1, -1,  0,  0,  0,  1,  0] [ 0,  6,  0] -1 */
       10642, /* 67645 (1623) [ 0,  0,  1,  0,  1,  0, -1,  0,  0] [ 0,  0,  0]  1 */
    18426538, /* 67646 (1623) [-1,  0,  0,  0,  0, -1,  0, -1,  0] [ 6,  6,  0]  1 */
    35445772, /* 67647 (1623) [ 1,  0,  0,  0,  0, -1,  0, -1,  0] [ 0,  6,  0] -1 */
    51027358, /* 67648 (1623) [ 0,  0, -1,  0, -1,  0, -1,  0,  0] [ 6,  0,  0] -1 */
    52565880, /* 67649 (1623) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    17133250, /* 67650 (1623) [ 0,  0, -1,  0, -1,  0,  1,  0,  0] [ 6,  0,  6]  1 */
     1542910, /* 67651 (1623) [ 0, -1,  0,  0,  0, -1,  1,  0,  0] [ 0,  6,  6]  1 */
     1544476, /* 67652 (1623) [ 0,  0, -1,  0,  1,  0,  1,  0,  0] [ 0,  6,  6]  1 */
     1547060, /* 67653 (1623) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 0,  6,  6]  1 */
       16482, /* 67654 (1623) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    34139362, /* 67655 (1623) [ 0,  0, -1,  0, -1,  0,  1,  0,  0] [ 0,  0,  6] -1 */
    17133568, /* 67656 (1623) [ 0,  0, -1,  1,  0,  0,  0,  1,  0] [ 6,  0,  6]  1 */
     1545754, /* 67657 (1623) [ 0,  0,  1,  0, -1,  0, -1,  0,  0] [ 0,  6,  6]  1 */
    35439898, /* 67658 (1623) [ 0,  0,  1,  0, -1,  0,  1,  0,  0] [ 0,  6,  0] -1 */
        3256, /* 67659 (1623) [-1,  0,  0,  0,  0, -1,  0,  1,  0] [ 0,  0,  0]  1 */
    52562968, /* 67660 (1623) [ 0,  0, -1,  1,  0,  0,  0,  1,  0] [ 6,  6,  6] -1 */
     1538474, /* 67661 (1623) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
        9184, /* 67662 (1623) [ 0,  0, -1,  0,  1,  0, -1,  0,  0] [ 0,  0,  0]  1 */
        7410, /* 67663 (1623) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    18430698, /* 67664 (1623) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 6,  6,  0]  1 */
        9352, /* 67665 (1623) [ 0,  0, -1,  1,  0,  0,  0, -1,  0] [ 0,  0,  0]  1 */
    52556972, /* 67666 (1623) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    34133684, /* 67667 (1623) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    18431184, /* 67668 (1623) [ 0, -1,  0,  1,  0,  0,  0,  0, -1] [ 6,  6,  0]  1 */
    34140652, /* 67669 (1623) [ 0,  0,  1, -1,  0,  0,  0,  1,  0] [ 0,  0,  6] -1 */
    52561228, /* 67670 (1623) [ 0, -1,  0,  0,  0, -1, -1,  0,  0] [ 6,  6,  6] -1 */
     1544296, /* 67671 (1623) [ 0,  0, -1,  0, -1,  0, -1,  0,  0] [ 0,  6,  6]  1 */
    51021534, /* 67672 (1623) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  0] -1 */
    51028834, /* 67673 (1623) [ 0,  0,  1,  0, -1,  0,  1,  0,  0] [ 6,  0,  0] -1 */
    18426598, /* 67674 (1623) [-1,  0,  0,  0,  0,  1,  0,  1,  0] [ 6,  6,  0]  1 */
    18426592, /* 67675 (1623) [-1,  0,  0,  0,  0,  1,  0, -1,  0] [ 6,  6,  0]  1 */
    34140982, /* 67676 (1623) [ 0,  0,  1,  0,  1,  0,  1,  0,  0] [ 0,  0,  6] -1 */
    18433612, /* 67677 (1623) [ 0,  0,  1, -1,  0,  0,  0, -1,  0] [ 6,  6,  0]  1 */
    17131846, /* 67678 (1623) [ 0, -1,  0,  0,  0, -1,  1,  0,  0] [ 6,  0,  6]  1 */
    35440216, /* 67679 (1623) [ 0,  0,  1,  1,  0,  0,  0,  1,  0] [ 0,  6,  0] -1 */
     1544146, /* 67680 (1623) [ 0,  0, -1, -1,  0,  0,  0,  1,  0] [ 0,  6,  6]  1 */
    17135996, /* 67681 (1623) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 6,  0,  6]  1 */
    51026026, /* 67682 (1623) [ 0, -1,  0,  0,  0,  1,  1,  0,  0] [ 6,  0,  0] -1 */
    17134690, /* 67683 (1623) [ 0,  0,  1,  0, -1,  0, -1,  0,  0] [ 6,  0,  6]  1 */
     1551646, /* 67684 (1623) [ 1,  0,  0,  0,  0, -1,  0, -1,  0] [ 0,  6,  6]  1 */
    51034708, /* 67685 (1623) [ 1,  0,  0,  0,  0, -1,  0, -1,  0] [ 6,  0,  0] -1 */
    34137958, /* 67686 (1623) [ 0, -1,  0,  0,  0, -1,  1,  0,  0] [ 0,  0,  6] -1 */
    18432472, /* 67687 (1623) [ 0,  0, -1,  0,  1,  0, -1,  0,  0] [ 6,  6,  0]  1 */
    34142108, /* 67688 (1623) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    52565396, /* 67689 (1623) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    34140802, /* 67690 (1623) [ 0,  0,  1,  0, -1,  0, -1,  0,  0] [ 0,  0,  6] -1 */
    52564090, /* 67691 (1623) [ 0,  0,  1,  0, -1,  0, -1,  0,  0] [ 6,  6,  6] -1 */
    51034762, /* 67692 (1623) [ 1,  0,  0,  0,  0,  1,  0, -1,  0] [ 6,  0,  0] -1 */
    34139680, /* 67693 (1623) [ 0,  0, -1,  1,  0,  0,  0,  1,  0] [ 0,  0,  6] -1 */
    17134870, /* 67694 (1623) [ 0,  0,  1,  0,  1,  0,  1,  0,  0] [ 6,  0,  6]  1 */
    17140530, /* 67695 (1623) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  6]  1 */
        7896, /* 67696 (1623) [ 0, -1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    17133232, /* 67697 (1623) [ 0,  0, -1,  0, -1,  0, -1,  0,  0] [ 6,  0,  6]  1 */
    52564270, /* 67698 (1623) [ 0,  0,  1,  0,  1,  0,  1,  0,  0] [ 6,  6,  6] -1 */
    35445722, /* 67699 (1623) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  0] -1 */
    34146642, /* 67700 (1623) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
    52569930, /* 67701 (1623) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    35438758, /* 67702 (1623) [ 0,  0, -1,  1,  0,  0,  0,  1,  0] [ 0,  6,  0] -1 */
    34139344, /* 67703 (1623) [ 0,  0, -1,  0, -1,  0, -1,  0,  0] [ 0,  0,  6] -1 */
    35432762, /* 67704 (1623) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  0] -1 */
     1551758, /* 67705 (1623) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
     1542946, /* 67706 (1623) [ 0, -1,  0,  0,  0,  1, -1,  0,  0] [ 0,  6,  6]  1 */
    17133082, /* 67707 (1623) [ 0,  0, -1, -1,  0,  0,  0,  1,  0] [ 6,  0,  6]  1 */
     1547266, /* 67708 (1623) [ 0,  1,  0,  0,  0, -1, -1,  0,  0] [ 0,  6,  6]  1 */
    17136482, /* 67709 (1623) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 6,  0,  6]  1 */
    17140582, /* 67710 (1623) [ 1,  0,  0,  0,  0, -1,  0, -1,  0] [ 6,  0,  6]  1 */
     1547546, /* 67711 (1623) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 0,  6,  6]  1 */
    34139194, /* 67712 (1623) [ 0,  0, -1, -1,  0,  0,  0,  1,  0] [ 0,  0,  6] -1 */
    52562812, /* 67713 (1623) [ 0,  0, -1,  0,  1,  0,  1,  0,  0] [ 6,  6,  6] -1 */
    34146694, /* 67714 (1623) [ 1,  0,  0,  0,  0, -1,  0, -1,  0] [ 0,  0,  6] -1 */
       11784, /* 67715 (1623) [ 0,  1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    18435072, /* 67716 (1623) [ 0,  1,  0, -1,  0,  0,  0,  0, -1] [ 6,  6,  0]  1 */
    35438602, /* 67717 (1623) [ 0,  0, -1,  0,  1,  0,  1,  0,  0] [ 0,  6,  0] -1 */
        3360, /* 67718 (1623) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
     1546084, /* 67719 (1623) [ 0,  0,  1,  1,  0,  0,  0, -1,  0] [ 0,  6,  6]  1 */
    35441186, /* 67720 (1623) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 0,  6,  0] -1 */
       12010, /* 67721 (1623) [ 0,  1,  0,  0,  0, -1,  1,  0,  0] [ 0,  0,  0]  1 */
    18426488, /* 67722 (1623) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    52562476, /* 67723 (1623) [ 0,  0, -1, -1,  0,  0,  0, -1,  0] [ 6,  6,  6] -1 */
    51027376, /* 67724 (1623) [ 0,  0, -1,  0, -1,  0,  1,  0,  0] [ 6,  0,  0] -1 */
     1543172, /* 67725 (1623) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 0,  6,  6]  1 */
     1545916, /* 67726 (1623) [ 0,  0,  1,  0,  1,  0, -1,  0,  0] [ 0,  6,  6]  1 */
       16378, /* 67727 (1623) [ 1,  0,  0,  0,  0, -1,  0,  1,  0] [ 0,  0,  0]  1 */
    35440060, /* 67728 (1623) [ 0,  0,  1,  0,  1,  0,  1,  0,  0] [ 0,  6,  0] -1 */
    18426486, /* 67729 (1623) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
     1551596, /* 67730 (1623) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
    35445720, /* 67731 (1623) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  0] -1 */
    17131882, /* 67732 (1623) [ 0, -1,  0,  0,  0,  1, -1,  0,  0] [ 6,  0,  6]  1 */
    52570094, /* 67733 (1623) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    17136202, /* 67734 (1623) [ 0,  1,  0,  0,  0, -1, -1,  0,  0] [ 6,  0,  6]  1 */
        7690, /* 67735 (1623) [ 0, -1,  0,  0,  0,  1,  1,  0,  0] [ 0,  0,  0]  1 */
    18430978, /* 67736 (1623) [ 0, -1,  0,  0,  0,  1,  1,  0,  0] [ 6,  6,  0]  1 */
    51021698, /* 67737 (1623) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  0] -1 */
    34137994, /* 67738 (1623) [ 0, -1,  0,  0,  0,  1, -1,  0,  0] [ 0,  0,  6] -1 */
    52561282, /* 67739 (1623) [ 0, -1,  0,  0,  0,  1, -1,  0,  0] [ 6,  6,  6] -1 */
     1551756, /* 67740 (1623) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
     1538530, /* 67741 (1623) [-1,  0,  0,  0,  0, -1,  0,  1,  0] [ 0,  6,  6]  1 */
     1542892, /* 67742 (1623) [ 0, -1,  0,  0,  0, -1, -1,  0,  0] [ 0,  6,  6]  1 */
    34142314, /* 67743 (1623) [ 0,  1,  0,  0,  0, -1, -1,  0,  0] [ 0,  0,  6] -1 */
    52565602, /* 67744 (1623) [ 0,  1,  0,  0,  0, -1, -1,  0,  0] [ 6,  6,  6] -1 */
     1547544, /* 67745 (1623) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 0,  6,  6]  1 */
    52565674, /* 67746 (1623) [ 0,  1,  0,  0,  0,  1,  1,  0,  0] [ 6,  6,  6] -1 */
    34142386, /* 67747 (1623) [ 0,  1,  0,  0,  0,  1,  1,  0,  0] [ 0,  0,  6] -1 */
    18439714, /* 67748 (1623) [ 1,  0,  0,  0,  0,  1,  0, -1,  0] [ 6,  6,  0]  1 */
    34142594, /* 67749 (1623) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    51029152, /* 67750 (1623) [ 0,  0,  1,  1,  0,  0,  0,  1,  0] [ 6,  0,  0] -1 */
    35439880, /* 67751 (1623) [ 0,  0,  1,  0, -1,  0, -1,  0,  0] [ 0,  6,  0] -1 */
    18439666, /* 67752 (1623) [ 1,  0,  0,  0,  0, -1,  0,  1,  0] [ 6,  6,  0]  1 */
       10498, /* 67753 (1623) [ 0,  0,  1,  0, -1,  0,  1,  0,  0] [ 0,  0,  0]  1 */
    18433786, /* 67754 (1623) [ 0,  0,  1,  0, -1,  0,  1,  0,  0] [ 6,  6,  0]  1 */
    52562962, /* 67755 (1623) [ 0,  0, -1,  1,  0,  0,  0, -1,  0] [ 6,  6,  6] -1 */
    17132108, /* 67756 (1623) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 6,  0,  6]  1 */
       16432, /* 67757 (1623) [ 1,  0,  0,  0,  0,  1,  0,  1,  0] [ 0,  0,  0]  1 */
    17140532, /* 67758 (1623) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
    51034658, /* 67759 (1623) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  0] -1 */
    51028816, /* 67760 (1623) [ 0,  0,  1,  0, -1,  0, -1,  0,  0] [ 6,  0,  0] -1 */
    35438266, /* 67761 (1623) [ 0,  0, -1, -1,  0,  0,  0, -1,  0] [ 0,  6,  0] -1 */
    51027694, /* 67762 (1623) [ 0,  0, -1,  1,  0,  0,  0,  1,  0] [ 6,  0,  0] -1 */
    52565656, /* 67763 (1623) [ 0,  1,  0,  0,  0,  1, -1,  0,  0] [ 6,  6,  6] -1 */
    34138220, /* 67764 (1623) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    52565882, /* 67765 (1623) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    17131828, /* 67766 (1623) [ 0, -1,  0,  0,  0, -1, -1,  0,  0] [ 6,  0,  6]  1 */
    51028996, /* 67767 (1623) [ 0,  0,  1,  0,  1,  0,  1,  0,  0] [ 6,  0,  0] -1 */
    17136480, /* 67768 (1623) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 6,  0,  6]  1 */
    51034656, /* 67769 (1623) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  0] -1 */
    17135020, /* 67770 (1623) [ 0,  0,  1,  1,  0,  0,  0, -1,  0] [ 6,  0,  6]  1 */
    35445884, /* 67771 (1623) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  0] -1 */
        3250, /* 67772 (1623) [-1,  0,  0,  0,  0, -1,  0, -1,  0] [ 0,  0,  0]  1 */
    52570092, /* 67773 (1623) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    34146804, /* 67774 (1623) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
    34137940, /* 67775 (1623) [ 0, -1,  0,  0,  0, -1, -1,  0,  0] [ 0,  0,  6] -1 */
    52556866, /* 67776 (1623) [-1,  0,  0,  0,  0, -1,  0,  1,  0] [ 6,  6,  6] -1 */
    34142592, /* 67777 (1623) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  6] -1 */
    34141132, /* 67778 (1623) [ 0,  0,  1,  1,  0,  0,  0, -1,  0] [ 0,  0,  6] -1 */
    52564420, /* 67779 (1623) [ 0,  0,  1,  1,  0,  0,  0, -1,  0] [ 6,  6,  6] -1 */
    35441392, /* 67780 (1623) [ 0,  1,  0,  0,  0, -1, -1,  0,  0] [ 0,  6,  0] -1 */
    51025972, /* 67781 (1623) [ 0, -1,  0,  0,  0, -1,  1,  0,  0] [ 6,  0,  0] -1 */
        3304, /* 67782 (1623) [-1,  0,  0,  0,  0,  1,  0, -1,  0] [ 0,  0,  0]  1 */
    35441464, /* 67783 (1623) [ 0,  1,  0,  0,  0,  1,  1,  0,  0] [ 0,  6,  0] -1 */
       10324, /* 67784 (1623) [ 0,  0,  1, -1,  0,  0,  0, -1,  0] [ 0,  0,  0]  1 */
     1538634, /* 67785 (1623) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
    17134852, /* 67786 (1623) [ 0,  0,  1,  0,  1,  0, -1,  0,  0] [ 6,  0,  6]  1 */
    34140964, /* 67787 (1623) [ 0,  0,  1,  0,  1,  0, -1,  0,  0] [ 0,  0,  6] -1 */
    52564252, /* 67788 (1623) [ 0,  0,  1,  0,  1,  0, -1,  0,  0] [ 6,  6,  6] -1 */
    17127572, /* 67789 (1623) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
    51030122, /* 67790 (1623) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 6,  0,  0] -1 */
    18439610, /* 67791 (1623) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    35437072, /* 67792 (1623) [ 0, -1,  0,  0,  0,  1, -1,  0,  0] [ 0,  6,  0] -1 */
     1544140, /* 67793 (1623) [ 0,  0, -1, -1,  0,  0,  0, -1,  0] [ 0,  6,  6]  1 */
    51027202, /* 67794 (1623) [ 0,  0, -1, -1,  0,  0,  0, -1,  0] [ 6,  0,  0] -1 */
        3310, /* 67795 (1623) [-1,  0,  0,  0,  0,  1,  0,  1,  0] [ 0,  0,  0]  1 */
       10816, /* 67796 (1623) [ 0,  0,  1,  1,  0,  0,  0,  1,  0] [ 0,  0,  0]  1 */
    18434104, /* 67797 (1623) [ 0,  0,  1,  1,  0,  0,  0,  1,  0] [ 6,  6,  0]  1 */
    35437298, /* 67798 (1623) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 0,  6,  0] -1 */
    35441672, /* 67799 (1623) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 0,  6,  0] -1 */
    52562794, /* 67800 (1623) [ 0,  0, -1,  0,  1,  0, -1,  0,  0] [ 6,  6,  6] -1 */
    52561020, /* 67801 (1623) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    17133412, /* 67802 (1623) [ 0,  0, -1,  0,  1,  0,  1,  0,  0] [ 6,  0,  6]  1 */
    52561506, /* 67803 (1623) [ 0, -1,  0,  1,  0,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    17127570, /* 67804 (1623) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6]  1 */
     1547320, /* 67805 (1623) [ 0,  1,  0,  0,  0,  1, -1,  0,  0] [ 0,  6,  6]  1 */
    35432656, /* 67806 (1623) [-1,  0,  0,  0,  0, -1,  0,  1,  0] [ 0,  6,  0] -1 */
    35441670, /* 67807 (1623) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 0,  6,  0] -1 */
        9040, /* 67808 (1623) [ 0,  0, -1,  0, -1,  0,  1,  0,  0] [ 0,  0,  0]  1 */
    18432328, /* 67809 (1623) [ 0,  0, -1,  0, -1,  0,  1,  0,  0] [ 6,  6,  0]  1 */
    35440210, /* 67810 (1623) [ 0,  0,  1,  1,  0,  0,  0, -1,  0] [ 0,  6,  0] -1 */
    35438752, /* 67811 (1623) [ 0,  0, -1,  1,  0,  0,  0, -1,  0] [ 0,  6,  0] -1 */
    51030328, /* 67812 (1623) [ 0,  1,  0,  0,  0, -1, -1,  0,  0] [ 6,  0,  0] -1 */
    51027208, /* 67813 (1623) [ 0,  0, -1, -1,  0,  0,  0,  1,  0] [ 6,  0,  0] -1 */
    51030400, /* 67814 (1623) [ 0,  1,  0,  0,  0,  1,  1,  0,  0] [ 6,  0,  0] -1 */
     1551706, /* 67815 (1623) [ 1,  0,  0,  0,  0,  1,  0,  1,  0] [ 0,  6,  6]  1 */
    18426650, /* 67816 (1623) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
       10330, /* 67817 (1623) [ 0,  0,  1, -1,  0,  0,  0,  1,  0] [ 0,  0,  0]  1 */
    18433618, /* 67818 (1623) [ 0,  0,  1, -1,  0,  0,  0,  1,  0] [ 6,  6,  0]  1 */
    35440042, /* 67819 (1623) [ 0,  0,  1,  0,  1,  0, -1,  0,  0] [ 0,  6,  0] -1 */
    17133076, /* 67820 (1623) [ 0,  0, -1, -1,  0,  0,  0, -1,  0] [ 6,  0,  6]  1 */
    18433948, /* 67821 (1623) [ 0,  0,  1,  0,  1,  0,  1,  0,  0] [ 6,  6,  0]  1 */
    35445882, /* 67822 (1623) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  0] -1 */
    34139188, /* 67823 (1623) [ 0,  0, -1, -1,  0,  0,  0, -1,  0] [ 0,  0,  6] -1 */
     1547284, /* 67824 (1623) [ 0,  1,  0,  0,  0, -1,  1,  0,  0] [ 0,  6,  6]  1 */
    18439608, /* 67825 (1623) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
    35437018, /* 67826 (1623) [ 0, -1,  0,  0,  0, -1, -1,  0,  0] [ 0,  6,  0] -1 */
    17136256, /* 67827 (1623) [ 0,  1,  0,  0,  0,  1, -1,  0,  0] [ 6,  0,  6]  1 */
    52556970, /* 67828 (1623) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
     1547338, /* 67829 (1623) [ 0,  1,  0,  0,  0,  1,  1,  0,  0] [ 0,  6,  6]  1 */
    51026234, /* 67830 (1623) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 6,  0,  0] -1 */
    51030608, /* 67831 (1623) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 6,  0,  0] -1 */
        7636, /* 67832 (1623) [ 0, -1,  0,  0,  0, -1,  1,  0,  0] [ 0,  0,  0]  1 */
     1542686, /* 67833 (1623) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 0,  6,  6]  1 */
    18430924, /* 67834 (1623) [ 0, -1,  0,  0,  0, -1,  1,  0,  0] [ 6,  6,  0]  1 */
    34139524, /* 67835 (1623) [ 0,  0, -1,  0,  1,  0,  1,  0,  0] [ 0,  0,  6] -1 */
    35436810, /* 67836 (1623) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 0,  6,  0] -1 */
    34133682, /* 67837 (1623) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
    51026008, /* 67838 (1623) [ 0, -1,  0,  0,  0,  1, -1,  0,  0] [ 6,  0,  0] -1 */
    18435074, /* 67839 (1623) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    35437296, /* 67840 (1623) [ 0, -1,  0,  1,  0,  0,  0,  0, -1] [ 0,  6,  0] -1 */
       10480, /* 67841 (1623) [ 0,  0,  1,  0, -1,  0, -1,  0,  0] [ 0,  0,  0]  1 */
    18433768, /* 67842 (1623) [ 0,  0,  1,  0, -1,  0, -1,  0,  0] [ 6,  6,  0]  1 */
    51034818, /* 67843 (1623) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  0] -1 */
    18432646, /* 67844 (1623) [ 0,  0, -1,  1,  0,  0,  0,  1,  0] [ 6,  6,  0]  1 */
    51030606, /* 67845 (1623) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 6,  0,  0] -1 */
       16426, /* 67846 (1623) [ 1,  0,  0,  0,  0,  1,  0, -1,  0] [ 0,  0,  0]  1 */
     1544626, /* 67847 (1623) [ 0,  0, -1,  1,  0,  0,  0, -1,  0] [ 0,  6,  6]  1 */
    51029146, /* 67848 (1623) [ 0,  0,  1,  1,  0,  0,  0, -1,  0] [ 6,  0,  0] -1 */
        3200, /* 67849 (1623) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    52561300, /* 67850 (1623) [ 0, -1,  0,  0,  0,  1,  1,  0,  0] [ 6,  6,  6] -1 */
       16484, /* 67851 (1624) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
     1428962, /* 67852 (1624) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 0,  6,  0]  1 */
    17140694, /* 67853 (1624) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
    17133568, /* 67854 (1624) [ 0,  0, -1,  1,  0,  0,  0,  1,  0] [ 6,  0,  6]  1 */
     1433602, /* 67855 (1624) [ 1,  0,  0,  0,  0,  1,  0, -1,  0] [ 0,  6,  0]  1 */
       16320, /* 67856 (1624) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    17136220, /* 67857 (1624) [ 0,  1,  0,  0,  0, -1,  1,  0,  0] [ 6,  0,  6]  1 */
     1420480, /* 67858 (1624) [-1,  0,  0,  0,  0,  1,  0, -1,  0] [ 0,  6,  0]  1 */
        3198, /* 67859 (1624) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
     1545598, /* 67860 (1624) [ 0,  0,  1, -1,  0,  0,  0, -1,  0] [ 0,  6,  6]  1 */
    17140532, /* 67861 (1624) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
      121354, /* 67862 (1624) [-1,  0,  0,  0,  0, -1,  0,  1,  0] [ 0,  0,  6]  1 */
    17015152, /* 67863 (1624) [ 0,  0, -1,  0, -1,  0,  1,  0,  0] [ 6,  0,  0]  1 */
     1424588, /* 67864 (1624) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 0,  6,  0]  1 */
     1538474, /* 67865 (1624) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
    18550570, /* 67866 (1624) [ 0,  0, -1,  0,  1,  0, -1,  0,  0] [ 6,  6,  6]  1 */
      127282, /* 67867 (1624) [ 0,  0, -1,  0,  1,  0, -1,  0,  0] [ 0,  0,  6]  1 */
      125508, /* 67868 (1624) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  6]  1 */
    17136274, /* 67869 (1624) [ 0,  1,  0,  0,  0,  1,  1,  0,  0] [ 6,  0,  6]  1 */
    18548796, /* 67870 (1624) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 6,  6,  6]  1 */
     1427836, /* 67871 (1624) [ 0,  0,  1,  0,  1,  0,  1,  0,  0] [ 0,  6,  0]  1 */
        9352, /* 67872 (1624) [ 0,  0, -1,  1,  0,  0,  0, -1,  0] [ 0,  0,  0]  1 */
    17014008, /* 67873 (1624) [ 0, -1,  0,  1,  0,  0,  0,  0, -1] [ 6,  0,  0]  1 */
     1433554, /* 67874 (1624) [ 1,  0,  0,  0,  0, -1,  0,  1,  0] [ 0,  6,  0]  1 */
    17131828, /* 67875 (1624) [ 0, -1,  0,  0,  0, -1, -1,  0,  0] [ 6,  0,  6]  1 */
    18426648, /* 67876 (1624) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
     1420432, /* 67877 (1624) [-1,  0,  0,  0,  0, -1,  0,  1,  0] [ 0,  6,  0]  1 */
        8872, /* 67878 (1624) [ 0,  0, -1, -1,  0,  0,  0,  1,  0] [ 0,  0,  0]  1 */
    18432160, /* 67879 (1624) [ 0,  0, -1, -1,  0,  0,  0,  1,  0] [ 6,  6,  0]  1 */
    17014010, /* 67880 (1624) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 6,  0,  0]  1 */
    17009422, /* 67881 (1624) [-1,  0,  0,  0,  0,  1,  0,  1,  0] [ 6,  0,  0]  1 */
     1426198, /* 67882 (1624) [ 0,  0, -1,  0, -1,  0, -1,  0,  0] [ 0,  6,  0]  1 */
    17018384, /* 67883 (1624) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 6,  0,  0]  1 */
    17135020, /* 67884 (1624) [ 0,  0,  1,  1,  0,  0,  0, -1,  0] [ 6,  0,  6]  1 */
    18544696, /* 67885 (1624) [-1,  0,  0,  0,  0,  1,  0,  1,  0] [ 6,  6,  6]  1 */
      125994, /* 67886 (1624) [ 0, -1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  6]  1 */
    17009362, /* 67887 (1624) [-1,  0,  0,  0,  0, -1,  0, -1,  0] [ 6,  0,  0]  1 */
      127300, /* 67888 (1624) [ 0,  0, -1,  0,  1,  0,  1,  0,  0] [ 0,  0,  6]  1 */
    18550588, /* 67889 (1624) [ 0,  0, -1,  0,  1,  0,  1,  0,  0] [ 6,  6,  6]  1 */
    17131900, /* 67890 (1624) [ 0, -1,  0,  0,  0,  1,  1,  0,  0] [ 6,  0,  6]  1 */
    18433612, /* 67891 (1624) [ 0,  0,  1, -1,  0,  0,  0, -1,  0] [ 6,  6,  0]  1 */
    17133562, /* 67892 (1624) [ 0,  0, -1,  1,  0,  0,  0, -1,  0] [ 6,  0,  6]  1 */
      121402, /* 67893 (1624) [-1,  0,  0,  0,  0,  1,  0, -1,  0] [ 0,  0,  6]  1 */
    17131846, /* 67894 (1624) [ 0, -1,  0,  0,  0, -1,  1,  0,  0] [ 6,  0,  6]  1 */
     1427656, /* 67895 (1624) [ 0,  0,  1,  0, -1,  0, -1,  0,  0] [ 0,  6,  0]  1 */
    17018382, /* 67896 (1624) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 6,  0,  0]  1 */
       10324, /* 67897 (1624) [ 0,  0,  1, -1,  0,  0,  0, -1,  0] [ 0,  0,  0]  1 */
     1538634, /* 67898 (1624) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
     1426378, /* 67899 (1624) [ 0,  0, -1,  0,  1,  0,  1,  0,  0] [ 0,  6,  0]  1 */
     1544146, /* 67900 (1624) [ 0,  0, -1, -1,  0,  0,  0,  1,  0] [ 0,  6,  6]  1 */
     1420426, /* 67901 (1624) [-1,  0,  0,  0,  0, -1,  0, -1,  0] [ 0,  6,  0]  1 */
    17134534, /* 67902 (1624) [ 0,  0,  1, -1,  0,  0,  0, -1,  0] [ 6,  0,  6]  1 */
        8866, /* 67903 (1624) [ 0,  0, -1, -1,  0,  0,  0, -1,  0] [ 0,  0,  0]  1 */
    17127572, /* 67904 (1624) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
    18432154, /* 67905 (1624) [ 0,  0, -1, -1,  0,  0,  0, -1,  0] [ 6,  6,  0]  1 */
      127138, /* 67906 (1624) [ 0,  0, -1,  0, -1,  0,  1,  0,  0] [ 0,  0,  6]  1 */
    18550426, /* 67907 (1624) [ 0,  0, -1,  0, -1,  0,  1,  0,  0] [ 6,  6,  6]  1 */
     1427674, /* 67908 (1624) [ 0,  0,  1,  0, -1,  0,  1,  0,  0] [ 0,  6,  0]  1 */
    17017896, /* 67909 (1624) [ 0,  1,  0, -1,  0,  0,  0,  0, -1] [ 6,  0,  0]  1 */
    18439772, /* 67910 (1624) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    17016754, /* 67911 (1624) [ 0,  0,  1,  0,  1,  0, -1,  0,  0] [ 6,  0,  0]  1 */
    17140530, /* 67912 (1624) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  6]  1 */
    18553170, /* 67913 (1624) [ 0,  1,  0, -1,  0,  0,  0,  0, -1] [ 6,  6,  6]  1 */
    17127408, /* 67914 (1624) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  6]  1 */
    17140692, /* 67915 (1624) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6]  1 */
    17016592, /* 67916 (1624) [ 0,  0,  1,  0, -1,  0, -1,  0,  0] [ 6,  0,  0]  1 */
    18439610, /* 67917 (1624) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    18430960, /* 67918 (1624) [ 0, -1,  0,  0,  0,  1, -1,  0,  0] [ 6,  6,  0]  1 */
      125996, /* 67919 (1624) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 0,  0,  6]  1 */
    18549284, /* 67920 (1624) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 6,  6,  6]  1 */
      129882, /* 67921 (1624) [ 0,  1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  6]  1 */
    18435280, /* 67922 (1624) [ 0,  1,  0,  0,  0, -1, -1,  0,  0] [ 6,  6,  0]  1 */
      121408, /* 67923 (1624) [-1,  0,  0,  0,  0,  1,  0,  1,  0] [ 0,  0,  6]  1 */
    18435352, /* 67924 (1624) [ 0,  1,  0,  0,  0,  1,  1,  0,  0] [ 6,  6,  0]  1 */
     1544140, /* 67925 (1624) [ 0,  0, -1, -1,  0,  0,  0, -1,  0] [ 0,  6,  6]  1 */
    18553658, /* 67926 (1624) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 6,  6,  6]  1 */
     1426360, /* 67927 (1624) [ 0,  0, -1,  0,  1,  0, -1,  0,  0] [ 0,  6,  0]  1 */
     1424586, /* 67928 (1624) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 0,  6,  0]  1 */
       10816, /* 67929 (1624) [ 0,  0,  1,  1,  0,  0,  0,  1,  0] [ 0,  0,  0]  1 */
    18434104, /* 67930 (1624) [ 0,  0,  1,  1,  0,  0,  0,  1,  0] [ 6,  6,  0]  1 */
    17016772, /* 67931 (1624) [ 0,  0,  1,  0,  1,  0,  1,  0,  0] [ 6,  0,  0]  1 */
     1425072, /* 67932 (1624) [ 0, -1,  0,  1,  0,  0,  0,  0, -1] [ 0,  6,  0]  1 */
       11992, /* 67933 (1624) [ 0,  1,  0,  0,  0, -1, -1,  0,  0] [ 0,  0,  0]  1 */
       12064, /* 67934 (1624) [ 0,  1,  0,  0,  0,  1,  1,  0,  0] [ 0,  0,  0]  1 */
      130370, /* 67935 (1624) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 0,  0,  6]  1 */
     1551758, /* 67936 (1624) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
    17022490, /* 67937 (1624) [ 1,  0,  0,  0,  0, -1,  0,  1,  0] [ 6,  0,  0]  1 */
    18557818, /* 67938 (1624) [ 1,  0,  0,  0,  0,  1,  0,  1,  0] [ 6,  6,  6]  1 */
      125510, /* 67939 (1624) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  6]  1 */
    17016610, /* 67940 (1624) [ 0,  0,  1,  0, -1,  0,  1,  0,  0] [ 6,  0,  0]  1 */
    18548798, /* 67941 (1624) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 6,  6,  6]  1 */
     1545604, /* 67942 (1624) [ 0,  0,  1, -1,  0,  0,  0,  1,  0] [ 0,  6,  6]  1 */
    18544642, /* 67943 (1624) [-1,  0,  0,  0,  0, -1,  0,  1,  0] [ 6,  6,  6]  1 */
     1433548, /* 67944 (1624) [ 1,  0,  0,  0,  0, -1,  0, -1,  0] [ 0,  6,  0]  1 */
    17015134, /* 67945 (1624) [ 0,  0, -1,  0, -1,  0, -1,  0,  0] [ 6,  0,  0]  1 */
      130368, /* 67946 (1624) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  6]  1 */
    18553656, /* 67947 (1624) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 6,  6,  6]  1 */
    17127570, /* 67948 (1624) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6]  1 */
     1542946, /* 67949 (1624) [ 0, -1,  0,  0,  0,  1, -1,  0,  0] [ 0,  6,  6]  1 */
    17133082, /* 67950 (1624) [ 0,  0, -1, -1,  0,  0,  0,  1,  0] [ 6,  0,  6]  1 */
     1547320, /* 67951 (1624) [ 0,  1,  0,  0,  0,  1, -1,  0,  0] [ 0,  6,  6]  1 */
     1547266, /* 67952 (1624) [ 0,  1,  0,  0,  0, -1, -1,  0,  0] [ 0,  6,  6]  1 */
    18434098, /* 67953 (1624) [ 0,  0,  1,  1,  0,  0,  0, -1,  0] [ 6,  6,  0]  1 */
     1546090, /* 67954 (1624) [ 0,  0,  1,  1,  0,  0,  0,  1,  0] [ 0,  6,  6]  1 */
      128740, /* 67955 (1624) [ 0,  0,  1,  0,  1,  0, -1,  0,  0] [ 0,  0,  6]  1 */
    18552028, /* 67956 (1624) [ 0,  0,  1,  0,  1,  0, -1,  0,  0] [ 6,  6,  6]  1 */
    18435298, /* 67957 (1624) [ 0,  1,  0,  0,  0, -1,  1,  0,  0] [ 6,  6,  0]  1 */
      129884, /* 67958 (1624) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  6]  1 */
    18553172, /* 67959 (1624) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    17017898, /* 67960 (1624) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 6,  0,  0]  1 */
    18426650, /* 67961 (1624) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    18557812, /* 67962 (1624) [ 1,  0,  0,  0,  0,  1,  0, -1,  0] [ 6,  6,  6]  1 */
      128578, /* 67963 (1624) [ 0,  0,  1,  0, -1,  0, -1,  0,  0] [ 0,  0,  6]  1 */
        7672, /* 67964 (1624) [ 0, -1,  0,  0,  0,  1, -1,  0,  0] [ 0,  0,  0]  1 */
    18551866, /* 67965 (1624) [ 0,  0,  1,  0, -1,  0, -1,  0,  0] [ 6,  6,  6]  1 */
       10330, /* 67966 (1624) [ 0,  0,  1, -1,  0,  0,  0,  1,  0] [ 0,  0,  0]  1 */
    18433618, /* 67967 (1624) [ 0,  0,  1, -1,  0,  0,  0,  1,  0] [ 6,  6,  0]  1 */
        3360, /* 67968 (1624) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
     1546084, /* 67969 (1624) [ 0,  0,  1,  1,  0,  0,  0, -1,  0] [ 0,  6,  6]  1 */
       12010, /* 67970 (1624) [ 0,  1,  0,  0,  0, -1,  1,  0,  0] [ 0,  0,  0]  1 */
       12046, /* 67971 (1624) [ 0,  1,  0,  0,  0,  1, -1,  0,  0] [ 0,  0,  0]  1 */
    18435334, /* 67972 (1624) [ 0,  1,  0,  0,  0,  1, -1,  0,  0] [ 6,  6,  0]  1 */
    18426488, /* 67973 (1624) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    17133076, /* 67974 (1624) [ 0,  0, -1, -1,  0,  0,  0, -1,  0] [ 6,  0,  6]  1 */
        3362, /* 67975 (1624) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    17013524, /* 67976 (1624) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 6,  0,  0]  1 */
    18439770, /* 67977 (1624) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
        7618, /* 67978 (1624) [ 0, -1,  0,  0,  0, -1, -1,  0,  0] [ 0,  0,  0]  1 */
    18430906, /* 67979 (1624) [ 0, -1,  0,  0,  0, -1, -1,  0,  0] [ 6,  6,  0]  1 */
    18552046, /* 67980 (1624) [ 0,  0,  1,  0,  1,  0,  1,  0,  0] [ 6,  6,  6]  1 */
     1544632, /* 67981 (1624) [ 0,  0, -1,  1,  0,  0,  0,  1,  0] [ 0,  6,  6]  1 */
      134476, /* 67982 (1624) [ 1,  0,  0,  0,  0, -1,  0,  1,  0] [ 0,  0,  6]  1 */
     1547284, /* 67983 (1624) [ 0,  1,  0,  0,  0, -1,  1,  0,  0] [ 0,  6,  6]  1 */
    18439608, /* 67984 (1624) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
    18557764, /* 67985 (1624) [ 1,  0,  0,  0,  0, -1,  0,  1,  0] [ 6,  6,  6]  1 */
      128596, /* 67986 (1624) [ 0,  0,  1,  0, -1,  0,  1,  0,  0] [ 0,  0,  6]  1 */
    18551884, /* 67987 (1624) [ 0,  0,  1,  0, -1,  0,  1,  0,  0] [ 6,  6,  6]  1 */
    17022544, /* 67988 (1624) [ 1,  0,  0,  0,  0,  1,  0,  1,  0] [ 6,  0,  0]  1 */
    18426486, /* 67989 (1624) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
    17134540, /* 67990 (1624) [ 0,  0,  1, -1,  0,  0,  0,  1,  0] [ 6,  0,  6]  1 */
     1425074, /* 67991 (1624) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 0,  6,  0]  1 */
     1538636, /* 67992 (1624) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
     1551596, /* 67993 (1624) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
    17009368, /* 67994 (1624) [-1,  0,  0,  0,  0, -1,  0,  1,  0] [ 6,  0,  0]  1 */
      128758, /* 67995 (1624) [ 0,  0,  1,  0,  1,  0,  1,  0,  0] [ 0,  0,  6]  1 */
    17136256, /* 67996 (1624) [ 0,  1,  0,  0,  0,  1, -1,  0,  0] [ 6,  0,  6]  1 */
     1420486, /* 67997 (1624) [-1,  0,  0,  0,  0,  1,  0,  1,  0] [ 0,  6,  0]  1 */
    17127410, /* 67998 (1624) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
    18550408, /* 67999 (1624) [ 0,  0, -1,  0, -1,  0, -1,  0,  0] [ 6,  6,  6]  1 */
     1429448, /* 68000 (1624) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 0,  6,  0]  1 */
      127120, /* 68001 (1624) [ 0,  0, -1,  0, -1,  0, -1,  0,  0] [ 0,  0,  6]  1 */
    17015296, /* 68002 (1624) [ 0,  0, -1,  0,  1,  0, -1,  0,  0] [ 6,  0,  0]  1 */
    17131882, /* 68003 (1624) [ 0, -1,  0,  0,  0,  1, -1,  0,  0] [ 6,  0,  6]  1 */
    17013522, /* 68004 (1624) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 6,  0,  0]  1 */
    17136202, /* 68005 (1624) [ 0,  1,  0,  0,  0, -1, -1,  0,  0] [ 6,  0,  6]  1 */
     1547338, /* 68006 (1624) [ 0,  1,  0,  0,  0,  1,  1,  0,  0] [ 0,  6,  6]  1 */
      134530, /* 68007 (1624) [ 1,  0,  0,  0,  0,  1,  0,  1,  0] [ 0,  0,  6]  1 */
       10810, /* 68008 (1624) [ 0,  0,  1,  1,  0,  0,  0, -1,  0] [ 0,  0,  0]  1 */
        7690, /* 68009 (1624) [ 0, -1,  0,  0,  0,  1,  1,  0,  0] [ 0,  0,  0]  1 */
    18432640, /* 68010 (1624) [ 0,  0, -1,  1,  0,  0,  0, -1,  0] [ 6,  6,  0]  1 */
    18430978, /* 68011 (1624) [ 0, -1,  0,  0,  0,  1,  1,  0,  0] [ 6,  6,  0]  1 */
    17135026, /* 68012 (1624) [ 0,  0,  1,  1,  0,  0,  0,  1,  0] [ 6,  0,  6]  1 */
    18549282, /* 68013 (1624) [ 0, -1,  0,  1,  0,  0,  0,  0, -1] [ 6,  6,  6]  1 */
        7636, /* 68014 (1624) [ 0, -1,  0,  0,  0, -1,  1,  0,  0] [ 0,  0,  0]  1 */
    18430924, /* 68015 (1624) [ 0, -1,  0,  0,  0, -1,  1,  0,  0] [ 6,  6,  0]  1 */
     1433608, /* 68016 (1624) [ 1,  0,  0,  0,  0,  1,  0,  1,  0] [ 0,  6,  0]  1 */
     1551756, /* 68017 (1624) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
     1542892, /* 68018 (1624) [ 0, -1,  0,  0,  0, -1, -1,  0,  0] [ 0,  6,  6]  1 */
    17022484, /* 68019 (1624) [ 1,  0,  0,  0,  0, -1,  0, -1,  0] [ 6,  0,  0]  1 */
     1551594, /* 68020 (1624) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
     1429446, /* 68021 (1624) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 0,  6,  0]  1 */
    18557758, /* 68022 (1624) [ 1,  0,  0,  0,  0, -1,  0, -1,  0] [ 6,  6,  6]  1 */
     1538472, /* 68023 (1624) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
    18544636, /* 68024 (1624) [-1,  0,  0,  0,  0, -1,  0, -1,  0] [ 6,  6,  6]  1 */
    17015314, /* 68025 (1624) [ 0,  0, -1,  0,  1,  0,  1,  0,  0] [ 6,  0,  0]  1 */
    18432646, /* 68026 (1624) [ 0,  0, -1,  1,  0,  0,  0,  1,  0] [ 6,  6,  0]  1 */
     1426216, /* 68027 (1624) [ 0,  0, -1,  0, -1,  0,  1,  0,  0] [ 0,  6,  0]  1 */
      134524, /* 68028 (1624) [ 1,  0,  0,  0,  0,  1,  0, -1,  0] [ 0,  0,  6]  1 */
      134470, /* 68029 (1624) [ 1,  0,  0,  0,  0, -1,  0, -1,  0] [ 0,  0,  6]  1 */
    17022538, /* 68030 (1624) [ 1,  0,  0,  0,  0,  1,  0, -1,  0] [ 6,  0,  0]  1 */
       16322, /* 68031 (1624) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
     1542964, /* 68032 (1624) [ 0, -1,  0,  0,  0,  1,  1,  0,  0] [ 0,  6,  6]  1 */
     1544626, /* 68033 (1624) [ 0,  0, -1,  1,  0,  0,  0, -1,  0] [ 0,  6,  6]  1 */
      121348, /* 68034 (1624) [-1,  0,  0,  0,  0, -1,  0, -1,  0] [ 0,  0,  6]  1 */
    17009416, /* 68035 (1624) [-1,  0,  0,  0,  0,  1,  0, -1,  0] [ 6,  0,  0]  1 */
        3200, /* 68036 (1624) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
        9358, /* 68037 (1624) [ 0,  0, -1,  1,  0,  0,  0,  1,  0] [ 0,  0,  0]  1 */
    18544690, /* 68038 (1624) [-1,  0,  0,  0,  0,  1,  0, -1,  0] [ 6,  6,  6]  1 */
     1542910, /* 68039 (1624) [ 0, -1,  0,  0,  0, -1,  1,  0,  0] [ 0,  6,  6]  1 */
     1427818, /* 68040 (1624) [ 0,  0,  1,  0,  1,  0, -1,  0,  0] [ 0,  6,  0]  1 */
       16482, /* 68041 (1624) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
     1428960, /* 68042 (1624) [ 0,  1,  0, -1,  0,  0,  0,  0, -1] [ 0,  6,  0]  1 */
       16484, /* 68043 (1625) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    17140694, /* 68044 (1625) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
    17136220, /* 68045 (1625) [ 0,  1,  0,  0,  0, -1,  1,  0,  0] [ 6,  0,  6]  1 */
    51028978, /* 68046 (1625) [ 0,  0,  1,  0,  1,  0, -1,  0,  0] [ 6,  0,  0] -1 */
    52451996, /* 68047 (1625) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
        3198, /* 68048 (1625) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
     1545598, /* 68049 (1625) [ 0,  0,  1, -1,  0,  0,  0, -1,  0] [ 0,  6,  6]  1 */
    52565394, /* 68050 (1625) [ 0,  1,  0, -1,  0,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    34019896, /* 68051 (1625) [ 0, -1,  0,  0,  0,  1, -1,  0,  0] [ 0,  0,  0] -1 */
    52443184, /* 68052 (1625) [ 0, -1,  0,  0,  0,  1, -1,  0,  0] [ 6,  6,  0] -1 */
    17136274, /* 68053 (1625) [ 0,  1,  0,  0,  0,  1,  1,  0,  0] [ 6,  0,  6]  1 */
    52447576, /* 68054 (1625) [ 0,  1,  0,  0,  0,  1,  1,  0,  0] [ 6,  6,  0] -1 */
        8872, /* 68055 (1625) [ 0,  0, -1, -1,  0,  0,  0,  1,  0] [ 0,  0,  0]  1 */
    18432160, /* 68056 (1625) [ 0,  0, -1, -1,  0,  0,  0,  1,  0] [ 6,  6,  0]  1 */
    17014010, /* 68057 (1625) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 6,  0,  0]  1 */
    52570042, /* 68058 (1625) [ 1,  0,  0,  0,  0,  1,  0,  1,  0] [ 6,  6,  6] -1 */
    17018384, /* 68059 (1625) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 6,  0,  0]  1 */
    34137734, /* 68060 (1625) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    52561022, /* 68061 (1625) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    52569988, /* 68062 (1625) [ 1,  0,  0,  0,  0, -1,  0,  1,  0] [ 6,  6,  6] -1 */
      127300, /* 68063 (1625) [ 0,  0, -1,  0,  1,  0,  1,  0,  0] [ 0,  0,  6]  1 */
    18550588, /* 68064 (1625) [ 0,  0, -1,  0,  1,  0,  1,  0,  0] [ 6,  6,  6]  1 */
    51146764, /* 68065 (1625) [ 0,  0,  1, -1,  0,  0,  0,  1,  0] [ 6,  0,  6] -1 */
    51021592, /* 68066 (1625) [-1,  0,  0,  0,  0, -1,  0,  1,  0] [ 6,  0,  0] -1 */
    17133562, /* 68067 (1625) [ 0,  0, -1,  1,  0,  0,  0, -1,  0] [ 6,  0,  6]  1 */
    34023034, /* 68068 (1625) [ 0,  0,  1,  1,  0,  0,  0, -1,  0] [ 0,  0,  0] -1 */
    52446322, /* 68069 (1625) [ 0,  0,  1,  1,  0,  0,  0, -1,  0] [ 6,  6,  0] -1 */
    52444864, /* 68070 (1625) [ 0,  0, -1,  1,  0,  0,  0, -1,  0] [ 6,  6,  0] -1 */
    17018382, /* 68071 (1625) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 6,  0,  0]  1 */
     1426378, /* 68072 (1625) [ 0,  0, -1,  0,  1,  0,  1,  0,  0] [ 0,  6,  0]  1 */
    17134534, /* 68073 (1625) [ 0,  0,  1, -1,  0,  0,  0, -1,  0] [ 6,  0,  6]  1 */
    34133572, /* 68074 (1625) [-1,  0,  0,  0,  0, -1,  0, -1,  0] [ 0,  0,  6] -1 */
    17016754, /* 68075 (1625) [ 0,  0,  1,  0,  1,  0, -1,  0,  0] [ 6,  0,  0]  1 */
    18439772, /* 68076 (1625) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    18553170, /* 68077 (1625) [ 0,  1,  0, -1,  0,  0,  0,  0, -1] [ 6,  6,  6]  1 */
    34015586, /* 68078 (1625) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    17140692, /* 68079 (1625) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6]  1 */
    18430960, /* 68080 (1625) [ 0, -1,  0,  0,  0,  1, -1,  0,  0] [ 6,  6,  0]  1 */
    35441184, /* 68081 (1625) [ 0,  1,  0, -1,  0,  0,  0,  0, -1] [ 0,  6,  0] -1 */
    34028706, /* 68082 (1625) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    52451994, /* 68083 (1625) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
    34019842, /* 68084 (1625) [ 0, -1,  0,  0,  0, -1, -1,  0,  0] [ 0,  0,  0] -1 */
    52443130, /* 68085 (1625) [ 0, -1,  0,  0,  0, -1, -1,  0,  0] [ 6,  6,  0] -1 */
    18435280, /* 68086 (1625) [ 0,  1,  0,  0,  0, -1, -1,  0,  0] [ 6,  6,  0]  1 */
    18435352, /* 68087 (1625) [ 0,  1,  0,  0,  0,  1,  1,  0,  0] [ 6,  6,  0]  1 */
    51139634, /* 68088 (1625) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
      130370, /* 68089 (1625) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 0,  0,  6]  1 */
    35550698, /* 68090 (1625) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
    18557818, /* 68091 (1625) [ 1,  0,  0,  0,  0,  1,  0,  1,  0] [ 6,  6,  6]  1 */
      125510, /* 68092 (1625) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  6]  1 */
    18548798, /* 68093 (1625) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    35445832, /* 68094 (1625) [ 1,  0,  0,  0,  0,  1,  0,  1,  0] [ 0,  6,  0] -1 */
    51026232, /* 68095 (1625) [ 0, -1,  0,  1,  0,  0,  0,  0, -1] [ 6,  0,  0] -1 */
    35445778, /* 68096 (1625) [ 1,  0,  0,  0,  0, -1,  0,  1,  0] [ 0,  6,  0] -1 */
    18434098, /* 68097 (1625) [ 0,  0,  1,  1,  0,  0,  0, -1,  0] [ 6,  6,  0]  1 */
    35550696, /* 68098 (1625) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  6] -1 */
    52556860, /* 68099 (1625) [-1,  0,  0,  0,  0, -1,  0, -1,  0] [ 6,  6,  6] -1 */
    51027538, /* 68100 (1625) [ 0,  0, -1,  0,  1,  0,  1,  0,  0] [ 6,  0,  0] -1 */
    34028546, /* 68101 (1625) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    34133626, /* 68102 (1625) [-1,  0,  0,  0,  0,  1,  0, -1,  0] [ 0,  0,  6] -1 */
    52556914, /* 68103 (1625) [-1,  0,  0,  0,  0,  1,  0, -1,  0] [ 6,  6,  6] -1 */
    35556370, /* 68104 (1625) [ 0,  0, -1, -1,  0,  0,  0,  1,  0] [ 0,  6,  6] -1 */
        3362, /* 68105 (1625) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    35432704, /* 68106 (1625) [-1,  0,  0,  0,  0,  1,  0, -1,  0] [ 0,  6,  0] -1 */
    34133578, /* 68107 (1625) [-1,  0,  0,  0,  0, -1,  0,  1,  0] [ 0,  0,  6] -1 */
    18439770, /* 68108 (1625) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
        7618, /* 68109 (1625) [ 0, -1,  0,  0,  0, -1, -1,  0,  0] [ 0,  0,  0]  1 */
    18430906, /* 68110 (1625) [ 0, -1,  0,  0,  0, -1, -1,  0,  0] [ 6,  6,  0]  1 */
    35436812, /* 68111 (1625) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 0,  6,  0] -1 */
    34139506, /* 68112 (1625) [ 0,  0, -1,  0,  1,  0, -1,  0,  0] [ 0,  0,  6] -1 */
    52562650, /* 68113 (1625) [ 0,  0, -1,  0, -1,  0,  1,  0,  0] [ 6,  6,  6] -1 */
    34137732, /* 68114 (1625) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  6] -1 */
    51030120, /* 68115 (1625) [ 0,  1,  0, -1,  0,  0,  0,  0, -1] [ 6,  0,  0] -1 */
    17127410, /* 68116 (1625) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
    52438872, /* 68117 (1625) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
    34133632, /* 68118 (1625) [-1,  0,  0,  0,  0,  1,  0,  1,  0] [ 0,  0,  6] -1 */
    52556920, /* 68119 (1625) [-1,  0,  0,  0,  0,  1,  0,  1,  0] [ 6,  6,  6] -1 */
    34138218, /* 68120 (1625) [ 0, -1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  6] -1 */
     1433608, /* 68121 (1625) [ 1,  0,  0,  0,  0,  1,  0,  1,  0] [ 0,  6,  0]  1 */
    51144124, /* 68122 (1625) [ 0, -1,  0,  0,  0,  1,  1,  0,  0] [ 6,  0,  6] -1 */
    51034714, /* 68123 (1625) [ 1,  0,  0,  0,  0, -1,  0,  1,  0] [ 6,  0,  0] -1 */
     1538472, /* 68124 (1625) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
    18544636, /* 68125 (1625) [-1,  0,  0,  0,  0, -1,  0, -1,  0] [ 6,  6,  6]  1 */
    17015314, /* 68126 (1625) [ 0,  0, -1,  0,  1,  0,  1,  0,  0] [ 6,  0,  0]  1 */
     1542964, /* 68127 (1625) [ 0, -1,  0,  0,  0,  1,  1,  0,  0] [ 0,  6,  6]  1 */
       16322, /* 68128 (1625) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    35432650, /* 68129 (1625) [-1,  0,  0,  0,  0, -1,  0, -1,  0] [ 0,  6,  0] -1 */
    51145306, /* 68130 (1625) [ 0,  0, -1, -1,  0,  0,  0,  1,  0] [ 6,  0,  6] -1 */
        9358, /* 68131 (1625) [ 0,  0, -1,  1,  0,  0,  0,  1,  0] [ 0,  0,  0]  1 */
    18544690, /* 68132 (1625) [-1,  0,  0,  0,  0,  1,  0, -1,  0] [ 6,  6,  6]  1 */
    34021090, /* 68133 (1625) [ 0,  0, -1, -1,  0,  0,  0, -1,  0] [ 0,  0,  0] -1 */
       16320, /* 68134 (1625) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
     1420480, /* 68135 (1625) [-1,  0,  0,  0,  0,  1,  0, -1,  0] [ 0,  6,  0]  1 */
    51139632, /* 68136 (1625) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  6] -1 */
      121354, /* 68137 (1625) [-1,  0,  0,  0,  0, -1,  0,  1,  0] [ 0,  0,  6]  1 */
     1424588, /* 68138 (1625) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 0,  6,  0]  1 */
      127282, /* 68139 (1625) [ 0,  0, -1,  0,  1,  0, -1,  0,  0] [ 0,  0,  6]  1 */
    18550570, /* 68140 (1625) [ 0,  0, -1,  0,  1,  0, -1,  0,  0] [ 6,  6,  6]  1 */
      125508, /* 68141 (1625) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  6]  1 */
    18548796, /* 68142 (1625) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 6,  6,  6]  1 */
    34015584, /* 68143 (1625) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    34142106, /* 68144 (1625) [ 0,  1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  6] -1 */
    34024234, /* 68145 (1625) [ 0,  1,  0,  0,  0, -1,  1,  0,  0] [ 0,  0,  0] -1 */
    35438584, /* 68146 (1625) [ 0,  0, -1,  0,  1,  0, -1,  0,  0] [ 0,  6,  0] -1 */
    18426648, /* 68147 (1625) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
     1420432, /* 68148 (1625) [-1,  0,  0,  0,  0, -1,  0,  1,  0] [ 0,  6,  0]  1 */
    34024288, /* 68149 (1625) [ 0,  1,  0,  0,  0,  1,  1,  0,  0] [ 0,  0,  0] -1 */
    18544696, /* 68150 (1625) [-1,  0,  0,  0,  0,  1,  0,  1,  0] [ 6,  6,  6]  1 */
    51034768, /* 68151 (1625) [ 1,  0,  0,  0,  0,  1,  0,  1,  0] [ 6,  0,  0] -1 */
      125994, /* 68152 (1625) [ 0, -1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  6]  1 */
    35563820, /* 68153 (1625) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
    35432710, /* 68154 (1625) [-1,  0,  0,  0,  0,  1,  0,  1,  0] [ 0,  6,  0] -1 */
    52562632, /* 68155 (1625) [ 0,  0, -1,  0, -1,  0, -1,  0,  0] [ 6,  6,  6] -1 */
    17131900, /* 68156 (1625) [ 0, -1,  0,  0,  0,  1,  1,  0,  0] [ 6,  0,  6]  1 */
    52443202, /* 68157 (1625) [ 0, -1,  0,  0,  0,  1,  1,  0,  0] [ 6,  6,  0] -1 */
    35558314, /* 68158 (1625) [ 0,  0,  1,  1,  0,  0,  0,  1,  0] [ 0,  6,  6] -1 */
     1420426, /* 68159 (1625) [-1,  0,  0,  0,  0, -1,  0, -1,  0] [ 0,  6,  0]  1 */
    52447522, /* 68160 (1625) [ 0,  1,  0,  0,  0, -1,  1,  0,  0] [ 6,  6,  0] -1 */
        8866, /* 68161 (1625) [ 0,  0, -1, -1,  0,  0,  0, -1,  0] [ 0,  0,  0]  1 */
    18432154, /* 68162 (1625) [ 0,  0, -1, -1,  0,  0,  0, -1,  0] [ 6,  6,  0]  1 */
    35438440, /* 68163 (1625) [ 0,  0, -1,  0, -1,  0,  1,  0,  0] [ 0,  6,  0] -1 */
    34146748, /* 68164 (1625) [ 1,  0,  0,  0,  0,  1,  0, -1,  0] [ 0,  0,  6] -1 */
    52570036, /* 68165 (1625) [ 1,  0,  0,  0,  0,  1,  0, -1,  0] [ 6,  6,  6] -1 */
    34024270, /* 68166 (1625) [ 0,  1,  0,  0,  0,  1, -1,  0,  0] [ 0,  0,  0] -1 */
    52447558, /* 68167 (1625) [ 0,  1,  0,  0,  0,  1, -1,  0,  0] [ 6,  6,  0] -1 */
    51021640, /* 68168 (1625) [-1,  0,  0,  0,  0,  1,  0, -1,  0] [ 6,  0,  0] -1 */
    34028708, /* 68169 (1625) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    17127408, /* 68170 (1625) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  6]  1 */
    51025748, /* 68171 (1625) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 6,  0,  0] -1 */
      129882, /* 68172 (1625) [ 0,  1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  6]  1 */
    35556856, /* 68173 (1625) [ 0,  0, -1,  1,  0,  0,  0,  1,  0] [ 0,  6,  6] -1 */
    34146700, /* 68174 (1625) [ 1,  0,  0,  0,  0, -1,  0,  1,  0] [ 0,  0,  6] -1 */
     1426360, /* 68175 (1625) [ 0,  0, -1,  0,  1,  0, -1,  0,  0] [ 0,  6,  0]  1 */
    34140820, /* 68176 (1625) [ 0,  0,  1,  0, -1,  0,  1,  0,  0] [ 0,  0,  6] -1 */
    52564108, /* 68177 (1625) [ 0,  0,  1,  0, -1,  0,  1,  0,  0] [ 6,  6,  6] -1 */
     1424586, /* 68178 (1625) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 0,  6,  0]  1 */
    51152756, /* 68179 (1625) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
    35550860, /* 68180 (1625) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
     1425072, /* 68181 (1625) [ 0, -1,  0,  1,  0,  0,  0,  0, -1] [ 0,  6,  0]  1 */
       11992, /* 68182 (1625) [ 0,  1,  0,  0,  0, -1, -1,  0,  0] [ 0,  0,  0]  1 */
       12064, /* 68183 (1625) [ 0,  1,  0,  0,  0,  1,  1,  0,  0] [ 0,  0,  0]  1 */
    51027520, /* 68184 (1625) [ 0,  0, -1,  0,  1,  0, -1,  0,  0] [ 6,  0,  0] -1 */
    51025746, /* 68185 (1625) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 6,  0,  0] -1 */
    34146754, /* 68186 (1625) [ 1,  0,  0,  0,  0,  1,  0,  1,  0] [ 0,  0,  6] -1 */
     1545604, /* 68187 (1625) [ 0,  0,  1, -1,  0,  0,  0,  1,  0] [ 0,  6,  6]  1 */
    51147250, /* 68188 (1625) [ 0,  0,  1,  1,  0,  0,  0,  1,  0] [ 6,  0,  6] -1 */
    35563818, /* 68189 (1625) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  6] -1 */
    52569982, /* 68190 (1625) [ 1,  0,  0,  0,  0, -1,  0, -1,  0] [ 6,  6,  6] -1 */
    51021646, /* 68191 (1625) [-1,  0,  0,  0,  0,  1,  0,  1,  0] [ 6,  0,  0] -1 */
    35438422, /* 68192 (1625) [ 0,  0, -1,  0, -1,  0, -1,  0,  0] [ 0,  6,  0] -1 */
     1546090, /* 68193 (1625) [ 0,  0,  1,  1,  0,  0,  0,  1,  0] [ 0,  6,  6]  1 */
    51021586, /* 68194 (1625) [-1,  0,  0,  0,  0, -1,  0, -1,  0] [ 6,  0,  0] -1 */
    18435298, /* 68195 (1625) [ 0,  1,  0,  0,  0, -1,  1,  0,  0] [ 6,  6,  0]  1 */
    35555134, /* 68196 (1625) [ 0, -1,  0,  0,  0, -1,  1,  0,  0] [ 0,  6,  6] -1 */
    34022548, /* 68197 (1625) [ 0,  0,  1, -1,  0,  0,  0, -1,  0] [ 0,  0,  0] -1 */
    18557812, /* 68198 (1625) [ 1,  0,  0,  0,  0,  1,  0, -1,  0] [ 6,  6,  6]  1 */
        7672, /* 68199 (1625) [ 0, -1,  0,  0,  0,  1, -1,  0,  0] [ 0,  0,  0]  1 */
       12046, /* 68200 (1625) [ 0,  1,  0,  0,  0,  1, -1,  0,  0] [ 0,  0,  0]  1 */
    18435334, /* 68201 (1625) [ 0,  1,  0,  0,  0,  1, -1,  0,  0] [ 6,  6,  0]  1 */
    51145792, /* 68202 (1625) [ 0,  0, -1,  1,  0,  0,  0,  1,  0] [ 6,  0,  6] -1 */
    35445826, /* 68203 (1625) [ 1,  0,  0,  0,  0,  1,  0, -1,  0] [ 0,  6,  0] -1 */
    17013524, /* 68204 (1625) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 6,  0,  0]  1 */
    51139796, /* 68205 (1625) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
     1544632, /* 68206 (1625) [ 0,  0, -1,  1,  0,  0,  0,  1,  0] [ 0,  6,  6]  1 */
      134476, /* 68207 (1625) [ 1,  0,  0,  0,  0, -1,  0,  1,  0] [ 0,  0,  6]  1 */
    18557764, /* 68208 (1625) [ 1,  0,  0,  0,  0, -1,  0,  1,  0] [ 6,  6,  6]  1 */
      128596, /* 68209 (1625) [ 0,  0,  1,  0, -1,  0,  1,  0,  0] [ 0,  0,  6]  1 */
    18551884, /* 68210 (1625) [ 0,  0,  1,  0, -1,  0,  1,  0,  0] [ 6,  6,  6]  1 */
    17134540, /* 68211 (1625) [ 0,  0,  1, -1,  0,  0,  0,  1,  0] [ 6,  0,  6]  1 */
    34021576, /* 68212 (1625) [ 0,  0, -1,  1,  0,  0,  0, -1,  0] [ 0,  0,  0] -1 */
     1538636, /* 68213 (1625) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
    17009368, /* 68214 (1625) [-1,  0,  0,  0,  0, -1,  0,  1,  0] [ 6,  0,  0]  1 */
    17015296, /* 68215 (1625) [ 0,  0, -1,  0,  1,  0, -1,  0,  0] [ 6,  0,  0]  1 */
    17013522, /* 68216 (1625) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 6,  0,  0]  1 */
      134530, /* 68217 (1625) [ 1,  0,  0,  0,  0,  1,  0,  1,  0] [ 0,  0,  6]  1 */
       10810, /* 68218 (1625) [ 0,  0,  1,  1,  0,  0,  0, -1,  0] [ 0,  0,  0]  1 */
    18432640, /* 68219 (1625) [ 0,  0, -1,  1,  0,  0,  0, -1,  0] [ 6,  6,  0]  1 */
    52561508, /* 68220 (1625) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    17135026, /* 68221 (1625) [ 0,  0,  1,  1,  0,  0,  0,  1,  0] [ 6,  0,  6]  1 */
    35556364, /* 68222 (1625) [ 0,  0, -1, -1,  0,  0,  0, -1,  0] [ 0,  6,  6] -1 */
    52445836, /* 68223 (1625) [ 0,  0,  1, -1,  0,  0,  0, -1,  0] [ 6,  6,  0] -1 */
     1551594, /* 68224 (1625) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
    18557758, /* 68225 (1625) [ 1,  0,  0,  0,  0, -1,  0, -1,  0] [ 6,  6,  6]  1 */
    51144070, /* 68226 (1625) [ 0, -1,  0,  0,  0, -1,  1,  0,  0] [ 6,  0,  6] -1 */
    35445772, /* 68227 (1625) [ 1,  0,  0,  0,  0, -1,  0, -1,  0] [ 0,  6,  0] -1 */
    51027358, /* 68228 (1625) [ 0,  0, -1,  0, -1,  0, -1,  0,  0] [ 6,  0,  0] -1 */
    35559544, /* 68229 (1625) [ 0,  1,  0,  0,  0,  1, -1,  0,  0] [ 0,  6,  6] -1 */
    52565880, /* 68230 (1625) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 6,  6,  6] -1 */
      121348, /* 68231 (1625) [-1,  0,  0,  0,  0, -1,  0, -1,  0] [ 0,  0,  6]  1 */
     1542910, /* 68232 (1625) [ 0, -1,  0,  0,  0, -1,  1,  0,  0] [ 0,  6,  6]  1 */
       16482, /* 68233 (1625) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
     1428960, /* 68234 (1625) [ 0,  1,  0, -1,  0,  0,  0,  0, -1] [ 0,  6,  0]  1 */
    34139362, /* 68235 (1625) [ 0,  0, -1,  0, -1,  0,  1,  0,  0] [ 0,  0,  6] -1 */
    17133568, /* 68236 (1625) [ 0,  0, -1,  1,  0,  0,  0,  1,  0] [ 6,  0,  6]  1 */
    35439898, /* 68237 (1625) [ 0,  0,  1,  0, -1,  0,  1,  0,  0] [ 0,  6,  0] -1 */
     1433602, /* 68238 (1625) [ 1,  0,  0,  0,  0,  1,  0, -1,  0] [ 0,  6,  0]  1 */
    51152754, /* 68239 (1625) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  6] -1 */
     1538474, /* 68240 (1625) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
    52445842, /* 68241 (1625) [ 0,  0,  1, -1,  0,  0,  0,  1,  0] [ 6,  6,  0] -1 */
        9352, /* 68242 (1625) [ 0,  0, -1,  1,  0,  0,  0, -1,  0] [ 0,  0,  0]  1 */
    17014008, /* 68243 (1625) [ 0, -1,  0,  1,  0,  0,  0,  0, -1] [ 6,  0,  0]  1 */
     1433554, /* 68244 (1625) [ 1,  0,  0,  0,  0, -1,  0,  1,  0] [ 0,  6,  0]  1 */
    35563982, /* 68245 (1625) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
    51028834, /* 68246 (1625) [ 0,  0,  1,  0, -1,  0,  1,  0,  0] [ 6,  0,  0] -1 */
    34140982, /* 68247 (1625) [ 0,  0,  1,  0,  1,  0,  1,  0,  0] [ 0,  0,  6] -1 */
    35555170, /* 68248 (1625) [ 0, -1,  0,  0,  0,  1, -1,  0,  0] [ 0,  6,  6] -1 */
    18433612, /* 68249 (1625) [ 0,  0,  1, -1,  0,  0,  0, -1,  0] [ 6,  6,  0]  1 */
    35559490, /* 68250 (1625) [ 0,  1,  0,  0,  0, -1, -1,  0,  0] [ 0,  6,  6] -1 */
      121402, /* 68251 (1625) [-1,  0,  0,  0,  0,  1,  0, -1,  0] [ 0,  0,  6]  1 */
    35559562, /* 68252 (1625) [ 0,  1,  0,  0,  0,  1,  1,  0,  0] [ 0,  6,  6] -1 */
    17131846, /* 68253 (1625) [ 0, -1,  0,  0,  0, -1,  1,  0,  0] [ 6,  0,  6]  1 */
    52443148, /* 68254 (1625) [ 0, -1,  0,  0,  0, -1,  1,  0,  0] [ 6,  6,  0] -1 */
     1544146, /* 68255 (1625) [ 0,  0, -1, -1,  0,  0,  0,  1,  0] [ 0,  6,  6]  1 */
    51034708, /* 68256 (1625) [ 1,  0,  0,  0,  0, -1,  0, -1,  0] [ 6,  0,  0] -1 */
    34142108, /* 68257 (1625) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    52565396, /* 68258 (1625) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    34140802, /* 68259 (1625) [ 0,  0,  1,  0, -1,  0, -1,  0,  0] [ 0,  0,  6] -1 */
      127138, /* 68260 (1625) [ 0,  0, -1,  0, -1,  0,  1,  0,  0] [ 0,  0,  6]  1 */
    18550426, /* 68261 (1625) [ 0,  0, -1,  0, -1,  0,  1,  0,  0] [ 6,  6,  6]  1 */
    52564090, /* 68262 (1625) [ 0,  0,  1,  0, -1,  0, -1,  0,  0] [ 6,  6,  6] -1 */
    51034762, /* 68263 (1625) [ 1,  0,  0,  0,  0,  1,  0, -1,  0] [ 6,  0,  0] -1 */
     1427674, /* 68264 (1625) [ 0,  0,  1,  0, -1,  0,  1,  0,  0] [ 0,  6,  0]  1 */
    35558308, /* 68265 (1625) [ 0,  0,  1,  1,  0,  0,  0, -1,  0] [ 0,  6,  6] -1 */
    35556850, /* 68266 (1625) [ 0,  0, -1,  1,  0,  0,  0, -1,  0] [ 0,  6,  6] -1 */
    17017896, /* 68267 (1625) [ 0,  1,  0, -1,  0,  0,  0,  0, -1] [ 6,  0,  0]  1 */
    34015424, /* 68268 (1625) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    52438712, /* 68269 (1625) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
    17140530, /* 68270 (1625) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  6]  1 */
    52564270, /* 68271 (1625) [ 0,  0,  1,  0,  1,  0,  1,  0,  0] [ 6,  6,  6] -1 */
    51152918, /* 68272 (1625) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
      121408, /* 68273 (1625) [-1,  0,  0,  0,  0,  1,  0,  1,  0] [ 0,  0,  6]  1 */
    34015422, /* 68274 (1625) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    52438710, /* 68275 (1625) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
    34139344, /* 68276 (1625) [ 0,  0, -1,  0, -1,  0, -1,  0,  0] [ 0,  0,  6] -1 */
    51144106, /* 68277 (1625) [ 0, -1,  0,  0,  0,  1, -1,  0,  0] [ 6,  0,  6] -1 */
     1551758, /* 68278 (1625) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
    17022490, /* 68279 (1625) [ 1,  0,  0,  0,  0, -1,  0,  1,  0] [ 6,  0,  0]  1 */
    51148426, /* 68280 (1625) [ 0,  1,  0,  0,  0, -1, -1,  0,  0] [ 6,  0,  6] -1 */
    34019914, /* 68281 (1625) [ 0, -1,  0,  0,  0,  1,  1,  0,  0] [ 0,  0,  0] -1 */
    51148498, /* 68282 (1625) [ 0,  1,  0,  0,  0,  1,  1,  0,  0] [ 6,  0,  6] -1 */
    17016610, /* 68283 (1625) [ 0,  0,  1,  0, -1,  0,  1,  0,  0] [ 6,  0,  0]  1 */
     1542946, /* 68284 (1625) [ 0, -1,  0,  0,  0,  1, -1,  0,  0] [ 0,  6,  6]  1 */
    17133082, /* 68285 (1625) [ 0,  0, -1, -1,  0,  0,  0,  1,  0] [ 6,  0,  6]  1 */
    35563980, /* 68286 (1625) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6] -1 */
    35555116, /* 68287 (1625) [ 0, -1,  0,  0,  0, -1, -1,  0,  0] [ 0,  6,  6] -1 */
     1547266, /* 68288 (1625) [ 0,  1,  0,  0,  0, -1, -1,  0,  0] [ 0,  6,  6]  1 */
    52444384, /* 68289 (1625) [ 0,  0, -1, -1,  0,  0,  0,  1,  0] [ 6,  6,  0] -1 */
    52562812, /* 68290 (1625) [ 0,  0, -1,  0,  1,  0,  1,  0,  0] [ 6,  6,  6] -1 */
    34146694, /* 68291 (1625) [ 1,  0,  0,  0,  0, -1,  0, -1,  0] [ 0,  0,  6] -1 */
      129884, /* 68292 (1625) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  6]  1 */
    18553172, /* 68293 (1625) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 6,  6,  6]  1 */
      128578, /* 68294 (1625) [ 0,  0,  1,  0, -1,  0, -1,  0,  0] [ 0,  0,  6]  1 */
    18551866, /* 68295 (1625) [ 0,  0,  1,  0, -1,  0, -1,  0,  0] [ 6,  6,  6]  1 */
    35438602, /* 68296 (1625) [ 0,  0, -1,  0,  1,  0,  1,  0,  0] [ 0,  6,  0] -1 */
        3360, /* 68297 (1625) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
     1546084, /* 68298 (1625) [ 0,  0,  1,  1,  0,  0,  0, -1,  0] [ 0,  6,  6]  1 */
    35441186, /* 68299 (1625) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 0,  6,  0] -1 */
       12010, /* 68300 (1625) [ 0,  1,  0,  0,  0, -1,  1,  0,  0] [ 0,  0,  0]  1 */
    18426488, /* 68301 (1625) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    18552046, /* 68302 (1625) [ 0,  0,  1,  0,  1,  0,  1,  0,  0] [ 6,  6,  6]  1 */
    51027376, /* 68303 (1625) [ 0,  0, -1,  0, -1,  0,  1,  0,  0] [ 6,  0,  0] -1 */
    17022544, /* 68304 (1625) [ 1,  0,  0,  0,  0,  1,  0,  1,  0] [ 6,  0,  0]  1 */
    35440060, /* 68305 (1625) [ 0,  0,  1,  0,  1,  0,  1,  0,  0] [ 0,  6,  0] -1 */
    18426486, /* 68306 (1625) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
     1551596, /* 68307 (1625) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
     1420486, /* 68308 (1625) [-1,  0,  0,  0,  0,  1,  0,  1,  0] [ 0,  6,  0]  1 */
    18550408, /* 68309 (1625) [ 0,  0, -1,  0, -1,  0, -1,  0,  0] [ 6,  6,  6]  1 */
      127120, /* 68310 (1625) [ 0,  0, -1,  0, -1,  0, -1,  0,  0] [ 0,  0,  6]  1 */
    17131882, /* 68311 (1625) [ 0, -1,  0,  0,  0,  1, -1,  0,  0] [ 6,  0,  6]  1 */
    51152916, /* 68312 (1625) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6] -1 */
    51144052, /* 68313 (1625) [ 0, -1,  0,  0,  0, -1, -1,  0,  0] [ 6,  0,  6] -1 */
    17136202, /* 68314 (1625) [ 0,  1,  0,  0,  0, -1, -1,  0,  0] [ 6,  0,  6]  1 */
        7690, /* 68315 (1625) [ 0, -1,  0,  0,  0,  1,  1,  0,  0] [ 0,  0,  0]  1 */
    18430978, /* 68316 (1625) [ 0, -1,  0,  0,  0,  1,  1,  0,  0] [ 6,  6,  0]  1 */
    52447504, /* 68317 (1625) [ 0,  1,  0,  0,  0, -1, -1,  0,  0] [ 6,  6,  0] -1 */
    51147244, /* 68318 (1625) [ 0,  0,  1,  1,  0,  0,  0, -1,  0] [ 6,  0,  6] -1 */
     1551756, /* 68319 (1625) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
     1542892, /* 68320 (1625) [ 0, -1,  0,  0,  0, -1, -1,  0,  0] [ 0,  6,  6]  1 */
    34142594, /* 68321 (1625) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    35439880, /* 68322 (1625) [ 0,  0,  1,  0, -1,  0, -1,  0,  0] [ 0,  6,  0] -1 */
     1426216, /* 68323 (1625) [ 0,  0, -1,  0, -1,  0,  1,  0,  0] [ 0,  6,  0]  1 */
      134524, /* 68324 (1625) [ 1,  0,  0,  0,  0,  1,  0, -1,  0] [ 0,  0,  6]  1 */
    35550858, /* 68325 (1625) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6] -1 */
      134470, /* 68326 (1625) [ 1,  0,  0,  0,  0, -1,  0, -1,  0] [ 0,  0,  6]  1 */
    17009416, /* 68327 (1625) [-1,  0,  0,  0,  0,  1,  0, -1,  0] [ 6,  0,  0]  1 */
     1428962, /* 68328 (1625) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 0,  6,  0]  1 */
    17140532, /* 68329 (1625) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
    51028816, /* 68330 (1625) [ 0,  0,  1,  0, -1,  0, -1,  0,  0] [ 6,  0,  0] -1 */
    17015152, /* 68331 (1625) [ 0,  0, -1,  0, -1,  0,  1,  0,  0] [ 6,  0,  0]  1 */
    52451834, /* 68332 (1625) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
    34138220, /* 68333 (1625) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 0,  0,  6] -1 */
     1427836, /* 68334 (1625) [ 0,  0,  1,  0,  1,  0,  1,  0,  0] [ 0,  6,  0]  1 */
    52565882, /* 68335 (1625) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    34023040, /* 68336 (1625) [ 0,  0,  1,  1,  0,  0,  0,  1,  0] [ 0,  0,  0] -1 */
    52446328, /* 68337 (1625) [ 0,  0,  1,  1,  0,  0,  0,  1,  0] [ 6,  6,  0] -1 */
    17131828, /* 68338 (1625) [ 0, -1,  0,  0,  0, -1, -1,  0,  0] [ 6,  0,  6]  1 */
    51028996, /* 68339 (1625) [ 0,  0,  1,  0,  1,  0,  1,  0,  0] [ 6,  0,  0] -1 */
    17009422, /* 68340 (1625) [-1,  0,  0,  0,  0,  1,  0,  1,  0] [ 6,  0,  0]  1 */
     1426198, /* 68341 (1625) [ 0,  0, -1,  0, -1,  0, -1,  0,  0] [ 0,  6,  0]  1 */
    17135020, /* 68342 (1625) [ 0,  0,  1,  1,  0,  0,  0, -1,  0] [ 6,  0,  6]  1 */
    17009362, /* 68343 (1625) [-1,  0,  0,  0,  0, -1,  0, -1,  0] [ 6,  0,  0]  1 */
    52556866, /* 68344 (1625) [-1,  0,  0,  0,  0, -1,  0,  1,  0] [ 6,  6,  6] -1 */
    51139794, /* 68345 (1625) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6] -1 */
    34142592, /* 68346 (1625) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  6] -1 */
     1427656, /* 68347 (1625) [ 0,  0,  1,  0, -1,  0, -1,  0,  0] [ 0,  6,  0]  1 */
       10324, /* 68348 (1625) [ 0,  0,  1, -1,  0,  0,  0, -1,  0] [ 0,  0,  0]  1 */
     1538634, /* 68349 (1625) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
    34140964, /* 68350 (1625) [ 0,  0,  1,  0,  1,  0, -1,  0,  0] [ 0,  0,  6] -1 */
    52564252, /* 68351 (1625) [ 0,  0,  1,  0,  1,  0, -1,  0,  0] [ 6,  6,  6] -1 */
    17127572, /* 68352 (1625) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
    51030122, /* 68353 (1625) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 6,  0,  0] -1 */
    52438874, /* 68354 (1625) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
    34022554, /* 68355 (1625) [ 0,  0,  1, -1,  0,  0,  0,  1,  0] [ 0,  0,  0] -1 */
    35555188, /* 68356 (1625) [ 0, -1,  0,  0,  0,  1,  1,  0,  0] [ 0,  6,  6] -1 */
    34021582, /* 68357 (1625) [ 0,  0, -1,  1,  0,  0,  0,  1,  0] [ 0,  0,  0] -1 */
    51145300, /* 68358 (1625) [ 0,  0, -1, -1,  0,  0,  0, -1,  0] [ 6,  0,  6] -1 */
    17016592, /* 68359 (1625) [ 0,  0,  1,  0, -1,  0, -1,  0,  0] [ 6,  0,  0]  1 */
    18439610, /* 68360 (1625) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
      125996, /* 68361 (1625) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 0,  0,  6]  1 */
    18549284, /* 68362 (1625) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    35559508, /* 68363 (1625) [ 0,  1,  0,  0,  0, -1,  1,  0,  0] [ 0,  6,  6] -1 */
    34028544, /* 68364 (1625) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
     1544140, /* 68365 (1625) [ 0,  0, -1, -1,  0,  0,  0, -1,  0] [ 0,  6,  6]  1 */
    52451832, /* 68366 (1625) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
    18553658, /* 68367 (1625) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 6,  6,  6]  1 */
       10816, /* 68368 (1625) [ 0,  0,  1,  1,  0,  0,  0,  1,  0] [ 0,  0,  0]  1 */
    18434104, /* 68369 (1625) [ 0,  0,  1,  1,  0,  0,  0,  1,  0] [ 6,  6,  0]  1 */
    35437298, /* 68370 (1625) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 0,  6,  0] -1 */
    51148480, /* 68371 (1625) [ 0,  1,  0,  0,  0,  1, -1,  0,  0] [ 6,  0,  6] -1 */
    17016772, /* 68372 (1625) [ 0,  0,  1,  0,  1,  0,  1,  0,  0] [ 6,  0,  0]  1 */
    35441672, /* 68373 (1625) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 0,  6,  0] -1 */
    52562794, /* 68374 (1625) [ 0,  0, -1,  0,  1,  0, -1,  0,  0] [ 6,  6,  6] -1 */
    52561020, /* 68375 (1625) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    18544642, /* 68376 (1625) [-1,  0,  0,  0,  0, -1,  0,  1,  0] [ 6,  6,  6]  1 */
     1433548, /* 68377 (1625) [ 1,  0,  0,  0,  0, -1,  0, -1,  0] [ 0,  6,  0]  1 */
    34019860, /* 68378 (1625) [ 0, -1,  0,  0,  0, -1,  1,  0,  0] [ 0,  0,  0] -1 */
    17015134, /* 68379 (1625) [ 0,  0, -1,  0, -1,  0, -1,  0,  0] [ 6,  0,  0]  1 */
      130368, /* 68380 (1625) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  6]  1 */
    18553656, /* 68381 (1625) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 6,  6,  6]  1 */
    17127570, /* 68382 (1625) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6]  1 */
     1547320, /* 68383 (1625) [ 0,  1,  0,  0,  0,  1, -1,  0,  0] [ 0,  6,  6]  1 */
    52561506, /* 68384 (1625) [ 0, -1,  0,  1,  0,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    35432656, /* 68385 (1625) [-1,  0,  0,  0,  0, -1,  0,  1,  0] [ 0,  6,  0] -1 */
    35441670, /* 68386 (1625) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 0,  6,  0] -1 */
    52444870, /* 68387 (1625) [ 0,  0, -1,  1,  0,  0,  0,  1,  0] [ 6,  6,  0] -1 */
      128740, /* 68388 (1625) [ 0,  0,  1,  0,  1,  0, -1,  0,  0] [ 0,  0,  6]  1 */
    18552028, /* 68389 (1625) [ 0,  0,  1,  0,  1,  0, -1,  0,  0] [ 6,  6,  6]  1 */
    17017898, /* 68390 (1625) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 6,  0,  0]  1 */
    18426650, /* 68391 (1625) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
       10330, /* 68392 (1625) [ 0,  0,  1, -1,  0,  0,  0,  1,  0] [ 0,  0,  0]  1 */
    18433618, /* 68393 (1625) [ 0,  0,  1, -1,  0,  0,  0,  1,  0] [ 6,  6,  0]  1 */
    35440042, /* 68394 (1625) [ 0,  0,  1,  0,  1,  0, -1,  0,  0] [ 0,  6,  0] -1 */
    51148444, /* 68395 (1625) [ 0,  1,  0,  0,  0, -1,  1,  0,  0] [ 6,  0,  6] -1 */
    17133076, /* 68396 (1625) [ 0,  0, -1, -1,  0,  0,  0, -1,  0] [ 6,  0,  6]  1 */
    35557822, /* 68397 (1625) [ 0,  0,  1, -1,  0,  0,  0, -1,  0] [ 0,  6,  6] -1 */
    52444378, /* 68398 (1625) [ 0,  0, -1, -1,  0,  0,  0, -1,  0] [ 6,  6,  0] -1 */
     1547284, /* 68399 (1625) [ 0,  1,  0,  0,  0, -1,  1,  0,  0] [ 0,  6,  6]  1 */
    18439608, /* 68400 (1625) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
     1425074, /* 68401 (1625) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 0,  6,  0]  1 */
      128758, /* 68402 (1625) [ 0,  0,  1,  0,  1,  0,  1,  0,  0] [ 0,  0,  6]  1 */
    17136256, /* 68403 (1625) [ 0,  1,  0,  0,  0,  1, -1,  0,  0] [ 6,  0,  6]  1 */
     1429448, /* 68404 (1625) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 0,  6,  0]  1 */
    34021096, /* 68405 (1625) [ 0,  0, -1, -1,  0,  0,  0,  1,  0] [ 0,  0,  0] -1 */
     1547338, /* 68406 (1625) [ 0,  1,  0,  0,  0,  1,  1,  0,  0] [ 0,  6,  6]  1 */
    51026234, /* 68407 (1625) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 6,  0,  0] -1 */
    51030608, /* 68408 (1625) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 6,  0,  0] -1 */
    18549282, /* 68409 (1625) [ 0, -1,  0,  1,  0,  0,  0,  0, -1] [ 6,  6,  6]  1 */
        7636, /* 68410 (1625) [ 0, -1,  0,  0,  0, -1,  1,  0,  0] [ 0,  0,  0]  1 */
    18430924, /* 68411 (1625) [ 0, -1,  0,  0,  0, -1,  1,  0,  0] [ 6,  6,  0]  1 */
    34139524, /* 68412 (1625) [ 0,  0, -1,  0,  1,  0,  1,  0,  0] [ 0,  0,  6] -1 */
    35436810, /* 68413 (1625) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 0,  6,  0] -1 */
    35437296, /* 68414 (1625) [ 0, -1,  0,  1,  0,  0,  0,  0, -1] [ 0,  6,  0] -1 */
    17022484, /* 68415 (1625) [ 1,  0,  0,  0,  0, -1,  0, -1,  0] [ 6,  0,  0]  1 */
    34024216, /* 68416 (1625) [ 0,  1,  0,  0,  0, -1, -1,  0,  0] [ 0,  0,  0] -1 */
     1429446, /* 68417 (1625) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 0,  6,  0]  1 */
    51145786, /* 68418 (1625) [ 0,  0, -1,  1,  0,  0,  0, -1,  0] [ 6,  0,  6] -1 */
    18432646, /* 68419 (1625) [ 0,  0, -1,  1,  0,  0,  0,  1,  0] [ 6,  6,  0]  1 */
    35557828, /* 68420 (1625) [ 0,  0,  1, -1,  0,  0,  0,  1,  0] [ 0,  6,  6] -1 */
    51030606, /* 68421 (1625) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 6,  0,  0] -1 */
    17022538, /* 68422 (1625) [ 1,  0,  0,  0,  0,  1,  0, -1,  0] [ 6,  0,  0]  1 */
     1544626, /* 68423 (1625) [ 0,  0, -1,  1,  0,  0,  0, -1,  0] [ 0,  6,  6]  1 */
        3200, /* 68424 (1625) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    51146758, /* 68425 (1625) [ 0,  0,  1, -1,  0,  0,  0, -1,  0] [ 6,  0,  6] -1 */
     1427818, /* 68426 (1625) [ 0,  0,  1,  0,  1,  0, -1,  0,  0] [ 0,  6,  0]  1 */
       16484, /* 68427 (1626) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    17140694, /* 68428 (1626) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
    35439898, /* 68429 (1626) [ 0,  0,  1,  0, -1,  0,  1,  0,  0] [ 0,  6,  0] -1 */
       16320, /* 68430 (1626) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    51028978, /* 68431 (1626) [ 0,  0,  1,  0,  1,  0, -1,  0,  0] [ 6,  0,  0] -1 */
     1420480, /* 68432 (1626) [-1,  0,  0,  0,  0,  1,  0, -1,  0] [ 0,  6,  0]  1 */
     1545598, /* 68433 (1626) [ 0,  0,  1, -1,  0,  0,  0, -1,  0] [ 0,  6,  6]  1 */
    51139632, /* 68434 (1626) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  6] -1 */
      121354, /* 68435 (1626) [-1,  0,  0,  0,  0, -1,  0,  1,  0] [ 0,  0,  6]  1 */
    17015152, /* 68436 (1626) [ 0,  0, -1,  0, -1,  0,  1,  0,  0] [ 6,  0,  0]  1 */
    52451834, /* 68437 (1626) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
     1424588, /* 68438 (1626) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 0,  6,  0]  1 */
     1538474, /* 68439 (1626) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
    18550570, /* 68440 (1626) [ 0,  0, -1,  0,  1,  0, -1,  0,  0] [ 6,  6,  6]  1 */
      127282, /* 68441 (1626) [ 0,  0, -1,  0,  1,  0, -1,  0,  0] [ 0,  0,  6]  1 */
    17136274, /* 68442 (1626) [ 0,  1,  0,  0,  0,  1,  1,  0,  0] [ 6,  0,  6]  1 */
    52445842, /* 68443 (1626) [ 0,  0,  1, -1,  0,  0,  0,  1,  0] [ 6,  6,  0] -1 */
    34138220, /* 68444 (1626) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    34024234, /* 68445 (1626) [ 0,  1,  0,  0,  0, -1,  1,  0,  0] [ 0,  0,  0] -1 */
     1427836, /* 68446 (1626) [ 0,  0,  1,  0,  1,  0,  1,  0,  0] [ 0,  6,  0]  1 */
        9352, /* 68447 (1626) [ 0,  0, -1,  1,  0,  0,  0, -1,  0] [ 0,  0,  0]  1 */
    17014008, /* 68448 (1626) [ 0, -1,  0,  1,  0,  0,  0,  0, -1] [ 6,  0,  0]  1 */
    18426648, /* 68449 (1626) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
     1420432, /* 68450 (1626) [-1,  0,  0,  0,  0, -1,  0,  1,  0] [ 0,  6,  0]  1 */
        8872, /* 68451 (1626) [ 0,  0, -1, -1,  0,  0,  0,  1,  0] [ 0,  0,  0]  1 */
    18432160, /* 68452 (1626) [ 0,  0, -1, -1,  0,  0,  0,  1,  0] [ 6,  6,  0]  1 */
    17018384, /* 68453 (1626) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 6,  0,  0]  1 */
    51028834, /* 68454 (1626) [ 0,  0,  1,  0, -1,  0,  1,  0,  0] [ 6,  0,  0] -1 */
      125994, /* 68455 (1626) [ 0, -1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  6]  1 */
    52569988, /* 68456 (1626) [ 1,  0,  0,  0,  0, -1,  0,  1,  0] [ 6,  6,  6] -1 */
    51146764, /* 68457 (1626) [ 0,  0,  1, -1,  0,  0,  0,  1,  0] [ 6,  0,  6] -1 */
    35563820, /* 68458 (1626) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
    34142592, /* 68459 (1626) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  6] -1 */
    35432710, /* 68460 (1626) [-1,  0,  0,  0,  0,  1,  0,  1,  0] [ 0,  6,  0] -1 */
    18433612, /* 68461 (1626) [ 0,  0,  1, -1,  0,  0,  0, -1,  0] [ 6,  6,  0]  1 */
    52562632, /* 68462 (1626) [ 0,  0, -1,  0, -1,  0, -1,  0,  0] [ 6,  6,  6] -1 */
    17133562, /* 68463 (1626) [ 0,  0, -1,  1,  0,  0,  0, -1,  0] [ 6,  0,  6]  1 */
      121402, /* 68464 (1626) [-1,  0,  0,  0,  0,  1,  0, -1,  0] [ 0,  0,  6]  1 */
    52443202, /* 68465 (1626) [ 0, -1,  0,  0,  0,  1,  1,  0,  0] [ 6,  6,  0] -1 */
    34023034, /* 68466 (1626) [ 0,  0,  1,  1,  0,  0,  0, -1,  0] [ 0,  0,  0] -1 */
    52446322, /* 68467 (1626) [ 0,  0,  1,  1,  0,  0,  0, -1,  0] [ 6,  6,  0] -1 */
    17131846, /* 68468 (1626) [ 0, -1,  0,  0,  0, -1,  1,  0,  0] [ 6,  0,  6]  1 */
     1427656, /* 68469 (1626) [ 0,  0,  1,  0, -1,  0, -1,  0,  0] [ 0,  6,  0]  1 */
       10324, /* 68470 (1626) [ 0,  0,  1, -1,  0,  0,  0, -1,  0] [ 0,  0,  0]  1 */
     1538634, /* 68471 (1626) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
     1544146, /* 68472 (1626) [ 0,  0, -1, -1,  0,  0,  0,  1,  0] [ 0,  6,  6]  1 */
    17134534, /* 68473 (1626) [ 0,  0,  1, -1,  0,  0,  0, -1,  0] [ 6,  0,  6]  1 */
    52564252, /* 68474 (1626) [ 0,  0,  1,  0,  1,  0, -1,  0,  0] [ 6,  6,  6] -1 */
    34140964, /* 68475 (1626) [ 0,  0,  1,  0,  1,  0, -1,  0,  0] [ 0,  0,  6] -1 */
    52447522, /* 68476 (1626) [ 0,  1,  0,  0,  0, -1,  1,  0,  0] [ 6,  6,  0] -1 */
    34142108, /* 68477 (1626) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    52565396, /* 68478 (1626) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    51030122, /* 68479 (1626) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 6,  0,  0] -1 */
    34146748, /* 68480 (1626) [ 1,  0,  0,  0,  0,  1,  0, -1,  0] [ 0,  0,  6] -1 */
    52438874, /* 68481 (1626) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
    52570036, /* 68482 (1626) [ 1,  0,  0,  0,  0,  1,  0, -1,  0] [ 6,  6,  6] -1 */
      127138, /* 68483 (1626) [ 0,  0, -1,  0, -1,  0,  1,  0,  0] [ 0,  0,  6]  1 */
    18550426, /* 68484 (1626) [ 0,  0, -1,  0, -1,  0,  1,  0,  0] [ 6,  6,  6]  1 */
    34022554, /* 68485 (1626) [ 0,  0,  1, -1,  0,  0,  0,  1,  0] [ 0,  0,  0] -1 */
    51034762, /* 68486 (1626) [ 1,  0,  0,  0,  0,  1,  0, -1,  0] [ 6,  0,  0] -1 */
    35555188, /* 68487 (1626) [ 0, -1,  0,  0,  0,  1,  1,  0,  0] [ 0,  6,  6] -1 */
    35558308, /* 68488 (1626) [ 0,  0,  1,  1,  0,  0,  0, -1,  0] [ 0,  6,  6] -1 */
    34024270, /* 68489 (1626) [ 0,  1,  0,  0,  0,  1, -1,  0,  0] [ 0,  0,  0] -1 */
    34133572, /* 68490 (1626) [-1,  0,  0,  0,  0, -1,  0, -1,  0] [ 0,  0,  6] -1 */
    17017896, /* 68491 (1626) [ 0,  1,  0, -1,  0,  0,  0,  0, -1] [ 6,  0,  0]  1 */
    18439772, /* 68492 (1626) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    52447558, /* 68493 (1626) [ 0,  1,  0,  0,  0,  1, -1,  0,  0] [ 6,  6,  0] -1 */
    34021582, /* 68494 (1626) [ 0,  0, -1,  1,  0,  0,  0,  1,  0] [ 0,  0,  0] -1 */
    17140530, /* 68495 (1626) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  6]  1 */
    18553170, /* 68496 (1626) [ 0,  1,  0, -1,  0,  0,  0,  0, -1] [ 6,  6,  6]  1 */
    51145300, /* 68497 (1626) [ 0,  0, -1, -1,  0,  0,  0, -1,  0] [ 6,  0,  6] -1 */
    34015586, /* 68498 (1626) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    17016592, /* 68499 (1626) [ 0,  0,  1,  0, -1,  0, -1,  0,  0] [ 6,  0,  0]  1 */
    34028706, /* 68500 (1626) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    52451994, /* 68501 (1626) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
    18430960, /* 68502 (1626) [ 0, -1,  0,  0,  0,  1, -1,  0,  0] [ 6,  6,  0]  1 */
    34019842, /* 68503 (1626) [ 0, -1,  0,  0,  0, -1, -1,  0,  0] [ 0,  0,  0] -1 */
    52443130, /* 68504 (1626) [ 0, -1,  0,  0,  0, -1, -1,  0,  0] [ 6,  6,  0] -1 */
      129882, /* 68505 (1626) [ 0,  1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  6]  1 */
    35556856, /* 68506 (1626) [ 0,  0, -1,  1,  0,  0,  0,  1,  0] [ 0,  6,  6] -1 */
    18435280, /* 68507 (1626) [ 0,  1,  0,  0,  0, -1, -1,  0,  0] [ 6,  6,  0]  1 */
    18435352, /* 68508 (1626) [ 0,  1,  0,  0,  0,  1,  1,  0,  0] [ 6,  6,  0]  1 */
    34146700, /* 68509 (1626) [ 1,  0,  0,  0,  0, -1,  0,  1,  0] [ 0,  0,  6] -1 */
    35559508, /* 68510 (1626) [ 0,  1,  0,  0,  0, -1,  1,  0,  0] [ 0,  6,  6] -1 */
    18553658, /* 68511 (1626) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 6,  6,  6]  1 */
     1426360, /* 68512 (1626) [ 0,  0, -1,  0,  1,  0, -1,  0,  0] [ 0,  6,  0]  1 */
    34140820, /* 68513 (1626) [ 0,  0,  1,  0, -1,  0,  1,  0,  0] [ 0,  0,  6] -1 */
    52564108, /* 68514 (1626) [ 0,  0,  1,  0, -1,  0,  1,  0,  0] [ 6,  6,  6] -1 */
       10816, /* 68515 (1626) [ 0,  0,  1,  1,  0,  0,  0,  1,  0] [ 0,  0,  0]  1 */
    34015422, /* 68516 (1626) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    18434104, /* 68517 (1626) [ 0,  0,  1,  1,  0,  0,  0,  1,  0] [ 6,  6,  0]  1 */
    35437298, /* 68518 (1626) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 0,  6,  0] -1 */
    52438710, /* 68519 (1626) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
    35550860, /* 68520 (1626) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
    51152756, /* 68521 (1626) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
    51148480, /* 68522 (1626) [ 0,  1,  0,  0,  0,  1, -1,  0,  0] [ 6,  0,  6] -1 */
    17016772, /* 68523 (1626) [ 0,  0,  1,  0,  1,  0,  1,  0,  0] [ 6,  0,  0]  1 */
    34139344, /* 68524 (1626) [ 0,  0, -1,  0, -1,  0, -1,  0,  0] [ 0,  0,  6] -1 */
       11992, /* 68525 (1626) [ 0,  1,  0,  0,  0, -1, -1,  0,  0] [ 0,  0,  0]  1 */
     1425072, /* 68526 (1626) [ 0, -1,  0,  1,  0,  0,  0,  0, -1] [ 0,  6,  0]  1 */
       12064, /* 68527 (1626) [ 0,  1,  0,  0,  0,  1,  1,  0,  0] [ 0,  0,  0]  1 */
    51025746, /* 68528 (1626) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 6,  0,  0] -1 */
     1551758, /* 68529 (1626) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
      130370, /* 68530 (1626) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 0,  0,  6]  1 */
    34019914, /* 68531 (1626) [ 0, -1,  0,  0,  0,  1,  1,  0,  0] [ 0,  0,  0] -1 */
    18557818, /* 68532 (1626) [ 1,  0,  0,  0,  0,  1,  0,  1,  0] [ 6,  6,  6]  1 */
      125510, /* 68533 (1626) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  6]  1 */
    52561020, /* 68534 (1626) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    18548798, /* 68535 (1626) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    18544642, /* 68536 (1626) [-1,  0,  0,  0,  0, -1,  0,  1,  0] [ 6,  6,  6]  1 */
     1433548, /* 68537 (1626) [ 1,  0,  0,  0,  0, -1,  0, -1,  0] [ 0,  6,  0]  1 */
    17127570, /* 68538 (1626) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6]  1 */
     1542946, /* 68539 (1626) [ 0, -1,  0,  0,  0,  1, -1,  0,  0] [ 0,  6,  6]  1 */
    35563980, /* 68540 (1626) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6] -1 */
    17133082, /* 68541 (1626) [ 0,  0, -1, -1,  0,  0,  0,  1,  0] [ 6,  0,  6]  1 */
    35445778, /* 68542 (1626) [ 1,  0,  0,  0,  0, -1,  0,  1,  0] [ 0,  6,  0] -1 */
    35555116, /* 68543 (1626) [ 0, -1,  0,  0,  0, -1, -1,  0,  0] [ 0,  6,  6] -1 */
     1547266, /* 68544 (1626) [ 0,  1,  0,  0,  0, -1, -1,  0,  0] [ 0,  6,  6]  1 */
    35441670, /* 68545 (1626) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 0,  6,  0] -1 */
    51021646, /* 68546 (1626) [-1,  0,  0,  0,  0,  1,  0,  1,  0] [ 6,  0,  0] -1 */
    35438422, /* 68547 (1626) [ 0,  0, -1,  0, -1,  0, -1,  0,  0] [ 0,  6,  0] -1 */
     1546090, /* 68548 (1626) [ 0,  0,  1,  1,  0,  0,  0,  1,  0] [ 0,  6,  6]  1 */
    35550696, /* 68549 (1626) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  6] -1 */
    52556860, /* 68550 (1626) [-1,  0,  0,  0,  0, -1,  0, -1,  0] [ 6,  6,  6] -1 */
    51027538, /* 68551 (1626) [ 0,  0, -1,  0,  1,  0,  1,  0,  0] [ 6,  0,  0] -1 */
    52444870, /* 68552 (1626) [ 0,  0, -1,  1,  0,  0,  0,  1,  0] [ 6,  6,  0] -1 */
    51021586, /* 68553 (1626) [-1,  0,  0,  0,  0, -1,  0, -1,  0] [ 6,  0,  0] -1 */
    52562812, /* 68554 (1626) [ 0,  0, -1,  0,  1,  0,  1,  0,  0] [ 6,  6,  6] -1 */
    34028546, /* 68555 (1626) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
      128578, /* 68556 (1626) [ 0,  0,  1,  0, -1,  0, -1,  0,  0] [ 0,  0,  6]  1 */
    18551866, /* 68557 (1626) [ 0,  0,  1,  0, -1,  0, -1,  0,  0] [ 6,  6,  6]  1 */
        7672, /* 68558 (1626) [ 0, -1,  0,  0,  0,  1, -1,  0,  0] [ 0,  0,  0]  1 */
    35438602, /* 68559 (1626) [ 0,  0, -1,  0,  1,  0,  1,  0,  0] [ 0,  6,  0] -1 */
    35440042, /* 68560 (1626) [ 0,  0,  1,  0,  1,  0, -1,  0,  0] [ 0,  6,  0] -1 */
        3360, /* 68561 (1626) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    35441186, /* 68562 (1626) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 0,  6,  0] -1 */
    51145792, /* 68563 (1626) [ 0,  0, -1,  1,  0,  0,  0,  1,  0] [ 6,  0,  6] -1 */
    18426488, /* 68564 (1626) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    35445826, /* 68565 (1626) [ 1,  0,  0,  0,  0,  1,  0, -1,  0] [ 0,  6,  0] -1 */
    51148444, /* 68566 (1626) [ 0,  1,  0,  0,  0, -1,  1,  0,  0] [ 6,  0,  6] -1 */
    17013524, /* 68567 (1626) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 6,  0,  0]  1 */
    51139796, /* 68568 (1626) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
    52444378, /* 68569 (1626) [ 0,  0, -1, -1,  0,  0,  0, -1,  0] [ 6,  6,  0] -1 */
    18552046, /* 68570 (1626) [ 0,  0,  1,  0,  1,  0,  1,  0,  0] [ 6,  6,  6]  1 */
    34137732, /* 68571 (1626) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  6] -1 */
    17022544, /* 68572 (1626) [ 1,  0,  0,  0,  0,  1,  0,  1,  0] [ 6,  0,  0]  1 */
    18439608, /* 68573 (1626) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
    17009368, /* 68574 (1626) [-1,  0,  0,  0,  0, -1,  0,  1,  0] [ 6,  0,  0]  1 */
      128758, /* 68575 (1626) [ 0,  0,  1,  0,  1,  0,  1,  0,  0] [ 0,  0,  6]  1 */
    17127410, /* 68576 (1626) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
    51152916, /* 68577 (1626) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6] -1 */
     1429448, /* 68578 (1626) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 0,  6,  0]  1 */
    17131882, /* 68579 (1626) [ 0, -1,  0,  0,  0,  1, -1,  0,  0] [ 6,  0,  6]  1 */
    17015296, /* 68580 (1626) [ 0,  0, -1,  0,  1,  0, -1,  0,  0] [ 6,  0,  0]  1 */
    51144052, /* 68581 (1626) [ 0, -1,  0,  0,  0, -1, -1,  0,  0] [ 6,  0,  6] -1 */
    17136202, /* 68582 (1626) [ 0,  1,  0,  0,  0, -1, -1,  0,  0] [ 6,  0,  6]  1 */
     1547338, /* 68583 (1626) [ 0,  1,  0,  0,  0,  1,  1,  0,  0] [ 0,  6,  6]  1 */
      134530, /* 68584 (1626) [ 1,  0,  0,  0,  0,  1,  0,  1,  0] [ 0,  0,  6]  1 */
    51026234, /* 68585 (1626) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 6,  0,  0] -1 */
    18432640, /* 68586 (1626) [ 0,  0, -1,  1,  0,  0,  0, -1,  0] [ 6,  6,  0]  1 */
    52561508, /* 68587 (1626) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    51147244, /* 68588 (1626) [ 0,  0,  1,  1,  0,  0,  0, -1,  0] [ 6,  0,  6] -1 */
    17135026, /* 68589 (1626) [ 0,  0,  1,  1,  0,  0,  0,  1,  0] [ 6,  0,  6]  1 */
    34133632, /* 68590 (1626) [-1,  0,  0,  0,  0,  1,  0,  1,  0] [ 0,  0,  6] -1 */
    52556920, /* 68591 (1626) [-1,  0,  0,  0,  0,  1,  0,  1,  0] [ 6,  6,  6] -1 */
        7636, /* 68592 (1626) [ 0, -1,  0,  0,  0, -1,  1,  0,  0] [ 0,  0,  0]  1 */
    35556364, /* 68593 (1626) [ 0,  0, -1, -1,  0,  0,  0, -1,  0] [ 0,  6,  6] -1 */
    18430924, /* 68594 (1626) [ 0, -1,  0,  0,  0, -1,  1,  0,  0] [ 6,  6,  0]  1 */
     1433608, /* 68595 (1626) [ 1,  0,  0,  0,  0,  1,  0,  1,  0] [ 0,  6,  0]  1 */
    34139524, /* 68596 (1626) [ 0,  0, -1,  0,  1,  0,  1,  0,  0] [ 0,  0,  6] -1 */
    35436810, /* 68597 (1626) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 0,  6,  0] -1 */
    18549282, /* 68598 (1626) [ 0, -1,  0,  1,  0,  0,  0,  0, -1] [ 6,  6,  6]  1 */
    51144124, /* 68599 (1626) [ 0, -1,  0,  0,  0,  1,  1,  0,  0] [ 6,  0,  6] -1 */
    17022484, /* 68600 (1626) [ 1,  0,  0,  0,  0, -1,  0, -1,  0] [ 6,  0,  0]  1 */
     1551594, /* 68601 (1626) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
    18557758, /* 68602 (1626) [ 1,  0,  0,  0,  0, -1,  0, -1,  0] [ 6,  6,  6]  1 */
    51034714, /* 68603 (1626) [ 1,  0,  0,  0,  0, -1,  0,  1,  0] [ 6,  0,  0] -1 */
    35557828, /* 68604 (1626) [ 0,  0,  1, -1,  0,  0,  0,  1,  0] [ 0,  6,  6] -1 */
    51030606, /* 68605 (1626) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 6,  0,  0] -1 */
     1426216, /* 68606 (1626) [ 0,  0, -1,  0, -1,  0,  1,  0,  0] [ 0,  6,  0]  1 */
    51027358, /* 68607 (1626) [ 0,  0, -1,  0, -1,  0, -1,  0,  0] [ 6,  0,  0] -1 */
    35559544, /* 68608 (1626) [ 0,  1,  0,  0,  0,  1, -1,  0,  0] [ 0,  6,  6] -1 */
    52565880, /* 68609 (1626) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 6,  6,  6] -1 */
      134470, /* 68610 (1626) [ 1,  0,  0,  0,  0, -1,  0, -1,  0] [ 0,  0,  6]  1 */
    35432650, /* 68611 (1626) [-1,  0,  0,  0,  0, -1,  0, -1,  0] [ 0,  6,  0] -1 */
     1544626, /* 68612 (1626) [ 0,  0, -1,  1,  0,  0,  0, -1,  0] [ 0,  6,  6]  1 */
    17009416, /* 68613 (1626) [-1,  0,  0,  0,  0,  1,  0, -1,  0] [ 6,  0,  0]  1 */
        3200, /* 68614 (1626) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    18544690, /* 68615 (1626) [-1,  0,  0,  0,  0,  1,  0, -1,  0] [ 6,  6,  6]  1 */
     1542910, /* 68616 (1626) [ 0, -1,  0,  0,  0, -1,  1,  0,  0] [ 0,  6,  6]  1 */
    34021090, /* 68617 (1626) [ 0,  0, -1, -1,  0,  0,  0, -1,  0] [ 0,  0,  0] -1 */
     1428960, /* 68618 (1626) [ 0,  1,  0, -1,  0,  0,  0,  0, -1] [ 0,  6,  0]  1 */
       16484, /* 68619 (1627) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34139362, /* 68620 (1627) [ 0,  0, -1,  0, -1,  0,  1,  0,  0] [ 0,  0,  6] -1 */
    17140694, /* 68621 (1627) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
    17133568, /* 68622 (1627) [ 0,  0, -1,  1,  0,  0,  0,  1,  0] [ 6,  0,  6]  1 */
    35439898, /* 68623 (1627) [ 0,  0,  1,  0, -1,  0,  1,  0,  0] [ 0,  6,  0] -1 */
       16320, /* 68624 (1627) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    17136220, /* 68625 (1627) [ 0,  1,  0,  0,  0, -1,  1,  0,  0] [ 6,  0,  6]  1 */
    51028978, /* 68626 (1627) [ 0,  0,  1,  0,  1,  0, -1,  0,  0] [ 6,  0,  0] -1 */
        3198, /* 68627 (1627) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
     1545598, /* 68628 (1627) [ 0,  0,  1, -1,  0,  0,  0, -1,  0] [ 0,  6,  6]  1 */
    17140532, /* 68629 (1627) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
    52565394, /* 68630 (1627) [ 0,  1,  0, -1,  0,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    51028816, /* 68631 (1627) [ 0,  0,  1,  0, -1,  0, -1,  0,  0] [ 6,  0,  0] -1 */
     1538474, /* 68632 (1627) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
    17136274, /* 68633 (1627) [ 0,  1,  0,  0,  0,  1,  1,  0,  0] [ 6,  0,  6]  1 */
    34138220, /* 68634 (1627) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    34142106, /* 68635 (1627) [ 0,  1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  6] -1 */
        9352, /* 68636 (1627) [ 0,  0, -1,  1,  0,  0,  0, -1,  0] [ 0,  0,  0]  1 */
    52565882, /* 68637 (1627) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    35438584, /* 68638 (1627) [ 0,  0, -1,  0,  1,  0, -1,  0,  0] [ 0,  6,  0] -1 */
    17131828, /* 68639 (1627) [ 0, -1,  0,  0,  0, -1, -1,  0,  0] [ 6,  0,  6]  1 */
    18426648, /* 68640 (1627) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
        8872, /* 68641 (1627) [ 0,  0, -1, -1,  0,  0,  0,  1,  0] [ 0,  0,  0]  1 */
    18432160, /* 68642 (1627) [ 0,  0, -1, -1,  0,  0,  0,  1,  0] [ 6,  6,  0]  1 */
    51028996, /* 68643 (1627) [ 0,  0,  1,  0,  1,  0,  1,  0,  0] [ 6,  0,  0] -1 */
    52570042, /* 68644 (1627) [ 1,  0,  0,  0,  0,  1,  0,  1,  0] [ 6,  6,  6] -1 */
    17135020, /* 68645 (1627) [ 0,  0,  1,  1,  0,  0,  0, -1,  0] [ 6,  0,  6]  1 */
    51028834, /* 68646 (1627) [ 0,  0,  1,  0, -1,  0,  1,  0,  0] [ 6,  0,  0] -1 */
    34137734, /* 68647 (1627) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    52561022, /* 68648 (1627) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    52569988, /* 68649 (1627) [ 1,  0,  0,  0,  0, -1,  0,  1,  0] [ 6,  6,  6] -1 */
    51034768, /* 68650 (1627) [ 1,  0,  0,  0,  0,  1,  0,  1,  0] [ 6,  0,  0] -1 */
    52556866, /* 68651 (1627) [-1,  0,  0,  0,  0, -1,  0,  1,  0] [ 6,  6,  6] -1 */
    34142592, /* 68652 (1627) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  6] -1 */
    51021592, /* 68653 (1627) [-1,  0,  0,  0,  0, -1,  0,  1,  0] [ 6,  0,  0] -1 */
    34140982, /* 68654 (1627) [ 0,  0,  1,  0,  1,  0,  1,  0,  0] [ 0,  0,  6] -1 */
    35432710, /* 68655 (1627) [-1,  0,  0,  0,  0,  1,  0,  1,  0] [ 0,  6,  0] -1 */
    18433612, /* 68656 (1627) [ 0,  0,  1, -1,  0,  0,  0, -1,  0] [ 6,  6,  0]  1 */
    52562632, /* 68657 (1627) [ 0,  0, -1,  0, -1,  0, -1,  0,  0] [ 6,  6,  6] -1 */
    17131900, /* 68658 (1627) [ 0, -1,  0,  0,  0,  1,  1,  0,  0] [ 6,  0,  6]  1 */
    17133562, /* 68659 (1627) [ 0,  0, -1,  1,  0,  0,  0, -1,  0] [ 6,  0,  6]  1 */
    17131846, /* 68660 (1627) [ 0, -1,  0,  0,  0, -1,  1,  0,  0] [ 6,  0,  6]  1 */
       10324, /* 68661 (1627) [ 0,  0,  1, -1,  0,  0,  0, -1,  0] [ 0,  0,  0]  1 */
     1538634, /* 68662 (1627) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
     1544146, /* 68663 (1627) [ 0,  0, -1, -1,  0,  0,  0,  1,  0] [ 0,  6,  6]  1 */
    51034708, /* 68664 (1627) [ 1,  0,  0,  0,  0, -1,  0, -1,  0] [ 6,  0,  0] -1 */
    17134534, /* 68665 (1627) [ 0,  0,  1, -1,  0,  0,  0, -1,  0] [ 6,  0,  6]  1 */
    52564252, /* 68666 (1627) [ 0,  0,  1,  0,  1,  0, -1,  0,  0] [ 6,  6,  6] -1 */
    34140964, /* 68667 (1627) [ 0,  0,  1,  0,  1,  0, -1,  0,  0] [ 0,  0,  6] -1 */
        8866, /* 68668 (1627) [ 0,  0, -1, -1,  0,  0,  0, -1,  0] [ 0,  0,  0]  1 */
    17127572, /* 68669 (1627) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
    18432154, /* 68670 (1627) [ 0,  0, -1, -1,  0,  0,  0, -1,  0] [ 6,  6,  0]  1 */
    34142108, /* 68671 (1627) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    52565396, /* 68672 (1627) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    51030122, /* 68673 (1627) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 6,  0,  0] -1 */
    35438440, /* 68674 (1627) [ 0,  0, -1,  0, -1,  0,  1,  0,  0] [ 0,  6,  0] -1 */
    34146748, /* 68675 (1627) [ 1,  0,  0,  0,  0,  1,  0, -1,  0] [ 0,  0,  6] -1 */
    52570036, /* 68676 (1627) [ 1,  0,  0,  0,  0,  1,  0, -1,  0] [ 6,  6,  6] -1 */
    34140802, /* 68677 (1627) [ 0,  0,  1,  0, -1,  0, -1,  0,  0] [ 0,  0,  6] -1 */
    52564090, /* 68678 (1627) [ 0,  0,  1,  0, -1,  0, -1,  0,  0] [ 6,  6,  6] -1 */
    51034762, /* 68679 (1627) [ 1,  0,  0,  0,  0,  1,  0, -1,  0] [ 6,  0,  0] -1 */
    34133572, /* 68680 (1627) [-1,  0,  0,  0,  0, -1,  0, -1,  0] [ 0,  0,  6] -1 */
    51021640, /* 68681 (1627) [-1,  0,  0,  0,  0,  1,  0, -1,  0] [ 6,  0,  0] -1 */
    18439772, /* 68682 (1627) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    17140530, /* 68683 (1627) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  6]  1 */
    17127408, /* 68684 (1627) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  6]  1 */
    17140692, /* 68685 (1627) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6]  1 */
    18439610, /* 68686 (1627) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    51025748, /* 68687 (1627) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 6,  0,  0] -1 */
    18430960, /* 68688 (1627) [ 0, -1,  0,  0,  0,  1, -1,  0,  0] [ 6,  6,  0]  1 */
    35441184, /* 68689 (1627) [ 0,  1,  0, -1,  0,  0,  0,  0, -1] [ 0,  6,  0] -1 */
    52564270, /* 68690 (1627) [ 0,  0,  1,  0,  1,  0,  1,  0,  0] [ 6,  6,  6] -1 */
    18435280, /* 68691 (1627) [ 0,  1,  0,  0,  0, -1, -1,  0,  0] [ 6,  6,  0]  1 */
    18435352, /* 68692 (1627) [ 0,  1,  0,  0,  0,  1,  1,  0,  0] [ 6,  6,  0]  1 */
    34146700, /* 68693 (1627) [ 1,  0,  0,  0,  0, -1,  0,  1,  0] [ 0,  0,  6] -1 */
     1544140, /* 68694 (1627) [ 0,  0, -1, -1,  0,  0,  0, -1,  0] [ 0,  6,  6]  1 */
    34140820, /* 68695 (1627) [ 0,  0,  1,  0, -1,  0,  1,  0,  0] [ 0,  0,  6] -1 */
    52564108, /* 68696 (1627) [ 0,  0,  1,  0, -1,  0,  1,  0,  0] [ 6,  6,  6] -1 */
       10816, /* 68697 (1627) [ 0,  0,  1,  1,  0,  0,  0,  1,  0] [ 0,  0,  0]  1 */
    18434104, /* 68698 (1627) [ 0,  0,  1,  1,  0,  0,  0,  1,  0] [ 6,  6,  0]  1 */
    35437298, /* 68699 (1627) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 0,  6,  0] -1 */
    34139344, /* 68700 (1627) [ 0,  0, -1,  0, -1,  0, -1,  0,  0] [ 0,  0,  6] -1 */
       11992, /* 68701 (1627) [ 0,  1,  0,  0,  0, -1, -1,  0,  0] [ 0,  0,  0]  1 */
    35441672, /* 68702 (1627) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 0,  6,  0] -1 */
       12064, /* 68703 (1627) [ 0,  1,  0,  0,  0,  1,  1,  0,  0] [ 0,  0,  0]  1 */
    51027520, /* 68704 (1627) [ 0,  0, -1,  0,  1,  0, -1,  0,  0] [ 6,  0,  0] -1 */
    51025746, /* 68705 (1627) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 6,  0,  0] -1 */
     1551758, /* 68706 (1627) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
    52562794, /* 68707 (1627) [ 0,  0, -1,  0,  1,  0, -1,  0,  0] [ 6,  6,  6] -1 */
    34146754, /* 68708 (1627) [ 1,  0,  0,  0,  0,  1,  0,  1,  0] [ 0,  0,  6] -1 */
    52561020, /* 68709 (1627) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 6,  6,  6] -1 */
     1545604, /* 68710 (1627) [ 0,  0,  1, -1,  0,  0,  0,  1,  0] [ 0,  6,  6]  1 */
    52561506, /* 68711 (1627) [ 0, -1,  0,  1,  0,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    17127570, /* 68712 (1627) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6]  1 */
    35445832, /* 68713 (1627) [ 1,  0,  0,  0,  0,  1,  0,  1,  0] [ 0,  6,  0] -1 */
     1547320, /* 68714 (1627) [ 0,  1,  0,  0,  0,  1, -1,  0,  0] [ 0,  6,  6]  1 */
    51026232, /* 68715 (1627) [ 0, -1,  0,  1,  0,  0,  0,  0, -1] [ 6,  0,  0] -1 */
     1542946, /* 68716 (1627) [ 0, -1,  0,  0,  0,  1, -1,  0,  0] [ 0,  6,  6]  1 */
    17133082, /* 68717 (1627) [ 0,  0, -1, -1,  0,  0,  0,  1,  0] [ 6,  0,  6]  1 */
    35445778, /* 68718 (1627) [ 1,  0,  0,  0,  0, -1,  0,  1,  0] [ 0,  6,  0] -1 */
     1547266, /* 68719 (1627) [ 0,  1,  0,  0,  0, -1, -1,  0,  0] [ 0,  6,  6]  1 */
    35432656, /* 68720 (1627) [-1,  0,  0,  0,  0, -1,  0,  1,  0] [ 0,  6,  0] -1 */
    18434098, /* 68721 (1627) [ 0,  0,  1,  1,  0,  0,  0, -1,  0] [ 6,  6,  0]  1 */
    35441670, /* 68722 (1627) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 0,  6,  0] -1 */
    52569982, /* 68723 (1627) [ 1,  0,  0,  0,  0, -1,  0, -1,  0] [ 6,  6,  6] -1 */
    51021646, /* 68724 (1627) [-1,  0,  0,  0,  0,  1,  0,  1,  0] [ 6,  0,  0] -1 */
    35438422, /* 68725 (1627) [ 0,  0, -1,  0, -1,  0, -1,  0,  0] [ 0,  6,  0] -1 */
     1546090, /* 68726 (1627) [ 0,  0,  1,  1,  0,  0,  0,  1,  0] [ 0,  6,  6]  1 */
    52556860, /* 68727 (1627) [-1,  0,  0,  0,  0, -1,  0, -1,  0] [ 6,  6,  6] -1 */
    51027538, /* 68728 (1627) [ 0,  0, -1,  0,  1,  0,  1,  0,  0] [ 6,  0,  0] -1 */
    51021586, /* 68729 (1627) [-1,  0,  0,  0,  0, -1,  0, -1,  0] [ 6,  0,  0] -1 */
    52562812, /* 68730 (1627) [ 0,  0, -1,  0,  1,  0,  1,  0,  0] [ 6,  6,  6] -1 */
    34146694, /* 68731 (1627) [ 1,  0,  0,  0,  0, -1,  0, -1,  0] [ 0,  0,  6] -1 */
    34133626, /* 68732 (1627) [-1,  0,  0,  0,  0,  1,  0, -1,  0] [ 0,  0,  6] -1 */
    52556914, /* 68733 (1627) [-1,  0,  0,  0,  0,  1,  0, -1,  0] [ 6,  6,  6] -1 */
    18435298, /* 68734 (1627) [ 0,  1,  0,  0,  0, -1,  1,  0,  0] [ 6,  6,  0]  1 */
    18426650, /* 68735 (1627) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
        7672, /* 68736 (1627) [ 0, -1,  0,  0,  0,  1, -1,  0,  0] [ 0,  0,  0]  1 */
    35438602, /* 68737 (1627) [ 0,  0, -1,  0,  1,  0,  1,  0,  0] [ 0,  6,  0] -1 */
       10330, /* 68738 (1627) [ 0,  0,  1, -1,  0,  0,  0,  1,  0] [ 0,  0,  0]  1 */
    18433618, /* 68739 (1627) [ 0,  0,  1, -1,  0,  0,  0,  1,  0] [ 6,  6,  0]  1 */
    35440042, /* 68740 (1627) [ 0,  0,  1,  0,  1,  0, -1,  0,  0] [ 0,  6,  0] -1 */
        3360, /* 68741 (1627) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
     1546084, /* 68742 (1627) [ 0,  0,  1,  1,  0,  0,  0, -1,  0] [ 0,  6,  6]  1 */
    35441186, /* 68743 (1627) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 0,  6,  0] -1 */
       12010, /* 68744 (1627) [ 0,  1,  0,  0,  0, -1,  1,  0,  0] [ 0,  0,  0]  1 */
       12046, /* 68745 (1627) [ 0,  1,  0,  0,  0,  1, -1,  0,  0] [ 0,  0,  0]  1 */
    18435334, /* 68746 (1627) [ 0,  1,  0,  0,  0,  1, -1,  0,  0] [ 6,  6,  0]  1 */
    18426488, /* 68747 (1627) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    35445826, /* 68748 (1627) [ 1,  0,  0,  0,  0,  1,  0, -1,  0] [ 0,  6,  0] -1 */
    17133076, /* 68749 (1627) [ 0,  0, -1, -1,  0,  0,  0, -1,  0] [ 6,  0,  6]  1 */
        3362, /* 68750 (1627) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    35432704, /* 68751 (1627) [-1,  0,  0,  0,  0,  1,  0, -1,  0] [ 0,  6,  0] -1 */
    34133578, /* 68752 (1627) [-1,  0,  0,  0,  0, -1,  0,  1,  0] [ 0,  0,  6] -1 */
    18439770, /* 68753 (1627) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
        7618, /* 68754 (1627) [ 0, -1,  0,  0,  0, -1, -1,  0,  0] [ 0,  0,  0]  1 */
    18430906, /* 68755 (1627) [ 0, -1,  0,  0,  0, -1, -1,  0,  0] [ 6,  6,  0]  1 */
    51027376, /* 68756 (1627) [ 0,  0, -1,  0, -1,  0,  1,  0,  0] [ 6,  0,  0] -1 */
    35436812, /* 68757 (1627) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 0,  6,  0] -1 */
     1544632, /* 68758 (1627) [ 0,  0, -1,  1,  0,  0,  0,  1,  0] [ 0,  6,  6]  1 */
    34139506, /* 68759 (1627) [ 0,  0, -1,  0,  1,  0, -1,  0,  0] [ 0,  0,  6] -1 */
    52562650, /* 68760 (1627) [ 0,  0, -1,  0, -1,  0,  1,  0,  0] [ 6,  6,  6] -1 */
    34137732, /* 68761 (1627) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  6] -1 */
     1547284, /* 68762 (1627) [ 0,  1,  0,  0,  0, -1,  1,  0,  0] [ 0,  6,  6]  1 */
    18439608, /* 68763 (1627) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
    51030120, /* 68764 (1627) [ 0,  1,  0, -1,  0,  0,  0,  0, -1] [ 6,  0,  0] -1 */
    35440060, /* 68765 (1627) [ 0,  0,  1,  0,  1,  0,  1,  0,  0] [ 0,  6,  0] -1 */
    18426486, /* 68766 (1627) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
    17134540, /* 68767 (1627) [ 0,  0,  1, -1,  0,  0,  0,  1,  0] [ 6,  0,  6]  1 */
     1551596, /* 68768 (1627) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
     1538636, /* 68769 (1627) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
    17136256, /* 68770 (1627) [ 0,  1,  0,  0,  0,  1, -1,  0,  0] [ 6,  0,  6]  1 */
    17127410, /* 68771 (1627) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
    17131882, /* 68772 (1627) [ 0, -1,  0,  0,  0,  1, -1,  0,  0] [ 6,  0,  6]  1 */
    17136202, /* 68773 (1627) [ 0,  1,  0,  0,  0, -1, -1,  0,  0] [ 6,  0,  6]  1 */
     1547338, /* 68774 (1627) [ 0,  1,  0,  0,  0,  1,  1,  0,  0] [ 0,  6,  6]  1 */
        7690, /* 68775 (1627) [ 0, -1,  0,  0,  0,  1,  1,  0,  0] [ 0,  0,  0]  1 */
    51026234, /* 68776 (1627) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 6,  0,  0] -1 */
       10810, /* 68777 (1627) [ 0,  0,  1,  1,  0,  0,  0, -1,  0] [ 0,  0,  0]  1 */
    18432640, /* 68778 (1627) [ 0,  0, -1,  1,  0,  0,  0, -1,  0] [ 6,  6,  0]  1 */
    18430978, /* 68779 (1627) [ 0, -1,  0,  0,  0,  1,  1,  0,  0] [ 6,  6,  0]  1 */
    52561508, /* 68780 (1627) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    51030608, /* 68781 (1627) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 6,  0,  0] -1 */
    17135026, /* 68782 (1627) [ 0,  0,  1,  1,  0,  0,  0,  1,  0] [ 6,  0,  6]  1 */
    34133632, /* 68783 (1627) [-1,  0,  0,  0,  0,  1,  0,  1,  0] [ 0,  0,  6] -1 */
    52556920, /* 68784 (1627) [-1,  0,  0,  0,  0,  1,  0,  1,  0] [ 6,  6,  6] -1 */
        7636, /* 68785 (1627) [ 0, -1,  0,  0,  0, -1,  1,  0,  0] [ 0,  0,  0]  1 */
    18430924, /* 68786 (1627) [ 0, -1,  0,  0,  0, -1,  1,  0,  0] [ 6,  6,  0]  1 */
    34138218, /* 68787 (1627) [ 0, -1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  6] -1 */
    34139524, /* 68788 (1627) [ 0,  0, -1,  0,  1,  0,  1,  0,  0] [ 0,  0,  6] -1 */
    35436810, /* 68789 (1627) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 0,  6,  0] -1 */
     1551756, /* 68790 (1627) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
     1542892, /* 68791 (1627) [ 0, -1,  0,  0,  0, -1, -1,  0,  0] [ 0,  6,  6]  1 */
    35437296, /* 68792 (1627) [ 0, -1,  0,  1,  0,  0,  0,  0, -1] [ 0,  6,  0] -1 */
     1551594, /* 68793 (1627) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
    34142594, /* 68794 (1627) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    51034714, /* 68795 (1627) [ 1,  0,  0,  0,  0, -1,  0,  1,  0] [ 6,  0,  0] -1 */
     1538472, /* 68796 (1627) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
    18432646, /* 68797 (1627) [ 0,  0, -1,  1,  0,  0,  0,  1,  0] [ 6,  6,  0]  1 */
    35439880, /* 68798 (1627) [ 0,  0,  1,  0, -1,  0, -1,  0,  0] [ 0,  6,  0] -1 */
    51030606, /* 68799 (1627) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 6,  0,  0] -1 */
    35445772, /* 68800 (1627) [ 1,  0,  0,  0,  0, -1,  0, -1,  0] [ 0,  6,  0] -1 */
    51027358, /* 68801 (1627) [ 0,  0, -1,  0, -1,  0, -1,  0,  0] [ 6,  0,  0] -1 */
    52565880, /* 68802 (1627) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 6,  6,  6] -1 */
     1542964, /* 68803 (1627) [ 0, -1,  0,  0,  0,  1,  1,  0,  0] [ 0,  6,  6]  1 */
    35432650, /* 68804 (1627) [-1,  0,  0,  0,  0, -1,  0, -1,  0] [ 0,  6,  0] -1 */
       16322, /* 68805 (1627) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
     1544626, /* 68806 (1627) [ 0,  0, -1,  1,  0,  0,  0, -1,  0] [ 0,  6,  6]  1 */
        3200, /* 68807 (1627) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
        9358, /* 68808 (1627) [ 0,  0, -1,  1,  0,  0,  0,  1,  0] [ 0,  0,  0]  1 */
     1542910, /* 68809 (1627) [ 0, -1,  0,  0,  0, -1,  1,  0,  0] [ 0,  6,  6]  1 */
       16482, /* 68810 (1627) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
       16484, /* 68811 (1628) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
     1428962, /* 68812 (1628) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 0,  6,  0]  1 */
    34139362, /* 68813 (1628) [ 0,  0, -1,  0, -1,  0,  1,  0,  0] [ 0,  0,  6] -1 */
    17140694, /* 68814 (1628) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
     1433602, /* 68815 (1628) [ 1,  0,  0,  0,  0,  1,  0, -1,  0] [ 0,  6,  0]  1 */
       16320, /* 68816 (1628) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
     1545598, /* 68817 (1628) [ 0,  0,  1, -1,  0,  0,  0, -1,  0] [ 0,  6,  6]  1 */
    52565394, /* 68818 (1628) [ 0,  1,  0, -1,  0,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    51139632, /* 68819 (1628) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  6] -1 */
    51028816, /* 68820 (1628) [ 0,  0,  1,  0, -1,  0, -1,  0,  0] [ 6,  0,  0] -1 */
    52451834, /* 68821 (1628) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
     1538474, /* 68822 (1628) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
      125508, /* 68823 (1628) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  6]  1 */
    17136274, /* 68824 (1628) [ 0,  1,  0,  0,  0,  1,  1,  0,  0] [ 6,  0,  6]  1 */
    18548796, /* 68825 (1628) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 6,  6,  6]  1 */
    52445842, /* 68826 (1628) [ 0,  0,  1, -1,  0,  0,  0,  1,  0] [ 6,  6,  0] -1 */
    34142106, /* 68827 (1628) [ 0,  1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  6] -1 */
    34024234, /* 68828 (1628) [ 0,  1,  0,  0,  0, -1,  1,  0,  0] [ 0,  0,  0] -1 */
        9352, /* 68829 (1628) [ 0,  0, -1,  1,  0,  0,  0, -1,  0] [ 0,  0,  0]  1 */
    52565882, /* 68830 (1628) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    35438584, /* 68831 (1628) [ 0,  0, -1,  0,  1,  0, -1,  0,  0] [ 0,  6,  0] -1 */
     1433554, /* 68832 (1628) [ 1,  0,  0,  0,  0, -1,  0,  1,  0] [ 0,  6,  0]  1 */
    18426648, /* 68833 (1628) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
        8872, /* 68834 (1628) [ 0,  0, -1, -1,  0,  0,  0,  1,  0] [ 0,  0,  0]  1 */
    18432160, /* 68835 (1628) [ 0,  0, -1, -1,  0,  0,  0,  1,  0] [ 6,  6,  0]  1 */
    51028996, /* 68836 (1628) [ 0,  0,  1,  0,  1,  0,  1,  0,  0] [ 6,  0,  0] -1 */
    17014010, /* 68837 (1628) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 6,  0,  0]  1 */
    17009422, /* 68838 (1628) [-1,  0,  0,  0,  0,  1,  0,  1,  0] [ 6,  0,  0]  1 */
     1426198, /* 68839 (1628) [ 0,  0, -1,  0, -1,  0, -1,  0,  0] [ 0,  6,  0]  1 */
    52570042, /* 68840 (1628) [ 1,  0,  0,  0,  0,  1,  0,  1,  0] [ 6,  6,  6] -1 */
    18544696, /* 68841 (1628) [-1,  0,  0,  0,  0,  1,  0,  1,  0] [ 6,  6,  6]  1 */
    34137734, /* 68842 (1628) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    52561022, /* 68843 (1628) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    51034768, /* 68844 (1628) [ 1,  0,  0,  0,  0,  1,  0,  1,  0] [ 6,  0,  0] -1 */
    17009362, /* 68845 (1628) [-1,  0,  0,  0,  0, -1,  0, -1,  0] [ 6,  0,  0]  1 */
      127300, /* 68846 (1628) [ 0,  0, -1,  0,  1,  0,  1,  0,  0] [ 0,  0,  6]  1 */
    18550588, /* 68847 (1628) [ 0,  0, -1,  0,  1,  0,  1,  0,  0] [ 6,  6,  6]  1 */
    52556866, /* 68848 (1628) [-1,  0,  0,  0,  0, -1,  0,  1,  0] [ 6,  6,  6] -1 */
    51146764, /* 68849 (1628) [ 0,  0,  1, -1,  0,  0,  0,  1,  0] [ 6,  0,  6] -1 */
    35563820, /* 68850 (1628) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
    51021592, /* 68851 (1628) [-1,  0,  0,  0,  0, -1,  0,  1,  0] [ 6,  0,  0] -1 */
    34140982, /* 68852 (1628) [ 0,  0,  1,  0,  1,  0,  1,  0,  0] [ 0,  0,  6] -1 */
    18433612, /* 68853 (1628) [ 0,  0,  1, -1,  0,  0,  0, -1,  0] [ 6,  6,  0]  1 */
    17133562, /* 68854 (1628) [ 0,  0, -1,  1,  0,  0,  0, -1,  0] [ 6,  0,  6]  1 */
    52443202, /* 68855 (1628) [ 0, -1,  0,  0,  0,  1,  1,  0,  0] [ 6,  6,  0] -1 */
    34023034, /* 68856 (1628) [ 0,  0,  1,  1,  0,  0,  0, -1,  0] [ 0,  0,  0] -1 */
    52446322, /* 68857 (1628) [ 0,  0,  1,  1,  0,  0,  0, -1,  0] [ 6,  6,  0] -1 */
    17131846, /* 68858 (1628) [ 0, -1,  0,  0,  0, -1,  1,  0,  0] [ 6,  0,  6]  1 */
    17018382, /* 68859 (1628) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 6,  0,  0]  1 */
       10324, /* 68860 (1628) [ 0,  0,  1, -1,  0,  0,  0, -1,  0] [ 0,  0,  0]  1 */
     1538634, /* 68861 (1628) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
     1426378, /* 68862 (1628) [ 0,  0, -1,  0,  1,  0,  1,  0,  0] [ 0,  6,  0]  1 */
     1544146, /* 68863 (1628) [ 0,  0, -1, -1,  0,  0,  0,  1,  0] [ 0,  6,  6]  1 */
     1420426, /* 68864 (1628) [-1,  0,  0,  0,  0, -1,  0, -1,  0] [ 0,  6,  0]  1 */
    51034708, /* 68865 (1628) [ 1,  0,  0,  0,  0, -1,  0, -1,  0] [ 6,  0,  0] -1 */
    17134534, /* 68866 (1628) [ 0,  0,  1, -1,  0,  0,  0, -1,  0] [ 6,  0,  6]  1 */
    52447522, /* 68867 (1628) [ 0,  1,  0,  0,  0, -1,  1,  0,  0] [ 6,  6,  0] -1 */
    35438440, /* 68868 (1628) [ 0,  0, -1,  0, -1,  0,  1,  0,  0] [ 0,  6,  0] -1 */
    52438874, /* 68869 (1628) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
    34140802, /* 68870 (1628) [ 0,  0,  1,  0, -1,  0, -1,  0,  0] [ 0,  0,  6] -1 */
    52564090, /* 68871 (1628) [ 0,  0,  1,  0, -1,  0, -1,  0,  0] [ 6,  6,  6] -1 */
    34022554, /* 68872 (1628) [ 0,  0,  1, -1,  0,  0,  0,  1,  0] [ 0,  0,  0] -1 */
     1427674, /* 68873 (1628) [ 0,  0,  1,  0, -1,  0,  1,  0,  0] [ 0,  6,  0]  1 */
    35555188, /* 68874 (1628) [ 0, -1,  0,  0,  0,  1,  1,  0,  0] [ 0,  6,  6] -1 */
    35558308, /* 68875 (1628) [ 0,  0,  1,  1,  0,  0,  0, -1,  0] [ 0,  6,  6] -1 */
    34024270, /* 68876 (1628) [ 0,  1,  0,  0,  0,  1, -1,  0,  0] [ 0,  0,  0] -1 */
    52447558, /* 68877 (1628) [ 0,  1,  0,  0,  0,  1, -1,  0,  0] [ 6,  6,  0] -1 */
    17016754, /* 68878 (1628) [ 0,  0,  1,  0,  1,  0, -1,  0,  0] [ 6,  0,  0]  1 */
    18439772, /* 68879 (1628) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    51021640, /* 68880 (1628) [-1,  0,  0,  0,  0,  1,  0, -1,  0] [ 6,  0,  0] -1 */
    34021582, /* 68881 (1628) [ 0,  0, -1,  1,  0,  0,  0,  1,  0] [ 0,  0,  0] -1 */
    17140530, /* 68882 (1628) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  6]  1 */
    51145300, /* 68883 (1628) [ 0,  0, -1, -1,  0,  0,  0, -1,  0] [ 6,  0,  6] -1 */
    34015586, /* 68884 (1628) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    51025748, /* 68885 (1628) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 6,  0,  0] -1 */
    34028706, /* 68886 (1628) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    35441184, /* 68887 (1628) [ 0,  1,  0, -1,  0,  0,  0,  0, -1] [ 0,  6,  0] -1 */
    52451994, /* 68888 (1628) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
    18430960, /* 68889 (1628) [ 0, -1,  0,  0,  0,  1, -1,  0,  0] [ 6,  6,  0]  1 */
    34019842, /* 68890 (1628) [ 0, -1,  0,  0,  0, -1, -1,  0,  0] [ 0,  0,  0] -1 */
    52443130, /* 68891 (1628) [ 0, -1,  0,  0,  0, -1, -1,  0,  0] [ 6,  6,  0] -1 */
      125996, /* 68892 (1628) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 0,  0,  6]  1 */
    18549284, /* 68893 (1628) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    35556856, /* 68894 (1628) [ 0,  0, -1,  1,  0,  0,  0,  1,  0] [ 0,  6,  6] -1 */
    18435280, /* 68895 (1628) [ 0,  1,  0,  0,  0, -1, -1,  0,  0] [ 6,  6,  0]  1 */
    52564270, /* 68896 (1628) [ 0,  0,  1,  0,  1,  0,  1,  0,  0] [ 6,  6,  6] -1 */
      121408, /* 68897 (1628) [-1,  0,  0,  0,  0,  1,  0,  1,  0] [ 0,  0,  6]  1 */
    18435352, /* 68898 (1628) [ 0,  1,  0,  0,  0,  1,  1,  0,  0] [ 6,  6,  0]  1 */
    35559508, /* 68899 (1628) [ 0,  1,  0,  0,  0, -1,  1,  0,  0] [ 0,  6,  6] -1 */
     1424586, /* 68900 (1628) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 0,  6,  0]  1 */
       10816, /* 68901 (1628) [ 0,  0,  1,  1,  0,  0,  0,  1,  0] [ 0,  0,  0]  1 */
    34015422, /* 68902 (1628) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    18434104, /* 68903 (1628) [ 0,  0,  1,  1,  0,  0,  0,  1,  0] [ 6,  6,  0]  1 */
    52438710, /* 68904 (1628) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
    35550860, /* 68905 (1628) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
    51152756, /* 68906 (1628) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
    51148480, /* 68907 (1628) [ 0,  1,  0,  0,  0,  1, -1,  0,  0] [ 6,  0,  6] -1 */
       11992, /* 68908 (1628) [ 0,  1,  0,  0,  0, -1, -1,  0,  0] [ 0,  0,  0]  1 */
    35441672, /* 68909 (1628) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 0,  6,  0] -1 */
       12064, /* 68910 (1628) [ 0,  1,  0,  0,  0,  1,  1,  0,  0] [ 0,  0,  0]  1 */
    51027520, /* 68911 (1628) [ 0,  0, -1,  0,  1,  0, -1,  0,  0] [ 6,  0,  0] -1 */
     1551758, /* 68912 (1628) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
    34019914, /* 68913 (1628) [ 0, -1,  0,  0,  0,  1,  1,  0,  0] [ 0,  0,  0] -1 */
    52562794, /* 68914 (1628) [ 0,  0, -1,  0,  1,  0, -1,  0,  0] [ 6,  6,  6] -1 */
    34146754, /* 68915 (1628) [ 1,  0,  0,  0,  0,  1,  0,  1,  0] [ 0,  0,  6] -1 */
    17022490, /* 68916 (1628) [ 1,  0,  0,  0,  0, -1,  0,  1,  0] [ 6,  0,  0]  1 */
    17016610, /* 68917 (1628) [ 0,  0,  1,  0, -1,  0,  1,  0,  0] [ 6,  0,  0]  1 */
    52561506, /* 68918 (1628) [ 0, -1,  0,  1,  0,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    17015134, /* 68919 (1628) [ 0,  0, -1,  0, -1,  0, -1,  0,  0] [ 6,  0,  0]  1 */
      130368, /* 68920 (1628) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  6]  1 */
    18553656, /* 68921 (1628) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 6,  6,  6]  1 */
    17127570, /* 68922 (1628) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6]  1 */
     1542946, /* 68923 (1628) [ 0, -1,  0,  0,  0,  1, -1,  0,  0] [ 0,  6,  6]  1 */
    35563980, /* 68924 (1628) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6] -1 */
    17133082, /* 68925 (1628) [ 0,  0, -1, -1,  0,  0,  0,  1,  0] [ 6,  0,  6]  1 */
    51026232, /* 68926 (1628) [ 0, -1,  0,  1,  0,  0,  0,  0, -1] [ 6,  0,  0] -1 */
    35445832, /* 68927 (1628) [ 1,  0,  0,  0,  0,  1,  0,  1,  0] [ 0,  6,  0] -1 */
    35555116, /* 68928 (1628) [ 0, -1,  0,  0,  0, -1, -1,  0,  0] [ 0,  6,  6] -1 */
     1547266, /* 68929 (1628) [ 0,  1,  0,  0,  0, -1, -1,  0,  0] [ 0,  6,  6]  1 */
    35432656, /* 68930 (1628) [-1,  0,  0,  0,  0, -1,  0,  1,  0] [ 0,  6,  0] -1 */
    52569982, /* 68931 (1628) [ 1,  0,  0,  0,  0, -1,  0, -1,  0] [ 6,  6,  6] -1 */
     1546090, /* 68932 (1628) [ 0,  0,  1,  1,  0,  0,  0,  1,  0] [ 0,  6,  6]  1 */
    35550696, /* 68933 (1628) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  6] -1 */
    52444870, /* 68934 (1628) [ 0,  0, -1,  1,  0,  0,  0,  1,  0] [ 6,  6,  0] -1 */
    34146694, /* 68935 (1628) [ 1,  0,  0,  0,  0, -1,  0, -1,  0] [ 0,  0,  6] -1 */
    34028546, /* 68936 (1628) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    34133626, /* 68937 (1628) [-1,  0,  0,  0,  0,  1,  0, -1,  0] [ 0,  0,  6] -1 */
      128740, /* 68938 (1628) [ 0,  0,  1,  0,  1,  0, -1,  0,  0] [ 0,  0,  6]  1 */
    18552028, /* 68939 (1628) [ 0,  0,  1,  0,  1,  0, -1,  0,  0] [ 6,  6,  6]  1 */
    52556914, /* 68940 (1628) [-1,  0,  0,  0,  0,  1,  0, -1,  0] [ 6,  6,  6] -1 */
      129884, /* 68941 (1628) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  6]  1 */
    18553172, /* 68942 (1628) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    17017898, /* 68943 (1628) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 6,  0,  0]  1 */
    18557812, /* 68944 (1628) [ 1,  0,  0,  0,  0,  1,  0, -1,  0] [ 6,  6,  6]  1 */
        7672, /* 68945 (1628) [ 0, -1,  0,  0,  0,  1, -1,  0,  0] [ 0,  0,  0]  1 */
        3360, /* 68946 (1628) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    51145792, /* 68947 (1628) [ 0,  0, -1,  1,  0,  0,  0,  1,  0] [ 6,  0,  6] -1 */
    18426488, /* 68948 (1628) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    51148444, /* 68949 (1628) [ 0,  1,  0,  0,  0, -1,  1,  0,  0] [ 6,  0,  6] -1 */
    35432704, /* 68950 (1628) [-1,  0,  0,  0,  0,  1,  0, -1,  0] [ 0,  6,  0] -1 */
    51139796, /* 68951 (1628) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
    52444378, /* 68952 (1628) [ 0,  0, -1, -1,  0,  0,  0, -1,  0] [ 6,  6,  0] -1 */
    34133578, /* 68953 (1628) [-1,  0,  0,  0,  0, -1,  0,  1,  0] [ 0,  0,  6] -1 */
    51027376, /* 68954 (1628) [ 0,  0, -1,  0, -1,  0,  1,  0,  0] [ 6,  0,  0] -1 */
    35436812, /* 68955 (1628) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 0,  6,  0] -1 */
    34139506, /* 68956 (1628) [ 0,  0, -1,  0,  1,  0, -1,  0,  0] [ 0,  0,  6] -1 */
    52562650, /* 68957 (1628) [ 0,  0, -1,  0, -1,  0,  1,  0,  0] [ 6,  6,  6] -1 */
      134476, /* 68958 (1628) [ 1,  0,  0,  0,  0, -1,  0,  1,  0] [ 0,  0,  6]  1 */
    18557764, /* 68959 (1628) [ 1,  0,  0,  0,  0, -1,  0,  1,  0] [ 6,  6,  6]  1 */
    18439608, /* 68960 (1628) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
      128596, /* 68961 (1628) [ 0,  0,  1,  0, -1,  0,  1,  0,  0] [ 0,  0,  6]  1 */
    18551884, /* 68962 (1628) [ 0,  0,  1,  0, -1,  0,  1,  0,  0] [ 6,  6,  6]  1 */
    51030120, /* 68963 (1628) [ 0,  1,  0, -1,  0,  0,  0,  0, -1] [ 6,  0,  0] -1 */
    35440060, /* 68964 (1628) [ 0,  0,  1,  0,  1,  0,  1,  0,  0] [ 0,  6,  0] -1 */
     1425074, /* 68965 (1628) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 0,  6,  0]  1 */
     1420486, /* 68966 (1628) [-1,  0,  0,  0,  0,  1,  0,  1,  0] [ 0,  6,  0]  1 */
    17127410, /* 68967 (1628) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
    18550408, /* 68968 (1628) [ 0,  0, -1,  0, -1,  0, -1,  0,  0] [ 6,  6,  6]  1 */
    51152916, /* 68969 (1628) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6] -1 */
      127120, /* 68970 (1628) [ 0,  0, -1,  0, -1,  0, -1,  0,  0] [ 0,  0,  6]  1 */
    17131882, /* 68971 (1628) [ 0, -1,  0,  0,  0,  1, -1,  0,  0] [ 6,  0,  6]  1 */
    51144052, /* 68972 (1628) [ 0, -1,  0,  0,  0, -1, -1,  0,  0] [ 6,  0,  6] -1 */
    17013522, /* 68973 (1628) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 6,  0,  0]  1 */
    17136202, /* 68974 (1628) [ 0,  1,  0,  0,  0, -1, -1,  0,  0] [ 6,  0,  6]  1 */
     1547338, /* 68975 (1628) [ 0,  1,  0,  0,  0,  1,  1,  0,  0] [ 0,  6,  6]  1 */
    18432640, /* 68976 (1628) [ 0,  0, -1,  1,  0,  0,  0, -1,  0] [ 6,  6,  0]  1 */
    51030608, /* 68977 (1628) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 6,  0,  0] -1 */
    51147244, /* 68978 (1628) [ 0,  0,  1,  1,  0,  0,  0, -1,  0] [ 6,  0,  6] -1 */
    17135026, /* 68979 (1628) [ 0,  0,  1,  1,  0,  0,  0,  1,  0] [ 6,  0,  6]  1 */
        7636, /* 68980 (1628) [ 0, -1,  0,  0,  0, -1,  1,  0,  0] [ 0,  0,  0]  1 */
    18430924, /* 68981 (1628) [ 0, -1,  0,  0,  0, -1,  1,  0,  0] [ 6,  6,  0]  1 */
    35556364, /* 68982 (1628) [ 0,  0, -1, -1,  0,  0,  0, -1,  0] [ 0,  6,  6] -1 */
    34138218, /* 68983 (1628) [ 0, -1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  6] -1 */
    35437296, /* 68984 (1628) [ 0, -1,  0,  1,  0,  0,  0,  0, -1] [ 0,  6,  0] -1 */
    51144124, /* 68985 (1628) [ 0, -1,  0,  0,  0,  1,  1,  0,  0] [ 6,  0,  6] -1 */
     1551594, /* 68986 (1628) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
     1429446, /* 68987 (1628) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 0,  6,  0]  1 */
    34142594, /* 68988 (1628) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    18544636, /* 68989 (1628) [-1,  0,  0,  0,  0, -1,  0, -1,  0] [ 6,  6,  6]  1 */
    17015314, /* 68990 (1628) [ 0,  0, -1,  0,  1,  0,  1,  0,  0] [ 6,  0,  0]  1 */
    35439880, /* 68991 (1628) [ 0,  0,  1,  0, -1,  0, -1,  0,  0] [ 0,  6,  0] -1 */
    35557828, /* 68992 (1628) [ 0,  0,  1, -1,  0,  0,  0,  1,  0] [ 0,  6,  6] -1 */
      134524, /* 68993 (1628) [ 1,  0,  0,  0,  0,  1,  0, -1,  0] [ 0,  0,  6]  1 */
    35445772, /* 68994 (1628) [ 1,  0,  0,  0,  0, -1,  0, -1,  0] [ 0,  6,  0] -1 */
    35559544, /* 68995 (1628) [ 0,  1,  0,  0,  0,  1, -1,  0,  0] [ 0,  6,  6] -1 */
    17022538, /* 68996 (1628) [ 1,  0,  0,  0,  0,  1,  0, -1,  0] [ 6,  0,  0]  1 */
     1544626, /* 68997 (1628) [ 0,  0, -1,  1,  0,  0,  0, -1,  0] [ 0,  6,  6]  1 */
      121348, /* 68998 (1628) [-1,  0,  0,  0,  0, -1,  0, -1,  0] [ 0,  0,  6]  1 */
        3200, /* 68999 (1628) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
     1542910, /* 69000 (1628) [ 0, -1,  0,  0,  0, -1,  1,  0,  0] [ 0,  6,  6]  1 */
    34021090, /* 69001 (1628) [ 0,  0, -1, -1,  0,  0,  0, -1,  0] [ 0,  0,  0] -1 */
     1427818, /* 69002 (1628) [ 0,  0,  1,  0,  1,  0, -1,  0,  0] [ 0,  6,  0]  1 */
       16484, /* 69003 (1629) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    17140694, /* 69004 (1629) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
    17136220, /* 69005 (1629) [ 0,  1,  0,  0,  0, -1,  1,  0,  0] [ 6,  0,  6]  1 */
        3198, /* 69006 (1629) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
     1545598, /* 69007 (1629) [ 0,  0,  1, -1,  0,  0,  0, -1,  0] [ 0,  6,  6]  1 */
    17136274, /* 69008 (1629) [ 0,  1,  0,  0,  0,  1,  1,  0,  0] [ 6,  0,  6]  1 */
    52565620, /* 69009 (1629) [ 0,  1,  0,  0,  0, -1,  1,  0,  0] [ 6,  6,  6] -1 */
    34142332, /* 69010 (1629) [ 0,  1,  0,  0,  0, -1,  1,  0,  0] [ 0,  0,  6] -1 */
    35556538, /* 69011 (1629) [ 0,  0, -1,  0, -1,  0,  1,  0,  0] [ 0,  6,  6] -1 */
    34020122, /* 69012 (1629) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    34024496, /* 69013 (1629) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    52447784, /* 69014 (1629) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 6,  6,  0] -1 */
    34142368, /* 69015 (1629) [ 0,  1,  0,  0,  0,  1, -1,  0,  0] [ 0,  0,  6] -1 */
        8872, /* 69016 (1629) [ 0,  0, -1, -1,  0,  0,  0,  1,  0] [ 0,  0,  0]  1 */
    18432160, /* 69017 (1629) [ 0,  0, -1, -1,  0,  0,  0,  1,  0] [ 6,  6,  0]  1 */
    17014010, /* 69018 (1629) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 6,  0,  0]  1 */
    35432760, /* 69019 (1629) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  0] -1 */
    17018384, /* 69020 (1629) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 6,  0,  0]  1 */
      127300, /* 69021 (1629) [ 0,  0, -1,  0,  1,  0,  1,  0,  0] [ 0,  0,  6]  1 */
    18550588, /* 69022 (1629) [ 0,  0, -1,  0,  1,  0,  1,  0,  0] [ 6,  6,  6]  1 */
    34024494, /* 69023 (1629) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    17133562, /* 69024 (1629) [ 0,  0, -1,  1,  0,  0,  0, -1,  0] [ 6,  0,  6]  1 */
    17018382, /* 69025 (1629) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 6,  0,  0]  1 */
     1426378, /* 69026 (1629) [ 0,  0, -1,  0,  1,  0,  1,  0,  0] [ 0,  6,  0]  1 */
    34139674, /* 69027 (1629) [ 0,  0, -1,  1,  0,  0,  0, -1,  0] [ 0,  0,  6] -1 */
    17134534, /* 69028 (1629) [ 0,  0,  1, -1,  0,  0,  0, -1,  0] [ 6,  0,  6]  1 */
    34022866, /* 69029 (1629) [ 0,  0,  1,  0,  1,  0, -1,  0,  0] [ 0,  0,  0] -1 */
    52446154, /* 69030 (1629) [ 0,  0,  1,  0,  1,  0, -1,  0,  0] [ 6,  6,  0] -1 */
    34146806, /* 69031 (1629) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    17016754, /* 69032 (1629) [ 0,  0,  1,  0,  1,  0, -1,  0,  0] [ 6,  0,  0]  1 */
    18439772, /* 69033 (1629) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    51145618, /* 69034 (1629) [ 0,  0, -1,  0,  1,  0, -1,  0,  0] [ 6,  0,  6] -1 */
    18553170, /* 69035 (1629) [ 0,  1,  0, -1,  0,  0,  0,  0, -1] [ 6,  6,  6]  1 */
    17140692, /* 69036 (1629) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6]  1 */
    18430960, /* 69037 (1629) [ 0, -1,  0,  0,  0,  1, -1,  0,  0] [ 6,  6,  0]  1 */
    51025954, /* 69038 (1629) [ 0, -1,  0,  0,  0, -1, -1,  0,  0] [ 6,  0,  0] -1 */
    52438768, /* 69039 (1629) [-1,  0,  0,  0,  0, -1,  0,  1,  0] [ 6,  6,  0] -1 */
    18435280, /* 69040 (1629) [ 0,  1,  0,  0,  0, -1, -1,  0,  0] [ 6,  6,  0]  1 */
    18435352, /* 69041 (1629) [ 0,  1,  0,  0,  0,  1,  1,  0,  0] [ 6,  6,  0]  1 */
    35441410, /* 69042 (1629) [ 0,  1,  0,  0,  0, -1,  1,  0,  0] [ 0,  6,  0] -1 */
    51139744, /* 69043 (1629) [-1,  0,  0,  0,  0,  1,  0,  1,  0] [ 6,  0,  6] -1 */
      130370, /* 69044 (1629) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 0,  0,  6]  1 */
    18557818, /* 69045 (1629) [ 1,  0,  0,  0,  0,  1,  0,  1,  0] [ 6,  6,  6]  1 */
      125510, /* 69046 (1629) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  6]  1 */
    18548798, /* 69047 (1629) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    52442922, /* 69048 (1629) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 6,  6,  0] -1 */
    52443408, /* 69049 (1629) [ 0, -1,  0,  1,  0,  0,  0,  0, -1] [ 6,  6,  0] -1 */
    35556520, /* 69050 (1629) [ 0,  0, -1,  0, -1,  0, -1,  0,  0] [ 0,  6,  6] -1 */
    18434098, /* 69051 (1629) [ 0,  0,  1,  1,  0,  0,  0, -1,  0] [ 6,  6,  0]  1 */
    52563940, /* 69052 (1629) [ 0,  0,  1, -1,  0,  0,  0,  1,  0] [ 6,  6,  6] -1 */
    35437090, /* 69053 (1629) [ 0, -1,  0,  0,  0,  1,  1,  0,  0] [ 0,  6,  0] -1 */
    34140646, /* 69054 (1629) [ 0,  0,  1, -1,  0,  0,  0, -1,  0] [ 0,  0,  6] -1 */
    52563934, /* 69055 (1629) [ 0,  0,  1, -1,  0,  0,  0, -1,  0] [ 6,  6,  6] -1 */
    35563924, /* 69056 (1629) [ 1,  0,  0,  0,  0,  1,  0, -1,  0] [ 0,  6,  6] -1 */
    35563870, /* 69057 (1629) [ 1,  0,  0,  0,  0, -1,  0, -1,  0] [ 0,  6,  6] -1 */
        3362, /* 69058 (1629) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    35441446, /* 69059 (1629) [ 0,  1,  0,  0,  0,  1, -1,  0,  0] [ 0,  6,  0] -1 */
    52444696, /* 69060 (1629) [ 0,  0, -1,  0,  1,  0, -1,  0,  0] [ 6,  6,  0] -1 */
    35439724, /* 69061 (1629) [ 0,  0,  1, -1,  0,  0,  0, -1,  0] [ 0,  6,  0] -1 */
    18439770, /* 69062 (1629) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
        7618, /* 69063 (1629) [ 0, -1,  0,  0,  0, -1, -1,  0,  0] [ 0,  0,  0]  1 */
    18430906, /* 69064 (1629) [ 0, -1,  0,  0,  0, -1, -1,  0,  0] [ 6,  6,  0]  1 */
    51146932, /* 69065 (1629) [ 0,  0,  1,  0, -1,  0,  1,  0,  0] [ 6,  0,  6] -1 */
    35557996, /* 69066 (1629) [ 0,  0,  1,  0, -1,  0,  1,  0,  0] [ 0,  6,  6] -1 */
    17127410, /* 69067 (1629) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
    51021696, /* 69068 (1629) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  0] -1 */
    51030346, /* 69069 (1629) [ 0,  1,  0,  0,  0, -1,  1,  0,  0] [ 6,  0,  0] -1 */
    51145456, /* 69070 (1629) [ 0,  0, -1,  0, -1,  0, -1,  0,  0] [ 6,  0,  6] -1 */
     1433608, /* 69071 (1629) [ 1,  0,  0,  0,  0,  1,  0,  1,  0] [ 0,  6,  0]  1 */
    34021426, /* 69072 (1629) [ 0,  0, -1,  0,  1,  0,  1,  0,  0] [ 0,  0,  0] -1 */
     1538472, /* 69073 (1629) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
    18544636, /* 69074 (1629) [-1,  0,  0,  0,  0, -1,  0, -1,  0] [ 6,  6,  6]  1 */
    17015314, /* 69075 (1629) [ 0,  0, -1,  0,  1,  0,  1,  0,  0] [ 6,  0,  0]  1 */
     1542964, /* 69076 (1629) [ 0, -1,  0,  0,  0,  1,  1,  0,  0] [ 0,  6,  6]  1 */
       16322, /* 69077 (1629) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    51152860, /* 69078 (1629) [ 1,  0,  0,  0,  0,  1,  0, -1,  0] [ 6,  0,  6] -1 */
        9358, /* 69079 (1629) [ 0,  0, -1,  1,  0,  0,  0,  1,  0] [ 0,  0,  0]  1 */
    18544690, /* 69080 (1629) [-1,  0,  0,  0,  0,  1,  0, -1,  0] [ 6,  6,  6]  1 */
    51152806, /* 69081 (1629) [ 1,  0,  0,  0,  0, -1,  0, -1,  0] [ 6,  0,  6] -1 */
       16320, /* 69082 (1629) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
     1420480, /* 69083 (1629) [-1,  0,  0,  0,  0,  1,  0, -1,  0] [ 0,  6,  0]  1 */
    52447296, /* 69084 (1629) [ 0,  1,  0, -1,  0,  0,  0,  0, -1] [ 6,  6,  0] -1 */
      121354, /* 69085 (1629) [-1,  0,  0,  0,  0, -1,  0,  1,  0] [ 0,  0,  6]  1 */
    51030382, /* 69086 (1629) [ 0,  1,  0,  0,  0,  1, -1,  0,  0] [ 6,  0,  0] -1 */
     1424588, /* 69087 (1629) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 0,  6,  0]  1 */
      127282, /* 69088 (1629) [ 0,  0, -1,  0,  1,  0, -1,  0,  0] [ 0,  0,  6]  1 */
    18550570, /* 69089 (1629) [ 0,  0, -1,  0,  1,  0, -1,  0,  0] [ 6,  6,  6]  1 */
    51034820, /* 69090 (1629) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  0] -1 */
      125508, /* 69091 (1629) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  6]  1 */
    18548796, /* 69092 (1629) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 6,  6,  6]  1 */
    18426648, /* 69093 (1629) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
    34133522, /* 69094 (1629) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    52556810, /* 69095 (1629) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
     1420432, /* 69096 (1629) [-1,  0,  0,  0,  0, -1,  0,  1,  0] [ 0,  6,  0]  1 */
    35439730, /* 69097 (1629) [ 0,  0,  1, -1,  0,  0,  0,  1,  0] [ 0,  6,  0] -1 */
    18544696, /* 69098 (1629) [-1,  0,  0,  0,  0,  1,  0,  1,  0] [ 6,  6,  6]  1 */
      125994, /* 69099 (1629) [ 0, -1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  6]  1 */
    52451944, /* 69100 (1629) [ 1,  0,  0,  0,  0,  1,  0,  1,  0] [ 6,  6,  0] -1 */
    35555396, /* 69101 (1629) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 0,  6,  6] -1 */
    17131900, /* 69102 (1629) [ 0, -1,  0,  0,  0,  1,  1,  0,  0] [ 6,  0,  6]  1 */
    34133520, /* 69103 (1629) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
    52561246, /* 69104 (1629) [ 0, -1,  0,  0,  0, -1,  1,  0,  0] [ 6,  6,  6] -1 */
    34138012, /* 69105 (1629) [ 0, -1,  0,  0,  0,  1,  1,  0,  0] [ 0,  0,  6] -1 */
     1420426, /* 69106 (1629) [-1,  0,  0,  0,  0, -1,  0, -1,  0] [ 0,  6,  0]  1 */
    51027688, /* 69107 (1629) [ 0,  0, -1,  1,  0,  0,  0, -1,  0] [ 6,  0,  0] -1 */
        8866, /* 69108 (1629) [ 0,  0, -1, -1,  0,  0,  0, -1,  0] [ 0,  0,  0]  1 */
    18432154, /* 69109 (1629) [ 0,  0, -1, -1,  0,  0,  0, -1,  0] [ 6,  6,  0]  1 */
    52562482, /* 69110 (1629) [ 0,  0, -1, -1,  0,  0,  0,  1,  0] [ 6,  6,  6] -1 */
    51028660, /* 69111 (1629) [ 0,  0,  1, -1,  0,  0,  0, -1,  0] [ 6,  0,  0] -1 */
    17127408, /* 69112 (1629) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  6]  1 */
    34019636, /* 69113 (1629) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    52442924, /* 69114 (1629) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 6,  6,  0] -1 */
    52451890, /* 69115 (1629) [ 1,  0,  0,  0,  0, -1,  0,  1,  0] [ 6,  6,  0] -1 */
      129882, /* 69116 (1629) [ 0,  1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  6]  1 */
    52556808, /* 69117 (1629) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
     1426360, /* 69118 (1629) [ 0,  0, -1,  0,  1,  0, -1,  0,  0] [ 0,  6,  0]  1 */
     1424586, /* 69119 (1629) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 0,  6,  0]  1 */
     1425072, /* 69120 (1629) [ 0, -1,  0,  1,  0,  0,  0,  0, -1] [ 0,  6,  0]  1 */
       11992, /* 69121 (1629) [ 0,  1,  0,  0,  0, -1, -1,  0,  0] [ 0,  0,  0]  1 */
       12064, /* 69122 (1629) [ 0,  1,  0,  0,  0,  1,  1,  0,  0] [ 0,  0,  0]  1 */
     1545604, /* 69123 (1629) [ 0,  0,  1, -1,  0,  0,  0,  1,  0] [ 0,  6,  6]  1 */
    35558158, /* 69124 (1629) [ 0,  0,  1,  0,  1,  0,  1,  0,  0] [ 0,  6,  6] -1 */
     1546090, /* 69125 (1629) [ 0,  0,  1,  1,  0,  0,  0,  1,  0] [ 0,  6,  6]  1 */
    34015474, /* 69126 (1629) [-1,  0,  0,  0,  0, -1,  0, -1,  0] [ 0,  0,  0] -1 */
    52438762, /* 69127 (1629) [-1,  0,  0,  0,  0, -1,  0, -1,  0] [ 6,  6,  0] -1 */
    35437036, /* 69128 (1629) [ 0, -1,  0,  0,  0, -1,  1,  0,  0] [ 0,  6,  0] -1 */
    51145474, /* 69129 (1629) [ 0,  0, -1,  0, -1,  0,  1,  0,  0] [ 6,  0,  6] -1 */
    18435298, /* 69130 (1629) [ 0,  1,  0,  0,  0, -1,  1,  0,  0] [ 6,  6,  0]  1 */
    34015528, /* 69131 (1629) [-1,  0,  0,  0,  0,  1,  0, -1,  0] [ 0,  0,  0] -1 */
    35556700, /* 69132 (1629) [ 0,  0, -1,  0,  1,  0,  1,  0,  0] [ 0,  6,  6] -1 */
    18557812, /* 69133 (1629) [ 1,  0,  0,  0,  0,  1,  0, -1,  0] [ 6,  6,  6]  1 */
        7672, /* 69134 (1629) [ 0, -1,  0,  0,  0,  1, -1,  0,  0] [ 0,  0,  0]  1 */
    35559284, /* 69135 (1629) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 0,  6,  6] -1 */
       12046, /* 69136 (1629) [ 0,  1,  0,  0,  0,  1, -1,  0,  0] [ 0,  0,  0]  1 */
    18435334, /* 69137 (1629) [ 0,  1,  0,  0,  0,  1, -1,  0,  0] [ 6,  6,  0]  1 */
    35557978, /* 69138 (1629) [ 0,  0,  1,  0, -1,  0, -1,  0,  0] [ 0,  6,  6] -1 */
    35432600, /* 69139 (1629) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  0] -1 */
    17013524, /* 69140 (1629) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 6,  0,  0]  1 */
    34015480, /* 69141 (1629) [-1,  0,  0,  0,  0, -1,  0,  1,  0] [ 0,  0,  0] -1 */
     1544632, /* 69142 (1629) [ 0,  0, -1,  1,  0,  0,  0,  1,  0] [ 0,  6,  6]  1 */
      134476, /* 69143 (1629) [ 1,  0,  0,  0,  0, -1,  0,  1,  0] [ 0,  0,  6]  1 */
    18557764, /* 69144 (1629) [ 1,  0,  0,  0,  0, -1,  0,  1,  0] [ 6,  6,  6]  1 */
    34021408, /* 69145 (1629) [ 0,  0, -1,  0,  1,  0, -1,  0,  0] [ 0,  0,  0] -1 */
      128596, /* 69146 (1629) [ 0,  0,  1,  0, -1,  0,  1,  0,  0] [ 0,  0,  6]  1 */
    18551884, /* 69147 (1629) [ 0,  0,  1,  0, -1,  0,  1,  0,  0] [ 6,  6,  6]  1 */
    34019634, /* 69148 (1629) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    17134540, /* 69149 (1629) [ 0,  0,  1, -1,  0,  0,  0,  1,  0] [ 6,  0,  6]  1 */
     1538636, /* 69150 (1629) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
    17009368, /* 69151 (1629) [-1,  0,  0,  0,  0, -1,  0,  1,  0] [ 6,  0,  0]  1 */
    51028666, /* 69152 (1629) [ 0,  0,  1, -1,  0,  0,  0,  1,  0] [ 6,  0,  0] -1 */
    35432598, /* 69153 (1629) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  0] -1 */
    17015296, /* 69154 (1629) [ 0,  0, -1,  0,  1,  0, -1,  0,  0] [ 6,  0,  0]  1 */
    17013522, /* 69155 (1629) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 6,  0,  0]  1 */
      134530, /* 69156 (1629) [ 1,  0,  0,  0,  0,  1,  0,  1,  0] [ 0,  0,  6]  1 */
       10810, /* 69157 (1629) [ 0,  0,  1,  1,  0,  0,  0, -1,  0] [ 0,  0,  0]  1 */
    18432640, /* 69158 (1629) [ 0,  0, -1,  1,  0,  0,  0, -1,  0] [ 6,  6,  0]  1 */
    34146644, /* 69159 (1629) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    52569932, /* 69160 (1629) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    17135026, /* 69161 (1629) [ 0,  0,  1,  1,  0,  0,  0,  1,  0] [ 6,  0,  6]  1 */
    34015534, /* 69162 (1629) [-1,  0,  0,  0,  0,  1,  0,  1,  0] [ 0,  0,  0] -1 */
    52438822, /* 69163 (1629) [-1,  0,  0,  0,  0,  1,  0,  1,  0] [ 6,  6,  0] -1 */
    51021536, /* 69164 (1629) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  0] -1 */
    52438816, /* 69165 (1629) [-1,  0,  0,  0,  0,  1,  0, -1,  0] [ 6,  6,  0] -1 */
     1551594, /* 69166 (1629) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
    18557758, /* 69167 (1629) [ 1,  0,  0,  0,  0, -1,  0, -1,  0] [ 6,  6,  6]  1 */
    34141138, /* 69168 (1629) [ 0,  0,  1,  1,  0,  0,  0,  1,  0] [ 0,  0,  6] -1 */
    52564426, /* 69169 (1629) [ 0,  0,  1,  1,  0,  0,  0,  1,  0] [ 6,  6,  6] -1 */
    35438272, /* 69170 (1629) [ 0,  0, -1, -1,  0,  0,  0,  1,  0] [ 0,  6,  0] -1 */
    51145636, /* 69171 (1629) [ 0,  0, -1,  0,  1,  0,  1,  0,  0] [ 6,  0,  6] -1 */
    51148220, /* 69172 (1629) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 6,  0,  6] -1 */
      121348, /* 69173 (1629) [-1,  0,  0,  0,  0, -1,  0, -1,  0] [ 0,  0,  6]  1 */
    51146914, /* 69174 (1629) [ 0,  0,  1,  0, -1,  0, -1,  0,  0] [ 6,  0,  6] -1 */
     1542910, /* 69175 (1629) [ 0, -1,  0,  0,  0, -1,  1,  0,  0] [ 0,  6,  6]  1 */
    52444552, /* 69176 (1629) [ 0,  0, -1,  0, -1,  0,  1,  0,  0] [ 6,  6,  0] -1 */
       16482, /* 69177 (1629) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
     1428960, /* 69178 (1629) [ 0,  1,  0, -1,  0,  0,  0,  0, -1] [ 0,  6,  0]  1 */
    17133568, /* 69179 (1629) [ 0,  0, -1,  1,  0,  0,  0,  1,  0] [ 6,  0,  6]  1 */
     1433602, /* 69180 (1629) [ 1,  0,  0,  0,  0,  1,  0, -1,  0] [ 0,  6,  0]  1 */
    51147094, /* 69181 (1629) [ 0,  0,  1,  0,  1,  0,  1,  0,  0] [ 6,  0,  6] -1 */
    52562968, /* 69182 (1629) [ 0,  0, -1,  1,  0,  0,  0,  1,  0] [ 6,  6,  6] -1 */
    34020120, /* 69183 (1629) [ 0, -1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  0] -1 */
     1538474, /* 69184 (1629) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
        9352, /* 69185 (1629) [ 0,  0, -1,  1,  0,  0,  0, -1,  0] [ 0,  0,  0]  1 */
    52556972, /* 69186 (1629) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    34133684, /* 69187 (1629) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    17014008, /* 69188 (1629) [ 0, -1,  0,  1,  0,  0,  0,  0, -1] [ 6,  0,  0]  1 */
    34140652, /* 69189 (1629) [ 0,  0,  1, -1,  0,  0,  0,  1,  0] [ 0,  0,  6] -1 */
     1433554, /* 69190 (1629) [ 1,  0,  0,  0,  0, -1,  0,  1,  0] [ 0,  6,  0]  1 */
    52561228, /* 69191 (1629) [ 0, -1,  0,  0,  0, -1, -1,  0,  0] [ 6,  6,  6] -1 */
    51021534, /* 69192 (1629) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  0] -1 */
    18433612, /* 69193 (1629) [ 0,  0,  1, -1,  0,  0,  0, -1,  0] [ 6,  6,  0]  1 */
      121402, /* 69194 (1629) [-1,  0,  0,  0,  0,  1,  0, -1,  0] [ 0,  0,  6]  1 */
    51148706, /* 69195 (1629) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 6,  0,  6] -1 */
    17131846, /* 69196 (1629) [ 0, -1,  0,  0,  0, -1,  1,  0,  0] [ 6,  0,  6]  1 */
    35559770, /* 69197 (1629) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 0,  6,  6] -1 */
    35440216, /* 69198 (1629) [ 0,  0,  1,  1,  0,  0,  0,  1,  0] [ 0,  6,  0] -1 */
     1544146, /* 69199 (1629) [ 0,  0, -1, -1,  0,  0,  0,  1,  0] [ 0,  6,  6]  1 */
    51026026, /* 69200 (1629) [ 0, -1,  0,  0,  0,  1,  1,  0,  0] [ 6,  0,  0] -1 */
    52447298, /* 69201 (1629) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 6,  6,  0] -1 */
    34137958, /* 69202 (1629) [ 0, -1,  0,  0,  0, -1,  1,  0,  0] [ 0,  0,  6] -1 */
    34024008, /* 69203 (1629) [ 0,  1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  0] -1 */
      127138, /* 69204 (1629) [ 0,  0, -1,  0, -1,  0,  1,  0,  0] [ 0,  0,  6]  1 */
    18550426, /* 69205 (1629) [ 0,  0, -1,  0, -1,  0,  1,  0,  0] [ 6,  6,  6]  1 */
    34028650, /* 69206 (1629) [ 1,  0,  0,  0,  0,  1,  0, -1,  0] [ 0,  0,  0] -1 */
     1427674, /* 69207 (1629) [ 0,  0,  1,  0, -1,  0,  1,  0,  0] [ 0,  6,  0]  1 */
    34139680, /* 69208 (1629) [ 0,  0, -1,  1,  0,  0,  0,  1,  0] [ 0,  0,  6] -1 */
    17017896, /* 69209 (1629) [ 0,  1,  0, -1,  0,  0,  0,  0, -1] [ 6,  0,  0]  1 */
    17140530, /* 69210 (1629) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  6]  1 */
    35445722, /* 69211 (1629) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  0] -1 */
    34146642, /* 69212 (1629) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
    52569930, /* 69213 (1629) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
      121408, /* 69214 (1629) [-1,  0,  0,  0,  0,  1,  0,  1,  0] [ 0,  0,  6]  1 */
    35438758, /* 69215 (1629) [ 0,  0, -1,  1,  0,  0,  0,  1,  0] [ 0,  6,  0] -1 */
    52444534, /* 69216 (1629) [ 0,  0, -1,  0, -1,  0, -1,  0,  0] [ 6,  6,  0] -1 */
    35558140, /* 69217 (1629) [ 0,  0,  1,  0,  1,  0, -1,  0,  0] [ 0,  6,  6] -1 */
    34028602, /* 69218 (1629) [ 1,  0,  0,  0,  0, -1,  0,  1,  0] [ 0,  0,  0] -1 */
    35432762, /* 69219 (1629) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  0] -1 */
     1551758, /* 69220 (1629) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
    17022490, /* 69221 (1629) [ 1,  0,  0,  0,  0, -1,  0,  1,  0] [ 6,  0,  0]  1 */
    17016610, /* 69222 (1629) [ 0,  0,  1,  0, -1,  0,  1,  0,  0] [ 6,  0,  0]  1 */
     1542946, /* 69223 (1629) [ 0, -1,  0,  0,  0,  1, -1,  0,  0] [ 0,  6,  6]  1 */
    17133082, /* 69224 (1629) [ 0,  0, -1, -1,  0,  0,  0,  1,  0] [ 6,  0,  6]  1 */
    35550754, /* 69225 (1629) [-1,  0,  0,  0,  0, -1,  0,  1,  0] [ 0,  6,  6] -1 */
     1547266, /* 69226 (1629) [ 0,  1,  0,  0,  0, -1, -1,  0,  0] [ 0,  6,  6]  1 */
    35559768, /* 69227 (1629) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 0,  6,  6] -1 */
    52451938, /* 69228 (1629) [ 1,  0,  0,  0,  0,  1,  0, -1,  0] [ 6,  6,  0] -1 */
    52451884, /* 69229 (1629) [ 1,  0,  0,  0,  0, -1,  0, -1,  0] [ 6,  6,  0] -1 */
    34139194, /* 69230 (1629) [ 0,  0, -1, -1,  0,  0,  0,  1,  0] [ 0,  0,  6] -1 */
    35554908, /* 69231 (1629) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 0,  6,  6] -1 */
      129884, /* 69232 (1629) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  6]  1 */
    18553172, /* 69233 (1629) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    35555394, /* 69234 (1629) [ 0, -1,  0,  1,  0,  0,  0,  0, -1] [ 0,  6,  6] -1 */
      128578, /* 69235 (1629) [ 0,  0,  1,  0, -1,  0, -1,  0,  0] [ 0,  0,  6]  1 */
    18551866, /* 69236 (1629) [ 0,  0,  1,  0, -1,  0, -1,  0,  0] [ 6,  6,  6]  1 */
    34022722, /* 69237 (1629) [ 0,  0,  1,  0, -1,  0,  1,  0,  0] [ 0,  0,  0] -1 */
    52446010, /* 69238 (1629) [ 0,  0,  1,  0, -1,  0,  1,  0,  0] [ 6,  6,  0] -1 */
        3360, /* 69239 (1629) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
     1546084, /* 69240 (1629) [ 0,  0,  1,  1,  0,  0,  0, -1,  0] [ 0,  6,  6]  1 */
       12010, /* 69241 (1629) [ 0,  1,  0,  0,  0, -1,  1,  0,  0] [ 0,  0,  0]  1 */
    18426488, /* 69242 (1629) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    51144332, /* 69243 (1629) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 6,  0,  6] -1 */
    52562476, /* 69244 (1629) [ 0,  0, -1, -1,  0,  0,  0, -1,  0] [ 6,  6,  6] -1 */
    34028656, /* 69245 (1629) [ 1,  0,  0,  0,  0,  1,  0,  1,  0] [ 0,  0,  0] -1 */
    18552046, /* 69246 (1629) [ 0,  0,  1,  0,  1,  0,  1,  0,  0] [ 6,  6,  6]  1 */
    17022544, /* 69247 (1629) [ 1,  0,  0,  0,  0,  1,  0,  1,  0] [ 6,  0,  0]  1 */
    18426486, /* 69248 (1629) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
     1551596, /* 69249 (1629) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
    35445720, /* 69250 (1629) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  0] -1 */
     1420486, /* 69251 (1629) [-1,  0,  0,  0,  0,  1,  0,  1,  0] [ 0,  6,  0]  1 */
    18550408, /* 69252 (1629) [ 0,  0, -1,  0, -1,  0, -1,  0,  0] [ 6,  6,  6]  1 */
      127120, /* 69253 (1629) [ 0,  0, -1,  0, -1,  0, -1,  0,  0] [ 0,  0,  6]  1 */
    17131882, /* 69254 (1629) [ 0, -1,  0,  0,  0,  1, -1,  0,  0] [ 6,  0,  6]  1 */
    51139690, /* 69255 (1629) [-1,  0,  0,  0,  0, -1,  0,  1,  0] [ 6,  0,  6] -1 */
    52570094, /* 69256 (1629) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    17136202, /* 69257 (1629) [ 0,  1,  0,  0,  0, -1, -1,  0,  0] [ 6,  0,  6]  1 */
    51148704, /* 69258 (1629) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 6,  0,  6] -1 */
        7690, /* 69259 (1629) [ 0, -1,  0,  0,  0,  1,  1,  0,  0] [ 0,  0,  0]  1 */
    18430978, /* 69260 (1629) [ 0, -1,  0,  0,  0,  1,  1,  0,  0] [ 6,  6,  0]  1 */
    51021698, /* 69261 (1629) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  0] -1 */
    35556682, /* 69262 (1629) [ 0,  0, -1,  0,  1,  0, -1,  0,  0] [ 0,  6,  6] -1 */
    34137994, /* 69263 (1629) [ 0, -1,  0,  0,  0,  1, -1,  0,  0] [ 0,  0,  6] -1 */
    52561282, /* 69264 (1629) [ 0, -1,  0,  0,  0,  1, -1,  0,  0] [ 6,  6,  6] -1 */
     1551756, /* 69265 (1629) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
     1542892, /* 69266 (1629) [ 0, -1,  0,  0,  0, -1, -1,  0,  0] [ 0,  6,  6]  1 */
    34142314, /* 69267 (1629) [ 0,  1,  0,  0,  0, -1, -1,  0,  0] [ 0,  0,  6] -1 */
    52565602, /* 69268 (1629) [ 0,  1,  0,  0,  0, -1, -1,  0,  0] [ 6,  6,  6] -1 */
    34142386, /* 69269 (1629) [ 0,  1,  0,  0,  0,  1,  1,  0,  0] [ 0,  0,  6] -1 */
    52565674, /* 69270 (1629) [ 0,  1,  0,  0,  0,  1,  1,  0,  0] [ 6,  6,  6] -1 */
    51029152, /* 69271 (1629) [ 0,  0,  1,  1,  0,  0,  0,  1,  0] [ 6,  0,  0] -1 */
    51144330, /* 69272 (1629) [ 0, -1,  0,  1,  0,  0,  0,  0, -1] [ 6,  0,  6] -1 */
     1426216, /* 69273 (1629) [ 0,  0, -1,  0, -1,  0,  1,  0,  0] [ 0,  6,  0]  1 */
      134524, /* 69274 (1629) [ 1,  0,  0,  0,  0,  1,  0, -1,  0] [ 0,  0,  6]  1 */
    51147076, /* 69275 (1629) [ 0,  0,  1,  0,  1,  0, -1,  0,  0] [ 6,  0,  6] -1 */
      134470, /* 69276 (1629) [ 1,  0,  0,  0,  0, -1,  0, -1,  0] [ 0,  0,  6]  1 */
    17009416, /* 69277 (1629) [-1,  0,  0,  0,  0,  1,  0, -1,  0] [ 6,  0,  0]  1 */
    52562962, /* 69278 (1629) [ 0,  0, -1,  1,  0,  0,  0, -1,  0] [ 6,  6,  6] -1 */
     1428962, /* 69279 (1629) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 0,  6,  0]  1 */
    17140532, /* 69280 (1629) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
    52443410, /* 69281 (1629) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 6,  6,  0] -1 */
    51034658, /* 69282 (1629) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  0] -1 */
    17015152, /* 69283 (1629) [ 0,  0, -1,  0, -1,  0,  1,  0,  0] [ 6,  0,  0]  1 */
    35438266, /* 69284 (1629) [ 0,  0, -1, -1,  0,  0,  0, -1,  0] [ 0,  6,  0] -1 */
    51027694, /* 69285 (1629) [ 0,  0, -1,  1,  0,  0,  0,  1,  0] [ 6,  0,  0] -1 */
    52565656, /* 69286 (1629) [ 0,  1,  0,  0,  0,  1, -1,  0,  0] [ 6,  6,  6] -1 */
     1427836, /* 69287 (1629) [ 0,  0,  1,  0,  1,  0,  1,  0,  0] [ 0,  6,  0]  1 */
    51143844, /* 69288 (1629) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 6,  0,  6] -1 */
    17131828, /* 69289 (1629) [ 0, -1,  0,  0,  0, -1, -1,  0,  0] [ 6,  0,  6]  1 */
    51034656, /* 69290 (1629) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  0] -1 */
    17009422, /* 69291 (1629) [-1,  0,  0,  0,  0,  1,  0,  1,  0] [ 6,  0,  0]  1 */
     1426198, /* 69292 (1629) [ 0,  0, -1,  0, -1,  0, -1,  0,  0] [ 0,  6,  0]  1 */
    52447782, /* 69293 (1629) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 6,  6,  0] -1 */
    17135020, /* 69294 (1629) [ 0,  0,  1,  1,  0,  0,  0, -1,  0] [ 6,  0,  6]  1 */
    35445884, /* 69295 (1629) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  0] -1 */
    17009362, /* 69296 (1629) [-1,  0,  0,  0,  0, -1,  0, -1,  0] [ 6,  0,  0]  1 */
    35559282, /* 69297 (1629) [ 0,  1,  0, -1,  0,  0,  0,  0, -1] [ 0,  6,  6] -1 */
    52570092, /* 69298 (1629) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    34146804, /* 69299 (1629) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
    34137940, /* 69300 (1629) [ 0, -1,  0,  0,  0, -1, -1,  0,  0] [ 0,  0,  6] -1 */
    34141132, /* 69301 (1629) [ 0,  0,  1,  1,  0,  0,  0, -1,  0] [ 0,  0,  6] -1 */
    52564420, /* 69302 (1629) [ 0,  0,  1,  1,  0,  0,  0, -1,  0] [ 6,  6,  6] -1 */
    35441392, /* 69303 (1629) [ 0,  1,  0,  0,  0, -1, -1,  0,  0] [ 0,  6,  0] -1 */
    51025972, /* 69304 (1629) [ 0, -1,  0,  0,  0, -1,  1,  0,  0] [ 6,  0,  0] -1 */
    35441464, /* 69305 (1629) [ 0,  1,  0,  0,  0,  1,  1,  0,  0] [ 0,  6,  0] -1 */
    34021264, /* 69306 (1629) [ 0,  0, -1,  0, -1,  0,  1,  0,  0] [ 0,  0,  0] -1 */
     1427656, /* 69307 (1629) [ 0,  0,  1,  0, -1,  0, -1,  0,  0] [ 0,  6,  0]  1 */
       10324, /* 69308 (1629) [ 0,  0,  1, -1,  0,  0,  0, -1,  0] [ 0,  0,  0]  1 */
     1538634, /* 69309 (1629) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
    35563930, /* 69310 (1629) [ 1,  0,  0,  0,  0,  1,  0,  1,  0] [ 0,  6,  6] -1 */
    17127572, /* 69311 (1629) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
    17016592, /* 69312 (1629) [ 0,  0,  1,  0, -1,  0, -1,  0,  0] [ 6,  0,  0]  1 */
    18439610, /* 69313 (1629) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
      125996, /* 69314 (1629) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 0,  0,  6]  1 */
    18549284, /* 69315 (1629) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    34022884, /* 69316 (1629) [ 0,  0,  1,  0,  1,  0,  1,  0,  0] [ 0,  0,  0] -1 */
    52446172, /* 69317 (1629) [ 0,  0,  1,  0,  1,  0,  1,  0,  0] [ 6,  6,  0] -1 */
    35437072, /* 69318 (1629) [ 0, -1,  0,  0,  0,  1, -1,  0,  0] [ 0,  6,  0] -1 */
     1544140, /* 69319 (1629) [ 0,  0, -1, -1,  0,  0,  0, -1,  0] [ 0,  6,  6]  1 */
    51027202, /* 69320 (1629) [ 0,  0, -1, -1,  0,  0,  0, -1,  0] [ 6,  0,  0] -1 */
    18553658, /* 69321 (1629) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    51148218, /* 69322 (1629) [ 0,  1,  0, -1,  0,  0,  0,  0, -1] [ 6,  0,  6] -1 */
       10816, /* 69323 (1629) [ 0,  0,  1,  1,  0,  0,  0,  1,  0] [ 0,  0,  0]  1 */
    18434104, /* 69324 (1629) [ 0,  0,  1,  1,  0,  0,  0,  1,  0] [ 6,  6,  0]  1 */
    17016772, /* 69325 (1629) [ 0,  0,  1,  0,  1,  0,  1,  0,  0] [ 6,  0,  0]  1 */
    18544642, /* 69326 (1629) [-1,  0,  0,  0,  0, -1,  0,  1,  0] [ 6,  6,  6]  1 */
     1433548, /* 69327 (1629) [ 1,  0,  0,  0,  0, -1,  0, -1,  0] [ 0,  6,  0]  1 */
    17015134, /* 69328 (1629) [ 0,  0, -1,  0, -1,  0, -1,  0,  0] [ 6,  0,  0]  1 */
      130368, /* 69329 (1629) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  6]  1 */
    18553656, /* 69330 (1629) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 6,  6,  6]  1 */
    17127570, /* 69331 (1629) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6]  1 */
     1547320, /* 69332 (1629) [ 0,  1,  0,  0,  0,  1, -1,  0,  0] [ 0,  6,  6]  1 */
    35554910, /* 69333 (1629) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 0,  6,  6] -1 */
    35563876, /* 69334 (1629) [ 1,  0,  0,  0,  0, -1,  0,  1,  0] [ 0,  6,  6] -1 */
    51152866, /* 69335 (1629) [ 1,  0,  0,  0,  0,  1,  0,  1,  0] [ 6,  0,  6] -1 */
    34022704, /* 69336 (1629) [ 0,  0,  1,  0, -1,  0, -1,  0,  0] [ 0,  0,  0] -1 */
    52445992, /* 69337 (1629) [ 0,  0,  1,  0, -1,  0, -1,  0,  0] [ 6,  6,  0] -1 */
    35440210, /* 69338 (1629) [ 0,  0,  1,  1,  0,  0,  0, -1,  0] [ 0,  6,  0] -1 */
    35438752, /* 69339 (1629) [ 0,  0, -1,  1,  0,  0,  0, -1,  0] [ 0,  6,  0] -1 */
    51030328, /* 69340 (1629) [ 0,  1,  0,  0,  0, -1, -1,  0,  0] [ 6,  0,  0] -1 */
    51027208, /* 69341 (1629) [ 0,  0, -1, -1,  0,  0,  0,  1,  0] [ 6,  0,  0] -1 */
    51030400, /* 69342 (1629) [ 0,  1,  0,  0,  0,  1,  1,  0,  0] [ 6,  0,  0] -1 */
      128740, /* 69343 (1629) [ 0,  0,  1,  0,  1,  0, -1,  0,  0] [ 0,  0,  6]  1 */
    18552028, /* 69344 (1629) [ 0,  0,  1,  0,  1,  0, -1,  0,  0] [ 6,  6,  6]  1 */
    17017898, /* 69345 (1629) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 6,  0,  0]  1 */
    18426650, /* 69346 (1629) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
       10330, /* 69347 (1629) [ 0,  0,  1, -1,  0,  0,  0,  1,  0] [ 0,  0,  0]  1 */
    18433618, /* 69348 (1629) [ 0,  0,  1, -1,  0,  0,  0,  1,  0] [ 6,  6,  0]  1 */
    34021246, /* 69349 (1629) [ 0,  0, -1,  0, -1,  0, -1,  0,  0] [ 0,  0,  0] -1 */
    35550802, /* 69350 (1629) [-1,  0,  0,  0,  0,  1,  0, -1,  0] [ 0,  6,  6] -1 */
    17133076, /* 69351 (1629) [ 0,  0, -1, -1,  0,  0,  0, -1,  0] [ 6,  0,  6]  1 */
    35550748, /* 69352 (1629) [-1,  0,  0,  0,  0, -1,  0, -1,  0] [ 0,  6,  6] -1 */
    35445882, /* 69353 (1629) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  0] -1 */
    34139188, /* 69354 (1629) [ 0,  0, -1, -1,  0,  0,  0, -1,  0] [ 0,  0,  6] -1 */
     1547284, /* 69355 (1629) [ 0,  1,  0,  0,  0, -1,  1,  0,  0] [ 0,  6,  6]  1 */
    18439608, /* 69356 (1629) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
    35437018, /* 69357 (1629) [ 0, -1,  0,  0,  0, -1, -1,  0,  0] [ 0,  6,  0] -1 */
     1425074, /* 69358 (1629) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 0,  6,  0]  1 */
      128758, /* 69359 (1629) [ 0,  0,  1,  0,  1,  0,  1,  0,  0] [ 0,  0,  6]  1 */
    51143846, /* 69360 (1629) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 6,  0,  6] -1 */
    17136256, /* 69361 (1629) [ 0,  1,  0,  0,  0,  1, -1,  0,  0] [ 6,  0,  6]  1 */
    51152812, /* 69362 (1629) [ 1,  0,  0,  0,  0, -1,  0,  1,  0] [ 6,  0,  6] -1 */
    52556970, /* 69363 (1629) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
     1429448, /* 69364 (1629) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 0,  6,  0]  1 */
     1547338, /* 69365 (1629) [ 0,  1,  0,  0,  0,  1,  1,  0,  0] [ 0,  6,  6]  1 */
    52444714, /* 69366 (1629) [ 0,  0, -1,  0,  1,  0,  1,  0,  0] [ 6,  6,  0] -1 */
    34024010, /* 69367 (1629) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    34028596, /* 69368 (1629) [ 1,  0,  0,  0,  0, -1,  0, -1,  0] [ 0,  0,  0] -1 */
    18549282, /* 69369 (1629) [ 0, -1,  0,  1,  0,  0,  0,  0, -1] [ 6,  6,  6]  1 */
        7636, /* 69370 (1629) [ 0, -1,  0,  0,  0, -1,  1,  0,  0] [ 0,  0,  0]  1 */
    18430924, /* 69371 (1629) [ 0, -1,  0,  0,  0, -1,  1,  0,  0] [ 6,  6,  0]  1 */
    34133682, /* 69372 (1629) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
    51026008, /* 69373 (1629) [ 0, -1,  0,  0,  0,  1, -1,  0,  0] [ 6,  0,  0] -1 */
    17022484, /* 69374 (1629) [ 1,  0,  0,  0,  0, -1,  0, -1,  0] [ 6,  0,  0]  1 */
     1429446, /* 69375 (1629) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 0,  6,  0]  1 */
    51034818, /* 69376 (1629) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  0] -1 */
    18432646, /* 69377 (1629) [ 0,  0, -1,  1,  0,  0,  0,  1,  0] [ 6,  6,  0]  1 */
    17022538, /* 69378 (1629) [ 1,  0,  0,  0,  0,  1,  0, -1,  0] [ 6,  0,  0]  1 */
     1544626, /* 69379 (1629) [ 0,  0, -1,  1,  0,  0,  0, -1,  0] [ 0,  6,  6]  1 */
    51029146, /* 69380 (1629) [ 0,  0,  1,  1,  0,  0,  0, -1,  0] [ 6,  0,  0] -1 */
        3200, /* 69381 (1629) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    51139738, /* 69382 (1629) [-1,  0,  0,  0,  0,  1,  0, -1,  0] [ 6,  0,  6] -1 */
    35550808, /* 69383 (1629) [-1,  0,  0,  0,  0,  1,  0,  1,  0] [ 0,  6,  6] -1 */
    51139684, /* 69384 (1629) [-1,  0,  0,  0,  0, -1,  0, -1,  0] [ 6,  0,  6] -1 */
    52561300, /* 69385 (1629) [ 0, -1,  0,  0,  0,  1,  1,  0,  0] [ 6,  6,  6] -1 */
     1427818, /* 69386 (1629) [ 0,  0,  1,  0,  1,  0, -1,  0,  0] [ 0,  6,  0]  1 */
       16484, /* 69387 (1630) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
        7896, /* 69388 (1630) [ 0, -1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    18431184, /* 69389 (1630) [ 0, -1,  0,  1,  0,  0,  0,  0, -1] [ 6,  6,  0]  1 */
    17127570, /* 69390 (1630) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6]  1 */
       10660, /* 69391 (1630) [ 0,  0,  1,  0,  1,  0,  1,  0,  0] [ 0,  0,  0]  1 */
    17140694, /* 69392 (1630) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
    17134534, /* 69393 (1630) [ 0,  0,  1, -1,  0,  0,  0, -1,  0] [ 6,  0,  6]  1 */
     9279715, /* 69394 (1630) [ 0,  0, -1,  0, -1,  0, -1,  0,  0] [ 3,  3,  3]  1 */
    27703003, /* 69395 (1630) [ 0,  0, -1,  0, -1,  0, -1,  0,  0] [ 9,  9,  3]  1 */
    27705991, /* 69396 (1630) [ 0,  1,  0,  0,  0, -1,  1,  0,  0] [ 9,  9,  3]  1 */
    26406689, /* 69397 (1630) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 9,  3,  9]  1 */
    26406949, /* 69398 (1630) [ 0,  1,  0,  0,  0,  1, -1,  0,  0] [ 9,  3,  9]  1 */
     1538474, /* 69399 (1630) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
    10809217, /* 69400 (1630) [-1,  0,  0,  0,  0, -1,  0, -1,  0] [ 3,  9,  9]  1 */
     9273891, /* 69401 (1630) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 3,  3,  3]  1 */
       16432, /* 69402 (1630) [ 1,  0,  0,  0,  0,  1,  0,  1,  0] [ 0,  0,  0]  1 */
     9281023, /* 69403 (1630) [ 0,  0,  1, -1,  0,  0,  0,  1,  0] [ 3,  3,  3]  1 */
        3304, /* 69404 (1630) [-1,  0,  0,  0,  0,  1,  0, -1,  0] [ 0,  0,  0]  1 */
    18430960, /* 69405 (1630) [ 0, -1,  0,  0,  0,  1, -1,  0,  0] [ 6,  6,  0]  1 */
       16320, /* 69406 (1630) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    10816297, /* 69407 (1630) [ 0,  0,  1, -1,  0,  0,  0,  1,  0] [ 3,  9,  9]  1 */
    27710303, /* 69408 (1630) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 9,  9,  3]  1 */
     1542686, /* 69409 (1630) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 0,  6,  6]  1 */
    17131882, /* 69410 (1630) [ 0, -1,  0,  0,  0,  1, -1,  0,  0] [ 6,  0,  6]  1 */
    18426648, /* 69411 (1630) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
    26411385, /* 69412 (1630) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 9,  3,  9]  1 */
    17136274, /* 69413 (1630) [ 0,  1,  0,  0,  0,  1,  1,  0,  0] [ 6,  0,  6]  1 */
    27704791, /* 69414 (1630) [ 0,  0,  1,  1,  0,  0,  0, -1,  0] [ 9,  9,  3]  1 */
     1538530, /* 69415 (1630) [-1,  0,  0,  0,  0, -1,  0,  1,  0] [ 0,  6,  6]  1 */
     9278103, /* 69416 (1630) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 3,  3,  3]  1 */
    26407173, /* 69417 (1630) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 9,  3,  9]  1 */
    27701391, /* 69418 (1630) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 9,  9,  3]  1 */
    27710359, /* 69419 (1630) [ 1,  0,  0,  0,  0, -1,  0,  1,  0] [ 9,  9,  3]  1 */
    26405713, /* 69420 (1630) [ 0,  0,  1,  1,  0,  0,  0, -1,  0] [ 9,  3,  9]  1 */
    27704479, /* 69421 (1630) [ 0,  0,  1,  0, -1,  0,  1,  0,  0] [ 9,  9,  3]  1 */
     9278383, /* 69422 (1630) [ 0, -1,  0,  0,  0,  1,  1,  0,  0] [ 3,  3,  3]  1 */
    26402521, /* 69423 (1630) [ 0, -1,  0,  0,  0, -1, -1,  0,  0] [ 9,  3,  9]  1 */
    10814989, /* 69424 (1630) [ 0,  0, -1,  0, -1,  0, -1,  0,  0] [ 3,  9,  9]  1 */
    17140642, /* 69425 (1630) [ 1,  0,  0,  0,  0,  1,  0,  1,  0] [ 6,  0,  6]  1 */
        7636, /* 69426 (1630) [ 0, -1,  0,  0,  0, -1,  1,  0,  0] [ 0,  0,  0]  1 */
        9040, /* 69427 (1630) [ 0,  0, -1,  0, -1,  0,  1,  0,  0] [ 0,  0,  0]  1 */
     9273943, /* 69428 (1630) [-1,  0,  0,  0,  0, -1,  0, -1,  0] [ 3,  3,  3]  1 */
    18435072, /* 69429 (1630) [ 0,  1,  0, -1,  0,  0,  0,  0, -1] [ 6,  6,  0]  1 */
     1542910, /* 69430 (1630) [ 0, -1,  0,  0,  0, -1,  1,  0,  0] [ 0,  6,  6]  1 */
    27701879, /* 69431 (1630) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 9,  9,  3]  1 */
       16372, /* 69432 (1630) [ 1,  0,  0,  0,  0, -1,  0, -1,  0] [ 0,  0,  0]  1 */
     1545754, /* 69433 (1630) [ 0,  0,  1,  0, -1,  0, -1,  0,  0] [ 0,  6,  6]  1 */
    10816777, /* 69434 (1630) [ 0,  0,  1,  1,  0,  0,  0, -1,  0] [ 3,  9,  9]  1 */
    27697291, /* 69435 (1630) [-1,  0,  0,  0,  0,  1,  0,  1,  0] [ 9,  9,  3]  1 */
    26404261, /* 69436 (1630) [ 0,  0, -1,  1,  0,  0,  0,  1,  0] [ 9,  3,  9]  1 */
    26405545, /* 69437 (1630) [ 0,  0,  1,  0,  1,  0, -1,  0,  0] [ 9,  3,  9]  1 */
    10813377, /* 69438 (1630) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 3,  9,  9]  1 */
     9279895, /* 69439 (1630) [ 0,  0, -1,  0,  1,  0,  1,  0,  0] [ 3,  3,  3]  1 */
     1544146, /* 69440 (1630) [ 0,  0, -1, -1,  0,  0,  0,  1,  0] [ 0,  6,  6]  1 */
     1544626, /* 69441 (1630) [ 0,  0, -1,  1,  0,  0,  0, -1,  0] [ 0,  6,  6]  1 */
     1547266, /* 69442 (1630) [ 0,  1,  0,  0,  0, -1, -1,  0,  0] [ 0,  6,  6]  1 */
    26411329, /* 69443 (1630) [ 1,  0,  0,  0,  0,  1,  0, -1,  0] [ 9,  3,  9]  1 */
    17136202, /* 69444 (1630) [ 0,  1,  0,  0,  0, -1, -1,  0,  0] [ 6,  0,  6]  1 */
        3200, /* 69445 (1630) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
     1545598, /* 69446 (1630) [ 0,  0,  1, -1,  0,  0,  0, -1,  0] [ 0,  6,  6]  1 */
    18439608, /* 69447 (1630) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
    26405233, /* 69448 (1630) [ 0,  0,  1, -1,  0,  0,  0,  1,  0] [ 9,  3,  9]  1 */
    18432328, /* 69449 (1630) [ 0,  0, -1,  0, -1,  0,  1,  0,  0] [ 6,  6,  0]  1 */
        3360, /* 69450 (1630) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
       10324, /* 69451 (1630) [ 0,  0,  1, -1,  0,  0,  0, -1,  0] [ 0,  0,  0]  1 */
    17133250, /* 69452 (1630) [ 0,  0, -1,  0, -1,  0,  1,  0,  0] [ 6,  0,  6]  1 */
    10817977, /* 69453 (1630) [ 0,  1,  0,  0,  0, -1,  1,  0,  0] [ 3,  9,  9]  1 */
     9282703, /* 69454 (1630) [ 0,  1,  0,  0,  0, -1,  1,  0,  0] [ 3,  3,  3]  1 */
     9279559, /* 69455 (1630) [ 0,  0, -1, -1,  0,  0,  0, -1,  0] [ 3,  3,  3]  1 */
    27702847, /* 69456 (1630) [ 0,  0, -1, -1,  0,  0,  0, -1,  0] [ 9,  9,  3]  1 */
        7412, /* 69457 (1630) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  0]  1 */
     9287015, /* 69458 (1630) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 3,  3,  3]  1 */
    10822289, /* 69459 (1630) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 3,  9,  9]  1 */
    10818013, /* 69460 (1630) [ 0,  1,  0,  0,  0,  1, -1,  0,  0] [ 3,  9,  9]  1 */
    27706251, /* 69461 (1630) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 9,  9,  3]  1 */
    17134870, /* 69462 (1630) [ 0,  0,  1,  0,  1,  0,  1,  0,  0] [ 6,  0,  6]  1 */
    18439772, /* 69463 (1630) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
     9281191, /* 69464 (1630) [ 0,  0,  1,  0, -1,  0,  1,  0,  0] [ 3,  3,  3]  1 */
    10822345, /* 69465 (1630) [ 1,  0,  0,  0,  0, -1,  0,  1,  0] [ 3,  9,  9]  1 */
    26398101, /* 69466 (1630) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 9,  3,  9]  1 */
    17127410, /* 69467 (1630) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
    18426488, /* 69468 (1630) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    26402593, /* 69469 (1630) [ 0, -1,  0,  0,  0,  1,  1,  0,  0] [ 9,  3,  9]  1 */
    26403925, /* 69470 (1630) [ 0,  0, -1,  0, -1,  0, -1,  0,  0] [ 9,  3,  9]  1 */
    17135994, /* 69471 (1630) [ 0,  1,  0, -1,  0,  0,  0,  0, -1] [ 6,  0,  6]  1 */
     1544458, /* 69472 (1630) [ 0,  0, -1,  0,  1,  0, -1,  0,  0] [ 0,  6,  6]  1 */
    18435352, /* 69473 (1630) [ 0,  1,  0,  0,  0,  1,  1,  0,  0] [ 6,  6,  0]  1 */
    18430700, /* 69474 (1630) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    10814833, /* 69475 (1630) [ 0,  0, -1, -1,  0,  0,  0, -1,  0] [ 3,  9,  9]  1 */
     9287175, /* 69476 (1630) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 3,  3,  3]  1 */
    18426544, /* 69477 (1630) [-1,  0,  0,  0,  0, -1,  0,  1,  0] [ 6,  6,  0]  1 */
       10816, /* 69478 (1630) [ 0,  0,  1,  1,  0,  0,  0,  1,  0] [ 0,  0,  0]  1 */
    18434104, /* 69479 (1630) [ 0,  0,  1,  1,  0,  0,  0,  1,  0] [ 6,  6,  0]  1 */
    18435560, /* 69480 (1630) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 6,  6,  0]  1 */
     9278591, /* 69481 (1630) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 3,  3,  3]  1 */
     9282963, /* 69482 (1630) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 3,  3,  3]  1 */
        9184, /* 69483 (1630) [ 0,  0, -1,  0,  1,  0, -1,  0,  0] [ 0,  0,  0]  1 */
    10818237, /* 69484 (1630) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 3,  9,  9]  1 */
       12064, /* 69485 (1630) [ 0,  1,  0,  0,  0,  1,  1,  0,  0] [ 0,  0,  0]  1 */
    27697343, /* 69486 (1630) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 9,  9,  3]  1 */
    10809277, /* 69487 (1630) [-1,  0,  0,  0,  0,  1,  0,  1,  0] [ 3,  9,  9]  1 */
     1551646, /* 69488 (1630) [ 1,  0,  0,  0,  0, -1,  0, -1,  0] [ 0,  6,  6]  1 */
    18433768, /* 69489 (1630) [ 0,  0,  1,  0, -1,  0, -1,  0,  0] [ 6,  6,  0]  1 */
     1551758, /* 69490 (1630) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
    17133562, /* 69491 (1630) [ 0,  0, -1,  1,  0,  0,  0, -1,  0] [ 6,  0,  6]  1 */
     9281503, /* 69492 (1630) [ 0,  0,  1,  1,  0,  0,  0, -1,  0] [ 3,  3,  3]  1 */
    10815169, /* 69493 (1630) [ 0,  0, -1,  0,  1,  0,  1,  0,  0] [ 3,  9,  9]  1 */
    17131846, /* 69494 (1630) [ 0, -1,  0,  0,  0, -1,  1,  0,  0] [ 6,  0,  6]  1 */
    18439720, /* 69495 (1630) [ 1,  0,  0,  0,  0,  1,  0,  1,  0] [ 6,  6,  0]  1 */
    18433612, /* 69496 (1630) [ 0,  0,  1, -1,  0,  0,  0, -1,  0] [ 6,  6,  0]  1 */
       11992, /* 69497 (1630) [ 0,  1,  0,  0,  0, -1, -1,  0,  0] [ 0,  0,  0]  1 */
     9282479, /* 69498 (1630) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 3,  3,  3]  1 */
    27705767, /* 69499 (1630) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 9,  9,  3]  1 */
    26411225, /* 69500 (1630) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 9,  3,  9]  1 */
    17136482, /* 69501 (1630) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 6,  0,  6]  1 */
        7672, /* 69502 (1630) [ 0, -1,  0,  0,  0,  1, -1,  0,  0] [ 0,  0,  0]  1 */
    26398153, /* 69503 (1630) [-1,  0,  0,  0,  0, -1,  0, -1,  0] [ 9,  3,  9]  1 */
     1547546, /* 69504 (1630) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 0,  6,  6]  1 */
     1546090, /* 69505 (1630) [ 0,  0,  1,  1,  0,  0,  0,  1,  0] [ 0,  6,  6]  1 */
     9281335, /* 69506 (1630) [ 0,  0,  1,  0,  1,  0, -1,  0,  0] [ 3,  3,  3]  1 */
    17127514, /* 69507 (1630) [-1,  0,  0,  0,  0,  1,  0, -1,  0] [ 6,  0,  6]  1 */
     1538578, /* 69508 (1630) [-1,  0,  0,  0,  0,  1,  0, -1,  0] [ 0,  6,  6]  1 */
    27710463, /* 69509 (1630) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 9,  9,  3]  1 */
     9287119, /* 69510 (1630) [ 1,  0,  0,  0,  0,  1,  0, -1,  0] [ 3,  3,  3]  1 */
        3256, /* 69511 (1630) [-1,  0,  0,  0,  0, -1,  0,  1,  0] [ 0,  0,  0]  1 */
    26405401, /* 69512 (1630) [ 0,  0,  1,  0, -1,  0,  1,  0,  0] [ 9,  3,  9]  1 */
     9282739, /* 69513 (1630) [ 0,  1,  0,  0,  0,  1, -1,  0,  0] [ 3,  3,  3]  1 */
     1551706, /* 69514 (1630) [ 1,  0,  0,  0,  0,  1,  0,  1,  0] [ 0,  6,  6]  1 */
    27701671, /* 69515 (1630) [ 0, -1,  0,  0,  0,  1,  1,  0,  0] [ 9,  9,  3]  1 */
    10816465, /* 69516 (1630) [ 0,  0,  1,  0, -1,  0,  1,  0,  0] [ 3,  9,  9]  1 */
     9287071, /* 69517 (1630) [ 1,  0,  0,  0,  0, -1,  0,  1,  0] [ 3,  3,  3]  1 */
       11784, /* 69518 (1630) [ 0,  1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    18432472, /* 69519 (1630) [ 0,  0, -1,  0,  1,  0, -1,  0,  0] [ 6,  6,  0]  1 */
    26402313, /* 69520 (1630) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 9,  3,  9]  1 */
    18439660, /* 69521 (1630) [ 1,  0,  0,  0,  0, -1,  0, -1,  0] [ 6,  6,  0]  1 */
    17131622, /* 69522 (1630) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 6,  0,  6]  1 */
    26403769, /* 69523 (1630) [ 0,  0, -1, -1,  0,  0,  0, -1,  0] [ 9,  3,  9]  1 */
    26404105, /* 69524 (1630) [ 0,  0, -1,  0,  1,  0,  1,  0,  0] [ 9,  3,  9]  1 */
       12272, /* 69525 (1630) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 0,  0,  0]  1 */
        9352, /* 69526 (1630) [ 0,  0, -1,  1,  0,  0,  0, -1,  0] [ 0,  0,  0]  1 */
    10822449, /* 69527 (1630) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 3,  9,  9]  1 */
    17134690, /* 69528 (1630) [ 0,  0,  1,  0, -1,  0, -1,  0,  0] [ 6,  0,  6]  1 */
    18435280, /* 69529 (1630) [ 0,  1,  0,  0,  0, -1, -1,  0,  0] [ 6,  6,  0]  1 */
    17127466, /* 69530 (1630) [-1,  0,  0,  0,  0, -1,  0,  1,  0] [ 6,  0,  6]  1 */
    27703339, /* 69531 (1630) [ 0,  0, -1,  1,  0,  0,  0,  1,  0] [ 9,  9,  3]  1 */
    27704623, /* 69532 (1630) [ 0,  0,  1,  0,  1,  0, -1,  0,  0] [ 9,  9,  3]  1 */
    10813865, /* 69533 (1630) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 3,  9,  9]  1 */
     9274055, /* 69534 (1630) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 3,  3,  3]  1 */
    17132106, /* 69535 (1630) [ 0, -1,  0,  1,  0,  0,  0,  0, -1] [ 6,  0,  6]  1 */
        8872, /* 69536 (1630) [ 0,  0, -1, -1,  0,  0,  0,  1,  0] [ 0,  0,  0]  1 */
     9278311, /* 69537 (1630) [ 0, -1,  0,  0,  0, -1, -1,  0,  0] [ 3,  3,  3]  1 */
    27701599, /* 69538 (1630) [ 0, -1,  0,  0,  0, -1, -1,  0,  0] [ 9,  9,  3]  1 */
    10809329, /* 69539 (1630) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 3,  9,  9]  1 */
     1543170, /* 69540 (1630) [ 0, -1,  0,  1,  0,  0,  0,  0, -1] [ 0,  6,  6]  1 */
    27710407, /* 69541 (1630) [ 1,  0,  0,  0,  0,  1,  0, -1,  0] [ 9,  9,  3]  1 */
     9274003, /* 69542 (1630) [-1,  0,  0,  0,  0,  1,  0,  1,  0] [ 3,  3,  3]  1 */
    18433948, /* 69543 (1630) [ 0,  0,  1,  0,  1,  0,  1,  0,  0] [ 6,  6,  0]  1 */
    18432640, /* 69544 (1630) [ 0,  0, -1,  1,  0,  0,  0, -1,  0] [ 6,  6,  0]  1 */
    18430924, /* 69545 (1630) [ 0, -1,  0,  0,  0, -1,  1,  0,  0] [ 6,  6,  0]  1 */
    27697179, /* 69546 (1630) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 9,  9,  3]  1 */
     1551594, /* 69547 (1630) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
     1542946, /* 69548 (1630) [ 0, -1,  0,  0,  0,  1, -1,  0,  0] [ 0,  6,  6]  1 */
    17140530, /* 69549 (1630) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  6]  1 */
    27704311, /* 69550 (1630) [ 0,  0,  1, -1,  0,  0,  0,  1,  0] [ 9,  9,  3]  1 */
    26406913, /* 69551 (1630) [ 0,  1,  0,  0,  0, -1,  1,  0,  0] [ 9,  3,  9]  1 */
     1538634, /* 69552 (1630) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
     1547338, /* 69553 (1630) [ 0,  1,  0,  0,  0,  1,  1,  0,  0] [ 0,  6,  6]  1 */
    10817753, /* 69554 (1630) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 3,  9,  9]  1 */
    17135026, /* 69555 (1630) [ 0,  0,  1,  1,  0,  0,  0,  1,  0] [ 6,  0,  6]  1 */
    18426592, /* 69556 (1630) [-1,  0,  0,  0,  0,  1,  0, -1,  0] [ 6,  6,  0]  1 */
    18432160, /* 69557 (1630) [ 0,  0, -1, -1,  0,  0,  0,  1,  0] [ 6,  6,  0]  1 */
    10816609, /* 69558 (1630) [ 0,  0,  1,  0,  1,  0, -1,  0,  0] [ 3,  9,  9]  1 */
    17133082, /* 69559 (1630) [ 0,  0, -1, -1,  0,  0,  0,  1,  0] [ 6,  0,  6]  1 */
    10813585, /* 69560 (1630) [ 0, -1,  0,  0,  0, -1, -1,  0,  0] [ 3,  9,  9]  1 */
    10822393, /* 69561 (1630) [ 1,  0,  0,  0,  0,  1,  0, -1,  0] [ 3,  9,  9]  1 */
     1545934, /* 69562 (1630) [ 0,  0,  1,  0,  1,  0,  1,  0,  0] [ 0,  6,  6]  1 */
    26411281, /* 69563 (1630) [ 1,  0,  0,  0,  0, -1,  0,  1,  0] [ 9,  3,  9]  1 */
    10813657, /* 69564 (1630) [ 0, -1,  0,  0,  0,  1,  1,  0,  0] [ 3,  9,  9]  1 */
    10809165, /* 69565 (1630) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 3,  9,  9]  1 */
     1544314, /* 69566 (1630) [ 0,  0, -1,  0, -1,  0,  1,  0,  0] [ 0,  6,  6]  1 */
    27697231, /* 69567 (1630) [-1,  0,  0,  0,  0, -1,  0, -1,  0] [ 9,  9,  3]  1 */
    17140582, /* 69568 (1630) [ 1,  0,  0,  0,  0, -1,  0, -1,  0] [ 6,  0,  6]  1 */
    26402801, /* 69569 (1630) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 9,  3,  9]  1 */
     1547058, /* 69570 (1630) [ 0,  1,  0, -1,  0,  0,  0,  0, -1] [ 0,  6,  6]  1 */
    26398265, /* 69571 (1630) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 9,  3,  9]  1 */
    27703183, /* 69572 (1630) [ 0,  0, -1,  0,  1,  0,  1,  0,  0] [ 9,  9,  3]  1 */
    17133394, /* 69573 (1630) [ 0,  0, -1,  0,  1,  0, -1,  0,  0] [ 6,  0,  6]  1 */
       10480, /* 69574 (1630) [ 0,  0,  1,  0, -1,  0, -1,  0,  0] [ 0,  0,  0]  1 */
    26398213, /* 69575 (1630) [-1,  0,  0,  0,  0,  1,  0,  1,  0] [ 9,  3,  9]  1 */
     9280051, /* 69576 (1630) [ 0,  0, -1,  1,  0,  0,  0,  1,  0] [ 3,  3,  3]  1 */
    10815325, /* 69577 (1630) [ 0,  0, -1,  1,  0,  0,  0,  1,  0] [ 3,  9,  9]  1 */
    27706027, /* 69578 (1630) [ 0,  1,  0,  0,  0,  1, -1,  0,  0] [ 9,  9,  3]  1 */
       16484, /* 69579 (1631) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    17127570, /* 69580 (1631) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6]  1 */
    17140694, /* 69581 (1631) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
     9279715, /* 69582 (1631) [ 0,  0, -1,  0, -1,  0, -1,  0,  0] [ 3,  3,  3]  1 */
    27703003, /* 69583 (1631) [ 0,  0, -1,  0, -1,  0, -1,  0,  0] [ 9,  9,  3]  1 */
    27705991, /* 69584 (1631) [ 0,  1,  0,  0,  0, -1,  1,  0,  0] [ 9,  9,  3]  1 */
    26406949, /* 69585 (1631) [ 0,  1,  0,  0,  0,  1, -1,  0,  0] [ 9,  3,  9]  1 */
    52451996, /* 69586 (1631) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
     9273891, /* 69587 (1631) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 3,  3,  3]  1 */
    10809217, /* 69588 (1631) [-1,  0,  0,  0,  0, -1,  0, -1,  0] [ 3,  9,  9]  1 */
    61713895, /* 69589 (1631) [ 0, -1,  0,  0,  0,  1,  1,  0,  0] [ 9,  9,  3] -1 */
    10816297, /* 69590 (1631) [ 0,  0,  1, -1,  0,  0,  0,  1,  0] [ 3,  9,  9]  1 */
    43299295, /* 69591 (1631) [ 1,  0,  0,  0,  0, -1,  0,  1,  0] [ 3,  3,  3] -1 */
     1542686, /* 69592 (1631) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 0,  6,  6]  1 */
    17136274, /* 69593 (1631) [ 0,  1,  0,  0,  0,  1,  1,  0,  0] [ 6,  0,  6]  1 */
    51148218, /* 69594 (1631) [ 0,  1,  0, -1,  0,  0,  0,  0, -1] [ 6,  0,  6] -1 */
    52447576, /* 69595 (1631) [ 0,  1,  0,  0,  0,  1,  1,  0,  0] [ 6,  6,  0] -1 */
    27710359, /* 69596 (1631) [ 1,  0,  0,  0,  0, -1,  0,  1,  0] [ 9,  9,  3]  1 */
    27704479, /* 69597 (1631) [ 0,  0,  1,  0, -1,  0,  1,  0,  0] [ 9,  9,  3]  1 */
    34024496, /* 69598 (1631) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    52447784, /* 69599 (1631) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 6,  6,  0] -1 */
    52447504, /* 69600 (1631) [ 0,  1,  0,  0,  0, -1, -1,  0,  0] [ 6,  6,  0] -1 */
    44821501, /* 69601 (1631) [-1,  0,  0,  0,  0,  1,  0,  1,  0] [ 3,  9,  9] -1 */
    51145786, /* 69602 (1631) [ 0,  0, -1,  1,  0,  0,  0, -1,  0] [ 6,  0,  6] -1 */
    51144070, /* 69603 (1631) [ 0, -1,  0,  0,  0, -1,  1,  0,  0] [ 6,  0,  6] -1 */
    10813377, /* 69604 (1631) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 3,  9,  9]  1 */
     9279895, /* 69605 (1631) [ 0,  0, -1,  0,  1,  0,  1,  0,  0] [ 3,  3,  3]  1 */
    60423449, /* 69606 (1631) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 9,  3,  9] -1 */
    44829977, /* 69607 (1631) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 3,  9,  9] -1 */
    51139738, /* 69608 (1631) [-1,  0,  0,  0,  0,  1,  0, -1,  0] [ 6,  0,  6] -1 */
       10324, /* 69609 (1631) [ 0,  0,  1, -1,  0,  0,  0, -1,  0] [ 0,  0,  0]  1 */
    17133250, /* 69610 (1631) [ 0,  0, -1,  0, -1,  0,  1,  0,  0] [ 6,  0,  6]  1 */
     9282703, /* 69611 (1631) [ 0,  1,  0,  0,  0, -1,  1,  0,  0] [ 3,  3,  3]  1 */
        7412, /* 69612 (1631) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    35556538, /* 69613 (1631) [ 0,  0, -1,  0, -1,  0,  1,  0,  0] [ 0,  6,  6] -1 */
    60415025, /* 69614 (1631) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 9,  3,  9] -1 */
    18439772, /* 69615 (1631) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    52451884, /* 69616 (1631) [ 1,  0,  0,  0,  0, -1,  0, -1,  0] [ 6,  6,  0] -1 */
    17127410, /* 69617 (1631) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
    26402593, /* 69618 (1631) [ 0, -1,  0,  0,  0,  1,  1,  0,  0] [ 9,  3,  9]  1 */
    17135994, /* 69619 (1631) [ 0,  1,  0, -1,  0,  0,  0,  0, -1] [ 6,  0,  6]  1 */
    43290535, /* 69620 (1631) [ 0, -1,  0,  0,  0, -1, -1,  0,  0] [ 3,  3,  3] -1 */
    61713823, /* 69621 (1631) [ 0, -1,  0,  0,  0, -1, -1,  0,  0] [ 9,  9,  3] -1 */
    18435352, /* 69622 (1631) [ 0,  1,  0,  0,  0,  1,  1,  0,  0] [ 6,  6,  0]  1 */
    18430700, /* 69623 (1631) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    18435560, /* 69624 (1631) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    43293247, /* 69625 (1631) [ 0,  0,  1, -1,  0,  0,  0,  1,  0] [ 3,  3,  3] -1 */
    61716535, /* 69626 (1631) [ 0,  0,  1, -1,  0,  0,  0,  1,  0] [ 9,  9,  3] -1 */
    52443184, /* 69627 (1631) [ 0, -1,  0,  0,  0,  1, -1,  0,  0] [ 6,  6,  0] -1 */
    10809277, /* 69628 (1631) [-1,  0,  0,  0,  0,  1,  0,  1,  0] [ 3,  9,  9]  1 */
    17133562, /* 69629 (1631) [ 0,  0, -1,  1,  0,  0,  0, -1,  0] [ 6,  0,  6]  1 */
    17131846, /* 69630 (1631) [ 0, -1,  0,  0,  0, -1,  1,  0,  0] [ 6,  0,  6]  1 */
    61713615, /* 69631 (1631) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 9,  9,  3] -1 */
    51145306, /* 69632 (1631) [ 0,  0, -1, -1,  0,  0,  0,  1,  0] [ 6,  0,  6] -1 */
    26411225, /* 69633 (1631) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 9,  3,  9]  1 */
    44827213, /* 69634 (1631) [ 0,  0, -1,  0, -1,  0, -1,  0,  0] [ 3,  9,  9] -1 */
    17127514, /* 69635 (1631) [-1,  0,  0,  0,  0,  1,  0, -1,  0] [ 6,  0,  6]  1 */
    44821389, /* 69636 (1631) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 3,  9,  9] -1 */
     1538578, /* 69637 (1631) [-1,  0,  0,  0,  0,  1,  0, -1,  0] [ 0,  6,  6]  1 */
    27710463, /* 69638 (1631) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 9,  9,  3]  1 */
        3256, /* 69639 (1631) [-1,  0,  0,  0,  0, -1,  0,  1,  0] [ 0,  0,  0]  1 */
    35555134, /* 69640 (1631) [ 0, -1,  0,  0,  0, -1,  1,  0,  0] [ 0,  6,  6] -1 */
     9282739, /* 69641 (1631) [ 0,  1,  0,  0,  0,  1, -1,  0,  0] [ 3,  3,  3]  1 */
    60410489, /* 69642 (1631) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 9,  3,  9] -1 */
    51145618, /* 69643 (1631) [ 0,  0, -1,  0,  1,  0, -1,  0,  0] [ 6,  0,  6] -1 */
    10816465, /* 69644 (1631) [ 0,  0,  1,  0, -1,  0,  1,  0,  0] [ 3,  9,  9]  1 */
    34015424, /* 69645 (1631) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    35557822, /* 69646 (1631) [ 0,  0,  1, -1,  0,  0,  0, -1,  0] [ 0,  6,  6] -1 */
    52444552, /* 69647 (1631) [ 0,  0, -1,  0, -1,  0,  1,  0,  0] [ 6,  6,  0] -1 */
    51146758, /* 69648 (1631) [ 0,  0,  1, -1,  0,  0,  0, -1,  0] [ 6,  0,  6] -1 */
    34015584, /* 69649 (1631) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    26402313, /* 69650 (1631) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 9,  3,  9]  1 */
    18439660, /* 69651 (1631) [ 1,  0,  0,  0,  0, -1,  0, -1,  0] [ 6,  6,  0]  1 */
    35550698, /* 69652 (1631) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
    27704623, /* 69653 (1631) [ 0,  0,  1,  0,  1,  0, -1,  0,  0] [ 9,  9,  3]  1 */
     9278311, /* 69654 (1631) [ 0, -1,  0,  0,  0, -1, -1,  0,  0] [ 3,  3,  3]  1 */
    27701599, /* 69655 (1631) [ 0, -1,  0,  0,  0, -1, -1,  0,  0] [ 9,  9,  3]  1 */
    27704311, /* 69656 (1631) [ 0,  0,  1, -1,  0,  0,  0,  1,  0] [ 9,  9,  3]  1 */
    60416149, /* 69657 (1631) [ 0,  0, -1,  0, -1,  0, -1,  0,  0] [ 9,  3,  9] -1 */
    17133082, /* 69658 (1631) [ 0,  0, -1, -1,  0,  0,  0,  1,  0] [ 6,  0,  6]  1 */
    10822393, /* 69659 (1631) [ 1,  0,  0,  0,  0,  1,  0, -1,  0] [ 3,  9,  9]  1 */
    34028596, /* 69660 (1631) [ 1,  0,  0,  0,  0, -1,  0, -1,  0] [ 0,  0,  0] -1 */
    44829001, /* 69661 (1631) [ 0,  0,  1,  1,  0,  0,  0, -1,  0] [ 3,  9,  9] -1 */
    61709515, /* 69662 (1631) [-1,  0,  0,  0,  0,  1,  0,  1,  0] [ 9,  9,  3] -1 */
    60416485, /* 69663 (1631) [ 0,  0, -1,  1,  0,  0,  0,  1,  0] [ 9,  3,  9] -1 */
    35556370, /* 69664 (1631) [ 0,  0, -1, -1,  0,  0,  0,  1,  0] [ 0,  6,  6] -1 */
    10813657, /* 69665 (1631) [ 0, -1,  0,  0,  0,  1,  1,  0,  0] [ 3,  9,  9]  1 */
    10809165, /* 69666 (1631) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 3,  9,  9]  1 */
    52451832, /* 69667 (1631) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
    61717991, /* 69668 (1631) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 9,  9,  3] -1 */
    26398265, /* 69669 (1631) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 9,  3,  9]  1 */
    17133394, /* 69670 (1631) [ 0,  0, -1,  0,  1,  0, -1,  0,  0] [ 6,  0,  6]  1 */
    43291783, /* 69671 (1631) [ 0,  0, -1, -1,  0,  0,  0, -1,  0] [ 3,  3,  3] -1 */
    44834513, /* 69672 (1631) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 3,  9,  9] -1 */
       10660, /* 69673 (1631) [ 0,  0,  1,  0,  1,  0,  1,  0,  0] [ 0,  0,  0]  1 */
    17134534, /* 69674 (1631) [ 0,  0,  1, -1,  0,  0,  0, -1,  0] [ 6,  0,  6]  1 */
    26406689, /* 69675 (1631) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 9,  3,  9]  1 */
     1538474, /* 69676 (1631) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
    60410325, /* 69677 (1631) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 9,  3,  9] -1 */
    52438712, /* 69678 (1631) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
    60416329, /* 69679 (1631) [ 0,  0, -1,  0,  1,  0,  1,  0,  0] [ 9,  3,  9] -1 */
    51146914, /* 69680 (1631) [ 0,  0,  1,  0, -1,  0, -1,  0,  0] [ 6,  0,  6] -1 */
    44826089, /* 69681 (1631) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 3,  9,  9] -1 */
    44830461, /* 69682 (1631) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 3,  9,  9] -1 */
    34024288, /* 69683 (1631) [ 0,  1,  0,  0,  0,  1,  1,  0,  0] [ 0,  0,  0] -1 */
    17140642, /* 69684 (1631) [ 1,  0,  0,  0,  0,  1,  0,  1,  0] [ 6,  0,  6]  1 */
    52445992, /* 69685 (1631) [ 0,  0,  1,  0, -1,  0, -1,  0,  0] [ 6,  6,  0] -1 */
    61722631, /* 69686 (1631) [ 1,  0,  0,  0,  0,  1,  0, -1,  0] [ 9,  9,  3] -1 */
    43286227, /* 69687 (1631) [-1,  0,  0,  0,  0,  1,  0,  1,  0] [ 3,  3,  3] -1 */
    52451944, /* 69688 (1631) [ 1,  0,  0,  0,  0,  1,  0,  1,  0] [ 6,  6,  0] -1 */
    52443148, /* 69689 (1631) [ 0, -1,  0,  0,  0, -1,  1,  0,  0] [ 6,  6,  0] -1 */
       16372, /* 69690 (1631) [ 1,  0,  0,  0,  0, -1,  0, -1,  0] [ 0,  0,  0]  1 */
    51152754, /* 69691 (1631) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  6] -1 */
    10816777, /* 69692 (1631) [ 0,  0,  1,  1,  0,  0,  0, -1,  0] [ 3,  9,  9]  1 */
    35555170, /* 69693 (1631) [ 0, -1,  0,  0,  0,  1, -1,  0,  0] [ 0,  6,  6] -1 */
    27697291, /* 69694 (1631) [-1,  0,  0,  0,  0,  1,  0,  1,  0] [ 9,  9,  3]  1 */
    26404261, /* 69695 (1631) [ 0,  0, -1,  1,  0,  0,  0,  1,  0] [ 9,  3,  9]  1 */
    60419137, /* 69696 (1631) [ 0,  1,  0,  0,  0, -1,  1,  0,  0] [ 9,  3,  9] -1 */
     1544146, /* 69697 (1631) [ 0,  0, -1, -1,  0,  0,  0,  1,  0] [ 0,  6,  6]  1 */
    26411329, /* 69698 (1631) [ 1,  0,  0,  0,  0,  1,  0, -1,  0] [ 9,  3,  9]  1 */
    34019896, /* 69699 (1631) [ 0, -1,  0,  0,  0,  1, -1,  0,  0] [ 0,  0,  0] -1 */
    35558314, /* 69700 (1631) [ 0,  0,  1,  1,  0,  0,  0,  1,  0] [ 0,  6,  6] -1 */
    52444384, /* 69701 (1631) [ 0,  0, -1, -1,  0,  0,  0,  1,  0] [ 6,  6,  0] -1 */
    44828833, /* 69702 (1631) [ 0,  0,  1,  0,  1,  0, -1,  0,  0] [ 3,  9,  9] -1 */
    43299343, /* 69703 (1631) [ 1,  0,  0,  0,  0,  1,  0, -1,  0] [ 3,  3,  3] -1 */
    18439608, /* 69704 (1631) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
     9279559, /* 69705 (1631) [ 0,  0, -1, -1,  0,  0,  0, -1,  0] [ 3,  3,  3]  1 */
    27702847, /* 69706 (1631) [ 0,  0, -1, -1,  0,  0,  0, -1,  0] [ 9,  9,  3]  1 */
    10822289, /* 69707 (1631) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 3,  9,  9]  1 */
    34028708, /* 69708 (1631) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
     9281191, /* 69709 (1631) [ 0,  0,  1,  0, -1,  0,  1,  0,  0] [ 3,  3,  3]  1 */
    26398101, /* 69710 (1631) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 9,  3,  9]  1 */
    34021576, /* 69711 (1631) [ 0,  0, -1,  1,  0,  0,  0, -1,  0] [ 0,  0,  0] -1 */
    18426488, /* 69712 (1631) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    44821553, /* 69713 (1631) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 3,  9,  9] -1 */
    10818237, /* 69714 (1631) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 3,  9,  9]  1 */
    34015528, /* 69715 (1631) [-1,  0,  0,  0,  0,  1,  0, -1,  0] [ 0,  0,  0] -1 */
       12064, /* 69716 (1631) [ 0,  1,  0,  0,  0,  1,  1,  0,  0] [ 0,  0,  0]  1 */
    18433768, /* 69717 (1631) [ 0,  0,  1,  0, -1,  0, -1,  0,  0] [ 6,  6,  0]  1 */
    18439720, /* 69718 (1631) [ 1,  0,  0,  0,  0,  1,  0,  1,  0] [ 6,  6,  0]  1 */
    60419397, /* 69719 (1631) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 9,  3,  9] -1 */
    51147250, /* 69720 (1631) [ 0,  0,  1,  1,  0,  0,  0,  1,  0] [ 6,  0,  6] -1 */
    60417937, /* 69721 (1631) [ 0,  0,  1,  1,  0,  0,  0, -1,  0] [ 9,  3,  9] -1 */
    35558158, /* 69722 (1631) [ 0,  0,  1,  0,  1,  0,  1,  0,  0] [ 0,  6,  6] -1 */
        7672, /* 69723 (1631) [ 0, -1,  0,  0,  0,  1, -1,  0,  0] [ 0,  0,  0]  1 */
    26398153, /* 69724 (1631) [-1,  0,  0,  0,  0, -1,  0, -1,  0] [ 9,  3,  9]  1 */
     1546090, /* 69725 (1631) [ 0,  0,  1,  1,  0,  0,  0,  1,  0] [ 0,  6,  6]  1 */
    43286167, /* 69726 (1631) [-1,  0,  0,  0,  0, -1,  0, -1,  0] [ 3,  3,  3] -1 */
    61709455, /* 69727 (1631) [-1,  0,  0,  0,  0, -1,  0, -1,  0] [ 9,  9,  3] -1 */
     9287119, /* 69728 (1631) [ 1,  0,  0,  0,  0,  1,  0, -1,  0] [ 3,  3,  3]  1 */
    51152806, /* 69729 (1631) [ 1,  0,  0,  0,  0, -1,  0, -1,  0] [ 6,  0,  6] -1 */
    60417769, /* 69730 (1631) [ 0,  0,  1,  0,  1,  0, -1,  0,  0] [ 9,  3,  9] -1 */
    27701671, /* 69731 (1631) [ 0, -1,  0,  0,  0,  1,  1,  0,  0] [ 9,  9,  3]  1 */
    35559282, /* 69732 (1631) [ 0,  1,  0, -1,  0,  0,  0,  0, -1] [ 0,  6,  6] -1 */
    51148426, /* 69733 (1631) [ 0,  1,  0,  0,  0, -1, -1,  0,  0] [ 6,  0,  6] -1 */
    34022704, /* 69734 (1631) [ 0,  0,  1,  0, -1,  0, -1,  0,  0] [ 0,  0,  0] -1 */
     9287071, /* 69735 (1631) [ 1,  0,  0,  0,  0, -1,  0,  1,  0] [ 3,  3,  3]  1 */
    44827549, /* 69736 (1631) [ 0,  0, -1,  1,  0,  0,  0,  1,  0] [ 3,  9,  9] -1 */
    34020120, /* 69737 (1631) [ 0, -1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    44830201, /* 69738 (1631) [ 0,  1,  0,  0,  0, -1,  1,  0,  0] [ 3,  9,  9] -1 */
       12272, /* 69739 (1631) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 0,  0,  0]  1 */
        9352, /* 69740 (1631) [ 0,  0, -1,  1,  0,  0,  0, -1,  0] [ 0,  0,  0]  1 */
    18435280, /* 69741 (1631) [ 0,  1,  0,  0,  0, -1, -1,  0,  0] [ 6,  6,  0]  1 */
    43299239, /* 69742 (1631) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 3,  3,  3] -1 */
    34028544, /* 69743 (1631) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    61722527, /* 69744 (1631) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 9,  9,  3] -1 */
    10809329, /* 69745 (1631) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 3,  9,  9]  1 */
    43290327, /* 69746 (1631) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 3,  3,  3] -1 */
    43290607, /* 69747 (1631) [ 0, -1,  0,  0,  0,  1,  1,  0,  0] [ 3,  3,  3] -1 */
    10817753, /* 69748 (1631) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 3,  9,  9]  1 */
    34019860, /* 69749 (1631) [ 0, -1,  0,  0,  0, -1,  1,  0,  0] [ 0,  0,  0] -1 */
    17135026, /* 69750 (1631) [ 0,  0,  1,  1,  0,  0,  0,  1,  0] [ 6,  0,  6]  1 */
    34021264, /* 69751 (1631) [ 0,  0, -1,  0, -1,  0,  1,  0,  0] [ 0,  0,  0] -1 */
    44827057, /* 69752 (1631) [ 0,  0, -1, -1,  0,  0,  0, -1,  0] [ 3,  9,  9] -1 */
    43295187, /* 69753 (1631) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 3,  3,  3] -1 */
    61714103, /* 69754 (1631) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 9,  9,  3] -1 */
    34021408, /* 69755 (1631) [ 0,  0, -1,  0,  1,  0, -1,  0,  0] [ 0,  0,  0] -1 */
     1545934, /* 69756 (1631) [ 0,  0,  1,  0,  1,  0,  1,  0,  0] [ 0,  6,  6]  1 */
    43293727, /* 69757 (1631) [ 0,  0,  1,  1,  0,  0,  0, -1,  0] [ 3,  3,  3] -1 */
    44827393, /* 69758 (1631) [ 0,  0, -1,  0,  1,  0,  1,  0,  0] [ 3,  9,  9] -1 */
     1544314, /* 69759 (1631) [ 0,  0, -1,  0, -1,  0,  1,  0,  0] [ 0,  6,  6]  1 */
    27697231, /* 69760 (1631) [-1,  0,  0,  0,  0, -1,  0, -1,  0] [ 9,  9,  3]  1 */
    17140582, /* 69761 (1631) [ 1,  0,  0,  0,  0, -1,  0, -1,  0] [ 6,  0,  6]  1 */
    26402801, /* 69762 (1631) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 9,  3,  9]  1 */
     1547058, /* 69763 (1631) [ 0,  1,  0, -1,  0,  0,  0,  0, -1] [ 0,  6,  6]  1 */
       10480, /* 69764 (1631) [ 0,  0,  1,  0, -1,  0, -1,  0,  0] [ 0,  0,  0]  1 */
    43293559, /* 69765 (1631) [ 0,  0,  1,  0,  1,  0, -1,  0,  0] [ 3,  3,  3] -1 */
    10815325, /* 69766 (1631) [ 0,  0, -1,  1,  0,  0,  0,  1,  0] [ 3,  9,  9]  1 */
        7896, /* 69767 (1631) [ 0, -1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    44830237, /* 69768 (1631) [ 0,  1,  0,  0,  0,  1, -1,  0,  0] [ 3,  9,  9] -1 */
    51147094, /* 69769 (1631) [ 0,  0,  1,  0,  1,  0,  1,  0,  0] [ 6,  0,  6] -1 */
     9281023, /* 69770 (1631) [ 0,  0,  1, -1,  0,  0,  0,  1,  0] [ 3,  3,  3]  1 */
    18430960, /* 69771 (1631) [ 0, -1,  0,  0,  0,  1, -1,  0,  0] [ 6,  6,  0]  1 */
       16320, /* 69772 (1631) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    27710303, /* 69773 (1631) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 9,  9,  3]  1 */
     9278103, /* 69774 (1631) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 3,  3,  3]  1 */
    27701391, /* 69775 (1631) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 9,  9,  3]  1 */
    51143846, /* 69776 (1631) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 6,  0,  6] -1 */
     9278383, /* 69777 (1631) [ 0, -1,  0,  0,  0,  1,  1,  0,  0] [ 3,  3,  3]  1 */
    43286279, /* 69778 (1631) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 3,  3,  3] -1 */
    10814989, /* 69779 (1631) [ 0,  0, -1,  0, -1,  0, -1,  0,  0] [ 3,  9,  9]  1 */
    61709567, /* 69780 (1631) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 9,  9,  3] -1 */
    35555394, /* 69781 (1631) [ 0, -1,  0,  1,  0,  0,  0,  0, -1] [ 0,  6,  6] -1 */
        7636, /* 69782 (1631) [ 0, -1,  0,  0,  0, -1,  1,  0,  0] [ 0,  0,  0]  1 */
    35563982, /* 69783 (1631) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
        9040, /* 69784 (1631) [ 0,  0, -1,  0, -1,  0,  1,  0,  0] [ 0,  0,  0]  1 */
    52444864, /* 69785 (1631) [ 0,  0, -1,  1,  0,  0,  0, -1,  0] [ 6,  6,  0] -1 */
    34024216, /* 69786 (1631) [ 0,  1,  0,  0,  0, -1, -1,  0,  0] [ 0,  0,  0] -1 */
     1542910, /* 69787 (1631) [ 0, -1,  0,  0,  0, -1,  1,  0,  0] [ 0,  6,  6]  1 */
    27701879, /* 69788 (1631) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 9,  9,  3]  1 */
    35550858, /* 69789 (1631) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6] -1 */
    43294703, /* 69790 (1631) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 3,  3,  3] -1 */
    35559562, /* 69791 (1631) [ 0,  1,  0,  0,  0,  1,  1,  0,  0] [ 0,  6,  6] -1 */
    51148706, /* 69792 (1631) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 6,  0,  6] -1 */
    35559770, /* 69793 (1631) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 0,  6,  6] -1 */
    52438816, /* 69794 (1631) [-1,  0,  0,  0,  0,  1,  0, -1,  0] [ 6,  6,  0] -1 */
        3200, /* 69795 (1631) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
     1545598, /* 69796 (1631) [ 0,  0,  1, -1,  0,  0,  0, -1,  0] [ 0,  6,  6]  1 */
    60417625, /* 69797 (1631) [ 0,  0,  1,  0, -1,  0,  1,  0,  0] [ 9,  3,  9] -1 */
    18432328, /* 69798 (1631) [ 0,  0, -1,  0, -1,  0,  1,  0,  0] [ 6,  6,  0]  1 */
        3360, /* 69799 (1631) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    10818013, /* 69800 (1631) [ 0,  1,  0,  0,  0,  1, -1,  0,  0] [ 3,  9,  9]  1 */
    17134870, /* 69801 (1631) [ 0,  0,  1,  0,  1,  0,  1,  0,  0] [ 6,  0,  6]  1 */
    52444696, /* 69802 (1631) [ 0,  0, -1,  0,  1,  0, -1,  0,  0] [ 6,  6,  0] -1 */
    44834673, /* 69803 (1631) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 3,  9,  9] -1 */
    43292275, /* 69804 (1631) [ 0,  0, -1,  1,  0,  0,  0,  1,  0] [ 3,  3,  3] -1 */
    51139690, /* 69805 (1631) [-1,  0,  0,  0,  0, -1,  0,  1,  0] [ 6,  0,  6] -1 */
    61715563, /* 69806 (1631) [ 0,  0, -1,  1,  0,  0,  0,  1,  0] [ 9,  9,  3] -1 */
    34021096, /* 69807 (1631) [ 0,  0, -1, -1,  0,  0,  0,  1,  0] [ 0,  0,  0] -1 */
    26403925, /* 69808 (1631) [ 0,  0, -1,  0, -1,  0, -1,  0,  0] [ 9,  3,  9]  1 */
    51152918, /* 69809 (1631) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
    61715227, /* 69810 (1631) [ 0,  0, -1,  0, -1,  0, -1,  0,  0] [ 9,  9,  3] -1 */
    61718215, /* 69811 (1631) [ 0,  1,  0,  0,  0, -1,  1,  0,  0] [ 9,  9,  3] -1 */
    60419173, /* 69812 (1631) [ 0,  1,  0,  0,  0,  1, -1,  0,  0] [ 9,  3,  9] -1 */
    43286115, /* 69813 (1631) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 3,  3,  3] -1 */
    61709403, /* 69814 (1631) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 9,  9,  3] -1 */
    35563818, /* 69815 (1631) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  6] -1 */
    27697343, /* 69816 (1631) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 9,  9,  3]  1 */
    35554910, /* 69817 (1631) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 0,  6,  6] -1 */
     1551758, /* 69818 (1631) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
    51148498, /* 69819 (1631) [ 0,  1,  0,  0,  0,  1,  1,  0,  0] [ 6,  0,  6] -1 */
       11992, /* 69820 (1631) [ 0,  1,  0,  0,  0, -1, -1,  0,  0] [ 0,  0,  0]  1 */
    44825809, /* 69821 (1631) [ 0, -1,  0,  0,  0, -1, -1,  0,  0] [ 3,  9,  9] -1 */
     9282479, /* 69822 (1631) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 3,  3,  3]  1 */
    27705767, /* 69823 (1631) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 9,  9,  3]  1 */
    17136482, /* 69824 (1631) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 6,  0,  6]  1 */
    60423505, /* 69825 (1631) [ 1,  0,  0,  0,  0, -1,  0,  1,  0] [ 9,  3,  9] -1 */
     1547546, /* 69826 (1631) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 0,  6,  6]  1 */
    26405401, /* 69827 (1631) [ 0,  0,  1,  0, -1,  0,  1,  0,  0] [ 9,  3,  9]  1 */
    44825601, /* 69828 (1631) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 3,  9,  9] -1 */
    61715407, /* 69829 (1631) [ 0,  0, -1,  0,  1,  0,  1,  0,  0] [ 9,  9,  3] -1 */
    52443408, /* 69830 (1631) [ 0, -1,  0,  1,  0,  0,  0,  0, -1] [ 6,  6,  0] -1 */
    18432472, /* 69831 (1631) [ 0,  0, -1,  0,  1,  0, -1,  0,  0] [ 6,  6,  0]  1 */
    26404105, /* 69832 (1631) [ 0,  0, -1,  0,  1,  0,  1,  0,  0] [ 9,  3,  9]  1 */
    17134690, /* 69833 (1631) [ 0,  0,  1,  0, -1,  0, -1,  0,  0] [ 6,  0,  6]  1 */
    10822449, /* 69834 (1631) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 3,  9,  9]  1 */
    34028656, /* 69835 (1631) [ 1,  0,  0,  0,  0,  1,  0,  1,  0] [ 0,  0,  0] -1 */
    17127466, /* 69836 (1631) [-1,  0,  0,  0,  0, -1,  0,  1,  0] [ 6,  0,  6]  1 */
    27703339, /* 69837 (1631) [ 0,  0, -1,  1,  0,  0,  0,  1,  0] [ 9,  9,  3]  1 */
    10813865, /* 69838 (1631) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 3,  9,  9]  1 */
        8872, /* 69839 (1631) [ 0,  0, -1, -1,  0,  0,  0,  1,  0] [ 0,  0,  0]  1 */
    51144106, /* 69840 (1631) [ 0, -1,  0,  0,  0,  1, -1,  0,  0] [ 6,  0,  6] -1 */
    52438872, /* 69841 (1631) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
    27710407, /* 69842 (1631) [ 1,  0,  0,  0,  0,  1,  0, -1,  0] [ 9,  9,  3]  1 */
     9274003, /* 69843 (1631) [-1,  0,  0,  0,  0,  1,  0,  1,  0] [ 3,  3,  3]  1 */
    60423609, /* 69844 (1631) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 9,  3,  9] -1 */
    61717015, /* 69845 (1631) [ 0,  0,  1,  1,  0,  0,  0, -1,  0] [ 9,  9,  3] -1 */
    35550754, /* 69846 (1631) [-1,  0,  0,  0,  0, -1,  0,  1,  0] [ 0,  6,  6] -1 */
    18430924, /* 69847 (1631) [ 0, -1,  0,  0,  0, -1,  1,  0,  0] [ 6,  6,  0]  1 */
    27697179, /* 69848 (1631) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 9,  9,  3]  1 */
     1551594, /* 69849 (1631) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
     1542946, /* 69850 (1631) [ 0, -1,  0,  0,  0,  1, -1,  0,  0] [ 0,  6,  6]  1 */
    17140530, /* 69851 (1631) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  6]  1 */
    26406913, /* 69852 (1631) [ 0,  1,  0,  0,  0, -1,  1,  0,  0] [ 9,  3,  9]  1 */
    51139634, /* 69853 (1631) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
    60414745, /* 69854 (1631) [ 0, -1,  0,  0,  0, -1, -1,  0,  0] [ 9,  3,  9] -1 */
    60414817, /* 69855 (1631) [ 0, -1,  0,  0,  0,  1,  1,  0,  0] [ 9,  3,  9] -1 */
    52442924, /* 69856 (1631) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 6,  6,  0] -1 */
    18432160, /* 69857 (1631) [ 0,  0, -1, -1,  0,  0,  0,  1,  0] [ 6,  6,  0]  1 */
    10816609, /* 69858 (1631) [ 0,  0,  1,  0,  1,  0, -1,  0,  0] [ 3,  9,  9]  1 */
    52447296, /* 69859 (1631) [ 0,  1,  0, -1,  0,  0,  0,  0, -1] [ 6,  6,  0] -1 */
    10813585, /* 69860 (1631) [ 0, -1,  0,  0,  0, -1, -1,  0,  0] [ 3,  9,  9]  1 */
    35557978, /* 69861 (1631) [ 0,  0,  1,  0, -1,  0, -1,  0,  0] [ 0,  6,  6] -1 */
    26411281, /* 69862 (1631) [ 1,  0,  0,  0,  0, -1,  0,  1,  0] [ 9,  3,  9]  1 */
    35556850, /* 69863 (1631) [ 0,  0, -1,  1,  0,  0,  0, -1,  0] [ 0,  6,  6] -1 */
    35559490, /* 69864 (1631) [ 0,  1,  0,  0,  0, -1, -1,  0,  0] [ 0,  6,  6] -1 */
    60417457, /* 69865 (1631) [ 0,  0,  1, -1,  0,  0,  0,  1,  0] [ 9,  3,  9] -1 */
    27703183, /* 69866 (1631) [ 0,  0, -1,  0,  1,  0,  1,  0,  0] [ 9,  9,  3]  1 */
    35550802, /* 69867 (1631) [-1,  0,  0,  0,  0,  1,  0, -1,  0] [ 0,  6,  6] -1 */
    61722687, /* 69868 (1631) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 9,  9,  3] -1 */
    18431184, /* 69869 (1631) [ 0, -1,  0,  1,  0,  0,  0,  0, -1] [ 6,  6,  0]  1 */
    34015480, /* 69870 (1631) [-1,  0,  0,  0,  0, -1,  0,  1,  0] [ 0,  0,  0] -1 */
    43294963, /* 69871 (1631) [ 0,  1,  0,  0,  0,  1, -1,  0,  0] [ 3,  3,  3] -1 */
    61718475, /* 69872 (1631) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 9,  9,  3] -1 */
       16432, /* 69873 (1631) [ 1,  0,  0,  0,  0,  1,  0,  1,  0] [ 0,  0,  0]  1 */
    44834569, /* 69874 (1631) [ 1,  0,  0,  0,  0, -1,  0,  1,  0] [ 3,  9,  9] -1 */
        3304, /* 69875 (1631) [-1,  0,  0,  0,  0,  1,  0, -1,  0] [ 0,  0,  0]  1 */
    44828689, /* 69876 (1631) [ 0,  0,  1,  0, -1,  0,  1,  0,  0] [ 3,  9,  9] -1 */
    17131882, /* 69877 (1631) [ 0, -1,  0,  0,  0,  1, -1,  0,  0] [ 6,  0,  6]  1 */
    18426648, /* 69878 (1631) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
    26411385, /* 69879 (1631) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 9,  3,  9]  1 */
    27704791, /* 69880 (1631) [ 0,  0,  1,  1,  0,  0,  0, -1,  0] [ 9,  9,  3]  1 */
     1538530, /* 69881 (1631) [-1,  0,  0,  0,  0, -1,  0,  1,  0] [ 0,  6,  6]  1 */
    26407173, /* 69882 (1631) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 9,  3,  9]  1 */
    35556682, /* 69883 (1631) [ 0,  0, -1,  0,  1,  0, -1,  0,  0] [ 0,  6,  6] -1 */
    60414537, /* 69884 (1631) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 9,  3,  9] -1 */
    43299399, /* 69885 (1631) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 3,  3,  3] -1 */
    26405713, /* 69886 (1631) [ 0,  0,  1,  1,  0,  0,  0, -1,  0] [ 9,  3,  9]  1 */
    52438768, /* 69887 (1631) [-1,  0,  0,  0,  0, -1,  0,  1,  0] [ 6,  6,  0] -1 */
    34023040, /* 69888 (1631) [ 0,  0,  1,  1,  0,  0,  0,  1,  0] [ 0,  0,  0] -1 */
    52446328, /* 69889 (1631) [ 0,  0,  1,  1,  0,  0,  0,  1,  0] [ 6,  6,  0] -1 */
    43290815, /* 69890 (1631) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 3,  3,  3] -1 */
    26402521, /* 69891 (1631) [ 0, -1,  0,  0,  0, -1, -1,  0,  0] [ 9,  3,  9]  1 */
    61716847, /* 69892 (1631) [ 0,  0,  1,  0,  1,  0, -1,  0,  0] [ 9,  9,  3] -1 */
    35563870, /* 69893 (1631) [ 1,  0,  0,  0,  0, -1,  0, -1,  0] [ 0,  6,  6] -1 */
    52445836, /* 69894 (1631) [ 0,  0,  1, -1,  0,  0,  0, -1,  0] [ 6,  6,  0] -1 */
     9273943, /* 69895 (1631) [-1,  0,  0,  0,  0, -1,  0, -1,  0] [ 3,  3,  3]  1 */
    18435072, /* 69896 (1631) [ 0,  1,  0, -1,  0,  0,  0,  0, -1] [ 6,  6,  0]  1 */
     1545754, /* 69897 (1631) [ 0,  0,  1,  0, -1,  0, -1,  0,  0] [ 0,  6,  6]  1 */
    26405545, /* 69898 (1631) [ 0,  0,  1,  0,  1,  0, -1,  0,  0] [ 9,  3,  9]  1 */
     1544626, /* 69899 (1631) [ 0,  0, -1,  1,  0,  0,  0, -1,  0] [ 0,  6,  6]  1 */
     1547266, /* 69900 (1631) [ 0,  1,  0,  0,  0, -1, -1,  0,  0] [ 0,  6,  6]  1 */
    17136202, /* 69901 (1631) [ 0,  1,  0,  0,  0, -1, -1,  0,  0] [ 6,  0,  6]  1 */
    26405233, /* 69902 (1631) [ 0,  0,  1, -1,  0,  0,  0,  1,  0] [ 9,  3,  9]  1 */
    44834617, /* 69903 (1631) [ 1,  0,  0,  0,  0,  1,  0, -1,  0] [ 3,  9,  9] -1 */
    10817977, /* 69904 (1631) [ 0,  1,  0,  0,  0, -1,  1,  0,  0] [ 3,  9,  9]  1 */
    35563930, /* 69905 (1631) [ 1,  0,  0,  0,  0,  1,  0,  1,  0] [ 0,  6,  6] -1 */
    44825881, /* 69906 (1631) [ 0, -1,  0,  0,  0,  1,  1,  0,  0] [ 3,  9,  9] -1 */
     9287015, /* 69907 (1631) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 3,  3,  3]  1 */
    27706251, /* 69908 (1631) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 9,  9,  3]  1 */
    34024008, /* 69909 (1631) [ 0,  1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    60415993, /* 69910 (1631) [ 0,  0, -1, -1,  0,  0,  0, -1,  0] [ 9,  3,  9] -1 */
    10822345, /* 69911 (1631) [ 1,  0,  0,  0,  0, -1,  0,  1,  0] [ 3,  9,  9]  1 */
    51144330, /* 69912 (1631) [ 0, -1,  0,  1,  0,  0,  0,  0, -1] [ 6,  0,  6] -1 */
    34022884, /* 69913 (1631) [ 0,  0,  1,  0,  1,  0,  1,  0,  0] [ 0,  0,  0] -1 */
    52446172, /* 69914 (1631) [ 0,  0,  1,  0,  1,  0,  1,  0,  0] [ 6,  6,  0] -1 */
     1544458, /* 69915 (1631) [ 0,  0, -1,  0,  1,  0, -1,  0,  0] [ 0,  6,  6]  1 */
    10814833, /* 69916 (1631) [ 0,  0, -1, -1,  0,  0,  0, -1,  0] [ 3,  9,  9]  1 */
     9287175, /* 69917 (1631) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 3,  3,  3]  1 */
    60418913, /* 69918 (1631) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 9,  3,  9] -1 */
    18426544, /* 69919 (1631) [-1,  0,  0,  0,  0, -1,  0,  1,  0] [ 6,  6,  0]  1 */
       10816, /* 69920 (1631) [ 0,  0,  1,  1,  0,  0,  0,  1,  0] [ 0,  0,  0]  1 */
    18434104, /* 69921 (1631) [ 0,  0,  1,  1,  0,  0,  0,  1,  0] [ 6,  6,  0]  1 */
     9278591, /* 69922 (1631) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 3,  3,  3]  1 */
     9282963, /* 69923 (1631) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 3,  3,  3]  1 */
        9184, /* 69924 (1631) [ 0,  0, -1,  0,  1,  0, -1,  0,  0] [ 0,  0,  0]  1 */
     1551646, /* 69925 (1631) [ 1,  0,  0,  0,  0, -1,  0, -1,  0] [ 0,  6,  6]  1 */
     9281503, /* 69926 (1631) [ 0,  0,  1,  1,  0,  0,  0, -1,  0] [ 3,  3,  3]  1 */
    10815169, /* 69927 (1631) [ 0,  0, -1,  0,  1,  0,  1,  0,  0] [ 3,  9,  9]  1 */
    18433612, /* 69928 (1631) [ 0,  0,  1, -1,  0,  0,  0, -1,  0] [ 6,  6,  0]  1 */
    51152866, /* 69929 (1631) [ 1,  0,  0,  0,  0,  1,  0,  1,  0] [ 6,  0,  6] -1 */
     9281335, /* 69930 (1631) [ 0,  0,  1,  0,  1,  0, -1,  0,  0] [ 3,  3,  3]  1 */
     1551706, /* 69931 (1631) [ 1,  0,  0,  0,  0,  1,  0,  1,  0] [ 0,  6,  6]  1 */
    60423553, /* 69932 (1631) [ 1,  0,  0,  0,  0,  1,  0, -1,  0] [ 9,  3,  9] -1 */
    60410437, /* 69933 (1631) [-1,  0,  0,  0,  0,  1,  0,  1,  0] [ 9,  3,  9] -1 */
    61718251, /* 69934 (1631) [ 0,  1,  0,  0,  0,  1, -1,  0,  0] [ 9,  9,  3] -1 */
       11784, /* 69935 (1631) [ 0,  1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    51139794, /* 69936 (1631) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6] -1 */
    43291939, /* 69937 (1631) [ 0,  0, -1,  0, -1,  0, -1,  0,  0] [ 3,  3,  3] -1 */
    26403769, /* 69938 (1631) [ 0,  0, -1, -1,  0,  0,  0, -1,  0] [ 9,  3,  9]  1 */
    17131622, /* 69939 (1631) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 6,  0,  6]  1 */
    44821441, /* 69940 (1631) [-1,  0,  0,  0,  0, -1,  0, -1,  0] [ 3,  9,  9] -1 */
    61715071, /* 69941 (1631) [ 0,  0, -1, -1,  0,  0,  0, -1,  0] [ 9,  9,  3] -1 */
     9274055, /* 69942 (1631) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 3,  3,  3]  1 */
    17132106, /* 69943 (1631) [ 0, -1,  0,  1,  0,  0,  0,  0, -1] [ 6,  0,  6]  1 */
    44828521, /* 69944 (1631) [ 0,  0,  1, -1,  0,  0,  0,  1,  0] [ 3,  9,  9] -1 */
     1543170, /* 69945 (1631) [ 0, -1,  0,  1,  0,  0,  0,  0, -1] [ 0,  6,  6]  1 */
    18433948, /* 69946 (1631) [ 0,  0,  1,  0,  1,  0,  1,  0,  0] [ 6,  6,  0]  1 */
    18432640, /* 69947 (1631) [ 0,  0, -1,  1,  0,  0,  0, -1,  0] [ 6,  6,  0]  1 */
    61722583, /* 69948 (1631) [ 1,  0,  0,  0,  0, -1,  0,  1,  0] [ 9,  9,  3] -1 */
    43293415, /* 69949 (1631) [ 0,  0,  1,  0, -1,  0,  1,  0,  0] [ 3,  3,  3] -1 */
    61716703, /* 69950 (1631) [ 0,  0,  1,  0, -1,  0,  1,  0,  0] [ 9,  9,  3] -1 */
     1538634, /* 69951 (1631) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
     1547338, /* 69952 (1631) [ 0,  1,  0,  0,  0,  1,  1,  0,  0] [ 0,  6,  6]  1 */
    18426592, /* 69953 (1631) [-1,  0,  0,  0,  0,  1,  0, -1,  0] [ 6,  6,  0]  1 */
    43292119, /* 69954 (1631) [ 0,  0, -1,  0,  1,  0,  1,  0,  0] [ 3,  3,  3] -1 */
    34022548, /* 69955 (1631) [ 0,  0,  1, -1,  0,  0,  0, -1,  0] [ 0,  0,  0] -1 */
    51145474, /* 69956 (1631) [ 0,  0, -1,  0, -1,  0,  1,  0,  0] [ 6,  0,  6] -1 */
    43294927, /* 69957 (1631) [ 0,  1,  0,  0,  0, -1,  1,  0,  0] [ 3,  3,  3] -1 */
    26398213, /* 69958 (1631) [-1,  0,  0,  0,  0,  1,  0,  1,  0] [ 9,  3,  9]  1 */
    60410377, /* 69959 (1631) [-1,  0,  0,  0,  0, -1,  0, -1,  0] [ 9,  3,  9] -1 */
     9280051, /* 69960 (1631) [ 0,  0, -1,  1,  0,  0,  0,  1,  0] [ 3,  3,  3]  1 */
    34019636, /* 69961 (1631) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    27706027, /* 69962 (1631) [ 0,  1,  0,  0,  0,  1, -1,  0,  0] [ 9,  9,  3]  1 */
       16484, /* 69963 (1632) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    61722687, /* 69964 (1632) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 9,  9,  3] -1 */
    44834513, /* 69965 (1632) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 3,  9,  9] -1 */
        7896, /* 69966 (1632) [ 0, -1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    18431184, /* 69967 (1632) [ 0, -1,  0,  1,  0,  0,  0,  0, -1] [ 6,  6,  0]  1 */
    17127570, /* 69968 (1632) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6]  1 */
       10660, /* 69969 (1632) [ 0,  0,  1,  0,  1,  0,  1,  0,  0] [ 0,  0,  0]  1 */
    17140694, /* 69970 (1632) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
    17134534, /* 69971 (1632) [ 0,  0,  1, -1,  0,  0,  0, -1,  0] [ 6,  0,  6]  1 */
    43294963, /* 69972 (1632) [ 0,  1,  0,  0,  0,  1, -1,  0,  0] [ 3,  3,  3] -1 */
    61718475, /* 69973 (1632) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 9,  9,  3] -1 */
    44830237, /* 69974 (1632) [ 0,  1,  0,  0,  0,  1, -1,  0,  0] [ 3,  9,  9] -1 */
     1538474, /* 69975 (1632) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
    61713895, /* 69976 (1632) [ 0, -1,  0,  0,  0,  1,  1,  0,  0] [ 9,  9,  3] -1 */
       16432, /* 69977 (1632) [ 1,  0,  0,  0,  0,  1,  0,  1,  0] [ 0,  0,  0]  1 */
    44834569, /* 69978 (1632) [ 1,  0,  0,  0,  0, -1,  0,  1,  0] [ 3,  9,  9] -1 */
    60410325, /* 69979 (1632) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 9,  3,  9] -1 */
        3304, /* 69980 (1632) [-1,  0,  0,  0,  0,  1,  0, -1,  0] [ 0,  0,  0]  1 */
    18430960, /* 69981 (1632) [ 0, -1,  0,  0,  0,  1, -1,  0,  0] [ 6,  6,  0]  1 */
       16320, /* 69982 (1632) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    44828689, /* 69983 (1632) [ 0,  0,  1,  0, -1,  0,  1,  0,  0] [ 3,  9,  9] -1 */
    43299295, /* 69984 (1632) [ 1,  0,  0,  0,  0, -1,  0,  1,  0] [ 3,  3,  3] -1 */
     1542686, /* 69985 (1632) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 0,  6,  6]  1 */
    17131882, /* 69986 (1632) [ 0, -1,  0,  0,  0,  1, -1,  0,  0] [ 6,  0,  6]  1 */
    18426648, /* 69987 (1632) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
    17136274, /* 69988 (1632) [ 0,  1,  0,  0,  0,  1,  1,  0,  0] [ 6,  0,  6]  1 */
     1538530, /* 69989 (1632) [-1,  0,  0,  0,  0, -1,  0,  1,  0] [ 0,  6,  6]  1 */
    60414537, /* 69990 (1632) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 9,  3,  9] -1 */
    43299399, /* 69991 (1632) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 3,  3,  3] -1 */
    60416329, /* 69992 (1632) [ 0,  0, -1,  0,  1,  0,  1,  0,  0] [ 9,  3,  9] -1 */
    43290815, /* 69993 (1632) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 3,  3,  3] -1 */
    61716847, /* 69994 (1632) [ 0,  0,  1,  0,  1,  0, -1,  0,  0] [ 9,  9,  3] -1 */
    44826089, /* 69995 (1632) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 3,  9,  9] -1 */
    43286279, /* 69996 (1632) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 3,  3,  3] -1 */
    44830461, /* 69997 (1632) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 3,  9,  9] -1 */
    61709567, /* 69998 (1632) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 9,  9,  3] -1 */
    17140642, /* 69999 (1632) [ 1,  0,  0,  0,  0,  1,  0,  1,  0] [ 6,  0,  6]  1 */
    44821501, /* 70000 (1632) [-1,  0,  0,  0,  0,  1,  0,  1,  0] [ 3,  9,  9] -1 */
        7636, /* 70001 (1632) [ 0, -1,  0,  0,  0, -1,  1,  0,  0] [ 0,  0,  0]  1 */
    61722631, /* 70002 (1632) [ 1,  0,  0,  0,  0,  1,  0, -1,  0] [ 9,  9,  3] -1 */
    43286227, /* 70003 (1632) [-1,  0,  0,  0,  0,  1,  0,  1,  0] [ 3,  3,  3] -1 */
        9040, /* 70004 (1632) [ 0,  0, -1,  0, -1,  0,  1,  0,  0] [ 0,  0,  0]  1 */
    18435072, /* 70005 (1632) [ 0,  1,  0, -1,  0,  0,  0,  0, -1] [ 6,  6,  0]  1 */
     1542910, /* 70006 (1632) [ 0, -1,  0,  0,  0, -1,  1,  0,  0] [ 0,  6,  6]  1 */
       16372, /* 70007 (1632) [ 1,  0,  0,  0,  0, -1,  0, -1,  0] [ 0,  0,  0]  1 */
     1545754, /* 70008 (1632) [ 0,  0,  1,  0, -1,  0, -1,  0,  0] [ 0,  6,  6]  1 */
    60419137, /* 70009 (1632) [ 0,  1,  0,  0,  0, -1,  1,  0,  0] [ 9,  3,  9] -1 */
    43294703, /* 70010 (1632) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 3,  3,  3] -1 */
     1544146, /* 70011 (1632) [ 0,  0, -1, -1,  0,  0,  0,  1,  0] [ 0,  6,  6]  1 */
    60423449, /* 70012 (1632) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 9,  3,  9] -1 */
    44829977, /* 70013 (1632) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 3,  9,  9] -1 */
     1544626, /* 70014 (1632) [ 0,  0, -1,  1,  0,  0,  0, -1,  0] [ 0,  6,  6]  1 */
     1547266, /* 70015 (1632) [ 0,  1,  0,  0,  0, -1, -1,  0,  0] [ 0,  6,  6]  1 */
    17136202, /* 70016 (1632) [ 0,  1,  0,  0,  0, -1, -1,  0,  0] [ 6,  0,  6]  1 */
    44828833, /* 70017 (1632) [ 0,  0,  1,  0,  1,  0, -1,  0,  0] [ 3,  9,  9] -1 */
        3200, /* 70018 (1632) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    43299343, /* 70019 (1632) [ 1,  0,  0,  0,  0,  1,  0, -1,  0] [ 3,  3,  3] -1 */
     1545598, /* 70020 (1632) [ 0,  0,  1, -1,  0,  0,  0, -1,  0] [ 0,  6,  6]  1 */
    18439608, /* 70021 (1632) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
    60417625, /* 70022 (1632) [ 0,  0,  1,  0, -1,  0,  1,  0,  0] [ 9,  3,  9] -1 */
    44834617, /* 70023 (1632) [ 1,  0,  0,  0,  0,  1,  0, -1,  0] [ 3,  9,  9] -1 */
    18432328, /* 70024 (1632) [ 0,  0, -1,  0, -1,  0,  1,  0,  0] [ 6,  6,  0]  1 */
        3360, /* 70025 (1632) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
       10324, /* 70026 (1632) [ 0,  0,  1, -1,  0,  0,  0, -1,  0] [ 0,  0,  0]  1 */
    17133250, /* 70027 (1632) [ 0,  0, -1,  0, -1,  0,  1,  0,  0] [ 6,  0,  6]  1 */
    44825881, /* 70028 (1632) [ 0, -1,  0,  0,  0,  1,  1,  0,  0] [ 3,  9,  9] -1 */
        7412, /* 70029 (1632) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    60415025, /* 70030 (1632) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 9,  3,  9] -1 */
    17134870, /* 70031 (1632) [ 0,  0,  1,  0,  1,  0,  1,  0,  0] [ 6,  0,  6]  1 */
    18439772, /* 70032 (1632) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    60415993, /* 70033 (1632) [ 0,  0, -1, -1,  0,  0,  0, -1,  0] [ 9,  3,  9] -1 */
    17127410, /* 70034 (1632) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
    44834673, /* 70035 (1632) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 3,  9,  9] -1 */
    43292275, /* 70036 (1632) [ 0,  0, -1,  1,  0,  0,  0,  1,  0] [ 3,  3,  3] -1 */
    18426488, /* 70037 (1632) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    61715563, /* 70038 (1632) [ 0,  0, -1,  1,  0,  0,  0,  1,  0] [ 9,  9,  3] -1 */
    17135994, /* 70039 (1632) [ 0,  1,  0, -1,  0,  0,  0,  0, -1] [ 6,  0,  6]  1 */
    43290535, /* 70040 (1632) [ 0, -1,  0,  0,  0, -1, -1,  0,  0] [ 3,  3,  3] -1 */
    44821553, /* 70041 (1632) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 3,  9,  9] -1 */
    61713823, /* 70042 (1632) [ 0, -1,  0,  0,  0, -1, -1,  0,  0] [ 9,  9,  3] -1 */
     1544458, /* 70043 (1632) [ 0,  0, -1,  0,  1,  0, -1,  0,  0] [ 0,  6,  6]  1 */
    18435352, /* 70044 (1632) [ 0,  1,  0,  0,  0,  1,  1,  0,  0] [ 6,  6,  0]  1 */
    18430700, /* 70045 (1632) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    61715227, /* 70046 (1632) [ 0,  0, -1,  0, -1,  0, -1,  0,  0] [ 9,  9,  3] -1 */
    61718215, /* 70047 (1632) [ 0,  1,  0,  0,  0, -1,  1,  0,  0] [ 9,  9,  3] -1 */
    60418913, /* 70048 (1632) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 9,  3,  9] -1 */
    60419173, /* 70049 (1632) [ 0,  1,  0,  0,  0,  1, -1,  0,  0] [ 9,  3,  9] -1 */
    18426544, /* 70050 (1632) [-1,  0,  0,  0,  0, -1,  0,  1,  0] [ 6,  6,  0]  1 */
       10816, /* 70051 (1632) [ 0,  0,  1,  1,  0,  0,  0,  1,  0] [ 0,  0,  0]  1 */
    43286115, /* 70052 (1632) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 3,  3,  3] -1 */
    18434104, /* 70053 (1632) [ 0,  0,  1,  1,  0,  0,  0,  1,  0] [ 6,  6,  0]  1 */
    61709403, /* 70054 (1632) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 9,  9,  3] -1 */
    18435560, /* 70055 (1632) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 6,  6,  0]  1 */
        9184, /* 70056 (1632) [ 0,  0, -1,  0,  1,  0, -1,  0,  0] [ 0,  0,  0]  1 */
    43293247, /* 70057 (1632) [ 0,  0,  1, -1,  0,  0,  0,  1,  0] [ 3,  3,  3] -1 */
    61716535, /* 70058 (1632) [ 0,  0,  1, -1,  0,  0,  0,  1,  0] [ 9,  9,  3] -1 */
       12064, /* 70059 (1632) [ 0,  1,  0,  0,  0,  1,  1,  0,  0] [ 0,  0,  0]  1 */
     1551646, /* 70060 (1632) [ 1,  0,  0,  0,  0, -1,  0, -1,  0] [ 0,  6,  6]  1 */
    18433768, /* 70061 (1632) [ 0,  0,  1,  0, -1,  0, -1,  0,  0] [ 6,  6,  0]  1 */
     1551758, /* 70062 (1632) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
    17133562, /* 70063 (1632) [ 0,  0, -1,  1,  0,  0,  0, -1,  0] [ 6,  0,  6]  1 */
    17131846, /* 70064 (1632) [ 0, -1,  0,  0,  0, -1,  1,  0,  0] [ 6,  0,  6]  1 */
    18439720, /* 70065 (1632) [ 1,  0,  0,  0,  0,  1,  0,  1,  0] [ 6,  6,  0]  1 */
    18433612, /* 70066 (1632) [ 0,  0,  1, -1,  0,  0,  0, -1,  0] [ 6,  6,  0]  1 */
    60419397, /* 70067 (1632) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 9,  3,  9] -1 */
    61713615, /* 70068 (1632) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 9,  9,  3] -1 */
       11992, /* 70069 (1632) [ 0,  1,  0,  0,  0, -1, -1,  0,  0] [ 0,  0,  0]  1 */
    60417937, /* 70070 (1632) [ 0,  0,  1,  1,  0,  0,  0, -1,  0] [ 9,  3,  9] -1 */
    44825809, /* 70071 (1632) [ 0, -1,  0,  0,  0, -1, -1,  0,  0] [ 3,  9,  9] -1 */
    17136482, /* 70072 (1632) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 6,  0,  6]  1 */
    44827213, /* 70073 (1632) [ 0,  0, -1,  0, -1,  0, -1,  0,  0] [ 3,  9,  9] -1 */
    60423505, /* 70074 (1632) [ 1,  0,  0,  0,  0, -1,  0,  1,  0] [ 9,  3,  9] -1 */
        7672, /* 70075 (1632) [ 0, -1,  0,  0,  0,  1, -1,  0,  0] [ 0,  0,  0]  1 */
    17127514, /* 70076 (1632) [-1,  0,  0,  0,  0,  1,  0, -1,  0] [ 6,  0,  6]  1 */
     1547546, /* 70077 (1632) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 0,  6,  6]  1 */
     1546090, /* 70078 (1632) [ 0,  0,  1,  1,  0,  0,  0,  1,  0] [ 0,  6,  6]  1 */
    44821389, /* 70079 (1632) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 3,  9,  9] -1 */
     1538578, /* 70080 (1632) [-1,  0,  0,  0,  0,  1,  0, -1,  0] [ 0,  6,  6]  1 */
    43286167, /* 70081 (1632) [-1,  0,  0,  0,  0, -1,  0, -1,  0] [ 3,  3,  3] -1 */
    61709455, /* 70082 (1632) [-1,  0,  0,  0,  0, -1,  0, -1,  0] [ 9,  9,  3] -1 */
        3256, /* 70083 (1632) [-1,  0,  0,  0,  0, -1,  0,  1,  0] [ 0,  0,  0]  1 */
    60417769, /* 70084 (1632) [ 0,  0,  1,  0,  1,  0, -1,  0,  0] [ 9,  3,  9] -1 */
     1551706, /* 70085 (1632) [ 1,  0,  0,  0,  0,  1,  0,  1,  0] [ 0,  6,  6]  1 */
    44825601, /* 70086 (1632) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 3,  9,  9] -1 */
    60410489, /* 70087 (1632) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 9,  3,  9] -1 */
    61715407, /* 70088 (1632) [ 0,  0, -1,  0,  1,  0,  1,  0,  0] [ 9,  9,  3] -1 */
    60423553, /* 70089 (1632) [ 1,  0,  0,  0,  0,  1,  0, -1,  0] [ 9,  3,  9] -1 */
    60410437, /* 70090 (1632) [-1,  0,  0,  0,  0,  1,  0,  1,  0] [ 9,  3,  9] -1 */
    44827549, /* 70091 (1632) [ 0,  0, -1,  1,  0,  0,  0,  1,  0] [ 3,  9,  9] -1 */
    61718251, /* 70092 (1632) [ 0,  1,  0,  0,  0,  1, -1,  0,  0] [ 9,  9,  3] -1 */
       11784, /* 70093 (1632) [ 0,  1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    43291939, /* 70094 (1632) [ 0,  0, -1,  0, -1,  0, -1,  0,  0] [ 3,  3,  3] -1 */
    18432472, /* 70095 (1632) [ 0,  0, -1,  0,  1,  0, -1,  0,  0] [ 6,  6,  0]  1 */
    18439660, /* 70096 (1632) [ 1,  0,  0,  0,  0, -1,  0, -1,  0] [ 6,  6,  0]  1 */
    44830201, /* 70097 (1632) [ 0,  1,  0,  0,  0, -1,  1,  0,  0] [ 3,  9,  9] -1 */
    17131622, /* 70098 (1632) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 6,  0,  6]  1 */
    17134690, /* 70099 (1632) [ 0,  0,  1,  0, -1,  0, -1,  0,  0] [ 6,  0,  6]  1 */
    44821441, /* 70100 (1632) [-1,  0,  0,  0,  0, -1,  0, -1,  0] [ 3,  9,  9] -1 */
        9352, /* 70101 (1632) [ 0,  0, -1,  1,  0,  0,  0, -1,  0] [ 0,  0,  0]  1 */
       12272, /* 70102 (1632) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    18435280, /* 70103 (1632) [ 0,  1,  0,  0,  0, -1, -1,  0,  0] [ 6,  6,  0]  1 */
    17127466, /* 70104 (1632) [-1,  0,  0,  0,  0, -1,  0,  1,  0] [ 6,  0,  6]  1 */
    61715071, /* 70105 (1632) [ 0,  0, -1, -1,  0,  0,  0, -1,  0] [ 9,  9,  3] -1 */
    43299239, /* 70106 (1632) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 3,  3,  3] -1 */
    17132106, /* 70107 (1632) [ 0, -1,  0,  1,  0,  0,  0,  0, -1] [ 6,  0,  6]  1 */
        8872, /* 70108 (1632) [ 0,  0, -1, -1,  0,  0,  0,  1,  0] [ 0,  0,  0]  1 */
    44828521, /* 70109 (1632) [ 0,  0,  1, -1,  0,  0,  0,  1,  0] [ 3,  9,  9] -1 */
     1543170, /* 70110 (1632) [ 0, -1,  0,  1,  0,  0,  0,  0, -1] [ 0,  6,  6]  1 */
    61722527, /* 70111 (1632) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 9,  9,  3] -1 */
    60423609, /* 70112 (1632) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 9,  3,  9] -1 */
    18433948, /* 70113 (1632) [ 0,  0,  1,  0,  1,  0,  1,  0,  0] [ 6,  6,  0]  1 */
    61717015, /* 70114 (1632) [ 0,  0,  1,  1,  0,  0,  0, -1,  0] [ 9,  9,  3] -1 */
    18432640, /* 70115 (1632) [ 0,  0, -1,  1,  0,  0,  0, -1,  0] [ 6,  6,  0]  1 */
    43290327, /* 70116 (1632) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 3,  3,  3] -1 */
    18430924, /* 70117 (1632) [ 0, -1,  0,  0,  0, -1,  1,  0,  0] [ 6,  6,  0]  1 */
    61722583, /* 70118 (1632) [ 1,  0,  0,  0,  0, -1,  0,  1,  0] [ 9,  9,  3] -1 */
     1551594, /* 70119 (1632) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
    43293415, /* 70120 (1632) [ 0,  0,  1,  0, -1,  0,  1,  0,  0] [ 3,  3,  3] -1 */
     1542946, /* 70121 (1632) [ 0, -1,  0,  0,  0,  1, -1,  0,  0] [ 0,  6,  6]  1 */
    17140530, /* 70122 (1632) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  6]  1 */
    61716703, /* 70123 (1632) [ 0,  0,  1,  0, -1,  0,  1,  0,  0] [ 9,  9,  3] -1 */
    43290607, /* 70124 (1632) [ 0, -1,  0,  0,  0,  1,  1,  0,  0] [ 3,  3,  3] -1 */
     1538634, /* 70125 (1632) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
    60414745, /* 70126 (1632) [ 0, -1,  0,  0,  0, -1, -1,  0,  0] [ 9,  3,  9] -1 */
    60414817, /* 70127 (1632) [ 0, -1,  0,  0,  0,  1,  1,  0,  0] [ 9,  3,  9] -1 */
     1547338, /* 70128 (1632) [ 0,  1,  0,  0,  0,  1,  1,  0,  0] [ 0,  6,  6]  1 */
    60416149, /* 70129 (1632) [ 0,  0, -1,  0, -1,  0, -1,  0,  0] [ 9,  3,  9] -1 */
    17135026, /* 70130 (1632) [ 0,  0,  1,  1,  0,  0,  0,  1,  0] [ 6,  0,  6]  1 */
    18426592, /* 70131 (1632) [-1,  0,  0,  0,  0,  1,  0, -1,  0] [ 6,  6,  0]  1 */
    18432160, /* 70132 (1632) [ 0,  0, -1, -1,  0,  0,  0,  1,  0] [ 6,  6,  0]  1 */
    44827057, /* 70133 (1632) [ 0,  0, -1, -1,  0,  0,  0, -1,  0] [ 3,  9,  9] -1 */
    17133082, /* 70134 (1632) [ 0,  0, -1, -1,  0,  0,  0,  1,  0] [ 6,  0,  6]  1 */
    43295187, /* 70135 (1632) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 3,  3,  3] -1 */
    61714103, /* 70136 (1632) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 9,  9,  3] -1 */
     1545934, /* 70137 (1632) [ 0,  0,  1,  0,  1,  0,  1,  0,  0] [ 0,  6,  6]  1 */
    44829001, /* 70138 (1632) [ 0,  0,  1,  1,  0,  0,  0, -1,  0] [ 3,  9,  9] -1 */
    61709515, /* 70139 (1632) [-1,  0,  0,  0,  0,  1,  0,  1,  0] [ 9,  9,  3] -1 */
    60416485, /* 70140 (1632) [ 0,  0, -1,  1,  0,  0,  0,  1,  0] [ 9,  3,  9] -1 */
    43293727, /* 70141 (1632) [ 0,  0,  1,  1,  0,  0,  0, -1,  0] [ 3,  3,  3] -1 */
    43292119, /* 70142 (1632) [ 0,  0, -1,  0,  1,  0,  1,  0,  0] [ 3,  3,  3] -1 */
    44827393, /* 70143 (1632) [ 0,  0, -1,  0,  1,  0,  1,  0,  0] [ 3,  9,  9] -1 */
     1544314, /* 70144 (1632) [ 0,  0, -1,  0, -1,  0,  1,  0,  0] [ 0,  6,  6]  1 */
    17140582, /* 70145 (1632) [ 1,  0,  0,  0,  0, -1,  0, -1,  0] [ 6,  0,  6]  1 */
    60417457, /* 70146 (1632) [ 0,  0,  1, -1,  0,  0,  0,  1,  0] [ 9,  3,  9] -1 */
    61717991, /* 70147 (1632) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 9,  9,  3] -1 */
     1547058, /* 70148 (1632) [ 0,  1,  0, -1,  0,  0,  0,  0, -1] [ 0,  6,  6]  1 */
    17133394, /* 70149 (1632) [ 0,  0, -1,  0,  1,  0, -1,  0,  0] [ 6,  0,  6]  1 */
    43294927, /* 70150 (1632) [ 0,  1,  0,  0,  0, -1,  1,  0,  0] [ 3,  3,  3] -1 */
    60410377, /* 70151 (1632) [-1,  0,  0,  0,  0, -1,  0, -1,  0] [ 9,  3,  9] -1 */
    43293559, /* 70152 (1632) [ 0,  0,  1,  0,  1,  0, -1,  0,  0] [ 3,  3,  3] -1 */
       10480, /* 70153 (1632) [ 0,  0,  1,  0, -1,  0, -1,  0,  0] [ 0,  0,  0]  1 */
    43291783, /* 70154 (1632) [ 0,  0, -1, -1,  0,  0,  0, -1,  0] [ 3,  3,  3] -1 */
       16484, /* 70155 (1633) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34015480, /* 70156 (1633) [-1,  0,  0,  0,  0, -1,  0,  1,  0] [ 0,  0,  0] -1 */
    17127570, /* 70157 (1633) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6]  1 */
    17140694, /* 70158 (1633) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
    17134534, /* 70159 (1633) [ 0,  0,  1, -1,  0,  0,  0, -1,  0] [ 6,  0,  6]  1 */
    61718475, /* 70160 (1633) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 9,  9,  3] -1 */
    27705991, /* 70161 (1633) [ 0,  1,  0,  0,  0, -1,  1,  0,  0] [ 9,  9,  3]  1 */
    26406949, /* 70162 (1633) [ 0,  1,  0,  0,  0,  1, -1,  0,  0] [ 9,  3,  9]  1 */
    51147094, /* 70163 (1633) [ 0,  0,  1,  0,  1,  0,  1,  0,  0] [ 6,  0,  6] -1 */
     1538474, /* 70164 (1633) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
     9273891, /* 70165 (1633) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 3,  3,  3]  1 */
     9281023, /* 70166 (1633) [ 0,  0,  1, -1,  0,  0,  0,  1,  0] [ 3,  3,  3]  1 */
    44834569, /* 70167 (1633) [ 1,  0,  0,  0,  0, -1,  0,  1,  0] [ 3,  9,  9] -1 */
    18430960, /* 70168 (1633) [ 0, -1,  0,  0,  0,  1, -1,  0,  0] [ 6,  6,  0]  1 */
       16320, /* 70169 (1633) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    44828689, /* 70170 (1633) [ 0,  0,  1,  0, -1,  0,  1,  0,  0] [ 3,  9,  9] -1 */
    10816297, /* 70171 (1633) [ 0,  0,  1, -1,  0,  0,  0,  1,  0] [ 3,  9,  9]  1 */
    27710303, /* 70172 (1633) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 9,  9,  3]  1 */
    17131882, /* 70173 (1633) [ 0, -1,  0,  0,  0,  1, -1,  0,  0] [ 6,  0,  6]  1 */
    18426648, /* 70174 (1633) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
    43299295, /* 70175 (1633) [ 1,  0,  0,  0,  0, -1,  0,  1,  0] [ 3,  3,  3] -1 */
    26411385, /* 70176 (1633) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 9,  3,  9]  1 */
    17136274, /* 70177 (1633) [ 0,  1,  0,  0,  0,  1,  1,  0,  0] [ 6,  0,  6]  1 */
    27704791, /* 70178 (1633) [ 0,  0,  1,  1,  0,  0,  0, -1,  0] [ 9,  9,  3]  1 */
    51148218, /* 70179 (1633) [ 0,  1,  0, -1,  0,  0,  0,  0, -1] [ 6,  0,  6] -1 */
    35556682, /* 70180 (1633) [ 0,  0, -1,  0,  1,  0, -1,  0,  0] [ 0,  6,  6] -1 */
    60414537, /* 70181 (1633) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 9,  3,  9] -1 */
    51143846, /* 70182 (1633) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 6,  0,  6] -1 */
    60416329, /* 70183 (1633) [ 0,  0, -1,  0,  1,  0,  1,  0,  0] [ 9,  3,  9] -1 */
    52438768, /* 70184 (1633) [-1,  0,  0,  0,  0, -1,  0,  1,  0] [ 6,  6,  0] -1 */
    34024496, /* 70185 (1633) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    52447784, /* 70186 (1633) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 6,  6,  0] -1 */
    26405713, /* 70187 (1633) [ 0,  0,  1,  1,  0,  0,  0, -1,  0] [ 9,  3,  9]  1 */
     9278383, /* 70188 (1633) [ 0, -1,  0,  0,  0,  1,  1,  0,  0] [ 3,  3,  3]  1 */
    43290815, /* 70189 (1633) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 3,  3,  3] -1 */
    26402521, /* 70190 (1633) [ 0, -1,  0,  0,  0, -1, -1,  0,  0] [ 9,  3,  9]  1 */
    51146914, /* 70191 (1633) [ 0,  0,  1,  0, -1,  0, -1,  0,  0] [ 6,  0,  6] -1 */
    61716847, /* 70192 (1633) [ 0,  0,  1,  0,  1,  0, -1,  0,  0] [ 9,  9,  3] -1 */
    44826089, /* 70193 (1633) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 3,  9,  9] -1 */
    44830461, /* 70194 (1633) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 3,  9,  9] -1 */
    35563870, /* 70195 (1633) [ 1,  0,  0,  0,  0, -1,  0, -1,  0] [ 0,  6,  6] -1 */
    52445992, /* 70196 (1633) [ 0,  0,  1,  0, -1,  0, -1,  0,  0] [ 6,  6,  0] -1 */
    44821501, /* 70197 (1633) [-1,  0,  0,  0,  0,  1,  0,  1,  0] [ 3,  9,  9] -1 */
    35555394, /* 70198 (1633) [ 0, -1,  0,  1,  0,  0,  0,  0, -1] [ 0,  6,  6] -1 */
        7636, /* 70199 (1633) [ 0, -1,  0,  0,  0, -1,  1,  0,  0] [ 0,  0,  0]  1 */
    61722631, /* 70200 (1633) [ 1,  0,  0,  0,  0,  1,  0, -1,  0] [ 9,  9,  3] -1 */
    43286227, /* 70201 (1633) [-1,  0,  0,  0,  0,  1,  0,  1,  0] [ 3,  3,  3] -1 */
    52451944, /* 70202 (1633) [ 1,  0,  0,  0,  0,  1,  0,  1,  0] [ 6,  6,  0] -1 */
     1542910, /* 70203 (1633) [ 0, -1,  0,  0,  0, -1,  1,  0,  0] [ 0,  6,  6]  1 */
    10816777, /* 70204 (1633) [ 0,  0,  1,  1,  0,  0,  0, -1,  0] [ 3,  9,  9]  1 */
    26404261, /* 70205 (1633) [ 0,  0, -1,  1,  0,  0,  0,  1,  0] [ 9,  3,  9]  1 */
    43294703, /* 70206 (1633) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 3,  3,  3] -1 */
     1544146, /* 70207 (1633) [ 0,  0, -1, -1,  0,  0,  0,  1,  0] [ 0,  6,  6]  1 */
    44829977, /* 70208 (1633) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 3,  9,  9] -1 */
    51148706, /* 70209 (1633) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 6,  0,  6] -1 */
     1544626, /* 70210 (1633) [ 0,  0, -1,  1,  0,  0,  0, -1,  0] [ 0,  6,  6]  1 */
     1547266, /* 70211 (1633) [ 0,  1,  0,  0,  0, -1, -1,  0,  0] [ 0,  6,  6]  1 */
    17136202, /* 70212 (1633) [ 0,  1,  0,  0,  0, -1, -1,  0,  0] [ 6,  0,  6]  1 */
    51139738, /* 70213 (1633) [-1,  0,  0,  0,  0,  1,  0, -1,  0] [ 6,  0,  6] -1 */
    35559770, /* 70214 (1633) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 0,  6,  6] -1 */
    52438816, /* 70215 (1633) [-1,  0,  0,  0,  0,  1,  0, -1,  0] [ 6,  6,  0] -1 */
    44828833, /* 70216 (1633) [ 0,  0,  1,  0,  1,  0, -1,  0,  0] [ 3,  9,  9] -1 */
        3200, /* 70217 (1633) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    43299343, /* 70218 (1633) [ 1,  0,  0,  0,  0,  1,  0, -1,  0] [ 3,  3,  3] -1 */
     1545598, /* 70219 (1633) [ 0,  0,  1, -1,  0,  0,  0, -1,  0] [ 0,  6,  6]  1 */
    18439608, /* 70220 (1633) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
    60417625, /* 70221 (1633) [ 0,  0,  1,  0, -1,  0,  1,  0,  0] [ 9,  3,  9] -1 */
    26405233, /* 70222 (1633) [ 0,  0,  1, -1,  0,  0,  0,  1,  0] [ 9,  3,  9]  1 */
    44834617, /* 70223 (1633) [ 1,  0,  0,  0,  0,  1,  0, -1,  0] [ 3,  9,  9] -1 */
        3360, /* 70224 (1633) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
       10324, /* 70225 (1633) [ 0,  0,  1, -1,  0,  0,  0, -1,  0] [ 0,  0,  0]  1 */
    35563930, /* 70226 (1633) [ 1,  0,  0,  0,  0,  1,  0,  1,  0] [ 0,  6,  6] -1 */
    10817977, /* 70227 (1633) [ 0,  1,  0,  0,  0, -1,  1,  0,  0] [ 3,  9,  9]  1 */
     9282703, /* 70228 (1633) [ 0,  1,  0,  0,  0, -1,  1,  0,  0] [ 3,  3,  3]  1 */
     9279559, /* 70229 (1633) [ 0,  0, -1, -1,  0,  0,  0, -1,  0] [ 3,  3,  3]  1 */
    27702847, /* 70230 (1633) [ 0,  0, -1, -1,  0,  0,  0, -1,  0] [ 9,  9,  3]  1 */
     9287015, /* 70231 (1633) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 3,  3,  3]  1 */
    35556538, /* 70232 (1633) [ 0,  0, -1,  0, -1,  0,  1,  0,  0] [ 0,  6,  6] -1 */
    10822289, /* 70233 (1633) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 3,  9,  9]  1 */
    10818013, /* 70234 (1633) [ 0,  1,  0,  0,  0,  1, -1,  0,  0] [ 3,  9,  9]  1 */
    60415025, /* 70235 (1633) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 9,  3,  9] -1 */
    34024008, /* 70236 (1633) [ 0,  1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    18439772, /* 70237 (1633) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    52444696, /* 70238 (1633) [ 0,  0, -1,  0,  1,  0, -1,  0,  0] [ 6,  6,  0] -1 */
    52451884, /* 70239 (1633) [ 1,  0,  0,  0,  0, -1,  0, -1,  0] [ 6,  6,  0] -1 */
    26398101, /* 70240 (1633) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 9,  3,  9]  1 */
    17127410, /* 70241 (1633) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
    51139690, /* 70242 (1633) [-1,  0,  0,  0,  0, -1,  0,  1,  0] [ 6,  0,  6] -1 */
    18426488, /* 70243 (1633) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    26402593, /* 70244 (1633) [ 0, -1,  0,  0,  0,  1,  1,  0,  0] [ 9,  3,  9]  1 */
    51144330, /* 70245 (1633) [ 0, -1,  0,  1,  0,  0,  0,  0, -1] [ 6,  0,  6] -1 */
    34022884, /* 70246 (1633) [ 0,  0,  1,  0,  1,  0,  1,  0,  0] [ 0,  0,  0] -1 */
    52446172, /* 70247 (1633) [ 0,  0,  1,  0,  1,  0,  1,  0,  0] [ 6,  6,  0] -1 */
    18435352, /* 70248 (1633) [ 0,  1,  0,  0,  0,  1,  1,  0,  0] [ 6,  6,  0]  1 */
    61715227, /* 70249 (1633) [ 0,  0, -1,  0, -1,  0, -1,  0,  0] [ 9,  9,  3] -1 */
    10814833, /* 70250 (1633) [ 0,  0, -1, -1,  0,  0,  0, -1,  0] [ 3,  9,  9]  1 */
     9287175, /* 70251 (1633) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 3,  3,  3]  1 */
    60418913, /* 70252 (1633) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 9,  3,  9] -1 */
       10816, /* 70253 (1633) [ 0,  0,  1,  1,  0,  0,  0,  1,  0] [ 0,  0,  0]  1 */
    18434104, /* 70254 (1633) [ 0,  0,  1,  1,  0,  0,  0,  1,  0] [ 6,  6,  0]  1 */
    34015528, /* 70255 (1633) [-1,  0,  0,  0,  0,  1,  0, -1,  0] [ 0,  0,  0] -1 */
       12064, /* 70256 (1633) [ 0,  1,  0,  0,  0,  1,  1,  0,  0] [ 0,  0,  0]  1 */
    27697343, /* 70257 (1633) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 9,  9,  3]  1 */
    35554910, /* 70258 (1633) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 0,  6,  6] -1 */
     9281503, /* 70259 (1633) [ 0,  0,  1,  1,  0,  0,  0, -1,  0] [ 3,  3,  3]  1 */
     1551758, /* 70260 (1633) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
    17133562, /* 70261 (1633) [ 0,  0, -1,  1,  0,  0,  0, -1,  0] [ 6,  0,  6]  1 */
    17131846, /* 70262 (1633) [ 0, -1,  0,  0,  0, -1,  1,  0,  0] [ 6,  0,  6]  1 */
    18433612, /* 70263 (1633) [ 0,  0,  1, -1,  0,  0,  0, -1,  0] [ 6,  6,  0]  1 */
    60419397, /* 70264 (1633) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 9,  3,  9] -1 */
    61713615, /* 70265 (1633) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 9,  9,  3] -1 */
       11992, /* 70266 (1633) [ 0,  1,  0,  0,  0, -1, -1,  0,  0] [ 0,  0,  0]  1 */
    26411225, /* 70267 (1633) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 9,  3,  9]  1 */
    35558158, /* 70268 (1633) [ 0,  0,  1,  0,  1,  0,  1,  0,  0] [ 0,  6,  6] -1 */
    44827213, /* 70269 (1633) [ 0,  0, -1,  0, -1,  0, -1,  0,  0] [ 3,  9,  9] -1 */
    60423505, /* 70270 (1633) [ 1,  0,  0,  0,  0, -1,  0,  1,  0] [ 9,  3,  9] -1 */
        7672, /* 70271 (1633) [ 0, -1,  0,  0,  0,  1, -1,  0,  0] [ 0,  0,  0]  1 */
    51152866, /* 70272 (1633) [ 1,  0,  0,  0,  0,  1,  0,  1,  0] [ 6,  0,  6] -1 */
     1546090, /* 70273 (1633) [ 0,  0,  1,  1,  0,  0,  0,  1,  0] [ 0,  6,  6]  1 */
    34019636, /* 70274 (1633) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    43286167, /* 70275 (1633) [-1,  0,  0,  0,  0, -1,  0, -1,  0] [ 3,  3,  3] -1 */
    61709455, /* 70276 (1633) [-1,  0,  0,  0,  0, -1,  0, -1,  0] [ 9,  9,  3] -1 */
    27710463, /* 70277 (1633) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 9,  9,  3]  1 */
    51152806, /* 70278 (1633) [ 1,  0,  0,  0,  0, -1,  0, -1,  0] [ 6,  0,  6] -1 */
     9282739, /* 70279 (1633) [ 0,  1,  0,  0,  0,  1, -1,  0,  0] [ 3,  3,  3]  1 */
    60417769, /* 70280 (1633) [ 0,  0,  1,  0,  1,  0, -1,  0,  0] [ 9,  3,  9] -1 */
    44825601, /* 70281 (1633) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 3,  9,  9] -1 */
    27701671, /* 70282 (1633) [ 0, -1,  0,  0,  0,  1,  1,  0,  0] [ 9,  9,  3]  1 */
    35559282, /* 70283 (1633) [ 0,  1,  0, -1,  0,  0,  0,  0, -1] [ 0,  6,  6] -1 */
    61715407, /* 70284 (1633) [ 0,  0, -1,  0,  1,  0,  1,  0,  0] [ 9,  9,  3] -1 */
    60423553, /* 70285 (1633) [ 1,  0,  0,  0,  0,  1,  0, -1,  0] [ 9,  3,  9] -1 */
    51145618, /* 70286 (1633) [ 0,  0, -1,  0,  1,  0, -1,  0,  0] [ 6,  0,  6] -1 */
    34022704, /* 70287 (1633) [ 0,  0,  1,  0, -1,  0, -1,  0,  0] [ 0,  0,  0] -1 */
    60410437, /* 70288 (1633) [-1,  0,  0,  0,  0,  1,  0,  1,  0] [ 9,  3,  9] -1 */
    34020120, /* 70289 (1633) [ 0, -1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    52443408, /* 70290 (1633) [ 0, -1,  0,  1,  0,  0,  0,  0, -1] [ 6,  6,  0] -1 */
    52444552, /* 70291 (1633) [ 0,  0, -1,  0, -1,  0,  1,  0,  0] [ 6,  6,  0] -1 */
    43291939, /* 70292 (1633) [ 0,  0, -1,  0, -1,  0, -1,  0,  0] [ 3,  3,  3] -1 */
    26403769, /* 70293 (1633) [ 0,  0, -1, -1,  0,  0,  0, -1,  0] [ 9,  3,  9]  1 */
    44821441, /* 70294 (1633) [-1,  0,  0,  0,  0, -1,  0, -1,  0] [ 3,  9,  9] -1 */
        9352, /* 70295 (1633) [ 0,  0, -1,  1,  0,  0,  0, -1,  0] [ 0,  0,  0]  1 */
    10822449, /* 70296 (1633) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 3,  9,  9]  1 */
    34028656, /* 70297 (1633) [ 1,  0,  0,  0,  0,  1,  0,  1,  0] [ 0,  0,  0] -1 */
    18435280, /* 70298 (1633) [ 0,  1,  0,  0,  0, -1, -1,  0,  0] [ 6,  6,  0]  1 */
    27703339, /* 70299 (1633) [ 0,  0, -1,  1,  0,  0,  0,  1,  0] [ 9,  9,  3]  1 */
     9274055, /* 70300 (1633) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 3,  3,  3]  1 */
        8872, /* 70301 (1633) [ 0,  0, -1, -1,  0,  0,  0,  1,  0] [ 0,  0,  0]  1 */
     9278311, /* 70302 (1633) [ 0, -1,  0,  0,  0, -1, -1,  0,  0] [ 3,  3,  3]  1 */
    27701599, /* 70303 (1633) [ 0, -1,  0,  0,  0, -1, -1,  0,  0] [ 9,  9,  3]  1 */
    10809329, /* 70304 (1633) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 3,  9,  9]  1 */
    35550754, /* 70305 (1633) [-1,  0,  0,  0,  0, -1,  0,  1,  0] [ 0,  6,  6] -1 */
    18432640, /* 70306 (1633) [ 0,  0, -1,  1,  0,  0,  0, -1,  0] [ 6,  6,  0]  1 */
    43290327, /* 70307 (1633) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 3,  3,  3] -1 */
    18430924, /* 70308 (1633) [ 0, -1,  0,  0,  0, -1,  1,  0,  0] [ 6,  6,  0]  1 */
    27697179, /* 70309 (1633) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 9,  9,  3]  1 */
    61722583, /* 70310 (1633) [ 1,  0,  0,  0,  0, -1,  0,  1,  0] [ 9,  9,  3] -1 */
     1551594, /* 70311 (1633) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
    43293415, /* 70312 (1633) [ 0,  0,  1,  0, -1,  0,  1,  0,  0] [ 3,  3,  3] -1 */
     1542946, /* 70313 (1633) [ 0, -1,  0,  0,  0,  1, -1,  0,  0] [ 0,  6,  6]  1 */
    17140530, /* 70314 (1633) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  6]  1 */
    61716703, /* 70315 (1633) [ 0,  0,  1,  0, -1,  0,  1,  0,  0] [ 9,  9,  3] -1 */
    27704311, /* 70316 (1633) [ 0,  0,  1, -1,  0,  0,  0,  1,  0] [ 9,  9,  3]  1 */
    26406913, /* 70317 (1633) [ 0,  1,  0,  0,  0, -1,  1,  0,  0] [ 9,  3,  9]  1 */
     1538634, /* 70318 (1633) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
     1547338, /* 70319 (1633) [ 0,  1,  0,  0,  0,  1,  1,  0,  0] [ 0,  6,  6]  1 */
    60416149, /* 70320 (1633) [ 0,  0, -1,  0, -1,  0, -1,  0,  0] [ 9,  3,  9] -1 */
    17135026, /* 70321 (1633) [ 0,  0,  1,  1,  0,  0,  0,  1,  0] [ 6,  0,  6]  1 */
    52442924, /* 70322 (1633) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 6,  6,  0] -1 */
    34021264, /* 70323 (1633) [ 0,  0, -1,  0, -1,  0,  1,  0,  0] [ 0,  0,  0] -1 */
    18432160, /* 70324 (1633) [ 0,  0, -1, -1,  0,  0,  0,  1,  0] [ 6,  6,  0]  1 */
    52447296, /* 70325 (1633) [ 0,  1,  0, -1,  0,  0,  0,  0, -1] [ 6,  6,  0] -1 */
    17133082, /* 70326 (1633) [ 0,  0, -1, -1,  0,  0,  0,  1,  0] [ 6,  0,  6]  1 */
    10813585, /* 70327 (1633) [ 0, -1,  0,  0,  0, -1, -1,  0,  0] [ 3,  9,  9]  1 */
    43295187, /* 70328 (1633) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 3,  3,  3] -1 */
    61714103, /* 70329 (1633) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 9,  9,  3] -1 */
    34021408, /* 70330 (1633) [ 0,  0, -1,  0,  1,  0, -1,  0,  0] [ 0,  0,  0] -1 */
    34028596, /* 70331 (1633) [ 1,  0,  0,  0,  0, -1,  0, -1,  0] [ 0,  0,  0] -1 */
    35557978, /* 70332 (1633) [ 0,  0,  1,  0, -1,  0, -1,  0,  0] [ 0,  6,  6] -1 */
    61709515, /* 70333 (1633) [-1,  0,  0,  0,  0,  1,  0,  1,  0] [ 9,  9,  3] -1 */
    43292119, /* 70334 (1633) [ 0,  0, -1,  0,  1,  0,  1,  0,  0] [ 3,  3,  3] -1 */
    10813657, /* 70335 (1633) [ 0, -1,  0,  0,  0,  1,  1,  0,  0] [ 3,  9,  9]  1 */
    10809165, /* 70336 (1633) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 3,  9,  9]  1 */
    44827393, /* 70337 (1633) [ 0,  0, -1,  0,  1,  0,  1,  0,  0] [ 3,  9,  9] -1 */
    61717991, /* 70338 (1633) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 9,  9,  3] -1 */
    26398265, /* 70339 (1633) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 9,  3,  9]  1 */
    51145474, /* 70340 (1633) [ 0,  0, -1,  0, -1,  0,  1,  0,  0] [ 6,  0,  6] -1 */
    60410377, /* 70341 (1633) [-1,  0,  0,  0,  0, -1,  0, -1,  0] [ 9,  3,  9] -1 */
    43293559, /* 70342 (1633) [ 0,  0,  1,  0,  1,  0, -1,  0,  0] [ 3,  3,  3] -1 */
     9280051, /* 70343 (1633) [ 0,  0, -1,  1,  0,  0,  0,  1,  0] [ 3,  3,  3]  1 */
    35550802, /* 70344 (1633) [-1,  0,  0,  0,  0,  1,  0, -1,  0] [ 0,  6,  6] -1 */
    10815325, /* 70345 (1633) [ 0,  0, -1,  1,  0,  0,  0,  1,  0] [ 3,  9,  9]  1 */
    27706027, /* 70346 (1633) [ 0,  1,  0,  0,  0,  1, -1,  0,  0] [ 9,  9,  3]  1 */
       16484, /* 70347 (1634) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    61722687, /* 70348 (1634) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 9,  9,  3] -1 */
    44834513, /* 70349 (1634) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 3,  9,  9] -1 */
    44830237, /* 70350 (1634) [ 0,  1,  0,  0,  0,  1, -1,  0,  0] [ 3,  9,  9] -1 */
    34015480, /* 70351 (1634) [-1,  0,  0,  0,  0, -1,  0,  1,  0] [ 0,  0,  0] -1 */
    17127570, /* 70352 (1634) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6]  1 */
    17140694, /* 70353 (1634) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
    17134534, /* 70354 (1634) [ 0,  0,  1, -1,  0,  0,  0, -1,  0] [ 6,  0,  6]  1 */
    43294963, /* 70355 (1634) [ 0,  1,  0,  0,  0,  1, -1,  0,  0] [ 3,  3,  3] -1 */
     9279715, /* 70356 (1634) [ 0,  0, -1,  0, -1,  0, -1,  0,  0] [ 3,  3,  3]  1 */
    27703003, /* 70357 (1634) [ 0,  0, -1,  0, -1,  0, -1,  0,  0] [ 9,  9,  3]  1 */
    26406689, /* 70358 (1634) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 9,  3,  9]  1 */
    51147094, /* 70359 (1634) [ 0,  0,  1,  0,  1,  0,  1,  0,  0] [ 6,  0,  6] -1 */
     1538474, /* 70360 (1634) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
    10809217, /* 70361 (1634) [-1,  0,  0,  0,  0, -1,  0, -1,  0] [ 3,  9,  9]  1 */
    61713895, /* 70362 (1634) [ 0, -1,  0,  0,  0,  1,  1,  0,  0] [ 9,  9,  3] -1 */
    60410325, /* 70363 (1634) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 9,  3,  9] -1 */
    18430960, /* 70364 (1634) [ 0, -1,  0,  0,  0,  1, -1,  0,  0] [ 6,  6,  0]  1 */
       16320, /* 70365 (1634) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    17131882, /* 70366 (1634) [ 0, -1,  0,  0,  0,  1, -1,  0,  0] [ 6,  0,  6]  1 */
    18426648, /* 70367 (1634) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
    17136274, /* 70368 (1634) [ 0,  1,  0,  0,  0,  1,  1,  0,  0] [ 6,  0,  6]  1 */
    51148218, /* 70369 (1634) [ 0,  1,  0, -1,  0,  0,  0,  0, -1] [ 6,  0,  6] -1 */
     9278103, /* 70370 (1634) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 3,  3,  3]  1 */
    26407173, /* 70371 (1634) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 9,  3,  9]  1 */
    27701391, /* 70372 (1634) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 9,  9,  3]  1 */
    35556682, /* 70373 (1634) [ 0,  0, -1,  0,  1,  0, -1,  0,  0] [ 0,  6,  6] -1 */
    27710359, /* 70374 (1634) [ 1,  0,  0,  0,  0, -1,  0,  1,  0] [ 9,  9,  3]  1 */
    43299399, /* 70375 (1634) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 3,  3,  3] -1 */
    51143846, /* 70376 (1634) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 6,  0,  6] -1 */
    51146914, /* 70377 (1634) [ 0,  0,  1,  0, -1,  0, -1,  0,  0] [ 6,  0,  6] -1 */
    27704479, /* 70378 (1634) [ 0,  0,  1,  0, -1,  0,  1,  0,  0] [ 9,  9,  3]  1 */
    34024496, /* 70379 (1634) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    52447784, /* 70380 (1634) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 6,  6,  0] -1 */
    52438768, /* 70381 (1634) [-1,  0,  0,  0,  0, -1,  0,  1,  0] [ 6,  6,  0] -1 */
    43286279, /* 70382 (1634) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 3,  3,  3] -1 */
    10814989, /* 70383 (1634) [ 0,  0, -1,  0, -1,  0, -1,  0,  0] [ 3,  9,  9]  1 */
    61709567, /* 70384 (1634) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 9,  9,  3] -1 */
    35563870, /* 70385 (1634) [ 1,  0,  0,  0,  0, -1,  0, -1,  0] [ 0,  6,  6] -1 */
    35555394, /* 70386 (1634) [ 0, -1,  0,  1,  0,  0,  0,  0, -1] [ 0,  6,  6] -1 */
    52445992, /* 70387 (1634) [ 0,  0,  1,  0, -1,  0, -1,  0,  0] [ 6,  6,  0] -1 */
        7636, /* 70388 (1634) [ 0, -1,  0,  0,  0, -1,  1,  0,  0] [ 0,  0,  0]  1 */
    52451944, /* 70389 (1634) [ 1,  0,  0,  0,  0,  1,  0,  1,  0] [ 6,  6,  0] -1 */
     9273943, /* 70390 (1634) [-1,  0,  0,  0,  0, -1,  0, -1,  0] [ 3,  3,  3]  1 */
     1542910, /* 70391 (1634) [ 0, -1,  0,  0,  0, -1,  1,  0,  0] [ 0,  6,  6]  1 */
    27701879, /* 70392 (1634) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 9,  9,  3]  1 */
    60419137, /* 70393 (1634) [ 0,  1,  0,  0,  0, -1,  1,  0,  0] [ 9,  3,  9] -1 */
    27697291, /* 70394 (1634) [-1,  0,  0,  0,  0,  1,  0,  1,  0] [ 9,  9,  3]  1 */
    26405545, /* 70395 (1634) [ 0,  0,  1,  0,  1,  0, -1,  0,  0] [ 9,  3,  9]  1 */
    10813377, /* 70396 (1634) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 3,  9,  9]  1 */
     9279895, /* 70397 (1634) [ 0,  0, -1,  0,  1,  0,  1,  0,  0] [ 3,  3,  3]  1 */
     1544146, /* 70398 (1634) [ 0,  0, -1, -1,  0,  0,  0,  1,  0] [ 0,  6,  6]  1 */
    60423449, /* 70399 (1634) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 9,  3,  9] -1 */
    51148706, /* 70400 (1634) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 6,  0,  6] -1 */
     1544626, /* 70401 (1634) [ 0,  0, -1,  1,  0,  0,  0, -1,  0] [ 0,  6,  6]  1 */
     1547266, /* 70402 (1634) [ 0,  1,  0,  0,  0, -1, -1,  0,  0] [ 0,  6,  6]  1 */
    26411329, /* 70403 (1634) [ 1,  0,  0,  0,  0,  1,  0, -1,  0] [ 9,  3,  9]  1 */
    17136202, /* 70404 (1634) [ 0,  1,  0,  0,  0, -1, -1,  0,  0] [ 6,  0,  6]  1 */
    51139738, /* 70405 (1634) [-1,  0,  0,  0,  0,  1,  0, -1,  0] [ 6,  0,  6] -1 */
    35559770, /* 70406 (1634) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 0,  6,  6] -1 */
    52438816, /* 70407 (1634) [-1,  0,  0,  0,  0,  1,  0, -1,  0] [ 6,  6,  0] -1 */
        3200, /* 70408 (1634) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
     1545598, /* 70409 (1634) [ 0,  0,  1, -1,  0,  0,  0, -1,  0] [ 0,  6,  6]  1 */
    18439608, /* 70410 (1634) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
        3360, /* 70411 (1634) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
       10324, /* 70412 (1634) [ 0,  0,  1, -1,  0,  0,  0, -1,  0] [ 0,  0,  0]  1 */
    35563930, /* 70413 (1634) [ 1,  0,  0,  0,  0,  1,  0,  1,  0] [ 0,  6,  6] -1 */
    44825881, /* 70414 (1634) [ 0, -1,  0,  0,  0,  1,  1,  0,  0] [ 3,  9,  9] -1 */
    35556538, /* 70415 (1634) [ 0,  0, -1,  0, -1,  0,  1,  0,  0] [ 0,  6,  6] -1 */
    27706251, /* 70416 (1634) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 9,  9,  3]  1 */
    34024008, /* 70417 (1634) [ 0,  1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    18439772, /* 70418 (1634) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    52444696, /* 70419 (1634) [ 0,  0, -1,  0,  1,  0, -1,  0,  0] [ 6,  6,  0] -1 */
    52451884, /* 70420 (1634) [ 1,  0,  0,  0,  0, -1,  0, -1,  0] [ 6,  6,  0] -1 */
     9281191, /* 70421 (1634) [ 0,  0,  1,  0, -1,  0,  1,  0,  0] [ 3,  3,  3]  1 */
    60415993, /* 70422 (1634) [ 0,  0, -1, -1,  0,  0,  0, -1,  0] [ 9,  3,  9] -1 */
    10822345, /* 70423 (1634) [ 1,  0,  0,  0,  0, -1,  0,  1,  0] [ 3,  9,  9]  1 */
    17127410, /* 70424 (1634) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
    44834673, /* 70425 (1634) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 3,  9,  9] -1 */
    43292275, /* 70426 (1634) [ 0,  0, -1,  1,  0,  0,  0,  1,  0] [ 3,  3,  3] -1 */
    51139690, /* 70427 (1634) [-1,  0,  0,  0,  0, -1,  0,  1,  0] [ 6,  0,  6] -1 */
    18426488, /* 70428 (1634) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    61715563, /* 70429 (1634) [ 0,  0, -1,  1,  0,  0,  0,  1,  0] [ 9,  9,  3] -1 */
    51144330, /* 70430 (1634) [ 0, -1,  0,  1,  0,  0,  0,  0, -1] [ 6,  0,  6] -1 */
    26403925, /* 70431 (1634) [ 0,  0, -1,  0, -1,  0, -1,  0,  0] [ 9,  3,  9]  1 */
    43290535, /* 70432 (1634) [ 0, -1,  0,  0,  0, -1, -1,  0,  0] [ 3,  3,  3] -1 */
    61713823, /* 70433 (1634) [ 0, -1,  0,  0,  0, -1, -1,  0,  0] [ 9,  9,  3] -1 */
    44821553, /* 70434 (1634) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 3,  9,  9] -1 */
    34022884, /* 70435 (1634) [ 0,  0,  1,  0,  1,  0,  1,  0,  0] [ 0,  0,  0] -1 */
    52446172, /* 70436 (1634) [ 0,  0,  1,  0,  1,  0,  1,  0,  0] [ 6,  6,  0] -1 */
    18435352, /* 70437 (1634) [ 0,  1,  0,  0,  0,  1,  1,  0,  0] [ 6,  6,  0]  1 */
    61718215, /* 70438 (1634) [ 0,  1,  0,  0,  0, -1,  1,  0,  0] [ 9,  9,  3] -1 */
    60419173, /* 70439 (1634) [ 0,  1,  0,  0,  0,  1, -1,  0,  0] [ 9,  3,  9] -1 */
       10816, /* 70440 (1634) [ 0,  0,  1,  1,  0,  0,  0,  1,  0] [ 0,  0,  0]  1 */
    43286115, /* 70441 (1634) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 3,  3,  3] -1 */
    18434104, /* 70442 (1634) [ 0,  0,  1,  1,  0,  0,  0,  1,  0] [ 6,  6,  0]  1 */
     9278591, /* 70443 (1634) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 3,  3,  3]  1 */
    61709403, /* 70444 (1634) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 9,  9,  3] -1 */
     9282963, /* 70445 (1634) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 3,  3,  3]  1 */
    43293247, /* 70446 (1634) [ 0,  0,  1, -1,  0,  0,  0,  1,  0] [ 3,  3,  3] -1 */
    10818237, /* 70447 (1634) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 3,  9,  9]  1 */
    61716535, /* 70448 (1634) [ 0,  0,  1, -1,  0,  0,  0,  1,  0] [ 9,  9,  3] -1 */
    34015528, /* 70449 (1634) [-1,  0,  0,  0,  0,  1,  0, -1,  0] [ 0,  0,  0] -1 */
       12064, /* 70450 (1634) [ 0,  1,  0,  0,  0,  1,  1,  0,  0] [ 0,  0,  0]  1 */
    10809277, /* 70451 (1634) [-1,  0,  0,  0,  0,  1,  0,  1,  0] [ 3,  9,  9]  1 */
    35554910, /* 70452 (1634) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 0,  6,  6] -1 */
     1551758, /* 70453 (1634) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
    17133562, /* 70454 (1634) [ 0,  0, -1,  1,  0,  0,  0, -1,  0] [ 6,  0,  6]  1 */
    10815169, /* 70455 (1634) [ 0,  0, -1,  0,  1,  0,  1,  0,  0] [ 3,  9,  9]  1 */
    17131846, /* 70456 (1634) [ 0, -1,  0,  0,  0, -1,  1,  0,  0] [ 6,  0,  6]  1 */
    18433612, /* 70457 (1634) [ 0,  0,  1, -1,  0,  0,  0, -1,  0] [ 6,  6,  0]  1 */
       11992, /* 70458 (1634) [ 0,  1,  0,  0,  0, -1, -1,  0,  0] [ 0,  0,  0]  1 */
    60417937, /* 70459 (1634) [ 0,  0,  1,  1,  0,  0,  0, -1,  0] [ 9,  3,  9] -1 */
    44825809, /* 70460 (1634) [ 0, -1,  0,  0,  0, -1, -1,  0,  0] [ 3,  9,  9] -1 */
     9282479, /* 70461 (1634) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 3,  3,  3]  1 */
    27705767, /* 70462 (1634) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 9,  9,  3]  1 */
    35558158, /* 70463 (1634) [ 0,  0,  1,  0,  1,  0,  1,  0,  0] [ 0,  6,  6] -1 */
        7672, /* 70464 (1634) [ 0, -1,  0,  0,  0,  1, -1,  0,  0] [ 0,  0,  0]  1 */
    51152866, /* 70465 (1634) [ 1,  0,  0,  0,  0,  1,  0,  1,  0] [ 6,  0,  6] -1 */
    26398153, /* 70466 (1634) [-1,  0,  0,  0,  0, -1,  0, -1,  0] [ 9,  3,  9]  1 */
     9281335, /* 70467 (1634) [ 0,  0,  1,  0,  1,  0, -1,  0,  0] [ 3,  3,  3]  1 */
     1546090, /* 70468 (1634) [ 0,  0,  1,  1,  0,  0,  0,  1,  0] [ 0,  6,  6]  1 */
    44821389, /* 70469 (1634) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 3,  9,  9] -1 */
     9287119, /* 70470 (1634) [ 1,  0,  0,  0,  0,  1,  0, -1,  0] [ 3,  3,  3]  1 */
    26405401, /* 70471 (1634) [ 0,  0,  1,  0, -1,  0,  1,  0,  0] [ 9,  3,  9]  1 */
    51152806, /* 70472 (1634) [ 1,  0,  0,  0,  0, -1,  0, -1,  0] [ 6,  0,  6] -1 */
    35559282, /* 70473 (1634) [ 0,  1,  0, -1,  0,  0,  0,  0, -1] [ 0,  6,  6] -1 */
    60410489, /* 70474 (1634) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 9,  3,  9] -1 */
    51145618, /* 70475 (1634) [ 0,  0, -1,  0,  1,  0, -1,  0,  0] [ 6,  0,  6] -1 */
    34022704, /* 70476 (1634) [ 0,  0,  1,  0, -1,  0, -1,  0,  0] [ 0,  0,  0] -1 */
    10816465, /* 70477 (1634) [ 0,  0,  1,  0, -1,  0,  1,  0,  0] [ 3,  9,  9]  1 */
     9287071, /* 70478 (1634) [ 1,  0,  0,  0,  0, -1,  0,  1,  0] [ 3,  3,  3]  1 */
    44827549, /* 70479 (1634) [ 0,  0, -1,  1,  0,  0,  0,  1,  0] [ 3,  9,  9] -1 */
    61718251, /* 70480 (1634) [ 0,  1,  0,  0,  0,  1, -1,  0,  0] [ 9,  9,  3] -1 */
    34020120, /* 70481 (1634) [ 0, -1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    52443408, /* 70482 (1634) [ 0, -1,  0,  1,  0,  0,  0,  0, -1] [ 6,  6,  0] -1 */
    52444552, /* 70483 (1634) [ 0,  0, -1,  0, -1,  0,  1,  0,  0] [ 6,  6,  0] -1 */
    26402313, /* 70484 (1634) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 9,  3,  9]  1 */
    44830201, /* 70485 (1634) [ 0,  1,  0,  0,  0, -1,  1,  0,  0] [ 3,  9,  9] -1 */
    26404105, /* 70486 (1634) [ 0,  0, -1,  0,  1,  0,  1,  0,  0] [ 9,  3,  9]  1 */
        9352, /* 70487 (1634) [ 0,  0, -1,  1,  0,  0,  0, -1,  0] [ 0,  0,  0]  1 */
    34028656, /* 70488 (1634) [ 1,  0,  0,  0,  0,  1,  0,  1,  0] [ 0,  0,  0] -1 */
    18435280, /* 70489 (1634) [ 0,  1,  0,  0,  0, -1, -1,  0,  0] [ 6,  6,  0]  1 */
    27704623, /* 70490 (1634) [ 0,  0,  1,  0,  1,  0, -1,  0,  0] [ 9,  9,  3]  1 */
    61715071, /* 70491 (1634) [ 0,  0, -1, -1,  0,  0,  0, -1,  0] [ 9,  9,  3] -1 */
    10813865, /* 70492 (1634) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 3,  9,  9]  1 */
    43299239, /* 70493 (1634) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 3,  3,  3] -1 */
        8872, /* 70494 (1634) [ 0,  0, -1, -1,  0,  0,  0,  1,  0] [ 0,  0,  0]  1 */
    44828521, /* 70495 (1634) [ 0,  0,  1, -1,  0,  0,  0,  1,  0] [ 3,  9,  9] -1 */
    61722527, /* 70496 (1634) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 9,  9,  3] -1 */
    27710407, /* 70497 (1634) [ 1,  0,  0,  0,  0,  1,  0, -1,  0] [ 9,  9,  3]  1 */
    60423609, /* 70498 (1634) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 9,  3,  9] -1 */
     9274003, /* 70499 (1634) [-1,  0,  0,  0,  0,  1,  0,  1,  0] [ 3,  3,  3]  1 */
    35550754, /* 70500 (1634) [-1,  0,  0,  0,  0, -1,  0,  1,  0] [ 0,  6,  6] -1 */
    61717015, /* 70501 (1634) [ 0,  0,  1,  1,  0,  0,  0, -1,  0] [ 9,  9,  3] -1 */
    18432640, /* 70502 (1634) [ 0,  0, -1,  1,  0,  0,  0, -1,  0] [ 6,  6,  0]  1 */
    18430924, /* 70503 (1634) [ 0, -1,  0,  0,  0, -1,  1,  0,  0] [ 6,  6,  0]  1 */
     1551594, /* 70504 (1634) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
     1542946, /* 70505 (1634) [ 0, -1,  0,  0,  0,  1, -1,  0,  0] [ 0,  6,  6]  1 */
    17140530, /* 70506 (1634) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  6]  1 */
    43290607, /* 70507 (1634) [ 0, -1,  0,  0,  0,  1,  1,  0,  0] [ 3,  3,  3] -1 */
     1538634, /* 70508 (1634) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
    60414745, /* 70509 (1634) [ 0, -1,  0,  0,  0, -1, -1,  0,  0] [ 9,  3,  9] -1 */
    60414817, /* 70510 (1634) [ 0, -1,  0,  0,  0,  1,  1,  0,  0] [ 9,  3,  9] -1 */
     1547338, /* 70511 (1634) [ 0,  1,  0,  0,  0,  1,  1,  0,  0] [ 0,  6,  6]  1 */
    10817753, /* 70512 (1634) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 3,  9,  9]  1 */
    17135026, /* 70513 (1634) [ 0,  0,  1,  1,  0,  0,  0,  1,  0] [ 6,  0,  6]  1 */
    52442924, /* 70514 (1634) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 6,  6,  0] -1 */
    34021264, /* 70515 (1634) [ 0,  0, -1,  0, -1,  0,  1,  0,  0] [ 0,  0,  0] -1 */
    18432160, /* 70516 (1634) [ 0,  0, -1, -1,  0,  0,  0,  1,  0] [ 6,  6,  0]  1 */
    44827057, /* 70517 (1634) [ 0,  0, -1, -1,  0,  0,  0, -1,  0] [ 3,  9,  9] -1 */
    10816609, /* 70518 (1634) [ 0,  0,  1,  0,  1,  0, -1,  0,  0] [ 3,  9,  9]  1 */
    52447296, /* 70519 (1634) [ 0,  1,  0, -1,  0,  0,  0,  0, -1] [ 6,  6,  0] -1 */
    17133082, /* 70520 (1634) [ 0,  0, -1, -1,  0,  0,  0,  1,  0] [ 6,  0,  6]  1 */
    34021408, /* 70521 (1634) [ 0,  0, -1,  0,  1,  0, -1,  0,  0] [ 0,  0,  0] -1 */
    10822393, /* 70522 (1634) [ 1,  0,  0,  0,  0,  1,  0, -1,  0] [ 3,  9,  9]  1 */
    34028596, /* 70523 (1634) [ 1,  0,  0,  0,  0, -1,  0, -1,  0] [ 0,  0,  0] -1 */
    35557978, /* 70524 (1634) [ 0,  0,  1,  0, -1,  0, -1,  0,  0] [ 0,  6,  6] -1 */
    44829001, /* 70525 (1634) [ 0,  0,  1,  1,  0,  0,  0, -1,  0] [ 3,  9,  9] -1 */
    26411281, /* 70526 (1634) [ 1,  0,  0,  0,  0, -1,  0,  1,  0] [ 9,  3,  9]  1 */
    60416485, /* 70527 (1634) [ 0,  0, -1,  1,  0,  0,  0,  1,  0] [ 9,  3,  9] -1 */
    43293727, /* 70528 (1634) [ 0,  0,  1,  1,  0,  0,  0, -1,  0] [ 3,  3,  3] -1 */
    27697231, /* 70529 (1634) [-1,  0,  0,  0,  0, -1,  0, -1,  0] [ 9,  9,  3]  1 */
    26402801, /* 70530 (1634) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 9,  3,  9]  1 */
    60417457, /* 70531 (1634) [ 0,  0,  1, -1,  0,  0,  0,  1,  0] [ 9,  3,  9] -1 */
    27703183, /* 70532 (1634) [ 0,  0, -1,  0,  1,  0,  1,  0,  0] [ 9,  9,  3]  1 */
    51145474, /* 70533 (1634) [ 0,  0, -1,  0, -1,  0,  1,  0,  0] [ 6,  0,  6] -1 */
    43294927, /* 70534 (1634) [ 0,  1,  0,  0,  0, -1,  1,  0,  0] [ 3,  3,  3] -1 */
    26398213, /* 70535 (1634) [-1,  0,  0,  0,  0,  1,  0,  1,  0] [ 9,  3,  9]  1 */
    35550802, /* 70536 (1634) [-1,  0,  0,  0,  0,  1,  0, -1,  0] [ 0,  6,  6] -1 */
    43291783, /* 70537 (1634) [ 0,  0, -1, -1,  0,  0,  0, -1,  0] [ 3,  3,  3] -1 */
    34019636, /* 70538 (1634) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  0] -1 */
       16484, /* 70539 (1635) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    17127570, /* 70540 (1635) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6]  1 */
    17140694, /* 70541 (1635) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
     9279715, /* 70542 (1635) [ 0,  0, -1,  0, -1,  0, -1,  0,  0] [ 3,  3,  3]  1 */
    27703003, /* 70543 (1635) [ 0,  0, -1,  0, -1,  0, -1,  0,  0] [ 9,  9,  3]  1 */
    27705991, /* 70544 (1635) [ 0,  1,  0,  0,  0, -1,  1,  0,  0] [ 9,  9,  3]  1 */
    26406949, /* 70545 (1635) [ 0,  1,  0,  0,  0,  1, -1,  0,  0] [ 9,  3,  9]  1 */
    60296719, /* 70546 (1635) [ 0, -1,  0,  0,  0,  1,  1,  0,  0] [ 9,  3,  3] -1 */
    10809217, /* 70547 (1635) [-1,  0,  0,  0,  0, -1,  0, -1,  0] [ 3,  9,  9]  1 */
     9273891, /* 70548 (1635) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 3,  3,  3]  1 */
    43417441, /* 70549 (1635) [ 1,  0,  0,  0,  0,  1,  0, -1,  0] [ 3,  3,  9] -1 */
    52556810, /* 70550 (1635) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    10816297, /* 70551 (1635) [ 0,  0,  1, -1,  0,  0,  0,  1,  0] [ 3,  9,  9]  1 */
     1542686, /* 70552 (1635) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 0,  6,  6]  1 */
    17136274, /* 70553 (1635) [ 0,  1,  0,  0,  0,  1,  1,  0,  0] [ 6,  0,  6]  1 */
    51028816, /* 70554 (1635) [ 0,  0,  1,  0, -1,  0, -1,  0,  0] [ 6,  0,  0] -1 */
    27710359, /* 70555 (1635) [ 1,  0,  0,  0,  0, -1,  0,  1,  0] [ 9,  9,  3]  1 */
    27704479, /* 70556 (1635) [ 0,  0,  1,  0, -1,  0,  1,  0,  0] [ 9,  9,  3]  1 */
    52570042, /* 70557 (1635) [ 1,  0,  0,  0,  0,  1,  0,  1,  0] [ 6,  6,  6] -1 */
    60299359, /* 70558 (1635) [ 0,  0,  1, -1,  0,  0,  0,  1,  0] [ 9,  3,  3] -1 */
    10813377, /* 70559 (1635) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 3,  9,  9]  1 */
     9279895, /* 70560 (1635) [ 0,  0, -1,  0,  1,  0,  1,  0,  0] [ 3,  3,  3]  1 */
    52562482, /* 70561 (1635) [ 0,  0, -1, -1,  0,  0,  0,  1,  0] [ 6,  6,  6] -1 */
    44716471, /* 70562 (1635) [ 1,  0,  0,  0,  0, -1,  0,  1,  0] [ 3,  9,  3] -1 */
       10324, /* 70563 (1635) [ 0,  0,  1, -1,  0,  0,  0, -1,  0] [ 0,  0,  0]  1 */
    17133250, /* 70564 (1635) [ 0,  0, -1,  0, -1,  0,  1,  0,  0] [ 6,  0,  6]  1 */
    44710591, /* 70565 (1635) [ 0,  0,  1,  0, -1,  0,  1,  0,  0] [ 3,  9,  3] -1 */
     9282703, /* 70566 (1635) [ 0,  1,  0,  0,  0, -1,  1,  0,  0] [ 3,  3,  3]  1 */
        7412, /* 70567 (1635) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34146806, /* 70568 (1635) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    43404265, /* 70569 (1635) [-1,  0,  0,  0,  0, -1,  0, -1,  0] [ 3,  3,  9] -1 */
    18439772, /* 70570 (1635) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    34142106, /* 70571 (1635) [ 0,  1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  6] -1 */
    51034708, /* 70572 (1635) [ 1,  0,  0,  0,  0, -1,  0, -1,  0] [ 6,  0,  0] -1 */
    17127410, /* 70573 (1635) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
    44716519, /* 70574 (1635) [ 1,  0,  0,  0,  0,  1,  0, -1,  0] [ 3,  9,  3] -1 */
    26402593, /* 70575 (1635) [ 0, -1,  0,  0,  0,  1,  1,  0,  0] [ 9,  3,  9]  1 */
    35441184, /* 70576 (1635) [ 0,  1,  0, -1,  0,  0,  0,  0, -1] [ 0,  6,  0] -1 */
    52563934, /* 70577 (1635) [ 0,  0,  1, -1,  0,  0,  0, -1,  0] [ 6,  6,  6] -1 */
    51021536, /* 70578 (1635) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  0] -1 */
    17135994, /* 70579 (1635) [ 0,  1,  0, -1,  0,  0,  0,  0, -1] [ 6,  0,  6]  1 */
    60296647, /* 70580 (1635) [ 0, -1,  0,  0,  0, -1, -1,  0,  0] [ 9,  3,  3] -1 */
    18435352, /* 70581 (1635) [ 0,  1,  0,  0,  0,  1,  1,  0,  0] [ 6,  6,  0]  1 */
    18430700, /* 70582 (1635) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    18435560, /* 70583 (1635) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    10809277, /* 70584 (1635) [-1,  0,  0,  0,  0,  1,  0,  1,  0] [ 3,  9,  9]  1 */
    17133562, /* 70585 (1635) [ 0,  0, -1,  1,  0,  0,  0, -1,  0] [ 6,  0,  6]  1 */
    17131846, /* 70586 (1635) [ 0, -1,  0,  0,  0, -1,  1,  0,  0] [ 6,  0,  6]  1 */
    35445832, /* 70587 (1635) [ 1,  0,  0,  0,  0,  1,  0,  1,  0] [ 0,  6,  0] -1 */
    52556914, /* 70588 (1635) [-1,  0,  0,  0,  0,  1,  0, -1,  0] [ 6,  6,  6] -1 */
    44707783, /* 70589 (1635) [ 0, -1,  0,  0,  0,  1,  1,  0,  0] [ 3,  9,  3] -1 */
    26411225, /* 70590 (1635) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 9,  3,  9]  1 */
    17127514, /* 70591 (1635) [-1,  0,  0,  0,  0,  1,  0, -1,  0] [ 6,  0,  6]  1 */
    43408705, /* 70592 (1635) [ 0, -1,  0,  0,  0,  1,  1,  0,  0] [ 3,  3,  9] -1 */
     1538578, /* 70593 (1635) [-1,  0,  0,  0,  0,  1,  0, -1,  0] [ 0,  6,  6]  1 */
    61827553, /* 70594 (1635) [-1,  0,  0,  0,  0, -1,  0, -1,  0] [ 9,  9,  9] -1 */
    27710463, /* 70595 (1635) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 9,  9,  3]  1 */
        3256, /* 70596 (1635) [-1,  0,  0,  0,  0, -1,  0,  1,  0] [ 0,  0,  0]  1 */
     9282739, /* 70597 (1635) [ 0,  1,  0,  0,  0,  1, -1,  0,  0] [ 3,  3,  3]  1 */
    34139362, /* 70598 (1635) [ 0,  0, -1,  0, -1,  0,  1,  0,  0] [ 0,  0,  6] -1 */
    51030328, /* 70599 (1635) [ 0,  1,  0,  0,  0, -1, -1,  0,  0] [ 6,  0,  0] -1 */
    43413285, /* 70600 (1635) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 3,  3,  9] -1 */
    61832201, /* 70601 (1635) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 9,  9,  9] -1 */
    10816465, /* 70602 (1635) [ 0,  0,  1,  0, -1,  0,  1,  0,  0] [ 3,  9,  9]  1 */
    60292339, /* 70603 (1635) [-1,  0,  0,  0,  0,  1,  0,  1,  0] [ 9,  3,  3] -1 */
    60300815, /* 70604 (1635) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 9,  3,  3] -1 */
    26402313, /* 70605 (1635) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 9,  3,  9]  1 */
    18439660, /* 70606 (1635) [ 1,  0,  0,  0,  0, -1,  0, -1,  0] [ 6,  6,  0]  1 */
    43417337, /* 70607 (1635) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 3,  3,  9] -1 */
    27704623, /* 70608 (1635) [ 0,  0,  1,  0,  1,  0, -1,  0,  0] [ 9,  9,  3]  1 */
     9278311, /* 70609 (1635) [ 0, -1,  0,  0,  0, -1, -1,  0,  0] [ 3,  3,  3]  1 */
    27701599, /* 70610 (1635) [ 0, -1,  0,  0,  0, -1, -1,  0,  0] [ 9,  9,  3]  1 */
    43408425, /* 70611 (1635) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 3,  3,  9] -1 */
    27704311, /* 70612 (1635) [ 0,  0,  1, -1,  0,  0,  0,  1,  0] [ 9,  9,  3]  1 */
    34137958, /* 70613 (1635) [ 0, -1,  0,  0,  0, -1,  1,  0,  0] [ 0,  0,  6] -1 */
    43408913, /* 70614 (1635) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 3,  3,  9] -1 */
    17133082, /* 70615 (1635) [ 0,  0, -1, -1,  0,  0,  0,  1,  0] [ 6,  0,  6]  1 */
    10822393, /* 70616 (1635) [ 1,  0,  0,  0,  0,  1,  0, -1,  0] [ 3,  9,  9]  1 */
    10813657, /* 70617 (1635) [ 0, -1,  0,  0,  0,  1,  1,  0,  0] [ 3,  9,  9]  1 */
    10809165, /* 70618 (1635) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 3,  9,  9]  1 */
    43404377, /* 70619 (1635) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 3,  3,  9] -1 */
    61827665, /* 70620 (1635) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 9,  9,  9] -1 */
    35437296, /* 70621 (1635) [ 0, -1,  0,  1,  0,  0,  0,  0, -1] [ 0,  6,  0] -1 */
    44703343, /* 70622 (1635) [-1,  0,  0,  0,  0, -1,  0, -1,  0] [ 3,  9,  3] -1 */
    26398265, /* 70623 (1635) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 9,  3,  9]  1 */
    44710423, /* 70624 (1635) [ 0,  0,  1, -1,  0,  0,  0,  1,  0] [ 3,  9,  3] -1 */
    17133394, /* 70625 (1635) [ 0,  0, -1,  0,  1,  0, -1,  0,  0] [ 6,  0,  6]  1 */
    43412801, /* 70626 (1635) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 3,  3,  9] -1 */
       10660, /* 70627 (1635) [ 0,  0,  1,  0,  1,  0,  1,  0,  0] [ 0,  0,  0]  1 */
    17134534, /* 70628 (1635) [ 0,  0,  1, -1,  0,  0,  0, -1,  0] [ 6,  0,  6]  1 */
    26406689, /* 70629 (1635) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 9,  3,  9]  1 */
     1538474, /* 70630 (1635) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
    51034820, /* 70631 (1635) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  0] -1 */
    17140642, /* 70632 (1635) [ 1,  0,  0,  0,  0,  1,  0,  1,  0] [ 6,  0,  6]  1 */
    43410373, /* 70633 (1635) [ 0,  0, -1,  1,  0,  0,  0,  1,  0] [ 3,  3,  9] -1 */
    61833661, /* 70634 (1635) [ 0,  0, -1,  1,  0,  0,  0,  1,  0] [ 9,  9,  9] -1 */
    51034768, /* 70635 (1635) [ 1,  0,  0,  0,  0,  1,  0,  1,  0] [ 6,  0,  0] -1 */
    34139194, /* 70636 (1635) [ 0,  0, -1, -1,  0,  0,  0,  1,  0] [ 0,  0,  6] -1 */
    34140646, /* 70637 (1635) [ 0,  0,  1, -1,  0,  0,  0, -1,  0] [ 0,  0,  6] -1 */
    35432760, /* 70638 (1635) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  0] -1 */
       16372, /* 70639 (1635) [ 1,  0,  0,  0,  0, -1,  0, -1,  0] [ 0,  0,  0]  1 */
    10816777, /* 70640 (1635) [ 0,  0,  1,  1,  0,  0,  0, -1,  0] [ 3,  9,  9]  1 */
    61833325, /* 70641 (1635) [ 0,  0, -1,  0, -1,  0, -1,  0,  0] [ 9,  9,  9] -1 */
    27697291, /* 70642 (1635) [-1,  0,  0,  0,  0,  1,  0,  1,  0] [ 9,  9,  3]  1 */
    26404261, /* 70643 (1635) [ 0,  0, -1,  1,  0,  0,  0,  1,  0] [ 9,  3,  9]  1 */
    61836313, /* 70644 (1635) [ 0,  1,  0,  0,  0, -1,  1,  0,  0] [ 9,  9,  9] -1 */
    43404213, /* 70645 (1635) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 3,  3,  9] -1 */
     1544146, /* 70646 (1635) [ 0,  0, -1, -1,  0,  0,  0,  1,  0] [ 0,  6,  6]  1 */
    35445720, /* 70647 (1635) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  0] -1 */
    26411329, /* 70648 (1635) [ 1,  0,  0,  0,  0,  1,  0, -1,  0] [ 9,  3,  9]  1 */
    51034656, /* 70649 (1635) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  0] -1 */
    18439608, /* 70650 (1635) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
    51027376, /* 70651 (1635) [ 0,  0, -1,  0, -1,  0,  1,  0,  0] [ 6,  0,  0] -1 */
     9279559, /* 70652 (1635) [ 0,  0, -1, -1,  0,  0,  0, -1,  0] [ 3,  3,  3]  1 */
    27702847, /* 70653 (1635) [ 0,  0, -1, -1,  0,  0,  0, -1,  0] [ 9,  9,  3]  1 */
    10822289, /* 70654 (1635) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 3,  9,  9]  1 */
    52565602, /* 70655 (1635) [ 0,  1,  0,  0,  0, -1, -1,  0,  0] [ 6,  6,  6] -1 */
     9281191, /* 70656 (1635) [ 0,  0,  1,  0, -1,  0,  1,  0,  0] [ 3,  3,  3]  1 */
    44703403, /* 70657 (1635) [-1,  0,  0,  0,  0,  1,  0,  1,  0] [ 3,  9,  3] -1 */
    26398101, /* 70658 (1635) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 9,  3,  9]  1 */
    52569982, /* 70659 (1635) [ 1,  0,  0,  0,  0, -1,  0, -1,  0] [ 6,  6,  6] -1 */
    18426488, /* 70660 (1635) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    61833505, /* 70661 (1635) [ 0,  0, -1,  0,  1,  0,  1,  0,  0] [ 9,  9,  9] -1 */
    61827501, /* 70662 (1635) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 9,  9,  9] -1 */
    60305351, /* 70663 (1635) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 9,  3,  3] -1 */
    44711879, /* 70664 (1635) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 3,  9,  3] -1 */
    10818237, /* 70665 (1635) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 3,  9,  9]  1 */
       12064, /* 70666 (1635) [ 0,  1,  0,  0,  0,  1,  1,  0,  0] [ 0,  0,  0]  1 */
    18433768, /* 70667 (1635) [ 0,  0,  1,  0, -1,  0, -1,  0,  0] [ 6,  6,  0]  1 */
    60296439, /* 70668 (1635) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 9,  3,  3] -1 */
    34146754, /* 70669 (1635) [ 1,  0,  0,  0,  0,  1,  0,  1,  0] [ 0,  0,  6] -1 */
    18439720, /* 70670 (1635) [ 1,  0,  0,  0,  0,  1,  0,  1,  0] [ 6,  6,  0]  1 */
    61835113, /* 70671 (1635) [ 0,  0,  1,  1,  0,  0,  0, -1,  0] [ 9,  9,  9] -1 */
    35438440, /* 70672 (1635) [ 0,  0, -1,  0, -1,  0,  1,  0,  0] [ 0,  6,  0] -1 */
        7672, /* 70673 (1635) [ 0, -1,  0,  0,  0,  1, -1,  0,  0] [ 0,  0,  0]  1 */
    51025972, /* 70674 (1635) [ 0, -1,  0,  0,  0, -1,  1,  0,  0] [ 6,  0,  0] -1 */
    44709115, /* 70675 (1635) [ 0,  0, -1,  0, -1,  0, -1,  0,  0] [ 3,  9,  3] -1 */
    26398153, /* 70676 (1635) [-1,  0,  0,  0,  0, -1,  0, -1,  0] [ 9,  3,  9]  1 */
     1546090, /* 70677 (1635) [ 0,  0,  1,  1,  0,  0,  0,  1,  0] [ 0,  6,  6]  1 */
    60296927, /* 70678 (1635) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 9,  3,  3] -1 */
    60292279, /* 70679 (1635) [-1,  0,  0,  0,  0, -1,  0, -1,  0] [ 9,  3,  3] -1 */
     9287119, /* 70680 (1635) [ 1,  0,  0,  0,  0,  1,  0, -1,  0] [ 3,  3,  3]  1 */
    43410217, /* 70681 (1635) [ 0,  0, -1,  0,  1,  0,  1,  0,  0] [ 3,  3,  9] -1 */
    27701671, /* 70682 (1635) [ 0, -1,  0,  0,  0,  1,  1,  0,  0] [ 9,  9,  3]  1 */
    51027208, /* 70683 (1635) [ 0,  0, -1, -1,  0,  0,  0,  1,  0] [ 6,  0,  0] -1 */
    60292391, /* 70684 (1635) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 9,  3,  3] -1 */
    35439880, /* 70685 (1635) [ 0,  0,  1,  0, -1,  0, -1,  0,  0] [ 0,  6,  0] -1 */
     9287071, /* 70686 (1635) [ 1,  0,  0,  0,  0, -1,  0,  1,  0] [ 3,  3,  3]  1 */
    35438752, /* 70687 (1635) [ 0,  0, -1,  1,  0,  0,  0, -1,  0] [ 0,  6,  0] -1 */
       12272, /* 70688 (1635) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 0,  0,  0]  1 */
        9352, /* 70689 (1635) [ 0,  0, -1,  1,  0,  0,  0, -1,  0] [ 0,  0,  0]  1 */
    18435280, /* 70690 (1635) [ 0,  1,  0,  0,  0, -1, -1,  0,  0] [ 6,  6,  0]  1 */
    51026008, /* 70691 (1635) [ 0, -1,  0,  0,  0,  1, -1,  0,  0] [ 6,  0,  0] -1 */
    10809329, /* 70692 (1635) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 3,  9,  9]  1 */
    35432704, /* 70693 (1635) [-1,  0,  0,  0,  0,  1,  0, -1,  0] [ 0,  6,  0] -1 */
    43413061, /* 70694 (1635) [ 0,  1,  0,  0,  0,  1, -1,  0,  0] [ 3,  3,  9] -1 */
    61836573, /* 70695 (1635) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 9,  9,  9] -1 */
    44703291, /* 70696 (1635) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 3,  9,  3] -1 */
    10817753, /* 70697 (1635) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 3,  9,  9]  1 */
    52561022, /* 70698 (1635) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    35437036, /* 70699 (1635) [ 0, -1,  0,  0,  0, -1,  1,  0,  0] [ 0,  6,  0] -1 */
    17135026, /* 70700 (1635) [ 0,  0,  1,  1,  0,  0,  0,  1,  0] [ 6,  0,  6]  1 */
    35438584, /* 70701 (1635) [ 0,  0, -1,  0,  1,  0, -1,  0,  0] [ 0,  6,  0] -1 */
     1545934, /* 70702 (1635) [ 0,  0,  1,  0,  1,  0,  1,  0,  0] [ 0,  6,  6]  1 */
    51027688, /* 70703 (1635) [ 0,  0, -1,  1,  0,  0,  0, -1,  0] [ 6,  0,  0] -1 */
    34146694, /* 70704 (1635) [ 1,  0,  0,  0,  0, -1,  0, -1,  0] [ 0,  0,  6] -1 */
    52556866, /* 70705 (1635) [-1,  0,  0,  0,  0, -1,  0,  1,  0] [ 6,  6,  6] -1 */
    35441392, /* 70706 (1635) [ 0,  1,  0,  0,  0, -1, -1,  0,  0] [ 0,  6,  0] -1 */
    34141138, /* 70707 (1635) [ 0,  0,  1,  1,  0,  0,  0,  1,  0] [ 0,  0,  6] -1 */
    52564426, /* 70708 (1635) [ 0,  0,  1,  1,  0,  0,  0,  1,  0] [ 6,  6,  6] -1 */
    61834945, /* 70709 (1635) [ 0,  0,  1,  0,  1,  0, -1,  0,  0] [ 9,  9,  9] -1 */
     1544314, /* 70710 (1635) [ 0,  0, -1,  0, -1,  0,  1,  0,  0] [ 0,  6,  6]  1 */
    27697231, /* 70711 (1635) [-1,  0,  0,  0,  0, -1,  0, -1,  0] [ 9,  9,  3]  1 */
    60305455, /* 70712 (1635) [ 1,  0,  0,  0,  0,  1,  0, -1,  0] [ 9,  3,  3] -1 */
    35445772, /* 70713 (1635) [ 1,  0,  0,  0,  0, -1,  0, -1,  0] [ 0,  6,  0] -1 */
    34133682, /* 70714 (1635) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
    43411825, /* 70715 (1635) [ 0,  0,  1,  1,  0,  0,  0, -1,  0] [ 3,  3,  9] -1 */
    60298051, /* 70716 (1635) [ 0,  0, -1,  0, -1,  0, -1,  0,  0] [ 9,  3,  3] -1 */
    17140582, /* 70717 (1635) [ 1,  0,  0,  0,  0, -1,  0, -1,  0] [ 6,  0,  6]  1 */
    35432600, /* 70718 (1635) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  0] -1 */
    26402801, /* 70719 (1635) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 9,  3,  9]  1 */
     1547058, /* 70720 (1635) [ 0,  1,  0, -1,  0,  0,  0,  0, -1] [ 0,  6,  6]  1 */
    52569930, /* 70721 (1635) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
       10480, /* 70722 (1635) [ 0,  0,  1,  0, -1,  0, -1,  0,  0] [ 0,  0,  0]  1 */
    61840785, /* 70723 (1635) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 9,  9,  9] -1 */
    10815325, /* 70724 (1635) [ 0,  0, -1,  1,  0,  0,  0,  1,  0] [ 3,  9,  9]  1 */
        7896, /* 70725 (1635) [ 0, -1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    43411657, /* 70726 (1635) [ 0,  0,  1,  0,  1,  0, -1,  0,  0] [ 3,  3,  9] -1 */
     9281023, /* 70727 (1635) [ 0,  0,  1, -1,  0,  0,  0,  1,  0] [ 3,  3,  3]  1 */
    18430960, /* 70728 (1635) [ 0, -1,  0,  0,  0,  1, -1,  0,  0] [ 6,  6,  0]  1 */
       16320, /* 70729 (1635) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    27710303, /* 70730 (1635) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 9,  9,  3]  1 */
     9278103, /* 70731 (1635) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 3,  3,  3]  1 */
    27701391, /* 70732 (1635) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 9,  9,  3]  1 */
    43417497, /* 70733 (1635) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 3,  3,  9] -1 */
    60298387, /* 70734 (1635) [ 0,  0, -1,  1,  0,  0,  0,  1,  0] [ 9,  3,  3] -1 */
     9278383, /* 70735 (1635) [ 0, -1,  0,  0,  0,  1,  1,  0,  0] [ 3,  3,  3]  1 */
    35438272, /* 70736 (1635) [ 0,  0, -1, -1,  0,  0,  0,  1,  0] [ 0,  6,  0] -1 */
    61831921, /* 70737 (1635) [ 0, -1,  0,  0,  0, -1, -1,  0,  0] [ 9,  9,  9] -1 */
    10814989, /* 70738 (1635) [ 0,  0, -1,  0, -1,  0, -1,  0,  0] [ 3,  9,  9]  1 */
    34142314, /* 70739 (1635) [ 0,  1,  0,  0,  0, -1, -1,  0,  0] [ 0,  0,  6] -1 */
        7636, /* 70740 (1635) [ 0, -1,  0,  0,  0, -1,  1,  0,  0] [ 0,  0,  0]  1 */
    60292227, /* 70741 (1635) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 9,  3,  3] -1 */
        9040, /* 70742 (1635) [ 0,  0, -1,  0, -1,  0,  1,  0,  0] [ 0,  0,  0]  1 */
    51026232, /* 70743 (1635) [ 0, -1,  0,  1,  0,  0,  0,  0, -1] [ 6,  0,  0] -1 */
     1542910, /* 70744 (1635) [ 0, -1,  0,  0,  0, -1,  1,  0,  0] [ 0,  6,  6]  1 */
    61834633, /* 70745 (1635) [ 0,  0,  1, -1,  0,  0,  0,  1,  0] [ 9,  9,  9] -1 */
    34140982, /* 70746 (1635) [ 0,  0,  1,  0,  1,  0,  1,  0,  0] [ 0,  0,  6] -1 */
    27701879, /* 70747 (1635) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 9,  9,  3]  1 */
    44716415, /* 70748 (1635) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 3,  9,  3] -1 */
    44712363, /* 70749 (1635) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 3,  9,  3] -1 */
    35440216, /* 70750 (1635) [ 0,  0,  1,  1,  0,  0,  0,  1,  0] [ 0,  6,  0] -1 */
        3200, /* 70751 (1635) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    44710903, /* 70752 (1635) [ 0,  0,  1,  1,  0,  0,  0, -1,  0] [ 3,  9,  3] -1 */
     1545598, /* 70753 (1635) [ 0,  0,  1, -1,  0,  0,  0, -1,  0] [ 0,  6,  6]  1 */
    18432328, /* 70754 (1635) [ 0,  0, -1,  0, -1,  0,  1,  0,  0] [ 6,  6,  0]  1 */
        3360, /* 70755 (1635) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    10818013, /* 70756 (1635) [ 0,  1,  0,  0,  0,  1, -1,  0,  0] [ 3,  9,  9]  1 */
    60298231, /* 70757 (1635) [ 0,  0, -1,  0,  1,  0,  1,  0,  0] [ 9,  3,  3] -1 */
    17134870, /* 70758 (1635) [ 0,  0,  1,  0,  1,  0,  1,  0,  0] [ 6,  0,  6]  1 */
    44710735, /* 70759 (1635) [ 0,  0,  1,  0,  1,  0, -1,  0,  0] [ 3,  9,  3] -1 */
    44707991, /* 70760 (1635) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 3,  9,  3] -1 */
    52564090, /* 70761 (1635) [ 0,  0,  1,  0, -1,  0, -1,  0,  0] [ 6,  6,  6] -1 */
    26403925, /* 70762 (1635) [ 0,  0, -1,  0, -1,  0, -1,  0,  0] [ 9,  3,  9]  1 */
    52564270, /* 70763 (1635) [ 0,  0,  1,  0,  1,  0,  1,  0,  0] [ 6,  6,  6] -1 */
    44716575, /* 70764 (1635) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 3,  9,  3] -1 */
    51021696, /* 70765 (1635) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  0] -1 */
    34137994, /* 70766 (1635) [ 0, -1,  0,  0,  0,  1, -1,  0,  0] [ 0,  0,  6] -1 */
    43410037, /* 70767 (1635) [ 0,  0, -1,  0, -1,  0, -1,  0,  0] [ 3,  3,  9] -1 */
    27697343, /* 70768 (1635) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 9,  9,  3]  1 */
    34133626, /* 70769 (1635) [-1,  0,  0,  0,  0,  1,  0, -1,  0] [ 0,  0,  6] -1 */
     1551758, /* 70770 (1635) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
       11992, /* 70771 (1635) [ 0,  1,  0,  0,  0, -1, -1,  0,  0] [ 0,  0,  0]  1 */
    60301299, /* 70772 (1635) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 9,  3,  3] -1 */
     9282479, /* 70773 (1635) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 3,  3,  3]  1 */
    60299839, /* 70774 (1635) [ 0,  0,  1,  1,  0,  0,  0, -1,  0] [ 9,  3,  3] -1 */
    27705767, /* 70775 (1635) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 9,  9,  3]  1 */
    17136482, /* 70776 (1635) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 6,  0,  6]  1 */
    61840681, /* 70777 (1635) [ 1,  0,  0,  0,  0, -1,  0,  1,  0] [ 9,  9,  9] -1 */
    61834801, /* 70778 (1635) [ 0,  0,  1,  0, -1,  0,  1,  0,  0] [ 9,  9,  9] -1 */
     1547546, /* 70779 (1635) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 0,  6,  6]  1 */
    26405401, /* 70780 (1635) [ 0,  0,  1,  0, -1,  0,  1,  0,  0] [ 9,  3,  9]  1 */
    34139674, /* 70781 (1635) [ 0,  0, -1,  1,  0,  0,  0, -1,  0] [ 0,  0,  6] -1 */
    60299671, /* 70782 (1635) [ 0,  0,  1,  0,  1,  0, -1,  0,  0] [ 9,  3,  3] -1 */
    44703455, /* 70783 (1635) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 3,  9,  3] -1 */
    61836349, /* 70784 (1635) [ 0,  1,  0,  0,  0,  1, -1,  0,  0] [ 9,  9,  9] -1 */
    18432472, /* 70785 (1635) [ 0,  0, -1,  0,  1,  0, -1,  0,  0] [ 6,  6,  0]  1 */
    26404105, /* 70786 (1635) [ 0,  0, -1,  0,  1,  0,  1,  0,  0] [ 9,  3,  9]  1 */
    17134690, /* 70787 (1635) [ 0,  0,  1,  0, -1,  0, -1,  0,  0] [ 6,  0,  6]  1 */
    10822449, /* 70788 (1635) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 3,  9,  9]  1 */
    61833169, /* 70789 (1635) [ 0,  0, -1, -1,  0,  0,  0, -1,  0] [ 9,  9,  9] -1 */
    17127466, /* 70790 (1635) [-1,  0,  0,  0,  0, -1,  0,  1,  0] [ 6,  0,  6]  1 */
    27703339, /* 70791 (1635) [ 0,  0, -1,  1,  0,  0,  0,  1,  0] [ 9,  9,  3]  1 */
    10813865, /* 70792 (1635) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 3,  9,  9]  1 */
        8872, /* 70793 (1635) [ 0,  0, -1, -1,  0,  0,  0,  1,  0] [ 0,  0,  0]  1 */
    43413025, /* 70794 (1635) [ 0,  1,  0,  0,  0, -1,  1,  0,  0] [ 3,  3,  9] -1 */
    27710407, /* 70795 (1635) [ 1,  0,  0,  0,  0,  1,  0, -1,  0] [ 9,  9,  3]  1 */
     9274003, /* 70796 (1635) [-1,  0,  0,  0,  0,  1,  0,  1,  0] [ 3,  3,  3]  1 */
    18430924, /* 70797 (1635) [ 0, -1,  0,  0,  0, -1,  1,  0,  0] [ 6,  6,  0]  1 */
    43411513, /* 70798 (1635) [ 0,  0,  1,  0, -1,  0,  1,  0,  0] [ 3,  3,  9] -1 */
    27697179, /* 70799 (1635) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 9,  9,  3]  1 */
    35440060, /* 70800 (1635) [ 0,  0,  1,  0,  1,  0,  1,  0,  0] [ 0,  6,  0] -1 */
     1551594, /* 70801 (1635) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
     1542946, /* 70802 (1635) [ 0, -1,  0,  0,  0,  1, -1,  0,  0] [ 0,  6,  6]  1 */
    17140530, /* 70803 (1635) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  6]  1 */
    26406913, /* 70804 (1635) [ 0,  1,  0,  0,  0, -1,  1,  0,  0] [ 9,  3,  9]  1 */
    52570094, /* 70805 (1635) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    43417393, /* 70806 (1635) [ 1,  0,  0,  0,  0, -1,  0,  1,  0] [ 3,  3,  9] -1 */
    18432160, /* 70807 (1635) [ 0,  0, -1, -1,  0,  0,  0,  1,  0] [ 6,  6,  0]  1 */
    10816609, /* 70808 (1635) [ 0,  0,  1,  0,  1,  0, -1,  0,  0] [ 3,  9,  9]  1 */
    51030120, /* 70809 (1635) [ 0,  1,  0, -1,  0,  0,  0,  0, -1] [ 6,  0,  0] -1 */
    10813585, /* 70810 (1635) [ 0, -1,  0,  0,  0, -1, -1,  0,  0] [ 3,  9,  9]  1 */
    34142386, /* 70811 (1635) [ 0,  1,  0,  0,  0,  1,  1,  0,  0] [ 0,  0,  6] -1 */
    52565674, /* 70812 (1635) [ 0,  1,  0,  0,  0,  1,  1,  0,  0] [ 6,  6,  6] -1 */
    34140802, /* 70813 (1635) [ 0,  0,  1,  0, -1,  0, -1,  0,  0] [ 0,  0,  6] -1 */
    26411281, /* 70814 (1635) [ 1,  0,  0,  0,  0, -1,  0,  1,  0] [ 9,  3,  9]  1 */
    34139506, /* 70815 (1635) [ 0,  0, -1,  0,  1,  0, -1,  0,  0] [ 0,  0,  6] -1 */
    34142594, /* 70816 (1635) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    44709451, /* 70817 (1635) [ 0,  0, -1,  1,  0,  0,  0,  1,  0] [ 3,  9,  3] -1 */
    51029152, /* 70818 (1635) [ 0,  0,  1,  1,  0,  0,  0,  1,  0] [ 6,  0,  0] -1 */
    34138218, /* 70819 (1635) [ 0, -1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  6] -1 */
    27703183, /* 70820 (1635) [ 0,  0, -1,  0,  1,  0,  1,  0,  0] [ 9,  9,  3]  1 */
    34146642, /* 70821 (1635) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
    34137734, /* 70822 (1635) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    18431184, /* 70823 (1635) [ 0, -1,  0,  1,  0,  0,  0,  0, -1] [ 6,  6,  0]  1 */
    51021640, /* 70824 (1635) [-1,  0,  0,  0,  0,  1,  0, -1,  0] [ 6,  0,  0] -1 */
    61831993, /* 70825 (1635) [ 0, -1,  0,  0,  0,  1,  1,  0,  0] [ 9,  9,  9] -1 */
       16432, /* 70826 (1635) [ 1,  0,  0,  0,  0,  1,  0,  1,  0] [ 0,  0,  0]  1 */
    34133578, /* 70827 (1635) [-1,  0,  0,  0,  0, -1,  0,  1,  0] [ 0,  0,  6] -1 */
        3304, /* 70828 (1635) [-1,  0,  0,  0,  0,  1,  0, -1,  0] [ 0,  0,  0]  1 */
    17131882, /* 70829 (1635) [ 0, -1,  0,  0,  0,  1, -1,  0,  0] [ 6,  0,  6]  1 */
    18426648, /* 70830 (1635) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
    44708959, /* 70831 (1635) [ 0,  0, -1, -1,  0,  0,  0, -1,  0] [ 3,  9,  3] -1 */
    26411385, /* 70832 (1635) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 9,  3,  9]  1 */
    27704791, /* 70833 (1635) [ 0,  0,  1,  1,  0,  0,  0, -1,  0] [ 9,  9,  3]  1 */
     1538530, /* 70834 (1635) [-1,  0,  0,  0,  0, -1,  0,  1,  0] [ 0,  6,  6]  1 */
    26407173, /* 70835 (1635) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 9,  3,  9]  1 */
    52565882, /* 70836 (1635) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    26405713, /* 70837 (1635) [ 0,  0,  1,  1,  0,  0,  0, -1,  0] [ 9,  3,  9]  1 */
    26402521, /* 70838 (1635) [ 0, -1,  0,  0,  0, -1, -1,  0,  0] [ 9,  3,  9]  1 */
    44709295, /* 70839 (1635) [ 0,  0, -1,  0,  1,  0,  1,  0,  0] [ 3,  9,  3] -1 */
    51028996, /* 70840 (1635) [ 0,  0,  1,  0,  1,  0,  1,  0,  0] [ 6,  0,  0] -1 */
    35445884, /* 70841 (1635) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  0] -1 */
     9273943, /* 70842 (1635) [-1,  0,  0,  0,  0, -1,  0, -1,  0] [ 3,  3,  3]  1 */
    18435072, /* 70843 (1635) [ 0,  1,  0, -1,  0,  0,  0,  0, -1] [ 6,  6,  0]  1 */
    43408633, /* 70844 (1635) [ 0, -1,  0,  0,  0, -1, -1,  0,  0] [ 3,  3,  9] -1 */
     1545754, /* 70845 (1635) [ 0,  0,  1,  0, -1,  0, -1,  0,  0] [ 0,  6,  6]  1 */
    26405545, /* 70846 (1635) [ 0,  0,  1,  0,  1,  0, -1,  0,  0] [ 9,  3,  9]  1 */
     1544626, /* 70847 (1635) [ 0,  0, -1,  1,  0,  0,  0, -1,  0] [ 0,  6,  6]  1 */
     1547266, /* 70848 (1635) [ 0,  1,  0,  0,  0, -1, -1,  0,  0] [ 0,  6,  6]  1 */
    35441464, /* 70849 (1635) [ 0,  1,  0,  0,  0,  1,  1,  0,  0] [ 0,  6,  0] -1 */
    17136202, /* 70850 (1635) [ 0,  1,  0,  0,  0, -1, -1,  0,  0] [ 6,  0,  6]  1 */
    52561282, /* 70851 (1635) [ 0, -1,  0,  0,  0,  1, -1,  0,  0] [ 6,  6,  6] -1 */
    26405233, /* 70852 (1635) [ 0,  0,  1, -1,  0,  0,  0,  1,  0] [ 9,  3,  9]  1 */
    10817977, /* 70853 (1635) [ 0,  1,  0,  0,  0, -1,  1,  0,  0] [ 3,  9,  9]  1 */
     9287015, /* 70854 (1635) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 3,  3,  3]  1 */
    27706251, /* 70855 (1635) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 9,  9,  3]  1 */
    10822345, /* 70856 (1635) [ 1,  0,  0,  0,  0, -1,  0,  1,  0] [ 3,  9,  9]  1 */
    52562962, /* 70857 (1635) [ 0,  0, -1,  1,  0,  0,  0, -1,  0] [ 6,  6,  6] -1 */
    44712139, /* 70858 (1635) [ 0,  1,  0,  0,  0,  1, -1,  0,  0] [ 3,  9,  3] -1 */
    51027520, /* 70859 (1635) [ 0,  0, -1,  0,  1,  0, -1,  0,  0] [ 6,  0,  0] -1 */
     1544458, /* 70860 (1635) [ 0,  0, -1,  0,  1,  0, -1,  0,  0] [ 0,  6,  6]  1 */
    10814833, /* 70861 (1635) [ 0,  0, -1, -1,  0,  0,  0, -1,  0] [ 3,  9,  9]  1 */
     9287175, /* 70862 (1635) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 3,  3,  3]  1 */
    60297895, /* 70863 (1635) [ 0,  0, -1, -1,  0,  0,  0, -1,  0] [ 9,  3,  3] -1 */
    51025748, /* 70864 (1635) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 6,  0,  0] -1 */
    18426544, /* 70865 (1635) [-1,  0,  0,  0,  0, -1,  0,  1,  0] [ 6,  6,  0]  1 */
       10816, /* 70866 (1635) [ 0,  0,  1,  1,  0,  0,  0,  1,  0] [ 0,  0,  0]  1 */
    18434104, /* 70867 (1635) [ 0,  0,  1,  1,  0,  0,  0,  1,  0] [ 6,  6,  0]  1 */
    43411345, /* 70868 (1635) [ 0,  0,  1, -1,  0,  0,  0,  1,  0] [ 3,  3,  9] -1 */
     9278591, /* 70869 (1635) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 3,  3,  3]  1 */
     9282963, /* 70870 (1635) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 3,  3,  3]  1 */
        9184, /* 70871 (1635) [ 0,  0, -1,  0,  1,  0, -1,  0,  0] [ 0,  0,  0]  1 */
    51028660, /* 70872 (1635) [ 0,  0,  1, -1,  0,  0,  0, -1,  0] [ 6,  0,  0] -1 */
    61840625, /* 70873 (1635) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 9,  9,  9] -1 */
    35441672, /* 70874 (1635) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 0,  6,  0] -1 */
     1551646, /* 70875 (1635) [ 1,  0,  0,  0,  0, -1,  0, -1,  0] [ 0,  6,  6]  1 */
     9281503, /* 70876 (1635) [ 0,  0,  1,  1,  0,  0,  0, -1,  0] [ 3,  3,  3]  1 */
    60301039, /* 70877 (1635) [ 0,  1,  0,  0,  0, -1,  1,  0,  0] [ 9,  3,  3] -1 */
    10815169, /* 70878 (1635) [ 0,  0, -1,  0,  1,  0,  1,  0,  0] [ 3,  9,  9]  1 */
    61831713, /* 70879 (1635) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 9,  9,  9] -1 */
    18433612, /* 70880 (1635) [ 0,  0,  1, -1,  0,  0,  0, -1,  0] [ 6,  6,  0]  1 */
    51021592, /* 70881 (1635) [-1,  0,  0,  0,  0, -1,  0,  1,  0] [ 6,  0,  0] -1 */
    60299527, /* 70882 (1635) [ 0,  0,  1,  0, -1,  0,  1,  0,  0] [ 9,  3,  3] -1 */
    60305407, /* 70883 (1635) [ 1,  0,  0,  0,  0, -1,  0,  1,  0] [ 9,  3,  3] -1 */
     9281335, /* 70884 (1635) [ 0,  0,  1,  0,  1,  0, -1,  0,  0] [ 3,  3,  3]  1 */
    51030400, /* 70885 (1635) [ 0,  1,  0,  0,  0,  1,  1,  0,  0] [ 6,  0,  0] -1 */
    52562794, /* 70886 (1635) [ 0,  0, -1,  0,  1,  0, -1,  0,  0] [ 6,  6,  6] -1 */
     1551706, /* 70887 (1635) [ 1,  0,  0,  0,  0,  1,  0,  1,  0] [ 0,  6,  6]  1 */
    61827613, /* 70888 (1635) [-1,  0,  0,  0,  0,  1,  0,  1,  0] [ 9,  9,  9] -1 */
    34133522, /* 70889 (1635) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    60301075, /* 70890 (1635) [ 0,  1,  0,  0,  0,  1, -1,  0,  0] [ 9,  3,  3] -1 */
    35439724, /* 70891 (1635) [ 0,  0,  1, -1,  0,  0,  0, -1,  0] [ 0,  6,  0] -1 */
    52562650, /* 70892 (1635) [ 0,  0, -1,  0, -1,  0,  1,  0,  0] [ 6,  6,  6] -1 */
       11784, /* 70893 (1635) [ 0,  1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    52561506, /* 70894 (1635) [ 0, -1,  0,  1,  0,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    26403769, /* 70895 (1635) [ 0,  0, -1, -1,  0,  0,  0, -1,  0] [ 9,  3,  9]  1 */
    17131622, /* 70896 (1635) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 6,  0,  6]  1 */
    35436812, /* 70897 (1635) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 0,  6,  0] -1 */
    61836089, /* 70898 (1635) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 9,  9,  9] -1 */
     9274055, /* 70899 (1635) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 3,  3,  3]  1 */
    17132106, /* 70900 (1635) [ 0, -1,  0,  1,  0,  0,  0,  0, -1] [ 6,  0,  6]  1 */
     1543170, /* 70901 (1635) [ 0, -1,  0,  1,  0,  0,  0,  0, -1] [ 0,  6,  6]  1 */
    18433948, /* 70902 (1635) [ 0,  0,  1,  0,  1,  0,  1,  0,  0] [ 6,  6,  0]  1 */
    43409881, /* 70903 (1635) [ 0,  0, -1, -1,  0,  0,  0, -1,  0] [ 3,  3,  9] -1 */
    18432640, /* 70904 (1635) [ 0,  0, -1,  1,  0,  0,  0, -1,  0] [ 6,  6,  0]  1 */
    44707711, /* 70905 (1635) [ 0, -1,  0,  0,  0, -1, -1,  0,  0] [ 3,  9,  3] -1 */
    35432656, /* 70906 (1635) [-1,  0,  0,  0,  0, -1,  0,  1,  0] [ 0,  6,  0] -1 */
     1538634, /* 70907 (1635) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
     1547338, /* 70908 (1635) [ 0,  1,  0,  0,  0,  1,  1,  0,  0] [ 0,  6,  6]  1 */
    51030608, /* 70909 (1635) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 6,  0,  0] -1 */
    18426592, /* 70910 (1635) [-1,  0,  0,  0,  0,  1,  0, -1,  0] [ 6,  6,  0]  1 */
    44707503, /* 70911 (1635) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 3,  9,  3] -1 */
    52565394, /* 70912 (1635) [ 0,  1,  0, -1,  0,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    61840729, /* 70913 (1635) [ 1,  0,  0,  0,  0,  1,  0, -1,  0] [ 9,  9,  9] -1 */
    43404325, /* 70914 (1635) [-1,  0,  0,  0,  0,  1,  0,  1,  0] [ 3,  3,  9] -1 */
    52561246, /* 70915 (1635) [ 0, -1,  0,  0,  0, -1,  1,  0,  0] [ 6,  6,  6] -1 */
    52556970, /* 70916 (1635) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    35437072, /* 70917 (1635) [ 0, -1,  0,  0,  0,  1, -1,  0,  0] [ 0,  6,  0] -1 */
    26398213, /* 70918 (1635) [-1,  0,  0,  0,  0,  1,  0,  1,  0] [ 9,  3,  9]  1 */
    60305511, /* 70919 (1635) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 9,  3,  3] -1 */
     9280051, /* 70920 (1635) [ 0,  0, -1,  1,  0,  0,  0,  1,  0] [ 3,  3,  3]  1 */
    44712103, /* 70921 (1635) [ 0,  1,  0,  0,  0, -1,  1,  0,  0] [ 3,  9,  3] -1 */
    27706027, /* 70922 (1635) [ 0,  1,  0,  0,  0,  1, -1,  0,  0] [ 9,  9,  3]  1 */
       16484, /* 70923 (1630) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    25694211, /* 70924 (1630) [ 0, -1,  0,  1,  0,  0,  0,  0, -1] [ 9,  0,  9]  1 */
    10105275, /* 70925 (1630) [ 0, -1,  0,  1,  0,  0,  0,  0, -1] [ 3,  6,  9]  1 */
     8565465, /* 70926 (1630) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 3,  0,  3]  1 */
       10660, /* 70927 (1630) [ 0,  0,  1,  0,  1,  0,  1,  0,  0] [ 0,  0,  0]  1 */
    17140694, /* 70928 (1630) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
    19201249, /* 70929 (1630) [ 0,  0,  1, -1,  0,  0,  0, -1,  0] [ 6,  9,  3]  1 */
        9022, /* 70930 (1630) [ 0,  0, -1,  0, -1,  0, -1,  0,  0] [ 0,  0,  0]  1 */
    18432310, /* 70931 (1630) [ 0,  0, -1,  0, -1,  0, -1,  0,  0] [ 6,  6,  0]  1 */
    26997403, /* 70932 (1630) [ 0,  1,  0,  0,  0, -1,  1,  0,  0] [ 9,  6,  3]  1 */
    25698101, /* 70933 (1630) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 9,  0,  9]  1 */
    26347900, /* 70934 (1630) [ 0,  1,  0,  0,  0,  1, -1,  0,  0] [ 9,  3,  6]  1 */
    26339054, /* 70935 (1630) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 9,  3,  6]  1 */
     1538524, /* 70936 (1630) [-1,  0,  0,  0,  0, -1,  0, -1,  0] [ 0,  6,  6]  1 */
        3198, /* 70937 (1630) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
       16432, /* 70938 (1630) [ 1,  0,  0,  0,  0,  1,  0,  1,  0] [ 0,  0,  0]  1 */
     8572435, /* 70939 (1630) [ 0,  0,  1, -1,  0,  0,  0,  1,  0] [ 3,  0,  3]  1 */
    25689619, /* 70940 (1630) [-1,  0,  0,  0,  0,  1,  0, -1,  0] [ 9,  0,  9]  1 */
    10105051, /* 70941 (1630) [ 0, -1,  0,  0,  0,  1, -1,  0,  0] [ 3,  6,  9]  1 */
     2319231, /* 70942 (1630) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  9,  9]  1 */
    10107709, /* 70943 (1630) [ 0,  0,  1, -1,  0,  0,  0,  1,  0] [ 3,  6,  9]  1 */
    27001715, /* 70944 (1630) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 9,  6,  3]  1 */
    26343266, /* 70945 (1630) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 9,  3,  6]  1 */
     8569777, /* 70946 (1630) [ 0, -1,  0,  0,  0,  1, -1,  0,  0] [ 3,  0,  3]  1 */
    10100739, /* 70947 (1630) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 3,  6,  9]  1 */
    26352336, /* 70948 (1630) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 9,  3,  6]  1 */
    17136274, /* 70949 (1630) [ 0,  1,  0,  0,  0,  1,  1,  0,  0] [ 6,  0,  6]  1 */
    27645742, /* 70950 (1630) [ 0,  0,  1,  1,  0,  0,  0, -1,  0] [ 9,  9,  0]  1 */
    26339110, /* 70951 (1630) [-1,  0,  0,  0,  0, -1,  0,  1,  0] [ 9,  3,  6]  1 */
        7410, /* 70952 (1630) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    26348124, /* 70953 (1630) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 9,  3,  6]  1 */
    18430698, /* 70954 (1630) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 6,  6,  0]  1 */
    27001771, /* 70955 (1630) [ 1,  0,  0,  0,  0, -1,  0,  1,  0] [ 9,  6,  3]  1 */
    26346664, /* 70956 (1630) [ 0,  0,  1,  1,  0,  0,  0, -1,  0] [ 9,  3,  6]  1 */
    26995891, /* 70957 (1630) [ 0,  0,  1,  0, -1,  0,  1,  0,  0] [ 9,  6,  3]  1 */
      775327, /* 70958 (1630) [ 0, -1,  0,  0,  0,  1,  1,  0,  0] [ 0,  3,  3]  1 */
    17131828, /* 70959 (1630) [ 0, -1,  0,  0,  0, -1, -1,  0,  0] [ 6,  0,  6]  1 */
     1544296, /* 70960 (1630) [ 0,  0, -1,  0, -1,  0, -1,  0,  0] [ 0,  6,  6]  1 */
    17140642, /* 70961 (1630) [ 1,  0,  0,  0,  0,  1,  0,  1,  0] [ 6,  0,  6]  1 */
    27642568, /* 70962 (1630) [ 0, -1,  0,  0,  0, -1,  1,  0,  0] [ 9,  9,  0]  1 */
    27643972, /* 70963 (1630) [ 0,  0, -1,  0, -1,  0,  1,  0,  0] [ 9,  9,  0]  1 */
        3250, /* 70964 (1630) [-1,  0,  0,  0,  0, -1,  0, -1,  0] [ 0,  0,  0]  1 */
    17903631, /* 70965 (1630) [ 0,  1,  0, -1,  0,  0,  0,  0, -1] [ 6,  3,  9]  1 */
    26343490, /* 70966 (1630) [ 0, -1,  0,  0,  0, -1,  1,  0,  0] [ 9,  3,  6]  1 */
    19198823, /* 70967 (1630) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 6,  9,  3]  1 */
     2319283, /* 70968 (1630) [ 1,  0,  0,  0,  0, -1,  0, -1,  0] [ 0,  9,  9]  1 */
      778117, /* 70969 (1630) [ 0,  0,  1,  0, -1,  0, -1,  0,  0] [ 0,  3,  3]  1 */
    10757728, /* 70970 (1630) [ 0,  0,  1,  1,  0,  0,  0, -1,  0] [ 3,  9,  6]  1 */
    19194235, /* 70971 (1630) [-1,  0,  0,  0,  0,  1,  0,  1,  0] [ 6,  9,  3]  1 */
    17901205, /* 70972 (1630) [ 0,  0, -1,  1,  0,  0,  0,  1,  0] [ 6,  3,  9]  1 */
    26346496, /* 70973 (1630) [ 0,  0,  1,  0,  1,  0, -1,  0,  0] [ 9,  3,  6]  1 */
     1542684, /* 70974 (1630) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 0,  6,  6]  1 */
      776839, /* 70975 (1630) [ 0,  0, -1,  0,  1,  0,  1,  0,  0] [ 0,  3,  3]  1 */
    26344726, /* 70976 (1630) [ 0,  0, -1, -1,  0,  0,  0,  1,  0] [ 9,  3,  6]  1 */
    26994745, /* 70977 (1630) [ 0,  0, -1,  1,  0,  0,  0, -1,  0] [ 9,  6,  3]  1 */
      779629, /* 70978 (1630) [ 0,  1,  0,  0,  0, -1, -1,  0,  0] [ 0,  3,  3]  1 */
    26352280, /* 70979 (1630) [ 1,  0,  0,  0,  0,  1,  0, -1,  0] [ 9,  3,  6]  1 */
    19202917, /* 70980 (1630) [ 0,  1,  0,  0,  0, -1, -1,  0,  0] [ 6,  9,  3]  1 */
    27638132, /* 70981 (1630) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 9,  9,  0]  1 */
      777961, /* 70982 (1630) [ 0,  0,  1, -1,  0,  0,  0, -1,  0] [ 0,  3,  3]  1 */
    17908167, /* 70983 (1630) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  3,  9]  1 */
    25696645, /* 70984 (1630) [ 0,  0,  1, -1,  0,  0,  0,  1,  0] [ 9,  0,  9]  1 */
     9220684, /* 70985 (1630) [ 0,  0, -1,  0, -1,  0,  1,  0,  0] [ 3,  3,  0]  1 */
    25689675, /* 70986 (1630) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 9,  0,  9]  1 */
     2313235, /* 70987 (1630) [ 0,  0,  1, -1,  0,  0,  0, -1,  0] [ 0,  9,  9]  1 */
    10755958, /* 70988 (1630) [ 0,  0, -1,  0, -1,  0,  1,  0,  0] [ 3,  9,  6]  1 */
    10109389, /* 70989 (1630) [ 0,  1,  0,  0,  0, -1,  1,  0,  0] [ 3,  6,  9]  1 */
     8574115, /* 70990 (1630) [ 0,  1,  0,  0,  0, -1,  1,  0,  0] [ 3,  0,  3]  1 */
        8866, /* 70991 (1630) [ 0,  0, -1, -1,  0,  0,  0, -1,  0] [ 0,  0,  0]  1 */
    18432154, /* 70992 (1630) [ 0,  0, -1, -1,  0,  0,  0, -1,  0] [ 6,  6,  0]  1 */
    27642344, /* 70993 (1630) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 9,  9,  0]  1 */
     8578427, /* 70994 (1630) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 3,  0,  3]  1 */
    10113701, /* 70995 (1630) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 3,  6,  9]  1 */
    10758964, /* 70996 (1630) [ 0,  1,  0,  0,  0,  1, -1,  0,  0] [ 3,  9,  6]  1 */
    27647202, /* 70997 (1630) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 9,  9,  0]  1 */
    17134870, /* 70998 (1630) [ 0,  0,  1,  0,  1,  0,  1,  0,  0] [ 6,  0,  6]  1 */
    18439772, /* 70999 (1630) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
     8572603, /* 71000 (1630) [ 0,  0,  1,  0, -1,  0,  1,  0,  0] [ 3,  0,  3]  1 */
    10113757, /* 71001 (1630) [ 1,  0,  0,  0,  0, -1,  0,  1,  0] [ 3,  6,  9]  1 */
    17127408, /* 71002 (1630) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  6]  1 */
    10750118, /* 71003 (1630) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 3,  9,  6]  1 */
     9214844, /* 71004 (1630) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 3,  3,  0]  1 */
    17899537, /* 71005 (1630) [ 0, -1,  0,  0,  0,  1,  1,  0,  0] [ 6,  3,  9]  1 */
    17133232, /* 71006 (1630) [ 0,  0, -1,  0, -1,  0, -1,  0,  0] [ 6,  0,  6]  1 */
    19202709, /* 71007 (1630) [ 0,  1,  0, -1,  0,  0,  0,  0, -1] [ 6,  9,  3]  1 */
    26994577, /* 71008 (1630) [ 0,  0, -1,  0,  1,  0, -1,  0,  0] [ 9,  6,  3]  1 */
    18435352, /* 71009 (1630) [ 0,  1,  0,  0,  0,  1,  1,  0,  0] [ 6,  6,  0]  1 */
     9219056, /* 71010 (1630) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 3,  3,  0]  1 */
     1544140, /* 71011 (1630) [ 0,  0, -1, -1,  0,  0,  0, -1,  0] [ 0,  6,  6]  1 */
     9228126, /* 71012 (1630) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 3,  3,  0]  1 */
     9214900, /* 71013 (1630) [-1,  0,  0,  0,  0, -1,  0,  1,  0] [ 3,  3,  0]  1 */
       10816, /* 71014 (1630) [ 0,  0,  1,  1,  0,  0,  0,  1,  0] [ 0,  0,  0]  1 */
    18434104, /* 71015 (1630) [ 0,  0,  1,  1,  0,  0,  0,  1,  0] [ 6,  6,  0]  1 */
    18435560, /* 71016 (1630) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 6,  6,  0]  1 */
      775535, /* 71017 (1630) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 0,  3,  3]  1 */
     9223914, /* 71018 (1630) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 3,  3,  0]  1 */
    25695499, /* 71019 (1630) [ 0,  0, -1,  0,  1,  0, -1,  0,  0] [ 9,  0,  9]  1 */
    10759188, /* 71020 (1630) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 3,  9,  6]  1 */
       12064, /* 71021 (1630) [ 0,  1,  0,  0,  0,  1,  1,  0,  0] [ 0,  0,  0]  1 */
    19194287, /* 71022 (1630) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  9,  3]  1 */
     2306221, /* 71023 (1630) [-1,  0,  0,  0,  0,  1,  0,  1,  0] [ 0,  9,  9]  1 */
      784009, /* 71024 (1630) [ 1,  0,  0,  0,  0, -1,  0, -1,  0] [ 0,  3,  3]  1 */
    17902327, /* 71025 (1630) [ 0,  0,  1,  0, -1,  0, -1,  0,  0] [ 6,  3,  9]  1 */
     1551758, /* 71026 (1630) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
     8571457, /* 71027 (1630) [ 0,  0, -1,  1,  0,  0,  0, -1,  0] [ 3,  0,  3]  1 */
     9222454, /* 71028 (1630) [ 0,  0,  1,  1,  0,  0,  0, -1,  0] [ 3,  3,  0]  1 */
     2312113, /* 71029 (1630) [ 0,  0, -1,  0,  1,  0,  1,  0,  0] [ 0,  9,  9]  1 */
    10754554, /* 71030 (1630) [ 0, -1,  0,  0,  0, -1,  1,  0,  0] [ 3,  9,  6]  1 */
    18439720, /* 71031 (1630) [ 1,  0,  0,  0,  0,  1,  0,  1,  0] [ 6,  6,  0]  1 */
    17902171, /* 71032 (1630) [ 0,  0,  1, -1,  0,  0,  0, -1,  0] [ 6,  3,  9]  1 */
     2314903, /* 71033 (1630) [ 0,  1,  0,  0,  0, -1, -1,  0,  0] [ 0,  9,  9]  1 */
     8573891, /* 71034 (1630) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 3,  0,  3]  1 */
    26997179, /* 71035 (1630) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 9,  6,  3]  1 */
    25702637, /* 71036 (1630) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 9,  0,  9]  1 */
    17136482, /* 71037 (1630) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 6,  0,  6]  1 */
    25693987, /* 71038 (1630) [ 0, -1,  0,  0,  0,  1, -1,  0,  0] [ 9,  0,  9]  1 */
    17127460, /* 71039 (1630) [-1,  0,  0,  0,  0, -1,  0, -1,  0] [ 6,  0,  6]  1 */
     1547546, /* 71040 (1630) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 0,  6,  6]  1 */
     1546090, /* 71041 (1630) [ 0,  0,  1,  1,  0,  0,  0,  1,  0] [ 0,  6,  6]  1 */
     9222286, /* 71042 (1630) [ 0,  0,  1,  0,  1,  0, -1,  0,  0] [ 3,  3,  0]  1 */
     8565409, /* 71043 (1630) [-1,  0,  0,  0,  0,  1,  0, -1,  0] [ 3,  0,  3]  1 */
    26988697, /* 71044 (1630) [-1,  0,  0,  0,  0,  1,  0, -1,  0] [ 9,  6,  3]  1 */
    27651414, /* 71045 (1630) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 9,  9,  0]  1 */
     9228070, /* 71046 (1630) [ 1,  0,  0,  0,  0,  1,  0, -1,  0] [ 3,  3,  0]  1 */
    27638188, /* 71047 (1630) [-1,  0,  0,  0,  0, -1,  0,  1,  0] [ 9,  9,  0]  1 */
    25696813, /* 71048 (1630) [ 0,  0,  1,  0, -1,  0,  1,  0,  0] [ 9,  0,  9]  1 */
     9223690, /* 71049 (1630) [ 0,  1,  0,  0,  0,  1, -1,  0,  0] [ 3,  3,  0]  1 */
     1551706, /* 71050 (1630) [ 1,  0,  0,  0,  0,  1,  0,  1,  0] [ 0,  6,  6]  1 */
    19198615, /* 71051 (1630) [ 0, -1,  0,  0,  0,  1,  1,  0,  0] [ 6,  9,  3]  1 */
    10107877, /* 71052 (1630) [ 0,  0,  1,  0, -1,  0,  1,  0,  0] [ 3,  6,  9]  1 */
     8578483, /* 71053 (1630) [ 1,  0,  0,  0,  0, -1,  0,  1,  0] [ 3,  0,  3]  1 */
     2314695, /* 71054 (1630) [ 0,  1,  0, -1,  0,  0,  0,  0, -1] [ 0,  9,  9]  1 */
    10106563, /* 71055 (1630) [ 0,  0, -1,  0,  1,  0, -1,  0,  0] [ 3,  6,  9]  1 */
    17131620, /* 71056 (1630) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 6,  0,  6]  1 */
    17908219, /* 71057 (1630) [ 1,  0,  0,  0,  0, -1,  0, -1,  0] [ 6,  3,  9]  1 */
    10754330, /* 71058 (1630) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 3,  9,  6]  1 */
    17133076, /* 71059 (1630) [ 0,  0, -1, -1,  0,  0,  0, -1,  0] [ 6,  0,  6]  1 */
    17901049, /* 71060 (1630) [ 0,  0, -1,  0,  1,  0,  1,  0,  0] [ 6,  3,  9]  1 */
       12272, /* 71061 (1630) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    25695667, /* 71062 (1630) [ 0,  0, -1,  1,  0,  0,  0, -1,  0] [ 9,  0,  9]  1 */
    10763400, /* 71063 (1630) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 3,  9,  6]  1 */
    19201405, /* 71064 (1630) [ 0,  0,  1,  0, -1,  0, -1,  0,  0] [ 6,  9,  3]  1 */
    17903839, /* 71065 (1630) [ 0,  1,  0,  0,  0, -1, -1,  0,  0] [ 6,  3,  9]  1 */
    10750174, /* 71066 (1630) [-1,  0,  0,  0,  0, -1,  0,  1,  0] [ 3,  9,  6]  1 */
    19200283, /* 71067 (1630) [ 0,  0, -1,  1,  0,  0,  0,  1,  0] [ 6,  9,  3]  1 */
    27645574, /* 71068 (1630) [ 0,  0,  1,  0,  1,  0, -1,  0,  0] [ 9,  9,  0]  1 */
     2310809, /* 71069 (1630) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 0,  9,  9]  1 */
      770999, /* 71070 (1630) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  3,  3]  1 */
     8570001, /* 71071 (1630) [ 0, -1,  0,  1,  0,  0,  0,  0, -1] [ 3,  0,  3]  1 */
    27643804, /* 71072 (1630) [ 0,  0, -1, -1,  0,  0,  0,  1,  0] [ 9,  9,  0]  1 */
        7618, /* 71073 (1630) [ 0, -1,  0,  0,  0, -1, -1,  0,  0] [ 0,  0,  0]  1 */
    18430906, /* 71074 (1630) [ 0, -1,  0,  0,  0, -1, -1,  0,  0] [ 6,  6,  0]  1 */
     2306273, /* 71075 (1630) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  9,  9]  1 */
    26993289, /* 71076 (1630) [ 0, -1,  0,  1,  0,  0,  0,  0, -1] [ 9,  6,  3]  1 */
    27651358, /* 71077 (1630) [ 1,  0,  0,  0,  0,  1,  0, -1,  0] [ 9,  9,  0]  1 */
      770947, /* 71078 (1630) [-1,  0,  0,  0,  0,  1,  0,  1,  0] [ 0,  3,  3]  1 */
    18433948, /* 71079 (1630) [ 0,  0,  1,  0,  1,  0,  1,  0,  0] [ 6,  6,  0]  1 */
    10106731, /* 71080 (1630) [ 0,  0, -1,  1,  0,  0,  0, -1,  0] [ 3,  6,  9]  1 */
     9219280, /* 71081 (1630) [ 0, -1,  0,  0,  0, -1,  1,  0,  0] [ 3,  3,  0]  1 */
    18426486, /* 71082 (1630) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
      783957, /* 71083 (1630) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  3,  3]  1 */
    26993065, /* 71084 (1630) [ 0, -1,  0,  0,  0,  1, -1,  0,  0] [ 9,  6,  3]  1 */
    19207245, /* 71085 (1630) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  9,  3]  1 */
    26995723, /* 71086 (1630) [ 0,  0,  1, -1,  0,  0,  0,  1,  0] [ 9,  6,  3]  1 */
    25698325, /* 71087 (1630) [ 0,  1,  0,  0,  0, -1,  1,  0,  0] [ 9,  0,  9]  1 */
    26988753, /* 71088 (1630) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 9,  6,  3]  1 */
     1547338, /* 71089 (1630) [ 0,  1,  0,  0,  0,  1,  1,  0,  0] [ 0,  6,  6]  1 */
    10109165, /* 71090 (1630) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 3,  6,  9]  1 */
    17135026, /* 71091 (1630) [ 0,  0,  1,  1,  0,  0,  0,  1,  0] [ 6,  0,  6]  1 */
    10100683, /* 71092 (1630) [-1,  0,  0,  0,  0,  1,  0, -1,  0] [ 3,  6,  9]  1 */
     9220516, /* 71093 (1630) [ 0,  0, -1, -1,  0,  0,  0,  1,  0] [ 3,  3,  0]  1 */
    10757560, /* 71094 (1630) [ 0,  0,  1,  0,  1,  0, -1,  0,  0] [ 3,  9,  6]  1 */
    10755790, /* 71095 (1630) [ 0,  0, -1, -1,  0,  0,  0,  1,  0] [ 3,  9,  6]  1 */
     1542892, /* 71096 (1630) [ 0, -1,  0,  0,  0, -1, -1,  0,  0] [ 0,  6,  6]  1 */
    10763344, /* 71097 (1630) [ 1,  0,  0,  0,  0,  1,  0, -1,  0] [ 3,  9,  6]  1 */
     1545934, /* 71098 (1630) [ 0,  0,  1,  0,  1,  0,  1,  0,  0] [ 0,  6,  6]  1 */
    25702693, /* 71099 (1630) [ 1,  0,  0,  0,  0, -1,  0,  1,  0] [ 9,  0,  9]  1 */
     2310601, /* 71100 (1630) [ 0, -1,  0,  0,  0,  1,  1,  0,  0] [ 0,  9,  9]  1 */
     1538472, /* 71101 (1630) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
    26344894, /* 71102 (1630) [ 0,  0, -1,  0, -1,  0,  1,  0,  0] [ 9,  3,  6]  1 */
    18426538, /* 71103 (1630) [-1,  0,  0,  0,  0, -1,  0, -1,  0] [ 6,  6,  0]  1 */
    19207297, /* 71104 (1630) [ 1,  0,  0,  0,  0, -1,  0, -1,  0] [ 6,  9,  3]  1 */
    17899745, /* 71105 (1630) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 6,  3,  9]  1 */
      779421, /* 71106 (1630) [ 0,  1,  0, -1,  0,  0,  0,  0, -1] [ 0,  3,  3]  1 */
    17895209, /* 71107 (1630) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  3,  9]  1 */
    19200127, /* 71108 (1630) [ 0,  0, -1,  0,  1,  0,  1,  0,  0] [ 6,  9,  3]  1 */
     8571289, /* 71109 (1630) [ 0,  0, -1,  0,  1,  0, -1,  0,  0] [ 3,  0,  3]  1 */
     2313391, /* 71110 (1630) [ 0,  0,  1,  0, -1,  0, -1,  0,  0] [ 0,  9,  9]  1 */
    17895157, /* 71111 (1630) [-1,  0,  0,  0,  0,  1,  0,  1,  0] [ 6,  3,  9]  1 */
      776995, /* 71112 (1630) [ 0,  0, -1,  1,  0,  0,  0,  1,  0] [ 0,  3,  3]  1 */
     2312269, /* 71113 (1630) [ 0,  0, -1,  1,  0,  0,  0,  1,  0] [ 0,  9,  9]  1 */
    27646978, /* 71114 (1630) [ 0,  1,  0,  0,  0,  1, -1,  0,  0] [ 9,  9,  0]  1 */
       16484, /* 71115 (1631) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
     8565465, /* 71116 (1631) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 3,  0,  3]  1 */
    17140694, /* 71117 (1631) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
        9022, /* 71118 (1631) [ 0,  0, -1,  0, -1,  0, -1,  0,  0] [ 0,  0,  0]  1 */
    18432310, /* 71119 (1631) [ 0,  0, -1,  0, -1,  0, -1,  0,  0] [ 6,  6,  0]  1 */
    26997403, /* 71120 (1631) [ 0,  1,  0,  0,  0, -1,  1,  0,  0] [ 9,  6,  3]  1 */
    26347900, /* 71121 (1631) [ 0,  1,  0,  0,  0,  1, -1,  0,  0] [ 9,  3,  6]  1 */
    52451996, /* 71122 (1631) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
        3198, /* 71123 (1631) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
     1538524, /* 71124 (1631) [-1,  0,  0,  0,  0, -1,  0, -1,  0] [ 0,  6,  6]  1 */
    53210839, /* 71125 (1631) [ 0, -1,  0,  0,  0,  1,  1,  0,  0] [ 6,  9,  3] -1 */
    10107709, /* 71126 (1631) [ 0,  0,  1, -1,  0,  0,  0,  1,  0] [ 3,  6,  9]  1 */
    42590707, /* 71127 (1631) [ 1,  0,  0,  0,  0, -1,  0,  1,  0] [ 3,  0,  3] -1 */
    26343266, /* 71128 (1631) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 9,  3,  6]  1 */
    17136274, /* 71129 (1631) [ 0,  1,  0,  0,  0,  1,  1,  0,  0] [ 6,  0,  6]  1 */
    53214933, /* 71130 (1631) [ 0,  1,  0, -1,  0,  0,  0,  0, -1] [ 6,  9,  3] -1 */
    52447576, /* 71131 (1631) [ 0,  1,  0,  0,  0,  1,  1,  0,  0] [ 6,  6,  0] -1 */
    27001771, /* 71132 (1631) [ 1,  0,  0,  0,  0, -1,  0,  1,  0] [ 9,  6,  3]  1 */
    26995891, /* 71133 (1631) [ 0,  0,  1,  0, -1,  0,  1,  0,  0] [ 9,  6,  3]  1 */
    34024496, /* 71134 (1631) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    52447784, /* 71135 (1631) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 6,  6,  0] -1 */
    51916063, /* 71136 (1631) [ 0,  1,  0,  0,  0, -1, -1,  0,  0] [ 6,  3,  9] -1 */
    36318445, /* 71137 (1631) [-1,  0,  0,  0,  0,  1,  0,  1,  0] [ 0,  9,  9] -1 */
    42583681, /* 71138 (1631) [ 0,  0, -1,  1,  0,  0,  0, -1,  0] [ 3,  0,  3] -1 */
    44766778, /* 71139 (1631) [ 0, -1,  0,  0,  0, -1,  1,  0,  0] [ 3,  9,  6] -1 */
     1542684, /* 71140 (1631) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 0,  6,  6]  1 */
      776839, /* 71141 (1631) [ 0,  0, -1,  0,  1,  0,  1,  0,  0] [ 0,  3,  3]  1 */
    59714861, /* 71142 (1631) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 9,  0,  9] -1 */
    44121389, /* 71143 (1631) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 3,  6,  9] -1 */
    42577633, /* 71144 (1631) [-1,  0,  0,  0,  0,  1,  0, -1,  0] [ 3,  0,  3] -1 */
     2313235, /* 71145 (1631) [ 0,  0,  1, -1,  0,  0,  0, -1,  0] [ 0,  9,  9]  1 */
    10755958, /* 71146 (1631) [ 0,  0, -1,  0, -1,  0,  1,  0,  0] [ 3,  9,  6]  1 */
     8574115, /* 71147 (1631) [ 0,  1,  0,  0,  0, -1,  1,  0,  0] [ 3,  0,  3]  1 */
    27642344, /* 71148 (1631) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 9,  9,  0]  1 */
    60357118, /* 71149 (1631) [ 0,  0, -1,  0, -1,  0,  1,  0,  0] [ 9,  3,  6] -1 */
    51911969, /* 71150 (1631) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 6,  3,  9] -1 */
    18439772, /* 71151 (1631) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    51920443, /* 71152 (1631) [ 1,  0,  0,  0,  0, -1,  0, -1,  0] [ 6,  3,  9] -1 */
    10750118, /* 71153 (1631) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 3,  9,  6]  1 */
    17899537, /* 71154 (1631) [ 0, -1,  0,  0,  0,  1,  1,  0,  0] [ 6,  3,  9]  1 */
    19202709, /* 71155 (1631) [ 0,  1,  0, -1,  0,  0,  0,  0, -1] [ 6,  9,  3]  1 */
    34019842, /* 71156 (1631) [ 0, -1,  0,  0,  0, -1, -1,  0,  0] [ 0,  0,  0] -1 */
    52443130, /* 71157 (1631) [ 0, -1,  0,  0,  0, -1, -1,  0,  0] [ 6,  6,  0] -1 */
    18435352, /* 71158 (1631) [ 0,  1,  0,  0,  0,  1,  1,  0,  0] [ 6,  6,  0]  1 */
     9219056, /* 71159 (1631) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 3,  3,  0]  1 */
    18435560, /* 71160 (1631) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    42584659, /* 71161 (1631) [ 0,  0,  1, -1,  0,  0,  0,  1,  0] [ 3,  0,  3] -1 */
    61007947, /* 71162 (1631) [ 0,  0,  1, -1,  0,  0,  0,  1,  0] [ 9,  6,  3] -1 */
    44117275, /* 71163 (1631) [ 0, -1,  0,  0,  0,  1, -1,  0,  0] [ 3,  6,  9] -1 */
     2306221, /* 71164 (1631) [-1,  0,  0,  0,  0,  1,  0,  1,  0] [ 0,  9,  9]  1 */
     8571457, /* 71165 (1631) [ 0,  0, -1,  1,  0,  0,  0, -1,  0] [ 3,  0,  3]  1 */
    10754554, /* 71166 (1631) [ 0, -1,  0,  0,  0, -1,  1,  0,  0] [ 3,  9,  6]  1 */
    52442922, /* 71167 (1631) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 6,  6,  0] -1 */
    44768014, /* 71168 (1631) [ 0,  0, -1, -1,  0,  0,  0,  1,  0] [ 3,  9,  6] -1 */
    25702637, /* 71169 (1631) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 9,  0,  9]  1 */
    35556520, /* 71170 (1631) [ 0,  0, -1,  0, -1,  0, -1,  0,  0] [ 0,  6,  6] -1 */
     8565409, /* 71171 (1631) [-1,  0,  0,  0,  0,  1,  0, -1,  0] [ 3,  0,  3]  1 */
    35550696, /* 71172 (1631) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  6] -1 */
    26988697, /* 71173 (1631) [-1,  0,  0,  0,  0,  1,  0, -1,  0] [ 9,  6,  3]  1 */
    27651414, /* 71174 (1631) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 9,  9,  0]  1 */
    27638188, /* 71175 (1631) [-1,  0,  0,  0,  0, -1,  0,  1,  0] [ 9,  9,  0]  1 */
    60355714, /* 71176 (1631) [ 0, -1,  0,  0,  0, -1,  1,  0,  0] [ 9,  3,  6] -1 */
     9223690, /* 71177 (1631) [ 0,  1,  0,  0,  0,  1, -1,  0,  0] [ 3,  3,  0]  1 */
    51907433, /* 71178 (1631) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  3,  9] -1 */
    42583513, /* 71179 (1631) [ 0,  0, -1,  0,  1,  0, -1,  0,  0] [ 3,  0,  3] -1 */
    10107877, /* 71180 (1631) [ 0,  0,  1,  0, -1,  0,  1,  0,  0] [ 3,  6,  9]  1 */
    61650356, /* 71181 (1631) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 9,  9,  0] -1 */
    34790185, /* 71182 (1631) [ 0,  0,  1, -1,  0,  0,  0, -1,  0] [ 0,  3,  3] -1 */
    43232908, /* 71183 (1631) [ 0,  0, -1,  0, -1,  0,  1,  0,  0] [ 3,  3,  0] -1 */
    53213473, /* 71184 (1631) [ 0,  0,  1, -1,  0,  0,  0, -1,  0] [ 6,  9,  3] -1 */
    59701899, /* 71185 (1631) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 9,  0,  9] -1 */
    17131620, /* 71186 (1631) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 6,  0,  6]  1 */
    17908219, /* 71187 (1631) [ 1,  0,  0,  0,  0, -1,  0, -1,  0] [ 6,  3,  9]  1 */
    60351278, /* 71188 (1631) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 9,  3,  6] -1 */
    27645574, /* 71189 (1631) [ 0,  0,  1,  0,  1,  0, -1,  0,  0] [ 9,  9,  0]  1 */
        7618, /* 71190 (1631) [ 0, -1,  0,  0,  0, -1, -1,  0,  0] [ 0,  0,  0]  1 */
    18430906, /* 71191 (1631) [ 0, -1,  0,  0,  0, -1, -1,  0,  0] [ 6,  6,  0]  1 */
    26995723, /* 71192 (1631) [ 0,  0,  1, -1,  0,  0,  0,  1,  0] [ 9,  6,  3]  1 */
    51145456, /* 71193 (1631) [ 0,  0, -1,  0, -1,  0, -1,  0,  0] [ 6,  0,  6] -1 */
    10755790, /* 71194 (1631) [ 0,  0, -1, -1,  0,  0,  0,  1,  0] [ 3,  9,  6]  1 */
    10763344, /* 71195 (1631) [ 1,  0,  0,  0,  0,  1,  0, -1,  0] [ 3,  9,  6]  1 */
    36331507, /* 71196 (1631) [ 1,  0,  0,  0,  0, -1,  0, -1,  0] [ 0,  9,  9] -1 */
    44769952, /* 71197 (1631) [ 0,  0,  1,  1,  0,  0,  0, -1,  0] [ 3,  9,  6] -1 */
    53206459, /* 71198 (1631) [-1,  0,  0,  0,  0,  1,  0,  1,  0] [ 6,  9,  3] -1 */
    51913429, /* 71199 (1631) [ 0,  0, -1,  1,  0,  0,  0,  1,  0] [ 6,  3,  9] -1 */
    60356950, /* 71200 (1631) [ 0,  0, -1, -1,  0,  0,  0,  1,  0] [ 9,  3,  6] -1 */
     2310601, /* 71201 (1631) [ 0, -1,  0,  0,  0,  1,  1,  0,  0] [ 0,  9,  9]  1 */
     1538472, /* 71202 (1631) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
    51920391, /* 71203 (1631) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  3,  9] -1 */
    61009403, /* 71204 (1631) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 9,  6,  3] -1 */
    17895209, /* 71205 (1631) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  3,  9]  1 */
     8571289, /* 71206 (1631) [ 0,  0, -1,  0,  1,  0, -1,  0,  0] [ 3,  0,  3]  1 */
    34021090, /* 71207 (1631) [ 0,  0, -1, -1,  0,  0,  0, -1,  0] [ 0,  0,  0] -1 */
    44125925, /* 71208 (1631) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 3,  6,  9] -1 */
       10660, /* 71209 (1631) [ 0,  0,  1,  0,  1,  0,  1,  0,  0] [ 0,  0,  0]  1 */
    19201249, /* 71210 (1631) [ 0,  0,  1, -1,  0,  0,  0, -1,  0] [ 6,  9,  3]  1 */
    25698101, /* 71211 (1631) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 9,  0,  9]  1 */
    26339054, /* 71212 (1631) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 9,  3,  6]  1 */
    51139632, /* 71213 (1631) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  6] -1 */
    43227068, /* 71214 (1631) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 3,  3,  0] -1 */
    51913273, /* 71215 (1631) [ 0,  0, -1,  0,  1,  0,  1,  0,  0] [ 6,  3,  9] -1 */
    53213629, /* 71216 (1631) [ 0,  0,  1,  0, -1,  0, -1,  0,  0] [ 6,  9,  3] -1 */
    36323033, /* 71217 (1631) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 0,  9,  9] -1 */
    44771412, /* 71218 (1631) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 3,  9,  6] -1 */
    34024288, /* 71219 (1631) [ 0,  1,  0,  0,  0,  1,  1,  0,  0] [ 0,  0,  0] -1 */
    17140642, /* 71220 (1631) [ 1,  0,  0,  0,  0,  1,  0,  1,  0] [ 6,  0,  6]  1 */
    51914551, /* 71221 (1631) [ 0,  0,  1,  0, -1,  0, -1,  0,  0] [ 6,  3,  9] -1 */
    61663582, /* 71222 (1631) [ 1,  0,  0,  0,  0,  1,  0, -1,  0] [ 9,  9,  0] -1 */
    34783171, /* 71223 (1631) [-1,  0,  0,  0,  0,  1,  0,  1,  0] [ 0,  3,  3] -1 */
    52451944, /* 71224 (1631) [ 1,  0,  0,  0,  0,  1,  0,  1,  0] [ 6,  6,  0] -1 */
    43231504, /* 71225 (1631) [ 0, -1,  0,  0,  0, -1,  1,  0,  0] [ 3,  3,  0] -1 */
     2319283, /* 71226 (1631) [ 1,  0,  0,  0,  0, -1,  0, -1,  0] [ 0,  9,  9]  1 */
    53219469, /* 71227 (1631) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  9,  3] -1 */
    10757728, /* 71228 (1631) [ 0,  0,  1,  1,  0,  0,  0, -1,  0] [ 3,  9,  6]  1 */
    61005289, /* 71229 (1631) [ 0, -1,  0,  0,  0,  1, -1,  0,  0] [ 9,  6,  3] -1 */
    19194235, /* 71230 (1631) [-1,  0,  0,  0,  0,  1,  0,  1,  0] [ 6,  9,  3]  1 */
    17901205, /* 71231 (1631) [ 0,  0, -1,  1,  0,  0,  0,  1,  0] [ 6,  3,  9]  1 */
    59710549, /* 71232 (1631) [ 0,  1,  0,  0,  0, -1,  1,  0,  0] [ 9,  0,  9] -1 */
    26344726, /* 71233 (1631) [ 0,  0, -1, -1,  0,  0,  0,  1,  0] [ 9,  3,  6]  1 */
    26352280, /* 71234 (1631) [ 1,  0,  0,  0,  0,  1,  0, -1,  0] [ 9,  3,  6]  1 */
    59706211, /* 71235 (1631) [ 0, -1,  0,  0,  0,  1, -1,  0,  0] [ 9,  0,  9] -1 */
    35558314, /* 71236 (1631) [ 0,  0,  1,  1,  0,  0,  0,  1,  0] [ 0,  6,  6] -1 */
    43232740, /* 71237 (1631) [ 0,  0, -1, -1,  0,  0,  0,  1,  0] [ 3,  3,  0] -1 */
    44769784, /* 71238 (1631) [ 0,  0,  1,  0,  1,  0, -1,  0,  0] [ 3,  9,  6] -1 */
    43240294, /* 71239 (1631) [ 1,  0,  0,  0,  0,  1,  0, -1,  0] [ 3,  3,  0] -1 */
    17908167, /* 71240 (1631) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  3,  9]  1 */
        8866, /* 71241 (1631) [ 0,  0, -1, -1,  0,  0,  0, -1,  0] [ 0,  0,  0]  1 */
    18432154, /* 71242 (1631) [ 0,  0, -1, -1,  0,  0,  0, -1,  0] [ 6,  6,  0]  1 */
    10113701, /* 71243 (1631) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 3,  6,  9]  1 */
    34028708, /* 71244 (1631) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
     8572603, /* 71245 (1631) [ 0,  0,  1,  0, -1,  0,  1,  0,  0] [ 3,  0,  3]  1 */
    17127408, /* 71246 (1631) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  6]  1 */
    59707891, /* 71247 (1631) [ 0,  0, -1,  1,  0,  0,  0, -1,  0] [ 9,  0,  9] -1 */
     9214844, /* 71248 (1631) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 3,  3,  0]  1 */
    36318497, /* 71249 (1631) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  9,  9] -1 */
    10759188, /* 71250 (1631) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 3,  9,  6]  1 */
    59701843, /* 71251 (1631) [-1,  0,  0,  0,  0,  1,  0, -1,  0] [ 9,  0,  9] -1 */
       12064, /* 71252 (1631) [ 0,  1,  0,  0,  0,  1,  1,  0,  0] [ 0,  0,  0]  1 */
    17902327, /* 71253 (1631) [ 0,  0,  1,  0, -1,  0, -1,  0,  0] [ 6,  3,  9]  1 */
    18439720, /* 71254 (1631) [ 1,  0,  0,  0,  0,  1,  0,  1,  0] [ 6,  6,  0]  1 */
    60360348, /* 71255 (1631) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 9,  3,  6] -1 */
    51147250, /* 71256 (1631) [ 0,  0,  1,  1,  0,  0,  0,  1,  0] [ 6,  0,  6] -1 */
    60358888, /* 71257 (1631) [ 0,  0,  1,  1,  0,  0,  0, -1,  0] [ 9,  3,  6] -1 */
    35558158, /* 71258 (1631) [ 0,  0,  1,  0,  1,  0,  1,  0,  0] [ 0,  6,  6] -1 */
    25693987, /* 71259 (1631) [ 0, -1,  0,  0,  0,  1, -1,  0,  0] [ 9,  0,  9]  1 */
    17127460, /* 71260 (1631) [-1,  0,  0,  0,  0, -1,  0, -1,  0] [ 6,  0,  6]  1 */
     1546090, /* 71261 (1631) [ 0,  0,  1,  1,  0,  0,  0,  1,  0] [ 0,  6,  6]  1 */
    34015474, /* 71262 (1631) [-1,  0,  0,  0,  0, -1,  0, -1,  0] [ 0,  0,  0] -1 */
    52438762, /* 71263 (1631) [-1,  0,  0,  0,  0, -1,  0, -1,  0] [ 6,  6,  0] -1 */
     9228070, /* 71264 (1631) [ 1,  0,  0,  0,  0,  1,  0, -1,  0] [ 3,  3,  0]  1 */
    53219521, /* 71265 (1631) [ 1,  0,  0,  0,  0, -1,  0, -1,  0] [ 6,  9,  3] -1 */
    60358720, /* 71266 (1631) [ 0,  0,  1,  0,  1,  0, -1,  0,  0] [ 9,  3,  6] -1 */
    19198615, /* 71267 (1631) [ 0, -1,  0,  0,  0,  1,  1,  0,  0] [ 6,  9,  3]  1 */
    34791645, /* 71268 (1631) [ 0,  1,  0, -1,  0,  0,  0,  0, -1] [ 0,  3,  3] -1 */
    53215141, /* 71269 (1631) [ 0,  1,  0,  0,  0, -1, -1,  0,  0] [ 6,  9,  3] -1 */
    36325615, /* 71270 (1631) [ 0,  0,  1,  0, -1,  0, -1,  0,  0] [ 0,  9,  9] -1 */
     8578483, /* 71271 (1631) [ 1,  0,  0,  0,  0, -1,  0,  1,  0] [ 3,  0,  3]  1 */
    36324493, /* 71272 (1631) [ 0,  0, -1,  1,  0,  0,  0,  1,  0] [ 0,  9,  9] -1 */
    59706435, /* 71273 (1631) [ 0, -1,  0,  1,  0,  0,  0,  0, -1] [ 9,  0,  9] -1 */
    44121613, /* 71274 (1631) [ 0,  1,  0,  0,  0, -1,  1,  0,  0] [ 3,  6,  9] -1 */
       12272, /* 71275 (1631) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    25695667, /* 71276 (1631) [ 0,  0, -1,  1,  0,  0,  0, -1,  0] [ 9,  0,  9]  1 */
    17903839, /* 71277 (1631) [ 0,  1,  0,  0,  0, -1, -1,  0,  0] [ 6,  3,  9]  1 */
    42590651, /* 71278 (1631) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 3,  0,  3] -1 */
    36331455, /* 71279 (1631) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  9,  9] -1 */
    61013939, /* 71280 (1631) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 9,  6,  3] -1 */
     2306273, /* 71281 (1631) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  9,  9]  1 */
    34019634, /* 71282 (1631) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    34787551, /* 71283 (1631) [ 0, -1,  0,  0,  0,  1,  1,  0,  0] [ 0,  3,  3] -1 */
    10109165, /* 71284 (1631) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 3,  6,  9]  1 */
    61654792, /* 71285 (1631) [ 0, -1,  0,  0,  0, -1,  1,  0,  0] [ 9,  9,  0] -1 */
    17135026, /* 71286 (1631) [ 0,  0,  1,  1,  0,  0,  0,  1,  0] [ 6,  0,  6]  1 */
    61656196, /* 71287 (1631) [ 0,  0, -1,  0, -1,  0,  1,  0,  0] [ 9,  9,  0] -1 */
    35556364, /* 71288 (1631) [ 0,  0, -1, -1,  0,  0,  0, -1,  0] [ 0,  6,  6] -1 */
    43236138, /* 71289 (1631) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 3,  3,  0] -1 */
    53211047, /* 71290 (1631) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 6,  9,  3] -1 */
    59707723, /* 71291 (1631) [ 0,  0, -1,  0,  1,  0, -1,  0,  0] [ 9,  0,  9] -1 */
     1545934, /* 71292 (1631) [ 0,  0,  1,  0,  1,  0,  1,  0,  0] [ 0,  6,  6]  1 */
    43234678, /* 71293 (1631) [ 0,  0,  1,  1,  0,  0,  0, -1,  0] [ 3,  3,  0] -1 */
    36324337, /* 71294 (1631) [ 0,  0, -1,  0,  1,  0,  1,  0,  0] [ 0,  9,  9] -1 */
    26344894, /* 71295 (1631) [ 0,  0, -1,  0, -1,  0,  1,  0,  0] [ 9,  3,  6]  1 */
    18426538, /* 71296 (1631) [-1,  0,  0,  0,  0, -1,  0, -1,  0] [ 6,  6,  0]  1 */
    19207297, /* 71297 (1631) [ 1,  0,  0,  0,  0, -1,  0, -1,  0] [ 6,  9,  3]  1 */
    17899745, /* 71298 (1631) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 6,  3,  9]  1 */
      779421, /* 71299 (1631) [ 0,  1,  0, -1,  0,  0,  0,  0, -1] [ 0,  3,  3]  1 */
     2313391, /* 71300 (1631) [ 0,  0,  1,  0, -1,  0, -1,  0,  0] [ 0,  9,  9]  1 */
    43234510, /* 71301 (1631) [ 0,  0,  1,  0,  1,  0, -1,  0,  0] [ 3,  3,  0] -1 */
     2312269, /* 71302 (1631) [ 0,  0, -1,  1,  0,  0,  0,  1,  0] [ 0,  9,  9]  1 */
    25694211, /* 71303 (1631) [ 0, -1,  0,  1,  0,  0,  0,  0, -1] [ 9,  0,  9]  1 */
    44771188, /* 71304 (1631) [ 0,  1,  0,  0,  0,  1, -1,  0,  0] [ 3,  9,  6] -1 */
    51147094, /* 71305 (1631) [ 0,  0,  1,  0,  1,  0,  1,  0,  0] [ 6,  0,  6] -1 */
     8572435, /* 71306 (1631) [ 0,  0,  1, -1,  0,  0,  0,  1,  0] [ 3,  0,  3]  1 */
    10105051, /* 71307 (1631) [ 0, -1,  0,  0,  0,  1, -1,  0,  0] [ 3,  6,  9]  1 */
     2319231, /* 71308 (1631) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  9,  9]  1 */
    27001715, /* 71309 (1631) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 9,  6,  3]  1 */
        7410, /* 71310 (1631) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    18430698, /* 71311 (1631) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 6,  6,  0]  1 */
    44766554, /* 71312 (1631) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 3,  9,  6] -1 */
      775327, /* 71313 (1631) [ 0, -1,  0,  0,  0,  1,  1,  0,  0] [ 0,  3,  3]  1 */
    34783223, /* 71314 (1631) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  3,  3] -1 */
     1544296, /* 71315 (1631) [ 0,  0, -1,  0, -1,  0, -1,  0,  0] [ 0,  6,  6]  1 */
    53206511, /* 71316 (1631) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  9,  3] -1 */
    61005513, /* 71317 (1631) [ 0, -1,  0,  1,  0,  0,  0,  0, -1] [ 9,  6,  3] -1 */
    27642568, /* 71318 (1631) [ 0, -1,  0,  0,  0, -1,  1,  0,  0] [ 9,  9,  0]  1 */
    35563982, /* 71319 (1631) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
    27643972, /* 71320 (1631) [ 0,  0, -1,  0, -1,  0,  1,  0,  0] [ 9,  9,  0]  1 */
    44118955, /* 71321 (1631) [ 0,  0, -1,  1,  0,  0,  0, -1,  0] [ 3,  6,  9] -1 */
    36327127, /* 71322 (1631) [ 0,  1,  0,  0,  0, -1, -1,  0,  0] [ 0,  9,  9] -1 */
    26343490, /* 71323 (1631) [ 0, -1,  0,  0,  0, -1,  1,  0,  0] [ 9,  3,  6]  1 */
    19198823, /* 71324 (1631) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 6,  9,  3]  1 */
    61000977, /* 71325 (1631) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 9,  6,  3] -1 */
    42586115, /* 71326 (1631) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 3,  0,  3] -1 */
    35559562, /* 71327 (1631) [ 0,  1,  0,  0,  0,  1,  1,  0,  0] [ 0,  6,  6] -1 */
    51148706, /* 71328 (1631) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 6,  0,  6] -1 */
    35559770, /* 71329 (1631) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 0,  6,  6] -1 */
    44112907, /* 71330 (1631) [-1,  0,  0,  0,  0,  1,  0, -1,  0] [ 3,  6,  9] -1 */
    27638132, /* 71331 (1631) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 9,  9,  0]  1 */
      777961, /* 71332 (1631) [ 0,  0,  1, -1,  0,  0,  0, -1,  0] [ 0,  3,  3]  1 */
    59709037, /* 71333 (1631) [ 0,  0,  1,  0, -1,  0,  1,  0,  0] [ 9,  0,  9] -1 */
     9220684, /* 71334 (1631) [ 0,  0, -1,  0, -1,  0,  1,  0,  0] [ 3,  3,  0]  1 */
    25689675, /* 71335 (1631) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 9,  0,  9]  1 */
    10758964, /* 71336 (1631) [ 0,  1,  0,  0,  0,  1, -1,  0,  0] [ 3,  9,  6]  1 */
    17134870, /* 71337 (1631) [ 0,  0,  1,  0,  1,  0,  1,  0,  0] [ 6,  0,  6]  1 */
    44118787, /* 71338 (1631) [ 0,  0, -1,  0,  1,  0, -1,  0,  0] [ 3,  6,  9] -1 */
    44775624, /* 71339 (1631) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 3,  9,  6] -1 */
    34789219, /* 71340 (1631) [ 0,  0, -1,  1,  0,  0,  0,  1,  0] [ 0,  3,  3] -1 */
    44762398, /* 71341 (1631) [-1,  0,  0,  0,  0, -1,  0,  1,  0] [ 3,  9,  6] -1 */
    53212507, /* 71342 (1631) [ 0,  0, -1,  1,  0,  0,  0,  1,  0] [ 6,  9,  3] -1 */
    61656028, /* 71343 (1631) [ 0,  0, -1, -1,  0,  0,  0,  1,  0] [ 9,  9,  0] -1 */
    17133232, /* 71344 (1631) [ 0,  0, -1,  0, -1,  0, -1,  0,  0] [ 6,  0,  6]  1 */
    51152918, /* 71345 (1631) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
    52444534, /* 71346 (1631) [ 0,  0, -1,  0, -1,  0, -1,  0,  0] [ 6,  6,  0] -1 */
    61009627, /* 71347 (1631) [ 0,  1,  0,  0,  0, -1,  1,  0,  0] [ 9,  6,  3] -1 */
    60360124, /* 71348 (1631) [ 0,  1,  0,  0,  0,  1, -1,  0,  0] [ 9,  3,  6] -1 */
    34015422, /* 71349 (1631) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    52438710, /* 71350 (1631) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
    34796181, /* 71351 (1631) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  3,  3] -1 */
    19194287, /* 71352 (1631) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  9,  3]  1 */
    60355490, /* 71353 (1631) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 9,  3,  6] -1 */
     1551758, /* 71354 (1631) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
    51148498, /* 71355 (1631) [ 0,  1,  0,  0,  0,  1,  1,  0,  0] [ 6,  0,  6] -1 */
     2314903, /* 71356 (1631) [ 0,  1,  0,  0,  0, -1, -1,  0,  0] [ 0,  9,  9]  1 */
    35555116, /* 71357 (1631) [ 0, -1,  0,  0,  0, -1, -1,  0,  0] [ 0,  6,  6] -1 */
     8573891, /* 71358 (1631) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 3,  0,  3]  1 */
    26997179, /* 71359 (1631) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 9,  6,  3]  1 */
    17136482, /* 71360 (1631) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 6,  0,  6]  1 */
    59714917, /* 71361 (1631) [ 1,  0,  0,  0,  0, -1,  0,  1,  0] [ 9,  0,  9] -1 */
     1547546, /* 71362 (1631) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 0,  6,  6]  1 */
    25696813, /* 71363 (1631) [ 0,  0,  1,  0, -1,  0,  1,  0,  0] [ 9,  0,  9]  1 */
    35554908, /* 71364 (1631) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 0,  6,  6] -1 */
    53212351, /* 71365 (1631) [ 0,  0, -1,  0,  1,  0,  1,  0,  0] [ 6,  9,  3] -1 */
    44117499, /* 71366 (1631) [ 0, -1,  0,  1,  0,  0,  0,  0, -1] [ 3,  6,  9] -1 */
    10106563, /* 71367 (1631) [ 0,  0, -1,  0,  1,  0, -1,  0,  0] [ 3,  6,  9]  1 */
    17901049, /* 71368 (1631) [ 0,  0, -1,  0,  1,  0,  1,  0,  0] [ 6,  3,  9]  1 */
    19201405, /* 71369 (1631) [ 0,  0,  1,  0, -1,  0, -1,  0,  0] [ 6,  9,  3]  1 */
    10763400, /* 71370 (1631) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 3,  9,  6]  1 */
    34028656, /* 71371 (1631) [ 1,  0,  0,  0,  0,  1,  0,  1,  0] [ 0,  0,  0] -1 */
    10750174, /* 71372 (1631) [-1,  0,  0,  0,  0, -1,  0,  1,  0] [ 3,  9,  6]  1 */
    19200283, /* 71373 (1631) [ 0,  0, -1,  1,  0,  0,  0,  1,  0] [ 6,  9,  3]  1 */
     2310809, /* 71374 (1631) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 0,  9,  9]  1 */
    27643804, /* 71375 (1631) [ 0,  0, -1, -1,  0,  0,  0,  1,  0] [ 9,  9,  0]  1 */
    42582001, /* 71376 (1631) [ 0, -1,  0,  0,  0,  1, -1,  0,  0] [ 3,  0,  3] -1 */
    44112963, /* 71377 (1631) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 3,  6,  9] -1 */
    27651358, /* 71378 (1631) [ 1,  0,  0,  0,  0,  1,  0, -1,  0] [ 9,  9,  0]  1 */
      770947, /* 71379 (1631) [-1,  0,  0,  0,  0,  1,  0,  1,  0] [ 0,  3,  3]  1 */
    60364560, /* 71380 (1631) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 9,  3,  6] -1 */
    61657966, /* 71381 (1631) [ 0,  0,  1,  1,  0,  0,  0, -1,  0] [ 9,  9,  0] -1 */
    60351334, /* 71382 (1631) [-1,  0,  0,  0,  0, -1,  0,  1,  0] [ 9,  3,  6] -1 */
     9219280, /* 71383 (1631) [ 0, -1,  0,  0,  0, -1,  1,  0,  0] [ 3,  3,  0]  1 */
    18426486, /* 71384 (1631) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
      783957, /* 71385 (1631) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  3,  3]  1 */
    26993065, /* 71386 (1631) [ 0, -1,  0,  0,  0,  1, -1,  0,  0] [ 9,  6,  3]  1 */
    19207245, /* 71387 (1631) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  9,  3]  1 */
    25698325, /* 71388 (1631) [ 0,  1,  0,  0,  0, -1,  1,  0,  0] [ 9,  0,  9]  1 */
    44762342, /* 71389 (1631) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 3,  9,  6] -1 */
    51144052, /* 71390 (1631) [ 0, -1,  0,  0,  0, -1, -1,  0,  0] [ 6,  0,  6] -1 */
    51911761, /* 71391 (1631) [ 0, -1,  0,  0,  0,  1,  1,  0,  0] [ 6,  3,  9] -1 */
    43231280, /* 71392 (1631) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 3,  3,  0] -1 */
     9220516, /* 71393 (1631) [ 0,  0, -1, -1,  0,  0,  0,  1,  0] [ 3,  3,  0]  1 */
    10757560, /* 71394 (1631) [ 0,  0,  1,  0,  1,  0, -1,  0,  0] [ 3,  9,  6]  1 */
    51915855, /* 71395 (1631) [ 0,  1,  0, -1,  0,  0,  0,  0, -1] [ 6,  3,  9] -1 */
     1542892, /* 71396 (1631) [ 0, -1,  0,  0,  0, -1, -1,  0,  0] [ 0,  6,  6]  1 */
    34790341, /* 71397 (1631) [ 0,  0,  1,  0, -1,  0, -1,  0,  0] [ 0,  3,  3] -1 */
    25702693, /* 71398 (1631) [ 1,  0,  0,  0,  0, -1,  0,  1,  0] [ 9,  0,  9]  1 */
    61006969, /* 71399 (1631) [ 0,  0, -1,  1,  0,  0,  0, -1,  0] [ 9,  6,  3] -1 */
    34791853, /* 71400 (1631) [ 0,  1,  0,  0,  0, -1, -1,  0,  0] [ 0,  3,  3] -1 */
    59708869, /* 71401 (1631) [ 0,  0,  1, -1,  0,  0,  0,  1,  0] [ 9,  0,  9] -1 */
    19200127, /* 71402 (1631) [ 0,  0, -1,  0,  1,  0,  1,  0,  0] [ 6,  9,  3]  1 */
    61000921, /* 71403 (1631) [-1,  0,  0,  0,  0,  1,  0, -1,  0] [ 9,  6,  3] -1 */
    61663638, /* 71404 (1631) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 9,  9,  0] -1 */
    10105275, /* 71405 (1631) [ 0, -1,  0,  1,  0,  0,  0,  0, -1] [ 3,  6,  9]  1 */
    61650412, /* 71406 (1631) [-1,  0,  0,  0,  0, -1,  0,  1,  0] [ 9,  9,  0] -1 */
    43235914, /* 71407 (1631) [ 0,  1,  0,  0,  0,  1, -1,  0,  0] [ 3,  3,  0] -1 */
    61659426, /* 71408 (1631) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 9,  9,  0] -1 */
       16432, /* 71409 (1631) [ 1,  0,  0,  0,  0,  1,  0,  1,  0] [ 0,  0,  0]  1 */
    44125981, /* 71410 (1631) [ 1,  0,  0,  0,  0, -1,  0,  1,  0] [ 3,  6,  9] -1 */
    25689619, /* 71411 (1631) [-1,  0,  0,  0,  0,  1,  0, -1,  0] [ 9,  0,  9]  1 */
    44120101, /* 71412 (1631) [ 0,  0,  1,  0, -1,  0,  1,  0,  0] [ 3,  6,  9] -1 */
     8569777, /* 71413 (1631) [ 0, -1,  0,  0,  0,  1, -1,  0,  0] [ 3,  0,  3]  1 */
    10100739, /* 71414 (1631) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 3,  6,  9]  1 */
    26352336, /* 71415 (1631) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 9,  3,  6]  1 */
    27645742, /* 71416 (1631) [ 0,  0,  1,  1,  0,  0,  0, -1,  0] [ 9,  9,  0]  1 */
    26339110, /* 71417 (1631) [-1,  0,  0,  0,  0, -1,  0,  1,  0] [ 9,  3,  6]  1 */
    26348124, /* 71418 (1631) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 9,  3,  6]  1 */
    61006801, /* 71419 (1631) [ 0,  0, -1,  0,  1,  0, -1,  0,  0] [ 9,  6,  3] -1 */
    51143844, /* 71420 (1631) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 6,  0,  6] -1 */
    43240350, /* 71421 (1631) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 3,  3,  0] -1 */
    26346664, /* 71422 (1631) [ 0,  0,  1,  1,  0,  0,  0, -1,  0] [ 9,  3,  6]  1 */
    43227124, /* 71423 (1631) [-1,  0,  0,  0,  0, -1,  0,  1,  0] [ 3,  3,  0] -1 */
    34023040, /* 71424 (1631) [ 0,  0,  1,  1,  0,  0,  0,  1,  0] [ 0,  0,  0] -1 */
    52446328, /* 71425 (1631) [ 0,  0,  1,  1,  0,  0,  0,  1,  0] [ 6,  6,  0] -1 */
    34787759, /* 71426 (1631) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 0,  3,  3] -1 */
    17131828, /* 71427 (1631) [ 0, -1,  0,  0,  0, -1, -1,  0,  0] [ 6,  0,  6]  1 */
    61657798, /* 71428 (1631) [ 0,  0,  1,  0,  1,  0, -1,  0,  0] [ 9,  9,  0] -1 */
    34796233, /* 71429 (1631) [ 1,  0,  0,  0,  0, -1,  0, -1,  0] [ 0,  3,  3] -1 */
    51914395, /* 71430 (1631) [ 0,  0,  1, -1,  0,  0,  0, -1,  0] [ 6,  3,  9] -1 */
        3250, /* 71431 (1631) [-1,  0,  0,  0,  0, -1,  0, -1,  0] [ 0,  0,  0]  1 */
    17903631, /* 71432 (1631) [ 0,  1,  0, -1,  0,  0,  0,  0, -1] [ 6,  3,  9]  1 */
      778117, /* 71433 (1631) [ 0,  0,  1,  0, -1,  0, -1,  0,  0] [ 0,  3,  3]  1 */
    26346496, /* 71434 (1631) [ 0,  0,  1,  0,  1,  0, -1,  0,  0] [ 9,  3,  6]  1 */
    26994745, /* 71435 (1631) [ 0,  0, -1,  1,  0,  0,  0, -1,  0] [ 9,  6,  3]  1 */
      779629, /* 71436 (1631) [ 0,  1,  0,  0,  0, -1, -1,  0,  0] [ 0,  3,  3]  1 */
    19202917, /* 71437 (1631) [ 0,  1,  0,  0,  0, -1, -1,  0,  0] [ 6,  9,  3]  1 */
    25696645, /* 71438 (1631) [ 0,  0,  1, -1,  0,  0,  0,  1,  0] [ 9,  0,  9]  1 */
    44775568, /* 71439 (1631) [ 1,  0,  0,  0,  0,  1,  0, -1,  0] [ 3,  9,  6] -1 */
    10109389, /* 71440 (1631) [ 0,  1,  0,  0,  0, -1,  1,  0,  0] [ 3,  6,  9]  1 */
    35563930, /* 71441 (1631) [ 1,  0,  0,  0,  0,  1,  0,  1,  0] [ 0,  6,  6] -1 */
    36322825, /* 71442 (1631) [ 0, -1,  0,  0,  0,  1,  1,  0,  0] [ 0,  9,  9] -1 */
     8578427, /* 71443 (1631) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 3,  0,  3]  1 */
    27647202, /* 71444 (1631) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 9,  9,  0]  1 */
    36326919, /* 71445 (1631) [ 0,  1,  0, -1,  0,  0,  0,  0, -1] [ 0,  9,  9] -1 */
    51145300, /* 71446 (1631) [ 0,  0, -1, -1,  0,  0,  0, -1,  0] [ 6,  0,  6] -1 */
    10113757, /* 71447 (1631) [ 1,  0,  0,  0,  0, -1,  0,  1,  0] [ 3,  6,  9]  1 */
    42582225, /* 71448 (1631) [ 0, -1,  0,  1,  0,  0,  0,  0, -1] [ 3,  0,  3] -1 */
    34022884, /* 71449 (1631) [ 0,  0,  1,  0,  1,  0,  1,  0,  0] [ 0,  0,  0] -1 */
    52446172, /* 71450 (1631) [ 0,  0,  1,  0,  1,  0,  1,  0,  0] [ 6,  6,  0] -1 */
    26994577, /* 71451 (1631) [ 0,  0, -1,  0,  1,  0, -1,  0,  0] [ 9,  6,  3]  1 */
     1544140, /* 71452 (1631) [ 0,  0, -1, -1,  0,  0,  0, -1,  0] [ 0,  6,  6]  1 */
     9228126, /* 71453 (1631) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 3,  3,  0]  1 */
    59710325, /* 71454 (1631) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 9,  0,  9] -1 */
     9214900, /* 71455 (1631) [-1,  0,  0,  0,  0, -1,  0,  1,  0] [ 3,  3,  0]  1 */
       10816, /* 71456 (1631) [ 0,  0,  1,  1,  0,  0,  0,  1,  0] [ 0,  0,  0]  1 */
    18434104, /* 71457 (1631) [ 0,  0,  1,  1,  0,  0,  0,  1,  0] [ 6,  6,  0]  1 */
      775535, /* 71458 (1631) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 0,  3,  3]  1 */
     9223914, /* 71459 (1631) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 3,  3,  0]  1 */
    25695499, /* 71460 (1631) [ 0,  0, -1,  0,  1,  0, -1,  0,  0] [ 9,  0,  9]  1 */
      784009, /* 71461 (1631) [ 1,  0,  0,  0,  0, -1,  0, -1,  0] [ 0,  3,  3]  1 */
     9222454, /* 71462 (1631) [ 0,  0,  1,  1,  0,  0,  0, -1,  0] [ 3,  3,  0]  1 */
     2312113, /* 71463 (1631) [ 0,  0, -1,  0,  1,  0,  1,  0,  0] [ 0,  9,  9]  1 */
    17902171, /* 71464 (1631) [ 0,  0,  1, -1,  0,  0,  0, -1,  0] [ 6,  3,  9]  1 */
    51152866, /* 71465 (1631) [ 1,  0,  0,  0,  0,  1,  0,  1,  0] [ 6,  0,  6] -1 */
     9222286, /* 71466 (1631) [ 0,  0,  1,  0,  1,  0, -1,  0,  0] [ 3,  3,  0]  1 */
     1551706, /* 71467 (1631) [ 1,  0,  0,  0,  0,  1,  0,  1,  0] [ 0,  6,  6]  1 */
    60364504, /* 71468 (1631) [ 1,  0,  0,  0,  0,  1,  0, -1,  0] [ 9,  3,  6] -1 */
    51907381, /* 71469 (1631) [-1,  0,  0,  0,  0,  1,  0,  1,  0] [ 6,  3,  9] -1 */
    61659202, /* 71470 (1631) [ 0,  1,  0,  0,  0,  1, -1,  0,  0] [ 9,  9,  0] -1 */
     2314695, /* 71471 (1631) [ 0,  1,  0, -1,  0,  0,  0,  0, -1] [ 0,  9,  9]  1 */
    42577689, /* 71472 (1631) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 3,  0,  3] -1 */
    34021246, /* 71473 (1631) [ 0,  0, -1,  0, -1,  0, -1,  0,  0] [ 0,  0,  0] -1 */
    17133076, /* 71474 (1631) [ 0,  0, -1, -1,  0,  0,  0, -1,  0] [ 6,  0,  6]  1 */
    10754330, /* 71475 (1631) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 3,  9,  6]  1 */
    35550748, /* 71476 (1631) [-1,  0,  0,  0,  0, -1,  0, -1,  0] [ 0,  6,  6] -1 */
    52444378, /* 71477 (1631) [ 0,  0, -1, -1,  0,  0,  0, -1,  0] [ 6,  6,  0] -1 */
      770999, /* 71478 (1631) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  3,  3]  1 */
     8570001, /* 71479 (1631) [ 0, -1,  0,  1,  0,  0,  0,  0, -1] [ 3,  0,  3]  1 */
    44119933, /* 71480 (1631) [ 0,  0,  1, -1,  0,  0,  0,  1,  0] [ 3,  6,  9] -1 */
    26993289, /* 71481 (1631) [ 0, -1,  0,  1,  0,  0,  0,  0, -1] [ 9,  6,  3]  1 */
    18433948, /* 71482 (1631) [ 0,  0,  1,  0,  1,  0,  1,  0,  0] [ 6,  6,  0]  1 */
    10106731, /* 71483 (1631) [ 0,  0, -1,  1,  0,  0,  0, -1,  0] [ 3,  6,  9]  1 */
    61013995, /* 71484 (1631) [ 1,  0,  0,  0,  0, -1,  0,  1,  0] [ 9,  6,  3] -1 */
    42584827, /* 71485 (1631) [ 0,  0,  1,  0, -1,  0,  1,  0,  0] [ 3,  0,  3] -1 */
    61008115, /* 71486 (1631) [ 0,  0,  1,  0, -1,  0,  1,  0,  0] [ 9,  6,  3] -1 */
    26988753, /* 71487 (1631) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 9,  6,  3]  1 */
     1547338, /* 71488 (1631) [ 0,  1,  0,  0,  0,  1,  1,  0,  0] [ 0,  6,  6]  1 */
    10100683, /* 71489 (1631) [-1,  0,  0,  0,  0,  1,  0, -1,  0] [ 3,  6,  9]  1 */
    34789063, /* 71490 (1631) [ 0,  0, -1,  0,  1,  0,  1,  0,  0] [ 0,  3,  3] -1 */
    36325459, /* 71491 (1631) [ 0,  0,  1, -1,  0,  0,  0, -1,  0] [ 0,  9,  9] -1 */
    44768182, /* 71492 (1631) [ 0,  0, -1,  0, -1,  0,  1,  0,  0] [ 3,  9,  6] -1 */
    42586339, /* 71493 (1631) [ 0,  1,  0,  0,  0, -1,  1,  0,  0] [ 3,  0,  3] -1 */
    17895157, /* 71494 (1631) [-1,  0,  0,  0,  0,  1,  0,  1,  0] [ 6,  3,  9]  1 */
    51139684, /* 71495 (1631) [-1,  0,  0,  0,  0, -1,  0, -1,  0] [ 6,  0,  6] -1 */
      776995, /* 71496 (1631) [ 0,  0, -1,  1,  0,  0,  0,  1,  0] [ 0,  3,  3]  1 */
    61654568, /* 71497 (1631) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 9,  9,  0] -1 */
    27646978, /* 71498 (1631) [ 0,  1,  0,  0,  0,  1, -1,  0,  0] [ 9,  9,  0]  1 */
       16484, /* 71499 (1632) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    61663638, /* 71500 (1632) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 9,  9,  0] -1 */
    44125925, /* 71501 (1632) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 3,  6,  9] -1 */
    25694211, /* 71502 (1632) [ 0, -1,  0,  1,  0,  0,  0,  0, -1] [ 9,  0,  9]  1 */
    10105275, /* 71503 (1632) [ 0, -1,  0,  1,  0,  0,  0,  0, -1] [ 3,  6,  9]  1 */
     8565465, /* 71504 (1632) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 3,  0,  3]  1 */
       10660, /* 71505 (1632) [ 0,  0,  1,  0,  1,  0,  1,  0,  0] [ 0,  0,  0]  1 */
    17140694, /* 71506 (1632) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
    19201249, /* 71507 (1632) [ 0,  0,  1, -1,  0,  0,  0, -1,  0] [ 6,  9,  3]  1 */
    43235914, /* 71508 (1632) [ 0,  1,  0,  0,  0,  1, -1,  0,  0] [ 3,  3,  0] -1 */
    61659426, /* 71509 (1632) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 9,  9,  0] -1 */
    44771188, /* 71510 (1632) [ 0,  1,  0,  0,  0,  1, -1,  0,  0] [ 3,  9,  6] -1 */
    26339054, /* 71511 (1632) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 9,  3,  6]  1 */
    53210839, /* 71512 (1632) [ 0, -1,  0,  0,  0,  1,  1,  0,  0] [ 6,  9,  3] -1 */
       16432, /* 71513 (1632) [ 1,  0,  0,  0,  0,  1,  0,  1,  0] [ 0,  0,  0]  1 */
    44125981, /* 71514 (1632) [ 1,  0,  0,  0,  0, -1,  0,  1,  0] [ 3,  6,  9] -1 */
    51139632, /* 71515 (1632) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  6] -1 */
    25689619, /* 71516 (1632) [-1,  0,  0,  0,  0,  1,  0, -1,  0] [ 9,  0,  9]  1 */
    10105051, /* 71517 (1632) [ 0, -1,  0,  0,  0,  1, -1,  0,  0] [ 3,  6,  9]  1 */
     2319231, /* 71518 (1632) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  9,  9]  1 */
    44120101, /* 71519 (1632) [ 0,  0,  1,  0, -1,  0,  1,  0,  0] [ 3,  6,  9] -1 */
    42590707, /* 71520 (1632) [ 1,  0,  0,  0,  0, -1,  0,  1,  0] [ 3,  0,  3] -1 */
    26343266, /* 71521 (1632) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 9,  3,  6]  1 */
     8569777, /* 71522 (1632) [ 0, -1,  0,  0,  0,  1, -1,  0,  0] [ 3,  0,  3]  1 */
    10100739, /* 71523 (1632) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 3,  6,  9]  1 */
    17136274, /* 71524 (1632) [ 0,  1,  0,  0,  0,  1,  1,  0,  0] [ 6,  0,  6]  1 */
    26339110, /* 71525 (1632) [-1,  0,  0,  0,  0, -1,  0,  1,  0] [ 9,  3,  6]  1 */
    51143844, /* 71526 (1632) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 6,  0,  6] -1 */
    43240350, /* 71527 (1632) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 3,  3,  0] -1 */
    51913273, /* 71528 (1632) [ 0,  0, -1,  0,  1,  0,  1,  0,  0] [ 6,  3,  9] -1 */
    34787759, /* 71529 (1632) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 0,  3,  3] -1 */
    61657798, /* 71530 (1632) [ 0,  0,  1,  0,  1,  0, -1,  0,  0] [ 9,  9,  0] -1 */
    36323033, /* 71531 (1632) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 0,  9,  9] -1 */
    34783223, /* 71532 (1632) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  3,  3] -1 */
    44771412, /* 71533 (1632) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 3,  9,  6] -1 */
    53206511, /* 71534 (1632) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  9,  3] -1 */
    17140642, /* 71535 (1632) [ 1,  0,  0,  0,  0,  1,  0,  1,  0] [ 6,  0,  6]  1 */
    36318445, /* 71536 (1632) [-1,  0,  0,  0,  0,  1,  0,  1,  0] [ 0,  9,  9] -1 */
    27642568, /* 71537 (1632) [ 0, -1,  0,  0,  0, -1,  1,  0,  0] [ 9,  9,  0]  1 */
    61663582, /* 71538 (1632) [ 1,  0,  0,  0,  0,  1,  0, -1,  0] [ 9,  9,  0] -1 */
    34783171, /* 71539 (1632) [-1,  0,  0,  0,  0,  1,  0,  1,  0] [ 0,  3,  3] -1 */
    27643972, /* 71540 (1632) [ 0,  0, -1,  0, -1,  0,  1,  0,  0] [ 9,  9,  0]  1 */
    17903631, /* 71541 (1632) [ 0,  1,  0, -1,  0,  0,  0,  0, -1] [ 6,  3,  9]  1 */
    26343490, /* 71542 (1632) [ 0, -1,  0,  0,  0, -1,  1,  0,  0] [ 9,  3,  6]  1 */
     2319283, /* 71543 (1632) [ 1,  0,  0,  0,  0, -1,  0, -1,  0] [ 0,  9,  9]  1 */
      778117, /* 71544 (1632) [ 0,  0,  1,  0, -1,  0, -1,  0,  0] [ 0,  3,  3]  1 */
    59710549, /* 71545 (1632) [ 0,  1,  0,  0,  0, -1,  1,  0,  0] [ 9,  0,  9] -1 */
    42586115, /* 71546 (1632) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 3,  0,  3] -1 */
    26344726, /* 71547 (1632) [ 0,  0, -1, -1,  0,  0,  0,  1,  0] [ 9,  3,  6]  1 */
    59714861, /* 71548 (1632) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 9,  0,  9] -1 */
    44121389, /* 71549 (1632) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 3,  6,  9] -1 */
    26994745, /* 71550 (1632) [ 0,  0, -1,  1,  0,  0,  0, -1,  0] [ 9,  6,  3]  1 */
      779629, /* 71551 (1632) [ 0,  1,  0,  0,  0, -1, -1,  0,  0] [ 0,  3,  3]  1 */
    19202917, /* 71552 (1632) [ 0,  1,  0,  0,  0, -1, -1,  0,  0] [ 6,  9,  3]  1 */
    44769784, /* 71553 (1632) [ 0,  0,  1,  0,  1,  0, -1,  0,  0] [ 3,  9,  6] -1 */
    27638132, /* 71554 (1632) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 9,  9,  0]  1 */
    43240294, /* 71555 (1632) [ 1,  0,  0,  0,  0,  1,  0, -1,  0] [ 3,  3,  0] -1 */
      777961, /* 71556 (1632) [ 0,  0,  1, -1,  0,  0,  0, -1,  0] [ 0,  3,  3]  1 */
    17908167, /* 71557 (1632) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  3,  9]  1 */
    59709037, /* 71558 (1632) [ 0,  0,  1,  0, -1,  0,  1,  0,  0] [ 9,  0,  9] -1 */
    44775568, /* 71559 (1632) [ 1,  0,  0,  0,  0,  1,  0, -1,  0] [ 3,  9,  6] -1 */
     9220684, /* 71560 (1632) [ 0,  0, -1,  0, -1,  0,  1,  0,  0] [ 3,  3,  0]  1 */
    25689675, /* 71561 (1632) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 9,  0,  9]  1 */
     2313235, /* 71562 (1632) [ 0,  0,  1, -1,  0,  0,  0, -1,  0] [ 0,  9,  9]  1 */
    10755958, /* 71563 (1632) [ 0,  0, -1,  0, -1,  0,  1,  0,  0] [ 3,  9,  6]  1 */
    36322825, /* 71564 (1632) [ 0, -1,  0,  0,  0,  1,  1,  0,  0] [ 0,  9,  9] -1 */
    27642344, /* 71565 (1632) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 9,  9,  0]  1 */
    51911969, /* 71566 (1632) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 6,  3,  9] -1 */
    17134870, /* 71567 (1632) [ 0,  0,  1,  0,  1,  0,  1,  0,  0] [ 6,  0,  6]  1 */
    18439772, /* 71568 (1632) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    51145300, /* 71569 (1632) [ 0,  0, -1, -1,  0,  0,  0, -1,  0] [ 6,  0,  6] -1 */
    10750118, /* 71570 (1632) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 3,  9,  6]  1 */
    44775624, /* 71571 (1632) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 3,  9,  6] -1 */
    34789219, /* 71572 (1632) [ 0,  0, -1,  1,  0,  0,  0,  1,  0] [ 0,  3,  3] -1 */
     9214844, /* 71573 (1632) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 3,  3,  0]  1 */
    53212507, /* 71574 (1632) [ 0,  0, -1,  1,  0,  0,  0,  1,  0] [ 6,  9,  3] -1 */
    19202709, /* 71575 (1632) [ 0,  1,  0, -1,  0,  0,  0,  0, -1] [ 6,  9,  3]  1 */
    34019842, /* 71576 (1632) [ 0, -1,  0,  0,  0, -1, -1,  0,  0] [ 0,  0,  0] -1 */
    36318497, /* 71577 (1632) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  9,  9] -1 */
    52443130, /* 71578 (1632) [ 0, -1,  0,  0,  0, -1, -1,  0,  0] [ 6,  6,  0] -1 */
    26994577, /* 71579 (1632) [ 0,  0, -1,  0,  1,  0, -1,  0,  0] [ 9,  6,  3]  1 */
    18435352, /* 71580 (1632) [ 0,  1,  0,  0,  0,  1,  1,  0,  0] [ 6,  6,  0]  1 */
     9219056, /* 71581 (1632) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 3,  3,  0]  1 */
    52444534, /* 71582 (1632) [ 0,  0, -1,  0, -1,  0, -1,  0,  0] [ 6,  6,  0] -1 */
    61009627, /* 71583 (1632) [ 0,  1,  0,  0,  0, -1,  1,  0,  0] [ 9,  6,  3] -1 */
    59710325, /* 71584 (1632) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 9,  0,  9] -1 */
    60360124, /* 71585 (1632) [ 0,  1,  0,  0,  0,  1, -1,  0,  0] [ 9,  3,  6] -1 */
     9214900, /* 71586 (1632) [-1,  0,  0,  0,  0, -1,  0,  1,  0] [ 3,  3,  0]  1 */
       10816, /* 71587 (1632) [ 0,  0,  1,  1,  0,  0,  0,  1,  0] [ 0,  0,  0]  1 */
    34015422, /* 71588 (1632) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    18434104, /* 71589 (1632) [ 0,  0,  1,  1,  0,  0,  0,  1,  0] [ 6,  6,  0]  1 */
    52438710, /* 71590 (1632) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
    18435560, /* 71591 (1632) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    25695499, /* 71592 (1632) [ 0,  0, -1,  0,  1,  0, -1,  0,  0] [ 9,  0,  9]  1 */
    42584659, /* 71593 (1632) [ 0,  0,  1, -1,  0,  0,  0,  1,  0] [ 3,  0,  3] -1 */
    61007947, /* 71594 (1632) [ 0,  0,  1, -1,  0,  0,  0,  1,  0] [ 9,  6,  3] -1 */
       12064, /* 71595 (1632) [ 0,  1,  0,  0,  0,  1,  1,  0,  0] [ 0,  0,  0]  1 */
      784009, /* 71596 (1632) [ 1,  0,  0,  0,  0, -1,  0, -1,  0] [ 0,  3,  3]  1 */
    17902327, /* 71597 (1632) [ 0,  0,  1,  0, -1,  0, -1,  0,  0] [ 6,  3,  9]  1 */
     1551758, /* 71598 (1632) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
     8571457, /* 71599 (1632) [ 0,  0, -1,  1,  0,  0,  0, -1,  0] [ 3,  0,  3]  1 */
    10754554, /* 71600 (1632) [ 0, -1,  0,  0,  0, -1,  1,  0,  0] [ 3,  9,  6]  1 */
    18439720, /* 71601 (1632) [ 1,  0,  0,  0,  0,  1,  0,  1,  0] [ 6,  6,  0]  1 */
    17902171, /* 71602 (1632) [ 0,  0,  1, -1,  0,  0,  0, -1,  0] [ 6,  3,  9]  1 */
    60360348, /* 71603 (1632) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 9,  3,  6] -1 */
    52442922, /* 71604 (1632) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 6,  6,  0] -1 */
     2314903, /* 71605 (1632) [ 0,  1,  0,  0,  0, -1, -1,  0,  0] [ 0,  9,  9]  1 */
    60358888, /* 71606 (1632) [ 0,  0,  1,  1,  0,  0,  0, -1,  0] [ 9,  3,  6] -1 */
    35555116, /* 71607 (1632) [ 0, -1,  0,  0,  0, -1, -1,  0,  0] [ 0,  6,  6] -1 */
    17136482, /* 71608 (1632) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 6,  0,  6]  1 */
    35556520, /* 71609 (1632) [ 0,  0, -1,  0, -1,  0, -1,  0,  0] [ 0,  6,  6] -1 */
    59714917, /* 71610 (1632) [ 1,  0,  0,  0,  0, -1,  0,  1,  0] [ 9,  0,  9] -1 */
    25693987, /* 71611 (1632) [ 0, -1,  0,  0,  0,  1, -1,  0,  0] [ 9,  0,  9]  1 */
     8565409, /* 71612 (1632) [-1,  0,  0,  0,  0,  1,  0, -1,  0] [ 3,  0,  3]  1 */
     1547546, /* 71613 (1632) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 0,  6,  6]  1 */
     1546090, /* 71614 (1632) [ 0,  0,  1,  1,  0,  0,  0,  1,  0] [ 0,  6,  6]  1 */
    35550696, /* 71615 (1632) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  6] -1 */
    26988697, /* 71616 (1632) [-1,  0,  0,  0,  0,  1,  0, -1,  0] [ 9,  6,  3]  1 */
    34015474, /* 71617 (1632) [-1,  0,  0,  0,  0, -1,  0, -1,  0] [ 0,  0,  0] -1 */
    52438762, /* 71618 (1632) [-1,  0,  0,  0,  0, -1,  0, -1,  0] [ 6,  6,  0] -1 */
    27638188, /* 71619 (1632) [-1,  0,  0,  0,  0, -1,  0,  1,  0] [ 9,  9,  0]  1 */
    60358720, /* 71620 (1632) [ 0,  0,  1,  0,  1,  0, -1,  0,  0] [ 9,  3,  6] -1 */
     1551706, /* 71621 (1632) [ 1,  0,  0,  0,  0,  1,  0,  1,  0] [ 0,  6,  6]  1 */
    35554908, /* 71622 (1632) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 0,  6,  6] -1 */
    51907433, /* 71623 (1632) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  3,  9] -1 */
    53212351, /* 71624 (1632) [ 0,  0, -1,  0,  1,  0,  1,  0,  0] [ 6,  9,  3] -1 */
    60364504, /* 71625 (1632) [ 1,  0,  0,  0,  0,  1,  0, -1,  0] [ 9,  3,  6] -1 */
    51907381, /* 71626 (1632) [-1,  0,  0,  0,  0,  1,  0,  1,  0] [ 6,  3,  9] -1 */
    36324493, /* 71627 (1632) [ 0,  0, -1,  1,  0,  0,  0,  1,  0] [ 0,  9,  9] -1 */
    61659202, /* 71628 (1632) [ 0,  1,  0,  0,  0,  1, -1,  0,  0] [ 9,  9,  0] -1 */
     2314695, /* 71629 (1632) [ 0,  1,  0, -1,  0,  0,  0,  0, -1] [ 0,  9,  9]  1 */
    34021246, /* 71630 (1632) [ 0,  0, -1,  0, -1,  0, -1,  0,  0] [ 0,  0,  0] -1 */
    10106563, /* 71631 (1632) [ 0,  0, -1,  0,  1,  0, -1,  0,  0] [ 3,  6,  9]  1 */
    17908219, /* 71632 (1632) [ 1,  0,  0,  0,  0, -1,  0, -1,  0] [ 6,  3,  9]  1 */
    44121613, /* 71633 (1632) [ 0,  1,  0,  0,  0, -1,  1,  0,  0] [ 3,  6,  9] -1 */
    10754330, /* 71634 (1632) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 3,  9,  6]  1 */
    19201405, /* 71635 (1632) [ 0,  0,  1,  0, -1,  0, -1,  0,  0] [ 6,  9,  3]  1 */
    35550748, /* 71636 (1632) [-1,  0,  0,  0,  0, -1,  0, -1,  0] [ 0,  6,  6] -1 */
    25695667, /* 71637 (1632) [ 0,  0, -1,  1,  0,  0,  0, -1,  0] [ 9,  0,  9]  1 */
       12272, /* 71638 (1632) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    17903839, /* 71639 (1632) [ 0,  1,  0,  0,  0, -1, -1,  0,  0] [ 6,  3,  9]  1 */
    10750174, /* 71640 (1632) [-1,  0,  0,  0,  0, -1,  0,  1,  0] [ 3,  9,  6]  1 */
    52444378, /* 71641 (1632) [ 0,  0, -1, -1,  0,  0,  0, -1,  0] [ 6,  6,  0] -1 */
    42590651, /* 71642 (1632) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 3,  0,  3] -1 */
     8570001, /* 71643 (1632) [ 0, -1,  0,  1,  0,  0,  0,  0, -1] [ 3,  0,  3]  1 */
    27643804, /* 71644 (1632) [ 0,  0, -1, -1,  0,  0,  0,  1,  0] [ 9,  9,  0]  1 */
    44119933, /* 71645 (1632) [ 0,  0,  1, -1,  0,  0,  0,  1,  0] [ 3,  6,  9] -1 */
    26993289, /* 71646 (1632) [ 0, -1,  0,  1,  0,  0,  0,  0, -1] [ 9,  6,  3]  1 */
    61013939, /* 71647 (1632) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 9,  6,  3] -1 */
    60364560, /* 71648 (1632) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 9,  3,  6] -1 */
    18433948, /* 71649 (1632) [ 0,  0,  1,  0,  1,  0,  1,  0,  0] [ 6,  6,  0]  1 */
    61657966, /* 71650 (1632) [ 0,  0,  1,  1,  0,  0,  0, -1,  0] [ 9,  9,  0] -1 */
    10106731, /* 71651 (1632) [ 0,  0, -1,  1,  0,  0,  0, -1,  0] [ 3,  6,  9]  1 */
    34019634, /* 71652 (1632) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  0] -1 */
     9219280, /* 71653 (1632) [ 0, -1,  0,  0,  0, -1,  1,  0,  0] [ 3,  3,  0]  1 */
    61013995, /* 71654 (1632) [ 1,  0,  0,  0,  0, -1,  0,  1,  0] [ 9,  6,  3] -1 */
      783957, /* 71655 (1632) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  3,  3]  1 */
    42584827, /* 71656 (1632) [ 0,  0,  1,  0, -1,  0,  1,  0,  0] [ 3,  0,  3] -1 */
    26993065, /* 71657 (1632) [ 0, -1,  0,  0,  0,  1, -1,  0,  0] [ 9,  6,  3]  1 */
    19207245, /* 71658 (1632) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  9,  3]  1 */
    61008115, /* 71659 (1632) [ 0,  0,  1,  0, -1,  0,  1,  0,  0] [ 9,  6,  3] -1 */
    34787551, /* 71660 (1632) [ 0, -1,  0,  0,  0,  1,  1,  0,  0] [ 0,  3,  3] -1 */
    26988753, /* 71661 (1632) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 9,  6,  3]  1 */
    51144052, /* 71662 (1632) [ 0, -1,  0,  0,  0, -1, -1,  0,  0] [ 6,  0,  6] -1 */
    51911761, /* 71663 (1632) [ 0, -1,  0,  0,  0,  1,  1,  0,  0] [ 6,  3,  9] -1 */
     1547338, /* 71664 (1632) [ 0,  1,  0,  0,  0,  1,  1,  0,  0] [ 0,  6,  6]  1 */
    51145456, /* 71665 (1632) [ 0,  0, -1,  0, -1,  0, -1,  0,  0] [ 6,  0,  6] -1 */
    17135026, /* 71666 (1632) [ 0,  0,  1,  1,  0,  0,  0,  1,  0] [ 6,  0,  6]  1 */
    10100683, /* 71667 (1632) [-1,  0,  0,  0,  0,  1,  0, -1,  0] [ 3,  6,  9]  1 */
     9220516, /* 71668 (1632) [ 0,  0, -1, -1,  0,  0,  0,  1,  0] [ 3,  3,  0]  1 */
    35556364, /* 71669 (1632) [ 0,  0, -1, -1,  0,  0,  0, -1,  0] [ 0,  6,  6] -1 */
    10755790, /* 71670 (1632) [ 0,  0, -1, -1,  0,  0,  0,  1,  0] [ 3,  9,  6]  1 */
    43236138, /* 71671 (1632) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 3,  3,  0] -1 */
    53211047, /* 71672 (1632) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 6,  9,  3] -1 */
     1545934, /* 71673 (1632) [ 0,  0,  1,  0,  1,  0,  1,  0,  0] [ 0,  6,  6]  1 */
    44769952, /* 71674 (1632) [ 0,  0,  1,  1,  0,  0,  0, -1,  0] [ 3,  9,  6] -1 */
    53206459, /* 71675 (1632) [-1,  0,  0,  0,  0,  1,  0,  1,  0] [ 6,  9,  3] -1 */
    51913429, /* 71676 (1632) [ 0,  0, -1,  1,  0,  0,  0,  1,  0] [ 6,  3,  9] -1 */
    43234678, /* 71677 (1632) [ 0,  0,  1,  1,  0,  0,  0, -1,  0] [ 3,  3,  0] -1 */
    34789063, /* 71678 (1632) [ 0,  0, -1,  0,  1,  0,  1,  0,  0] [ 0,  3,  3] -1 */
    36324337, /* 71679 (1632) [ 0,  0, -1,  0,  1,  0,  1,  0,  0] [ 0,  9,  9] -1 */
    26344894, /* 71680 (1632) [ 0,  0, -1,  0, -1,  0,  1,  0,  0] [ 9,  3,  6]  1 */
    19207297, /* 71681 (1632) [ 1,  0,  0,  0,  0, -1,  0, -1,  0] [ 6,  9,  3]  1 */
    59708869, /* 71682 (1632) [ 0,  0,  1, -1,  0,  0,  0,  1,  0] [ 9,  0,  9] -1 */
    61009403, /* 71683 (1632) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 9,  6,  3] -1 */
      779421, /* 71684 (1632) [ 0,  1,  0, -1,  0,  0,  0,  0, -1] [ 0,  3,  3]  1 */
     8571289, /* 71685 (1632) [ 0,  0, -1,  0,  1,  0, -1,  0,  0] [ 3,  0,  3]  1 */
    42586339, /* 71686 (1632) [ 0,  1,  0,  0,  0, -1,  1,  0,  0] [ 3,  0,  3] -1 */
    51139684, /* 71687 (1632) [-1,  0,  0,  0,  0, -1,  0, -1,  0] [ 6,  0,  6] -1 */
    43234510, /* 71688 (1632) [ 0,  0,  1,  0,  1,  0, -1,  0,  0] [ 3,  3,  0] -1 */
     2313391, /* 71689 (1632) [ 0,  0,  1,  0, -1,  0, -1,  0,  0] [ 0,  9,  9]  1 */
    34021090, /* 71690 (1632) [ 0,  0, -1, -1,  0,  0,  0, -1,  0] [ 0,  0,  0] -1 */
       16484, /* 71691 (1633) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    61650412, /* 71692 (1633) [-1,  0,  0,  0,  0, -1,  0,  1,  0] [ 9,  9,  0] -1 */
     8565465, /* 71693 (1633) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 3,  0,  3]  1 */
    17140694, /* 71694 (1633) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
    19201249, /* 71695 (1633) [ 0,  0,  1, -1,  0,  0,  0, -1,  0] [ 6,  9,  3]  1 */
    61659426, /* 71696 (1633) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 9,  9,  0] -1 */
    26997403, /* 71697 (1633) [ 0,  1,  0,  0,  0, -1,  1,  0,  0] [ 9,  6,  3]  1 */
    26347900, /* 71698 (1633) [ 0,  1,  0,  0,  0,  1, -1,  0,  0] [ 9,  3,  6]  1 */
    51147094, /* 71699 (1633) [ 0,  0,  1,  0,  1,  0,  1,  0,  0] [ 6,  0,  6] -1 */
    26339054, /* 71700 (1633) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 9,  3,  6]  1 */
        3198, /* 71701 (1633) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
     8572435, /* 71702 (1633) [ 0,  0,  1, -1,  0,  0,  0,  1,  0] [ 3,  0,  3]  1 */
    44125981, /* 71703 (1633) [ 1,  0,  0,  0,  0, -1,  0,  1,  0] [ 3,  6,  9] -1 */
    10105051, /* 71704 (1633) [ 0, -1,  0,  0,  0,  1, -1,  0,  0] [ 3,  6,  9]  1 */
     2319231, /* 71705 (1633) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  9,  9]  1 */
    44120101, /* 71706 (1633) [ 0,  0,  1,  0, -1,  0,  1,  0,  0] [ 3,  6,  9] -1 */
    10107709, /* 71707 (1633) [ 0,  0,  1, -1,  0,  0,  0,  1,  0] [ 3,  6,  9]  1 */
    27001715, /* 71708 (1633) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 9,  6,  3]  1 */
     8569777, /* 71709 (1633) [ 0, -1,  0,  0,  0,  1, -1,  0,  0] [ 3,  0,  3]  1 */
    10100739, /* 71710 (1633) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 3,  6,  9]  1 */
    42590707, /* 71711 (1633) [ 1,  0,  0,  0,  0, -1,  0,  1,  0] [ 3,  0,  3] -1 */
    26352336, /* 71712 (1633) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 9,  3,  6]  1 */
    17136274, /* 71713 (1633) [ 0,  1,  0,  0,  0,  1,  1,  0,  0] [ 6,  0,  6]  1 */
    27645742, /* 71714 (1633) [ 0,  0,  1,  1,  0,  0,  0, -1,  0] [ 9,  9,  0]  1 */
    53214933, /* 71715 (1633) [ 0,  1,  0, -1,  0,  0,  0,  0, -1] [ 6,  9,  3] -1 */
    61006801, /* 71716 (1633) [ 0,  0, -1,  0,  1,  0, -1,  0,  0] [ 9,  6,  3] -1 */
    51143844, /* 71717 (1633) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 6,  0,  6] -1 */
    44766554, /* 71718 (1633) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 3,  9,  6] -1 */
    51913273, /* 71719 (1633) [ 0,  0, -1,  0,  1,  0,  1,  0,  0] [ 6,  3,  9] -1 */
    43227124, /* 71720 (1633) [-1,  0,  0,  0,  0, -1,  0,  1,  0] [ 3,  3,  0] -1 */
    34024496, /* 71721 (1633) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    52447784, /* 71722 (1633) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 6,  6,  0] -1 */
    26346664, /* 71723 (1633) [ 0,  0,  1,  1,  0,  0,  0, -1,  0] [ 9,  3,  6]  1 */
      775327, /* 71724 (1633) [ 0, -1,  0,  0,  0,  1,  1,  0,  0] [ 0,  3,  3]  1 */
    34787759, /* 71725 (1633) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 0,  3,  3] -1 */
    17131828, /* 71726 (1633) [ 0, -1,  0,  0,  0, -1, -1,  0,  0] [ 6,  0,  6]  1 */
    53213629, /* 71727 (1633) [ 0,  0,  1,  0, -1,  0, -1,  0,  0] [ 6,  9,  3] -1 */
    61657798, /* 71728 (1633) [ 0,  0,  1,  0,  1,  0, -1,  0,  0] [ 9,  9,  0] -1 */
    36323033, /* 71729 (1633) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 0,  9,  9] -1 */
    44771412, /* 71730 (1633) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 3,  9,  6] -1 */
    34796233, /* 71731 (1633) [ 1,  0,  0,  0,  0, -1,  0, -1,  0] [ 0,  3,  3] -1 */
    51914551, /* 71732 (1633) [ 0,  0,  1,  0, -1,  0, -1,  0,  0] [ 6,  3,  9] -1 */
    36318445, /* 71733 (1633) [-1,  0,  0,  0,  0,  1,  0,  1,  0] [ 0,  9,  9] -1 */
    61005513, /* 71734 (1633) [ 0, -1,  0,  1,  0,  0,  0,  0, -1] [ 9,  6,  3] -1 */
    27642568, /* 71735 (1633) [ 0, -1,  0,  0,  0, -1,  1,  0,  0] [ 9,  9,  0]  1 */
    61663582, /* 71736 (1633) [ 1,  0,  0,  0,  0,  1,  0, -1,  0] [ 9,  9,  0] -1 */
    34783171, /* 71737 (1633) [-1,  0,  0,  0,  0,  1,  0,  1,  0] [ 0,  3,  3] -1 */
    52451944, /* 71738 (1633) [ 1,  0,  0,  0,  0,  1,  0,  1,  0] [ 6,  6,  0] -1 */
    26343490, /* 71739 (1633) [ 0, -1,  0,  0,  0, -1,  1,  0,  0] [ 9,  3,  6]  1 */
    10757728, /* 71740 (1633) [ 0,  0,  1,  1,  0,  0,  0, -1,  0] [ 3,  9,  6]  1 */
    17901205, /* 71741 (1633) [ 0,  0, -1,  1,  0,  0,  0,  1,  0] [ 6,  3,  9]  1 */
    42586115, /* 71742 (1633) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 3,  0,  3] -1 */
    26344726, /* 71743 (1633) [ 0,  0, -1, -1,  0,  0,  0,  1,  0] [ 9,  3,  6]  1 */
    44121389, /* 71744 (1633) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 3,  6,  9] -1 */
    51148706, /* 71745 (1633) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 6,  0,  6] -1 */
    26994745, /* 71746 (1633) [ 0,  0, -1,  1,  0,  0,  0, -1,  0] [ 9,  6,  3]  1 */
      779629, /* 71747 (1633) [ 0,  1,  0,  0,  0, -1, -1,  0,  0] [ 0,  3,  3]  1 */
    19202917, /* 71748 (1633) [ 0,  1,  0,  0,  0, -1, -1,  0,  0] [ 6,  9,  3]  1 */
    42577633, /* 71749 (1633) [-1,  0,  0,  0,  0,  1,  0, -1,  0] [ 3,  0,  3] -1 */
    35559770, /* 71750 (1633) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 0,  6,  6] -1 */
    44112907, /* 71751 (1633) [-1,  0,  0,  0,  0,  1,  0, -1,  0] [ 3,  6,  9] -1 */
    44769784, /* 71752 (1633) [ 0,  0,  1,  0,  1,  0, -1,  0,  0] [ 3,  9,  6] -1 */
    27638132, /* 71753 (1633) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 9,  9,  0]  1 */
    43240294, /* 71754 (1633) [ 1,  0,  0,  0,  0,  1,  0, -1,  0] [ 3,  3,  0] -1 */
      777961, /* 71755 (1633) [ 0,  0,  1, -1,  0,  0,  0, -1,  0] [ 0,  3,  3]  1 */
    17908167, /* 71756 (1633) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  3,  9]  1 */
    59709037, /* 71757 (1633) [ 0,  0,  1,  0, -1,  0,  1,  0,  0] [ 9,  0,  9] -1 */
    25696645, /* 71758 (1633) [ 0,  0,  1, -1,  0,  0,  0,  1,  0] [ 9,  0,  9]  1 */
    44775568, /* 71759 (1633) [ 1,  0,  0,  0,  0,  1,  0, -1,  0] [ 3,  9,  6] -1 */
    25689675, /* 71760 (1633) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 9,  0,  9]  1 */
     2313235, /* 71761 (1633) [ 0,  0,  1, -1,  0,  0,  0, -1,  0] [ 0,  9,  9]  1 */
    35563930, /* 71762 (1633) [ 1,  0,  0,  0,  0,  1,  0,  1,  0] [ 0,  6,  6] -1 */
    10109389, /* 71763 (1633) [ 0,  1,  0,  0,  0, -1,  1,  0,  0] [ 3,  6,  9]  1 */
     8574115, /* 71764 (1633) [ 0,  1,  0,  0,  0, -1,  1,  0,  0] [ 3,  0,  3]  1 */
        8866, /* 71765 (1633) [ 0,  0, -1, -1,  0,  0,  0, -1,  0] [ 0,  0,  0]  1 */
    18432154, /* 71766 (1633) [ 0,  0, -1, -1,  0,  0,  0, -1,  0] [ 6,  6,  0]  1 */
     8578427, /* 71767 (1633) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 3,  0,  3]  1 */
    60357118, /* 71768 (1633) [ 0,  0, -1,  0, -1,  0,  1,  0,  0] [ 9,  3,  6] -1 */
    10113701, /* 71769 (1633) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 3,  6,  9]  1 */
    10758964, /* 71770 (1633) [ 0,  1,  0,  0,  0,  1, -1,  0,  0] [ 3,  9,  6]  1 */
    51911969, /* 71771 (1633) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 6,  3,  9] -1 */
    36326919, /* 71772 (1633) [ 0,  1,  0, -1,  0,  0,  0,  0, -1] [ 0,  9,  9] -1 */
    18439772, /* 71773 (1633) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    44118787, /* 71774 (1633) [ 0,  0, -1,  0,  1,  0, -1,  0,  0] [ 3,  6,  9] -1 */
    51920443, /* 71775 (1633) [ 1,  0,  0,  0,  0, -1,  0, -1,  0] [ 6,  3,  9] -1 */
    17127408, /* 71776 (1633) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  6]  1 */
    10750118, /* 71777 (1633) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 3,  9,  6]  1 */
    44762398, /* 71778 (1633) [-1,  0,  0,  0,  0, -1,  0,  1,  0] [ 3,  9,  6] -1 */
     9214844, /* 71779 (1633) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 3,  3,  0]  1 */
    17899537, /* 71780 (1633) [ 0, -1,  0,  0,  0,  1,  1,  0,  0] [ 6,  3,  9]  1 */
    42582225, /* 71781 (1633) [ 0, -1,  0,  1,  0,  0,  0,  0, -1] [ 3,  0,  3] -1 */
    34022884, /* 71782 (1633) [ 0,  0,  1,  0,  1,  0,  1,  0,  0] [ 0,  0,  0] -1 */
    52446172, /* 71783 (1633) [ 0,  0,  1,  0,  1,  0,  1,  0,  0] [ 6,  6,  0] -1 */
    18435352, /* 71784 (1633) [ 0,  1,  0,  0,  0,  1,  1,  0,  0] [ 6,  6,  0]  1 */
    52444534, /* 71785 (1633) [ 0,  0, -1,  0, -1,  0, -1,  0,  0] [ 6,  6,  0] -1 */
     1544140, /* 71786 (1633) [ 0,  0, -1, -1,  0,  0,  0, -1,  0] [ 0,  6,  6]  1 */
     9228126, /* 71787 (1633) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 3,  3,  0]  1 */
    59710325, /* 71788 (1633) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 9,  0,  9] -1 */
       10816, /* 71789 (1633) [ 0,  0,  1,  1,  0,  0,  0,  1,  0] [ 0,  0,  0]  1 */
    18434104, /* 71790 (1633) [ 0,  0,  1,  1,  0,  0,  0,  1,  0] [ 6,  6,  0]  1 */
    59701843, /* 71791 (1633) [-1,  0,  0,  0,  0,  1,  0, -1,  0] [ 9,  0,  9] -1 */
       12064, /* 71792 (1633) [ 0,  1,  0,  0,  0,  1,  1,  0,  0] [ 0,  0,  0]  1 */
    19194287, /* 71793 (1633) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  9,  3]  1 */
    60355490, /* 71794 (1633) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 9,  3,  6] -1 */
     9222454, /* 71795 (1633) [ 0,  0,  1,  1,  0,  0,  0, -1,  0] [ 3,  3,  0]  1 */
     1551758, /* 71796 (1633) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
     8571457, /* 71797 (1633) [ 0,  0, -1,  1,  0,  0,  0, -1,  0] [ 3,  0,  3]  1 */
    10754554, /* 71798 (1633) [ 0, -1,  0,  0,  0, -1,  1,  0,  0] [ 3,  9,  6]  1 */
    17902171, /* 71799 (1633) [ 0,  0,  1, -1,  0,  0,  0, -1,  0] [ 6,  3,  9]  1 */
    60360348, /* 71800 (1633) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 9,  3,  6] -1 */
    52442922, /* 71801 (1633) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 6,  6,  0] -1 */
     2314903, /* 71802 (1633) [ 0,  1,  0,  0,  0, -1, -1,  0,  0] [ 0,  9,  9]  1 */
    25702637, /* 71803 (1633) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 9,  0,  9]  1 */
    35558158, /* 71804 (1633) [ 0,  0,  1,  0,  1,  0,  1,  0,  0] [ 0,  6,  6] -1 */
    35556520, /* 71805 (1633) [ 0,  0, -1,  0, -1,  0, -1,  0,  0] [ 0,  6,  6] -1 */
    59714917, /* 71806 (1633) [ 1,  0,  0,  0,  0, -1,  0,  1,  0] [ 9,  0,  9] -1 */
    25693987, /* 71807 (1633) [ 0, -1,  0,  0,  0,  1, -1,  0,  0] [ 9,  0,  9]  1 */
    51152866, /* 71808 (1633) [ 1,  0,  0,  0,  0,  1,  0,  1,  0] [ 6,  0,  6] -1 */
     1546090, /* 71809 (1633) [ 0,  0,  1,  1,  0,  0,  0,  1,  0] [ 0,  6,  6]  1 */
    61654568, /* 71810 (1633) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 9,  9,  0] -1 */
    34015474, /* 71811 (1633) [-1,  0,  0,  0,  0, -1,  0, -1,  0] [ 0,  0,  0] -1 */
    52438762, /* 71812 (1633) [-1,  0,  0,  0,  0, -1,  0, -1,  0] [ 6,  6,  0] -1 */
    27651414, /* 71813 (1633) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 9,  9,  0]  1 */
    53219521, /* 71814 (1633) [ 1,  0,  0,  0,  0, -1,  0, -1,  0] [ 6,  9,  3] -1 */
     9223690, /* 71815 (1633) [ 0,  1,  0,  0,  0,  1, -1,  0,  0] [ 3,  3,  0]  1 */
    60358720, /* 71816 (1633) [ 0,  0,  1,  0,  1,  0, -1,  0,  0] [ 9,  3,  6] -1 */
    35554908, /* 71817 (1633) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 0,  6,  6] -1 */
    19198615, /* 71818 (1633) [ 0, -1,  0,  0,  0,  1,  1,  0,  0] [ 6,  9,  3]  1 */
    34791645, /* 71819 (1633) [ 0,  1,  0, -1,  0,  0,  0,  0, -1] [ 0,  3,  3] -1 */
    53212351, /* 71820 (1633) [ 0,  0, -1,  0,  1,  0,  1,  0,  0] [ 6,  9,  3] -1 */
    60364504, /* 71821 (1633) [ 1,  0,  0,  0,  0,  1,  0, -1,  0] [ 9,  3,  6] -1 */
    42583513, /* 71822 (1633) [ 0,  0, -1,  0,  1,  0, -1,  0,  0] [ 3,  0,  3] -1 */
    36325615, /* 71823 (1633) [ 0,  0,  1,  0, -1,  0, -1,  0,  0] [ 0,  9,  9] -1 */
    51907381, /* 71824 (1633) [-1,  0,  0,  0,  0,  1,  0,  1,  0] [ 6,  3,  9] -1 */
    59706435, /* 71825 (1633) [ 0, -1,  0,  1,  0,  0,  0,  0, -1] [ 9,  0,  9] -1 */
    44117499, /* 71826 (1633) [ 0, -1,  0,  1,  0,  0,  0,  0, -1] [ 3,  6,  9] -1 */
    43232908, /* 71827 (1633) [ 0,  0, -1,  0, -1,  0,  1,  0,  0] [ 3,  3,  0] -1 */
    34021246, /* 71828 (1633) [ 0,  0, -1,  0, -1,  0, -1,  0,  0] [ 0,  0,  0] -1 */
    17133076, /* 71829 (1633) [ 0,  0, -1, -1,  0,  0,  0, -1,  0] [ 6,  0,  6]  1 */
    35550748, /* 71830 (1633) [-1,  0,  0,  0,  0, -1,  0, -1,  0] [ 0,  6,  6] -1 */
    25695667, /* 71831 (1633) [ 0,  0, -1,  1,  0,  0,  0, -1,  0] [ 9,  0,  9]  1 */
    10763400, /* 71832 (1633) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 3,  9,  6]  1 */
    34028656, /* 71833 (1633) [ 1,  0,  0,  0,  0,  1,  0,  1,  0] [ 0,  0,  0] -1 */
    17903839, /* 71834 (1633) [ 0,  1,  0,  0,  0, -1, -1,  0,  0] [ 6,  3,  9]  1 */
    19200283, /* 71835 (1633) [ 0,  0, -1,  1,  0,  0,  0,  1,  0] [ 6,  9,  3]  1 */
      770999, /* 71836 (1633) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  3,  3]  1 */
    27643804, /* 71837 (1633) [ 0,  0, -1, -1,  0,  0,  0,  1,  0] [ 9,  9,  0]  1 */
        7618, /* 71838 (1633) [ 0, -1,  0,  0,  0, -1, -1,  0,  0] [ 0,  0,  0]  1 */
    18430906, /* 71839 (1633) [ 0, -1,  0,  0,  0, -1, -1,  0,  0] [ 6,  6,  0]  1 */
     2306273, /* 71840 (1633) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  9,  9]  1 */
    60351334, /* 71841 (1633) [-1,  0,  0,  0,  0, -1,  0,  1,  0] [ 9,  3,  6] -1 */
    10106731, /* 71842 (1633) [ 0,  0, -1,  1,  0,  0,  0, -1,  0] [ 3,  6,  9]  1 */
    34019634, /* 71843 (1633) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  0] -1 */
     9219280, /* 71844 (1633) [ 0, -1,  0,  0,  0, -1,  1,  0,  0] [ 3,  3,  0]  1 */
    18426486, /* 71845 (1633) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
    61013995, /* 71846 (1633) [ 1,  0,  0,  0,  0, -1,  0,  1,  0] [ 9,  6,  3] -1 */
      783957, /* 71847 (1633) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  3,  3]  1 */
    42584827, /* 71848 (1633) [ 0,  0,  1,  0, -1,  0,  1,  0,  0] [ 3,  0,  3] -1 */
    26993065, /* 71849 (1633) [ 0, -1,  0,  0,  0,  1, -1,  0,  0] [ 9,  6,  3]  1 */
    19207245, /* 71850 (1633) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  9,  3]  1 */
    61008115, /* 71851 (1633) [ 0,  0,  1,  0, -1,  0,  1,  0,  0] [ 9,  6,  3] -1 */
    26995723, /* 71852 (1633) [ 0,  0,  1, -1,  0,  0,  0,  1,  0] [ 9,  6,  3]  1 */
    25698325, /* 71853 (1633) [ 0,  1,  0,  0,  0, -1,  1,  0,  0] [ 9,  0,  9]  1 */
    26988753, /* 71854 (1633) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 9,  6,  3]  1 */
     1547338, /* 71855 (1633) [ 0,  1,  0,  0,  0,  1,  1,  0,  0] [ 0,  6,  6]  1 */
    51145456, /* 71856 (1633) [ 0,  0, -1,  0, -1,  0, -1,  0,  0] [ 6,  0,  6] -1 */
    17135026, /* 71857 (1633) [ 0,  0,  1,  1,  0,  0,  0,  1,  0] [ 6,  0,  6]  1 */
    43231280, /* 71858 (1633) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 3,  3,  0] -1 */
    61656196, /* 71859 (1633) [ 0,  0, -1,  0, -1,  0,  1,  0,  0] [ 9,  9,  0] -1 */
     9220516, /* 71860 (1633) [ 0,  0, -1, -1,  0,  0,  0,  1,  0] [ 3,  3,  0]  1 */
    51915855, /* 71861 (1633) [ 0,  1,  0, -1,  0,  0,  0,  0, -1] [ 6,  3,  9] -1 */
    10755790, /* 71862 (1633) [ 0,  0, -1, -1,  0,  0,  0,  1,  0] [ 3,  9,  6]  1 */
     1542892, /* 71863 (1633) [ 0, -1,  0,  0,  0, -1, -1,  0,  0] [ 0,  6,  6]  1 */
    43236138, /* 71864 (1633) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 3,  3,  0] -1 */
    53211047, /* 71865 (1633) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 6,  9,  3] -1 */
    59707723, /* 71866 (1633) [ 0,  0, -1,  0,  1,  0, -1,  0,  0] [ 9,  0,  9] -1 */
    36331507, /* 71867 (1633) [ 1,  0,  0,  0,  0, -1,  0, -1,  0] [ 0,  9,  9] -1 */
    34790341, /* 71868 (1633) [ 0,  0,  1,  0, -1,  0, -1,  0,  0] [ 0,  3,  3] -1 */
    53206459, /* 71869 (1633) [-1,  0,  0,  0,  0,  1,  0,  1,  0] [ 6,  9,  3] -1 */
    34789063, /* 71870 (1633) [ 0,  0, -1,  0,  1,  0,  1,  0,  0] [ 0,  3,  3] -1 */
     2310601, /* 71871 (1633) [ 0, -1,  0,  0,  0,  1,  1,  0,  0] [ 0,  9,  9]  1 */
     1538472, /* 71872 (1633) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
    36324337, /* 71873 (1633) [ 0,  0, -1,  0,  1,  0,  1,  0,  0] [ 0,  9,  9] -1 */
    61009403, /* 71874 (1633) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 9,  6,  3] -1 */
    17895209, /* 71875 (1633) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  3,  9]  1 */
    44768182, /* 71876 (1633) [ 0,  0, -1,  0, -1,  0,  1,  0,  0] [ 3,  9,  6] -1 */
    51139684, /* 71877 (1633) [-1,  0,  0,  0,  0, -1,  0, -1,  0] [ 6,  0,  6] -1 */
    43234510, /* 71878 (1633) [ 0,  0,  1,  0,  1,  0, -1,  0,  0] [ 3,  3,  0] -1 */
      776995, /* 71879 (1633) [ 0,  0, -1,  1,  0,  0,  0,  1,  0] [ 0,  3,  3]  1 */
    61000921, /* 71880 (1633) [-1,  0,  0,  0,  0,  1,  0, -1,  0] [ 9,  6,  3] -1 */
     2312269, /* 71881 (1633) [ 0,  0, -1,  1,  0,  0,  0,  1,  0] [ 0,  9,  9]  1 */
    27646978, /* 71882 (1633) [ 0,  1,  0,  0,  0,  1, -1,  0,  0] [ 9,  9,  0]  1 */
       16484, /* 71883 (1634) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    61663638, /* 71884 (1634) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 9,  9,  0] -1 */
    44125925, /* 71885 (1634) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 3,  6,  9] -1 */
    44771188, /* 71886 (1634) [ 0,  1,  0,  0,  0,  1, -1,  0,  0] [ 3,  9,  6] -1 */
    61650412, /* 71887 (1634) [-1,  0,  0,  0,  0, -1,  0,  1,  0] [ 9,  9,  0] -1 */
     8565465, /* 71888 (1634) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 3,  0,  3]  1 */
    17140694, /* 71889 (1634) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
    19201249, /* 71890 (1634) [ 0,  0,  1, -1,  0,  0,  0, -1,  0] [ 6,  9,  3]  1 */
    43235914, /* 71891 (1634) [ 0,  1,  0,  0,  0,  1, -1,  0,  0] [ 3,  3,  0] -1 */
        9022, /* 71892 (1634) [ 0,  0, -1,  0, -1,  0, -1,  0,  0] [ 0,  0,  0]  1 */
    18432310, /* 71893 (1634) [ 0,  0, -1,  0, -1,  0, -1,  0,  0] [ 6,  6,  0]  1 */
    25698101, /* 71894 (1634) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 9,  0,  9]  1 */
    51147094, /* 71895 (1634) [ 0,  0,  1,  0,  1,  0,  1,  0,  0] [ 6,  0,  6] -1 */
    26339054, /* 71896 (1634) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 9,  3,  6]  1 */
     1538524, /* 71897 (1634) [-1,  0,  0,  0,  0, -1,  0, -1,  0] [ 0,  6,  6]  1 */
    53210839, /* 71898 (1634) [ 0, -1,  0,  0,  0,  1,  1,  0,  0] [ 6,  9,  3] -1 */
    51139632, /* 71899 (1634) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  6] -1 */
    10105051, /* 71900 (1634) [ 0, -1,  0,  0,  0,  1, -1,  0,  0] [ 3,  6,  9]  1 */
     2319231, /* 71901 (1634) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  9,  9]  1 */
     8569777, /* 71902 (1634) [ 0, -1,  0,  0,  0,  1, -1,  0,  0] [ 3,  0,  3]  1 */
    10100739, /* 71903 (1634) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 3,  6,  9]  1 */
    17136274, /* 71904 (1634) [ 0,  1,  0,  0,  0,  1,  1,  0,  0] [ 6,  0,  6]  1 */
    53214933, /* 71905 (1634) [ 0,  1,  0, -1,  0,  0,  0,  0, -1] [ 6,  9,  3] -1 */
        7410, /* 71906 (1634) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    26348124, /* 71907 (1634) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 9,  3,  6]  1 */
    18430698, /* 71908 (1634) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 6,  6,  0]  1 */
    61006801, /* 71909 (1634) [ 0,  0, -1,  0,  1,  0, -1,  0,  0] [ 9,  6,  3] -1 */
    27001771, /* 71910 (1634) [ 1,  0,  0,  0,  0, -1,  0,  1,  0] [ 9,  6,  3]  1 */
    43240350, /* 71911 (1634) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 3,  3,  0] -1 */
    44766554, /* 71912 (1634) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 3,  9,  6] -1 */
    53213629, /* 71913 (1634) [ 0,  0,  1,  0, -1,  0, -1,  0,  0] [ 6,  9,  3] -1 */
    26995891, /* 71914 (1634) [ 0,  0,  1,  0, -1,  0,  1,  0,  0] [ 9,  6,  3]  1 */
    34024496, /* 71915 (1634) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    52447784, /* 71916 (1634) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 6,  6,  0] -1 */
    43227124, /* 71917 (1634) [-1,  0,  0,  0,  0, -1,  0,  1,  0] [ 3,  3,  0] -1 */
    34783223, /* 71918 (1634) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  3,  3] -1 */
     1544296, /* 71919 (1634) [ 0,  0, -1,  0, -1,  0, -1,  0,  0] [ 0,  6,  6]  1 */
    53206511, /* 71920 (1634) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  9,  3] -1 */
    34796233, /* 71921 (1634) [ 1,  0,  0,  0,  0, -1,  0, -1,  0] [ 0,  3,  3] -1 */
    61005513, /* 71922 (1634) [ 0, -1,  0,  1,  0,  0,  0,  0, -1] [ 9,  6,  3] -1 */
    51914551, /* 71923 (1634) [ 0,  0,  1,  0, -1,  0, -1,  0,  0] [ 6,  3,  9] -1 */
    27642568, /* 71924 (1634) [ 0, -1,  0,  0,  0, -1,  1,  0,  0] [ 9,  9,  0]  1 */
    52451944, /* 71925 (1634) [ 1,  0,  0,  0,  0,  1,  0,  1,  0] [ 6,  6,  0] -1 */
        3250, /* 71926 (1634) [-1,  0,  0,  0,  0, -1,  0, -1,  0] [ 0,  0,  0]  1 */
    26343490, /* 71927 (1634) [ 0, -1,  0,  0,  0, -1,  1,  0,  0] [ 9,  3,  6]  1 */
    19198823, /* 71928 (1634) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 6,  9,  3]  1 */
    59710549, /* 71929 (1634) [ 0,  1,  0,  0,  0, -1,  1,  0,  0] [ 9,  0,  9] -1 */
    19194235, /* 71930 (1634) [-1,  0,  0,  0,  0,  1,  0,  1,  0] [ 6,  9,  3]  1 */
    26346496, /* 71931 (1634) [ 0,  0,  1,  0,  1,  0, -1,  0,  0] [ 9,  3,  6]  1 */
     1542684, /* 71932 (1634) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 0,  6,  6]  1 */
      776839, /* 71933 (1634) [ 0,  0, -1,  0,  1,  0,  1,  0,  0] [ 0,  3,  3]  1 */
    26344726, /* 71934 (1634) [ 0,  0, -1, -1,  0,  0,  0,  1,  0] [ 9,  3,  6]  1 */
    59714861, /* 71935 (1634) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 9,  0,  9] -1 */
    51148706, /* 71936 (1634) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 6,  0,  6] -1 */
    26994745, /* 71937 (1634) [ 0,  0, -1,  1,  0,  0,  0, -1,  0] [ 9,  6,  3]  1 */
      779629, /* 71938 (1634) [ 0,  1,  0,  0,  0, -1, -1,  0,  0] [ 0,  3,  3]  1 */
    26352280, /* 71939 (1634) [ 1,  0,  0,  0,  0,  1,  0, -1,  0] [ 9,  3,  6]  1 */
    19202917, /* 71940 (1634) [ 0,  1,  0,  0,  0, -1, -1,  0,  0] [ 6,  9,  3]  1 */
    42577633, /* 71941 (1634) [-1,  0,  0,  0,  0,  1,  0, -1,  0] [ 3,  0,  3] -1 */
    35559770, /* 71942 (1634) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 0,  6,  6] -1 */
    44112907, /* 71943 (1634) [-1,  0,  0,  0,  0,  1,  0, -1,  0] [ 3,  6,  9] -1 */
    27638132, /* 71944 (1634) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 9,  9,  0]  1 */
      777961, /* 71945 (1634) [ 0,  0,  1, -1,  0,  0,  0, -1,  0] [ 0,  3,  3]  1 */
    17908167, /* 71946 (1634) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  3,  9]  1 */
    25689675, /* 71947 (1634) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 9,  0,  9]  1 */
     2313235, /* 71948 (1634) [ 0,  0,  1, -1,  0,  0,  0, -1,  0] [ 0,  9,  9]  1 */
    35563930, /* 71949 (1634) [ 1,  0,  0,  0,  0,  1,  0,  1,  0] [ 0,  6,  6] -1 */
    36322825, /* 71950 (1634) [ 0, -1,  0,  0,  0,  1,  1,  0,  0] [ 0,  9,  9] -1 */
    60357118, /* 71951 (1634) [ 0,  0, -1,  0, -1,  0,  1,  0,  0] [ 9,  3,  6] -1 */
    27647202, /* 71952 (1634) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 9,  9,  0]  1 */
    36326919, /* 71953 (1634) [ 0,  1,  0, -1,  0,  0,  0,  0, -1] [ 0,  9,  9] -1 */
    18439772, /* 71954 (1634) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    44118787, /* 71955 (1634) [ 0,  0, -1,  0,  1,  0, -1,  0,  0] [ 3,  6,  9] -1 */
    51920443, /* 71956 (1634) [ 1,  0,  0,  0,  0, -1,  0, -1,  0] [ 6,  3,  9] -1 */
     8572603, /* 71957 (1634) [ 0,  0,  1,  0, -1,  0,  1,  0,  0] [ 3,  0,  3]  1 */
    51145300, /* 71958 (1634) [ 0,  0, -1, -1,  0,  0,  0, -1,  0] [ 6,  0,  6] -1 */
    10113757, /* 71959 (1634) [ 1,  0,  0,  0,  0, -1,  0,  1,  0] [ 3,  6,  9]  1 */
    10750118, /* 71960 (1634) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 3,  9,  6]  1 */
    44775624, /* 71961 (1634) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 3,  9,  6] -1 */
    34789219, /* 71962 (1634) [ 0,  0, -1,  1,  0,  0,  0,  1,  0] [ 0,  3,  3] -1 */
    44762398, /* 71963 (1634) [-1,  0,  0,  0,  0, -1,  0,  1,  0] [ 3,  9,  6] -1 */
     9214844, /* 71964 (1634) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 3,  3,  0]  1 */
    53212507, /* 71965 (1634) [ 0,  0, -1,  1,  0,  0,  0,  1,  0] [ 6,  9,  3] -1 */
    42582225, /* 71966 (1634) [ 0, -1,  0,  1,  0,  0,  0,  0, -1] [ 3,  0,  3] -1 */
    17133232, /* 71967 (1634) [ 0,  0, -1,  0, -1,  0, -1,  0,  0] [ 6,  0,  6]  1 */
    34019842, /* 71968 (1634) [ 0, -1,  0,  0,  0, -1, -1,  0,  0] [ 0,  0,  0] -1 */
    52443130, /* 71969 (1634) [ 0, -1,  0,  0,  0, -1, -1,  0,  0] [ 6,  6,  0] -1 */
    36318497, /* 71970 (1634) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  9,  9] -1 */
    34022884, /* 71971 (1634) [ 0,  0,  1,  0,  1,  0,  1,  0,  0] [ 0,  0,  0] -1 */
    52446172, /* 71972 (1634) [ 0,  0,  1,  0,  1,  0,  1,  0,  0] [ 6,  6,  0] -1 */
    18435352, /* 71973 (1634) [ 0,  1,  0,  0,  0,  1,  1,  0,  0] [ 6,  6,  0]  1 */
    61009627, /* 71974 (1634) [ 0,  1,  0,  0,  0, -1,  1,  0,  0] [ 9,  6,  3] -1 */
    60360124, /* 71975 (1634) [ 0,  1,  0,  0,  0,  1, -1,  0,  0] [ 9,  3,  6] -1 */
       10816, /* 71976 (1634) [ 0,  0,  1,  1,  0,  0,  0,  1,  0] [ 0,  0,  0]  1 */
    34015422, /* 71977 (1634) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    18434104, /* 71978 (1634) [ 0,  0,  1,  1,  0,  0,  0,  1,  0] [ 6,  6,  0]  1 */
      775535, /* 71979 (1634) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 0,  3,  3]  1 */
    52438710, /* 71980 (1634) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
     9223914, /* 71981 (1634) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 3,  3,  0]  1 */
    42584659, /* 71982 (1634) [ 0,  0,  1, -1,  0,  0,  0,  1,  0] [ 3,  0,  3] -1 */
    10759188, /* 71983 (1634) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 3,  9,  6]  1 */
    61007947, /* 71984 (1634) [ 0,  0,  1, -1,  0,  0,  0,  1,  0] [ 9,  6,  3] -1 */
    59701843, /* 71985 (1634) [-1,  0,  0,  0,  0,  1,  0, -1,  0] [ 9,  0,  9] -1 */
       12064, /* 71986 (1634) [ 0,  1,  0,  0,  0,  1,  1,  0,  0] [ 0,  0,  0]  1 */
     2306221, /* 71987 (1634) [-1,  0,  0,  0,  0,  1,  0,  1,  0] [ 0,  9,  9]  1 */
    60355490, /* 71988 (1634) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 9,  3,  6] -1 */
     1551758, /* 71989 (1634) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
     8571457, /* 71990 (1634) [ 0,  0, -1,  1,  0,  0,  0, -1,  0] [ 3,  0,  3]  1 */
     2312113, /* 71991 (1634) [ 0,  0, -1,  0,  1,  0,  1,  0,  0] [ 0,  9,  9]  1 */
    10754554, /* 71992 (1634) [ 0, -1,  0,  0,  0, -1,  1,  0,  0] [ 3,  9,  6]  1 */
    17902171, /* 71993 (1634) [ 0,  0,  1, -1,  0,  0,  0, -1,  0] [ 6,  3,  9]  1 */
     2314903, /* 71994 (1634) [ 0,  1,  0,  0,  0, -1, -1,  0,  0] [ 0,  9,  9]  1 */
    60358888, /* 71995 (1634) [ 0,  0,  1,  1,  0,  0,  0, -1,  0] [ 9,  3,  6] -1 */
    35555116, /* 71996 (1634) [ 0, -1,  0,  0,  0, -1, -1,  0,  0] [ 0,  6,  6] -1 */
     8573891, /* 71997 (1634) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 3,  0,  3]  1 */
    26997179, /* 71998 (1634) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 9,  6,  3]  1 */
    35558158, /* 71999 (1634) [ 0,  0,  1,  0,  1,  0,  1,  0,  0] [ 0,  6,  6] -1 */
    25693987, /* 72000 (1634) [ 0, -1,  0,  0,  0,  1, -1,  0,  0] [ 9,  0,  9]  1 */
    51152866, /* 72001 (1634) [ 1,  0,  0,  0,  0,  1,  0,  1,  0] [ 6,  0,  6] -1 */
    17127460, /* 72002 (1634) [-1,  0,  0,  0,  0, -1,  0, -1,  0] [ 6,  0,  6]  1 */
     9222286, /* 72003 (1634) [ 0,  0,  1,  0,  1,  0, -1,  0,  0] [ 3,  3,  0]  1 */
     1546090, /* 72004 (1634) [ 0,  0,  1,  1,  0,  0,  0,  1,  0] [ 0,  6,  6]  1 */
    35550696, /* 72005 (1634) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  6] -1 */
     9228070, /* 72006 (1634) [ 1,  0,  0,  0,  0,  1,  0, -1,  0] [ 3,  3,  0]  1 */
    25696813, /* 72007 (1634) [ 0,  0,  1,  0, -1,  0,  1,  0,  0] [ 9,  0,  9]  1 */
    53219521, /* 72008 (1634) [ 1,  0,  0,  0,  0, -1,  0, -1,  0] [ 6,  9,  3] -1 */
    34791645, /* 72009 (1634) [ 0,  1,  0, -1,  0,  0,  0,  0, -1] [ 0,  3,  3] -1 */
    51907433, /* 72010 (1634) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  3,  9] -1 */
    42583513, /* 72011 (1634) [ 0,  0, -1,  0,  1,  0, -1,  0,  0] [ 3,  0,  3] -1 */
    36325615, /* 72012 (1634) [ 0,  0,  1,  0, -1,  0, -1,  0,  0] [ 0,  9,  9] -1 */
    10107877, /* 72013 (1634) [ 0,  0,  1,  0, -1,  0,  1,  0,  0] [ 3,  6,  9]  1 */
     8578483, /* 72014 (1634) [ 1,  0,  0,  0,  0, -1,  0,  1,  0] [ 3,  0,  3]  1 */
    36324493, /* 72015 (1634) [ 0,  0, -1,  1,  0,  0,  0,  1,  0] [ 0,  9,  9] -1 */
    61659202, /* 72016 (1634) [ 0,  1,  0,  0,  0,  1, -1,  0,  0] [ 9,  9,  0] -1 */
    59706435, /* 72017 (1634) [ 0, -1,  0,  1,  0,  0,  0,  0, -1] [ 9,  0,  9] -1 */
    44117499, /* 72018 (1634) [ 0, -1,  0,  1,  0,  0,  0,  0, -1] [ 3,  6,  9] -1 */
    43232908, /* 72019 (1634) [ 0,  0, -1,  0, -1,  0,  1,  0,  0] [ 3,  3,  0] -1 */
    17131620, /* 72020 (1634) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 6,  0,  6]  1 */
    44121613, /* 72021 (1634) [ 0,  1,  0,  0,  0, -1,  1,  0,  0] [ 3,  6,  9] -1 */
    17901049, /* 72022 (1634) [ 0,  0, -1,  0,  1,  0,  1,  0,  0] [ 6,  3,  9]  1 */
    25695667, /* 72023 (1634) [ 0,  0, -1,  1,  0,  0,  0, -1,  0] [ 9,  0,  9]  1 */
    34028656, /* 72024 (1634) [ 1,  0,  0,  0,  0,  1,  0,  1,  0] [ 0,  0,  0] -1 */
    17903839, /* 72025 (1634) [ 0,  1,  0,  0,  0, -1, -1,  0,  0] [ 6,  3,  9]  1 */
    27645574, /* 72026 (1634) [ 0,  0,  1,  0,  1,  0, -1,  0,  0] [ 9,  9,  0]  1 */
    52444378, /* 72027 (1634) [ 0,  0, -1, -1,  0,  0,  0, -1,  0] [ 6,  6,  0] -1 */
     2310809, /* 72028 (1634) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 0,  9,  9]  1 */
    42590651, /* 72029 (1634) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 3,  0,  3] -1 */
    27643804, /* 72030 (1634) [ 0,  0, -1, -1,  0,  0,  0,  1,  0] [ 9,  9,  0]  1 */
    44119933, /* 72031 (1634) [ 0,  0,  1, -1,  0,  0,  0,  1,  0] [ 3,  6,  9] -1 */
    61013939, /* 72032 (1634) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 9,  6,  3] -1 */
    27651358, /* 72033 (1634) [ 1,  0,  0,  0,  0,  1,  0, -1,  0] [ 9,  9,  0]  1 */
    60364560, /* 72034 (1634) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 9,  3,  6] -1 */
      770947, /* 72035 (1634) [-1,  0,  0,  0,  0,  1,  0,  1,  0] [ 0,  3,  3]  1 */
    60351334, /* 72036 (1634) [-1,  0,  0,  0,  0, -1,  0,  1,  0] [ 9,  3,  6] -1 */
    61657966, /* 72037 (1634) [ 0,  0,  1,  1,  0,  0,  0, -1,  0] [ 9,  9,  0] -1 */
    10106731, /* 72038 (1634) [ 0,  0, -1,  1,  0,  0,  0, -1,  0] [ 3,  6,  9]  1 */
     9219280, /* 72039 (1634) [ 0, -1,  0,  0,  0, -1,  1,  0,  0] [ 3,  3,  0]  1 */
      783957, /* 72040 (1634) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  3,  3]  1 */
    26993065, /* 72041 (1634) [ 0, -1,  0,  0,  0,  1, -1,  0,  0] [ 9,  6,  3]  1 */
    19207245, /* 72042 (1634) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  9,  3]  1 */
    34787551, /* 72043 (1634) [ 0, -1,  0,  0,  0,  1,  1,  0,  0] [ 0,  3,  3] -1 */
    26988753, /* 72044 (1634) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 9,  6,  3]  1 */
    51144052, /* 72045 (1634) [ 0, -1,  0,  0,  0, -1, -1,  0,  0] [ 6,  0,  6] -1 */
    51911761, /* 72046 (1634) [ 0, -1,  0,  0,  0,  1,  1,  0,  0] [ 6,  3,  9] -1 */
     1547338, /* 72047 (1634) [ 0,  1,  0,  0,  0,  1,  1,  0,  0] [ 0,  6,  6]  1 */
    10109165, /* 72048 (1634) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 3,  6,  9]  1 */
    17135026, /* 72049 (1634) [ 0,  0,  1,  1,  0,  0,  0,  1,  0] [ 6,  0,  6]  1 */
    43231280, /* 72050 (1634) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 3,  3,  0] -1 */
    61656196, /* 72051 (1634) [ 0,  0, -1,  0, -1,  0,  1,  0,  0] [ 9,  9,  0] -1 */
     9220516, /* 72052 (1634) [ 0,  0, -1, -1,  0,  0,  0,  1,  0] [ 3,  3,  0]  1 */
    35556364, /* 72053 (1634) [ 0,  0, -1, -1,  0,  0,  0, -1,  0] [ 0,  6,  6] -1 */
    10757560, /* 72054 (1634) [ 0,  0,  1,  0,  1,  0, -1,  0,  0] [ 3,  9,  6]  1 */
    51915855, /* 72055 (1634) [ 0,  1,  0, -1,  0,  0,  0,  0, -1] [ 6,  3,  9] -1 */
    10755790, /* 72056 (1634) [ 0,  0, -1, -1,  0,  0,  0,  1,  0] [ 3,  9,  6]  1 */
    59707723, /* 72057 (1634) [ 0,  0, -1,  0,  1,  0, -1,  0,  0] [ 9,  0,  9] -1 */
    10763344, /* 72058 (1634) [ 1,  0,  0,  0,  0,  1,  0, -1,  0] [ 3,  9,  6]  1 */
    36331507, /* 72059 (1634) [ 1,  0,  0,  0,  0, -1,  0, -1,  0] [ 0,  9,  9] -1 */
    34790341, /* 72060 (1634) [ 0,  0,  1,  0, -1,  0, -1,  0,  0] [ 0,  3,  3] -1 */
    44769952, /* 72061 (1634) [ 0,  0,  1,  1,  0,  0,  0, -1,  0] [ 3,  9,  6] -1 */
    25702693, /* 72062 (1634) [ 1,  0,  0,  0,  0, -1,  0,  1,  0] [ 9,  0,  9]  1 */
    51913429, /* 72063 (1634) [ 0,  0, -1,  1,  0,  0,  0,  1,  0] [ 6,  3,  9] -1 */
    43234678, /* 72064 (1634) [ 0,  0,  1,  1,  0,  0,  0, -1,  0] [ 3,  3,  0] -1 */
    18426538, /* 72065 (1634) [-1,  0,  0,  0,  0, -1,  0, -1,  0] [ 6,  6,  0]  1 */
    17899745, /* 72066 (1634) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 6,  3,  9]  1 */
    59708869, /* 72067 (1634) [ 0,  0,  1, -1,  0,  0,  0,  1,  0] [ 9,  0,  9] -1 */
    19200127, /* 72068 (1634) [ 0,  0, -1,  0,  1,  0,  1,  0,  0] [ 6,  9,  3]  1 */
    44768182, /* 72069 (1634) [ 0,  0, -1,  0, -1,  0,  1,  0,  0] [ 3,  9,  6] -1 */
    42586339, /* 72070 (1634) [ 0,  1,  0,  0,  0, -1,  1,  0,  0] [ 3,  0,  3] -1 */
    17895157, /* 72071 (1634) [-1,  0,  0,  0,  0,  1,  0,  1,  0] [ 6,  3,  9]  1 */
    61000921, /* 72072 (1634) [-1,  0,  0,  0,  0,  1,  0, -1,  0] [ 9,  6,  3] -1 */
    34021090, /* 72073 (1634) [ 0,  0, -1, -1,  0,  0,  0, -1,  0] [ 0,  0,  0] -1 */
    61654568, /* 72074 (1634) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 9,  9,  0] -1 */
       16484, /* 72075 (1635) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
     8565465, /* 72076 (1635) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 3,  0,  3]  1 */
    17140694, /* 72077 (1635) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
        9022, /* 72078 (1635) [ 0,  0, -1,  0, -1,  0, -1,  0,  0] [ 0,  0,  0]  1 */
    18432310, /* 72079 (1635) [ 0,  0, -1,  0, -1,  0, -1,  0,  0] [ 6,  6,  0]  1 */
    26997403, /* 72080 (1635) [ 0,  1,  0,  0,  0, -1,  1,  0,  0] [ 9,  6,  3]  1 */
    26347900, /* 72081 (1635) [ 0,  1,  0,  0,  0,  1, -1,  0,  0] [ 9,  3,  6]  1 */
    51793663, /* 72082 (1635) [ 0, -1,  0,  0,  0,  1,  1,  0,  0] [ 6,  3,  3] -1 */
     1538524, /* 72083 (1635) [-1,  0,  0,  0,  0, -1,  0, -1,  0] [ 0,  6,  6]  1 */
        3198, /* 72084 (1635) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    43358392, /* 72085 (1635) [ 1,  0,  0,  0,  0,  1,  0, -1,  0] [ 3,  3,  6] -1 */
    43345166, /* 72086 (1635) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 3,  3,  6] -1 */
    10107709, /* 72087 (1635) [ 0,  0,  1, -1,  0,  0,  0,  1,  0] [ 3,  6,  9]  1 */
    26343266, /* 72088 (1635) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 9,  3,  6]  1 */
    17136274, /* 72089 (1635) [ 0,  1,  0,  0,  0,  1,  1,  0,  0] [ 6,  0,  6]  1 */
    53331727, /* 72090 (1635) [ 0,  0,  1,  0, -1,  0, -1,  0,  0] [ 6,  9,  9] -1 */
    27001771, /* 72091 (1635) [ 1,  0,  0,  0,  0, -1,  0,  1,  0] [ 9,  6,  3]  1 */
    26995891, /* 72092 (1635) [ 0,  0,  1,  0, -1,  0,  1,  0,  0] [ 9,  6,  3]  1 */
    52570042, /* 72093 (1635) [ 1,  0,  0,  0,  0,  1,  0,  1,  0] [ 6,  6,  6] -1 */
    59590771, /* 72094 (1635) [ 0,  0,  1, -1,  0,  0,  0,  1,  0] [ 9,  0,  3] -1 */
     1542684, /* 72095 (1635) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 0,  6,  6]  1 */
      776839, /* 72096 (1635) [ 0,  0, -1,  0,  1,  0,  1,  0,  0] [ 0,  3,  3]  1 */
    43350838, /* 72097 (1635) [ 0,  0, -1, -1,  0,  0,  0,  1,  0] [ 3,  3,  6] -1 */
    44007883, /* 72098 (1635) [ 1,  0,  0,  0,  0, -1,  0,  1,  0] [ 3,  6,  3] -1 */
     2313235, /* 72099 (1635) [ 0,  0,  1, -1,  0,  0,  0, -1,  0] [ 0,  9,  9]  1 */
    10755958, /* 72100 (1635) [ 0,  0, -1,  0, -1,  0,  1,  0,  0] [ 3,  9,  6]  1 */
    44002003, /* 72101 (1635) [ 0,  0,  1,  0, -1,  0,  1,  0,  0] [ 3,  6,  3] -1 */
     8574115, /* 72102 (1635) [ 0,  1,  0,  0,  0, -1,  1,  0,  0] [ 3,  0,  3]  1 */
    27642344, /* 72103 (1635) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 9,  9,  0]  1 */
    34146806, /* 72104 (1635) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    34133572, /* 72105 (1635) [-1,  0,  0,  0,  0, -1,  0, -1,  0] [ 0,  0,  6] -1 */
    18439772, /* 72106 (1635) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    36208821, /* 72107 (1635) [ 0,  1,  0, -1,  0,  0,  0,  0, -1] [ 0,  9,  3] -1 */
    53337619, /* 72108 (1635) [ 1,  0,  0,  0,  0, -1,  0, -1,  0] [ 6,  9,  9] -1 */
    10750118, /* 72109 (1635) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 3,  9,  6]  1 */
    44657470, /* 72110 (1635) [ 1,  0,  0,  0,  0,  1,  0, -1,  0] [ 3,  9,  0] -1 */
    17899537, /* 72111 (1635) [ 0, -1,  0,  0,  0,  1,  1,  0,  0] [ 6,  3,  9]  1 */
    34909743, /* 72112 (1635) [ 0,  1,  0, -1,  0,  0,  0,  0, -1] [ 0,  3,  9] -1 */
    51796297, /* 72113 (1635) [ 0,  0,  1, -1,  0,  0,  0, -1,  0] [ 6,  3,  3] -1 */
    44644244, /* 72114 (1635) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 3,  9,  0] -1 */
    19202709, /* 72115 (1635) [ 0,  1,  0, -1,  0,  0,  0,  0, -1] [ 6,  9,  3]  1 */
    51025954, /* 72116 (1635) [ 0, -1,  0,  0,  0, -1, -1,  0,  0] [ 6,  0,  0] -1 */
    18435352, /* 72117 (1635) [ 0,  1,  0,  0,  0,  1,  1,  0,  0] [ 6,  6,  0]  1 */
     9219056, /* 72118 (1635) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 3,  3,  0]  1 */
    18435560, /* 72119 (1635) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 6,  6,  0]  1 */
     2306221, /* 72120 (1635) [-1,  0,  0,  0,  0,  1,  0,  1,  0] [ 0,  9,  9]  1 */
     8571457, /* 72121 (1635) [ 0,  0, -1,  1,  0,  0,  0, -1,  0] [ 3,  0,  3]  1 */
    10754554, /* 72122 (1635) [ 0, -1,  0,  0,  0, -1,  1,  0,  0] [ 3,  9,  6]  1 */
    35445832, /* 72123 (1635) [ 1,  0,  0,  0,  0,  1,  0,  1,  0] [ 0,  6,  0] -1 */
    43994809, /* 72124 (1635) [-1,  0,  0,  0,  0,  1,  0, -1,  0] [ 3,  6,  3] -1 */
    36204727, /* 72125 (1635) [ 0, -1,  0,  0,  0,  1,  1,  0,  0] [ 0,  9,  3] -1 */
    25702637, /* 72126 (1635) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 9,  0,  9]  1 */
     8565409, /* 72127 (1635) [-1,  0,  0,  0,  0,  1,  0, -1,  0] [ 3,  0,  3]  1 */
    34905649, /* 72128 (1635) [ 0, -1,  0,  0,  0,  1,  1,  0,  0] [ 0,  3,  9] -1 */
    26988697, /* 72129 (1635) [-1,  0,  0,  0,  0,  1,  0, -1,  0] [ 9,  6,  3]  1 */
    52556860, /* 72130 (1635) [-1,  0,  0,  0,  0, -1,  0, -1,  0] [ 6,  6,  6] -1 */
    27651414, /* 72131 (1635) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 9,  9,  0]  1 */
    27638188, /* 72132 (1635) [-1,  0,  0,  0,  0, -1,  0,  1,  0] [ 9,  9,  0]  1 */
     9223690, /* 72133 (1635) [ 0,  1,  0,  0,  0,  1, -1,  0,  0] [ 3,  3,  0]  1 */
    61774294, /* 72134 (1635) [ 0,  0, -1,  0, -1,  0,  1,  0,  0] [ 9,  9,  6] -1 */
    53333239, /* 72135 (1635) [ 0,  1,  0,  0,  0, -1, -1,  0,  0] [ 6,  9,  9] -1 */
    43354236, /* 72136 (1635) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 3,  3,  6] -1 */
    53329145, /* 72137 (1635) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 6,  9,  9] -1 */
    10107877, /* 72138 (1635) [ 0,  0,  1,  0, -1,  0,  1,  0,  0] [ 3,  6,  9]  1 */
    51789283, /* 72139 (1635) [-1,  0,  0,  0,  0,  1,  0,  1,  0] [ 6,  3,  3] -1 */
    59592227, /* 72140 (1635) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 9,  0,  3] -1 */
    17131620, /* 72141 (1635) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 6,  0,  6]  1 */
    17908219, /* 72142 (1635) [ 1,  0,  0,  0,  0, -1,  0, -1,  0] [ 6,  3,  9]  1 */
    42708749, /* 72143 (1635) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 3,  0,  9] -1 */
    27645574, /* 72144 (1635) [ 0,  0,  1,  0,  1,  0, -1,  0,  0] [ 9,  9,  0]  1 */
        7618, /* 72145 (1635) [ 0, -1,  0,  0,  0, -1, -1,  0,  0] [ 0,  0,  0]  1 */
    18430906, /* 72146 (1635) [ 0, -1,  0,  0,  0, -1, -1,  0,  0] [ 6,  6,  0]  1 */
    34137732, /* 72147 (1635) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  6] -1 */
    26995723, /* 72148 (1635) [ 0,  0,  1, -1,  0,  0,  0,  1,  0] [ 9,  6,  3]  1 */
    61772890, /* 72149 (1635) [ 0, -1,  0,  0,  0, -1,  1,  0,  0] [ 9,  9,  6] -1 */
    34905857, /* 72150 (1635) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 0,  3,  9] -1 */
    10755790, /* 72151 (1635) [ 0,  0, -1, -1,  0,  0,  0,  1,  0] [ 3,  9,  6]  1 */
    10763344, /* 72152 (1635) [ 1,  0,  0,  0,  0,  1,  0, -1,  0] [ 3,  9,  6]  1 */
     2310601, /* 72153 (1635) [ 0, -1,  0,  0,  0,  1,  1,  0,  0] [ 0,  9,  9]  1 */
     1538472, /* 72154 (1635) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
    34901321, /* 72155 (1635) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  3,  9] -1 */
    53324609, /* 72156 (1635) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  9,  9] -1 */
    61123611, /* 72157 (1635) [ 0, -1,  0,  1,  0,  0,  0,  0, -1] [ 9,  6,  9] -1 */
    35432650, /* 72158 (1635) [-1,  0,  0,  0,  0, -1,  0, -1,  0] [ 0,  6,  0] -1 */
    17895209, /* 72159 (1635) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  3,  9]  1 */
    44001835, /* 72160 (1635) [ 0,  0,  1, -1,  0,  0,  0,  1,  0] [ 3,  6,  3] -1 */
     8571289, /* 72161 (1635) [ 0,  0, -1,  0,  1,  0, -1,  0,  0] [ 3,  0,  3]  1 */
    42704213, /* 72162 (1635) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 3,  0,  9] -1 */
       10660, /* 72163 (1635) [ 0,  0,  1,  0,  1,  0,  1,  0,  0] [ 0,  0,  0]  1 */
    19201249, /* 72164 (1635) [ 0,  0,  1, -1,  0,  0,  0, -1,  0] [ 6,  9,  3]  1 */
    25698101, /* 72165 (1635) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 9,  0,  9]  1 */
    26339054, /* 72166 (1635) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 9,  3,  6]  1 */
    51034820, /* 72167 (1635) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  0] -1 */
    17140642, /* 72168 (1635) [ 1,  0,  0,  0,  0,  1,  0,  1,  0] [ 6,  0,  6]  1 */
    34907317, /* 72169 (1635) [ 0,  0, -1,  1,  0,  0,  0,  1,  0] [ 0,  3,  9] -1 */
    53330605, /* 72170 (1635) [ 0,  0, -1,  1,  0,  0,  0,  1,  0] [ 6,  9,  9] -1 */
    51034768, /* 72171 (1635) [ 1,  0,  0,  0,  0,  1,  0,  1,  0] [ 6,  0,  0] -1 */
    61774126, /* 72172 (1635) [ 0,  0, -1, -1,  0,  0,  0,  1,  0] [ 9,  9,  6] -1 */
    36207361, /* 72173 (1635) [ 0,  0,  1, -1,  0,  0,  0, -1,  0] [ 0,  9,  3] -1 */
    61119075, /* 72174 (1635) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 9,  6,  9] -1 */
     2319283, /* 72175 (1635) [ 1,  0,  0,  0,  0, -1,  0, -1,  0] [ 0,  9,  9]  1 */
    10757728, /* 72176 (1635) [ 0,  0,  1,  1,  0,  0,  0, -1,  0] [ 3,  9,  6]  1 */
    52562632, /* 72177 (1635) [ 0,  0, -1,  0, -1,  0, -1,  0,  0] [ 6,  6,  6] -1 */
    19194235, /* 72178 (1635) [-1,  0,  0,  0,  0,  1,  0,  1,  0] [ 6,  9,  3]  1 */
    17901205, /* 72179 (1635) [ 0,  0, -1,  1,  0,  0,  0,  1,  0] [ 6,  3,  9]  1 */
    61127725, /* 72180 (1635) [ 0,  1,  0,  0,  0, -1,  1,  0,  0] [ 9,  6,  9] -1 */
    34133520, /* 72181 (1635) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
    26344726, /* 72182 (1635) [ 0,  0, -1, -1,  0,  0,  0,  1,  0] [ 9,  3,  6]  1 */
    34914279, /* 72183 (1635) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  3,  9] -1 */
    26352280, /* 72184 (1635) [ 1,  0,  0,  0,  0,  1,  0, -1,  0] [ 9,  3,  6]  1 */
    53337567, /* 72185 (1635) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  9,  9] -1 */
    17908167, /* 72186 (1635) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  3,  9]  1 */
    44650084, /* 72187 (1635) [ 0,  0, -1,  0, -1,  0,  1,  0,  0] [ 3,  9,  0] -1 */
        8866, /* 72188 (1635) [ 0,  0, -1, -1,  0,  0,  0, -1,  0] [ 0,  0,  0]  1 */
    18432154, /* 72189 (1635) [ 0,  0, -1, -1,  0,  0,  0, -1,  0] [ 6,  6,  0]  1 */
    10113701, /* 72190 (1635) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 3,  6,  9]  1 */
    51797965, /* 72191 (1635) [ 0,  1,  0,  0,  0, -1, -1,  0,  0] [ 6,  3,  3] -1 */
     8572603, /* 72192 (1635) [ 0,  0,  1,  0, -1,  0,  1,  0,  0] [ 3,  0,  3]  1 */
    36200347, /* 72193 (1635) [-1,  0,  0,  0,  0,  1,  0,  1,  0] [ 0,  9,  3] -1 */
    17127408, /* 72194 (1635) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  6]  1 */
    51802345, /* 72195 (1635) [ 1,  0,  0,  0,  0, -1,  0, -1,  0] [ 6,  3,  3] -1 */
     9214844, /* 72196 (1635) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 3,  3,  0]  1 */
    53330449, /* 72197 (1635) [ 0,  0, -1,  0,  1,  0,  1,  0,  0] [ 6,  9,  9] -1 */
    52556808, /* 72198 (1635) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    59596763, /* 72199 (1635) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 9,  0,  3] -1 */
    44003291, /* 72200 (1635) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 3,  6,  3] -1 */
    10759188, /* 72201 (1635) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 3,  9,  6]  1 */
       12064, /* 72202 (1635) [ 0,  1,  0,  0,  0,  1,  1,  0,  0] [ 0,  0,  0]  1 */
    17902327, /* 72203 (1635) [ 0,  0,  1,  0, -1,  0, -1,  0,  0] [ 6,  3,  9]  1 */
    51025746, /* 72204 (1635) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 6,  0,  0] -1 */
    34146754, /* 72205 (1635) [ 1,  0,  0,  0,  0,  1,  0,  1,  0] [ 0,  0,  6] -1 */
    18439720, /* 72206 (1635) [ 1,  0,  0,  0,  0,  1,  0,  1,  0] [ 6,  6,  0]  1 */
    61776064, /* 72207 (1635) [ 0,  0,  1,  1,  0,  0,  0, -1,  0] [ 9,  9,  6] -1 */
    60239020, /* 72208 (1635) [ 0,  0, -1,  0, -1,  0,  1,  0,  0] [ 9,  3,  0] -1 */
    25693987, /* 72209 (1635) [ 0, -1,  0,  0,  0,  1, -1,  0,  0] [ 9,  0,  9]  1 */
    44648680, /* 72210 (1635) [ 0, -1,  0,  0,  0, -1,  1,  0,  0] [ 3,  9,  0] -1 */
    35438422, /* 72211 (1635) [ 0,  0, -1,  0, -1,  0, -1,  0,  0] [ 0,  6,  0] -1 */
    17127460, /* 72212 (1635) [-1,  0,  0,  0,  0, -1,  0, -1,  0] [ 6,  0,  6]  1 */
     1546090, /* 72213 (1635) [ 0,  0,  1,  1,  0,  0,  0,  1,  0] [ 0,  6,  6]  1 */
    51793871, /* 72214 (1635) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 6,  3,  3] -1 */
    51021586, /* 72215 (1635) [-1,  0,  0,  0,  0, -1,  0, -1,  0] [ 6,  0,  0] -1 */
     9228070, /* 72216 (1635) [ 1,  0,  0,  0,  0,  1,  0, -1,  0] [ 3,  3,  0]  1 */
    34907161, /* 72217 (1635) [ 0,  0, -1,  0,  1,  0,  1,  0,  0] [ 0,  3,  9] -1 */
    19198615, /* 72218 (1635) [ 0, -1,  0,  0,  0,  1,  1,  0,  0] [ 6,  9,  3]  1 */
    44649916, /* 72219 (1635) [ 0,  0, -1, -1,  0,  0,  0,  1,  0] [ 3,  9,  0] -1 */
    51789335, /* 72220 (1635) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  3,  3] -1 */
    34908439, /* 72221 (1635) [ 0,  0,  1,  0, -1,  0, -1,  0,  0] [ 0,  3,  9] -1 */
     8578483, /* 72222 (1635) [ 1,  0,  0,  0,  0, -1,  0,  1,  0] [ 3,  0,  3]  1 */
    61125067, /* 72223 (1635) [ 0,  0, -1,  1,  0,  0,  0, -1,  0] [ 9,  6,  9] -1 */
       12272, /* 72224 (1635) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    25695667, /* 72225 (1635) [ 0,  0, -1,  1,  0,  0,  0, -1,  0] [ 9,  0,  9]  1 */
    17903839, /* 72226 (1635) [ 0,  1,  0,  0,  0, -1, -1,  0,  0] [ 6,  3,  9]  1 */
    42700099, /* 72227 (1635) [ 0, -1,  0,  0,  0,  1, -1,  0,  0] [ 3,  0,  9] -1 */
     2306273, /* 72228 (1635) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  9,  9]  1 */
    61119019, /* 72229 (1635) [-1,  0,  0,  0,  0,  1,  0, -1,  0] [ 9,  6,  9] -1 */
    43354012, /* 72230 (1635) [ 0,  1,  0,  0,  0,  1, -1,  0,  0] [ 3,  3,  6] -1 */
    61777524, /* 72231 (1635) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 9,  9,  6] -1 */
    35432598, /* 72232 (1635) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  0] -1 */
    10109165, /* 72233 (1635) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 3,  6,  9]  1 */
    43349378, /* 72234 (1635) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 3,  3,  6] -1 */
    60237616, /* 72235 (1635) [ 0, -1,  0,  0,  0, -1,  1,  0,  0] [ 9,  3,  0] -1 */
    17135026, /* 72236 (1635) [ 0,  0,  1,  1,  0,  0,  0,  1,  0] [ 6,  0,  6]  1 */
    61124899, /* 72237 (1635) [ 0,  0, -1,  0,  1,  0, -1,  0,  0] [ 9,  6,  9] -1 */
     1545934, /* 72238 (1635) [ 0,  0,  1,  0,  1,  0,  1,  0,  0] [ 0,  6,  6]  1 */
    42701779, /* 72239 (1635) [ 0,  0, -1,  1,  0,  0,  0, -1,  0] [ 3,  0,  9] -1 */
    36213409, /* 72240 (1635) [ 1,  0,  0,  0,  0, -1,  0, -1,  0] [ 0,  9,  3] -1 */
    43345222, /* 72241 (1635) [-1,  0,  0,  0,  0, -1,  0,  1,  0] [ 3,  3,  6] -1 */
    34909951, /* 72242 (1635) [ 0,  1,  0,  0,  0, -1, -1,  0,  0] [ 0,  3,  9] -1 */
    34141138, /* 72243 (1635) [ 0,  0,  1,  1,  0,  0,  0,  1,  0] [ 0,  0,  6] -1 */
    52564426, /* 72244 (1635) [ 0,  0,  1,  1,  0,  0,  0,  1,  0] [ 6,  6,  6] -1 */
    61775896, /* 72245 (1635) [ 0,  0,  1,  0,  1,  0, -1,  0,  0] [ 9,  9,  6] -1 */
    26344894, /* 72246 (1635) [ 0,  0, -1,  0, -1,  0,  1,  0,  0] [ 9,  3,  6]  1 */
    18426538, /* 72247 (1635) [-1,  0,  0,  0,  0, -1,  0, -1,  0] [ 6,  6,  0]  1 */
    60246406, /* 72248 (1635) [ 1,  0,  0,  0,  0,  1,  0, -1,  0] [ 9,  3,  0] -1 */
    34914331, /* 72249 (1635) [ 1,  0,  0,  0,  0, -1,  0, -1,  0] [ 0,  3,  9] -1 */
    59583801, /* 72250 (1635) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 9,  0,  3] -1 */
    43352776, /* 72251 (1635) [ 0,  0,  1,  1,  0,  0,  0, -1,  0] [ 3,  3,  6] -1 */
    51027358, /* 72252 (1635) [ 0,  0, -1,  0, -1,  0, -1,  0,  0] [ 6,  0,  0] -1 */
    19207297, /* 72253 (1635) [ 1,  0,  0,  0,  0, -1,  0, -1,  0] [ 6,  9,  3]  1 */
    60233180, /* 72254 (1635) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 9,  3,  0] -1 */
    17899745, /* 72255 (1635) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 6,  3,  9]  1 */
      779421, /* 72256 (1635) [ 0,  1,  0, -1,  0,  0,  0,  0, -1] [ 0,  3,  3]  1 */
    51802293, /* 72257 (1635) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  3,  3] -1 */
     2313391, /* 72258 (1635) [ 0,  0,  1,  0, -1,  0, -1,  0,  0] [ 0,  9,  9]  1 */
    61781736, /* 72259 (1635) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 9,  9,  6] -1 */
     2312269, /* 72260 (1635) [ 0,  0, -1,  1,  0,  0,  0,  1,  0] [ 0,  9,  9]  1 */
    25694211, /* 72261 (1635) [ 0, -1,  0,  1,  0,  0,  0,  0, -1] [ 9,  0,  9]  1 */
    43352608, /* 72262 (1635) [ 0,  0,  1,  0,  1,  0, -1,  0,  0] [ 3,  3,  6] -1 */
     8572435, /* 72263 (1635) [ 0,  0,  1, -1,  0,  0,  0,  1,  0] [ 3,  0,  3]  1 */
    10105051, /* 72264 (1635) [ 0, -1,  0,  0,  0,  1, -1,  0,  0] [ 3,  6,  9]  1 */
     2319231, /* 72265 (1635) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  9,  9]  1 */
    27001715, /* 72266 (1635) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 9,  6,  3]  1 */
        7410, /* 72267 (1635) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    18430698, /* 72268 (1635) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 6,  6,  0]  1 */
    43358448, /* 72269 (1635) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 3,  3,  6] -1 */
    51795331, /* 72270 (1635) [ 0,  0, -1,  1,  0,  0,  0,  1,  0] [ 6,  3,  3] -1 */
      775327, /* 72271 (1635) [ 0, -1,  0,  0,  0,  1,  1,  0,  0] [ 0,  3,  3]  1 */
    60238852, /* 72272 (1635) [ 0,  0, -1, -1,  0,  0,  0,  1,  0] [ 9,  3,  0] -1 */
    52561228, /* 72273 (1635) [ 0, -1,  0,  0,  0, -1, -1,  0,  0] [ 6,  6,  6] -1 */
     1544296, /* 72274 (1635) [ 0,  0, -1,  0, -1,  0, -1,  0,  0] [ 0,  6,  6]  1 */
    36209029, /* 72275 (1635) [ 0,  1,  0,  0,  0, -1, -1,  0,  0] [ 0,  9,  3] -1 */
    27642568, /* 72276 (1635) [ 0, -1,  0,  0,  0, -1,  1,  0,  0] [ 9,  9,  0]  1 */
    51021534, /* 72277 (1635) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  0] -1 */
    27643972, /* 72278 (1635) [ 0,  0, -1,  0, -1,  0,  1,  0,  0] [ 9,  9,  0]  1 */
    42700323, /* 72279 (1635) [ 0, -1,  0,  1,  0,  0,  0,  0, -1] [ 3,  0,  9] -1 */
    26343490, /* 72280 (1635) [ 0, -1,  0,  0,  0, -1,  1,  0,  0] [ 9,  3,  6]  1 */
    61126045, /* 72281 (1635) [ 0,  0,  1, -1,  0,  0,  0,  1,  0] [ 9,  6,  9] -1 */
    34140982, /* 72282 (1635) [ 0,  0,  1,  0,  1,  0,  1,  0,  0] [ 0,  0,  6] -1 */
    19198823, /* 72283 (1635) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 6,  9,  3]  1 */
    44007827, /* 72284 (1635) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 3,  6,  3] -1 */
    44653314, /* 72285 (1635) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 3,  9,  0] -1 */
    35440216, /* 72286 (1635) [ 0,  0,  1,  1,  0,  0,  0,  1,  0] [ 0,  6,  0] -1 */
    27638132, /* 72287 (1635) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 9,  9,  0]  1 */
    44651854, /* 72288 (1635) [ 0,  0,  1,  1,  0,  0,  0, -1,  0] [ 3,  9,  0] -1 */
      777961, /* 72289 (1635) [ 0,  0,  1, -1,  0,  0,  0, -1,  0] [ 0,  3,  3]  1 */
     9220684, /* 72290 (1635) [ 0,  0, -1,  0, -1,  0,  1,  0,  0] [ 3,  3,  0]  1 */
    25689675, /* 72291 (1635) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 9,  0,  9]  1 */
    10758964, /* 72292 (1635) [ 0,  1,  0,  0,  0,  1, -1,  0,  0] [ 3,  9,  6]  1 */
    51795175, /* 72293 (1635) [ 0,  0, -1,  0,  1,  0,  1,  0,  0] [ 6,  3,  3] -1 */
    17134870, /* 72294 (1635) [ 0,  0,  1,  0,  1,  0,  1,  0,  0] [ 6,  0,  6]  1 */
    44651686, /* 72295 (1635) [ 0,  0,  1,  0,  1,  0, -1,  0,  0] [ 3,  9,  0] -1 */
    36204935, /* 72296 (1635) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 0,  9,  3] -1 */
    51796453, /* 72297 (1635) [ 0,  0,  1,  0, -1,  0, -1,  0,  0] [ 6,  3,  3] -1 */
    17133232, /* 72298 (1635) [ 0,  0, -1,  0, -1,  0, -1,  0,  0] [ 6,  0,  6]  1 */
    52564270, /* 72299 (1635) [ 0,  0,  1,  0,  1,  0,  1,  0,  0] [ 6,  6,  6] -1 */
    44657526, /* 72300 (1635) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 3,  9,  0] -1 */
    42695787, /* 72301 (1635) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 3,  0,  9] -1 */
    59588113, /* 72302 (1635) [ 0, -1,  0,  0,  0,  1, -1,  0,  0] [ 9,  0,  3] -1 */
    34139344, /* 72303 (1635) [ 0,  0, -1,  0, -1,  0, -1,  0,  0] [ 0,  0,  6] -1 */
    19194287, /* 72304 (1635) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  9,  3]  1 */
    59583745, /* 72305 (1635) [-1,  0,  0,  0,  0,  1,  0, -1,  0] [ 9,  0,  3] -1 */
     1551758, /* 72306 (1635) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
     2314903, /* 72307 (1635) [ 0,  1,  0,  0,  0, -1, -1,  0,  0] [ 0,  9,  9]  1 */
    60242250, /* 72308 (1635) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 9,  3,  0] -1 */
     8573891, /* 72309 (1635) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 3,  0,  3]  1 */
    60240790, /* 72310 (1635) [ 0,  0,  1,  1,  0,  0,  0, -1,  0] [ 9,  3,  0] -1 */
    26997179, /* 72311 (1635) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 9,  6,  3]  1 */
    17136482, /* 72312 (1635) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 6,  0,  6]  1 */
    61132093, /* 72313 (1635) [ 1,  0,  0,  0,  0, -1,  0,  1,  0] [ 9,  6,  9] -1 */
    61126213, /* 72314 (1635) [ 0,  0,  1,  0, -1,  0,  1,  0,  0] [ 9,  6,  9] -1 */
     1547546, /* 72315 (1635) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 0,  6,  6]  1 */
    25696813, /* 72316 (1635) [ 0,  0,  1,  0, -1,  0,  1,  0,  0] [ 9,  0,  9]  1 */
    59589793, /* 72317 (1635) [ 0,  0, -1,  1,  0,  0,  0, -1,  0] [ 9,  0,  3] -1 */
    60240622, /* 72318 (1635) [ 0,  0,  1,  0,  1,  0, -1,  0,  0] [ 9,  3,  0] -1 */
    36200399, /* 72319 (1635) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  9,  3] -1 */
    61777300, /* 72320 (1635) [ 0,  1,  0,  0,  0,  1, -1,  0,  0] [ 9,  9,  6] -1 */
    10106563, /* 72321 (1635) [ 0,  0, -1,  0,  1,  0, -1,  0,  0] [ 3,  6,  9]  1 */
    17901049, /* 72322 (1635) [ 0,  0, -1,  0,  1,  0,  1,  0,  0] [ 6,  3,  9]  1 */
    19201405, /* 72323 (1635) [ 0,  0,  1,  0, -1,  0, -1,  0,  0] [ 6,  9,  3]  1 */
    10763400, /* 72324 (1635) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 3,  9,  6]  1 */
    52562476, /* 72325 (1635) [ 0,  0, -1, -1,  0,  0,  0, -1,  0] [ 6,  6,  6] -1 */
    10750174, /* 72326 (1635) [-1,  0,  0,  0,  0, -1,  0,  1,  0] [ 3,  9,  6]  1 */
    19200283, /* 72327 (1635) [ 0,  0, -1,  1,  0,  0,  0,  1,  0] [ 6,  9,  3]  1 */
     2310809, /* 72328 (1635) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 0,  9,  9]  1 */
    27643804, /* 72329 (1635) [ 0,  0, -1, -1,  0,  0,  0,  1,  0] [ 9,  9,  0]  1 */
    42704437, /* 72330 (1635) [ 0,  1,  0,  0,  0, -1,  1,  0,  0] [ 3,  0,  9] -1 */
    27651358, /* 72331 (1635) [ 1,  0,  0,  0,  0,  1,  0, -1,  0] [ 9,  9,  0]  1 */
      770947, /* 72332 (1635) [-1,  0,  0,  0,  0,  1,  0,  1,  0] [ 0,  3,  3]  1 */
     9219280, /* 72333 (1635) [ 0, -1,  0,  0,  0, -1,  1,  0,  0] [ 3,  3,  0]  1 */
    42702925, /* 72334 (1635) [ 0,  0,  1,  0, -1,  0,  1,  0,  0] [ 3,  0,  9] -1 */
    18426486, /* 72335 (1635) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
    35440060, /* 72336 (1635) [ 0,  0,  1,  0,  1,  0,  1,  0,  0] [ 0,  6,  0] -1 */
      783957, /* 72337 (1635) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  3,  3]  1 */
    26993065, /* 72338 (1635) [ 0, -1,  0,  0,  0,  1, -1,  0,  0] [ 9,  6,  3]  1 */
    19207245, /* 72339 (1635) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  9,  3]  1 */
    25698325, /* 72340 (1635) [ 0,  1,  0,  0,  0, -1,  1,  0,  0] [ 9,  0,  9]  1 */
    52570094, /* 72341 (1635) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    42708805, /* 72342 (1635) [ 1,  0,  0,  0,  0, -1,  0,  1,  0] [ 3,  0,  9] -1 */
     9220516, /* 72343 (1635) [ 0,  0, -1, -1,  0,  0,  0,  1,  0] [ 3,  3,  0]  1 */
    10757560, /* 72344 (1635) [ 0,  0,  1,  0,  1,  0, -1,  0,  0] [ 3,  9,  6]  1 */
    53333031, /* 72345 (1635) [ 0,  1,  0, -1,  0,  0,  0,  0, -1] [ 6,  9,  9] -1 */
     1542892, /* 72346 (1635) [ 0, -1,  0,  0,  0, -1, -1,  0,  0] [ 0,  6,  6]  1 */
    34142386, /* 72347 (1635) [ 0,  1,  0,  0,  0,  1,  1,  0,  0] [ 0,  0,  6] -1 */
    52565674, /* 72348 (1635) [ 0,  1,  0,  0,  0,  1,  1,  0,  0] [ 6,  6,  6] -1 */
    36207517, /* 72349 (1635) [ 0,  0,  1,  0, -1,  0, -1,  0,  0] [ 0,  9,  3] -1 */
    25702693, /* 72350 (1635) [ 1,  0,  0,  0,  0, -1,  0,  1,  0] [ 9,  0,  9]  1 */
    59589625, /* 72351 (1635) [ 0,  0, -1,  0,  1,  0, -1,  0,  0] [ 9,  0,  3] -1 */
    34142594, /* 72352 (1635) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    36206395, /* 72353 (1635) [ 0,  0, -1,  1,  0,  0,  0,  1,  0] [ 0,  9,  3] -1 */
    51029152, /* 72354 (1635) [ 0,  0,  1,  1,  0,  0,  0,  1,  0] [ 6,  0,  0] -1 */
    59588337, /* 72355 (1635) [ 0, -1,  0,  1,  0,  0,  0,  0, -1] [ 9,  0,  3] -1 */
    19200127, /* 72356 (1635) [ 0,  0, -1,  0,  1,  0,  1,  0,  0] [ 6,  9,  3]  1 */
    36213357, /* 72357 (1635) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  9,  3] -1 */
    61772666, /* 72358 (1635) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 9,  9,  6] -1 */
    10105275, /* 72359 (1635) [ 0, -1,  0,  1,  0,  0,  0,  0, -1] [ 3,  6,  9]  1 */
    42695731, /* 72360 (1635) [-1,  0,  0,  0,  0,  1,  0, -1,  0] [ 3,  0,  9] -1 */
    53328937, /* 72361 (1635) [ 0, -1,  0,  0,  0,  1,  1,  0,  0] [ 6,  9,  9] -1 */
       16432, /* 72362 (1635) [ 1,  0,  0,  0,  0,  1,  0,  1,  0] [ 0,  0,  0]  1 */
    61768510, /* 72363 (1635) [-1,  0,  0,  0,  0, -1,  0,  1,  0] [ 9,  9,  6] -1 */
    25689619, /* 72364 (1635) [-1,  0,  0,  0,  0,  1,  0, -1,  0] [ 9,  0,  9]  1 */
     8569777, /* 72365 (1635) [ 0, -1,  0,  0,  0,  1, -1,  0,  0] [ 3,  0,  3]  1 */
    10100739, /* 72366 (1635) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 3,  6,  9]  1 */
    35438266, /* 72367 (1635) [ 0,  0, -1, -1,  0,  0,  0, -1,  0] [ 0,  6,  0] -1 */
    26352336, /* 72368 (1635) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 9,  3,  6]  1 */
    27645742, /* 72369 (1635) [ 0,  0,  1,  1,  0,  0,  0, -1,  0] [ 9,  9,  0]  1 */
    26339110, /* 72370 (1635) [-1,  0,  0,  0,  0, -1,  0,  1,  0] [ 9,  3,  6]  1 */
    26348124, /* 72371 (1635) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 9,  3,  6]  1 */
    52565882, /* 72372 (1635) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    26346664, /* 72373 (1635) [ 0,  0,  1,  1,  0,  0,  0, -1,  0] [ 9,  3,  6]  1 */
    17131828, /* 72374 (1635) [ 0, -1,  0,  0,  0, -1, -1,  0,  0] [ 6,  0,  6]  1 */
    36206239, /* 72375 (1635) [ 0,  0, -1,  0,  1,  0,  1,  0,  0] [ 0,  9,  3] -1 */
    51028996, /* 72376 (1635) [ 0,  0,  1,  0,  1,  0,  1,  0,  0] [ 6,  0,  0] -1 */
    35445884, /* 72377 (1635) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  0] -1 */
        3250, /* 72378 (1635) [-1,  0,  0,  0,  0, -1,  0, -1,  0] [ 0,  0,  0]  1 */
    17903631, /* 72379 (1635) [ 0,  1,  0, -1,  0,  0,  0,  0, -1] [ 6,  3,  9]  1 */
    34137940, /* 72380 (1635) [ 0, -1,  0,  0,  0, -1, -1,  0,  0] [ 0,  0,  6] -1 */
      778117, /* 72381 (1635) [ 0,  0,  1,  0, -1,  0, -1,  0,  0] [ 0,  3,  3]  1 */
    26346496, /* 72382 (1635) [ 0,  0,  1,  0,  1,  0, -1,  0,  0] [ 9,  3,  6]  1 */
    26994745, /* 72383 (1635) [ 0,  0, -1,  1,  0,  0,  0, -1,  0] [ 9,  6,  3]  1 */
      779629, /* 72384 (1635) [ 0,  1,  0,  0,  0, -1, -1,  0,  0] [ 0,  3,  3]  1 */
    35441464, /* 72385 (1635) [ 0,  1,  0,  0,  0,  1,  1,  0,  0] [ 0,  6,  0] -1 */
    19202917, /* 72386 (1635) [ 0,  1,  0,  0,  0, -1, -1,  0,  0] [ 6,  9,  3]  1 */
    43999177, /* 72387 (1635) [ 0, -1,  0,  0,  0,  1, -1,  0,  0] [ 3,  6,  3] -1 */
    25696645, /* 72388 (1635) [ 0,  0,  1, -1,  0,  0,  0,  1,  0] [ 9,  0,  9]  1 */
    10109389, /* 72389 (1635) [ 0,  1,  0,  0,  0, -1,  1,  0,  0] [ 3,  6,  9]  1 */
     8578427, /* 72390 (1635) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 3,  0,  3]  1 */
    27647202, /* 72391 (1635) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 9,  9,  0]  1 */
    10113757, /* 72392 (1635) [ 1,  0,  0,  0,  0, -1,  0,  1,  0] [ 3,  6,  9]  1 */
    44000857, /* 72393 (1635) [ 0,  0, -1,  1,  0,  0,  0, -1,  0] [ 3,  6,  3] -1 */
    44653090, /* 72394 (1635) [ 0,  1,  0,  0,  0,  1, -1,  0,  0] [ 3,  9,  0] -1 */
    42701611, /* 72395 (1635) [ 0,  0, -1,  0,  1,  0, -1,  0,  0] [ 3,  0,  9] -1 */
    26994577, /* 72396 (1635) [ 0,  0, -1,  0,  1,  0, -1,  0,  0] [ 9,  6,  3]  1 */
     1544140, /* 72397 (1635) [ 0,  0, -1, -1,  0,  0,  0, -1,  0] [ 0,  6,  6]  1 */
     9228126, /* 72398 (1635) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 3,  3,  0]  1 */
    51027202, /* 72399 (1635) [ 0,  0, -1, -1,  0,  0,  0, -1,  0] [ 6,  0,  0] -1 */
    44648456, /* 72400 (1635) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 3,  9,  0] -1 */
     9214900, /* 72401 (1635) [-1,  0,  0,  0,  0, -1,  0,  1,  0] [ 3,  3,  0]  1 */
       10816, /* 72402 (1635) [ 0,  0,  1,  1,  0,  0,  0,  1,  0] [ 0,  0,  0]  1 */
    18434104, /* 72403 (1635) [ 0,  0,  1,  1,  0,  0,  0,  1,  0] [ 6,  6,  0]  1 */
    42702757, /* 72404 (1635) [ 0,  0,  1, -1,  0,  0,  0,  1,  0] [ 3,  0,  9] -1 */
      775535, /* 72405 (1635) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 0,  3,  3]  1 */
     9223914, /* 72406 (1635) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 3,  3,  0]  1 */
    25695499, /* 72407 (1635) [ 0,  0, -1,  0,  1,  0, -1,  0,  0] [ 9,  0,  9]  1 */
    53331571, /* 72408 (1635) [ 0,  0,  1, -1,  0,  0,  0, -1,  0] [ 6,  9,  9] -1 */
    61132037, /* 72409 (1635) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 9,  6,  9] -1 */
    35441672, /* 72410 (1635) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 0,  6,  0] -1 */
      784009, /* 72411 (1635) [ 1,  0,  0,  0,  0, -1,  0, -1,  0] [ 0,  3,  3]  1 */
     9222454, /* 72412 (1635) [ 0,  0,  1,  1,  0,  0,  0, -1,  0] [ 3,  3,  0]  1 */
    59592451, /* 72413 (1635) [ 0,  1,  0,  0,  0, -1,  1,  0,  0] [ 9,  0,  3] -1 */
     2312113, /* 72414 (1635) [ 0,  0, -1,  0,  1,  0,  1,  0,  0] [ 0,  9,  9]  1 */
    52561020, /* 72415 (1635) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    17902171, /* 72416 (1635) [ 0,  0,  1, -1,  0,  0,  0, -1,  0] [ 6,  3,  9]  1 */
    44644300, /* 72417 (1635) [-1,  0,  0,  0,  0, -1,  0,  1,  0] [ 3,  9,  0] -1 */
    59590939, /* 72418 (1635) [ 0,  0,  1,  0, -1,  0,  1,  0,  0] [ 9,  0,  3] -1 */
    59596819, /* 72419 (1635) [ 1,  0,  0,  0,  0, -1,  0,  1,  0] [ 9,  0,  3] -1 */
     9222286, /* 72420 (1635) [ 0,  0,  1,  0,  1,  0, -1,  0,  0] [ 3,  3,  0]  1 */
    51030400, /* 72421 (1635) [ 0,  1,  0,  0,  0,  1,  1,  0,  0] [ 6,  0,  0] -1 */
    44000689, /* 72422 (1635) [ 0,  0, -1,  0,  1,  0, -1,  0,  0] [ 3,  6,  3] -1 */
     1551706, /* 72423 (1635) [ 1,  0,  0,  0,  0,  1,  0,  1,  0] [ 0,  6,  6]  1 */
    53324557, /* 72424 (1635) [-1,  0,  0,  0,  0,  1,  0,  1,  0] [ 6,  9,  9] -1 */
    61768454, /* 72425 (1635) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 9,  9,  6] -1 */
    60242026, /* 72426 (1635) [ 0,  1,  0,  0,  0,  1, -1,  0,  0] [ 9,  3,  0] -1 */
    34908283, /* 72427 (1635) [ 0,  0,  1, -1,  0,  0,  0, -1,  0] [ 0,  3,  9] -1 */
    43351006, /* 72428 (1635) [ 0,  0, -1,  0, -1,  0,  1,  0,  0] [ 3,  3,  6] -1 */
     2314695, /* 72429 (1635) [ 0,  1,  0, -1,  0,  0,  0,  0, -1] [ 0,  9,  9]  1 */
    43999401, /* 72430 (1635) [ 0, -1,  0,  1,  0,  0,  0,  0, -1] [ 3,  6,  3] -1 */
    17133076, /* 72431 (1635) [ 0,  0, -1, -1,  0,  0,  0, -1,  0] [ 6,  0,  6]  1 */
    10754330, /* 72432 (1635) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 3,  9,  6]  1 */
    60237392, /* 72433 (1635) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 9,  3,  0] -1 */
    61127501, /* 72434 (1635) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 9,  6,  9] -1 */
      770999, /* 72435 (1635) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  3,  3]  1 */
     8570001, /* 72436 (1635) [ 0, -1,  0,  1,  0,  0,  0,  0, -1] [ 3,  0,  3]  1 */
    26993289, /* 72437 (1635) [ 0, -1,  0,  1,  0,  0,  0,  0, -1] [ 9,  6,  3]  1 */
    18433948, /* 72438 (1635) [ 0,  0,  1,  0,  1,  0,  1,  0,  0] [ 6,  6,  0]  1 */
    34139188, /* 72439 (1635) [ 0,  0, -1, -1,  0,  0,  0, -1,  0] [ 0,  0,  6] -1 */
    10106731, /* 72440 (1635) [ 0,  0, -1,  1,  0,  0,  0, -1,  0] [ 3,  6,  9]  1 */
    35437018, /* 72441 (1635) [ 0, -1,  0,  0,  0, -1, -1,  0,  0] [ 0,  6,  0] -1 */
    60233236, /* 72442 (1635) [-1,  0,  0,  0,  0, -1,  0,  1,  0] [ 9,  3,  0] -1 */
    26988753, /* 72443 (1635) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 9,  6,  3]  1 */
     1547338, /* 72444 (1635) [ 0,  1,  0,  0,  0,  1,  1,  0,  0] [ 0,  6,  6]  1 */
    51030608, /* 72445 (1635) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 6,  0,  0] -1 */
    10100683, /* 72446 (1635) [-1,  0,  0,  0,  0,  1,  0, -1,  0] [ 3,  6,  9]  1 */
    35436810, /* 72447 (1635) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 0,  6,  0] -1 */
    51797757, /* 72448 (1635) [ 0,  1,  0, -1,  0,  0,  0,  0, -1] [ 6,  3,  3] -1 */
    61781680, /* 72449 (1635) [ 1,  0,  0,  0,  0,  1,  0, -1,  0] [ 9,  9,  6] -1 */
    34901269, /* 72450 (1635) [-1,  0,  0,  0,  0,  1,  0,  1,  0] [ 0,  3,  9] -1 */
    43349602, /* 72451 (1635) [ 0, -1,  0,  0,  0, -1,  1,  0,  0] [ 3,  3,  6] -1 */
    43994865, /* 72452 (1635) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 3,  6,  3] -1 */
    61123387, /* 72453 (1635) [ 0, -1,  0,  0,  0,  1, -1,  0,  0] [ 9,  6,  9] -1 */
    17895157, /* 72454 (1635) [-1,  0,  0,  0,  0,  1,  0,  1,  0] [ 6,  3,  9]  1 */
    60246462, /* 72455 (1635) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 9,  3,  0] -1 */
      776995, /* 72456 (1635) [ 0,  0, -1,  1,  0,  0,  0,  1,  0] [ 0,  3,  3]  1 */
    44003515, /* 72457 (1635) [ 0,  1,  0,  0,  0, -1,  1,  0,  0] [ 3,  6,  3] -1 */
    27646978, /* 72458 (1635) [ 0,  1,  0,  0,  0,  1, -1,  0,  0] [ 9,  9,  0]  1 */
       16484, /* 72459 (1636) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
        3360, /* 72460 (1636) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    17140694, /* 72461 (1636) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
    18433612, /* 72462 (1636) [ 0,  0,  1, -1,  0,  0,  0, -1,  0] [ 6,  6,  0]  1 */
     1425072, /* 72463 (1636) [ 0, -1,  0,  1,  0,  0,  0,  0, -1] [ 0,  6,  0]  1 */
    26288815, /* 72464 (1636) [ 0,  1,  0,  0,  0, -1,  1,  0,  0] [ 9,  3,  3]  1 */
    26288851, /* 72465 (1636) [ 0,  1,  0,  0,  0,  1, -1,  0,  0] [ 9,  3,  3]  1 */
    17127410, /* 72466 (1636) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
    27815277, /* 72467 (1636) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 9,  9,  9]  1 */
     9282479, /* 72468 (1636) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 3,  3,  3]  1 */
    10698199, /* 72469 (1636) [ 0,  0,  1, -1,  0,  0,  0,  1,  0] [ 3,  9,  3]  1 */
     1542946, /* 72470 (1636) [ 0, -1,  0,  0,  0,  1, -1,  0,  0] [ 0,  6,  6]  1 */
     1551594, /* 72471 (1636) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
     9399121, /* 72472 (1636) [ 0,  0,  1, -1,  0,  0,  0,  1,  0] [ 3,  3,  9]  1 */
    26293127, /* 72473 (1636) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 9,  3,  3]  1 */
        7672, /* 72474 (1636) [ 0, -1,  0,  0,  0,  1, -1,  0,  0] [ 0,  0,  0]  1 */
     1538634, /* 72475 (1636) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
    17009416, /* 72476 (1636) [-1,  0,  0,  0,  0,  1,  0, -1,  0] [ 6,  0,  0]  1 */
    26293287, /* 72477 (1636) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 9,  3,  3]  1 */
    27701391, /* 72478 (1636) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 9,  9,  3]  1 */
    17136274, /* 72479 (1636) [ 0,  1,  0,  0,  0,  1,  1,  0,  0] [ 6,  0,  6]  1 */
     9278103, /* 72480 (1636) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 3,  3,  3]  1 */
    27822889, /* 72481 (1636) [ 0,  0,  1,  1,  0,  0,  0, -1,  0] [ 9,  9,  9]  1 */
    17009368, /* 72482 (1636) [-1,  0,  0,  0,  0, -1,  0,  1,  0] [ 6,  0,  0]  1 */
     1427836, /* 72483 (1636) [ 0,  0,  1,  0,  1,  0,  1,  0,  0] [ 0,  6,  0]  1 */
    26407173, /* 72484 (1636) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 9,  3,  9]  1 */
    26287615, /* 72485 (1636) [ 0,  0,  1,  1,  0,  0,  0, -1,  0] [ 9,  3,  3]  1 */
    27706251, /* 72486 (1636) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 9,  9,  3]  1 */
    26284495, /* 72487 (1636) [ 0, -1,  0,  0,  0,  1,  1,  0,  0] [ 9,  3,  3]  1 */
    10695487, /* 72488 (1636) [ 0, -1,  0,  0,  0, -1, -1,  0,  0] [ 3,  9,  3]  1 */
    26403925, /* 72489 (1636) [ 0,  0, -1,  0, -1,  0, -1,  0,  0] [ 9,  3,  9]  1 */
    18430924, /* 72490 (1636) [ 0, -1,  0,  0,  0, -1,  1,  0,  0] [ 6,  6,  0]  1 */
    27710359, /* 72491 (1636) [ 1,  0,  0,  0,  0, -1,  0,  1,  0] [ 9,  9,  3]  1 */
    17018384, /* 72492 (1636) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 6,  0,  0]  1 */
     9278591, /* 72493 (1636) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 3,  3,  3]  1 */
    10809217, /* 72494 (1636) [-1,  0,  0,  0,  0, -1,  0, -1,  0] [ 3,  9,  9]  1 */
    18553170, /* 72495 (1636) [ 0,  1,  0, -1,  0,  0,  0,  0, -1] [ 6,  6,  6]  1 */
    17131846, /* 72496 (1636) [ 0, -1,  0,  0,  0, -1,  1,  0,  0] [ 6,  0,  6]  1 */
    18550570, /* 72497 (1636) [ 0,  0, -1,  0,  1,  0, -1,  0,  0] [ 6,  6,  6]  1 */
    26404105, /* 72498 (1636) [ 0,  0, -1,  0,  1,  0,  1,  0,  0] [ 9,  3,  9]  1 */
    10698679, /* 72499 (1636) [ 0,  0,  1,  1,  0,  0,  0, -1,  0] [ 3,  9,  3]  1 */
     9398149, /* 72500 (1636) [ 0,  0, -1,  1,  0,  0,  0,  1,  0] [ 3,  3,  9]  1 */
     1427656, /* 72501 (1636) [ 0,  0,  1,  0, -1,  0, -1,  0,  0] [ 0,  6,  0]  1 */
      121354, /* 72502 (1636) [-1,  0,  0,  0,  0, -1,  0,  1,  0] [ 0,  0,  6]  1 */
    17133082, /* 72503 (1636) [ 0,  0, -1, -1,  0,  0,  0,  1,  0] [ 6,  0,  6]  1 */
    26405545, /* 72504 (1636) [ 0,  0,  1,  0,  1,  0, -1,  0,  0] [ 9,  3,  9]  1 */
     9282963, /* 72505 (1636) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 3,  3,  3]  1 */
    18432640, /* 72506 (1636) [ 0,  0, -1,  1,  0,  0,  0, -1,  0] [ 6,  6,  0]  1 */
       11992, /* 72507 (1636) [ 0,  1,  0,  0,  0, -1, -1,  0,  0] [ 0,  0,  0]  1 */
    18435280, /* 72508 (1636) [ 0,  1,  0,  0,  0, -1, -1,  0,  0] [ 6,  6,  0]  1 */
    17014008, /* 72509 (1636) [ 0, -1,  0,  1,  0,  0,  0,  0, -1] [ 6,  0,  0]  1 */
      134470, /* 72510 (1636) [ 1,  0,  0,  0,  0, -1,  0, -1,  0] [ 0,  0,  6]  1 */
    26411329, /* 72511 (1636) [ 1,  0,  0,  0,  0,  1,  0, -1,  0] [ 9,  3,  9]  1 */
     9274003, /* 72512 (1636) [-1,  0,  0,  0,  0,  1,  0,  1,  0] [ 3,  3,  3]  1 */
    27705767, /* 72513 (1636) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 9,  9,  3]  1 */
      127138, /* 72514 (1636) [ 0,  0, -1,  0, -1,  0,  1,  0,  0] [ 0,  0,  6]  1 */
    18426488, /* 72515 (1636) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    26398153, /* 72516 (1636) [-1,  0,  0,  0,  0, -1,  0, -1,  0] [ 9,  3,  9]  1 */
       10324, /* 72517 (1636) [ 0,  0,  1, -1,  0,  0,  0, -1,  0] [ 0,  0,  0]  1 */
    17140530, /* 72518 (1636) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  6]  1 */
    27822409, /* 72519 (1636) [ 0,  0,  1, -1,  0,  0,  0,  1,  0] [ 9,  9,  9]  1 */
    17127570, /* 72520 (1636) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6]  1 */
     1545598, /* 72521 (1636) [ 0,  0,  1, -1,  0,  0,  0, -1,  0] [ 0,  6,  6]  1 */
     9400801, /* 72522 (1636) [ 0,  1,  0,  0,  0, -1,  1,  0,  0] [ 3,  3,  9]  1 */
    17013524, /* 72523 (1636) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 6,  0,  0]  1 */
    10699879, /* 72524 (1636) [ 0,  1,  0,  0,  0, -1,  1,  0,  0] [ 3,  9,  3]  1 */
    18548798, /* 72525 (1636) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    10817753, /* 72526 (1636) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 3,  9,  9]  1 */
    27820945, /* 72527 (1636) [ 0,  0, -1, -1,  0,  0,  0, -1,  0] [ 9,  9,  9]  1 */
     9397657, /* 72528 (1636) [ 0,  0, -1, -1,  0,  0,  0, -1,  0] [ 3,  3,  9]  1 */
    26406689, /* 72529 (1636) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 9,  3,  9]  1 */
    10704191, /* 72530 (1636) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 3,  9,  3]  1 */
     9405113, /* 72531 (1636) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 3,  3,  9]  1 */
    10699915, /* 72532 (1636) [ 0,  1,  0,  0,  0,  1, -1,  0,  0] [ 3,  9,  3]  1 */
      121402, /* 72533 (1636) [-1,  0,  0,  0,  0,  1,  0, -1,  0] [ 0,  0,  6]  1 */
     9281335, /* 72534 (1636) [ 0,  0,  1,  0,  1,  0, -1,  0,  0] [ 3,  3,  3]  1 */
    18544690, /* 72535 (1636) [-1,  0,  0,  0,  0,  1,  0, -1,  0] [ 6,  6,  6]  1 */
    18439772, /* 72536 (1636) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    10816465, /* 72537 (1636) [ 0,  0,  1,  0, -1,  0,  1,  0,  0] [ 3,  9,  9]  1 */
     9287119, /* 72538 (1636) [ 1,  0,  0,  0,  0,  1,  0, -1,  0] [ 3,  3,  3]  1 */
    18544642, /* 72539 (1636) [-1,  0,  0,  0,  0, -1,  0,  1,  0] [ 6,  6,  6]  1 */
    10691067, /* 72540 (1636) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 3,  9,  3]  1 */
     1538474, /* 72541 (1636) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
        3200, /* 72542 (1636) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
     9396481, /* 72543 (1636) [ 0, -1,  0,  0,  0,  1,  1,  0,  0] [ 3,  3,  9]  1 */
      125510, /* 72544 (1636) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  6]  1 */
    10822345, /* 72545 (1636) [ 1,  0,  0,  0,  0, -1,  0,  1,  0] [ 3,  9,  9]  1 */
    18435352, /* 72546 (1636) [ 0,  1,  0,  0,  0,  1,  1,  0,  0] [ 6,  6,  0]  1 */
    26285671, /* 72547 (1636) [ 0,  0, -1, -1,  0,  0,  0, -1,  0] [ 9,  3,  3]  1 */
     9405273, /* 72548 (1636) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 3,  3,  9]  1 */
    18553658, /* 72549 (1636) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    26402801, /* 72550 (1636) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 9,  3,  9]  1 */
    26402313, /* 72551 (1636) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 9,  3,  9]  1 */
       10816, /* 72552 (1636) [ 0,  0,  1,  1,  0,  0,  0,  1,  0] [ 0,  0,  0]  1 */
    18434104, /* 72553 (1636) [ 0,  0,  1,  1,  0,  0,  0,  1,  0] [ 6,  6,  0]  1 */
    17017896, /* 72554 (1636) [ 0,  1,  0, -1,  0,  0,  0,  0, -1] [ 6,  0,  0]  1 */
    17016772, /* 72555 (1636) [ 0,  0,  1,  0,  1,  0,  1,  0,  0] [ 6,  0,  0]  1 */
    17015296, /* 72556 (1636) [ 0,  0, -1,  0,  1,  0, -1,  0,  0] [ 6,  0,  0]  1 */
       12064, /* 72557 (1636) [ 0,  1,  0,  0,  0,  1,  1,  0,  0] [ 0,  0,  0]  1 */
    10691231, /* 72558 (1636) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 3,  9,  3]  1 */
     1433548, /* 72559 (1636) [ 1,  0,  0,  0,  0, -1,  0, -1,  0] [ 0,  6,  0]  1 */
     9399601, /* 72560 (1636) [ 0,  0,  1,  1,  0,  0,  0, -1,  0] [ 3,  3,  9]  1 */
      130370, /* 72561 (1636) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 0,  0,  6]  1 */
     1551758, /* 72562 (1636) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
        9352, /* 72563 (1636) [ 0,  0, -1,  1,  0,  0,  0, -1,  0] [ 0,  0,  0]  1 */
    18557818, /* 72564 (1636) [ 1,  0,  0,  0,  0,  1,  0,  1,  0] [ 6,  6,  6]  1 */
     1542910, /* 72565 (1636) [ 0, -1,  0,  0,  0, -1,  1,  0,  0] [ 0,  6,  6]  1 */
    27704623, /* 72566 (1636) [ 0,  0,  1,  0,  1,  0, -1,  0,  0] [ 9,  9,  3]  1 */
    17134534, /* 72567 (1636) [ 0,  0,  1, -1,  0,  0,  0, -1,  0] [ 6,  0,  6]  1 */
     1547266, /* 72568 (1636) [ 0,  1,  0,  0,  0, -1, -1,  0,  0] [ 0,  6,  6]  1 */
      125994, /* 72569 (1636) [ 0, -1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  6]  1 */
    18549282, /* 72570 (1636) [ 0, -1,  0,  1,  0,  0,  0,  0, -1] [ 6,  6,  6]  1 */
    10814989, /* 72571 (1636) [ 0,  0, -1,  0, -1,  0, -1,  0,  0] [ 3,  9,  9]  1 */
    27710407, /* 72572 (1636) [ 1,  0,  0,  0,  0,  1,  0, -1,  0] [ 9,  9,  3]  1 */
    26398213, /* 72573 (1636) [-1,  0,  0,  0,  0,  1,  0,  1,  0] [ 9,  3,  9]  1 */
    27828401, /* 72574 (1636) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 9,  9,  9]  1 */
    17131882, /* 72575 (1636) [ 0, -1,  0,  0,  0,  1, -1,  0,  0] [ 6,  0,  6]  1 */
     1546090, /* 72576 (1636) [ 0,  0,  1,  1,  0,  0,  0,  1,  0] [ 0,  6,  6]  1 */
    27828561, /* 72577 (1636) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 9,  9,  9]  1 */
     9400837, /* 72578 (1636) [ 0,  1,  0,  0,  0,  1, -1,  0,  0] [ 3,  3,  9]  1 */
     9287071, /* 72579 (1636) [ 1,  0,  0,  0,  0, -1,  0,  1,  0] [ 3,  3,  3]  1 */
     1426216, /* 72580 (1636) [ 0,  0, -1,  0, -1,  0,  1,  0,  0] [ 0,  6,  0]  1 */
    10695559, /* 72581 (1636) [ 0, -1,  0,  0,  0,  1,  1,  0,  0] [ 3,  9,  3]  1 */
     9279895, /* 72582 (1636) [ 0,  0, -1,  0,  1,  0,  1,  0,  0] [ 3,  3,  3]  1 */
    18551866, /* 72583 (1636) [ 0,  0,  1,  0, -1,  0, -1,  0,  0] [ 6,  6,  6]  1 */
    18557758, /* 72584 (1636) [ 1,  0,  0,  0,  0, -1,  0, -1,  0] [ 6,  6,  6]  1 */
    10696735, /* 72585 (1636) [ 0,  0, -1, -1,  0,  0,  0, -1,  0] [ 3,  9,  3]  1 */
    27697291, /* 72586 (1636) [-1,  0,  0,  0,  0,  1,  0,  1,  0] [ 9,  9,  3]  1 */
    17016592, /* 72587 (1636) [ 0,  0,  1,  0, -1,  0, -1,  0,  0] [ 6,  0,  0]  1 */
    17133562, /* 72588 (1636) [ 0,  0, -1,  1,  0,  0,  0, -1,  0] [ 6,  0,  6]  1 */
    10704351, /* 72589 (1636) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 3,  9,  3]  1 */
    27703183, /* 72590 (1636) [ 0,  0, -1,  0,  1,  0,  1,  0,  0] [ 9,  9,  3]  1 */
    17136202, /* 72591 (1636) [ 0,  1,  0,  0,  0, -1, -1,  0,  0] [ 6,  0,  6]  1 */
    10697227, /* 72592 (1636) [ 0,  0, -1,  1,  0,  0,  0,  1,  0] [ 3,  9,  3]  1 */
      129882, /* 72593 (1636) [ 0,  1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  6]  1 */
    10815169, /* 72594 (1636) [ 0,  0, -1,  0,  1,  0,  1,  0,  0] [ 3,  9,  9]  1 */
    26280167, /* 72595 (1636) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 9,  3,  3]  1 */
    18432160, /* 72596 (1636) [ 0,  0, -1, -1,  0,  0,  0,  1,  0] [ 6,  6,  0]  1 */
    27819697, /* 72597 (1636) [ 0, -1,  0,  0,  0, -1, -1,  0,  0] [ 9,  9,  9]  1 */
      127282, /* 72598 (1636) [ 0,  0, -1,  0,  1,  0, -1,  0,  0] [ 0,  0,  6]  1 */
    27815441, /* 72599 (1636) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 9,  9,  9]  1 */
     9396409, /* 72600 (1636) [ 0, -1,  0,  0,  0, -1, -1,  0,  0] [ 3,  3,  9]  1 */
    18552046, /* 72601 (1636) [ 0,  0,  1,  0,  1,  0,  1,  0,  0] [ 6,  6,  6]  1 */
    17022544, /* 72602 (1636) [ 1,  0,  0,  0,  0,  1,  0,  1,  0] [ 6,  0,  0]  1 */
     1544626, /* 72603 (1636) [ 0,  0, -1,  1,  0,  0,  0, -1,  0] [ 0,  6,  6]  1 */
     1424588, /* 72604 (1636) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 0,  6,  0]  1 */
        7636, /* 72605 (1636) [ 0, -1,  0,  0,  0, -1,  1,  0,  0] [ 0,  0,  0]  1 */
     9391989, /* 72606 (1636) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 3,  3,  9]  1 */
      128758, /* 72607 (1636) [ 0,  0,  1,  0,  1,  0,  1,  0,  0] [ 0,  0,  6]  1 */
       16320, /* 72608 (1636) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    18430960, /* 72609 (1636) [ 0, -1,  0,  0,  0,  1, -1,  0,  0] [ 6,  6,  0]  1 */
    18439608, /* 72610 (1636) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
    26287135, /* 72611 (1636) [ 0,  0,  1, -1,  0,  0,  0,  1,  0] [ 9,  3,  3]  1 */
     9279715, /* 72612 (1636) [ 0,  0, -1,  0, -1,  0, -1,  0,  0] [ 3,  3,  3]  1 */
     1429448, /* 72613 (1636) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 0,  6,  0]  1 */
    18426648, /* 72614 (1636) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
    27703003, /* 72615 (1636) [ 0,  0, -1,  0, -1,  0, -1,  0,  0] [ 9,  9,  3]  1 */
    27824089, /* 72616 (1636) [ 0,  1,  0,  0,  0, -1,  1,  0,  0] [ 9,  9,  9]  1 */
    10813377, /* 72617 (1636) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 3,  9,  9]  1 */
     1547338, /* 72618 (1636) [ 0,  1,  0,  0,  0,  1,  1,  0,  0] [ 0,  6,  6]  1 */
      134530, /* 72619 (1636) [ 1,  0,  0,  0,  0,  1,  0,  1,  0] [ 0,  0,  6]  1 */
     1420432, /* 72620 (1636) [-1,  0,  0,  0,  0, -1,  0,  1,  0] [ 0,  6,  0]  1 */
    27704479, /* 72621 (1636) [ 0,  0,  1,  0, -1,  0,  1,  0,  0] [ 9,  9,  3]  1 */
    17135026, /* 72622 (1636) [ 0,  0,  1,  1,  0,  0,  0,  1,  0] [ 6,  0,  6]  1 */
    10818237, /* 72623 (1636) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 3,  9,  9]  1 */
        8872, /* 72624 (1636) [ 0,  0, -1, -1,  0,  0,  0,  1,  0] [ 0,  0,  0]  1 */
     1433608, /* 72625 (1636) [ 1,  0,  0,  0,  0,  1,  0,  1,  0] [ 0,  6,  0]  1 */
     1420480, /* 72626 (1636) [-1,  0,  0,  0,  0,  1,  0, -1,  0] [ 0,  6,  0]  1 */
     1544146, /* 72627 (1636) [ 0,  0, -1, -1,  0,  0,  0,  1,  0] [ 0,  6,  6]  1 */
    26284423, /* 72628 (1636) [ 0, -1,  0,  0,  0, -1, -1,  0,  0] [ 9,  3,  3]  1 */
    17015152, /* 72629 (1636) [ 0,  0, -1,  0, -1,  0,  1,  0,  0] [ 6,  0,  0]  1 */
     9281191, /* 72630 (1636) [ 0,  0,  1,  0, -1,  0,  1,  0,  0] [ 3,  3,  3]  1 */
    26411281, /* 72631 (1636) [ 1,  0,  0,  0,  0, -1,  0,  1,  0] [ 9,  3,  9]  1 */
    26405401, /* 72632 (1636) [ 0,  0,  1,  0, -1,  0,  1,  0,  0] [ 9,  3,  9]  1 */
    27819769, /* 72633 (1636) [ 0, -1,  0,  0,  0,  1,  1,  0,  0] [ 9,  9,  9]  1 */
    26280003, /* 72634 (1636) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 9,  3,  3]  1 */
     9273943, /* 72635 (1636) [-1,  0,  0,  0,  0, -1,  0, -1,  0] [ 3,  3,  3]  1 */
     1426360, /* 72636 (1636) [ 0,  0, -1,  0,  1,  0, -1,  0,  0] [ 0,  6,  0]  1 */
    18550426, /* 72637 (1636) [ 0,  0, -1,  0, -1,  0,  1,  0,  0] [ 6,  6,  6]  1 */
    27697231, /* 72638 (1636) [-1,  0,  0,  0,  0, -1,  0, -1,  0] [ 9,  9,  3]  1 */
    10816609, /* 72639 (1636) [ 0,  0,  1,  0,  1,  0, -1,  0,  0] [ 3,  9,  9]  1 */
    27701879, /* 72640 (1636) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 9,  9,  3]  1 */
     1428960, /* 72641 (1636) [ 0,  1,  0, -1,  0,  0,  0,  0, -1] [ 0,  6,  0]  1 */
     9392153, /* 72642 (1636) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 3,  3,  9]  1 */
    10813865, /* 72643 (1636) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 3,  9,  9]  1 */
      128578, /* 72644 (1636) [ 0,  0,  1,  0, -1,  0, -1,  0,  0] [ 0,  0,  6]  1 */
    17022484, /* 72645 (1636) [ 1,  0,  0,  0,  0, -1,  0, -1,  0] [ 6,  0,  0]  1 */
    10822393, /* 72646 (1636) [ 1,  0,  0,  0,  0,  1,  0, -1,  0] [ 3,  9,  9]  1 */
    10809277, /* 72647 (1636) [-1,  0,  0,  0,  0,  1,  0,  1,  0] [ 3,  9,  9]  1 */
    26286163, /* 72648 (1636) [ 0,  0, -1,  1,  0,  0,  0,  1,  0] [ 9,  3,  3]  1 */
    27821437, /* 72649 (1636) [ 0,  0, -1,  1,  0,  0,  0,  1,  0] [ 9,  9,  9]  1 */
    27824125, /* 72650 (1636) [ 0,  1,  0,  0,  0,  1, -1,  0,  0] [ 9,  9,  9]  1 */
       16484, /* 72651 (1637) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
        3360, /* 72652 (1637) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    17140694, /* 72653 (1637) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
     1425072, /* 72654 (1637) [ 0, -1,  0,  1,  0,  0,  0,  0, -1] [ 0,  6,  0]  1 */
    26288815, /* 72655 (1637) [ 0,  1,  0,  0,  0, -1,  1,  0,  0] [ 9,  3,  3]  1 */
    26288851, /* 72656 (1637) [ 0,  1,  0,  0,  0,  1, -1,  0,  0] [ 9,  3,  3]  1 */
    52451996, /* 72657 (1637) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
    27815277, /* 72658 (1637) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 9,  9,  9]  1 */
    43299343, /* 72659 (1637) [ 1,  0,  0,  0,  0,  1,  0, -1,  0] [ 3,  3,  3] -1 */
    44707783, /* 72660 (1637) [ 0, -1,  0,  0,  0,  1,  1,  0,  0] [ 3,  9,  3] -1 */
     9399121, /* 72661 (1637) [ 0,  0,  1, -1,  0,  0,  0,  1,  0] [ 3,  3,  9]  1 */
    17009416, /* 72662 (1637) [-1,  0,  0,  0,  0,  1,  0, -1,  0] [ 6,  0,  0]  1 */
    17136274, /* 72663 (1637) [ 0,  1,  0,  0,  0,  1,  1,  0,  0] [ 6,  0,  6]  1 */
    17009368, /* 72664 (1637) [-1,  0,  0,  0,  0, -1,  0,  1,  0] [ 6,  0,  0]  1 */
    52447576, /* 72665 (1637) [ 0,  1,  0,  0,  0,  1,  1,  0,  0] [ 6,  6,  0] -1 */
    52564090, /* 72666 (1637) [ 0,  0,  1,  0, -1,  0, -1,  0,  0] [ 6,  6,  6] -1 */
    26407173, /* 72667 (1637) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 9,  3,  9]  1 */
    51148426, /* 72668 (1637) [ 0,  1,  0,  0,  0, -1, -1,  0,  0] [ 6,  0,  6] -1 */
    34021576, /* 72669 (1637) [ 0,  0, -1,  1,  0,  0,  0, -1,  0] [ 0,  0,  0] -1 */
    17018384, /* 72670 (1637) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 6,  0,  0]  1 */
    52570042, /* 72671 (1637) [ 1,  0,  0,  0,  0,  1,  0,  1,  0] [ 6,  6,  6] -1 */
    35555134, /* 72672 (1637) [ 0, -1,  0,  0,  0, -1,  1,  0,  0] [ 0,  6,  6] -1 */
    26405545, /* 72673 (1637) [ 0,  0,  1,  0,  1,  0, -1,  0,  0] [ 9,  3,  9]  1 */
    61840625, /* 72674 (1637) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 9,  9,  9] -1 */
    43299295, /* 72675 (1637) [ 1,  0,  0,  0,  0, -1,  0,  1,  0] [ 3,  3,  3] -1 */
     1545598, /* 72676 (1637) [ 0,  0,  1, -1,  0,  0,  0, -1,  0] [ 0,  6,  6]  1 */
    43293415, /* 72677 (1637) [ 0,  0,  1,  0, -1,  0,  1,  0,  0] [ 3,  3,  3] -1 */
    10699879, /* 72678 (1637) [ 0,  1,  0,  0,  0, -1,  1,  0,  0] [ 3,  9,  3]  1 */
    61709455, /* 72679 (1637) [-1,  0,  0,  0,  0, -1,  0, -1,  0] [ 9,  9,  3] -1 */
    18439772, /* 72680 (1637) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    10816465, /* 72681 (1637) [ 0,  0,  1,  0, -1,  0,  1,  0,  0] [ 3,  9,  9]  1 */
     9287119, /* 72682 (1637) [ 1,  0,  0,  0,  0,  1,  0, -1,  0] [ 3,  3,  3]  1 */
    35441184, /* 72683 (1637) [ 0,  1,  0, -1,  0,  0,  0,  0, -1] [ 0,  6,  0] -1 */
    52569982, /* 72684 (1637) [ 1,  0,  0,  0,  0, -1,  0, -1,  0] [ 6,  6,  6] -1 */
     1538474, /* 72685 (1637) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
    44834617, /* 72686 (1637) [ 1,  0,  0,  0,  0,  1,  0, -1,  0] [ 3,  9,  9] -1 */
     9396481, /* 72687 (1637) [ 0, -1,  0,  0,  0,  1,  1,  0,  0] [ 3,  3,  9]  1 */
    34142106, /* 72688 (1637) [ 0,  1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  6] -1 */
    61831921, /* 72689 (1637) [ 0, -1,  0,  0,  0, -1, -1,  0,  0] [ 9,  9,  9] -1 */
    43408633, /* 72690 (1637) [ 0, -1,  0,  0,  0, -1, -1,  0,  0] [ 3,  3,  9] -1 */
    10822345, /* 72691 (1637) [ 1,  0,  0,  0,  0, -1,  0,  1,  0] [ 3,  9,  9]  1 */
    18435352, /* 72692 (1637) [ 0,  1,  0,  0,  0,  1,  1,  0,  0] [ 6,  6,  0]  1 */
    44710423, /* 72693 (1637) [ 0,  0,  1, -1,  0,  0,  0,  1,  0] [ 3,  9,  3] -1 */
    60299359, /* 72694 (1637) [ 0,  0,  1, -1,  0,  0,  0,  1,  0] [ 9,  3,  3] -1 */
    35555170, /* 72695 (1637) [ 0, -1,  0,  0,  0,  1, -1,  0,  0] [ 0,  6,  6] -1 */
    17015296, /* 72696 (1637) [ 0,  0, -1,  0,  1,  0, -1,  0,  0] [ 6,  0,  0]  1 */
      130370, /* 72697 (1637) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 0,  0,  6]  1 */
        9352, /* 72698 (1637) [ 0,  0, -1,  1,  0,  0,  0, -1,  0] [ 0,  0,  0]  1 */
    18557818, /* 72699 (1637) [ 1,  0,  0,  0,  0,  1,  0,  1,  0] [ 6,  6,  6]  1 */
     1542910, /* 72700 (1637) [ 0, -1,  0,  0,  0, -1,  1,  0,  0] [ 0,  6,  6]  1 */
    35445832, /* 72701 (1637) [ 1,  0,  0,  0,  0,  1,  0,  1,  0] [ 0,  6,  0] -1 */
    35432704, /* 72702 (1637) [-1,  0,  0,  0,  0,  1,  0, -1,  0] [ 0,  6,  0] -1 */
    35556370, /* 72703 (1637) [ 0,  0, -1, -1,  0,  0,  0,  1,  0] [ 0,  6,  6] -1 */
    27828401, /* 72704 (1637) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 9,  9,  9]  1 */
    60292227, /* 72705 (1637) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 9,  3,  3] -1 */
    43286167, /* 72706 (1637) [-1,  0,  0,  0,  0, -1,  0, -1,  0] [ 3,  3,  3] -1 */
    27828561, /* 72707 (1637) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 9,  9,  9]  1 */
    51144070, /* 72708 (1637) [ 0, -1,  0,  0,  0, -1,  1,  0,  0] [ 6,  0,  6] -1 */
     9400837, /* 72709 (1637) [ 0,  1,  0,  0,  0,  1, -1,  0,  0] [ 3,  3,  9]  1 */
     9287071, /* 72710 (1637) [ 1,  0,  0,  0,  0, -1,  0,  1,  0] [ 3,  3,  3]  1 */
    52562650, /* 72711 (1637) [ 0,  0, -1,  0, -1,  0,  1,  0,  0] [ 6,  6,  6] -1 */
    43404377, /* 72712 (1637) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 3,  3,  9] -1 */
    43295187, /* 72713 (1637) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 3,  3,  3] -1 */
    44826089, /* 72714 (1637) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 3,  9,  9] -1 */
    43286227, /* 72715 (1637) [-1,  0,  0,  0,  0,  1,  0,  1,  0] [ 3,  3,  3] -1 */
    61717991, /* 72716 (1637) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 9,  9,  3] -1 */
    52438712, /* 72717 (1637) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
    34022548, /* 72718 (1637) [ 0,  0,  1, -1,  0,  0,  0, -1,  0] [ 0,  0,  0] -1 */
    52445836, /* 72719 (1637) [ 0,  0,  1, -1,  0,  0,  0, -1,  0] [ 6,  6,  0] -1 */
    51139794, /* 72720 (1637) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6] -1 */
    18557758, /* 72721 (1637) [ 1,  0,  0,  0,  0, -1,  0, -1,  0] [ 6,  6,  6]  1 */
    51139634, /* 72722 (1637) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
    27703183, /* 72723 (1637) [ 0,  0, -1,  0,  1,  0,  1,  0,  0] [ 9,  9,  3]  1 */
      129882, /* 72724 (1637) [ 0,  1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  6]  1 */
    27819697, /* 72725 (1637) [ 0, -1,  0,  0,  0, -1, -1,  0,  0] [ 9,  9,  9]  1 */
     9396409, /* 72726 (1637) [ 0, -1,  0,  0,  0, -1, -1,  0,  0] [ 3,  3,  9]  1 */
    61713615, /* 72727 (1637) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 9,  9,  3] -1 */
    26287135, /* 72728 (1637) [ 0,  0,  1, -1,  0,  0,  0,  1,  0] [ 9,  3,  3]  1 */
     1433608, /* 72729 (1637) [ 1,  0,  0,  0,  0,  1,  0,  1,  0] [ 0,  6,  0]  1 */
    60415025, /* 72730 (1637) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 9,  3,  9] -1 */
     1420480, /* 72731 (1637) [-1,  0,  0,  0,  0,  1,  0, -1,  0] [ 0,  6,  0]  1 */
     1544146, /* 72732 (1637) [ 0,  0, -1, -1,  0,  0,  0,  1,  0] [ 0,  6,  6]  1 */
    44710903, /* 72733 (1637) [ 0,  0,  1,  1,  0,  0,  0, -1,  0] [ 3,  9,  3] -1 */
    43410373, /* 72734 (1637) [ 0,  0, -1,  1,  0,  0,  0,  1,  0] [ 3,  3,  9] -1 */
    51145306, /* 72735 (1637) [ 0,  0, -1, -1,  0,  0,  0,  1,  0] [ 6,  0,  6] -1 */
    27819769, /* 72736 (1637) [ 0, -1,  0,  0,  0,  1,  1,  0,  0] [ 9,  9,  9]  1 */
    26280003, /* 72737 (1637) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 9,  3,  3]  1 */
     9273943, /* 72738 (1637) [-1,  0,  0,  0,  0, -1,  0, -1,  0] [ 3,  3,  3]  1 */
    52561506, /* 72739 (1637) [ 0, -1,  0,  1,  0,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    18550426, /* 72740 (1637) [ 0,  0, -1,  0, -1,  0,  1,  0,  0] [ 6,  6,  6]  1 */
    60410377, /* 72741 (1637) [-1,  0,  0,  0,  0, -1,  0, -1,  0] [ 9,  3,  9] -1 */
    51152754, /* 72742 (1637) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  6] -1 */
     9392153, /* 72743 (1637) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 3,  3,  9]  1 */
    10813865, /* 72744 (1637) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 3,  9,  9]  1 */
    44829977, /* 72745 (1637) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 3,  9,  9] -1 */
    61833169, /* 72746 (1637) [ 0,  0, -1, -1,  0,  0,  0, -1,  0] [ 9,  9,  9] -1 */
    43417337, /* 72747 (1637) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 3,  3,  9] -1 */
    18433612, /* 72748 (1637) [ 0,  0,  1, -1,  0,  0,  0, -1,  0] [ 6,  6,  0]  1 */
    17127410, /* 72749 (1637) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
    44703291, /* 72750 (1637) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 3,  9,  3] -1 */
    34015424, /* 72751 (1637) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    27701391, /* 72752 (1637) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 9,  9,  3]  1 */
     9278103, /* 72753 (1637) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 3,  3,  3]  1 */
    34024288, /* 72754 (1637) [ 0,  1,  0,  0,  0,  1,  1,  0,  0] [ 0,  0,  0] -1 */
    27710359, /* 72755 (1637) [ 1,  0,  0,  0,  0, -1,  0,  1,  0] [ 9,  9,  3]  1 */
    51034768, /* 72756 (1637) [ 1,  0,  0,  0,  0,  1,  0,  1,  0] [ 6,  0,  0] -1 */
    34019860, /* 72757 (1637) [ 0, -1,  0,  0,  0, -1,  1,  0,  0] [ 0,  0,  0] -1 */
    52443184, /* 72758 (1637) [ 0, -1,  0,  0,  0,  1, -1,  0,  0] [ 6,  6,  0] -1 */
    52451832, /* 72759 (1637) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
    10698679, /* 72760 (1637) [ 0,  0,  1,  1,  0,  0,  0, -1,  0] [ 3,  9,  3]  1 */
    43291939, /* 72761 (1637) [ 0,  0, -1,  0, -1,  0, -1,  0,  0] [ 3,  3,  3] -1 */
     9398149, /* 72762 (1637) [ 0,  0, -1,  1,  0,  0,  0,  1,  0] [ 3,  3,  9]  1 */
    61836313, /* 72763 (1637) [ 0,  1,  0,  0,  0, -1,  1,  0,  0] [ 9,  9,  9] -1 */
    17133082, /* 72764 (1637) [ 0,  0, -1, -1,  0,  0,  0,  1,  0] [ 6,  0,  6]  1 */
    51144106, /* 72765 (1637) [ 0, -1,  0,  0,  0,  1, -1,  0,  0] [ 6,  0,  6] -1 */
    35558314, /* 72766 (1637) [ 0,  0,  1,  1,  0,  0,  0,  1,  0] [ 0,  6,  6] -1 */
    34021096, /* 72767 (1637) [ 0,  0, -1, -1,  0,  0,  0,  1,  0] [ 0,  0,  0] -1 */
      127138, /* 72768 (1637) [ 0,  0, -1,  0, -1,  0,  1,  0,  0] [ 0,  0,  6]  1 */
    26398153, /* 72769 (1637) [-1,  0,  0,  0,  0, -1,  0, -1,  0] [ 9,  3,  9]  1 */
    17140530, /* 72770 (1637) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  6]  1 */
    35438440, /* 72771 (1637) [ 0,  0, -1,  0, -1,  0,  1,  0,  0] [ 0,  6,  0] -1 */
    17013524, /* 72772 (1637) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 6,  0,  0]  1 */
    10817753, /* 72773 (1637) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 3,  9,  9]  1 */
    27820945, /* 72774 (1637) [ 0,  0, -1, -1,  0,  0,  0, -1,  0] [ 9,  9,  9]  1 */
     9397657, /* 72775 (1637) [ 0,  0, -1, -1,  0,  0,  0, -1,  0] [ 3,  3,  9]  1 */
    26406689, /* 72776 (1637) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 9,  3,  9]  1 */
     9405113, /* 72777 (1637) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 3,  3,  9]  1 */
    34028708, /* 72778 (1637) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    61709515, /* 72779 (1637) [-1,  0,  0,  0,  0,  1,  0,  1,  0] [ 9,  9,  3] -1 */
    10691067, /* 72780 (1637) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 3,  9,  3]  1 */
    51145786, /* 72781 (1637) [ 0,  0, -1,  1,  0,  0,  0, -1,  0] [ 6,  0,  6] -1 */
    51034708, /* 72782 (1637) [ 1,  0,  0,  0,  0, -1,  0, -1,  0] [ 6,  0,  0] -1 */
        3200, /* 72783 (1637) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    44827393, /* 72784 (1637) [ 0,  0, -1,  0,  1,  0,  1,  0,  0] [ 3,  9,  9] -1 */
    61827665, /* 72785 (1637) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 9,  9,  9] -1 */
    26402313, /* 72786 (1637) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 9,  3,  9]  1 */
    43294703, /* 72787 (1637) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 3,  3,  3] -1 */
    17017896, /* 72788 (1637) [ 0,  1,  0, -1,  0,  0,  0,  0, -1] [ 6,  0,  0]  1 */
       12064, /* 72789 (1637) [ 0,  1,  0,  0,  0,  1,  1,  0,  0] [ 0,  0,  0]  1 */
    44825601, /* 72790 (1637) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 3,  9,  9] -1 */
    34146754, /* 72791 (1637) [ 1,  0,  0,  0,  0,  1,  0,  1,  0] [ 0,  0,  6] -1 */
    51147250, /* 72792 (1637) [ 0,  0,  1,  1,  0,  0,  0,  1,  0] [ 6,  0,  6] -1 */
    27710407, /* 72793 (1637) [ 1,  0,  0,  0,  0,  1,  0, -1,  0] [ 9,  9,  3]  1 */
    26398213, /* 72794 (1637) [-1,  0,  0,  0,  0,  1,  0,  1,  0] [ 9,  3,  9]  1 */
    60299839, /* 72795 (1637) [ 0,  0,  1,  1,  0,  0,  0, -1,  0] [ 9,  3,  3] -1 */
    51027376, /* 72796 (1637) [ 0,  0, -1,  0, -1,  0,  1,  0,  0] [ 6,  0,  0] -1 */
    17131882, /* 72797 (1637) [ 0, -1,  0,  0,  0,  1, -1,  0,  0] [ 6,  0,  6]  1 */
    60416149, /* 72798 (1637) [ 0,  0, -1,  0, -1,  0, -1,  0,  0] [ 9,  3,  9] -1 */
     1546090, /* 72799 (1637) [ 0,  0,  1,  1,  0,  0,  0,  1,  0] [ 0,  6,  6]  1 */
    43290815, /* 72800 (1637) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 3,  3,  3] -1 */
    44821441, /* 72801 (1637) [-1,  0,  0,  0,  0, -1,  0, -1,  0] [ 3,  9,  9] -1 */
     1426216, /* 72802 (1637) [ 0,  0, -1,  0, -1,  0,  1,  0,  0] [ 0,  6,  0]  1 */
    60416329, /* 72803 (1637) [ 0,  0, -1,  0,  1,  0,  1,  0,  0] [ 9,  3,  9] -1 */
    10695559, /* 72804 (1637) [ 0, -1,  0,  0,  0,  1,  1,  0,  0] [ 3,  9,  3]  1 */
    52447504, /* 72805 (1637) [ 0,  1,  0,  0,  0, -1, -1,  0,  0] [ 6,  6,  0] -1 */
    34140802, /* 72806 (1637) [ 0,  0,  1,  0, -1,  0, -1,  0,  0] [ 0,  0,  6] -1 */
    61833661, /* 72807 (1637) [ 0,  0, -1,  1,  0,  0,  0,  1,  0] [ 9,  9,  9] -1 */
    18551866, /* 72808 (1637) [ 0,  0,  1,  0, -1,  0, -1,  0,  0] [ 6,  6,  6]  1 */
    43413025, /* 72809 (1637) [ 0,  1,  0,  0,  0, -1,  1,  0,  0] [ 3,  3,  9] -1 */
    27697291, /* 72810 (1637) [-1,  0,  0,  0,  0,  1,  0,  1,  0] [ 9,  9,  3]  1 */
    17133562, /* 72811 (1637) [ 0,  0, -1,  1,  0,  0,  0, -1,  0] [ 6,  0,  6]  1 */
    17136202, /* 72812 (1637) [ 0,  1,  0,  0,  0, -1, -1,  0,  0] [ 6,  0,  6]  1 */
    10815169, /* 72813 (1637) [ 0,  0, -1,  0,  1,  0,  1,  0,  0] [ 3,  9,  9]  1 */
    44716415, /* 72814 (1637) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 3,  9,  3] -1 */
    35563818, /* 72815 (1637) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  6] -1 */
    60305351, /* 72816 (1637) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 9,  3,  3] -1 */
    27815441, /* 72817 (1637) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 9,  9,  9]  1 */
    52556914, /* 72818 (1637) [-1,  0,  0,  0,  0,  1,  0, -1,  0] [ 6,  6,  6] -1 */
    61718475, /* 72819 (1637) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 9,  9,  3] -1 */
    60296719, /* 72820 (1637) [ 0, -1,  0,  0,  0,  1,  1,  0,  0] [ 9,  3,  3] -1 */
    10813377, /* 72821 (1637) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 3,  9,  9]  1 */
      134530, /* 72822 (1637) [ 1,  0,  0,  0,  0,  1,  0,  1,  0] [ 0,  0,  6]  1 */
    34137734, /* 72823 (1637) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    52443148, /* 72824 (1637) [ 0, -1,  0,  0,  0, -1,  1,  0,  0] [ 6,  6,  0] -1 */
    17135026, /* 72825 (1637) [ 0,  0,  1,  1,  0,  0,  0,  1,  0] [ 6,  0,  6]  1 */
    60297895, /* 72826 (1637) [ 0,  0, -1, -1,  0,  0,  0, -1,  0] [ 9,  3,  3] -1 */
    52562794, /* 72827 (1637) [ 0,  0, -1,  0,  1,  0, -1,  0,  0] [ 6,  6,  6] -1 */
    17015152, /* 72828 (1637) [ 0,  0, -1,  0, -1,  0,  1,  0,  0] [ 6,  0,  0]  1 */
     9281191, /* 72829 (1637) [ 0,  0,  1,  0, -1,  0,  1,  0,  0] [ 3,  3,  3]  1 */
    35445772, /* 72830 (1637) [ 1,  0,  0,  0,  0, -1,  0, -1,  0] [ 0,  6,  0] -1 */
    43411825, /* 72831 (1637) [ 0,  0,  1,  1,  0,  0,  0, -1,  0] [ 3,  3,  9] -1 */
    34133578, /* 72832 (1637) [-1,  0,  0,  0,  0, -1,  0,  1,  0] [ 0,  0,  6] -1 */
    61716847, /* 72833 (1637) [ 0,  0,  1,  0,  1,  0, -1,  0,  0] [ 9,  9,  3] -1 */
    34146694, /* 72834 (1637) [ 1,  0,  0,  0,  0, -1,  0, -1,  0] [ 0,  0,  6] -1 */
    60423553, /* 72835 (1637) [ 1,  0,  0,  0,  0,  1,  0, -1,  0] [ 9,  3,  9] -1 */
    44827213, /* 72836 (1637) [ 0,  0, -1,  0, -1,  0, -1,  0,  0] [ 3,  9,  9] -1 */
    27697231, /* 72837 (1637) [-1,  0,  0,  0,  0, -1,  0, -1,  0] [ 9,  9,  3]  1 */
     1428960, /* 72838 (1637) [ 0,  1,  0, -1,  0,  0,  0,  0, -1] [ 0,  6,  0]  1 */
      128578, /* 72839 (1637) [ 0,  0,  1,  0, -1,  0, -1,  0,  0] [ 0,  0,  6]  1 */
    10822393, /* 72840 (1637) [ 1,  0,  0,  0,  0,  1,  0, -1,  0] [ 3,  9,  9]  1 */
    27821437, /* 72841 (1637) [ 0,  0, -1,  1,  0,  0,  0,  1,  0] [ 9,  9,  9]  1 */
    44712139, /* 72842 (1637) [ 0,  1,  0,  0,  0,  1, -1,  0,  0] [ 3,  9,  3] -1 */
    43293559, /* 72843 (1637) [ 0,  0,  1,  0,  1,  0, -1,  0,  0] [ 3,  3,  3] -1 */
    10698199, /* 72844 (1637) [ 0,  0,  1, -1,  0,  0,  0,  1,  0] [ 3,  9,  3]  1 */
     1542946, /* 72845 (1637) [ 0, -1,  0,  0,  0,  1, -1,  0,  0] [ 0,  6,  6]  1 */
     1551594, /* 72846 (1637) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
    26293127, /* 72847 (1637) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 9,  3,  3]  1 */
    27706251, /* 72848 (1637) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 9,  9,  3]  1 */
    26284495, /* 72849 (1637) [ 0, -1,  0,  0,  0,  1,  1,  0,  0] [ 9,  3,  3]  1 */
    60292391, /* 72850 (1637) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 9,  3,  3] -1 */
    44703455, /* 72851 (1637) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 3,  9,  3] -1 */
    18430924, /* 72852 (1637) [ 0, -1,  0,  0,  0, -1,  1,  0,  0] [ 6,  6,  0]  1 */
    35563982, /* 72853 (1637) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
    35556850, /* 72854 (1637) [ 0,  0, -1,  1,  0,  0,  0, -1,  0] [ 0,  6,  6] -1 */
    35559490, /* 72855 (1637) [ 0,  1,  0,  0,  0, -1, -1,  0,  0] [ 0,  6,  6] -1 */
    34138218, /* 72856 (1637) [ 0, -1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  6] -1 */
    17131846, /* 72857 (1637) [ 0, -1,  0,  0,  0, -1,  1,  0,  0] [ 6,  0,  6]  1 */
    34140982, /* 72858 (1637) [ 0,  0,  1,  0,  1,  0,  1,  0,  0] [ 0,  0,  6] -1 */
    18550570, /* 72859 (1637) [ 0,  0, -1,  0,  1,  0, -1,  0,  0] [ 6,  6,  6]  1 */
    52438872, /* 72860 (1637) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
      121354, /* 72861 (1637) [-1,  0,  0,  0,  0, -1,  0,  1,  0] [ 0,  0,  6]  1 */
    35559562, /* 72862 (1637) [ 0,  1,  0,  0,  0,  1,  1,  0,  0] [ 0,  6,  6] -1 */
     9282963, /* 72863 (1637) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 3,  3,  3]  1 */
      134470, /* 72864 (1637) [ 1,  0,  0,  0,  0, -1,  0, -1,  0] [ 0,  0,  6]  1 */
    26411329, /* 72865 (1637) [ 1,  0,  0,  0,  0,  1,  0, -1,  0] [ 9,  3,  9]  1 */
    44830461, /* 72866 (1637) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 3,  9,  9] -1 */
     9274003, /* 72867 (1637) [-1,  0,  0,  0,  0,  1,  0,  1,  0] [ 3,  3,  3]  1 */
    27705767, /* 72868 (1637) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 9,  9,  3]  1 */
    18426488, /* 72869 (1637) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
       10324, /* 72870 (1637) [ 0,  0,  1, -1,  0,  0,  0, -1,  0] [ 0,  0,  0]  1 */
    17127570, /* 72871 (1637) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6]  1 */
    10699915, /* 72872 (1637) [ 0,  1,  0,  0,  0,  1, -1,  0,  0] [ 3,  9,  3]  1 */
     9281335, /* 72873 (1637) [ 0,  0,  1,  0,  1,  0, -1,  0,  0] [ 3,  3,  3]  1 */
    43292119, /* 72874 (1637) [ 0,  0, -1,  0,  1,  0,  1,  0,  0] [ 3,  3,  3] -1 */
    44828833, /* 72875 (1637) [ 0,  0,  1,  0,  1,  0, -1,  0,  0] [ 3,  9,  9] -1 */
    61714103, /* 72876 (1637) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 9,  9,  3] -1 */
    51028816, /* 72877 (1637) [ 0,  0,  1,  0, -1,  0, -1,  0,  0] [ 6,  0,  0] -1 */
    44716575, /* 72878 (1637) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 3,  9,  3] -1 */
    60298387, /* 72879 (1637) [ 0,  0, -1,  1,  0,  0,  0,  1,  0] [ 9,  3,  3] -1 */
    44709451, /* 72880 (1637) [ 0,  0, -1,  1,  0,  0,  0,  1,  0] [ 3,  9,  3] -1 */
    52444384, /* 72881 (1637) [ 0,  0, -1, -1,  0,  0,  0,  1,  0] [ 6,  6,  0] -1 */
    52564270, /* 72882 (1637) [ 0,  0,  1,  0,  1,  0,  1,  0,  0] [ 6,  6,  6] -1 */
    51152918, /* 72883 (1637) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
    60301039, /* 72884 (1637) [ 0,  1,  0,  0,  0, -1,  1,  0,  0] [ 9,  3,  3] -1 */
    60301075, /* 72885 (1637) [ 0,  1,  0,  0,  0,  1, -1,  0,  0] [ 9,  3,  3] -1 */
    26402801, /* 72886 (1637) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 9,  3,  9]  1 */
    61827501, /* 72887 (1637) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 9,  9,  9] -1 */
    43404213, /* 72888 (1637) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 3,  3,  9] -1 */
    34028544, /* 72889 (1637) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    61715227, /* 72890 (1637) [ 0,  0, -1,  0, -1,  0, -1,  0,  0] [ 9,  9,  3] -1 */
    10691231, /* 72891 (1637) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 3,  9,  3]  1 */
    51021640, /* 72892 (1637) [-1,  0,  0,  0,  0,  1,  0, -1,  0] [ 6,  0,  0] -1 */
     1551758, /* 72893 (1637) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
    51148498, /* 72894 (1637) [ 0,  1,  0,  0,  0,  1,  1,  0,  0] [ 6,  0,  6] -1 */
     1547266, /* 72895 (1637) [ 0,  1,  0,  0,  0, -1, -1,  0,  0] [ 0,  6,  6]  1 */
      125994, /* 72896 (1637) [ 0, -1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  6]  1 */
    18549282, /* 72897 (1637) [ 0, -1,  0,  1,  0,  0,  0,  0, -1] [ 6,  6,  6]  1 */
    60419397, /* 72898 (1637) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 9,  3,  9] -1 */
    60296647, /* 72899 (1637) [ 0, -1,  0,  0,  0, -1, -1,  0,  0] [ 9,  3,  3] -1 */
    60423505, /* 72900 (1637) [ 1,  0,  0,  0,  0, -1,  0,  1,  0] [ 9,  3,  9] -1 */
    60417625, /* 72901 (1637) [ 0,  0,  1,  0, -1,  0,  1,  0,  0] [ 9,  3,  9] -1 */
    60417769, /* 72902 (1637) [ 0,  0,  1,  0,  1,  0, -1,  0,  0] [ 9,  3,  9] -1 */
     9279895, /* 72903 (1637) [ 0,  0, -1,  0,  1,  0,  1,  0,  0] [ 3,  3,  3]  1 */
    17016592, /* 72904 (1637) [ 0,  0,  1,  0, -1,  0, -1,  0,  0] [ 6,  0,  0]  1 */
    10704351, /* 72905 (1637) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 3,  9,  3]  1 */
    10697227, /* 72906 (1637) [ 0,  0, -1,  1,  0,  0,  0,  1,  0] [ 3,  9,  3]  1 */
    18432160, /* 72907 (1637) [ 0,  0, -1, -1,  0,  0,  0,  1,  0] [ 6,  6,  0]  1 */
    18552046, /* 72908 (1637) [ 0,  0,  1,  0,  1,  0,  1,  0,  0] [ 6,  6,  6]  1 */
    34019896, /* 72909 (1637) [ 0, -1,  0,  0,  0,  1, -1,  0,  0] [ 0,  0,  0] -1 */
    35550858, /* 72910 (1637) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6] -1 */
    60305511, /* 72911 (1637) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 9,  3,  3] -1 */
    61835113, /* 72912 (1637) [ 0,  0,  1,  1,  0,  0,  0, -1,  0] [ 9,  9,  9] -1 */
    17022544, /* 72913 (1637) [ 1,  0,  0,  0,  0,  1,  0,  1,  0] [ 6,  0,  0]  1 */
        7636, /* 72914 (1637) [ 0, -1,  0,  0,  0, -1,  1,  0,  0] [ 0,  0,  0]  1 */
    44828689, /* 72915 (1637) [ 0,  0,  1,  0, -1,  0,  1,  0,  0] [ 3,  9,  9] -1 */
     9391989, /* 72916 (1637) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 3,  3,  9]  1 */
    35440060, /* 72917 (1637) [ 0,  0,  1,  0,  1,  0,  1,  0,  0] [ 0,  6,  0] -1 */
       16320, /* 72918 (1637) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    18430960, /* 72919 (1637) [ 0, -1,  0,  0,  0,  1, -1,  0,  0] [ 6,  6,  0]  1 */
    18439608, /* 72920 (1637) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
     9279715, /* 72921 (1637) [ 0,  0, -1,  0, -1,  0, -1,  0,  0] [ 3,  3,  3]  1 */
    27703003, /* 72922 (1637) [ 0,  0, -1,  0, -1,  0, -1,  0,  0] [ 9,  9,  3]  1 */
    35550698, /* 72923 (1637) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
    27824089, /* 72924 (1637) [ 0,  1,  0,  0,  0, -1,  1,  0,  0] [ 9,  9,  9]  1 */
    44707711, /* 72925 (1637) [ 0, -1,  0,  0,  0, -1, -1,  0,  0] [ 3,  9,  3] -1 */
    43408705, /* 72926 (1637) [ 0, -1,  0,  0,  0,  1,  1,  0,  0] [ 3,  3,  9] -1 */
    44834569, /* 72927 (1637) [ 1,  0,  0,  0,  0, -1,  0,  1,  0] [ 3,  9,  9] -1 */
        8872, /* 72928 (1637) [ 0,  0, -1, -1,  0,  0,  0,  1,  0] [ 0,  0,  0]  1 */
    52565394, /* 72929 (1637) [ 0,  1,  0, -1,  0,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    26284423, /* 72930 (1637) [ 0, -1,  0,  0,  0, -1, -1,  0,  0] [ 9,  3,  3]  1 */
    35439880, /* 72931 (1637) [ 0,  0,  1,  0, -1,  0, -1,  0,  0] [ 0,  6,  0] -1 */
    26411281, /* 72932 (1637) [ 1,  0,  0,  0,  0, -1,  0,  1,  0] [ 9,  3,  9]  1 */
    51027520, /* 72933 (1637) [ 0,  0, -1,  0,  1,  0, -1,  0,  0] [ 6,  0,  0] -1 */
    26405401, /* 72934 (1637) [ 0,  0,  1,  0, -1,  0,  1,  0,  0] [ 9,  3,  9]  1 */
    34142594, /* 72935 (1637) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    52444864, /* 72936 (1637) [ 0,  0, -1,  1,  0,  0,  0, -1,  0] [ 6,  6,  0] -1 */
    34024216, /* 72937 (1637) [ 0,  1,  0,  0,  0, -1, -1,  0,  0] [ 0,  0,  0] -1 */
    51026232, /* 72938 (1637) [ 0, -1,  0,  1,  0,  0,  0,  0, -1] [ 6,  0,  0] -1 */
    61834633, /* 72939 (1637) [ 0,  0,  1, -1,  0,  0,  0,  1,  0] [ 9,  9,  9] -1 */
    17022484, /* 72940 (1637) [ 1,  0,  0,  0,  0, -1,  0, -1,  0] [ 6,  0,  0]  1 */
    52561022, /* 72941 (1637) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    61840785, /* 72942 (1637) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 9,  9,  9] -1 */
    34133626, /* 72943 (1637) [-1,  0,  0,  0,  0,  1,  0, -1,  0] [ 0,  0,  6] -1 */
    43413061, /* 72944 (1637) [ 0,  1,  0,  0,  0,  1, -1,  0,  0] [ 3,  3,  9] -1 */
     9282479, /* 72945 (1637) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 3,  3,  3]  1 */
    52556866, /* 72946 (1637) [-1,  0,  0,  0,  0, -1,  0,  1,  0] [ 6,  6,  6] -1 */
        7672, /* 72947 (1637) [ 0, -1,  0,  0,  0,  1, -1,  0,  0] [ 0,  0,  0]  1 */
     1538634, /* 72948 (1637) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
    26293287, /* 72949 (1637) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 9,  3,  3]  1 */
    27822889, /* 72950 (1637) [ 0,  0,  1,  1,  0,  0,  0, -1,  0] [ 9,  9,  9]  1 */
     1427836, /* 72951 (1637) [ 0,  0,  1,  0,  1,  0,  1,  0,  0] [ 0,  6,  0]  1 */
    52565882, /* 72952 (1637) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    43417497, /* 72953 (1637) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 3,  3,  9] -1 */
    26287615, /* 72954 (1637) [ 0,  0,  1,  1,  0,  0,  0, -1,  0] [ 9,  3,  3]  1 */
    34023040, /* 72955 (1637) [ 0,  0,  1,  1,  0,  0,  0,  1,  0] [ 0,  0,  0] -1 */
    52446328, /* 72956 (1637) [ 0,  0,  1,  1,  0,  0,  0,  1,  0] [ 6,  6,  0] -1 */
    10695487, /* 72957 (1637) [ 0, -1,  0,  0,  0, -1, -1,  0,  0] [ 3,  9,  3]  1 */
    61715407, /* 72958 (1637) [ 0,  0, -1,  0,  1,  0,  1,  0,  0] [ 9,  9,  3] -1 */
    51028996, /* 72959 (1637) [ 0,  0,  1,  0,  1,  0,  1,  0,  0] [ 6,  0,  0] -1 */
    26403925, /* 72960 (1637) [ 0,  0, -1,  0, -1,  0, -1,  0,  0] [ 9,  3,  9]  1 */
     9278591, /* 72961 (1637) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 3,  3,  3]  1 */
    51146758, /* 72962 (1637) [ 0,  0,  1, -1,  0,  0,  0, -1,  0] [ 6,  0,  6] -1 */
    10809217, /* 72963 (1637) [-1,  0,  0,  0,  0, -1,  0, -1,  0] [ 3,  9,  9]  1 */
    18553170, /* 72964 (1637) [ 0,  1,  0, -1,  0,  0,  0,  0, -1] [ 6,  6,  6]  1 */
    26404105, /* 72965 (1637) [ 0,  0, -1,  0,  1,  0,  1,  0,  0] [ 9,  3,  9]  1 */
     1427656, /* 72966 (1637) [ 0,  0,  1,  0, -1,  0, -1,  0,  0] [ 0,  6,  0]  1 */
    18432640, /* 72967 (1637) [ 0,  0, -1,  1,  0,  0,  0, -1,  0] [ 6,  6,  0]  1 */
       11992, /* 72968 (1637) [ 0,  1,  0,  0,  0, -1, -1,  0,  0] [ 0,  0,  0]  1 */
    18435280, /* 72969 (1637) [ 0,  1,  0,  0,  0, -1, -1,  0,  0] [ 6,  6,  0]  1 */
    17014008, /* 72970 (1637) [ 0, -1,  0,  1,  0,  0,  0,  0, -1] [ 6,  0,  0]  1 */
    27822409, /* 72971 (1637) [ 0,  0,  1, -1,  0,  0,  0,  1,  0] [ 9,  9,  9]  1 */
     9400801, /* 72972 (1637) [ 0,  1,  0,  0,  0, -1,  1,  0,  0] [ 3,  3,  9]  1 */
    61831993, /* 72973 (1637) [ 0, -1,  0,  0,  0,  1,  1,  0,  0] [ 9,  9,  9] -1 */
    18548798, /* 72974 (1637) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    10704191, /* 72975 (1637) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 3,  9,  3]  1 */
      121402, /* 72976 (1637) [-1,  0,  0,  0,  0,  1,  0, -1,  0] [ 0,  0,  6]  1 */
    18544690, /* 72977 (1637) [-1,  0,  0,  0,  0,  1,  0, -1,  0] [ 6,  6,  6]  1 */
    18544642, /* 72978 (1637) [-1,  0,  0,  0,  0, -1,  0,  1,  0] [ 6,  6,  6]  1 */
    44708959, /* 72979 (1637) [ 0,  0, -1, -1,  0,  0,  0, -1,  0] [ 3,  9,  3] -1 */
    34139506, /* 72980 (1637) [ 0,  0, -1,  0,  1,  0, -1,  0,  0] [ 0,  0,  6] -1 */
      125510, /* 72981 (1637) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  6]  1 */
    26285671, /* 72982 (1637) [ 0,  0, -1, -1,  0,  0,  0, -1,  0] [ 9,  3,  3]  1 */
     9405273, /* 72983 (1637) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 3,  3,  9]  1 */
    18553658, /* 72984 (1637) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    35436812, /* 72985 (1637) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 0,  6,  0] -1 */
       10816, /* 72986 (1637) [ 0,  0,  1,  1,  0,  0,  0,  1,  0] [ 0,  0,  0]  1 */
    18434104, /* 72987 (1637) [ 0,  0,  1,  1,  0,  0,  0,  1,  0] [ 6,  6,  0]  1 */
    17016772, /* 72988 (1637) [ 0,  0,  1,  0,  1,  0,  1,  0,  0] [ 6,  0,  0]  1 */
    35441672, /* 72989 (1637) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 0,  6,  0] -1 */
     1433548, /* 72990 (1637) [ 1,  0,  0,  0,  0, -1,  0, -1,  0] [ 0,  6,  0]  1 */
     9399601, /* 72991 (1637) [ 0,  0,  1,  1,  0,  0,  0, -1,  0] [ 3,  3,  9]  1 */
    43290327, /* 72992 (1637) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 3,  3,  3] -1 */
    27704623, /* 72993 (1637) [ 0,  0,  1,  0,  1,  0, -1,  0,  0] [ 9,  9,  3]  1 */
    17134534, /* 72994 (1637) [ 0,  0,  1, -1,  0,  0,  0, -1,  0] [ 6,  0,  6]  1 */
    35432656, /* 72995 (1637) [-1,  0,  0,  0,  0, -1,  0,  1,  0] [ 0,  6,  0] -1 */
    61716703, /* 72996 (1637) [ 0,  0,  1,  0, -1,  0,  1,  0,  0] [ 9,  9,  3] -1 */
    10814989, /* 72997 (1637) [ 0,  0, -1,  0, -1,  0, -1,  0,  0] [ 3,  9,  9]  1 */
    61722583, /* 72998 (1637) [ 1,  0,  0,  0,  0, -1,  0,  1,  0] [ 9,  9,  3] -1 */
    35438584, /* 72999 (1637) [ 0,  0, -1,  0,  1,  0, -1,  0,  0] [ 0,  6,  0] -1 */
    44821501, /* 73000 (1637) [-1,  0,  0,  0,  0,  1,  0,  1,  0] [ 3,  9,  9] -1 */
    61836349, /* 73001 (1637) [ 0,  1,  0,  0,  0,  1, -1,  0,  0] [ 9,  9,  9] -1 */
    34139362, /* 73002 (1637) [ 0,  0, -1,  0, -1,  0,  1,  0,  0] [ 0,  0,  6] -1 */
    34015584, /* 73003 (1637) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    35437296, /* 73004 (1637) [ 0, -1,  0,  1,  0,  0,  0,  0, -1] [ 0,  6,  0] -1 */
    10696735, /* 73005 (1637) [ 0,  0, -1, -1,  0,  0,  0, -1,  0] [ 3,  9,  3]  1 */
    51025748, /* 73006 (1637) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 6,  0,  0] -1 */
    43409881, /* 73007 (1637) [ 0,  0, -1, -1,  0,  0,  0, -1,  0] [ 3,  3,  9] -1 */
    60418913, /* 73008 (1637) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 9,  3,  9] -1 */
    26280167, /* 73009 (1637) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 9,  3,  3]  1 */
    43411345, /* 73010 (1637) [ 0,  0,  1, -1,  0,  0,  0,  1,  0] [ 3,  3,  9] -1 */
      127282, /* 73011 (1637) [ 0,  0, -1,  0,  1,  0, -1,  0,  0] [ 0,  0,  6]  1 */
     1544626, /* 73012 (1637) [ 0,  0, -1,  1,  0,  0,  0, -1,  0] [ 0,  6,  6]  1 */
     1424588, /* 73013 (1637) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 0,  6,  0]  1 */
    51021592, /* 73014 (1637) [-1,  0,  0,  0,  0, -1,  0,  1,  0] [ 6,  0,  0] -1 */
      128758, /* 73015 (1637) [ 0,  0,  1,  0,  1,  0,  1,  0,  0] [ 0,  0,  6]  1 */
     1429448, /* 73016 (1637) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 0,  6,  0]  1 */
    18426648, /* 73017 (1637) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
     1547338, /* 73018 (1637) [ 0,  1,  0,  0,  0,  1,  1,  0,  0] [ 0,  6,  6]  1 */
     1420432, /* 73019 (1637) [-1,  0,  0,  0,  0, -1,  0,  1,  0] [ 0,  6,  0]  1 */
    27704479, /* 73020 (1637) [ 0,  0,  1,  0, -1,  0,  1,  0,  0] [ 9,  9,  3]  1 */
    51030608, /* 73021 (1637) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 6,  0,  0] -1 */
    10818237, /* 73022 (1637) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 3,  9,  9]  1 */
    60414537, /* 73023 (1637) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 9,  3,  9] -1 */
    51030120, /* 73024 (1637) [ 0,  1,  0, -1,  0,  0,  0,  0, -1] [ 6,  0,  0] -1 */
     1426360, /* 73025 (1637) [ 0,  0, -1,  0,  1,  0, -1,  0,  0] [ 0,  6,  0]  1 */
    61722631, /* 73026 (1637) [ 1,  0,  0,  0,  0,  1,  0, -1,  0] [ 9,  9,  3] -1 */
    60410437, /* 73027 (1637) [-1,  0,  0,  0,  0,  1,  0,  1,  0] [ 9,  3,  9] -1 */
    10816609, /* 73028 (1637) [ 0,  0,  1,  0,  1,  0, -1,  0,  0] [ 3,  9,  9]  1 */
    27701879, /* 73029 (1637) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 9,  9,  3]  1 */
    35557822, /* 73030 (1637) [ 0,  0,  1, -1,  0,  0,  0, -1,  0] [ 0,  6,  6] -1 */
    44712103, /* 73031 (1637) [ 0,  1,  0,  0,  0, -1,  1,  0,  0] [ 3,  9,  3] -1 */
    10809277, /* 73032 (1637) [-1,  0,  0,  0,  0,  1,  0,  1,  0] [ 3,  9,  9]  1 */
    26286163, /* 73033 (1637) [ 0,  0, -1,  1,  0,  0,  0,  1,  0] [ 9,  3,  3]  1 */
    27824125, /* 73034 (1637) [ 0,  1,  0,  0,  0,  1, -1,  0,  0] [ 9,  9,  9]  1 */
       16484, /* 73035 (1638) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    61840785, /* 73036 (1638) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 9,  9,  9] -1 */
    43417337, /* 73037 (1638) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 3,  3,  9] -1 */
    44712139, /* 73038 (1638) [ 0,  1,  0,  0,  0,  1, -1,  0,  0] [ 3,  9,  3] -1 */
        3360, /* 73039 (1638) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    17140694, /* 73040 (1638) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
    18433612, /* 73041 (1638) [ 0,  0,  1, -1,  0,  0,  0, -1,  0] [ 6,  6,  0]  1 */
    43293559, /* 73042 (1638) [ 0,  0,  1,  0,  1,  0, -1,  0,  0] [ 3,  3,  3] -1 */
     1425072, /* 73043 (1638) [ 0, -1,  0,  1,  0,  0,  0,  0, -1] [ 0,  6,  0]  1 */
    43413061, /* 73044 (1638) [ 0,  1,  0,  0,  0,  1, -1,  0,  0] [ 3,  3,  9] -1 */
    17127410, /* 73045 (1638) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
    44707783, /* 73046 (1638) [ 0, -1,  0,  0,  0,  1,  1,  0,  0] [ 3,  9,  3] -1 */
    43299343, /* 73047 (1638) [ 1,  0,  0,  0,  0,  1,  0, -1,  0] [ 3,  3,  3] -1 */
    44703291, /* 73048 (1638) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 3,  9,  3] -1 */
     1542946, /* 73049 (1638) [ 0, -1,  0,  0,  0,  1, -1,  0,  0] [ 0,  6,  6]  1 */
     1551594, /* 73050 (1638) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
        7672, /* 73051 (1638) [ 0, -1,  0,  0,  0,  1, -1,  0,  0] [ 0,  0,  0]  1 */
     1538634, /* 73052 (1638) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
    17009416, /* 73053 (1638) [-1,  0,  0,  0,  0,  1,  0, -1,  0] [ 6,  0,  0]  1 */
    17136274, /* 73054 (1638) [ 0,  1,  0,  0,  0,  1,  1,  0,  0] [ 6,  0,  6]  1 */
    17009368, /* 73055 (1638) [-1,  0,  0,  0,  0, -1,  0,  1,  0] [ 6,  0,  0]  1 */
     1427836, /* 73056 (1638) [ 0,  0,  1,  0,  1,  0,  1,  0,  0] [ 0,  6,  0]  1 */
    43417497, /* 73057 (1638) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 3,  3,  9] -1 */
    61715407, /* 73058 (1638) [ 0,  0, -1,  0,  1,  0,  1,  0,  0] [ 9,  9,  3] -1 */
    60292391, /* 73059 (1638) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 9,  3,  3] -1 */
    44703455, /* 73060 (1638) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 3,  9,  3] -1 */
    18430924, /* 73061 (1638) [ 0, -1,  0,  0,  0, -1,  1,  0,  0] [ 6,  6,  0]  1 */
    17018384, /* 73062 (1638) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 6,  0,  0]  1 */
    18553170, /* 73063 (1638) [ 0,  1,  0, -1,  0,  0,  0,  0, -1] [ 6,  6,  6]  1 */
    17131846, /* 73064 (1638) [ 0, -1,  0,  0,  0, -1,  1,  0,  0] [ 6,  0,  6]  1 */
    18550570, /* 73065 (1638) [ 0,  0, -1,  0,  1,  0, -1,  0,  0] [ 6,  6,  6]  1 */
    61836313, /* 73066 (1638) [ 0,  1,  0,  0,  0, -1,  1,  0,  0] [ 9,  9,  9] -1 */
    43291939, /* 73067 (1638) [ 0,  0, -1,  0, -1,  0, -1,  0,  0] [ 3,  3,  3] -1 */
     1427656, /* 73068 (1638) [ 0,  0,  1,  0, -1,  0, -1,  0,  0] [ 0,  6,  0]  1 */
      121354, /* 73069 (1638) [-1,  0,  0,  0,  0, -1,  0,  1,  0] [ 0,  0,  6]  1 */
    17133082, /* 73070 (1638) [ 0,  0, -1, -1,  0,  0,  0,  1,  0] [ 6,  0,  6]  1 */
    61840625, /* 73071 (1638) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 9,  9,  9] -1 */
    18432640, /* 73072 (1638) [ 0,  0, -1,  1,  0,  0,  0, -1,  0] [ 6,  6,  0]  1 */
       11992, /* 73073 (1638) [ 0,  1,  0,  0,  0, -1, -1,  0,  0] [ 0,  0,  0]  1 */
    18435280, /* 73074 (1638) [ 0,  1,  0,  0,  0, -1, -1,  0,  0] [ 6,  6,  0]  1 */
    17014008, /* 73075 (1638) [ 0, -1,  0,  1,  0,  0,  0,  0, -1] [ 6,  0,  0]  1 */
      134470, /* 73076 (1638) [ 1,  0,  0,  0,  0, -1,  0, -1,  0] [ 0,  0,  6]  1 */
    44830461, /* 73077 (1638) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 3,  9,  9] -1 */
      127138, /* 73078 (1638) [ 0,  0, -1,  0, -1,  0,  1,  0,  0] [ 0,  0,  6]  1 */
    18426488, /* 73079 (1638) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
       10324, /* 73080 (1638) [ 0,  0,  1, -1,  0,  0,  0, -1,  0] [ 0,  0,  0]  1 */
    17140530, /* 73081 (1638) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  6]  1 */
    43299295, /* 73082 (1638) [ 1,  0,  0,  0,  0, -1,  0,  1,  0] [ 3,  3,  3] -1 */
    17127570, /* 73083 (1638) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6]  1 */
     1545598, /* 73084 (1638) [ 0,  0,  1, -1,  0,  0,  0, -1,  0] [ 0,  6,  6]  1 */
    43293415, /* 73085 (1638) [ 0,  0,  1,  0, -1,  0,  1,  0,  0] [ 3,  3,  3] -1 */
    17013524, /* 73086 (1638) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 6,  0,  0]  1 */
    61831993, /* 73087 (1638) [ 0, -1,  0,  0,  0,  1,  1,  0,  0] [ 9,  9,  9] -1 */
    18548798, /* 73088 (1638) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 6,  6,  6]  1 */
      121402, /* 73089 (1638) [-1,  0,  0,  0,  0,  1,  0, -1,  0] [ 0,  0,  6]  1 */
    43292119, /* 73090 (1638) [ 0,  0, -1,  0,  1,  0,  1,  0,  0] [ 3,  3,  3] -1 */
    18544690, /* 73091 (1638) [-1,  0,  0,  0,  0,  1,  0, -1,  0] [ 6,  6,  6]  1 */
    61709455, /* 73092 (1638) [-1,  0,  0,  0,  0, -1,  0, -1,  0] [ 9,  9,  3] -1 */
    18439772, /* 73093 (1638) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    44828833, /* 73094 (1638) [ 0,  0,  1,  0,  1,  0, -1,  0,  0] [ 3,  9,  9] -1 */
    61714103, /* 73095 (1638) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 9,  9,  3] -1 */
    18544642, /* 73096 (1638) [-1,  0,  0,  0,  0, -1,  0,  1,  0] [ 6,  6,  6]  1 */
    44708959, /* 73097 (1638) [ 0,  0, -1, -1,  0,  0,  0, -1,  0] [ 3,  9,  3] -1 */
    61709515, /* 73098 (1638) [-1,  0,  0,  0,  0,  1,  0,  1,  0] [ 9,  9,  3] -1 */
     1538474, /* 73099 (1638) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
    44834617, /* 73100 (1638) [ 1,  0,  0,  0,  0,  1,  0, -1,  0] [ 3,  9,  9] -1 */
    44716575, /* 73101 (1638) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 3,  9,  3] -1 */
    60298387, /* 73102 (1638) [ 0,  0, -1,  1,  0,  0,  0,  1,  0] [ 9,  3,  3] -1 */
        3200, /* 73103 (1638) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    44709451, /* 73104 (1638) [ 0,  0, -1,  1,  0,  0,  0,  1,  0] [ 3,  9,  3] -1 */
    44827393, /* 73105 (1638) [ 0,  0, -1,  0,  1,  0,  1,  0,  0] [ 3,  9,  9] -1 */
    61831921, /* 73106 (1638) [ 0, -1,  0,  0,  0, -1, -1,  0,  0] [ 9,  9,  9] -1 */
    43408633, /* 73107 (1638) [ 0, -1,  0,  0,  0, -1, -1,  0,  0] [ 3,  3,  9] -1 */
    61827665, /* 73108 (1638) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 9,  9,  9] -1 */
      125510, /* 73109 (1638) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  6]  1 */
    18435352, /* 73110 (1638) [ 0,  1,  0,  0,  0,  1,  1,  0,  0] [ 6,  6,  0]  1 */
    60301039, /* 73111 (1638) [ 0,  1,  0,  0,  0, -1,  1,  0,  0] [ 9,  3,  3] -1 */
    18553658, /* 73112 (1638) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    60301075, /* 73113 (1638) [ 0,  1,  0,  0,  0,  1, -1,  0,  0] [ 9,  3,  3] -1 */
       10816, /* 73114 (1638) [ 0,  0,  1,  1,  0,  0,  0,  1,  0] [ 0,  0,  0]  1 */
    61827501, /* 73115 (1638) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 9,  9,  9] -1 */
    18434104, /* 73116 (1638) [ 0,  0,  1,  1,  0,  0,  0,  1,  0] [ 6,  6,  0]  1 */
    43404213, /* 73117 (1638) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 3,  3,  9] -1 */
    43294703, /* 73118 (1638) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 3,  3,  3] -1 */
    17017896, /* 73119 (1638) [ 0,  1,  0, -1,  0,  0,  0,  0, -1] [ 6,  0,  0]  1 */
    44710423, /* 73120 (1638) [ 0,  0,  1, -1,  0,  0,  0,  1,  0] [ 3,  9,  3] -1 */
    17016772, /* 73121 (1638) [ 0,  0,  1,  0,  1,  0,  1,  0,  0] [ 6,  0,  0]  1 */
    61715227, /* 73122 (1638) [ 0,  0, -1,  0, -1,  0, -1,  0,  0] [ 9,  9,  3] -1 */
    60299359, /* 73123 (1638) [ 0,  0,  1, -1,  0,  0,  0,  1,  0] [ 9,  3,  3] -1 */
    17015296, /* 73124 (1638) [ 0,  0, -1,  0,  1,  0, -1,  0,  0] [ 6,  0,  0]  1 */
       12064, /* 73125 (1638) [ 0,  1,  0,  0,  0,  1,  1,  0,  0] [ 0,  0,  0]  1 */
     1433548, /* 73126 (1638) [ 1,  0,  0,  0,  0, -1,  0, -1,  0] [ 0,  6,  0]  1 */
    44825601, /* 73127 (1638) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 3,  9,  9] -1 */
     1551758, /* 73128 (1638) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
        9352, /* 73129 (1638) [ 0,  0, -1,  1,  0,  0,  0, -1,  0] [ 0,  0,  0]  1 */
      130370, /* 73130 (1638) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 0,  0,  6]  1 */
    18557818, /* 73131 (1638) [ 1,  0,  0,  0,  0,  1,  0,  1,  0] [ 6,  6,  6]  1 */
    43290327, /* 73132 (1638) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 3,  3,  3] -1 */
     1542910, /* 73133 (1638) [ 0, -1,  0,  0,  0, -1,  1,  0,  0] [ 0,  6,  6]  1 */
    17134534, /* 73134 (1638) [ 0,  0,  1, -1,  0,  0,  0, -1,  0] [ 6,  0,  6]  1 */
    61716703, /* 73135 (1638) [ 0,  0,  1,  0, -1,  0,  1,  0,  0] [ 9,  9,  3] -1 */
     1547266, /* 73136 (1638) [ 0,  1,  0,  0,  0, -1, -1,  0,  0] [ 0,  6,  6]  1 */
      125994, /* 73137 (1638) [ 0, -1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  6]  1 */
    18549282, /* 73138 (1638) [ 0, -1,  0,  1,  0,  0,  0,  0, -1] [ 6,  6,  6]  1 */
    60419397, /* 73139 (1638) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 9,  3,  9] -1 */
    60299839, /* 73140 (1638) [ 0,  0,  1,  1,  0,  0,  0, -1,  0] [ 9,  3,  3] -1 */
    60296647, /* 73141 (1638) [ 0, -1,  0,  0,  0, -1, -1,  0,  0] [ 9,  3,  3] -1 */
    60423505, /* 73142 (1638) [ 1,  0,  0,  0,  0, -1,  0,  1,  0] [ 9,  3,  9] -1 */
    17131882, /* 73143 (1638) [ 0, -1,  0,  0,  0,  1, -1,  0,  0] [ 6,  0,  6]  1 */
    60417625, /* 73144 (1638) [ 0,  0,  1,  0, -1,  0,  1,  0,  0] [ 9,  3,  9] -1 */
    60416149, /* 73145 (1638) [ 0,  0, -1,  0, -1,  0, -1,  0,  0] [ 9,  3,  9] -1 */
    61722583, /* 73146 (1638) [ 1,  0,  0,  0,  0, -1,  0,  1,  0] [ 9,  9,  3] -1 */
     1546090, /* 73147 (1638) [ 0,  0,  1,  1,  0,  0,  0,  1,  0] [ 0,  6,  6]  1 */
    60292227, /* 73148 (1638) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 9,  3,  3] -1 */
    43286167, /* 73149 (1638) [-1,  0,  0,  0,  0, -1,  0, -1,  0] [ 3,  3,  3] -1 */
    43290815, /* 73150 (1638) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 3,  3,  3] -1 */
    44821441, /* 73151 (1638) [-1,  0,  0,  0,  0, -1,  0, -1,  0] [ 3,  9,  9] -1 */
     1426216, /* 73152 (1638) [ 0,  0, -1,  0, -1,  0,  1,  0,  0] [ 0,  6,  0]  1 */
    60416329, /* 73153 (1638) [ 0,  0, -1,  0,  1,  0,  1,  0,  0] [ 9,  3,  9] -1 */
    60417769, /* 73154 (1638) [ 0,  0,  1,  0,  1,  0, -1,  0,  0] [ 9,  3,  9] -1 */
    43404377, /* 73155 (1638) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 3,  3,  9] -1 */
    43295187, /* 73156 (1638) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 3,  3,  3] -1 */
    44826089, /* 73157 (1638) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 3,  9,  9] -1 */
    44821501, /* 73158 (1638) [-1,  0,  0,  0,  0,  1,  0,  1,  0] [ 3,  9,  9] -1 */
    43286227, /* 73159 (1638) [-1,  0,  0,  0,  0,  1,  0,  1,  0] [ 3,  3,  3] -1 */
    61717991, /* 73160 (1638) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 9,  9,  3] -1 */
    61833661, /* 73161 (1638) [ 0,  0, -1,  1,  0,  0,  0,  1,  0] [ 9,  9,  9] -1 */
    61836349, /* 73162 (1638) [ 0,  1,  0,  0,  0,  1, -1,  0,  0] [ 9,  9,  9] -1 */
    18551866, /* 73163 (1638) [ 0,  0,  1,  0, -1,  0, -1,  0,  0] [ 6,  6,  6]  1 */
    18557758, /* 73164 (1638) [ 1,  0,  0,  0,  0, -1,  0, -1,  0] [ 6,  6,  6]  1 */
    17016592, /* 73165 (1638) [ 0,  0,  1,  0, -1,  0, -1,  0,  0] [ 6,  0,  0]  1 */
    43413025, /* 73166 (1638) [ 0,  1,  0,  0,  0, -1,  1,  0,  0] [ 3,  3,  9] -1 */
    17133562, /* 73167 (1638) [ 0,  0, -1,  1,  0,  0,  0, -1,  0] [ 6,  0,  6]  1 */
    17136202, /* 73168 (1638) [ 0,  1,  0,  0,  0, -1, -1,  0,  0] [ 6,  0,  6]  1 */
    43409881, /* 73169 (1638) [ 0,  0, -1, -1,  0,  0,  0, -1,  0] [ 3,  3,  9] -1 */
      129882, /* 73170 (1638) [ 0,  1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  6]  1 */
    60418913, /* 73171 (1638) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 9,  3,  9] -1 */
    44716415, /* 73172 (1638) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 3,  9,  3] -1 */
    18432160, /* 73173 (1638) [ 0,  0, -1, -1,  0,  0,  0,  1,  0] [ 6,  6,  0]  1 */
    43411345, /* 73174 (1638) [ 0,  0,  1, -1,  0,  0,  0,  1,  0] [ 3,  3,  9] -1 */
    60305351, /* 73175 (1638) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 9,  3,  3] -1 */
      127282, /* 73176 (1638) [ 0,  0, -1,  0,  1,  0, -1,  0,  0] [ 0,  0,  6]  1 */
    18552046, /* 73177 (1638) [ 0,  0,  1,  0,  1,  0,  1,  0,  0] [ 6,  6,  6]  1 */
    60305511, /* 73178 (1638) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 9,  3,  3] -1 */
    61713615, /* 73179 (1638) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 9,  9,  3] -1 */
    61835113, /* 73180 (1638) [ 0,  0,  1,  1,  0,  0,  0, -1,  0] [ 9,  9,  9] -1 */
    17022544, /* 73181 (1638) [ 1,  0,  0,  0,  0,  1,  0,  1,  0] [ 6,  0,  0]  1 */
     1544626, /* 73182 (1638) [ 0,  0, -1,  1,  0,  0,  0, -1,  0] [ 0,  6,  6]  1 */
     1424588, /* 73183 (1638) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 0,  6,  0]  1 */
        7636, /* 73184 (1638) [ 0, -1,  0,  0,  0, -1,  1,  0,  0] [ 0,  0,  0]  1 */
    44828689, /* 73185 (1638) [ 0,  0,  1,  0, -1,  0,  1,  0,  0] [ 3,  9,  9] -1 */
      128758, /* 73186 (1638) [ 0,  0,  1,  0,  1,  0,  1,  0,  0] [ 0,  0,  6]  1 */
       16320, /* 73187 (1638) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    18430960, /* 73188 (1638) [ 0, -1,  0,  0,  0,  1, -1,  0,  0] [ 6,  6,  0]  1 */
    18439608, /* 73189 (1638) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
    61718475, /* 73190 (1638) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 9,  9,  3] -1 */
    60296719, /* 73191 (1638) [ 0, -1,  0,  0,  0,  1,  1,  0,  0] [ 9,  3,  3] -1 */
     1429448, /* 73192 (1638) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 0,  6,  0]  1 */
    18426648, /* 73193 (1638) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
    44707711, /* 73194 (1638) [ 0, -1,  0,  0,  0, -1, -1,  0,  0] [ 3,  9,  3] -1 */
    43408705, /* 73195 (1638) [ 0, -1,  0,  0,  0,  1,  1,  0,  0] [ 3,  3,  9] -1 */
     1547338, /* 73196 (1638) [ 0,  1,  0,  0,  0,  1,  1,  0,  0] [ 0,  6,  6]  1 */
      134530, /* 73197 (1638) [ 1,  0,  0,  0,  0,  1,  0,  1,  0] [ 0,  0,  6]  1 */
     1420432, /* 73198 (1638) [-1,  0,  0,  0,  0, -1,  0,  1,  0] [ 0,  6,  0]  1 */
    44834569, /* 73199 (1638) [ 1,  0,  0,  0,  0, -1,  0,  1,  0] [ 3,  9,  9] -1 */
    17135026, /* 73200 (1638) [ 0,  0,  1,  1,  0,  0,  0,  1,  0] [ 6,  0,  6]  1 */
        8872, /* 73201 (1638) [ 0,  0, -1, -1,  0,  0,  0,  1,  0] [ 0,  0,  0]  1 */
    60297895, /* 73202 (1638) [ 0,  0, -1, -1,  0,  0,  0, -1,  0] [ 9,  3,  3] -1 */
     1433608, /* 73203 (1638) [ 1,  0,  0,  0,  0,  1,  0,  1,  0] [ 0,  6,  0]  1 */
    60415025, /* 73204 (1638) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 9,  3,  9] -1 */
    60414537, /* 73205 (1638) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 9,  3,  9] -1 */
     1544146, /* 73206 (1638) [ 0,  0, -1, -1,  0,  0,  0,  1,  0] [ 0,  6,  6]  1 */
     1420480, /* 73207 (1638) [-1,  0,  0,  0,  0,  1,  0, -1,  0] [ 0,  6,  0]  1 */
    17015152, /* 73208 (1638) [ 0,  0, -1,  0, -1,  0,  1,  0,  0] [ 6,  0,  0]  1 */
    44710903, /* 73209 (1638) [ 0,  0,  1,  1,  0,  0,  0, -1,  0] [ 3,  9,  3] -1 */
    43410373, /* 73210 (1638) [ 0,  0, -1,  1,  0,  0,  0,  1,  0] [ 3,  3,  9] -1 */
    43411825, /* 73211 (1638) [ 0,  0,  1,  1,  0,  0,  0, -1,  0] [ 3,  3,  9] -1 */
    61716847, /* 73212 (1638) [ 0,  0,  1,  0,  1,  0, -1,  0,  0] [ 9,  9,  3] -1 */
    60423553, /* 73213 (1638) [ 1,  0,  0,  0,  0,  1,  0, -1,  0] [ 9,  3,  9] -1 */
     1426360, /* 73214 (1638) [ 0,  0, -1,  0,  1,  0, -1,  0,  0] [ 0,  6,  0]  1 */
    44827213, /* 73215 (1638) [ 0,  0, -1,  0, -1,  0, -1,  0,  0] [ 3,  9,  9] -1 */
    61722631, /* 73216 (1638) [ 1,  0,  0,  0,  0,  1,  0, -1,  0] [ 9,  9,  3] -1 */
    60410437, /* 73217 (1638) [-1,  0,  0,  0,  0,  1,  0,  1,  0] [ 9,  3,  9] -1 */
    18550426, /* 73218 (1638) [ 0,  0, -1,  0, -1,  0,  1,  0,  0] [ 6,  6,  6]  1 */
    60410377, /* 73219 (1638) [-1,  0,  0,  0,  0, -1,  0, -1,  0] [ 9,  3,  9] -1 */
    61834633, /* 73220 (1638) [ 0,  0,  1, -1,  0,  0,  0,  1,  0] [ 9,  9,  9] -1 */
     1428960, /* 73221 (1638) [ 0,  1,  0, -1,  0,  0,  0,  0, -1] [ 0,  6,  0]  1 */
      128578, /* 73222 (1638) [ 0,  0,  1,  0, -1,  0, -1,  0,  0] [ 0,  0,  6]  1 */
    17022484, /* 73223 (1638) [ 1,  0,  0,  0,  0, -1,  0, -1,  0] [ 6,  0,  0]  1 */
    44712103, /* 73224 (1638) [ 0,  1,  0,  0,  0, -1,  1,  0,  0] [ 3,  9,  3] -1 */
    44829977, /* 73225 (1638) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 3,  9,  9] -1 */
    61833169, /* 73226 (1638) [ 0,  0, -1, -1,  0,  0,  0, -1,  0] [ 9,  9,  9] -1 */
       16484, /* 73227 (1639) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
        3360, /* 73228 (1639) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    34133626, /* 73229 (1639) [-1,  0,  0,  0,  0,  1,  0, -1,  0] [ 0,  0,  6] -1 */
    17140694, /* 73230 (1639) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
    18433612, /* 73231 (1639) [ 0,  0,  1, -1,  0,  0,  0, -1,  0] [ 6,  6,  0]  1 */
    43293559, /* 73232 (1639) [ 0,  0,  1,  0,  1,  0, -1,  0,  0] [ 3,  3,  3] -1 */
    26288815, /* 73233 (1639) [ 0,  1,  0,  0,  0, -1,  1,  0,  0] [ 9,  3,  3]  1 */
    26288851, /* 73234 (1639) [ 0,  1,  0,  0,  0,  1, -1,  0,  0] [ 9,  3,  3]  1 */
    17127410, /* 73235 (1639) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
    27815277, /* 73236 (1639) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 9,  9,  9]  1 */
    43299343, /* 73237 (1639) [ 1,  0,  0,  0,  0,  1,  0, -1,  0] [ 3,  3,  3] -1 */
    52556866, /* 73238 (1639) [-1,  0,  0,  0,  0, -1,  0,  1,  0] [ 6,  6,  6] -1 */
    10698199, /* 73239 (1639) [ 0,  0,  1, -1,  0,  0,  0,  1,  0] [ 3,  9,  3]  1 */
     1542946, /* 73240 (1639) [ 0, -1,  0,  0,  0,  1, -1,  0,  0] [ 0,  6,  6]  1 */
     1551594, /* 73241 (1639) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
     9399121, /* 73242 (1639) [ 0,  0,  1, -1,  0,  0,  0,  1,  0] [ 3,  3,  9]  1 */
    26293127, /* 73243 (1639) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 9,  3,  3]  1 */
        7672, /* 73244 (1639) [ 0, -1,  0,  0,  0,  1, -1,  0,  0] [ 0,  0,  0]  1 */
     1538634, /* 73245 (1639) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
    26293287, /* 73246 (1639) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 9,  3,  3]  1 */
    17136274, /* 73247 (1639) [ 0,  1,  0,  0,  0,  1,  1,  0,  0] [ 6,  0,  6]  1 */
    27822889, /* 73248 (1639) [ 0,  0,  1,  1,  0,  0,  0, -1,  0] [ 9,  9,  9]  1 */
    52564090, /* 73249 (1639) [ 0,  0,  1,  0, -1,  0, -1,  0,  0] [ 6,  6,  6] -1 */
    52565882, /* 73250 (1639) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    26287615, /* 73251 (1639) [ 0,  0,  1,  1,  0,  0,  0, -1,  0] [ 9,  3,  3]  1 */
    26284495, /* 73252 (1639) [ 0, -1,  0,  0,  0,  1,  1,  0,  0] [ 9,  3,  3]  1 */
    61715407, /* 73253 (1639) [ 0,  0, -1,  0,  1,  0,  1,  0,  0] [ 9,  9,  3] -1 */
    10695487, /* 73254 (1639) [ 0, -1,  0,  0,  0, -1, -1,  0,  0] [ 3,  9,  3]  1 */
    51028996, /* 73255 (1639) [ 0,  0,  1,  0,  1,  0,  1,  0,  0] [ 6,  0,  0] -1 */
    18430924, /* 73256 (1639) [ 0, -1,  0,  0,  0, -1,  1,  0,  0] [ 6,  6,  0]  1 */
    52570042, /* 73257 (1639) [ 1,  0,  0,  0,  0,  1,  0,  1,  0] [ 6,  6,  6] -1 */
    51034768, /* 73258 (1639) [ 1,  0,  0,  0,  0,  1,  0,  1,  0] [ 6,  0,  0] -1 */
    34138218, /* 73259 (1639) [ 0, -1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  6] -1 */
    17131846, /* 73260 (1639) [ 0, -1,  0,  0,  0, -1,  1,  0,  0] [ 6,  0,  6]  1 */
    34140982, /* 73261 (1639) [ 0,  0,  1,  0,  1,  0,  1,  0,  0] [ 0,  0,  6] -1 */
    43291939, /* 73262 (1639) [ 0,  0, -1,  0, -1,  0, -1,  0,  0] [ 3,  3,  3] -1 */
    10698679, /* 73263 (1639) [ 0,  0,  1,  1,  0,  0,  0, -1,  0] [ 3,  9,  3]  1 */
     9398149, /* 73264 (1639) [ 0,  0, -1,  1,  0,  0,  0,  1,  0] [ 3,  3,  9]  1 */
    17133082, /* 73265 (1639) [ 0,  0, -1, -1,  0,  0,  0,  1,  0] [ 6,  0,  6]  1 */
    18432640, /* 73266 (1639) [ 0,  0, -1,  1,  0,  0,  0, -1,  0] [ 6,  6,  0]  1 */
       11992, /* 73267 (1639) [ 0,  1,  0,  0,  0, -1, -1,  0,  0] [ 0,  0,  0]  1 */
    18435280, /* 73268 (1639) [ 0,  1,  0,  0,  0, -1, -1,  0,  0] [ 6,  6,  0]  1 */
    44830461, /* 73269 (1639) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 3,  9,  9] -1 */
    18426488, /* 73270 (1639) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
       10324, /* 73271 (1639) [ 0,  0,  1, -1,  0,  0,  0, -1,  0] [ 0,  0,  0]  1 */
    17140530, /* 73272 (1639) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  6]  1 */
    27822409, /* 73273 (1639) [ 0,  0,  1, -1,  0,  0,  0,  1,  0] [ 9,  9,  9]  1 */
    43299295, /* 73274 (1639) [ 1,  0,  0,  0,  0, -1,  0,  1,  0] [ 3,  3,  3] -1 */
    17127570, /* 73275 (1639) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6]  1 */
     1545598, /* 73276 (1639) [ 0,  0,  1, -1,  0,  0,  0, -1,  0] [ 0,  6,  6]  1 */
    35438440, /* 73277 (1639) [ 0,  0, -1,  0, -1,  0,  1,  0,  0] [ 0,  6,  0] -1 */
    43293415, /* 73278 (1639) [ 0,  0,  1,  0, -1,  0,  1,  0,  0] [ 3,  3,  3] -1 */
     9400801, /* 73279 (1639) [ 0,  1,  0,  0,  0, -1,  1,  0,  0] [ 3,  3,  9]  1 */
    10699879, /* 73280 (1639) [ 0,  1,  0,  0,  0, -1,  1,  0,  0] [ 3,  9,  3]  1 */
    27820945, /* 73281 (1639) [ 0,  0, -1, -1,  0,  0,  0, -1,  0] [ 9,  9,  9]  1 */
     9397657, /* 73282 (1639) [ 0,  0, -1, -1,  0,  0,  0, -1,  0] [ 3,  3,  9]  1 */
    10704191, /* 73283 (1639) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 3,  9,  3]  1 */
     9405113, /* 73284 (1639) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 3,  3,  9]  1 */
    10699915, /* 73285 (1639) [ 0,  1,  0,  0,  0,  1, -1,  0,  0] [ 3,  9,  3]  1 */
    43292119, /* 73286 (1639) [ 0,  0, -1,  0,  1,  0,  1,  0,  0] [ 3,  3,  3] -1 */
    61709455, /* 73287 (1639) [-1,  0,  0,  0,  0, -1,  0, -1,  0] [ 9,  9,  3] -1 */
    18439772, /* 73288 (1639) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    44828833, /* 73289 (1639) [ 0,  0,  1,  0,  1,  0, -1,  0,  0] [ 3,  9,  9] -1 */
    61714103, /* 73290 (1639) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 9,  9,  3] -1 */
    35441184, /* 73291 (1639) [ 0,  1,  0, -1,  0,  0,  0,  0, -1] [ 0,  6,  0] -1 */
    52569982, /* 73292 (1639) [ 1,  0,  0,  0,  0, -1,  0, -1,  0] [ 6,  6,  6] -1 */
    51028816, /* 73293 (1639) [ 0,  0,  1,  0, -1,  0, -1,  0,  0] [ 6,  0,  0] -1 */
    61709515, /* 73294 (1639) [-1,  0,  0,  0,  0,  1,  0,  1,  0] [ 9,  9,  3] -1 */
    10691067, /* 73295 (1639) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 3,  9,  3]  1 */
     1538474, /* 73296 (1639) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
    44834617, /* 73297 (1639) [ 1,  0,  0,  0,  0,  1,  0, -1,  0] [ 3,  9,  9] -1 */
    51034708, /* 73298 (1639) [ 1,  0,  0,  0,  0, -1,  0, -1,  0] [ 6,  0,  0] -1 */
        3200, /* 73299 (1639) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
     9396481, /* 73300 (1639) [ 0, -1,  0,  0,  0,  1,  1,  0,  0] [ 3,  3,  9]  1 */
    34142106, /* 73301 (1639) [ 0,  1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  6] -1 */
    44827393, /* 73302 (1639) [ 0,  0, -1,  0,  1,  0,  1,  0,  0] [ 3,  9,  9] -1 */
    52564270, /* 73303 (1639) [ 0,  0,  1,  0,  1,  0,  1,  0,  0] [ 6,  6,  6] -1 */
    34139506, /* 73304 (1639) [ 0,  0, -1,  0,  1,  0, -1,  0,  0] [ 0,  0,  6] -1 */
    18435352, /* 73305 (1639) [ 0,  1,  0,  0,  0,  1,  1,  0,  0] [ 6,  6,  0]  1 */
    26285671, /* 73306 (1639) [ 0,  0, -1, -1,  0,  0,  0, -1,  0] [ 9,  3,  3]  1 */
    35436812, /* 73307 (1639) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 0,  6,  0] -1 */
     9405273, /* 73308 (1639) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 3,  3,  9]  1 */
       10816, /* 73309 (1639) [ 0,  0,  1,  1,  0,  0,  0,  1,  0] [ 0,  0,  0]  1 */
    18434104, /* 73310 (1639) [ 0,  0,  1,  1,  0,  0,  0,  1,  0] [ 6,  6,  0]  1 */
    43294703, /* 73311 (1639) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 3,  3,  3] -1 */
    61715227, /* 73312 (1639) [ 0,  0, -1,  0, -1,  0, -1,  0,  0] [ 9,  9,  3] -1 */
    35441672, /* 73313 (1639) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 0,  6,  0] -1 */
       12064, /* 73314 (1639) [ 0,  1,  0,  0,  0,  1,  1,  0,  0] [ 0,  0,  0]  1 */
    10691231, /* 73315 (1639) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 3,  9,  3]  1 */
     9399601, /* 73316 (1639) [ 0,  0,  1,  1,  0,  0,  0, -1,  0] [ 3,  3,  9]  1 */
    51021640, /* 73317 (1639) [-1,  0,  0,  0,  0,  1,  0, -1,  0] [ 6,  0,  0] -1 */
    44825601, /* 73318 (1639) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 3,  9,  9] -1 */
     1551758, /* 73319 (1639) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
        9352, /* 73320 (1639) [ 0,  0, -1,  1,  0,  0,  0, -1,  0] [ 0,  0,  0]  1 */
    34146754, /* 73321 (1639) [ 1,  0,  0,  0,  0,  1,  0,  1,  0] [ 0,  0,  6] -1 */
    43290327, /* 73322 (1639) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 3,  3,  3] -1 */
     1542910, /* 73323 (1639) [ 0, -1,  0,  0,  0, -1,  1,  0,  0] [ 0,  6,  6]  1 */
    17134534, /* 73324 (1639) [ 0,  0,  1, -1,  0,  0,  0, -1,  0] [ 6,  0,  6]  1 */
    35432656, /* 73325 (1639) [-1,  0,  0,  0,  0, -1,  0,  1,  0] [ 0,  6,  0] -1 */
    61716703, /* 73326 (1639) [ 0,  0,  1,  0, -1,  0,  1,  0,  0] [ 9,  9,  3] -1 */
     1547266, /* 73327 (1639) [ 0,  1,  0,  0,  0, -1, -1,  0,  0] [ 0,  6,  6]  1 */
    60419397, /* 73328 (1639) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 9,  3,  9] -1 */
    35445832, /* 73329 (1639) [ 1,  0,  0,  0,  0,  1,  0,  1,  0] [ 0,  6,  0] -1 */
    35432704, /* 73330 (1639) [-1,  0,  0,  0,  0,  1,  0, -1,  0] [ 0,  6,  0] -1 */
    27828401, /* 73331 (1639) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 9,  9,  9]  1 */
    51027376, /* 73332 (1639) [ 0,  0, -1,  0, -1,  0,  1,  0,  0] [ 6,  0,  0] -1 */
    60423505, /* 73333 (1639) [ 1,  0,  0,  0,  0, -1,  0,  1,  0] [ 9,  3,  9] -1 */
    17131882, /* 73334 (1639) [ 0, -1,  0,  0,  0,  1, -1,  0,  0] [ 6,  0,  6]  1 */
    60417625, /* 73335 (1639) [ 0,  0,  1,  0, -1,  0,  1,  0,  0] [ 9,  3,  9] -1 */
    60416149, /* 73336 (1639) [ 0,  0, -1,  0, -1,  0, -1,  0,  0] [ 9,  3,  9] -1 */
    61722583, /* 73337 (1639) [ 1,  0,  0,  0,  0, -1,  0,  1,  0] [ 9,  9,  3] -1 */
     1546090, /* 73338 (1639) [ 0,  0,  1,  1,  0,  0,  0,  1,  0] [ 0,  6,  6]  1 */
    43286167, /* 73339 (1639) [-1,  0,  0,  0,  0, -1,  0, -1,  0] [ 3,  3,  3] -1 */
    43290815, /* 73340 (1639) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 3,  3,  3] -1 */
    44821441, /* 73341 (1639) [-1,  0,  0,  0,  0, -1,  0, -1,  0] [ 3,  9,  9] -1 */
    27828561, /* 73342 (1639) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 9,  9,  9]  1 */
    35438584, /* 73343 (1639) [ 0,  0, -1,  0,  1,  0, -1,  0,  0] [ 0,  6,  0] -1 */
     9400837, /* 73344 (1639) [ 0,  1,  0,  0,  0,  1, -1,  0,  0] [ 3,  3,  9]  1 */
    52562650, /* 73345 (1639) [ 0,  0, -1,  0, -1,  0,  1,  0,  0] [ 6,  6,  6] -1 */
    60416329, /* 73346 (1639) [ 0,  0, -1,  0,  1,  0,  1,  0,  0] [ 9,  3,  9] -1 */
    10695559, /* 73347 (1639) [ 0, -1,  0,  0,  0,  1,  1,  0,  0] [ 3,  9,  3]  1 */
    60417769, /* 73348 (1639) [ 0,  0,  1,  0,  1,  0, -1,  0,  0] [ 9,  3,  9] -1 */
    43295187, /* 73349 (1639) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 3,  3,  3] -1 */
    44826089, /* 73350 (1639) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 3,  9,  9] -1 */
    34140802, /* 73351 (1639) [ 0,  0,  1,  0, -1,  0, -1,  0,  0] [ 0,  0,  6] -1 */
    44821501, /* 73352 (1639) [-1,  0,  0,  0,  0,  1,  0,  1,  0] [ 3,  9,  9] -1 */
    43286227, /* 73353 (1639) [-1,  0,  0,  0,  0,  1,  0,  1,  0] [ 3,  3,  3] -1 */
    61717991, /* 73354 (1639) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 9,  9,  3] -1 */
    34139362, /* 73355 (1639) [ 0,  0, -1,  0, -1,  0,  1,  0,  0] [ 0,  0,  6] -1 */
    35437296, /* 73356 (1639) [ 0, -1,  0,  1,  0,  0,  0,  0, -1] [ 0,  6,  0] -1 */
    10696735, /* 73357 (1639) [ 0,  0, -1, -1,  0,  0,  0, -1,  0] [ 3,  9,  3]  1 */
    51025748, /* 73358 (1639) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 6,  0,  0] -1 */
    17133562, /* 73359 (1639) [ 0,  0, -1,  1,  0,  0,  0, -1,  0] [ 6,  0,  6]  1 */
    10704351, /* 73360 (1639) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 3,  9,  3]  1 */
    17136202, /* 73361 (1639) [ 0,  1,  0,  0,  0, -1, -1,  0,  0] [ 6,  0,  6]  1 */
    10697227, /* 73362 (1639) [ 0,  0, -1,  1,  0,  0,  0,  1,  0] [ 3,  9,  3]  1 */
    60418913, /* 73363 (1639) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 9,  3,  9] -1 */
    26280167, /* 73364 (1639) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 9,  3,  3]  1 */
    18432160, /* 73365 (1639) [ 0,  0, -1, -1,  0,  0,  0,  1,  0] [ 6,  6,  0]  1 */
    27819697, /* 73366 (1639) [ 0, -1,  0,  0,  0, -1, -1,  0,  0] [ 9,  9,  9]  1 */
     9396409, /* 73367 (1639) [ 0, -1,  0,  0,  0, -1, -1,  0,  0] [ 3,  3,  9]  1 */
    27815441, /* 73368 (1639) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 9,  9,  9]  1 */
    61713615, /* 73369 (1639) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 9,  9,  3] -1 */
    52556914, /* 73370 (1639) [-1,  0,  0,  0,  0,  1,  0, -1,  0] [ 6,  6,  6] -1 */
     1544626, /* 73371 (1639) [ 0,  0, -1,  1,  0,  0,  0, -1,  0] [ 0,  6,  6]  1 */
        7636, /* 73372 (1639) [ 0, -1,  0,  0,  0, -1,  1,  0,  0] [ 0,  0,  0]  1 */
    51021592, /* 73373 (1639) [-1,  0,  0,  0,  0, -1,  0,  1,  0] [ 6,  0,  0] -1 */
    44828689, /* 73374 (1639) [ 0,  0,  1,  0, -1,  0,  1,  0,  0] [ 3,  9,  9] -1 */
     9391989, /* 73375 (1639) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 3,  3,  9]  1 */
    35440060, /* 73376 (1639) [ 0,  0,  1,  0,  1,  0,  1,  0,  0] [ 0,  6,  0] -1 */
       16320, /* 73377 (1639) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    18430960, /* 73378 (1639) [ 0, -1,  0,  0,  0,  1, -1,  0,  0] [ 6,  6,  0]  1 */
    18439608, /* 73379 (1639) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
    61718475, /* 73380 (1639) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 9,  9,  3] -1 */
    26287135, /* 73381 (1639) [ 0,  0,  1, -1,  0,  0,  0,  1,  0] [ 9,  3,  3]  1 */
    27824089, /* 73382 (1639) [ 0,  1,  0,  0,  0, -1,  1,  0,  0] [ 9,  9,  9]  1 */
    18426648, /* 73383 (1639) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
     1547338, /* 73384 (1639) [ 0,  1,  0,  0,  0,  1,  1,  0,  0] [ 0,  6,  6]  1 */
    34137734, /* 73385 (1639) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    51030608, /* 73386 (1639) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 6,  0,  0] -1 */
    44834569, /* 73387 (1639) [ 1,  0,  0,  0,  0, -1,  0,  1,  0] [ 3,  9,  9] -1 */
    17135026, /* 73388 (1639) [ 0,  0,  1,  1,  0,  0,  0,  1,  0] [ 6,  0,  6]  1 */
        8872, /* 73389 (1639) [ 0,  0, -1, -1,  0,  0,  0,  1,  0] [ 0,  0,  0]  1 */
    60415025, /* 73390 (1639) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 9,  3,  9] -1 */
    60414537, /* 73391 (1639) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 9,  3,  9] -1 */
     1544146, /* 73392 (1639) [ 0,  0, -1, -1,  0,  0,  0,  1,  0] [ 0,  6,  6]  1 */
    52565394, /* 73393 (1639) [ 0,  1,  0, -1,  0,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    26284423, /* 73394 (1639) [ 0, -1,  0,  0,  0, -1, -1,  0,  0] [ 9,  3,  3]  1 */
    51030120, /* 73395 (1639) [ 0,  1,  0, -1,  0,  0,  0,  0, -1] [ 6,  0,  0] -1 */
    52562794, /* 73396 (1639) [ 0,  0, -1,  0,  1,  0, -1,  0,  0] [ 6,  6,  6] -1 */
    35439880, /* 73397 (1639) [ 0,  0,  1,  0, -1,  0, -1,  0,  0] [ 0,  6,  0] -1 */
    51027520, /* 73398 (1639) [ 0,  0, -1,  0,  1,  0, -1,  0,  0] [ 6,  0,  0] -1 */
    35445772, /* 73399 (1639) [ 1,  0,  0,  0,  0, -1,  0, -1,  0] [ 0,  6,  0] -1 */
    34133578, /* 73400 (1639) [-1,  0,  0,  0,  0, -1,  0,  1,  0] [ 0,  0,  6] -1 */
    34142594, /* 73401 (1639) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    27819769, /* 73402 (1639) [ 0, -1,  0,  0,  0,  1,  1,  0,  0] [ 9,  9,  9]  1 */
    26280003, /* 73403 (1639) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 9,  3,  3]  1 */
    61716847, /* 73404 (1639) [ 0,  0,  1,  0,  1,  0, -1,  0,  0] [ 9,  9,  3] -1 */
    51026232, /* 73405 (1639) [ 0, -1,  0,  1,  0,  0,  0,  0, -1] [ 6,  0,  0] -1 */
    34146694, /* 73406 (1639) [ 1,  0,  0,  0,  0, -1,  0, -1,  0] [ 0,  0,  6] -1 */
    60423553, /* 73407 (1639) [ 1,  0,  0,  0,  0,  1,  0, -1,  0] [ 9,  3,  9] -1 */
    52561506, /* 73408 (1639) [ 0, -1,  0,  1,  0,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    44827213, /* 73409 (1639) [ 0,  0, -1,  0, -1,  0, -1,  0,  0] [ 3,  9,  9] -1 */
    61722631, /* 73410 (1639) [ 1,  0,  0,  0,  0,  1,  0, -1,  0] [ 9,  9,  3] -1 */
    60410437, /* 73411 (1639) [-1,  0,  0,  0,  0,  1,  0,  1,  0] [ 9,  3,  9] -1 */
    60410377, /* 73412 (1639) [-1,  0,  0,  0,  0, -1,  0, -1,  0] [ 9,  3,  9] -1 */
     9392153, /* 73413 (1639) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 3,  3,  9]  1 */
    26286163, /* 73414 (1639) [ 0,  0, -1,  1,  0,  0,  0,  1,  0] [ 9,  3,  3]  1 */
    52561022, /* 73415 (1639) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    44829977, /* 73416 (1639) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 3,  9,  9] -1 */
    27821437, /* 73417 (1639) [ 0,  0, -1,  1,  0,  0,  0,  1,  0] [ 9,  9,  9]  1 */
    27824125, /* 73418 (1639) [ 0,  1,  0,  0,  0,  1, -1,  0,  0] [ 9,  9,  9]  1 */
       16484, /* 73419 (1640) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    61840785, /* 73420 (1640) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 9,  9,  9] -1 */
    43417337, /* 73421 (1640) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 3,  3,  9] -1 */
    44712139, /* 73422 (1640) [ 0,  1,  0,  0,  0,  1, -1,  0,  0] [ 3,  9,  3] -1 */
        3360, /* 73423 (1640) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    34133626, /* 73424 (1640) [-1,  0,  0,  0,  0,  1,  0, -1,  0] [ 0,  0,  6] -1 */
    17140694, /* 73425 (1640) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
    18433612, /* 73426 (1640) [ 0,  0,  1, -1,  0,  0,  0, -1,  0] [ 6,  6,  0]  1 */
    43413061, /* 73427 (1640) [ 0,  1,  0,  0,  0,  1, -1,  0,  0] [ 3,  3,  9] -1 */
    17127410, /* 73428 (1640) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
    44707783, /* 73429 (1640) [ 0, -1,  0,  0,  0,  1,  1,  0,  0] [ 3,  9,  3] -1 */
     9282479, /* 73430 (1640) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 3,  3,  3]  1 */
    52556866, /* 73431 (1640) [-1,  0,  0,  0,  0, -1,  0,  1,  0] [ 6,  6,  6] -1 */
    44703291, /* 73432 (1640) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 3,  9,  3] -1 */
     1542946, /* 73433 (1640) [ 0, -1,  0,  0,  0,  1, -1,  0,  0] [ 0,  6,  6]  1 */
     1551594, /* 73434 (1640) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
        7672, /* 73435 (1640) [ 0, -1,  0,  0,  0,  1, -1,  0,  0] [ 0,  0,  0]  1 */
     1538634, /* 73436 (1640) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
    27701391, /* 73437 (1640) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 9,  9,  3]  1 */
    17136274, /* 73438 (1640) [ 0,  1,  0,  0,  0,  1,  1,  0,  0] [ 6,  0,  6]  1 */
     9278103, /* 73439 (1640) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 3,  3,  3]  1 */
    52564090, /* 73440 (1640) [ 0,  0,  1,  0, -1,  0, -1,  0,  0] [ 6,  6,  6] -1 */
    26407173, /* 73441 (1640) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 9,  3,  9]  1 */
    52565882, /* 73442 (1640) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    43417497, /* 73443 (1640) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 3,  3,  9] -1 */
    27706251, /* 73444 (1640) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 9,  9,  3]  1 */
    51028996, /* 73445 (1640) [ 0,  0,  1,  0,  1,  0,  1,  0,  0] [ 6,  0,  0] -1 */
    60292391, /* 73446 (1640) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 9,  3,  3] -1 */
    44703455, /* 73447 (1640) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 3,  9,  3] -1 */
    26403925, /* 73448 (1640) [ 0,  0, -1,  0, -1,  0, -1,  0,  0] [ 9,  3,  9]  1 */
    18430924, /* 73449 (1640) [ 0, -1,  0,  0,  0, -1,  1,  0,  0] [ 6,  6,  0]  1 */
    27710359, /* 73450 (1640) [ 1,  0,  0,  0,  0, -1,  0,  1,  0] [ 9,  9,  3]  1 */
    44710903, /* 73451 (1640) [ 0,  0,  1,  1,  0,  0,  0, -1,  0] [ 3,  9,  3] -1 */
    52570042, /* 73452 (1640) [ 1,  0,  0,  0,  0,  1,  0,  1,  0] [ 6,  6,  6] -1 */
    51034768, /* 73453 (1640) [ 1,  0,  0,  0,  0,  1,  0,  1,  0] [ 6,  0,  0] -1 */
     9278591, /* 73454 (1640) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 3,  3,  3]  1 */
    10809217, /* 73455 (1640) [-1,  0,  0,  0,  0, -1,  0, -1,  0] [ 3,  9,  9]  1 */
    34138218, /* 73456 (1640) [ 0, -1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  6] -1 */
    17131846, /* 73457 (1640) [ 0, -1,  0,  0,  0, -1,  1,  0,  0] [ 6,  0,  6]  1 */
    34140982, /* 73458 (1640) [ 0,  0,  1,  0,  1,  0,  1,  0,  0] [ 0,  0,  6] -1 */
    61836313, /* 73459 (1640) [ 0,  1,  0,  0,  0, -1,  1,  0,  0] [ 9,  9,  9] -1 */
    26404105, /* 73460 (1640) [ 0,  0, -1,  0,  1,  0,  1,  0,  0] [ 9,  3,  9]  1 */
    17133082, /* 73461 (1640) [ 0,  0, -1, -1,  0,  0,  0,  1,  0] [ 6,  0,  6]  1 */
    26405545, /* 73462 (1640) [ 0,  0,  1,  0,  1,  0, -1,  0,  0] [ 9,  3,  9]  1 */
    61840625, /* 73463 (1640) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 9,  9,  9] -1 */
     9282963, /* 73464 (1640) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 3,  3,  3]  1 */
    18432640, /* 73465 (1640) [ 0,  0, -1,  1,  0,  0,  0, -1,  0] [ 6,  6,  0]  1 */
       11992, /* 73466 (1640) [ 0,  1,  0,  0,  0, -1, -1,  0,  0] [ 0,  0,  0]  1 */
    18435280, /* 73467 (1640) [ 0,  1,  0,  0,  0, -1, -1,  0,  0] [ 6,  6,  0]  1 */
    26411329, /* 73468 (1640) [ 1,  0,  0,  0,  0,  1,  0, -1,  0] [ 9,  3,  9]  1 */
     9274003, /* 73469 (1640) [-1,  0,  0,  0,  0,  1,  0,  1,  0] [ 3,  3,  3]  1 */
    27705767, /* 73470 (1640) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 9,  9,  3]  1 */
    18426488, /* 73471 (1640) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    26398153, /* 73472 (1640) [-1,  0,  0,  0,  0, -1,  0, -1,  0] [ 9,  3,  9]  1 */
       10324, /* 73473 (1640) [ 0,  0,  1, -1,  0,  0,  0, -1,  0] [ 0,  0,  0]  1 */
    17140530, /* 73474 (1640) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  6]  1 */
    17127570, /* 73475 (1640) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6]  1 */
     1545598, /* 73476 (1640) [ 0,  0,  1, -1,  0,  0,  0, -1,  0] [ 0,  6,  6]  1 */
    35438440, /* 73477 (1640) [ 0,  0, -1,  0, -1,  0,  1,  0,  0] [ 0,  6,  0] -1 */
    61831993, /* 73478 (1640) [ 0, -1,  0,  0,  0,  1,  1,  0,  0] [ 9,  9,  9] -1 */
    10817753, /* 73479 (1640) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 3,  9,  9]  1 */
    26406689, /* 73480 (1640) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 9,  3,  9]  1 */
     9281335, /* 73481 (1640) [ 0,  0,  1,  0,  1,  0, -1,  0,  0] [ 3,  3,  3]  1 */
    18439772, /* 73482 (1640) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    10816465, /* 73483 (1640) [ 0,  0,  1,  0, -1,  0,  1,  0,  0] [ 3,  9,  9]  1 */
     9287119, /* 73484 (1640) [ 1,  0,  0,  0,  0,  1,  0, -1,  0] [ 3,  3,  3]  1 */
    35441184, /* 73485 (1640) [ 0,  1,  0, -1,  0,  0,  0,  0, -1] [ 0,  6,  0] -1 */
    52569982, /* 73486 (1640) [ 1,  0,  0,  0,  0, -1,  0, -1,  0] [ 6,  6,  6] -1 */
    44708959, /* 73487 (1640) [ 0,  0, -1, -1,  0,  0,  0, -1,  0] [ 3,  9,  3] -1 */
    51028816, /* 73488 (1640) [ 0,  0,  1,  0, -1,  0, -1,  0,  0] [ 6,  0,  0] -1 */
     1538474, /* 73489 (1640) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
    44716575, /* 73490 (1640) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 3,  9,  3] -1 */
    51034708, /* 73491 (1640) [ 1,  0,  0,  0,  0, -1,  0, -1,  0] [ 6,  0,  0] -1 */
    60298387, /* 73492 (1640) [ 0,  0, -1,  1,  0,  0,  0,  1,  0] [ 9,  3,  3] -1 */
        3200, /* 73493 (1640) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    44709451, /* 73494 (1640) [ 0,  0, -1,  1,  0,  0,  0,  1,  0] [ 3,  9,  3] -1 */
    34142106, /* 73495 (1640) [ 0,  1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  6] -1 */
    61831921, /* 73496 (1640) [ 0, -1,  0,  0,  0, -1, -1,  0,  0] [ 9,  9,  9] -1 */
    34139506, /* 73497 (1640) [ 0,  0, -1,  0,  1,  0, -1,  0,  0] [ 0,  0,  6] -1 */
    61827665, /* 73498 (1640) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 9,  9,  9] -1 */
    43408633, /* 73499 (1640) [ 0, -1,  0,  0,  0, -1, -1,  0,  0] [ 3,  3,  9] -1 */
    52564270, /* 73500 (1640) [ 0,  0,  1,  0,  1,  0,  1,  0,  0] [ 6,  6,  6] -1 */
    10822345, /* 73501 (1640) [ 1,  0,  0,  0,  0, -1,  0,  1,  0] [ 3,  9,  9]  1 */
    18435352, /* 73502 (1640) [ 0,  1,  0,  0,  0,  1,  1,  0,  0] [ 6,  6,  0]  1 */
    60301039, /* 73503 (1640) [ 0,  1,  0,  0,  0, -1,  1,  0,  0] [ 9,  3,  3] -1 */
    35436812, /* 73504 (1640) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 0,  6,  0] -1 */
    60301075, /* 73505 (1640) [ 0,  1,  0,  0,  0,  1, -1,  0,  0] [ 9,  3,  3] -1 */
    26402801, /* 73506 (1640) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 9,  3,  9]  1 */
    26402313, /* 73507 (1640) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 9,  3,  9]  1 */
       10816, /* 73508 (1640) [ 0,  0,  1,  1,  0,  0,  0,  1,  0] [ 0,  0,  0]  1 */
    61827501, /* 73509 (1640) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 9,  9,  9] -1 */
    18434104, /* 73510 (1640) [ 0,  0,  1,  1,  0,  0,  0,  1,  0] [ 6,  6,  0]  1 */
    43404213, /* 73511 (1640) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 3,  3,  9] -1 */
    44710423, /* 73512 (1640) [ 0,  0,  1, -1,  0,  0,  0,  1,  0] [ 3,  9,  3] -1 */
    60299359, /* 73513 (1640) [ 0,  0,  1, -1,  0,  0,  0,  1,  0] [ 9,  3,  3] -1 */
    35441672, /* 73514 (1640) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 0,  6,  0] -1 */
       12064, /* 73515 (1640) [ 0,  1,  0,  0,  0,  1,  1,  0,  0] [ 0,  0,  0]  1 */
    51021640, /* 73516 (1640) [-1,  0,  0,  0,  0,  1,  0, -1,  0] [ 6,  0,  0] -1 */
     1551758, /* 73517 (1640) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
        9352, /* 73518 (1640) [ 0,  0, -1,  1,  0,  0,  0, -1,  0] [ 0,  0,  0]  1 */
    34146754, /* 73519 (1640) [ 1,  0,  0,  0,  0,  1,  0,  1,  0] [ 0,  0,  6] -1 */
     1542910, /* 73520 (1640) [ 0, -1,  0,  0,  0, -1,  1,  0,  0] [ 0,  6,  6]  1 */
    27704623, /* 73521 (1640) [ 0,  0,  1,  0,  1,  0, -1,  0,  0] [ 9,  9,  3]  1 */
    17134534, /* 73522 (1640) [ 0,  0,  1, -1,  0,  0,  0, -1,  0] [ 6,  0,  6]  1 */
    35432656, /* 73523 (1640) [-1,  0,  0,  0,  0, -1,  0,  1,  0] [ 0,  6,  0] -1 */
     1547266, /* 73524 (1640) [ 0,  1,  0,  0,  0, -1, -1,  0,  0] [ 0,  6,  6]  1 */
    10814989, /* 73525 (1640) [ 0,  0, -1,  0, -1,  0, -1,  0,  0] [ 3,  9,  9]  1 */
    27710407, /* 73526 (1640) [ 1,  0,  0,  0,  0,  1,  0, -1,  0] [ 9,  9,  3]  1 */
    26398213, /* 73527 (1640) [-1,  0,  0,  0,  0,  1,  0,  1,  0] [ 9,  3,  9]  1 */
    35445832, /* 73528 (1640) [ 1,  0,  0,  0,  0,  1,  0,  1,  0] [ 0,  6,  0] -1 */
    60299839, /* 73529 (1640) [ 0,  0,  1,  1,  0,  0,  0, -1,  0] [ 9,  3,  3] -1 */
    35432704, /* 73530 (1640) [-1,  0,  0,  0,  0,  1,  0, -1,  0] [ 0,  6,  0] -1 */
    60296647, /* 73531 (1640) [ 0, -1,  0,  0,  0, -1, -1,  0,  0] [ 9,  3,  3] -1 */
    51027376, /* 73532 (1640) [ 0,  0, -1,  0, -1,  0,  1,  0,  0] [ 6,  0,  0] -1 */
    17131882, /* 73533 (1640) [ 0, -1,  0,  0,  0,  1, -1,  0,  0] [ 6,  0,  6]  1 */
     1546090, /* 73534 (1640) [ 0,  0,  1,  1,  0,  0,  0,  1,  0] [ 0,  6,  6]  1 */
    60292227, /* 73535 (1640) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 9,  3,  3] -1 */
    35438584, /* 73536 (1640) [ 0,  0, -1,  0,  1,  0, -1,  0,  0] [ 0,  6,  0] -1 */
     9287071, /* 73537 (1640) [ 1,  0,  0,  0,  0, -1,  0,  1,  0] [ 3,  3,  3]  1 */
    52562650, /* 73538 (1640) [ 0,  0, -1,  0, -1,  0,  1,  0,  0] [ 6,  6,  6] -1 */
    43404377, /* 73539 (1640) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 3,  3,  9] -1 */
    34140802, /* 73540 (1640) [ 0,  0,  1,  0, -1,  0, -1,  0,  0] [ 0,  0,  6] -1 */
    61833661, /* 73541 (1640) [ 0,  0, -1,  1,  0,  0,  0,  1,  0] [ 9,  9,  9] -1 */
    61836349, /* 73542 (1640) [ 0,  1,  0,  0,  0,  1, -1,  0,  0] [ 9,  9,  9] -1 */
     9279895, /* 73543 (1640) [ 0,  0, -1,  0,  1,  0,  1,  0,  0] [ 3,  3,  3]  1 */
    34139362, /* 73544 (1640) [ 0,  0, -1,  0, -1,  0,  1,  0,  0] [ 0,  0,  6] -1 */
    35437296, /* 73545 (1640) [ 0, -1,  0,  1,  0,  0,  0,  0, -1] [ 0,  6,  0] -1 */
    43413025, /* 73546 (1640) [ 0,  1,  0,  0,  0, -1,  1,  0,  0] [ 3,  3,  9] -1 */
    27697291, /* 73547 (1640) [-1,  0,  0,  0,  0,  1,  0,  1,  0] [ 9,  9,  3]  1 */
    51025748, /* 73548 (1640) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 6,  0,  0] -1 */
    17133562, /* 73549 (1640) [ 0,  0, -1,  1,  0,  0,  0, -1,  0] [ 6,  0,  6]  1 */
    27703183, /* 73550 (1640) [ 0,  0, -1,  0,  1,  0,  1,  0,  0] [ 9,  9,  3]  1 */
    17136202, /* 73551 (1640) [ 0,  1,  0,  0,  0, -1, -1,  0,  0] [ 6,  0,  6]  1 */
    43409881, /* 73552 (1640) [ 0,  0, -1, -1,  0,  0,  0, -1,  0] [ 3,  3,  9] -1 */
    10815169, /* 73553 (1640) [ 0,  0, -1,  0,  1,  0,  1,  0,  0] [ 3,  9,  9]  1 */
    44716415, /* 73554 (1640) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 3,  9,  3] -1 */
    18432160, /* 73555 (1640) [ 0,  0, -1, -1,  0,  0,  0,  1,  0] [ 6,  6,  0]  1 */
    43411345, /* 73556 (1640) [ 0,  0,  1, -1,  0,  0,  0,  1,  0] [ 3,  3,  9] -1 */
    60305351, /* 73557 (1640) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 9,  3,  3] -1 */
    60305511, /* 73558 (1640) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 9,  3,  3] -1 */
    52556914, /* 73559 (1640) [-1,  0,  0,  0,  0,  1,  0, -1,  0] [ 6,  6,  6] -1 */
    61835113, /* 73560 (1640) [ 0,  0,  1,  1,  0,  0,  0, -1,  0] [ 9,  9,  9] -1 */
     1544626, /* 73561 (1640) [ 0,  0, -1,  1,  0,  0,  0, -1,  0] [ 0,  6,  6]  1 */
        7636, /* 73562 (1640) [ 0, -1,  0,  0,  0, -1,  1,  0,  0] [ 0,  0,  0]  1 */
    51021592, /* 73563 (1640) [-1,  0,  0,  0,  0, -1,  0,  1,  0] [ 6,  0,  0] -1 */
    35440060, /* 73564 (1640) [ 0,  0,  1,  0,  1,  0,  1,  0,  0] [ 0,  6,  0] -1 */
       16320, /* 73565 (1640) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    18430960, /* 73566 (1640) [ 0, -1,  0,  0,  0,  1, -1,  0,  0] [ 6,  6,  0]  1 */
    18439608, /* 73567 (1640) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
     9279715, /* 73568 (1640) [ 0,  0, -1,  0, -1,  0, -1,  0,  0] [ 3,  3,  3]  1 */
    27703003, /* 73569 (1640) [ 0,  0, -1,  0, -1,  0, -1,  0,  0] [ 9,  9,  3]  1 */
    60296719, /* 73570 (1640) [ 0, -1,  0,  0,  0,  1,  1,  0,  0] [ 9,  3,  3] -1 */
    18426648, /* 73571 (1640) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
    44707711, /* 73572 (1640) [ 0, -1,  0,  0,  0, -1, -1,  0,  0] [ 3,  9,  3] -1 */
    43408705, /* 73573 (1640) [ 0, -1,  0,  0,  0,  1,  1,  0,  0] [ 3,  3,  9] -1 */
    10813377, /* 73574 (1640) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 3,  9,  9]  1 */
     1547338, /* 73575 (1640) [ 0,  1,  0,  0,  0,  1,  1,  0,  0] [ 0,  6,  6]  1 */
    34137734, /* 73576 (1640) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    27704479, /* 73577 (1640) [ 0,  0,  1,  0, -1,  0,  1,  0,  0] [ 9,  9,  3]  1 */
    51030608, /* 73578 (1640) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 6,  0,  0] -1 */
    17135026, /* 73579 (1640) [ 0,  0,  1,  1,  0,  0,  0,  1,  0] [ 6,  0,  6]  1 */
    10818237, /* 73580 (1640) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 3,  9,  9]  1 */
        8872, /* 73581 (1640) [ 0,  0, -1, -1,  0,  0,  0,  1,  0] [ 0,  0,  0]  1 */
    60297895, /* 73582 (1640) [ 0,  0, -1, -1,  0,  0,  0, -1,  0] [ 9,  3,  3] -1 */
     1544146, /* 73583 (1640) [ 0,  0, -1, -1,  0,  0,  0,  1,  0] [ 0,  6,  6]  1 */
    52565394, /* 73584 (1640) [ 0,  1,  0, -1,  0,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    51030120, /* 73585 (1640) [ 0,  1,  0, -1,  0,  0,  0,  0, -1] [ 6,  0,  0] -1 */
    52562794, /* 73586 (1640) [ 0,  0, -1,  0,  1,  0, -1,  0,  0] [ 6,  6,  6] -1 */
    35439880, /* 73587 (1640) [ 0,  0,  1,  0, -1,  0, -1,  0,  0] [ 0,  6,  0] -1 */
     9281191, /* 73588 (1640) [ 0,  0,  1,  0, -1,  0,  1,  0,  0] [ 3,  3,  3]  1 */
    51027520, /* 73589 (1640) [ 0,  0, -1,  0,  1,  0, -1,  0,  0] [ 6,  0,  0] -1 */
    43410373, /* 73590 (1640) [ 0,  0, -1,  1,  0,  0,  0,  1,  0] [ 3,  3,  9] -1 */
    35445772, /* 73591 (1640) [ 1,  0,  0,  0,  0, -1,  0, -1,  0] [ 0,  6,  0] -1 */
    26411281, /* 73592 (1640) [ 1,  0,  0,  0,  0, -1,  0,  1,  0] [ 9,  3,  9]  1 */
    26405401, /* 73593 (1640) [ 0,  0,  1,  0, -1,  0,  1,  0,  0] [ 9,  3,  9]  1 */
    34142594, /* 73594 (1640) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    43411825, /* 73595 (1640) [ 0,  0,  1,  1,  0,  0,  0, -1,  0] [ 3,  3,  9] -1 */
    34133578, /* 73596 (1640) [-1,  0,  0,  0,  0, -1,  0,  1,  0] [ 0,  0,  6] -1 */
     9273943, /* 73597 (1640) [-1,  0,  0,  0,  0, -1,  0, -1,  0] [ 3,  3,  3]  1 */
    51026232, /* 73598 (1640) [ 0, -1,  0,  1,  0,  0,  0,  0, -1] [ 6,  0,  0] -1 */
    34146694, /* 73599 (1640) [ 1,  0,  0,  0,  0, -1,  0, -1,  0] [ 0,  0,  6] -1 */
    52561506, /* 73600 (1640) [ 0, -1,  0,  1,  0,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    27697231, /* 73601 (1640) [-1,  0,  0,  0,  0, -1,  0, -1,  0] [ 9,  9,  3]  1 */
    61834633, /* 73602 (1640) [ 0,  0,  1, -1,  0,  0,  0,  1,  0] [ 9,  9,  9] -1 */
    10816609, /* 73603 (1640) [ 0,  0,  1,  0,  1,  0, -1,  0,  0] [ 3,  9,  9]  1 */
    27701879, /* 73604 (1640) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 9,  9,  3]  1 */
    10813865, /* 73605 (1640) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 3,  9,  9]  1 */
    44712103, /* 73606 (1640) [ 0,  1,  0,  0,  0, -1,  1,  0,  0] [ 3,  9,  3] -1 */
    10822393, /* 73607 (1640) [ 1,  0,  0,  0,  0,  1,  0, -1,  0] [ 3,  9,  9]  1 */
    10809277, /* 73608 (1640) [-1,  0,  0,  0,  0,  1,  0,  1,  0] [ 3,  9,  9]  1 */
    52561022, /* 73609 (1640) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    61833169, /* 73610 (1640) [ 0,  0, -1, -1,  0,  0,  0, -1,  0] [ 9,  9,  9] -1 */
       16484, /* 73611 (1641) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
        3360, /* 73612 (1641) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    17140694, /* 73613 (1641) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
     1425072, /* 73614 (1641) [ 0, -1,  0,  1,  0,  0,  0,  0, -1] [ 0,  6,  0]  1 */
    26288815, /* 73615 (1641) [ 0,  1,  0,  0,  0, -1,  1,  0,  0] [ 9,  3,  3]  1 */
    26288851, /* 73616 (1641) [ 0,  1,  0,  0,  0,  1, -1,  0,  0] [ 9,  3,  3]  1 */
    43290607, /* 73617 (1641) [ 0, -1,  0,  0,  0,  1,  1,  0,  0] [ 3,  3,  3] -1 */
    27815277, /* 73618 (1641) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 9,  9,  9]  1 */
    34133522, /* 73619 (1641) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
     9399121, /* 73620 (1641) [ 0,  0,  1, -1,  0,  0,  0,  1,  0] [ 3,  3,  9]  1 */
    44716471, /* 73621 (1641) [ 1,  0,  0,  0,  0, -1,  0,  1,  0] [ 3,  9,  3] -1 */
    17009416, /* 73622 (1641) [-1,  0,  0,  0,  0,  1,  0, -1,  0] [ 6,  0,  0]  1 */
    17136274, /* 73623 (1641) [ 0,  1,  0,  0,  0,  1,  1,  0,  0] [ 6,  0,  6]  1 */
    52447296, /* 73624 (1641) [ 0,  1,  0, -1,  0,  0,  0,  0, -1] [ 6,  6,  0] -1 */
    17009368, /* 73625 (1641) [-1,  0,  0,  0,  0, -1,  0,  1,  0] [ 6,  0,  0]  1 */
    26407173, /* 73626 (1641) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 9,  3,  9]  1 */
    34024496, /* 73627 (1641) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    52447784, /* 73628 (1641) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 6,  6,  0] -1 */
    61827613, /* 73629 (1641) [-1,  0,  0,  0,  0,  1,  0,  1,  0] [ 9,  9,  9] -1 */
    17018384, /* 73630 (1641) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 6,  0,  0]  1 */
    61716535, /* 73631 (1641) [ 0,  0,  1, -1,  0,  0,  0,  1,  0] [ 9,  9,  3] -1 */
    26405545, /* 73632 (1641) [ 0,  0,  1,  0,  1,  0, -1,  0,  0] [ 9,  3,  9]  1 */
    43412801, /* 73633 (1641) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 3,  3,  9] -1 */
    34015528, /* 73634 (1641) [-1,  0,  0,  0,  0,  1,  0, -1,  0] [ 0,  0,  0] -1 */
    34139194, /* 73635 (1641) [ 0,  0, -1, -1,  0,  0,  0,  1,  0] [ 0,  0,  6] -1 */
     1545598, /* 73636 (1641) [ 0,  0,  1, -1,  0,  0,  0, -1,  0] [ 0,  6,  6]  1 */
    10699879, /* 73637 (1641) [ 0,  1,  0,  0,  0, -1,  1,  0,  0] [ 3,  9,  3]  1 */
    51145474, /* 73638 (1641) [ 0,  0, -1,  0, -1,  0,  1,  0,  0] [ 6,  0,  6] -1 */
    34146806, /* 73639 (1641) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    43408913, /* 73640 (1641) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 3,  3,  9] -1 */
    18439772, /* 73641 (1641) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    10816465, /* 73642 (1641) [ 0,  0,  1,  0, -1,  0,  1,  0,  0] [ 3,  9,  9]  1 */
     9287119, /* 73643 (1641) [ 1,  0,  0,  0,  0,  1,  0, -1,  0] [ 3,  3,  3]  1 */
    51152806, /* 73644 (1641) [ 1,  0,  0,  0,  0, -1,  0, -1,  0] [ 6,  0,  6] -1 */
     1538474, /* 73645 (1641) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
     9396481, /* 73646 (1641) [ 0, -1,  0,  0,  0,  1,  1,  0,  0] [ 3,  3,  9]  1 */
    51028660, /* 73647 (1641) [ 0,  0,  1, -1,  0,  0,  0, -1,  0] [ 6,  0,  0] -1 */
    35432600, /* 73648 (1641) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  0] -1 */
    44825809, /* 73649 (1641) [ 0, -1,  0,  0,  0, -1, -1,  0,  0] [ 3,  9,  9] -1 */
    10822345, /* 73650 (1641) [ 1,  0,  0,  0,  0, -1,  0,  1,  0] [ 3,  9,  9]  1 */
    18435352, /* 73651 (1641) [ 0,  1,  0,  0,  0,  1,  1,  0,  0] [ 6,  6,  0]  1 */
    17015296, /* 73652 (1641) [ 0,  0, -1,  0,  1,  0, -1,  0,  0] [ 6,  0,  0]  1 */
      130370, /* 73653 (1641) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 0,  0,  6]  1 */
        9352, /* 73654 (1641) [ 0,  0, -1,  1,  0,  0,  0, -1,  0] [ 0,  0,  0]  1 */
    18557818, /* 73655 (1641) [ 1,  0,  0,  0,  0,  1,  0,  1,  0] [ 6,  6,  6]  1 */
     1542910, /* 73656 (1641) [ 0, -1,  0,  0,  0, -1,  1,  0,  0] [ 0,  6,  6]  1 */
    43408425, /* 73657 (1641) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 3,  3,  9] -1 */
    61713895, /* 73658 (1641) [ 0, -1,  0,  0,  0,  1,  1,  0,  0] [ 9,  9,  3] -1 */
    27828401, /* 73659 (1641) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 9,  9,  9]  1 */
    60298051, /* 73660 (1641) [ 0,  0, -1,  0, -1,  0, -1,  0,  0] [ 9,  3,  3] -1 */
    60414817, /* 73661 (1641) [ 0, -1,  0,  0,  0,  1,  1,  0,  0] [ 9,  3,  9] -1 */
    27828561, /* 73662 (1641) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 9,  9,  9]  1 */
     9400837, /* 73663 (1641) [ 0,  1,  0,  0,  0,  1, -1,  0,  0] [ 3,  3,  9]  1 */
     9287071, /* 73664 (1641) [ 1,  0,  0,  0,  0, -1,  0,  1,  0] [ 3,  3,  3]  1 */
    52565602, /* 73665 (1641) [ 0,  1,  0,  0,  0, -1, -1,  0,  0] [ 6,  6,  6] -1 */
    34021408, /* 73666 (1641) [ 0,  0, -1,  0,  1,  0, -1,  0,  0] [ 0,  0,  0] -1 */
    34021264, /* 73667 (1641) [ 0,  0, -1,  0, -1,  0,  1,  0,  0] [ 0,  0,  0] -1 */
    18557758, /* 73668 (1641) [ 1,  0,  0,  0,  0, -1,  0, -1,  0] [ 6,  6,  6]  1 */
    44834513, /* 73669 (1641) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 3,  9,  9] -1 */
    27703183, /* 73670 (1641) [ 0,  0, -1,  0,  1,  0,  1,  0,  0] [ 9,  9,  3]  1 */
      129882, /* 73671 (1641) [ 0,  1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  6]  1 */
    27819697, /* 73672 (1641) [ 0, -1,  0,  0,  0, -1, -1,  0,  0] [ 9,  9,  9]  1 */
     9396409, /* 73673 (1641) [ 0, -1,  0,  0,  0, -1, -1,  0,  0] [ 3,  3,  9]  1 */
    26287135, /* 73674 (1641) [ 0,  0,  1, -1,  0,  0,  0,  1,  0] [ 9,  3,  3]  1 */
    52561246, /* 73675 (1641) [ 0, -1,  0,  0,  0, -1,  1,  0,  0] [ 6,  6,  6] -1 */
    44709115, /* 73676 (1641) [ 0,  0, -1,  0, -1,  0, -1,  0,  0] [ 3,  9,  3] -1 */
     1433608, /* 73677 (1641) [ 1,  0,  0,  0,  0,  1,  0,  1,  0] [ 0,  6,  0]  1 */
     1420480, /* 73678 (1641) [-1,  0,  0,  0,  0,  1,  0, -1,  0] [ 0,  6,  0]  1 */
     1544146, /* 73679 (1641) [ 0,  0, -1, -1,  0,  0,  0,  1,  0] [ 0,  6,  6]  1 */
    35563870, /* 73680 (1641) [ 1,  0,  0,  0,  0, -1,  0, -1,  0] [ 0,  6,  6] -1 */
    44703403, /* 73681 (1641) [-1,  0,  0,  0,  0,  1,  0,  1,  0] [ 3,  9,  3] -1 */
    27819769, /* 73682 (1641) [ 0, -1,  0,  0,  0,  1,  1,  0,  0] [ 9,  9,  9]  1 */
    26280003, /* 73683 (1641) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 9,  3,  3]  1 */
     9273943, /* 73684 (1641) [-1,  0,  0,  0,  0, -1,  0, -1,  0] [ 3,  3,  3]  1 */
    60410489, /* 73685 (1641) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 9,  3,  9] -1 */
    44821553, /* 73686 (1641) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 3,  9,  9] -1 */
    18550426, /* 73687 (1641) [ 0,  0, -1,  0, -1,  0,  1,  0,  0] [ 6,  6,  6]  1 */
    60300815, /* 73688 (1641) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 9,  3,  3] -1 */
     9392153, /* 73689 (1641) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 3,  3,  9]  1 */
    43293247, /* 73690 (1641) [ 0,  0,  1, -1,  0,  0,  0,  1,  0] [ 3,  3,  3] -1 */
    10813865, /* 73691 (1641) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 3,  9,  9]  1 */
    18433612, /* 73692 (1641) [ 0,  0,  1, -1,  0,  0,  0, -1,  0] [ 6,  6,  0]  1 */
    17127410, /* 73693 (1641) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
    51034820, /* 73694 (1641) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  0] -1 */
    27701391, /* 73695 (1641) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 9,  9,  3]  1 */
     9278103, /* 73696 (1641) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 3,  3,  3]  1 */
    43410217, /* 73697 (1641) [ 0,  0, -1,  0,  1,  0,  1,  0,  0] [ 3,  3,  9] -1 */
    52445992, /* 73698 (1641) [ 0,  0,  1,  0, -1,  0, -1,  0,  0] [ 6,  6,  0] -1 */
    61832201, /* 73699 (1641) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 9,  9,  9] -1 */
    44712363, /* 73700 (1641) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 3,  9,  3] -1 */
    51146914, /* 73701 (1641) [ 0,  0,  1,  0, -1,  0, -1,  0,  0] [ 6,  0,  6] -1 */
    27710359, /* 73702 (1641) [ 1,  0,  0,  0,  0, -1,  0,  1,  0] [ 9,  9,  3]  1 */
    61840729, /* 73703 (1641) [ 1,  0,  0,  0,  0,  1,  0, -1,  0] [ 9,  9,  9] -1 */
    60292339, /* 73704 (1641) [-1,  0,  0,  0,  0,  1,  0,  1,  0] [ 9,  3,  3] -1 */
    60416485, /* 73705 (1641) [ 0,  0, -1,  1,  0,  0,  0,  1,  0] [ 9,  3,  9] -1 */
    44827549, /* 73706 (1641) [ 0,  0, -1,  1,  0,  0,  0,  1,  0] [ 3,  9,  9] -1 */
    52451944, /* 73707 (1641) [ 1,  0,  0,  0,  0,  1,  0,  1,  0] [ 6,  6,  0] -1 */
    52562482, /* 73708 (1641) [ 0,  0, -1, -1,  0,  0,  0,  1,  0] [ 6,  6,  6] -1 */
    35439724, /* 73709 (1641) [ 0,  0,  1, -1,  0,  0,  0, -1,  0] [ 0,  6,  0] -1 */
    52556970, /* 73710 (1641) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    10698679, /* 73711 (1641) [ 0,  0,  1,  1,  0,  0,  0, -1,  0] [ 3,  9,  3]  1 */
    60419137, /* 73712 (1641) [ 0,  1,  0,  0,  0, -1,  1,  0,  0] [ 9,  3,  9] -1 */
     9398149, /* 73713 (1641) [ 0,  0, -1,  1,  0,  0,  0,  1,  0] [ 3,  3,  9]  1 */
    61709403, /* 73714 (1641) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 9,  9,  3] -1 */
    17133082, /* 73715 (1641) [ 0,  0, -1, -1,  0,  0,  0,  1,  0] [ 6,  0,  6]  1 */
    34146642, /* 73716 (1641) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
    52569930, /* 73717 (1641) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    44710735, /* 73718 (1641) [ 0,  0,  1,  0,  1,  0, -1,  0,  0] [ 3,  9,  3] -1 */
      127138, /* 73719 (1641) [ 0,  0, -1,  0, -1,  0,  1,  0,  0] [ 0,  0,  6]  1 */
    26398153, /* 73720 (1641) [-1,  0,  0,  0,  0, -1,  0, -1,  0] [ 9,  3,  9]  1 */
    43417441, /* 73721 (1641) [ 1,  0,  0,  0,  0,  1,  0, -1,  0] [ 3,  3,  9] -1 */
    17140530, /* 73722 (1641) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  6]  1 */
    17013524, /* 73723 (1641) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 6,  0,  0]  1 */
    10817753, /* 73724 (1641) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 3,  9,  9]  1 */
    27820945, /* 73725 (1641) [ 0,  0, -1, -1,  0,  0,  0, -1,  0] [ 9,  9,  9]  1 */
     9397657, /* 73726 (1641) [ 0,  0, -1, -1,  0,  0,  0, -1,  0] [ 3,  3,  9]  1 */
    26406689, /* 73727 (1641) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 9,  3,  9]  1 */
     9405113, /* 73728 (1641) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 3,  3,  9]  1 */
    51030328, /* 73729 (1641) [ 0,  1,  0,  0,  0, -1, -1,  0,  0] [ 6,  0,  0] -1 */
    10691067, /* 73730 (1641) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 3,  9,  3]  1 */
        3200, /* 73731 (1641) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    43286115, /* 73732 (1641) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 3,  3,  3] -1 */
    26402313, /* 73733 (1641) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 9,  3,  9]  1 */
    61722527, /* 73734 (1641) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 9,  9,  3] -1 */
    17017896, /* 73735 (1641) [ 0,  1,  0, -1,  0,  0,  0,  0, -1] [ 6,  0,  0]  1 */
    51139738, /* 73736 (1641) [-1,  0,  0,  0,  0,  1,  0, -1,  0] [ 6,  0,  6] -1 */
       12064, /* 73737 (1641) [ 0,  1,  0,  0,  0,  1,  1,  0,  0] [ 0,  0,  0]  1 */
    60301299, /* 73738 (1641) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 9,  3,  3] -1 */
    27710407, /* 73739 (1641) [ 1,  0,  0,  0,  0,  1,  0, -1,  0] [ 9,  9,  3]  1 */
    26398213, /* 73740 (1641) [-1,  0,  0,  0,  0,  1,  0,  1,  0] [ 9,  3,  9]  1 */
    61717015, /* 73741 (1641) [ 0,  0,  1,  1,  0,  0,  0, -1,  0] [ 9,  9,  3] -1 */
    35558158, /* 73742 (1641) [ 0,  0,  1,  0,  1,  0,  1,  0,  0] [ 0,  6,  6] -1 */
    17131882, /* 73743 (1641) [ 0, -1,  0,  0,  0,  1, -1,  0,  0] [ 6,  0,  6]  1 */
    35437036, /* 73744 (1641) [ 0, -1,  0,  0,  0, -1,  1,  0,  0] [ 0,  6,  0] -1 */
     1546090, /* 73745 (1641) [ 0,  0,  1,  1,  0,  0,  0,  1,  0] [ 0,  6,  6]  1 */
    61827553, /* 73746 (1641) [-1,  0,  0,  0,  0, -1,  0, -1,  0] [ 9,  9,  9] -1 */
    43404265, /* 73747 (1641) [-1,  0,  0,  0,  0, -1,  0, -1,  0] [ 3,  3,  9] -1 */
    52451884, /* 73748 (1641) [ 1,  0,  0,  0,  0, -1,  0, -1,  0] [ 6,  6,  0] -1 */
     1426216, /* 73749 (1641) [ 0,  0, -1,  0, -1,  0,  1,  0,  0] [ 0,  6,  0]  1 */
    60299671, /* 73750 (1641) [ 0,  0,  1,  0,  1,  0, -1,  0,  0] [ 9,  3,  3] -1 */
    10695559, /* 73751 (1641) [ 0, -1,  0,  0,  0,  1,  1,  0,  0] [ 3,  9,  3]  1 */
    34024008, /* 73752 (1641) [ 0,  1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    35438272, /* 73753 (1641) [ 0,  0, -1, -1,  0,  0,  0,  1,  0] [ 0,  6,  0] -1 */
    43286279, /* 73754 (1641) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 3,  3,  3] -1 */
    35557978, /* 73755 (1641) [ 0,  0,  1,  0, -1,  0, -1,  0,  0] [ 0,  6,  6] -1 */
    52562962, /* 73756 (1641) [ 0,  0, -1,  1,  0,  0,  0, -1,  0] [ 6,  6,  6] -1 */
    51144330, /* 73757 (1641) [ 0, -1,  0,  1,  0,  0,  0,  0, -1] [ 6,  0,  6] -1 */
    18551866, /* 73758 (1641) [ 0,  0,  1,  0, -1,  0, -1,  0,  0] [ 6,  6,  6]  1 */
    27697291, /* 73759 (1641) [-1,  0,  0,  0,  0,  1,  0,  1,  0] [ 9,  9,  3]  1 */
    17133562, /* 73760 (1641) [ 0,  0, -1,  1,  0,  0,  0, -1,  0] [ 6,  0,  6]  1 */
    17136202, /* 73761 (1641) [ 0,  1,  0,  0,  0, -1, -1,  0,  0] [ 6,  0,  6]  1 */
    10815169, /* 73762 (1641) [ 0,  0, -1,  0,  1,  0,  1,  0,  0] [ 3,  9,  9]  1 */
    34137994, /* 73763 (1641) [ 0, -1,  0,  0,  0,  1, -1,  0,  0] [ 0,  0,  6] -1 */
    27815441, /* 73764 (1641) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 9,  9,  9]  1 */
    61831713, /* 73765 (1641) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 9,  9,  9] -1 */
    43294963, /* 73766 (1641) [ 0,  1,  0,  0,  0,  1, -1,  0,  0] [ 3,  3,  3] -1 */
    60410325, /* 73767 (1641) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 9,  3,  9] -1 */
    10813377, /* 73768 (1641) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 3,  9,  9]  1 */
      134530, /* 73769 (1641) [ 1,  0,  0,  0,  0,  1,  0,  1,  0] [ 0,  0,  6]  1 */
    51025972, /* 73770 (1641) [ 0, -1,  0,  0,  0, -1,  1,  0,  0] [ 6,  0,  0] -1 */
    17135026, /* 73771 (1641) [ 0,  0,  1,  1,  0,  0,  0,  1,  0] [ 6,  0,  6]  1 */
    52444552, /* 73772 (1641) [ 0,  0, -1,  0, -1,  0,  1,  0,  0] [ 6,  6,  0] -1 */
    43413285, /* 73773 (1641) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 3,  3,  9] -1 */
    44707991, /* 73774 (1641) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 3,  9,  3] -1 */
    51145618, /* 73775 (1641) [ 0,  0, -1,  0,  1,  0, -1,  0,  0] [ 6,  0,  6] -1 */
    17015152, /* 73776 (1641) [ 0,  0, -1,  0, -1,  0,  1,  0,  0] [ 6,  0,  0]  1 */
     9281191, /* 73777 (1641) [ 0,  0,  1,  0, -1,  0,  1,  0,  0] [ 3,  3,  3]  1 */
    34139674, /* 73778 (1641) [ 0,  0, -1,  1,  0,  0,  0, -1,  0] [ 0,  0,  6] -1 */
    34142314, /* 73779 (1641) [ 0,  1,  0,  0,  0, -1, -1,  0,  0] [ 0,  0,  6] -1 */
    34141138, /* 73780 (1641) [ 0,  0,  1,  1,  0,  0,  0,  1,  0] [ 0,  0,  6] -1 */
    52564426, /* 73781 (1641) [ 0,  0,  1,  1,  0,  0,  0,  1,  0] [ 6,  6,  6] -1 */
    61833505, /* 73782 (1641) [ 0,  0, -1,  0,  1,  0,  1,  0,  0] [ 9,  9,  9] -1 */
    51021696, /* 73783 (1641) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  0] -1 */
    43293727, /* 73784 (1641) [ 0,  0,  1,  1,  0,  0,  0, -1,  0] [ 3,  3,  3] -1 */
    51021536, /* 73785 (1641) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  0] -1 */
    27697231, /* 73786 (1641) [-1,  0,  0,  0,  0, -1,  0, -1,  0] [ 9,  9,  3]  1 */
     1428960, /* 73787 (1641) [ 0,  1,  0, -1,  0,  0,  0,  0, -1] [ 0,  6,  0]  1 */
    51034656, /* 73788 (1641) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  0] -1 */
      128578, /* 73789 (1641) [ 0,  0,  1,  0, -1,  0, -1,  0,  0] [ 0,  0,  6]  1 */
    10822393, /* 73790 (1641) [ 1,  0,  0,  0,  0,  1,  0, -1,  0] [ 3,  9,  9]  1 */
    43411657, /* 73791 (1641) [ 0,  0,  1,  0,  1,  0, -1,  0,  0] [ 3,  3,  9] -1 */
    61722687, /* 73792 (1641) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 9,  9,  3] -1 */
    27821437, /* 73793 (1641) [ 0,  0, -1,  1,  0,  0,  0,  1,  0] [ 9,  9,  9]  1 */
    51147094, /* 73794 (1641) [ 0,  0,  1,  0,  1,  0,  1,  0,  0] [ 6,  0,  6] -1 */
    10698199, /* 73795 (1641) [ 0,  0,  1, -1,  0,  0,  0,  1,  0] [ 3,  9,  3]  1 */
     1542946, /* 73796 (1641) [ 0, -1,  0,  0,  0,  1, -1,  0,  0] [ 0,  6,  6]  1 */
     1551594, /* 73797 (1641) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
    26293127, /* 73798 (1641) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 9,  3,  3]  1 */
    43299399, /* 73799 (1641) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 3,  3,  3] -1 */
    43292275, /* 73800 (1641) [ 0,  0, -1,  1,  0,  0,  0,  1,  0] [ 3,  3,  3] -1 */
    35554910, /* 73801 (1641) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 0,  6,  6] -1 */
    27706251, /* 73802 (1641) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 9,  9,  3]  1 */
    26284495, /* 73803 (1641) [ 0, -1,  0,  0,  0,  1,  1,  0,  0] [ 9,  3,  3]  1 */
    51027208, /* 73804 (1641) [ 0,  0, -1, -1,  0,  0,  0,  1,  0] [ 6,  0,  0] -1 */
    43290535, /* 73805 (1641) [ 0, -1,  0,  0,  0, -1, -1,  0,  0] [ 3,  3,  3] -1 */
    35441392, /* 73806 (1641) [ 0,  1,  0,  0,  0, -1, -1,  0,  0] [ 0,  6,  0] -1 */
    52443408, /* 73807 (1641) [ 0, -1,  0,  1,  0,  0,  0,  0, -1] [ 6,  6,  0] -1 */
    18430924, /* 73808 (1641) [ 0, -1,  0,  0,  0, -1,  1,  0,  0] [ 6,  6,  0]  1 */
    44821389, /* 73809 (1641) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 3,  9,  9] -1 */
    17131846, /* 73810 (1641) [ 0, -1,  0,  0,  0, -1,  1,  0,  0] [ 6,  0,  6]  1 */
    60417457, /* 73811 (1641) [ 0,  0,  1, -1,  0,  0,  0,  1,  0] [ 9,  3,  9] -1 */
    18550570, /* 73812 (1641) [ 0,  0, -1,  0,  1,  0, -1,  0,  0] [ 6,  6,  6]  1 */
    44711879, /* 73813 (1641) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 3,  9,  3] -1 */
      121354, /* 73814 (1641) [-1,  0,  0,  0,  0, -1,  0,  1,  0] [ 0,  0,  6]  1 */
    51148706, /* 73815 (1641) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 6,  0,  6] -1 */
     9282963, /* 73816 (1641) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 3,  3,  3]  1 */
    43299239, /* 73817 (1641) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 3,  3,  3] -1 */
    35559770, /* 73818 (1641) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 0,  6,  6] -1 */
      134470, /* 73819 (1641) [ 1,  0,  0,  0,  0, -1,  0, -1,  0] [ 0,  0,  6]  1 */
    26411329, /* 73820 (1641) [ 1,  0,  0,  0,  0,  1,  0, -1,  0] [ 9,  3,  9]  1 */
     9274003, /* 73821 (1641) [-1,  0,  0,  0,  0,  1,  0,  1,  0] [ 3,  3,  3]  1 */
    35550802, /* 73822 (1641) [-1,  0,  0,  0,  0,  1,  0, -1,  0] [ 0,  6,  6] -1 */
    35440216, /* 73823 (1641) [ 0,  0,  1,  1,  0,  0,  0,  1,  0] [ 0,  6,  0] -1 */
    27705767, /* 73824 (1641) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 9,  9,  3]  1 */
    18426488, /* 73825 (1641) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    44829001, /* 73826 (1641) [ 0,  0,  1,  1,  0,  0,  0, -1,  0] [ 3,  9,  9] -1 */
       10324, /* 73827 (1641) [ 0,  0,  1, -1,  0,  0,  0, -1,  0] [ 0,  0,  0]  1 */
    61834801, /* 73828 (1641) [ 0,  0,  1,  0, -1,  0,  1,  0,  0] [ 9,  9,  9] -1 */
    17127570, /* 73829 (1641) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6]  1 */
    10699915, /* 73830 (1641) [ 0,  1,  0,  0,  0,  1, -1,  0,  0] [ 3,  9,  3]  1 */
     9281335, /* 73831 (1641) [ 0,  0,  1,  0,  1,  0, -1,  0,  0] [ 3,  3,  3]  1 */
    35556682, /* 73832 (1641) [ 0,  0, -1,  0,  1,  0, -1,  0,  0] [ 0,  6,  6] -1 */
    35550754, /* 73833 (1641) [-1,  0,  0,  0,  0, -1,  0,  1,  0] [ 0,  6,  6] -1 */
    43410037, /* 73834 (1641) [ 0,  0, -1,  0, -1,  0, -1,  0,  0] [ 3,  3,  9] -1 */
    26402801, /* 73835 (1641) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 9,  3,  9]  1 */
    44834673, /* 73836 (1641) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 3,  9,  9] -1 */
    34133682, /* 73837 (1641) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
    51026008, /* 73838 (1641) [ 0, -1,  0,  0,  0,  1, -1,  0,  0] [ 6,  0,  0] -1 */
    10691231, /* 73839 (1641) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 3,  9,  3]  1 */
    51143846, /* 73840 (1641) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 6,  0,  6] -1 */
     1551758, /* 73841 (1641) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
     1547266, /* 73842 (1641) [ 0,  1,  0,  0,  0, -1, -1,  0,  0] [ 0,  6,  6]  1 */
      125994, /* 73843 (1641) [ 0, -1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  6]  1 */
    18549282, /* 73844 (1641) [ 0, -1,  0,  1,  0,  0,  0,  0, -1] [ 6,  6,  6]  1 */
    60417937, /* 73845 (1641) [ 0,  0,  1,  1,  0,  0,  0, -1,  0] [ 9,  3,  9] -1 */
    61840681, /* 73846 (1641) [ 1,  0,  0,  0,  0, -1,  0,  1,  0] [ 9,  9,  9] -1 */
    51027688, /* 73847 (1641) [ 0,  0, -1,  1,  0,  0,  0, -1,  0] [ 6,  0,  0] -1 */
    60296439, /* 73848 (1641) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 9,  3,  3] -1 */
    44709295, /* 73849 (1641) [ 0,  0, -1,  0,  1,  0,  1,  0,  0] [ 3,  9,  3] -1 */
    61709567, /* 73850 (1641) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 9,  9,  3] -1 */
    61718251, /* 73851 (1641) [ 0,  1,  0,  0,  0,  1, -1,  0,  0] [ 9,  9,  3] -1 */
     9279895, /* 73852 (1641) [ 0,  0, -1,  0,  1,  0,  1,  0,  0] [ 3,  3,  3]  1 */
    35555394, /* 73853 (1641) [ 0, -1,  0,  1,  0,  0,  0,  0, -1] [ 0,  6,  6] -1 */
    17016592, /* 73854 (1641) [ 0,  0,  1,  0, -1,  0, -1,  0,  0] [ 6,  0,  0]  1 */
    10704351, /* 73855 (1641) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 3,  9,  3]  1 */
    43291783, /* 73856 (1641) [ 0,  0, -1, -1,  0,  0,  0, -1,  0] [ 3,  3,  3] -1 */
    34028656, /* 73857 (1641) [ 1,  0,  0,  0,  0,  1,  0,  1,  0] [ 0,  0,  0] -1 */
    10697227, /* 73858 (1641) [ 0,  0, -1,  1,  0,  0,  0,  1,  0] [ 3,  9,  3]  1 */
    18432160, /* 73859 (1641) [ 0,  0, -1, -1,  0,  0,  0,  1,  0] [ 6,  6,  0]  1 */
    18552046, /* 73860 (1641) [ 0,  0,  1,  0,  1,  0,  1,  0,  0] [ 6,  6,  6]  1 */
    44830201, /* 73861 (1641) [ 0,  1,  0,  0,  0, -1,  1,  0,  0] [ 3,  9,  9] -1 */
    51139690, /* 73862 (1641) [-1,  0,  0,  0,  0, -1,  0,  1,  0] [ 6,  0,  6] -1 */
    17022544, /* 73863 (1641) [ 1,  0,  0,  0,  0,  1,  0,  1,  0] [ 6,  0,  0]  1 */
        7636, /* 73864 (1641) [ 0, -1,  0,  0,  0, -1,  1,  0,  0] [ 0,  0,  0]  1 */
     9391989, /* 73865 (1641) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 3,  3,  9]  1 */
       16320, /* 73866 (1641) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    18430960, /* 73867 (1641) [ 0, -1,  0,  0,  0,  1, -1,  0,  0] [ 6,  6,  0]  1 */
    27824089, /* 73868 (1641) [ 0,  1,  0,  0,  0, -1,  1,  0,  0] [ 9,  9,  9]  1 */
    18439608, /* 73869 (1641) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
     9279715, /* 73870 (1641) [ 0,  0, -1,  0, -1,  0, -1,  0,  0] [ 3,  3,  3]  1 */
    27703003, /* 73871 (1641) [ 0,  0, -1,  0, -1,  0, -1,  0,  0] [ 9,  9,  3]  1 */
    52570094, /* 73872 (1641) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    34019636, /* 73873 (1641) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  0] -1 */
        8872, /* 73874 (1641) [ 0,  0, -1, -1,  0,  0,  0,  1,  0] [ 0,  0,  0]  1 */
    51148218, /* 73875 (1641) [ 0,  1,  0, -1,  0,  0,  0,  0, -1] [ 6,  0,  6] -1 */
    26284423, /* 73876 (1641) [ 0, -1,  0,  0,  0, -1, -1,  0,  0] [ 9,  3,  3]  1 */
    34142386, /* 73877 (1641) [ 0,  1,  0,  0,  0,  1,  1,  0,  0] [ 0,  0,  6] -1 */
    52565674, /* 73878 (1641) [ 0,  1,  0,  0,  0,  1,  1,  0,  0] [ 6,  6,  6] -1 */
    34022704, /* 73879 (1641) [ 0,  0,  1,  0, -1,  0, -1,  0,  0] [ 0,  0,  0] -1 */
    26411281, /* 73880 (1641) [ 1,  0,  0,  0,  0, -1,  0,  1,  0] [ 9,  3,  9]  1 */
    26405401, /* 73881 (1641) [ 0,  0,  1,  0, -1,  0,  1,  0,  0] [ 9,  3,  9]  1 */
    61715563, /* 73882 (1641) [ 0,  0, -1,  1,  0,  0,  0,  1,  0] [ 9,  9,  3] -1 */
    51029152, /* 73883 (1641) [ 0,  0,  1,  1,  0,  0,  0,  1,  0] [ 6,  0,  0] -1 */
    35445720, /* 73884 (1641) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  0] -1 */
    17022484, /* 73885 (1641) [ 1,  0,  0,  0,  0, -1,  0, -1,  0] [ 6,  0,  0]  1 */
    52438816, /* 73886 (1641) [-1,  0,  0,  0,  0,  1,  0, -1,  0] [ 6,  6,  0] -1 */
    52438768, /* 73887 (1641) [-1,  0,  0,  0,  0, -1,  0,  1,  0] [ 6,  6,  0] -1 */
    61836573, /* 73888 (1641) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 9,  9,  9] -1 */
    44825881, /* 73889 (1641) [ 0, -1,  0,  0,  0,  1,  1,  0,  0] [ 3,  9,  9] -1 */
     9282479, /* 73890 (1641) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 3,  3,  3]  1 */
    43417393, /* 73891 (1641) [ 1,  0,  0,  0,  0, -1,  0,  1,  0] [ 3,  3,  9] -1 */
    43411513, /* 73892 (1641) [ 0,  0,  1,  0, -1,  0,  1,  0,  0] [ 3,  3,  9] -1 */
        7672, /* 73893 (1641) [ 0, -1,  0,  0,  0,  1, -1,  0,  0] [ 0,  0,  0]  1 */
     1538634, /* 73894 (1641) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
    60415993, /* 73895 (1641) [ 0,  0, -1, -1,  0,  0,  0, -1,  0] [ 9,  3,  9] -1 */
    26293287, /* 73896 (1641) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 9,  3,  3]  1 */
    27822889, /* 73897 (1641) [ 0,  0,  1,  1,  0,  0,  0, -1,  0] [ 9,  9,  9]  1 */
    52444696, /* 73898 (1641) [ 0,  0, -1,  0,  1,  0, -1,  0,  0] [ 6,  6,  0] -1 */
     1427836, /* 73899 (1641) [ 0,  0,  1,  0,  1,  0,  1,  0,  0] [ 0,  6,  0]  1 */
    44707503, /* 73900 (1641) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 3,  9,  3] -1 */
    26287615, /* 73901 (1641) [ 0,  0,  1,  1,  0,  0,  0, -1,  0] [ 9,  3,  3]  1 */
    34015480, /* 73902 (1641) [-1,  0,  0,  0,  0, -1,  0,  1,  0] [ 0,  0,  0] -1 */
    60296927, /* 73903 (1641) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 9,  3,  3] -1 */
    10695487, /* 73904 (1641) [ 0, -1,  0,  0,  0, -1, -1,  0,  0] [ 3,  9,  3]  1 */
    61834945, /* 73905 (1641) [ 0,  0,  1,  0,  1,  0, -1,  0,  0] [ 9,  9,  9] -1 */
    34028596, /* 73906 (1641) [ 1,  0,  0,  0,  0, -1,  0, -1,  0] [ 0,  0,  0] -1 */
    26403925, /* 73907 (1641) [ 0,  0, -1,  0, -1,  0, -1,  0,  0] [ 9,  3,  9]  1 */
    35445884, /* 73908 (1641) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  0] -1 */
     9278591, /* 73909 (1641) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 3,  3,  3]  1 */
    10809217, /* 73910 (1641) [-1,  0,  0,  0,  0, -1,  0, -1,  0] [ 3,  9,  9]  1 */
    18553170, /* 73911 (1641) [ 0,  1,  0, -1,  0,  0,  0,  0, -1] [ 6,  6,  6]  1 */
    61713823, /* 73912 (1641) [ 0, -1,  0,  0,  0, -1, -1,  0,  0] [ 9,  9,  3] -1 */
    26404105, /* 73913 (1641) [ 0,  0, -1,  0,  1,  0,  1,  0,  0] [ 9,  3,  9]  1 */
     1427656, /* 73914 (1641) [ 0,  0,  1,  0, -1,  0, -1,  0,  0] [ 0,  6,  0]  1 */
    18432640, /* 73915 (1641) [ 0,  0, -1,  1,  0,  0,  0, -1,  0] [ 6,  6,  0]  1 */
       11992, /* 73916 (1641) [ 0,  1,  0,  0,  0, -1, -1,  0,  0] [ 0,  0,  0]  1 */
    35441464, /* 73917 (1641) [ 0,  1,  0,  0,  0,  1,  1,  0,  0] [ 0,  6,  0] -1 */
    18435280, /* 73918 (1641) [ 0,  1,  0,  0,  0, -1, -1,  0,  0] [ 6,  6,  0]  1 */
    17014008, /* 73919 (1641) [ 0, -1,  0,  1,  0,  0,  0,  0, -1] [ 6,  0,  0]  1 */
    35437072, /* 73920 (1641) [ 0, -1,  0,  0,  0,  1, -1,  0,  0] [ 0,  6,  0] -1 */
    27822409, /* 73921 (1641) [ 0,  0,  1, -1,  0,  0,  0,  1,  0] [ 9,  9,  9]  1 */
    44716519, /* 73922 (1641) [ 1,  0,  0,  0,  0,  1,  0, -1,  0] [ 3,  9,  3] -1 */
     9400801, /* 73923 (1641) [ 0,  1,  0,  0,  0, -1,  1,  0,  0] [ 3,  3,  9]  1 */
    35563930, /* 73924 (1641) [ 1,  0,  0,  0,  0,  1,  0,  1,  0] [ 0,  6,  6] -1 */
    18548798, /* 73925 (1641) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    10704191, /* 73926 (1641) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 3,  9,  3]  1 */
      121402, /* 73927 (1641) [-1,  0,  0,  0,  0,  1,  0, -1,  0] [ 0,  0,  6]  1 */
    18544690, /* 73928 (1641) [-1,  0,  0,  0,  0,  1,  0, -1,  0] [ 6,  6,  6]  1 */
    35559282, /* 73929 (1641) [ 0,  1,  0, -1,  0,  0,  0,  0, -1] [ 0,  6,  6] -1 */
    18544642, /* 73930 (1641) [-1,  0,  0,  0,  0, -1,  0,  1,  0] [ 6,  6,  6]  1 */
    35438752, /* 73931 (1641) [ 0,  0, -1,  1,  0,  0,  0, -1,  0] [ 0,  6,  0] -1 */
    44830237, /* 73932 (1641) [ 0,  1,  0,  0,  0,  1, -1,  0,  0] [ 3,  9,  9] -1 */
    34020120, /* 73933 (1641) [ 0, -1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  0] -1 */
      125510, /* 73934 (1641) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  6]  1 */
    34022884, /* 73935 (1641) [ 0,  0,  1,  0,  1,  0,  1,  0,  0] [ 0,  0,  0] -1 */
    52446172, /* 73936 (1641) [ 0,  0,  1,  0,  1,  0,  1,  0,  0] [ 6,  6,  0] -1 */
    26285671, /* 73937 (1641) [ 0,  0, -1, -1,  0,  0,  0, -1,  0] [ 9,  3,  3]  1 */
     9405273, /* 73938 (1641) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 3,  3,  9]  1 */
    44827057, /* 73939 (1641) [ 0,  0, -1, -1,  0,  0,  0, -1,  0] [ 3,  9,  9] -1 */
    18553658, /* 73940 (1641) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    61836089, /* 73941 (1641) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 9,  9,  9] -1 */
       10816, /* 73942 (1641) [ 0,  0,  1,  1,  0,  0,  0,  1,  0] [ 0,  0,  0]  1 */
    18434104, /* 73943 (1641) [ 0,  0,  1,  1,  0,  0,  0,  1,  0] [ 6,  6,  0]  1 */
    44828521, /* 73944 (1641) [ 0,  0,  1, -1,  0,  0,  0,  1,  0] [ 3,  9,  9] -1 */
    60423449, /* 73945 (1641) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 9,  3,  9] -1 */
    52563934, /* 73946 (1641) [ 0,  0,  1, -1,  0,  0,  0, -1,  0] [ 6,  6,  6] -1 */
    17016772, /* 73947 (1641) [ 0,  0,  1,  0,  1,  0,  1,  0,  0] [ 6,  0,  0]  1 */
     1433548, /* 73948 (1641) [ 1,  0,  0,  0,  0, -1,  0, -1,  0] [ 0,  6,  0]  1 */
     9399601, /* 73949 (1641) [ 0,  0,  1,  1,  0,  0,  0, -1,  0] [ 3,  3,  9]  1 */
    61718215, /* 73950 (1641) [ 0,  1,  0,  0,  0, -1,  1,  0,  0] [ 9,  9,  3] -1 */
    27704623, /* 73951 (1641) [ 0,  0,  1,  0,  1,  0, -1,  0,  0] [ 9,  9,  3]  1 */
    17134534, /* 73952 (1641) [ 0,  0,  1, -1,  0,  0,  0, -1,  0] [ 6,  0,  6]  1 */
    10814989, /* 73953 (1641) [ 0,  0, -1,  0, -1,  0, -1,  0,  0] [ 3,  9,  9]  1 */
    51152866, /* 73954 (1641) [ 1,  0,  0,  0,  0,  1,  0,  1,  0] [ 6,  0,  6] -1 */
    51030400, /* 73955 (1641) [ 0,  1,  0,  0,  0,  1,  1,  0,  0] [ 6,  0,  0] -1 */
    60305455, /* 73956 (1641) [ 1,  0,  0,  0,  0,  1,  0, -1,  0] [ 9,  3,  3] -1 */
    43404325, /* 73957 (1641) [-1,  0,  0,  0,  0,  1,  0,  1,  0] [ 3,  3,  9] -1 */
    52556810, /* 73958 (1641) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    60419173, /* 73959 (1641) [ 0,  1,  0,  0,  0,  1, -1,  0,  0] [ 9,  3,  9] -1 */
    34140646, /* 73960 (1641) [ 0,  0,  1, -1,  0,  0,  0, -1,  0] [ 0,  0,  6] -1 */
    61833325, /* 73961 (1641) [ 0,  0, -1,  0, -1,  0, -1,  0,  0] [ 9,  9,  9] -1 */
    10696735, /* 73962 (1641) [ 0,  0, -1, -1,  0,  0,  0, -1,  0] [ 3,  9,  3]  1 */
    60292279, /* 73963 (1641) [-1,  0,  0,  0,  0, -1,  0, -1,  0] [ 9,  3,  3] -1 */
    26280167, /* 73964 (1641) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 9,  3,  3]  1 */
      127282, /* 73965 (1641) [ 0,  0, -1,  0,  1,  0, -1,  0,  0] [ 0,  0,  6]  1 */
    61715071, /* 73966 (1641) [ 0,  0, -1, -1,  0,  0,  0, -1,  0] [ 9,  9,  3] -1 */
     1544626, /* 73967 (1641) [ 0,  0, -1,  1,  0,  0,  0, -1,  0] [ 0,  6,  6]  1 */
     1424588, /* 73968 (1641) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 0,  6,  0]  1 */
    60414745, /* 73969 (1641) [ 0, -1,  0,  0,  0, -1, -1,  0,  0] [ 9,  3,  9] -1 */
      128758, /* 73970 (1641) [ 0,  0,  1,  0,  1,  0,  1,  0,  0] [ 0,  0,  6]  1 */
    44710591, /* 73971 (1641) [ 0,  0,  1,  0, -1,  0,  1,  0,  0] [ 3,  9,  3] -1 */
    60305407, /* 73972 (1641) [ 1,  0,  0,  0,  0, -1,  0,  1,  0] [ 9,  3,  3] -1 */
    60299527, /* 73973 (1641) [ 0,  0,  1,  0, -1,  0,  1,  0,  0] [ 9,  3,  3] -1 */
     1429448, /* 73974 (1641) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 0,  6,  0]  1 */
    18426648, /* 73975 (1641) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
     1547338, /* 73976 (1641) [ 0,  1,  0,  0,  0,  1,  1,  0,  0] [ 0,  6,  6]  1 */
     1420432, /* 73977 (1641) [-1,  0,  0,  0,  0, -1,  0,  1,  0] [ 0,  6,  0]  1 */
    27704479, /* 73978 (1641) [ 0,  0,  1,  0, -1,  0,  1,  0,  0] [ 9,  9,  3]  1 */
    10818237, /* 73979 (1641) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 3,  9,  9]  1 */
    60298231, /* 73980 (1641) [ 0,  0, -1,  0,  1,  0,  1,  0,  0] [ 9,  3,  3] -1 */
     1426360, /* 73981 (1641) [ 0,  0, -1,  0,  1,  0, -1,  0,  0] [ 0,  6,  0]  1 */
    34137958, /* 73982 (1641) [ 0, -1,  0,  0,  0, -1,  1,  0,  0] [ 0,  0,  6] -1 */
    10816609, /* 73983 (1641) [ 0,  0,  1,  0,  1,  0, -1,  0,  0] [ 3,  9,  9]  1 */
    27701879, /* 73984 (1641) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 9,  9,  3]  1 */
    35556538, /* 73985 (1641) [ 0,  0, -1,  0, -1,  0,  1,  0,  0] [ 0,  6,  6] -1 */
    35432760, /* 73986 (1641) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  0] -1 */
    52561282, /* 73987 (1641) [ 0, -1,  0,  0,  0,  1, -1,  0,  0] [ 6,  6,  6] -1 */
    44703343, /* 73988 (1641) [-1,  0,  0,  0,  0, -1,  0, -1,  0] [ 3,  9,  3] -1 */
    10809277, /* 73989 (1641) [-1,  0,  0,  0,  0,  1,  0,  1,  0] [ 3,  9,  9]  1 */
    26286163, /* 73990 (1641) [ 0,  0, -1,  1,  0,  0,  0,  1,  0] [ 9,  3,  3]  1 */
    60423609, /* 73991 (1641) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 9,  3,  9] -1 */
    43294927, /* 73992 (1641) [ 0,  1,  0,  0,  0, -1,  1,  0,  0] [ 3,  3,  3] -1 */
    52442924, /* 73993 (1641) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 6,  6,  0] -1 */
    27824125, /* 73994 (1641) [ 0,  1,  0,  0,  0,  1, -1,  0,  0] [ 9,  9,  9]  1 */
       16484, /* 73995 (1636) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
     8565465, /* 73996 (1636) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 3,  0,  3]  1 */
    17140694, /* 73997 (1636) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
    19201249, /* 73998 (1636) [ 0,  0,  1, -1,  0,  0,  0, -1,  0] [ 6,  9,  3]  1 */
     9987177, /* 73999 (1636) [ 0, -1,  0,  1,  0,  0,  0,  0, -1] [ 3,  6,  3]  1 */
    26997403, /* 74000 (1636) [ 0,  1,  0,  0,  0, -1,  1,  0,  0] [ 9,  6,  3]  1 */
    26347900, /* 74001 (1636) [ 0,  1,  0,  0,  0,  1, -1,  0,  0] [ 9,  3,  6]  1 */
    26339054, /* 74002 (1636) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 9,  3,  6]  1 */
        3198, /* 74003 (1636) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
     9991067, /* 74004 (1636) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 3,  6,  3]  1 */
     8572435, /* 74005 (1636) [ 0,  0,  1, -1,  0,  0,  0,  1,  0] [ 3,  0,  3]  1 */
    10105051, /* 74006 (1636) [ 0, -1,  0,  0,  0,  1, -1,  0,  0] [ 3,  6,  9]  1 */
     2319231, /* 74007 (1636) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  9,  9]  1 */
    10107709, /* 74008 (1636) [ 0,  0,  1, -1,  0,  0,  0,  1,  0] [ 3,  6,  9]  1 */
    27001715, /* 74009 (1636) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 9,  6,  3]  1 */
     8569777, /* 74010 (1636) [ 0, -1,  0,  0,  0,  1, -1,  0,  0] [ 3,  0,  3]  1 */
    10100739, /* 74011 (1636) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 3,  6,  9]  1 */
    25571521, /* 74012 (1636) [-1,  0,  0,  0,  0,  1,  0, -1,  0] [ 9,  0,  3]  1 */
    26352336, /* 74013 (1636) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 9,  3,  6]  1 */
      125508, /* 74014 (1636) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  6]  1 */
    17136274, /* 74015 (1636) [ 0,  1,  0,  0,  0,  1,  1,  0,  0] [ 6,  0,  6]  1 */
    18548796, /* 74016 (1636) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 6,  6,  6]  1 */
    27645742, /* 74017 (1636) [ 0,  0,  1,  1,  0,  0,  0, -1,  0] [ 9,  9,  0]  1 */
    26221012, /* 74018 (1636) [-1,  0,  0,  0,  0, -1,  0,  1,  0] [ 9,  3,  0]  1 */
     1427836, /* 74019 (1636) [ 0,  0,  1,  0,  1,  0,  1,  0,  0] [ 0,  6,  0]  1 */
    26230026, /* 74020 (1636) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 9,  3,  0]  1 */
    26346664, /* 74021 (1636) [ 0,  0,  1,  1,  0,  0,  0, -1,  0] [ 9,  3,  6]  1 */
    27765300, /* 74022 (1636) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 9,  9,  6]  1 */
      775327, /* 74023 (1636) [ 0, -1,  0,  0,  0,  1,  1,  0,  0] [ 0,  3,  3]  1 */
    17131828, /* 74024 (1636) [ 0, -1,  0,  0,  0, -1, -1,  0,  0] [ 6,  0,  6]  1 */
     1426198, /* 74025 (1636) [ 0,  0, -1,  0, -1,  0, -1,  0,  0] [ 0,  6,  0]  1 */
    27642568, /* 74026 (1636) [ 0, -1,  0,  0,  0, -1,  1,  0,  0] [ 9,  9,  0]  1 */
    25584595, /* 74027 (1636) [ 1,  0,  0,  0,  0, -1,  0,  1,  0] [ 9,  0,  3]  1 */
    17018384, /* 74028 (1636) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 6,  0,  0]  1 */
    17781647, /* 74029 (1636) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 6,  3,  3]  1 */
    17009362, /* 74030 (1636) [-1,  0,  0,  0,  0, -1,  0, -1,  0] [ 6,  0,  0]  1 */
    19320807, /* 74031 (1636) [ 0,  1,  0, -1,  0,  0,  0,  0, -1] [ 6,  9,  9]  1 */
    26343490, /* 74032 (1636) [ 0, -1,  0,  0,  0, -1,  1,  0,  0] [ 9,  3,  6]  1 */
    27112675, /* 74033 (1636) [ 0,  0, -1,  0,  1,  0, -1,  0,  0] [ 9,  6,  9]  1 */
      894937, /* 74034 (1636) [ 0,  0, -1,  0,  1,  0,  1,  0,  0] [ 0,  3,  9]  1 */
    10757728, /* 74035 (1636) [ 0,  0,  1,  1,  0,  0,  0, -1,  0] [ 3,  9,  6]  1 */
    17901205, /* 74036 (1636) [ 0,  0, -1,  1,  0,  0,  0,  1,  0] [ 6,  3,  9]  1 */
     2195293, /* 74037 (1636) [ 0,  0,  1,  0, -1,  0, -1,  0,  0] [ 0,  9,  3]  1 */
     9332998, /* 74038 (1636) [-1,  0,  0,  0,  0, -1,  0,  1,  0] [ 3,  3,  6]  1 */
    26344726, /* 74039 (1636) [ 0,  0, -1, -1,  0,  0,  0,  1,  0] [ 9,  3,  6]  1 */
    26228398, /* 74040 (1636) [ 0,  0,  1,  0,  1,  0, -1,  0,  0] [ 9,  3,  0]  1 */
     9342012, /* 74041 (1636) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 3,  3,  6]  1 */
    26994745, /* 74042 (1636) [ 0,  0, -1,  1,  0,  0,  0, -1,  0] [ 9,  6,  3]  1 */
      779629, /* 74043 (1636) [ 0,  1,  0,  0,  0, -1, -1,  0,  0] [ 0,  3,  3]  1 */
    19202917, /* 74044 (1636) [ 0,  1,  0,  0,  0, -1, -1,  0,  0] [ 6,  9,  3]  1 */
    25576113, /* 74045 (1636) [ 0, -1,  0,  1,  0,  0,  0,  0, -1] [ 9,  0,  3]  1 */
      902107, /* 74046 (1636) [ 1,  0,  0,  0,  0, -1,  0, -1,  0] [ 0,  3,  9]  1 */
    26234182, /* 74047 (1636) [ 1,  0,  0,  0,  0,  1,  0, -1,  0] [ 9,  3,  0]  1 */
    17777059, /* 74048 (1636) [-1,  0,  0,  0,  0,  1,  0,  1,  0] [ 6,  3,  3]  1 */
    25580003, /* 74049 (1636) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 9,  0,  3]  1 */
     9338782, /* 74050 (1636) [ 0,  0, -1,  0, -1,  0,  1,  0,  0] [ 3,  3,  6]  1 */
    27638132, /* 74051 (1636) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 9,  9,  0]  1 */
     1420426, /* 74052 (1636) [-1,  0,  0,  0,  0, -1,  0, -1,  0] [ 0,  6,  0]  1 */
      777961, /* 74053 (1636) [ 0,  0,  1, -1,  0,  0,  0, -1,  0] [ 0,  3,  3]  1 */
    17908167, /* 74054 (1636) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  3,  9]  1 */
    25696645, /* 74055 (1636) [ 0,  0,  1, -1,  0,  0,  0,  1,  0] [ 9,  0,  9]  1 */
    25689675, /* 74056 (1636) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 9,  0,  9]  1 */
     2313235, /* 74057 (1636) [ 0,  0,  1, -1,  0,  0,  0, -1,  0] [ 0,  9,  9]  1 */
    10109389, /* 74058 (1636) [ 0,  1,  0,  0,  0, -1,  1,  0,  0] [ 3,  6,  9]  1 */
    26225168, /* 74059 (1636) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 9,  3,  0]  1 */
     8574115, /* 74060 (1636) [ 0,  1,  0,  0,  0, -1,  1,  0,  0] [ 3,  0,  3]  1 */
    27760442, /* 74061 (1636) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 9,  9,  6]  1 */
     8691989, /* 74062 (1636) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 3,  0,  9]  1 */
        8866, /* 74063 (1636) [ 0,  0, -1, -1,  0,  0,  0, -1,  0] [ 0,  0,  0]  1 */
    18432154, /* 74064 (1636) [ 0,  0, -1, -1,  0,  0,  0, -1,  0] [ 6,  6,  0]  1 */
    27115277, /* 74065 (1636) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 9,  6,  9]  1 */
     8578427, /* 74066 (1636) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 3,  0,  3]  1 */
    10113701, /* 74067 (1636) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 3,  6,  9]  1 */
    10758964, /* 74068 (1636) [ 0,  1,  0,  0,  0,  1, -1,  0,  0] [ 3,  9,  6]  1 */
     8683507, /* 74069 (1636) [-1,  0,  0,  0,  0,  1,  0, -1,  0] [ 3,  0,  9]  1 */
     9340384, /* 74070 (1636) [ 0,  0,  1,  0,  1,  0, -1,  0,  0] [ 3,  3,  6]  1 */
    27106795, /* 74071 (1636) [-1,  0,  0,  0,  0,  1,  0, -1,  0] [ 9,  6,  9]  1 */
    18439772, /* 74072 (1636) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
     8690701, /* 74073 (1636) [ 0,  0,  1,  0, -1,  0,  1,  0,  0] [ 3,  0,  9]  1 */
     9346168, /* 74074 (1636) [ 1,  0,  0,  0,  0,  1,  0, -1,  0] [ 3,  3,  6]  1 */
    27756286, /* 74075 (1636) [-1,  0,  0,  0,  0, -1,  0,  1,  0] [ 9,  9,  6]  1 */
    17127408, /* 74076 (1636) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  6]  1 */
    10750118, /* 74077 (1636) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 3,  9,  6]  1 */
     9214844, /* 74078 (1636) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 3,  3,  0]  1 */
    17899537, /* 74079 (1636) [ 0, -1,  0,  0,  0,  1,  1,  0,  0] [ 6,  3,  9]  1 */
     9337154, /* 74080 (1636) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 3,  3,  6]  1 */
     8696581, /* 74081 (1636) [ 1,  0,  0,  0,  0, -1,  0,  1,  0] [ 3,  0,  9]  1 */
    18435352, /* 74082 (1636) [ 0,  1,  0,  0,  0,  1,  1,  0,  0] [ 6,  6,  0]  1 */
     1544140, /* 74083 (1636) [ 0,  0, -1, -1,  0,  0,  0, -1,  0] [ 0,  6,  6]  1 */
     9228126, /* 74084 (1636) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 3,  3,  0]  1 */
    18553658, /* 74085 (1636) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 6,  6,  6]  1 */
      893633, /* 74086 (1636) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 0,  3,  9]  1 */
     1424586, /* 74087 (1636) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 0,  6,  0]  1 */
       10816, /* 74088 (1636) [ 0,  0,  1,  1,  0,  0,  0,  1,  0] [ 0,  0,  0]  1 */
    18434104, /* 74089 (1636) [ 0,  0,  1,  1,  0,  0,  0,  1,  0] [ 6,  6,  0]  1 */
    17785533, /* 74090 (1636) [ 0,  1,  0, -1,  0,  0,  0,  0, -1] [ 6,  3,  3]  1 */
    17016772, /* 74091 (1636) [ 0,  0,  1,  0,  1,  0,  1,  0,  0] [ 6,  0,  0]  1 */
    25577401, /* 74092 (1636) [ 0,  0, -1,  0,  1,  0, -1,  0,  0] [ 9,  0,  3]  1 */
       12064, /* 74093 (1636) [ 0,  1,  0,  0,  0,  1,  1,  0,  0] [ 0,  0,  0]  1 */
    19194287, /* 74094 (1636) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  9,  3]  1 */
     2201185, /* 74095 (1636) [ 1,  0,  0,  0,  0, -1,  0, -1,  0] [ 0,  9,  3]  1 */
     9222454, /* 74096 (1636) [ 0,  0,  1,  1,  0,  0,  0, -1,  0] [ 3,  3,  0]  1 */
      130370, /* 74097 (1636) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 0,  0,  6]  1 */
     1551758, /* 74098 (1636) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
     8571457, /* 74099 (1636) [ 0,  0, -1,  1,  0,  0,  0, -1,  0] [ 3,  0,  3]  1 */
    18557818, /* 74100 (1636) [ 1,  0,  0,  0,  0,  1,  0,  1,  0] [ 6,  6,  6]  1 */
    10754554, /* 74101 (1636) [ 0, -1,  0,  0,  0, -1,  1,  0,  0] [ 3,  9,  6]  1 */
    27763672, /* 74102 (1636) [ 0,  0,  1,  0,  1,  0, -1,  0,  0] [ 9,  9,  6]  1 */
    17902171, /* 74103 (1636) [ 0,  0,  1, -1,  0,  0,  0, -1,  0] [ 6,  3,  9]  1 */
     2314903, /* 74104 (1636) [ 0,  1,  0,  0,  0, -1, -1,  0,  0] [ 0,  9,  9]  1 */
     8688099, /* 74105 (1636) [ 0, -1,  0,  1,  0,  0,  0,  0, -1] [ 3,  0,  9]  1 */
    27111387, /* 74106 (1636) [ 0, -1,  0,  1,  0,  0,  0,  0, -1] [ 9,  6,  9]  1 */
    17015134, /* 74107 (1636) [ 0,  0, -1,  0, -1,  0, -1,  0,  0] [ 6,  0,  0]  1 */
    27769456, /* 74108 (1636) [ 1,  0,  0,  0,  0,  1,  0, -1,  0] [ 9,  9,  6]  1 */
      889045, /* 74109 (1636) [-1,  0,  0,  0,  0,  1,  0,  1,  0] [ 0,  3,  9]  1 */
    25702637, /* 74110 (1636) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 9,  0,  9]  1 */
    25693987, /* 74111 (1636) [ 0, -1,  0,  0,  0,  1, -1,  0,  0] [ 9,  0,  9]  1 */
     1546090, /* 74112 (1636) [ 0,  0,  1,  1,  0,  0,  0,  1,  0] [ 0,  6,  6]  1 */
    27651414, /* 74113 (1636) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 9,  9,  0]  1 */
     9223690, /* 74114 (1636) [ 0,  1,  0,  0,  0,  1, -1,  0,  0] [ 3,  3,  0]  1 */
     9995659, /* 74115 (1636) [ 1,  0,  0,  0,  0, -1,  0,  1,  0] [ 3,  6,  3]  1 */
    10637860, /* 74116 (1636) [ 0,  0, -1,  0, -1,  0,  1,  0,  0] [ 3,  9,  0]  1 */
    19198615, /* 74117 (1636) [ 0, -1,  0,  0,  0,  1,  1,  0,  0] [ 6,  9,  3]  1 */
    17782951, /* 74118 (1636) [ 0,  0, -1,  0,  1,  0,  1,  0,  0] [ 6,  3,  3]  1 */
    19319503, /* 74119 (1636) [ 0,  0,  1,  0, -1,  0, -1,  0,  0] [ 6,  9,  9]  1 */
    19325395, /* 74120 (1636) [ 1,  0,  0,  0,  0, -1,  0, -1,  0] [ 6,  9,  9]  1 */
    17133076, /* 74121 (1636) [ 0,  0, -1, -1,  0,  0,  0, -1,  0] [ 6,  0,  6]  1 */
     2188123, /* 74122 (1636) [-1,  0,  0,  0,  0,  1,  0,  1,  0] [ 0,  9,  3]  1 */
    17784229, /* 74123 (1636) [ 0,  0,  1,  0, -1,  0, -1,  0,  0] [ 6,  3,  3]  1 */
    25695667, /* 74124 (1636) [ 0,  0, -1,  1,  0,  0,  0, -1,  0] [ 9,  0,  9]  1 */
    10763400, /* 74125 (1636) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 3,  9,  6]  1 */
     2194015, /* 74126 (1636) [ 0,  0, -1,  0,  1,  0,  1,  0,  0] [ 0,  9,  3]  1 */
    17903839, /* 74127 (1636) [ 0,  1,  0,  0,  0, -1, -1,  0,  0] [ 6,  3,  9]  1 */
    19200283, /* 74128 (1636) [ 0,  0, -1,  1,  0,  0,  0,  1,  0] [ 6,  9,  3]  1 */
      897519, /* 74129 (1636) [ 0,  1,  0, -1,  0,  0,  0,  0, -1] [ 0,  3,  9]  1 */
    19318225, /* 74130 (1636) [ 0,  0, -1,  0,  1,  0,  1,  0,  0] [ 6,  9,  9]  1 */
      770999, /* 74131 (1636) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  3,  3]  1 */
    27643804, /* 74132 (1636) [ 0,  0, -1, -1,  0,  0,  0,  1,  0] [ 9,  9,  0]  1 */
        7618, /* 74133 (1636) [ 0, -1,  0,  0,  0, -1, -1,  0,  0] [ 0,  0,  0]  1 */
     8689387, /* 74134 (1636) [ 0,  0, -1,  0,  1,  0, -1,  0,  0] [ 3,  0,  9]  1 */
     2306273, /* 74135 (1636) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  9,  9]  1 */
    18430906, /* 74136 (1636) [ 0, -1,  0,  0,  0, -1, -1,  0,  0] [ 6,  6,  0]  1 */
    18552046, /* 74137 (1636) [ 0,  0,  1,  0,  1,  0,  1,  0,  0] [ 6,  6,  6]  1 */
    17022544, /* 74138 (1636) [ 1,  0,  0,  0,  0,  1,  0,  1,  0] [ 6,  0,  0]  1 */
    10106731, /* 74139 (1636) [ 0,  0, -1,  1,  0,  0,  0, -1,  0] [ 3,  6,  9]  1 */
    10636232, /* 74140 (1636) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 3,  9,  0]  1 */
     9219280, /* 74141 (1636) [ 0, -1,  0,  0,  0, -1,  1,  0,  0] [ 3,  3,  0]  1 */
    18426486, /* 74142 (1636) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
      128758, /* 74143 (1636) [ 0,  0,  1,  0,  1,  0,  1,  0,  0] [ 0,  0,  6]  1 */
      783957, /* 74144 (1636) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  3,  3]  1 */
    26993065, /* 74145 (1636) [ 0, -1,  0,  0,  0,  1, -1,  0,  0] [ 9,  6,  3]  1 */
    19207245, /* 74146 (1636) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  9,  3]  1 */
    26995723, /* 74147 (1636) [ 0,  0,  1, -1,  0,  0,  0,  1,  0] [ 9,  6,  3]  1 */
    18550408, /* 74148 (1636) [ 0,  0, -1,  0, -1,  0, -1,  0,  0] [ 6,  6,  6]  1 */
     1429448, /* 74149 (1636) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 0,  6,  0]  1 */
    26988753, /* 74150 (1636) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 9,  6,  3]  1 */
      127120, /* 74151 (1636) [ 0,  0, -1,  0, -1,  0, -1,  0,  0] [ 0,  0,  6]  1 */
    25698325, /* 74152 (1636) [ 0,  1,  0,  0,  0, -1,  1,  0,  0] [ 9,  0,  9]  1 */
    17013522, /* 74153 (1636) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 6,  0,  0]  1 */
     1547338, /* 74154 (1636) [ 0,  1,  0,  0,  0,  1,  1,  0,  0] [ 0,  6,  6]  1 */
      134530, /* 74155 (1636) [ 1,  0,  0,  0,  0,  1,  0,  1,  0] [ 0,  0,  6]  1 */
    10632076, /* 74156 (1636) [-1,  0,  0,  0,  0, -1,  0,  1,  0] [ 3,  9,  0]  1 */
    25578715, /* 74157 (1636) [ 0,  0,  1,  0, -1,  0,  1,  0,  0] [ 9,  0,  3]  1 */
    17135026, /* 74158 (1636) [ 0,  0,  1,  1,  0,  0,  0,  1,  0] [ 6,  0,  6]  1 */
    10641090, /* 74159 (1636) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 3,  9,  0]  1 */
     9220516, /* 74160 (1636) [ 0,  0, -1, -1,  0,  0,  0,  1,  0] [ 3,  3,  0]  1 */
     1433608, /* 74161 (1636) [ 1,  0,  0,  0,  0,  1,  0,  1,  0] [ 0,  6,  0]  1 */
     9982585, /* 74162 (1636) [-1,  0,  0,  0,  0,  1,  0, -1,  0] [ 3,  6,  3]  1 */
    10755790, /* 74163 (1636) [ 0,  0, -1, -1,  0,  0,  0,  1,  0] [ 3,  9,  6]  1 */
     1542892, /* 74164 (1636) [ 0, -1,  0,  0,  0, -1, -1,  0,  0] [ 0,  6,  6]  1 */
    26226796, /* 74165 (1636) [ 0,  0, -1,  0, -1,  0,  1,  0,  0] [ 9,  3,  0]  1 */
     9989779, /* 74166 (1636) [ 0,  0,  1,  0, -1,  0,  1,  0,  0] [ 3,  6,  3]  1 */
    27119869, /* 74167 (1636) [ 1,  0,  0,  0,  0, -1,  0,  1,  0] [ 9,  6,  9]  1 */
    27113989, /* 74168 (1636) [ 0,  0,  1,  0, -1,  0,  1,  0,  0] [ 9,  6,  9]  1 */
     2310601, /* 74169 (1636) [ 0, -1,  0,  0,  0,  1,  1,  0,  0] [ 0,  9,  9]  1 */
     1538472, /* 74170 (1636) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
    18544636, /* 74171 (1636) [-1,  0,  0,  0,  0, -1,  0, -1,  0] [ 6,  6,  6]  1 */
     9988465, /* 74172 (1636) [ 0,  0, -1,  0,  1,  0, -1,  0,  0] [ 3,  6,  3]  1 */
    27762070, /* 74173 (1636) [ 0,  0, -1,  0, -1,  0,  1,  0,  0] [ 9,  9,  6]  1 */
      121348, /* 74174 (1636) [-1,  0,  0,  0,  0, -1,  0, -1,  0] [ 0,  0,  6]  1 */
    10639462, /* 74175 (1636) [ 0,  0,  1,  0,  1,  0, -1,  0,  0] [ 3,  9,  0]  1 */
     2192711, /* 74176 (1636) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 0,  9,  3]  1 */
     2196597, /* 74177 (1636) [ 0,  1,  0, -1,  0,  0,  0,  0, -1] [ 0,  9,  3]  1 */
    17895209, /* 74178 (1636) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  3,  9]  1 */
    19316921, /* 74179 (1636) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 6,  9,  9]  1 */
      896215, /* 74180 (1636) [ 0,  0,  1,  0, -1,  0, -1,  0,  0] [ 0,  3,  9]  1 */
    17790121, /* 74181 (1636) [ 1,  0,  0,  0,  0, -1,  0, -1,  0] [ 6,  3,  3]  1 */
    10645246, /* 74182 (1636) [ 1,  0,  0,  0,  0,  1,  0, -1,  0] [ 3,  9,  0]  1 */
    19312333, /* 74183 (1636) [-1,  0,  0,  0,  0,  1,  0,  1,  0] [ 6,  9,  9]  1 */
      776995, /* 74184 (1636) [ 0,  0, -1,  1,  0,  0,  0,  1,  0] [ 0,  3,  3]  1 */
     2312269, /* 74185 (1636) [ 0,  0, -1,  1,  0,  0,  0,  1,  0] [ 0,  9,  9]  1 */
    27646978, /* 74186 (1636) [ 0,  1,  0,  0,  0,  1, -1,  0,  0] [ 9,  9,  0]  1 */
       16484, /* 74187 (1637) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
     8565465, /* 74188 (1637) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 3,  0,  3]  1 */
    17140694, /* 74189 (1637) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
     9987177, /* 74190 (1637) [ 0, -1,  0,  1,  0,  0,  0,  0, -1] [ 3,  6,  3]  1 */
    26997403, /* 74191 (1637) [ 0,  1,  0,  0,  0, -1,  1,  0,  0] [ 9,  6,  3]  1 */
    26347900, /* 74192 (1637) [ 0,  1,  0,  0,  0,  1, -1,  0,  0] [ 9,  3,  6]  1 */
    52451996, /* 74193 (1637) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
        3198, /* 74194 (1637) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    43358392, /* 74195 (1637) [ 1,  0,  0,  0,  0,  1,  0, -1,  0] [ 3,  3,  6] -1 */
    53210839, /* 74196 (1637) [ 0, -1,  0,  0,  0,  1,  1,  0,  0] [ 6,  9,  3] -1 */
    10107709, /* 74197 (1637) [ 0,  0,  1, -1,  0,  0,  0,  1,  0] [ 3,  6,  9]  1 */
    25571521, /* 74198 (1637) [-1,  0,  0,  0,  0,  1,  0, -1,  0] [ 9,  0,  3]  1 */
    17136274, /* 74199 (1637) [ 0,  1,  0,  0,  0,  1,  1,  0,  0] [ 6,  0,  6]  1 */
    26221012, /* 74200 (1637) [-1,  0,  0,  0,  0, -1,  0,  1,  0] [ 9,  3,  0]  1 */
    52447576, /* 74201 (1637) [ 0,  1,  0,  0,  0,  1,  1,  0,  0] [ 6,  6,  0] -1 */
    53331727, /* 74202 (1637) [ 0,  0,  1,  0, -1,  0, -1,  0,  0] [ 6,  9,  9] -1 */
    26230026, /* 74203 (1637) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 9,  3,  0]  1 */
    51916063, /* 74204 (1637) [ 0,  1,  0,  0,  0, -1, -1,  0,  0] [ 6,  3,  9] -1 */
    42583681, /* 74205 (1637) [ 0,  0, -1,  1,  0,  0,  0, -1,  0] [ 3,  0,  3] -1 */
    17018384, /* 74206 (1637) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 6,  0,  0]  1 */
    52570042, /* 74207 (1637) [ 1,  0,  0,  0,  0,  1,  0,  1,  0] [ 6,  6,  6] -1 */
    44766778, /* 74208 (1637) [ 0, -1,  0,  0,  0, -1,  1,  0,  0] [ 3,  9,  6] -1 */
    26228398, /* 74209 (1637) [ 0,  0,  1,  0,  1,  0, -1,  0,  0] [ 9,  3,  0]  1 */
    59714861, /* 74210 (1637) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 9,  0,  9] -1 */
    44007883, /* 74211 (1637) [ 1,  0,  0,  0,  0, -1,  0,  1,  0] [ 3,  6,  3] -1 */
     2313235, /* 74212 (1637) [ 0,  0,  1, -1,  0,  0,  0, -1,  0] [ 0,  9,  9]  1 */
    44002003, /* 74213 (1637) [ 0,  0,  1,  0, -1,  0,  1,  0,  0] [ 3,  6,  3] -1 */
     8574115, /* 74214 (1637) [ 0,  1,  0,  0,  0, -1,  1,  0,  0] [ 3,  0,  3]  1 */
    34133572, /* 74215 (1637) [-1,  0,  0,  0,  0, -1,  0, -1,  0] [ 0,  0,  6] -1 */
    18439772, /* 74216 (1637) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
     8690701, /* 74217 (1637) [ 0,  0,  1,  0, -1,  0,  1,  0,  0] [ 3,  0,  9]  1 */
     9346168, /* 74218 (1637) [ 1,  0,  0,  0,  0,  1,  0, -1,  0] [ 3,  3,  6]  1 */
    36208821, /* 74219 (1637) [ 0,  1,  0, -1,  0,  0,  0,  0, -1] [ 0,  9,  3] -1 */
    53337619, /* 74220 (1637) [ 1,  0,  0,  0,  0, -1,  0, -1,  0] [ 6,  9,  9] -1 */
    10750118, /* 74221 (1637) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 3,  9,  6]  1 */
    44657470, /* 74222 (1637) [ 1,  0,  0,  0,  0,  1,  0, -1,  0] [ 3,  9,  0] -1 */
    17899537, /* 74223 (1637) [ 0, -1,  0,  0,  0,  1,  1,  0,  0] [ 6,  3,  9]  1 */
    34909743, /* 74224 (1637) [ 0,  1,  0, -1,  0,  0,  0,  0, -1] [ 0,  3,  9] -1 */
    34019842, /* 74225 (1637) [ 0, -1,  0,  0,  0, -1, -1,  0,  0] [ 0,  0,  0] -1 */
    52443130, /* 74226 (1637) [ 0, -1,  0,  0,  0, -1, -1,  0,  0] [ 6,  6,  0] -1 */
     8696581, /* 74227 (1637) [ 1,  0,  0,  0,  0, -1,  0,  1,  0] [ 3,  0,  9]  1 */
    18435352, /* 74228 (1637) [ 0,  1,  0,  0,  0,  1,  1,  0,  0] [ 6,  6,  0]  1 */
    42584659, /* 74229 (1637) [ 0,  0,  1, -1,  0,  0,  0,  1,  0] [ 3,  0,  3] -1 */
    61007947, /* 74230 (1637) [ 0,  0,  1, -1,  0,  0,  0,  1,  0] [ 9,  6,  3] -1 */
    44117275, /* 74231 (1637) [ 0, -1,  0,  0,  0,  1, -1,  0,  0] [ 3,  6,  9] -1 */
    25577401, /* 74232 (1637) [ 0,  0, -1,  0,  1,  0, -1,  0,  0] [ 9,  0,  3]  1 */
      130370, /* 74233 (1637) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 0,  0,  6]  1 */
     8571457, /* 74234 (1637) [ 0,  0, -1,  1,  0,  0,  0, -1,  0] [ 3,  0,  3]  1 */
    18557818, /* 74235 (1637) [ 1,  0,  0,  0,  0,  1,  0,  1,  0] [ 6,  6,  6]  1 */
    10754554, /* 74236 (1637) [ 0, -1,  0,  0,  0, -1,  1,  0,  0] [ 3,  9,  6]  1 */
    35445832, /* 74237 (1637) [ 1,  0,  0,  0,  0,  1,  0,  1,  0] [ 0,  6,  0] -1 */
    43994809, /* 74238 (1637) [-1,  0,  0,  0,  0,  1,  0, -1,  0] [ 3,  6,  3] -1 */
    44768014, /* 74239 (1637) [ 0,  0, -1, -1,  0,  0,  0,  1,  0] [ 3,  9,  6] -1 */
    25702637, /* 74240 (1637) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 9,  0,  9]  1 */
    35550696, /* 74241 (1637) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  6] -1 */
    52556860, /* 74242 (1637) [-1,  0,  0,  0,  0, -1,  0, -1,  0] [ 6,  6,  6] -1 */
    27651414, /* 74243 (1637) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 9,  9,  0]  1 */
    60355714, /* 74244 (1637) [ 0, -1,  0,  0,  0, -1,  1,  0,  0] [ 9,  3,  6] -1 */
     9223690, /* 74245 (1637) [ 0,  1,  0,  0,  0,  1, -1,  0,  0] [ 3,  3,  0]  1 */
     9995659, /* 74246 (1637) [ 1,  0,  0,  0,  0, -1,  0,  1,  0] [ 3,  6,  3]  1 */
    61774294, /* 74247 (1637) [ 0,  0, -1,  0, -1,  0,  1,  0,  0] [ 9,  9,  6] -1 */
    51907433, /* 74248 (1637) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  3,  9] -1 */
    43354236, /* 74249 (1637) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 3,  3,  6] -1 */
    53329145, /* 74250 (1637) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 6,  9,  9] -1 */
    51789283, /* 74251 (1637) [-1,  0,  0,  0,  0,  1,  0,  1,  0] [ 6,  3,  3] -1 */
    59592227, /* 74252 (1637) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 9,  0,  3] -1 */
    61650356, /* 74253 (1637) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 9,  9,  0] -1 */
    34790185, /* 74254 (1637) [ 0,  0,  1, -1,  0,  0,  0, -1,  0] [ 0,  3,  3] -1 */
    53213473, /* 74255 (1637) [ 0,  0,  1, -1,  0,  0,  0, -1,  0] [ 6,  9,  3] -1 */
    59701899, /* 74256 (1637) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 9,  0,  9] -1 */
    19325395, /* 74257 (1637) [ 1,  0,  0,  0,  0, -1,  0, -1,  0] [ 6,  9,  9]  1 */
    60351278, /* 74258 (1637) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 9,  3,  6] -1 */
     2194015, /* 74259 (1637) [ 0,  0, -1,  0,  1,  0,  1,  0,  0] [ 0,  9,  3]  1 */
      897519, /* 74260 (1637) [ 0,  1,  0, -1,  0,  0,  0,  0, -1] [ 0,  3,  9]  1 */
        7618, /* 74261 (1637) [ 0, -1,  0,  0,  0, -1, -1,  0,  0] [ 0,  0,  0]  1 */
    18430906, /* 74262 (1637) [ 0, -1,  0,  0,  0, -1, -1,  0,  0] [ 6,  6,  0]  1 */
    34137732, /* 74263 (1637) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  6] -1 */
    26995723, /* 74264 (1637) [ 0,  0,  1, -1,  0,  0,  0,  1,  0] [ 9,  6,  3]  1 */
     1433608, /* 74265 (1637) [ 1,  0,  0,  0,  0,  1,  0,  1,  0] [ 0,  6,  0]  1 */
    34905857, /* 74266 (1637) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 0,  3,  9] -1 */
     9982585, /* 74267 (1637) [-1,  0,  0,  0,  0,  1,  0, -1,  0] [ 3,  6,  3]  1 */
    10755790, /* 74268 (1637) [ 0,  0, -1, -1,  0,  0,  0,  1,  0] [ 3,  9,  6]  1 */
    44769952, /* 74269 (1637) [ 0,  0,  1,  1,  0,  0,  0, -1,  0] [ 3,  9,  6] -1 */
    51913429, /* 74270 (1637) [ 0,  0, -1,  1,  0,  0,  0,  1,  0] [ 6,  3,  9] -1 */
    60356950, /* 74271 (1637) [ 0,  0, -1, -1,  0,  0,  0,  1,  0] [ 9,  3,  6] -1 */
     2310601, /* 74272 (1637) [ 0, -1,  0,  0,  0,  1,  1,  0,  0] [ 0,  9,  9]  1 */
     1538472, /* 74273 (1637) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
    18544636, /* 74274 (1637) [-1,  0,  0,  0,  0, -1,  0, -1,  0] [ 6,  6,  6]  1 */
    61123611, /* 74275 (1637) [ 0, -1,  0,  1,  0,  0,  0,  0, -1] [ 9,  6,  9] -1 */
    27762070, /* 74276 (1637) [ 0,  0, -1,  0, -1,  0,  1,  0,  0] [ 9,  9,  6]  1 */
    35432650, /* 74277 (1637) [-1,  0,  0,  0,  0, -1,  0, -1,  0] [ 0,  6,  0] -1 */
    51920391, /* 74278 (1637) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  3,  9] -1 */
    17895209, /* 74279 (1637) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  3,  9]  1 */
    19316921, /* 74280 (1637) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 6,  9,  9]  1 */
    42704213, /* 74281 (1637) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 3,  0,  9] -1 */
    34021090, /* 74282 (1637) [ 0,  0, -1, -1,  0,  0,  0, -1,  0] [ 0,  0,  0] -1 */
    44125925, /* 74283 (1637) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 3,  6,  9] -1 */
    19201249, /* 74284 (1637) [ 0,  0,  1, -1,  0,  0,  0, -1,  0] [ 6,  9,  3]  1 */
    26339054, /* 74285 (1637) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 9,  3,  6]  1 */
    51139632, /* 74286 (1637) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  6] -1 */
    43227068, /* 74287 (1637) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 3,  3,  0] -1 */
      125508, /* 74288 (1637) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  6]  1 */
    18548796, /* 74289 (1637) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 6,  6,  6]  1 */
    34024288, /* 74290 (1637) [ 0,  1,  0,  0,  0,  1,  1,  0,  0] [ 0,  0,  0] -1 */
    25584595, /* 74291 (1637) [ 1,  0,  0,  0,  0, -1,  0,  1,  0] [ 9,  0,  3]  1 */
    51034768, /* 74292 (1637) [ 1,  0,  0,  0,  0,  1,  0,  1,  0] [ 6,  0,  0] -1 */
    43231504, /* 74293 (1637) [ 0, -1,  0,  0,  0, -1,  1,  0,  0] [ 3,  3,  0] -1 */
    61005289, /* 74294 (1637) [ 0, -1,  0,  0,  0,  1, -1,  0,  0] [ 9,  6,  3] -1 */
    53219469, /* 74295 (1637) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  9,  3] -1 */
    10757728, /* 74296 (1637) [ 0,  0,  1,  1,  0,  0,  0, -1,  0] [ 3,  9,  6]  1 */
    52562632, /* 74297 (1637) [ 0,  0, -1,  0, -1,  0, -1,  0,  0] [ 6,  6,  6] -1 */
    17901205, /* 74298 (1637) [ 0,  0, -1,  1,  0,  0,  0,  1,  0] [ 6,  3,  9]  1 */
    59710549, /* 74299 (1637) [ 0,  1,  0,  0,  0, -1,  1,  0,  0] [ 9,  0,  9] -1 */
    26344726, /* 74300 (1637) [ 0,  0, -1, -1,  0,  0,  0,  1,  0] [ 9,  3,  6]  1 */
    59706211, /* 74301 (1637) [ 0, -1,  0,  0,  0,  1, -1,  0,  0] [ 9,  0,  9] -1 */
    35558314, /* 74302 (1637) [ 0,  0,  1,  1,  0,  0,  0,  1,  0] [ 0,  6,  6] -1 */
    43232740, /* 74303 (1637) [ 0,  0, -1, -1,  0,  0,  0,  1,  0] [ 3,  3,  0] -1 */
     9338782, /* 74304 (1637) [ 0,  0, -1,  0, -1,  0,  1,  0,  0] [ 3,  3,  6]  1 */
     1420426, /* 74305 (1637) [-1,  0,  0,  0,  0, -1,  0, -1,  0] [ 0,  6,  0]  1 */
    17908167, /* 74306 (1637) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  3,  9]  1 */
    44650084, /* 74307 (1637) [ 0,  0, -1,  0, -1,  0,  1,  0,  0] [ 3,  9,  0] -1 */
    26225168, /* 74308 (1637) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 9,  3,  0]  1 */
     8691989, /* 74309 (1637) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 3,  0,  9]  1 */
        8866, /* 74310 (1637) [ 0,  0, -1, -1,  0,  0,  0, -1,  0] [ 0,  0,  0]  1 */
    18432154, /* 74311 (1637) [ 0,  0, -1, -1,  0,  0,  0, -1,  0] [ 6,  6,  0]  1 */
    27115277, /* 74312 (1637) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 9,  6,  9]  1 */
    10113701, /* 74313 (1637) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 3,  6,  9]  1 */
    34028708, /* 74314 (1637) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    36200347, /* 74315 (1637) [-1,  0,  0,  0,  0,  1,  0,  1,  0] [ 0,  9,  3] -1 */
    17127408, /* 74316 (1637) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  6]  1 */
    59707891, /* 74317 (1637) [ 0,  0, -1,  1,  0,  0,  0, -1,  0] [ 9,  0,  9] -1 */
    51802345, /* 74318 (1637) [ 1,  0,  0,  0,  0, -1,  0, -1,  0] [ 6,  3,  3] -1 */
     9214844, /* 74319 (1637) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 3,  3,  0]  1 */
    53330449, /* 74320 (1637) [ 0,  0, -1,  0,  1,  0,  1,  0,  0] [ 6,  9,  9] -1 */
    36318497, /* 74321 (1637) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  9,  9] -1 */
     1424586, /* 74322 (1637) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 0,  6,  0]  1 */
    44003291, /* 74323 (1637) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 3,  6,  3] -1 */
    17785533, /* 74324 (1637) [ 0,  1,  0, -1,  0,  0,  0,  0, -1] [ 6,  3,  3]  1 */
       12064, /* 74325 (1637) [ 0,  1,  0,  0,  0,  1,  1,  0,  0] [ 0,  0,  0]  1 */
    51025746, /* 74326 (1637) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 6,  0,  0] -1 */
    34146754, /* 74327 (1637) [ 1,  0,  0,  0,  0,  1,  0,  1,  0] [ 0,  0,  6] -1 */
    51147250, /* 74328 (1637) [ 0,  0,  1,  1,  0,  0,  0,  1,  0] [ 6,  0,  6] -1 */
    27769456, /* 74329 (1637) [ 1,  0,  0,  0,  0,  1,  0, -1,  0] [ 9,  9,  6]  1 */
      889045, /* 74330 (1637) [-1,  0,  0,  0,  0,  1,  0,  1,  0] [ 0,  3,  9]  1 */
    60358888, /* 74331 (1637) [ 0,  0,  1,  1,  0,  0,  0, -1,  0] [ 9,  3,  6] -1 */
    60239020, /* 74332 (1637) [ 0,  0, -1,  0, -1,  0,  1,  0,  0] [ 9,  3,  0] -1 */
    25693987, /* 74333 (1637) [ 0, -1,  0,  0,  0,  1, -1,  0,  0] [ 9,  0,  9]  1 */
    35438422, /* 74334 (1637) [ 0,  0, -1,  0, -1,  0, -1,  0,  0] [ 0,  6,  0] -1 */
     1546090, /* 74335 (1637) [ 0,  0,  1,  1,  0,  0,  0,  1,  0] [ 0,  6,  6]  1 */
    51793871, /* 74336 (1637) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 6,  3,  3] -1 */
    51021586, /* 74337 (1637) [-1,  0,  0,  0,  0, -1,  0, -1,  0] [ 6,  0,  0] -1 */
    10637860, /* 74338 (1637) [ 0,  0, -1,  0, -1,  0,  1,  0,  0] [ 3,  9,  0]  1 */
    34907161, /* 74339 (1637) [ 0,  0, -1,  0,  1,  0,  1,  0,  0] [ 0,  3,  9] -1 */
    19198615, /* 74340 (1637) [ 0, -1,  0,  0,  0,  1,  1,  0,  0] [ 6,  9,  3]  1 */
    53215141, /* 74341 (1637) [ 0,  1,  0,  0,  0, -1, -1,  0,  0] [ 6,  9,  3] -1 */
    34908439, /* 74342 (1637) [ 0,  0,  1,  0, -1,  0, -1,  0,  0] [ 0,  3,  9] -1 */
    36324493, /* 74343 (1637) [ 0,  0, -1,  1,  0,  0,  0,  1,  0] [ 0,  9,  9] -1 */
    19319503, /* 74344 (1637) [ 0,  0,  1,  0, -1,  0, -1,  0,  0] [ 6,  9,  9]  1 */
    44121613, /* 74345 (1637) [ 0,  1,  0,  0,  0, -1,  1,  0,  0] [ 3,  6,  9] -1 */
     2188123, /* 74346 (1637) [-1,  0,  0,  0,  0,  1,  0,  1,  0] [ 0,  9,  3]  1 */
    25695667, /* 74347 (1637) [ 0,  0, -1,  1,  0,  0,  0, -1,  0] [ 9,  0,  9]  1 */
    17903839, /* 74348 (1637) [ 0,  1,  0,  0,  0, -1, -1,  0,  0] [ 6,  3,  9]  1 */
    19318225, /* 74349 (1637) [ 0,  0, -1,  0,  1,  0,  1,  0,  0] [ 6,  9,  9]  1 */
    42590651, /* 74350 (1637) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 3,  0,  3] -1 */
    36331455, /* 74351 (1637) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  9,  9] -1 */
    61013939, /* 74352 (1637) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 9,  6,  3] -1 */
     2306273, /* 74353 (1637) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  9,  9]  1 */
    61119019, /* 74354 (1637) [-1,  0,  0,  0,  0,  1,  0, -1,  0] [ 9,  6,  9] -1 */
    61777524, /* 74355 (1637) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 9,  9,  6] -1 */
    34787551, /* 74356 (1637) [ 0, -1,  0,  0,  0,  1,  1,  0,  0] [ 0,  3,  3] -1 */
    17013522, /* 74357 (1637) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 6,  0,  0]  1 */
      134530, /* 74358 (1637) [ 1,  0,  0,  0,  0,  1,  0,  1,  0] [ 0,  0,  6]  1 */
    43349378, /* 74359 (1637) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 3,  3,  6] -1 */
    61654792, /* 74360 (1637) [ 0, -1,  0,  0,  0, -1,  1,  0,  0] [ 9,  9,  0] -1 */
    17135026, /* 74361 (1637) [ 0,  0,  1,  1,  0,  0,  0,  1,  0] [ 6,  0,  6]  1 */
    35556364, /* 74362 (1637) [ 0,  0, -1, -1,  0,  0,  0, -1,  0] [ 0,  6,  6] -1 */
    61124899, /* 74363 (1637) [ 0,  0, -1,  0,  1,  0, -1,  0,  0] [ 9,  6,  9] -1 */
    26226796, /* 74364 (1637) [ 0,  0, -1,  0, -1,  0,  1,  0,  0] [ 9,  3,  0]  1 */
     9989779, /* 74365 (1637) [ 0,  0,  1,  0, -1,  0,  1,  0,  0] [ 3,  6,  3]  1 */
    36213409, /* 74366 (1637) [ 1,  0,  0,  0,  0, -1,  0, -1,  0] [ 0,  9,  3] -1 */
    43234678, /* 74367 (1637) [ 0,  0,  1,  1,  0,  0,  0, -1,  0] [ 3,  3,  0] -1 */
    43345222, /* 74368 (1637) [-1,  0,  0,  0,  0, -1,  0,  1,  0] [ 3,  3,  6] -1 */
    61775896, /* 74369 (1637) [ 0,  0,  1,  0,  1,  0, -1,  0,  0] [ 9,  9,  6] -1 */
    34914331, /* 74370 (1637) [ 1,  0,  0,  0,  0, -1,  0, -1,  0] [ 0,  3,  9] -1 */
    60246406, /* 74371 (1637) [ 1,  0,  0,  0,  0,  1,  0, -1,  0] [ 9,  3,  0] -1 */
    51027358, /* 74372 (1637) [ 0,  0, -1,  0, -1,  0, -1,  0,  0] [ 6,  0,  0] -1 */
      121348, /* 74373 (1637) [-1,  0,  0,  0,  0, -1,  0, -1,  0] [ 0,  0,  6]  1 */
     2196597, /* 74374 (1637) [ 0,  1,  0, -1,  0,  0,  0,  0, -1] [ 0,  9,  3]  1 */
      896215, /* 74375 (1637) [ 0,  0,  1,  0, -1,  0, -1,  0,  0] [ 0,  3,  9]  1 */
    10645246, /* 74376 (1637) [ 1,  0,  0,  0,  0,  1,  0, -1,  0] [ 3,  9,  0]  1 */
     2312269, /* 74377 (1637) [ 0,  0, -1,  1,  0,  0,  0,  1,  0] [ 0,  9,  9]  1 */
    44771188, /* 74378 (1637) [ 0,  1,  0,  0,  0,  1, -1,  0,  0] [ 3,  9,  6] -1 */
    43352608, /* 74379 (1637) [ 0,  0,  1,  0,  1,  0, -1,  0,  0] [ 3,  3,  6] -1 */
     8572435, /* 74380 (1637) [ 0,  0,  1, -1,  0,  0,  0,  1,  0] [ 3,  0,  3]  1 */
    10105051, /* 74381 (1637) [ 0, -1,  0,  0,  0,  1, -1,  0,  0] [ 3,  6,  9]  1 */
     2319231, /* 74382 (1637) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  9,  9]  1 */
    27001715, /* 74383 (1637) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 9,  6,  3]  1 */
    27765300, /* 74384 (1637) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 9,  9,  6]  1 */
      775327, /* 74385 (1637) [ 0, -1,  0,  0,  0,  1,  1,  0,  0] [ 0,  3,  3]  1 */
    34783223, /* 74386 (1637) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  3,  3] -1 */
    53206511, /* 74387 (1637) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  9,  3] -1 */
    27642568, /* 74388 (1637) [ 0, -1,  0,  0,  0, -1,  1,  0,  0] [ 9,  9,  0]  1 */
    35563982, /* 74389 (1637) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
    44118955, /* 74390 (1637) [ 0,  0, -1,  1,  0,  0,  0, -1,  0] [ 3,  6,  9] -1 */
    36327127, /* 74391 (1637) [ 0,  1,  0,  0,  0, -1, -1,  0,  0] [ 0,  9,  9] -1 */
    42700323, /* 74392 (1637) [ 0, -1,  0,  1,  0,  0,  0,  0, -1] [ 3,  0,  9] -1 */
    26343490, /* 74393 (1637) [ 0, -1,  0,  0,  0, -1,  1,  0,  0] [ 9,  3,  6]  1 */
    34140982, /* 74394 (1637) [ 0,  0,  1,  0,  1,  0,  1,  0,  0] [ 0,  0,  6] -1 */
    27112675, /* 74395 (1637) [ 0,  0, -1,  0,  1,  0, -1,  0,  0] [ 9,  6,  9]  1 */
    61000977, /* 74396 (1637) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 9,  6,  3] -1 */
     9332998, /* 74397 (1637) [-1,  0,  0,  0,  0, -1,  0,  1,  0] [ 3,  3,  6]  1 */
    35559562, /* 74398 (1637) [ 0,  1,  0,  0,  0,  1,  1,  0,  0] [ 0,  6,  6] -1 */
     9342012, /* 74399 (1637) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 3,  3,  6]  1 */
      902107, /* 74400 (1637) [ 1,  0,  0,  0,  0, -1,  0, -1,  0] [ 0,  3,  9]  1 */
    26234182, /* 74401 (1637) [ 1,  0,  0,  0,  0,  1,  0, -1,  0] [ 9,  3,  0]  1 */
    44653314, /* 74402 (1637) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 3,  9,  0] -1 */
    17777059, /* 74403 (1637) [-1,  0,  0,  0,  0,  1,  0,  1,  0] [ 6,  3,  3]  1 */
    25580003, /* 74404 (1637) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 9,  0,  3]  1 */
    27638132, /* 74405 (1637) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 9,  9,  0]  1 */
      777961, /* 74406 (1637) [ 0,  0,  1, -1,  0,  0,  0, -1,  0] [ 0,  3,  3]  1 */
    25689675, /* 74407 (1637) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 9,  0,  9]  1 */
    10758964, /* 74408 (1637) [ 0,  1,  0,  0,  0,  1, -1,  0,  0] [ 3,  9,  6]  1 */
     9340384, /* 74409 (1637) [ 0,  0,  1,  0,  1,  0, -1,  0,  0] [ 3,  3,  6]  1 */
    51795175, /* 74410 (1637) [ 0,  0, -1,  0,  1,  0,  1,  0,  0] [ 6,  3,  3] -1 */
    44651686, /* 74411 (1637) [ 0,  0,  1,  0,  1,  0, -1,  0,  0] [ 3,  9,  0] -1 */
    36204935, /* 74412 (1637) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 0,  9,  3] -1 */
    51796453, /* 74413 (1637) [ 0,  0,  1,  0, -1,  0, -1,  0,  0] [ 6,  3,  3] -1 */
    44775624, /* 74414 (1637) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 3,  9,  6] -1 */
    34789219, /* 74415 (1637) [ 0,  0, -1,  1,  0,  0,  0,  1,  0] [ 0,  3,  3] -1 */
    53212507, /* 74416 (1637) [ 0,  0, -1,  1,  0,  0,  0,  1,  0] [ 6,  9,  3] -1 */
    61656028, /* 74417 (1637) [ 0,  0, -1, -1,  0,  0,  0,  1,  0] [ 9,  9,  0] -1 */
    52564270, /* 74418 (1637) [ 0,  0,  1,  0,  1,  0,  1,  0,  0] [ 6,  6,  6] -1 */
    51152918, /* 74419 (1637) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
    61009627, /* 74420 (1637) [ 0,  1,  0,  0,  0, -1,  1,  0,  0] [ 9,  6,  3] -1 */
    60360124, /* 74421 (1637) [ 0,  1,  0,  0,  0,  1, -1,  0,  0] [ 9,  3,  6] -1 */
      893633, /* 74422 (1637) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 0,  3,  9]  1 */
    34015422, /* 74423 (1637) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    52438710, /* 74424 (1637) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
    34796181, /* 74425 (1637) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  3,  3] -1 */
    34139344, /* 74426 (1637) [ 0,  0, -1,  0, -1,  0, -1,  0,  0] [ 0,  0,  6] -1 */
    19194287, /* 74427 (1637) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  9,  3]  1 */
    59583745, /* 74428 (1637) [-1,  0,  0,  0,  0,  1,  0, -1,  0] [ 9,  0,  3] -1 */
     1551758, /* 74429 (1637) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
    51148498, /* 74430 (1637) [ 0,  1,  0,  0,  0,  1,  1,  0,  0] [ 6,  0,  6] -1 */
     2314903, /* 74431 (1637) [ 0,  1,  0,  0,  0, -1, -1,  0,  0] [ 0,  9,  9]  1 */
     8688099, /* 74432 (1637) [ 0, -1,  0,  1,  0,  0,  0,  0, -1] [ 3,  0,  9]  1 */
    27111387, /* 74433 (1637) [ 0, -1,  0,  1,  0,  0,  0,  0, -1] [ 9,  6,  9]  1 */
    60242250, /* 74434 (1637) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 9,  3,  0] -1 */
    35555116, /* 74435 (1637) [ 0, -1,  0,  0,  0, -1, -1,  0,  0] [ 0,  6,  6] -1 */
    61132093, /* 74436 (1637) [ 1,  0,  0,  0,  0, -1,  0,  1,  0] [ 9,  6,  9] -1 */
    61126213, /* 74437 (1637) [ 0,  0,  1,  0, -1,  0,  1,  0,  0] [ 9,  6,  9] -1 */
    60240622, /* 74438 (1637) [ 0,  0,  1,  0,  1,  0, -1,  0,  0] [ 9,  3,  0] -1 */
    17782951, /* 74439 (1637) [ 0,  0, -1,  0,  1,  0,  1,  0,  0] [ 6,  3,  3]  1 */
    17784229, /* 74440 (1637) [ 0,  0,  1,  0, -1,  0, -1,  0,  0] [ 6,  3,  3]  1 */
    10763400, /* 74441 (1637) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 3,  9,  6]  1 */
    19200283, /* 74442 (1637) [ 0,  0, -1,  1,  0,  0,  0,  1,  0] [ 6,  9,  3]  1 */
    27643804, /* 74443 (1637) [ 0,  0, -1, -1,  0,  0,  0,  1,  0] [ 9,  9,  0]  1 */
    18552046, /* 74444 (1637) [ 0,  0,  1,  0,  1,  0,  1,  0,  0] [ 6,  6,  6]  1 */
    42582001, /* 74445 (1637) [ 0, -1,  0,  0,  0,  1, -1,  0,  0] [ 3,  0,  3] -1 */
    44112963, /* 74446 (1637) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 3,  6,  9] -1 */
    60364560, /* 74447 (1637) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 9,  3,  6] -1 */
    61657966, /* 74448 (1637) [ 0,  0,  1,  1,  0,  0,  0, -1,  0] [ 9,  9,  0] -1 */
    17022544, /* 74449 (1637) [ 1,  0,  0,  0,  0,  1,  0,  1,  0] [ 6,  0,  0]  1 */
     9219280, /* 74450 (1637) [ 0, -1,  0,  0,  0, -1,  1,  0,  0] [ 3,  3,  0]  1 */
    42702925, /* 74451 (1637) [ 0,  0,  1,  0, -1,  0,  1,  0,  0] [ 3,  0,  9] -1 */
    18426486, /* 74452 (1637) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
    35440060, /* 74453 (1637) [ 0,  0,  1,  0,  1,  0,  1,  0,  0] [ 0,  6,  0] -1 */
      783957, /* 74454 (1637) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  3,  3]  1 */
    26993065, /* 74455 (1637) [ 0, -1,  0,  0,  0,  1, -1,  0,  0] [ 9,  6,  3]  1 */
    19207245, /* 74456 (1637) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  9,  3]  1 */
    18550408, /* 74457 (1637) [ 0,  0, -1,  0, -1,  0, -1,  0,  0] [ 6,  6,  6]  1 */
      127120, /* 74458 (1637) [ 0,  0, -1,  0, -1,  0, -1,  0,  0] [ 0,  0,  6]  1 */
    44762342, /* 74459 (1637) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 3,  9,  6] -1 */
    25698325, /* 74460 (1637) [ 0,  1,  0,  0,  0, -1,  1,  0,  0] [ 9,  0,  9]  1 */
    51144052, /* 74461 (1637) [ 0, -1,  0,  0,  0, -1, -1,  0,  0] [ 6,  0,  6] -1 */
    51911761, /* 74462 (1637) [ 0, -1,  0,  0,  0,  1,  1,  0,  0] [ 6,  3,  9] -1 */
    42708805, /* 74463 (1637) [ 1,  0,  0,  0,  0, -1,  0,  1,  0] [ 3,  0,  9] -1 */
     9220516, /* 74464 (1637) [ 0,  0, -1, -1,  0,  0,  0,  1,  0] [ 3,  3,  0]  1 */
    53333031, /* 74465 (1637) [ 0,  1,  0, -1,  0,  0,  0,  0, -1] [ 6,  9,  9] -1 */
     1542892, /* 74466 (1637) [ 0, -1,  0,  0,  0, -1, -1,  0,  0] [ 0,  6,  6]  1 */
    36207517, /* 74467 (1637) [ 0,  0,  1,  0, -1,  0, -1,  0,  0] [ 0,  9,  3] -1 */
    27119869, /* 74468 (1637) [ 1,  0,  0,  0,  0, -1,  0,  1,  0] [ 9,  6,  9]  1 */
    59589625, /* 74469 (1637) [ 0,  0, -1,  0,  1,  0, -1,  0,  0] [ 9,  0,  3] -1 */
    27113989, /* 74470 (1637) [ 0,  0,  1,  0, -1,  0,  1,  0,  0] [ 9,  6,  9]  1 */
    34142594, /* 74471 (1637) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    61006969, /* 74472 (1637) [ 0,  0, -1,  1,  0,  0,  0, -1,  0] [ 9,  6,  3] -1 */
    34791853, /* 74473 (1637) [ 0,  1,  0,  0,  0, -1, -1,  0,  0] [ 0,  3,  3] -1 */
    59588337, /* 74474 (1637) [ 0, -1,  0,  1,  0,  0,  0,  0, -1] [ 9,  0,  3] -1 */
    59708869, /* 74475 (1637) [ 0,  0,  1, -1,  0,  0,  0,  1,  0] [ 9,  0,  9] -1 */
    17790121, /* 74476 (1637) [ 1,  0,  0,  0,  0, -1,  0, -1,  0] [ 6,  3,  3]  1 */
    61772666, /* 74477 (1637) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 9,  9,  6] -1 */
    61663638, /* 74478 (1637) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 9,  9,  0] -1 */
    42695731, /* 74479 (1637) [-1,  0,  0,  0,  0,  1,  0, -1,  0] [ 3,  0,  9] -1 */
    43235914, /* 74480 (1637) [ 0,  1,  0,  0,  0,  1, -1,  0,  0] [ 3,  3,  0] -1 */
     9991067, /* 74481 (1637) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 3,  6,  3]  1 */
    61768510, /* 74482 (1637) [-1,  0,  0,  0,  0, -1,  0,  1,  0] [ 9,  9,  6] -1 */
     8569777, /* 74483 (1637) [ 0, -1,  0,  0,  0,  1, -1,  0,  0] [ 3,  0,  3]  1 */
    10100739, /* 74484 (1637) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 3,  6,  9]  1 */
    26352336, /* 74485 (1637) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 9,  3,  6]  1 */
    27645742, /* 74486 (1637) [ 0,  0,  1,  1,  0,  0,  0, -1,  0] [ 9,  9,  0]  1 */
     1427836, /* 74487 (1637) [ 0,  0,  1,  0,  1,  0,  1,  0,  0] [ 0,  6,  0]  1 */
    52565882, /* 74488 (1637) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    43240350, /* 74489 (1637) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 3,  3,  0] -1 */
    26346664, /* 74490 (1637) [ 0,  0,  1,  1,  0,  0,  0, -1,  0] [ 9,  3,  6]  1 */
    34023040, /* 74491 (1637) [ 0,  0,  1,  1,  0,  0,  0,  1,  0] [ 0,  0,  0] -1 */
    52446328, /* 74492 (1637) [ 0,  0,  1,  1,  0,  0,  0,  1,  0] [ 6,  6,  0] -1 */
    17131828, /* 74493 (1637) [ 0, -1,  0,  0,  0, -1, -1,  0,  0] [ 6,  0,  6]  1 */
    36206239, /* 74494 (1637) [ 0,  0, -1,  0,  1,  0,  1,  0,  0] [ 0,  9,  3] -1 */
    51028996, /* 74495 (1637) [ 0,  0,  1,  0,  1,  0,  1,  0,  0] [ 6,  0,  0] -1 */
     1426198, /* 74496 (1637) [ 0,  0, -1,  0, -1,  0, -1,  0,  0] [ 0,  6,  0]  1 */
    17781647, /* 74497 (1637) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 6,  3,  3]  1 */
    51914395, /* 74498 (1637) [ 0,  0,  1, -1,  0,  0,  0, -1,  0] [ 6,  3,  9] -1 */
    17009362, /* 74499 (1637) [-1,  0,  0,  0,  0, -1,  0, -1,  0] [ 6,  0,  0]  1 */
    19320807, /* 74500 (1637) [ 0,  1,  0, -1,  0,  0,  0,  0, -1] [ 6,  9,  9]  1 */
      894937, /* 74501 (1637) [ 0,  0, -1,  0,  1,  0,  1,  0,  0] [ 0,  3,  9]  1 */
     2195293, /* 74502 (1637) [ 0,  0,  1,  0, -1,  0, -1,  0,  0] [ 0,  9,  3]  1 */
    26994745, /* 74503 (1637) [ 0,  0, -1,  1,  0,  0,  0, -1,  0] [ 9,  6,  3]  1 */
      779629, /* 74504 (1637) [ 0,  1,  0,  0,  0, -1, -1,  0,  0] [ 0,  3,  3]  1 */
    19202917, /* 74505 (1637) [ 0,  1,  0,  0,  0, -1, -1,  0,  0] [ 6,  9,  3]  1 */
    25576113, /* 74506 (1637) [ 0, -1,  0,  1,  0,  0,  0,  0, -1] [ 9,  0,  3]  1 */
    25696645, /* 74507 (1637) [ 0,  0,  1, -1,  0,  0,  0,  1,  0] [ 9,  0,  9]  1 */
    10109389, /* 74508 (1637) [ 0,  1,  0,  0,  0, -1,  1,  0,  0] [ 3,  6,  9]  1 */
    36322825, /* 74509 (1637) [ 0, -1,  0,  0,  0,  1,  1,  0,  0] [ 0,  9,  9] -1 */
    27760442, /* 74510 (1637) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 9,  9,  6]  1 */
     8578427, /* 74511 (1637) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 3,  0,  3]  1 */
     8683507, /* 74512 (1637) [-1,  0,  0,  0,  0,  1,  0, -1,  0] [ 3,  0,  9]  1 */
    27106795, /* 74513 (1637) [-1,  0,  0,  0,  0,  1,  0, -1,  0] [ 9,  6,  9]  1 */
    27756286, /* 74514 (1637) [-1,  0,  0,  0,  0, -1,  0,  1,  0] [ 9,  9,  6]  1 */
    51145300, /* 74515 (1637) [ 0,  0, -1, -1,  0,  0,  0, -1,  0] [ 6,  0,  6] -1 */
    42701611, /* 74516 (1637) [ 0,  0, -1,  0,  1,  0, -1,  0,  0] [ 3,  0,  9] -1 */
     9337154, /* 74517 (1637) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 3,  3,  6]  1 */
     1544140, /* 74518 (1637) [ 0,  0, -1, -1,  0,  0,  0, -1,  0] [ 0,  6,  6]  1 */
     9228126, /* 74519 (1637) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 3,  3,  0]  1 */
    18553658, /* 74520 (1637) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    44648456, /* 74521 (1637) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 3,  9,  0] -1 */
       10816, /* 74522 (1637) [ 0,  0,  1,  1,  0,  0,  0,  1,  0] [ 0,  0,  0]  1 */
    18434104, /* 74523 (1637) [ 0,  0,  1,  1,  0,  0,  0,  1,  0] [ 6,  6,  0]  1 */
    17016772, /* 74524 (1637) [ 0,  0,  1,  0,  1,  0,  1,  0,  0] [ 6,  0,  0]  1 */
    35441672, /* 74525 (1637) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 0,  6,  0] -1 */
     2201185, /* 74526 (1637) [ 1,  0,  0,  0,  0, -1,  0, -1,  0] [ 0,  9,  3]  1 */
     9222454, /* 74527 (1637) [ 0,  0,  1,  1,  0,  0,  0, -1,  0] [ 3,  3,  0]  1 */
    52561020, /* 74528 (1637) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    27763672, /* 74529 (1637) [ 0,  0,  1,  0,  1,  0, -1,  0,  0] [ 9,  9,  6]  1 */
    17902171, /* 74530 (1637) [ 0,  0,  1, -1,  0,  0,  0, -1,  0] [ 6,  3,  9]  1 */
    44644300, /* 74531 (1637) [-1,  0,  0,  0,  0, -1,  0,  1,  0] [ 3,  9,  0] -1 */
    59590939, /* 74532 (1637) [ 0,  0,  1,  0, -1,  0,  1,  0,  0] [ 9,  0,  3] -1 */
    17015134, /* 74533 (1637) [ 0,  0, -1,  0, -1,  0, -1,  0,  0] [ 6,  0,  0]  1 */
    59596819, /* 74534 (1637) [ 1,  0,  0,  0,  0, -1,  0,  1,  0] [ 9,  0,  3] -1 */
    44000689, /* 74535 (1637) [ 0,  0, -1,  0,  1,  0, -1,  0,  0] [ 3,  6,  3] -1 */
    53324557, /* 74536 (1637) [-1,  0,  0,  0,  0,  1,  0,  1,  0] [ 6,  9,  9] -1 */
    61659202, /* 74537 (1637) [ 0,  1,  0,  0,  0,  1, -1,  0,  0] [ 9,  9,  0] -1 */
    43351006, /* 74538 (1637) [ 0,  0, -1,  0, -1,  0,  1,  0,  0] [ 3,  3,  6] -1 */
    42577689, /* 74539 (1637) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 3,  0,  3] -1 */
    43999401, /* 74540 (1637) [ 0, -1,  0,  1,  0,  0,  0,  0, -1] [ 3,  6,  3] -1 */
    17133076, /* 74541 (1637) [ 0,  0, -1, -1,  0,  0,  0, -1,  0] [ 6,  0,  6]  1 */
    60237392, /* 74542 (1637) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 9,  3,  0] -1 */
    52444378, /* 74543 (1637) [ 0,  0, -1, -1,  0,  0,  0, -1,  0] [ 6,  6,  0] -1 */
    61127501, /* 74544 (1637) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 9,  6,  9] -1 */
      770999, /* 74545 (1637) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  3,  3]  1 */
    44119933, /* 74546 (1637) [ 0,  0,  1, -1,  0,  0,  0,  1,  0] [ 3,  6,  9] -1 */
     8689387, /* 74547 (1637) [ 0,  0, -1,  0,  1,  0, -1,  0,  0] [ 3,  0,  9]  1 */
    10106731, /* 74548 (1637) [ 0,  0, -1,  1,  0,  0,  0, -1,  0] [ 3,  6,  9]  1 */
    10636232, /* 74549 (1637) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 3,  9,  0]  1 */
    60233236, /* 74550 (1637) [-1,  0,  0,  0,  0, -1,  0,  1,  0] [ 9,  3,  0] -1 */
      128758, /* 74551 (1637) [ 0,  0,  1,  0,  1,  0,  1,  0,  0] [ 0,  0,  6]  1 */
     1429448, /* 74552 (1637) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 0,  6,  0]  1 */
    26988753, /* 74553 (1637) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 9,  6,  3]  1 */
     1547338, /* 74554 (1637) [ 0,  1,  0,  0,  0,  1,  1,  0,  0] [ 0,  6,  6]  1 */
    10632076, /* 74555 (1637) [-1,  0,  0,  0,  0, -1,  0,  1,  0] [ 3,  9,  0]  1 */
    25578715, /* 74556 (1637) [ 0,  0,  1,  0, -1,  0,  1,  0,  0] [ 9,  0,  3]  1 */
    51030608, /* 74557 (1637) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 6,  0,  0] -1 */
    10641090, /* 74558 (1637) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 3,  9,  0]  1 */
    35436810, /* 74559 (1637) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 0,  6,  0] -1 */
    51797757, /* 74560 (1637) [ 0,  1,  0, -1,  0,  0,  0,  0, -1] [ 6,  3,  3] -1 */
     9988465, /* 74561 (1637) [ 0,  0, -1,  0,  1,  0, -1,  0,  0] [ 3,  6,  3]  1 */
    61781680, /* 74562 (1637) [ 1,  0,  0,  0,  0,  1,  0, -1,  0] [ 9,  9,  6] -1 */
    34901269, /* 74563 (1637) [-1,  0,  0,  0,  0,  1,  0,  1,  0] [ 0,  3,  9] -1 */
    10639462, /* 74564 (1637) [ 0,  0,  1,  0,  1,  0, -1,  0,  0] [ 3,  9,  0]  1 */
     2192711, /* 74565 (1637) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 0,  9,  3]  1 */
    36325459, /* 74566 (1637) [ 0,  0,  1, -1,  0,  0,  0, -1,  0] [ 0,  9,  9] -1 */
    42586339, /* 74567 (1637) [ 0,  1,  0,  0,  0, -1,  1,  0,  0] [ 3,  0,  3] -1 */
    19312333, /* 74568 (1637) [-1,  0,  0,  0,  0,  1,  0,  1,  0] [ 6,  9,  9]  1 */
      776995, /* 74569 (1637) [ 0,  0, -1,  1,  0,  0,  0,  1,  0] [ 0,  3,  3]  1 */
    27646978, /* 74570 (1637) [ 0,  1,  0,  0,  0,  1, -1,  0,  0] [ 9,  9,  0]  1 */
       16484, /* 74571 (1638) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    61663638, /* 74572 (1638) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 9,  9,  0] -1 */
    44125925, /* 74573 (1638) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 3,  6,  9] -1 */
    44771188, /* 74574 (1638) [ 0,  1,  0,  0,  0,  1, -1,  0,  0] [ 3,  9,  6] -1 */
     8565465, /* 74575 (1638) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 3,  0,  3]  1 */
    17140694, /* 74576 (1638) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
    19201249, /* 74577 (1638) [ 0,  0,  1, -1,  0,  0,  0, -1,  0] [ 6,  9,  3]  1 */
    43352608, /* 74578 (1638) [ 0,  0,  1,  0,  1,  0, -1,  0,  0] [ 3,  3,  6] -1 */
     9987177, /* 74579 (1638) [ 0, -1,  0,  1,  0,  0,  0,  0, -1] [ 3,  6,  3]  1 */
    43235914, /* 74580 (1638) [ 0,  1,  0,  0,  0,  1, -1,  0,  0] [ 3,  3,  0] -1 */
    26339054, /* 74581 (1638) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 9,  3,  6]  1 */
    53210839, /* 74582 (1638) [ 0, -1,  0,  0,  0,  1,  1,  0,  0] [ 6,  9,  3] -1 */
    43358392, /* 74583 (1638) [ 1,  0,  0,  0,  0,  1,  0, -1,  0] [ 3,  3,  6] -1 */
    51139632, /* 74584 (1638) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  6] -1 */
    10105051, /* 74585 (1638) [ 0, -1,  0,  0,  0,  1, -1,  0,  0] [ 3,  6,  9]  1 */
     2319231, /* 74586 (1638) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  9,  9]  1 */
     8569777, /* 74587 (1638) [ 0, -1,  0,  0,  0,  1, -1,  0,  0] [ 3,  0,  3]  1 */
    10100739, /* 74588 (1638) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 3,  6,  9]  1 */
    25571521, /* 74589 (1638) [-1,  0,  0,  0,  0,  1,  0, -1,  0] [ 9,  0,  3]  1 */
    17136274, /* 74590 (1638) [ 0,  1,  0,  0,  0,  1,  1,  0,  0] [ 6,  0,  6]  1 */
    26221012, /* 74591 (1638) [-1,  0,  0,  0,  0, -1,  0,  1,  0] [ 9,  3,  0]  1 */
     1427836, /* 74592 (1638) [ 0,  0,  1,  0,  1,  0,  1,  0,  0] [ 0,  6,  0]  1 */
    43240350, /* 74593 (1638) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 3,  3,  0] -1 */
    36206239, /* 74594 (1638) [ 0,  0, -1,  0,  1,  0,  1,  0,  0] [ 0,  9,  3] -1 */
    34783223, /* 74595 (1638) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  3,  3] -1 */
    53206511, /* 74596 (1638) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  9,  3] -1 */
    27642568, /* 74597 (1638) [ 0, -1,  0,  0,  0, -1,  1,  0,  0] [ 9,  9,  0]  1 */
    17018384, /* 74598 (1638) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 6,  0,  0]  1 */
    19320807, /* 74599 (1638) [ 0,  1,  0, -1,  0,  0,  0,  0, -1] [ 6,  9,  9]  1 */
    26343490, /* 74600 (1638) [ 0, -1,  0,  0,  0, -1,  1,  0,  0] [ 9,  3,  6]  1 */
    27112675, /* 74601 (1638) [ 0,  0, -1,  0,  1,  0, -1,  0,  0] [ 9,  6,  9]  1 */
    59710549, /* 74602 (1638) [ 0,  1,  0,  0,  0, -1,  1,  0,  0] [ 9,  0,  9] -1 */
    52562632, /* 74603 (1638) [ 0,  0, -1,  0, -1,  0, -1,  0,  0] [ 6,  6,  6] -1 */
     2195293, /* 74604 (1638) [ 0,  0,  1,  0, -1,  0, -1,  0,  0] [ 0,  9,  3]  1 */
     9332998, /* 74605 (1638) [-1,  0,  0,  0,  0, -1,  0,  1,  0] [ 3,  3,  6]  1 */
    26344726, /* 74606 (1638) [ 0,  0, -1, -1,  0,  0,  0,  1,  0] [ 9,  3,  6]  1 */
    59714861, /* 74607 (1638) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 9,  0,  9] -1 */
    26994745, /* 74608 (1638) [ 0,  0, -1,  1,  0,  0,  0, -1,  0] [ 9,  6,  3]  1 */
      779629, /* 74609 (1638) [ 0,  1,  0,  0,  0, -1, -1,  0,  0] [ 0,  3,  3]  1 */
    19202917, /* 74610 (1638) [ 0,  1,  0,  0,  0, -1, -1,  0,  0] [ 6,  9,  3]  1 */
    25576113, /* 74611 (1638) [ 0, -1,  0,  1,  0,  0,  0,  0, -1] [ 9,  0,  3]  1 */
      902107, /* 74612 (1638) [ 1,  0,  0,  0,  0, -1,  0, -1,  0] [ 0,  3,  9]  1 */
    44653314, /* 74613 (1638) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 3,  9,  0] -1 */
     9338782, /* 74614 (1638) [ 0,  0, -1,  0, -1,  0,  1,  0,  0] [ 3,  3,  6]  1 */
    27638132, /* 74615 (1638) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 9,  9,  0]  1 */
      777961, /* 74616 (1638) [ 0,  0,  1, -1,  0,  0,  0, -1,  0] [ 0,  3,  3]  1 */
    17908167, /* 74617 (1638) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  3,  9]  1 */
    44007883, /* 74618 (1638) [ 1,  0,  0,  0,  0, -1,  0,  1,  0] [ 3,  6,  3] -1 */
    25689675, /* 74619 (1638) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 9,  0,  9]  1 */
     2313235, /* 74620 (1638) [ 0,  0,  1, -1,  0,  0,  0, -1,  0] [ 0,  9,  9]  1 */
    44002003, /* 74621 (1638) [ 0,  0,  1,  0, -1,  0,  1,  0,  0] [ 3,  6,  3] -1 */
    26225168, /* 74622 (1638) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 9,  3,  0]  1 */
    36322825, /* 74623 (1638) [ 0, -1,  0,  0,  0,  1,  1,  0,  0] [ 0,  9,  9] -1 */
    27760442, /* 74624 (1638) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 9,  9,  6]  1 */
     8683507, /* 74625 (1638) [-1,  0,  0,  0,  0,  1,  0, -1,  0] [ 3,  0,  9]  1 */
    51795175, /* 74626 (1638) [ 0,  0, -1,  0,  1,  0,  1,  0,  0] [ 6,  3,  3] -1 */
    27106795, /* 74627 (1638) [-1,  0,  0,  0,  0,  1,  0, -1,  0] [ 9,  6,  9]  1 */
    34133572, /* 74628 (1638) [-1,  0,  0,  0,  0, -1,  0, -1,  0] [ 0,  0,  6] -1 */
    18439772, /* 74629 (1638) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    44651686, /* 74630 (1638) [ 0,  0,  1,  0,  1,  0, -1,  0,  0] [ 3,  9,  0] -1 */
    36204935, /* 74631 (1638) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 0,  9,  3] -1 */
    27756286, /* 74632 (1638) [-1,  0,  0,  0,  0, -1,  0,  1,  0] [ 9,  9,  6]  1 */
    51145300, /* 74633 (1638) [ 0,  0, -1, -1,  0,  0,  0, -1,  0] [ 6,  0,  6] -1 */
    36200347, /* 74634 (1638) [-1,  0,  0,  0,  0,  1,  0,  1,  0] [ 0,  9,  3] -1 */
    10750118, /* 74635 (1638) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 3,  9,  6]  1 */
    44657470, /* 74636 (1638) [ 1,  0,  0,  0,  0,  1,  0, -1,  0] [ 3,  9,  0] -1 */
    44775624, /* 74637 (1638) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 3,  9,  6] -1 */
    34789219, /* 74638 (1638) [ 0,  0, -1,  1,  0,  0,  0,  1,  0] [ 0,  3,  3] -1 */
     9214844, /* 74639 (1638) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 3,  3,  0]  1 */
    53212507, /* 74640 (1638) [ 0,  0, -1,  1,  0,  0,  0,  1,  0] [ 6,  9,  3] -1 */
    53330449, /* 74641 (1638) [ 0,  0, -1,  0,  1,  0,  1,  0,  0] [ 6,  9,  9] -1 */
    34019842, /* 74642 (1638) [ 0, -1,  0,  0,  0, -1, -1,  0,  0] [ 0,  0,  0] -1 */
    52443130, /* 74643 (1638) [ 0, -1,  0,  0,  0, -1, -1,  0,  0] [ 6,  6,  0] -1 */
    36318497, /* 74644 (1638) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  9,  9] -1 */
     9337154, /* 74645 (1638) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 3,  3,  6]  1 */
    18435352, /* 74646 (1638) [ 0,  1,  0,  0,  0,  1,  1,  0,  0] [ 6,  6,  0]  1 */
    61009627, /* 74647 (1638) [ 0,  1,  0,  0,  0, -1,  1,  0,  0] [ 9,  6,  3] -1 */
    18553658, /* 74648 (1638) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    60360124, /* 74649 (1638) [ 0,  1,  0,  0,  0,  1, -1,  0,  0] [ 9,  3,  6] -1 */
       10816, /* 74650 (1638) [ 0,  0,  1,  1,  0,  0,  0,  1,  0] [ 0,  0,  0]  1 */
    34015422, /* 74651 (1638) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    18434104, /* 74652 (1638) [ 0,  0,  1,  1,  0,  0,  0,  1,  0] [ 6,  6,  0]  1 */
    52438710, /* 74653 (1638) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
    44003291, /* 74654 (1638) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 3,  6,  3] -1 */
    17785533, /* 74655 (1638) [ 0,  1,  0, -1,  0,  0,  0,  0, -1] [ 6,  3,  3]  1 */
    42584659, /* 74656 (1638) [ 0,  0,  1, -1,  0,  0,  0,  1,  0] [ 3,  0,  3] -1 */
    17016772, /* 74657 (1638) [ 0,  0,  1,  0,  1,  0,  1,  0,  0] [ 6,  0,  0]  1 */
    34139344, /* 74658 (1638) [ 0,  0, -1,  0, -1,  0, -1,  0,  0] [ 0,  0,  6] -1 */
    61007947, /* 74659 (1638) [ 0,  0,  1, -1,  0,  0,  0,  1,  0] [ 9,  6,  3] -1 */
    25577401, /* 74660 (1638) [ 0,  0, -1,  0,  1,  0, -1,  0,  0] [ 9,  0,  3]  1 */
       12064, /* 74661 (1638) [ 0,  1,  0,  0,  0,  1,  1,  0,  0] [ 0,  0,  0]  1 */
     2201185, /* 74662 (1638) [ 1,  0,  0,  0,  0, -1,  0, -1,  0] [ 0,  9,  3]  1 */
    51025746, /* 74663 (1638) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 6,  0,  0] -1 */
     1551758, /* 74664 (1638) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
     8571457, /* 74665 (1638) [ 0,  0, -1,  1,  0,  0,  0, -1,  0] [ 3,  0,  3]  1 */
      130370, /* 74666 (1638) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 0,  0,  6]  1 */
    18557818, /* 74667 (1638) [ 1,  0,  0,  0,  0,  1,  0,  1,  0] [ 6,  6,  6]  1 */
    52561020, /* 74668 (1638) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    10754554, /* 74669 (1638) [ 0, -1,  0,  0,  0, -1,  1,  0,  0] [ 3,  9,  6]  1 */
    17902171, /* 74670 (1638) [ 0,  0,  1, -1,  0,  0,  0, -1,  0] [ 6,  3,  9]  1 */
    59590939, /* 74671 (1638) [ 0,  0,  1,  0, -1,  0,  1,  0,  0] [ 9,  0,  3] -1 */
     2314903, /* 74672 (1638) [ 0,  1,  0,  0,  0, -1, -1,  0,  0] [ 0,  9,  9]  1 */
     8688099, /* 74673 (1638) [ 0, -1,  0,  1,  0,  0,  0,  0, -1] [ 3,  0,  9]  1 */
    27111387, /* 74674 (1638) [ 0, -1,  0,  1,  0,  0,  0,  0, -1] [ 9,  6,  9]  1 */
    60242250, /* 74675 (1638) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 9,  3,  0] -1 */
    60358888, /* 74676 (1638) [ 0,  0,  1,  1,  0,  0,  0, -1,  0] [ 9,  3,  6] -1 */
    35555116, /* 74677 (1638) [ 0, -1,  0,  0,  0, -1, -1,  0,  0] [ 0,  6,  6] -1 */
    61132093, /* 74678 (1638) [ 1,  0,  0,  0,  0, -1,  0,  1,  0] [ 9,  6,  9] -1 */
    25693987, /* 74679 (1638) [ 0, -1,  0,  0,  0,  1, -1,  0,  0] [ 9,  0,  9]  1 */
    61126213, /* 74680 (1638) [ 0,  0,  1,  0, -1,  0,  1,  0,  0] [ 9,  6,  9] -1 */
    35438422, /* 74681 (1638) [ 0,  0, -1,  0, -1,  0, -1,  0,  0] [ 0,  6,  0] -1 */
    59596819, /* 74682 (1638) [ 1,  0,  0,  0,  0, -1,  0,  1,  0] [ 9,  0,  3] -1 */
     1546090, /* 74683 (1638) [ 0,  0,  1,  1,  0,  0,  0,  1,  0] [ 0,  6,  6]  1 */
    35550696, /* 74684 (1638) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  6] -1 */
    52556860, /* 74685 (1638) [-1,  0,  0,  0,  0, -1,  0, -1,  0] [ 6,  6,  6] -1 */
    51793871, /* 74686 (1638) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 6,  3,  3] -1 */
    51021586, /* 74687 (1638) [-1,  0,  0,  0,  0, -1,  0, -1,  0] [ 6,  0,  0] -1 */
    10637860, /* 74688 (1638) [ 0,  0, -1,  0, -1,  0,  1,  0,  0] [ 3,  9,  0]  1 */
    34907161, /* 74689 (1638) [ 0,  0, -1,  0,  1,  0,  1,  0,  0] [ 0,  3,  9] -1 */
    60240622, /* 74690 (1638) [ 0,  0,  1,  0,  1,  0, -1,  0,  0] [ 9,  3,  0] -1 */
    51907433, /* 74691 (1638) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  3,  9] -1 */
    43354236, /* 74692 (1638) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 3,  3,  6] -1 */
    53329145, /* 74693 (1638) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 6,  9,  9] -1 */
    53324557, /* 74694 (1638) [-1,  0,  0,  0,  0,  1,  0,  1,  0] [ 6,  9,  9] -1 */
    51789283, /* 74695 (1638) [-1,  0,  0,  0,  0,  1,  0,  1,  0] [ 6,  3,  3] -1 */
    59592227, /* 74696 (1638) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 9,  0,  3] -1 */
    36324493, /* 74697 (1638) [ 0,  0, -1,  1,  0,  0,  0,  1,  0] [ 0,  9,  9] -1 */
    61659202, /* 74698 (1638) [ 0,  1,  0,  0,  0,  1, -1,  0,  0] [ 9,  9,  0] -1 */
    19319503, /* 74699 (1638) [ 0,  0,  1,  0, -1,  0, -1,  0,  0] [ 6,  9,  9]  1 */
    19325395, /* 74700 (1638) [ 1,  0,  0,  0,  0, -1,  0, -1,  0] [ 6,  9,  9]  1 */
    17784229, /* 74701 (1638) [ 0,  0,  1,  0, -1,  0, -1,  0,  0] [ 6,  3,  3]  1 */
    44121613, /* 74702 (1638) [ 0,  1,  0,  0,  0, -1,  1,  0,  0] [ 3,  6,  9] -1 */
    25695667, /* 74703 (1638) [ 0,  0, -1,  1,  0,  0,  0, -1,  0] [ 9,  0,  9]  1 */
    17903839, /* 74704 (1638) [ 0,  1,  0,  0,  0, -1, -1,  0,  0] [ 6,  3,  9]  1 */
    52444378, /* 74705 (1638) [ 0,  0, -1, -1,  0,  0,  0, -1,  0] [ 6,  6,  0] -1 */
      897519, /* 74706 (1638) [ 0,  1,  0, -1,  0,  0,  0,  0, -1] [ 0,  3,  9]  1 */
    61127501, /* 74707 (1638) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 9,  6,  9] -1 */
    42590651, /* 74708 (1638) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 3,  0,  3] -1 */
    27643804, /* 74709 (1638) [ 0,  0, -1, -1,  0,  0,  0,  1,  0] [ 9,  9,  0]  1 */
    44119933, /* 74710 (1638) [ 0,  0,  1, -1,  0,  0,  0,  1,  0] [ 3,  6,  9] -1 */
    61013939, /* 74711 (1638) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 9,  6,  3] -1 */
     8689387, /* 74712 (1638) [ 0,  0, -1,  0,  1,  0, -1,  0,  0] [ 3,  0,  9]  1 */
    18552046, /* 74713 (1638) [ 0,  0,  1,  0,  1,  0,  1,  0,  0] [ 6,  6,  6]  1 */
    60364560, /* 74714 (1638) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 9,  3,  6] -1 */
    34137732, /* 74715 (1638) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  6] -1 */
    61657966, /* 74716 (1638) [ 0,  0,  1,  1,  0,  0,  0, -1,  0] [ 9,  9,  0] -1 */
    17022544, /* 74717 (1638) [ 1,  0,  0,  0,  0,  1,  0,  1,  0] [ 6,  0,  0]  1 */
    10106731, /* 74718 (1638) [ 0,  0, -1,  1,  0,  0,  0, -1,  0] [ 3,  6,  9]  1 */
    10636232, /* 74719 (1638) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 3,  9,  0]  1 */
     9219280, /* 74720 (1638) [ 0, -1,  0,  0,  0, -1,  1,  0,  0] [ 3,  3,  0]  1 */
    42702925, /* 74721 (1638) [ 0,  0,  1,  0, -1,  0,  1,  0,  0] [ 3,  0,  9] -1 */
      128758, /* 74722 (1638) [ 0,  0,  1,  0,  1,  0,  1,  0,  0] [ 0,  0,  6]  1 */
      783957, /* 74723 (1638) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  3,  3]  1 */
    26993065, /* 74724 (1638) [ 0, -1,  0,  0,  0,  1, -1,  0,  0] [ 9,  6,  3]  1 */
    19207245, /* 74725 (1638) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  9,  3]  1 */
    61777524, /* 74726 (1638) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 9,  9,  6] -1 */
    34787551, /* 74727 (1638) [ 0, -1,  0,  0,  0,  1,  1,  0,  0] [ 0,  3,  3] -1 */
     1429448, /* 74728 (1638) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 0,  6,  0]  1 */
    26988753, /* 74729 (1638) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 9,  6,  3]  1 */
    51144052, /* 74730 (1638) [ 0, -1,  0,  0,  0, -1, -1,  0,  0] [ 6,  0,  6] -1 */
    51911761, /* 74731 (1638) [ 0, -1,  0,  0,  0,  1,  1,  0,  0] [ 6,  3,  9] -1 */
     1547338, /* 74732 (1638) [ 0,  1,  0,  0,  0,  1,  1,  0,  0] [ 0,  6,  6]  1 */
      134530, /* 74733 (1638) [ 1,  0,  0,  0,  0,  1,  0,  1,  0] [ 0,  0,  6]  1 */
    10632076, /* 74734 (1638) [-1,  0,  0,  0,  0, -1,  0,  1,  0] [ 3,  9,  0]  1 */
    42708805, /* 74735 (1638) [ 1,  0,  0,  0,  0, -1,  0,  1,  0] [ 3,  0,  9] -1 */
    17135026, /* 74736 (1638) [ 0,  0,  1,  1,  0,  0,  0,  1,  0] [ 6,  0,  6]  1 */
     9220516, /* 74737 (1638) [ 0,  0, -1, -1,  0,  0,  0,  1,  0] [ 3,  3,  0]  1 */
    35556364, /* 74738 (1638) [ 0,  0, -1, -1,  0,  0,  0, -1,  0] [ 0,  6,  6] -1 */
     1433608, /* 74739 (1638) [ 1,  0,  0,  0,  0,  1,  0,  1,  0] [ 0,  6,  0]  1 */
    34905857, /* 74740 (1638) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 0,  3,  9] -1 */
    35436810, /* 74741 (1638) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 0,  6,  0] -1 */
    10755790, /* 74742 (1638) [ 0,  0, -1, -1,  0,  0,  0,  1,  0] [ 3,  9,  6]  1 */
     9982585, /* 74743 (1638) [-1,  0,  0,  0,  0,  1,  0, -1,  0] [ 3,  6,  3]  1 */
    26226796, /* 74744 (1638) [ 0,  0, -1,  0, -1,  0,  1,  0,  0] [ 9,  3,  0]  1 */
    44769952, /* 74745 (1638) [ 0,  0,  1,  1,  0,  0,  0, -1,  0] [ 3,  9,  6] -1 */
    51913429, /* 74746 (1638) [ 0,  0, -1,  1,  0,  0,  0,  1,  0] [ 6,  3,  9] -1 */
    43234678, /* 74747 (1638) [ 0,  0,  1,  1,  0,  0,  0, -1,  0] [ 3,  3,  0] -1 */
    61775896, /* 74748 (1638) [ 0,  0,  1,  0,  1,  0, -1,  0,  0] [ 9,  9,  6] -1 */
    60246406, /* 74749 (1638) [ 1,  0,  0,  0,  0,  1,  0, -1,  0] [ 9,  3,  0] -1 */
     9988465, /* 74750 (1638) [ 0,  0, -1,  0,  1,  0, -1,  0,  0] [ 3,  6,  3]  1 */
    51027358, /* 74751 (1638) [ 0,  0, -1,  0, -1,  0, -1,  0,  0] [ 6,  0,  0] -1 */
    61781680, /* 74752 (1638) [ 1,  0,  0,  0,  0,  1,  0, -1,  0] [ 9,  9,  6] -1 */
    34901269, /* 74753 (1638) [-1,  0,  0,  0,  0,  1,  0,  1,  0] [ 0,  3,  9] -1 */
    27762070, /* 74754 (1638) [ 0,  0, -1,  0, -1,  0,  1,  0,  0] [ 9,  9,  6]  1 */
    35432650, /* 74755 (1638) [-1,  0,  0,  0,  0, -1,  0, -1,  0] [ 0,  6,  0] -1 */
    59708869, /* 74756 (1638) [ 0,  0,  1, -1,  0,  0,  0,  1,  0] [ 9,  0,  9] -1 */
     2196597, /* 74757 (1638) [ 0,  1,  0, -1,  0,  0,  0,  0, -1] [ 0,  9,  3]  1 */
      896215, /* 74758 (1638) [ 0,  0,  1,  0, -1,  0, -1,  0,  0] [ 0,  3,  9]  1 */
    17790121, /* 74759 (1638) [ 1,  0,  0,  0,  0, -1,  0, -1,  0] [ 6,  3,  3]  1 */
    42586339, /* 74760 (1638) [ 0,  1,  0,  0,  0, -1,  1,  0,  0] [ 3,  0,  3] -1 */
    42704213, /* 74761 (1638) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 3,  0,  9] -1 */
    34021090, /* 74762 (1638) [ 0,  0, -1, -1,  0,  0,  0, -1,  0] [ 0,  0,  0] -1 */
       16484, /* 74763 (1639) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
     8565465, /* 74764 (1639) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 3,  0,  3]  1 */
    42695731, /* 74765 (1639) [-1,  0,  0,  0,  0,  1,  0, -1,  0] [ 3,  0,  9] -1 */
    17140694, /* 74766 (1639) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
    19201249, /* 74767 (1639) [ 0,  0,  1, -1,  0,  0,  0, -1,  0] [ 6,  9,  3]  1 */
    43352608, /* 74768 (1639) [ 0,  0,  1,  0,  1,  0, -1,  0,  0] [ 3,  3,  6] -1 */
    26997403, /* 74769 (1639) [ 0,  1,  0,  0,  0, -1,  1,  0,  0] [ 9,  6,  3]  1 */
    26347900, /* 74770 (1639) [ 0,  1,  0,  0,  0,  1, -1,  0,  0] [ 9,  3,  6]  1 */
    26339054, /* 74771 (1639) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 9,  3,  6]  1 */
        3198, /* 74772 (1639) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    43358392, /* 74773 (1639) [ 1,  0,  0,  0,  0,  1,  0, -1,  0] [ 3,  3,  6] -1 */
    61768510, /* 74774 (1639) [-1,  0,  0,  0,  0, -1,  0,  1,  0] [ 9,  9,  6] -1 */
     8572435, /* 74775 (1639) [ 0,  0,  1, -1,  0,  0,  0,  1,  0] [ 3,  0,  3]  1 */
    10105051, /* 74776 (1639) [ 0, -1,  0,  0,  0,  1, -1,  0,  0] [ 3,  6,  9]  1 */
     2319231, /* 74777 (1639) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  9,  9]  1 */
    10107709, /* 74778 (1639) [ 0,  0,  1, -1,  0,  0,  0,  1,  0] [ 3,  6,  9]  1 */
    27001715, /* 74779 (1639) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 9,  6,  3]  1 */
     8569777, /* 74780 (1639) [ 0, -1,  0,  0,  0,  1, -1,  0,  0] [ 3,  0,  3]  1 */
    10100739, /* 74781 (1639) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 3,  6,  9]  1 */
    26352336, /* 74782 (1639) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 9,  3,  6]  1 */
    17136274, /* 74783 (1639) [ 0,  1,  0,  0,  0,  1,  1,  0,  0] [ 6,  0,  6]  1 */
    27645742, /* 74784 (1639) [ 0,  0,  1,  1,  0,  0,  0, -1,  0] [ 9,  9,  0]  1 */
    53331727, /* 74785 (1639) [ 0,  0,  1,  0, -1,  0, -1,  0,  0] [ 6,  9,  9] -1 */
    52565882, /* 74786 (1639) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    26346664, /* 74787 (1639) [ 0,  0,  1,  1,  0,  0,  0, -1,  0] [ 9,  3,  6]  1 */
      775327, /* 74788 (1639) [ 0, -1,  0,  0,  0,  1,  1,  0,  0] [ 0,  3,  3]  1 */
    36206239, /* 74789 (1639) [ 0,  0, -1,  0,  1,  0,  1,  0,  0] [ 0,  9,  3] -1 */
    17131828, /* 74790 (1639) [ 0, -1,  0,  0,  0, -1, -1,  0,  0] [ 6,  0,  6]  1 */
    51028996, /* 74791 (1639) [ 0,  0,  1,  0,  1,  0,  1,  0,  0] [ 6,  0,  0] -1 */
    27642568, /* 74792 (1639) [ 0, -1,  0,  0,  0, -1,  1,  0,  0] [ 9,  9,  0]  1 */
    52570042, /* 74793 (1639) [ 1,  0,  0,  0,  0,  1,  0,  1,  0] [ 6,  6,  6] -1 */
    51034768, /* 74794 (1639) [ 1,  0,  0,  0,  0,  1,  0,  1,  0] [ 6,  0,  0] -1 */
    42700323, /* 74795 (1639) [ 0, -1,  0,  1,  0,  0,  0,  0, -1] [ 3,  0,  9] -1 */
    26343490, /* 74796 (1639) [ 0, -1,  0,  0,  0, -1,  1,  0,  0] [ 9,  3,  6]  1 */
    34140982, /* 74797 (1639) [ 0,  0,  1,  0,  1,  0,  1,  0,  0] [ 0,  0,  6] -1 */
    52562632, /* 74798 (1639) [ 0,  0, -1,  0, -1,  0, -1,  0,  0] [ 6,  6,  6] -1 */
    10757728, /* 74799 (1639) [ 0,  0,  1,  1,  0,  0,  0, -1,  0] [ 3,  9,  6]  1 */
    17901205, /* 74800 (1639) [ 0,  0, -1,  1,  0,  0,  0,  1,  0] [ 6,  3,  9]  1 */
    26344726, /* 74801 (1639) [ 0,  0, -1, -1,  0,  0,  0,  1,  0] [ 9,  3,  6]  1 */
    26994745, /* 74802 (1639) [ 0,  0, -1,  1,  0,  0,  0, -1,  0] [ 9,  6,  3]  1 */
      779629, /* 74803 (1639) [ 0,  1,  0,  0,  0, -1, -1,  0,  0] [ 0,  3,  3]  1 */
    19202917, /* 74804 (1639) [ 0,  1,  0,  0,  0, -1, -1,  0,  0] [ 6,  9,  3]  1 */
    44653314, /* 74805 (1639) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 3,  9,  0] -1 */
    27638132, /* 74806 (1639) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 9,  9,  0]  1 */
      777961, /* 74807 (1639) [ 0,  0,  1, -1,  0,  0,  0, -1,  0] [ 0,  3,  3]  1 */
    17908167, /* 74808 (1639) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  3,  9]  1 */
    25696645, /* 74809 (1639) [ 0,  0,  1, -1,  0,  0,  0,  1,  0] [ 9,  0,  9]  1 */
    44007883, /* 74810 (1639) [ 1,  0,  0,  0,  0, -1,  0,  1,  0] [ 3,  6,  3] -1 */
    25689675, /* 74811 (1639) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 9,  0,  9]  1 */
     2313235, /* 74812 (1639) [ 0,  0,  1, -1,  0,  0,  0, -1,  0] [ 0,  9,  9]  1 */
    44650084, /* 74813 (1639) [ 0,  0, -1,  0, -1,  0,  1,  0,  0] [ 3,  9,  0] -1 */
    44002003, /* 74814 (1639) [ 0,  0,  1,  0, -1,  0,  1,  0,  0] [ 3,  6,  3] -1 */
    10109389, /* 74815 (1639) [ 0,  1,  0,  0,  0, -1,  1,  0,  0] [ 3,  6,  9]  1 */
     8574115, /* 74816 (1639) [ 0,  1,  0,  0,  0, -1,  1,  0,  0] [ 3,  0,  3]  1 */
        8866, /* 74817 (1639) [ 0,  0, -1, -1,  0,  0,  0, -1,  0] [ 0,  0,  0]  1 */
    18432154, /* 74818 (1639) [ 0,  0, -1, -1,  0,  0,  0, -1,  0] [ 6,  6,  0]  1 */
     8578427, /* 74819 (1639) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 3,  0,  3]  1 */
    10113701, /* 74820 (1639) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 3,  6,  9]  1 */
    10758964, /* 74821 (1639) [ 0,  1,  0,  0,  0,  1, -1,  0,  0] [ 3,  9,  6]  1 */
    51795175, /* 74822 (1639) [ 0,  0, -1,  0,  1,  0,  1,  0,  0] [ 6,  3,  3] -1 */
    34133572, /* 74823 (1639) [-1,  0,  0,  0,  0, -1,  0, -1,  0] [ 0,  0,  6] -1 */
    18439772, /* 74824 (1639) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    44651686, /* 74825 (1639) [ 0,  0,  1,  0,  1,  0, -1,  0,  0] [ 3,  9,  0] -1 */
    36204935, /* 74826 (1639) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 0,  9,  3] -1 */
    36208821, /* 74827 (1639) [ 0,  1,  0, -1,  0,  0,  0,  0, -1] [ 0,  9,  3] -1 */
    53337619, /* 74828 (1639) [ 1,  0,  0,  0,  0, -1,  0, -1,  0] [ 6,  9,  9] -1 */
    51796453, /* 74829 (1639) [ 0,  0,  1,  0, -1,  0, -1,  0,  0] [ 6,  3,  3] -1 */
    36200347, /* 74830 (1639) [-1,  0,  0,  0,  0,  1,  0,  1,  0] [ 0,  9,  3] -1 */
    17127408, /* 74831 (1639) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  6]  1 */
    10750118, /* 74832 (1639) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 3,  9,  6]  1 */
    44657470, /* 74833 (1639) [ 1,  0,  0,  0,  0,  1,  0, -1,  0] [ 3,  9,  0] -1 */
    51802345, /* 74834 (1639) [ 1,  0,  0,  0,  0, -1,  0, -1,  0] [ 6,  3,  3] -1 */
     9214844, /* 74835 (1639) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 3,  3,  0]  1 */
    17899537, /* 74836 (1639) [ 0, -1,  0,  0,  0,  1,  1,  0,  0] [ 6,  3,  9]  1 */
    34909743, /* 74837 (1639) [ 0,  1,  0, -1,  0,  0,  0,  0, -1] [ 0,  3,  9] -1 */
    53330449, /* 74838 (1639) [ 0,  0, -1,  0,  1,  0,  1,  0,  0] [ 6,  9,  9] -1 */
    52564270, /* 74839 (1639) [ 0,  0,  1,  0,  1,  0,  1,  0,  0] [ 6,  6,  6] -1 */
    42701611, /* 74840 (1639) [ 0,  0, -1,  0,  1,  0, -1,  0,  0] [ 3,  0,  9] -1 */
    18435352, /* 74841 (1639) [ 0,  1,  0,  0,  0,  1,  1,  0,  0] [ 6,  6,  0]  1 */
     1544140, /* 74842 (1639) [ 0,  0, -1, -1,  0,  0,  0, -1,  0] [ 0,  6,  6]  1 */
    44648456, /* 74843 (1639) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 3,  9,  0] -1 */
     9228126, /* 74844 (1639) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 3,  3,  0]  1 */
       10816, /* 74845 (1639) [ 0,  0,  1,  1,  0,  0,  0,  1,  0] [ 0,  0,  0]  1 */
    18434104, /* 74846 (1639) [ 0,  0,  1,  1,  0,  0,  0,  1,  0] [ 6,  6,  0]  1 */
    44003291, /* 74847 (1639) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 3,  6,  3] -1 */
    34139344, /* 74848 (1639) [ 0,  0, -1,  0, -1,  0, -1,  0,  0] [ 0,  0,  6] -1 */
    35441672, /* 74849 (1639) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 0,  6,  0] -1 */
       12064, /* 74850 (1639) [ 0,  1,  0,  0,  0,  1,  1,  0,  0] [ 0,  0,  0]  1 */
    19194287, /* 74851 (1639) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  9,  3]  1 */
     9222454, /* 74852 (1639) [ 0,  0,  1,  1,  0,  0,  0, -1,  0] [ 3,  3,  0]  1 */
    59583745, /* 74853 (1639) [-1,  0,  0,  0,  0,  1,  0, -1,  0] [ 9,  0,  3] -1 */
    51025746, /* 74854 (1639) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 6,  0,  0] -1 */
     1551758, /* 74855 (1639) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
     8571457, /* 74856 (1639) [ 0,  0, -1,  1,  0,  0,  0, -1,  0] [ 3,  0,  3]  1 */
    34146754, /* 74857 (1639) [ 1,  0,  0,  0,  0,  1,  0,  1,  0] [ 0,  0,  6] -1 */
    52561020, /* 74858 (1639) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    10754554, /* 74859 (1639) [ 0, -1,  0,  0,  0, -1,  1,  0,  0] [ 3,  9,  6]  1 */
    17902171, /* 74860 (1639) [ 0,  0,  1, -1,  0,  0,  0, -1,  0] [ 6,  3,  9]  1 */
    44644300, /* 74861 (1639) [-1,  0,  0,  0,  0, -1,  0,  1,  0] [ 3,  9,  0] -1 */
    59590939, /* 74862 (1639) [ 0,  0,  1,  0, -1,  0,  1,  0,  0] [ 9,  0,  3] -1 */
     2314903, /* 74863 (1639) [ 0,  1,  0,  0,  0, -1, -1,  0,  0] [ 0,  9,  9]  1 */
    60242250, /* 74864 (1639) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 9,  3,  0] -1 */
    35445832, /* 74865 (1639) [ 1,  0,  0,  0,  0,  1,  0,  1,  0] [ 0,  6,  0] -1 */
    43994809, /* 74866 (1639) [-1,  0,  0,  0,  0,  1,  0, -1,  0] [ 3,  6,  3] -1 */
    25702637, /* 74867 (1639) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 9,  0,  9]  1 */
    60239020, /* 74868 (1639) [ 0,  0, -1,  0, -1,  0,  1,  0,  0] [ 9,  3,  0] -1 */
    61132093, /* 74869 (1639) [ 1,  0,  0,  0,  0, -1,  0,  1,  0] [ 9,  6,  9] -1 */
    25693987, /* 74870 (1639) [ 0, -1,  0,  0,  0,  1, -1,  0,  0] [ 9,  0,  9]  1 */
    61126213, /* 74871 (1639) [ 0,  0,  1,  0, -1,  0,  1,  0,  0] [ 9,  6,  9] -1 */
    35438422, /* 74872 (1639) [ 0,  0, -1,  0, -1,  0, -1,  0,  0] [ 0,  6,  0] -1 */
    59596819, /* 74873 (1639) [ 1,  0,  0,  0,  0, -1,  0,  1,  0] [ 9,  0,  3] -1 */
     1546090, /* 74874 (1639) [ 0,  0,  1,  1,  0,  0,  0,  1,  0] [ 0,  6,  6]  1 */
    52556860, /* 74875 (1639) [-1,  0,  0,  0,  0, -1,  0, -1,  0] [ 6,  6,  6] -1 */
    51793871, /* 74876 (1639) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 6,  3,  3] -1 */
    51021586, /* 74877 (1639) [-1,  0,  0,  0,  0, -1,  0, -1,  0] [ 6,  0,  0] -1 */
    27651414, /* 74878 (1639) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 9,  9,  0]  1 */
    44000689, /* 74879 (1639) [ 0,  0, -1,  0,  1,  0, -1,  0,  0] [ 3,  6,  3] -1 */
     9223690, /* 74880 (1639) [ 0,  1,  0,  0,  0,  1, -1,  0,  0] [ 3,  3,  0]  1 */
    61774294, /* 74881 (1639) [ 0,  0, -1,  0, -1,  0,  1,  0,  0] [ 9,  9,  6] -1 */
    34907161, /* 74882 (1639) [ 0,  0, -1,  0,  1,  0,  1,  0,  0] [ 0,  3,  9] -1 */
    19198615, /* 74883 (1639) [ 0, -1,  0,  0,  0,  1,  1,  0,  0] [ 6,  9,  3]  1 */
    60240622, /* 74884 (1639) [ 0,  0,  1,  0,  1,  0, -1,  0,  0] [ 9,  3,  0] -1 */
    43354236, /* 74885 (1639) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 3,  3,  6] -1 */
    53329145, /* 74886 (1639) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 6,  9,  9] -1 */
    34908439, /* 74887 (1639) [ 0,  0,  1,  0, -1,  0, -1,  0,  0] [ 0,  3,  9] -1 */
    53324557, /* 74888 (1639) [-1,  0,  0,  0,  0,  1,  0,  1,  0] [ 6,  9,  9] -1 */
    51789283, /* 74889 (1639) [-1,  0,  0,  0,  0,  1,  0,  1,  0] [ 6,  3,  3] -1 */
    59592227, /* 74890 (1639) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 9,  0,  3] -1 */
    43351006, /* 74891 (1639) [ 0,  0, -1,  0, -1,  0,  1,  0,  0] [ 3,  3,  6] -1 */
    43999401, /* 74892 (1639) [ 0, -1,  0,  1,  0,  0,  0,  0, -1] [ 3,  6,  3] -1 */
    17133076, /* 74893 (1639) [ 0,  0, -1, -1,  0,  0,  0, -1,  0] [ 6,  0,  6]  1 */
    60237392, /* 74894 (1639) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 9,  3,  0] -1 */
    25695667, /* 74895 (1639) [ 0,  0, -1,  1,  0,  0,  0, -1,  0] [ 9,  0,  9]  1 */
    10763400, /* 74896 (1639) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 3,  9,  6]  1 */
    17903839, /* 74897 (1639) [ 0,  1,  0,  0,  0, -1, -1,  0,  0] [ 6,  3,  9]  1 */
    19200283, /* 74898 (1639) [ 0,  0, -1,  1,  0,  0,  0,  1,  0] [ 6,  9,  3]  1 */
    61127501, /* 74899 (1639) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 9,  6,  9] -1 */
      770999, /* 74900 (1639) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  3,  3]  1 */
    27643804, /* 74901 (1639) [ 0,  0, -1, -1,  0,  0,  0,  1,  0] [ 9,  9,  0]  1 */
        7618, /* 74902 (1639) [ 0, -1,  0,  0,  0, -1, -1,  0,  0] [ 0,  0,  0]  1 */
    18430906, /* 74903 (1639) [ 0, -1,  0,  0,  0, -1, -1,  0,  0] [ 6,  6,  0]  1 */
     2306273, /* 74904 (1639) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  9,  9]  1 */
    34137732, /* 74905 (1639) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  6] -1 */
    61119019, /* 74906 (1639) [-1,  0,  0,  0,  0,  1,  0, -1,  0] [ 9,  6,  9] -1 */
    10106731, /* 74907 (1639) [ 0,  0, -1,  1,  0,  0,  0, -1,  0] [ 3,  6,  9]  1 */
     9219280, /* 74908 (1639) [ 0, -1,  0,  0,  0, -1,  1,  0,  0] [ 3,  3,  0]  1 */
    60233236, /* 74909 (1639) [-1,  0,  0,  0,  0, -1,  0,  1,  0] [ 9,  3,  0] -1 */
    42702925, /* 74910 (1639) [ 0,  0,  1,  0, -1,  0,  1,  0,  0] [ 3,  0,  9] -1 */
    18426486, /* 74911 (1639) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
    35440060, /* 74912 (1639) [ 0,  0,  1,  0,  1,  0,  1,  0,  0] [ 0,  6,  0] -1 */
      783957, /* 74913 (1639) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  3,  3]  1 */
    26993065, /* 74914 (1639) [ 0, -1,  0,  0,  0,  1, -1,  0,  0] [ 9,  6,  3]  1 */
    19207245, /* 74915 (1639) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  9,  3]  1 */
    61777524, /* 74916 (1639) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 9,  9,  6] -1 */
    26995723, /* 74917 (1639) [ 0,  0,  1, -1,  0,  0,  0,  1,  0] [ 9,  6,  3]  1 */
    25698325, /* 74918 (1639) [ 0,  1,  0,  0,  0, -1,  1,  0,  0] [ 9,  0,  9]  1 */
    26988753, /* 74919 (1639) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 9,  6,  3]  1 */
     1547338, /* 74920 (1639) [ 0,  1,  0,  0,  0,  1,  1,  0,  0] [ 0,  6,  6]  1 */
    43349378, /* 74921 (1639) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 3,  3,  6] -1 */
    51030608, /* 74922 (1639) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 6,  0,  0] -1 */
    42708805, /* 74923 (1639) [ 1,  0,  0,  0,  0, -1,  0,  1,  0] [ 3,  0,  9] -1 */
    17135026, /* 74924 (1639) [ 0,  0,  1,  1,  0,  0,  0,  1,  0] [ 6,  0,  6]  1 */
     9220516, /* 74925 (1639) [ 0,  0, -1, -1,  0,  0,  0,  1,  0] [ 3,  3,  0]  1 */
    34905857, /* 74926 (1639) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 0,  3,  9] -1 */
    35436810, /* 74927 (1639) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 0,  6,  0] -1 */
    10755790, /* 74928 (1639) [ 0,  0, -1, -1,  0,  0,  0,  1,  0] [ 3,  9,  6]  1 */
    53333031, /* 74929 (1639) [ 0,  1,  0, -1,  0,  0,  0,  0, -1] [ 6,  9,  9] -1 */
     1542892, /* 74930 (1639) [ 0, -1,  0,  0,  0, -1, -1,  0,  0] [ 0,  6,  6]  1 */
    51797757, /* 74931 (1639) [ 0,  1,  0, -1,  0,  0,  0,  0, -1] [ 6,  3,  3] -1 */
    61124899, /* 74932 (1639) [ 0,  0, -1,  0,  1,  0, -1,  0,  0] [ 9,  6,  9] -1 */
    36207517, /* 74933 (1639) [ 0,  0,  1,  0, -1,  0, -1,  0,  0] [ 0,  9,  3] -1 */
    59589625, /* 74934 (1639) [ 0,  0, -1,  0,  1,  0, -1,  0,  0] [ 9,  0,  3] -1 */
    36213409, /* 74935 (1639) [ 1,  0,  0,  0,  0, -1,  0, -1,  0] [ 0,  9,  3] -1 */
    43345222, /* 74936 (1639) [-1,  0,  0,  0,  0, -1,  0,  1,  0] [ 3,  3,  6] -1 */
    34142594, /* 74937 (1639) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 0,  0,  6] -1 */
     2310601, /* 74938 (1639) [ 0, -1,  0,  0,  0,  1,  1,  0,  0] [ 0,  9,  9]  1 */
     1538472, /* 74939 (1639) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
    61775896, /* 74940 (1639) [ 0,  0,  1,  0,  1,  0, -1,  0,  0] [ 9,  9,  6] -1 */
    59588337, /* 74941 (1639) [ 0, -1,  0,  1,  0,  0,  0,  0, -1] [ 9,  0,  3] -1 */
    34914331, /* 74942 (1639) [ 1,  0,  0,  0,  0, -1,  0, -1,  0] [ 0,  3,  9] -1 */
    60246406, /* 74943 (1639) [ 1,  0,  0,  0,  0,  1,  0, -1,  0] [ 9,  3,  0] -1 */
    61123611, /* 74944 (1639) [ 0, -1,  0,  1,  0,  0,  0,  0, -1] [ 9,  6,  9] -1 */
    51027358, /* 74945 (1639) [ 0,  0, -1,  0, -1,  0, -1,  0,  0] [ 6,  0,  0] -1 */
    61781680, /* 74946 (1639) [ 1,  0,  0,  0,  0,  1,  0, -1,  0] [ 9,  9,  6] -1 */
    34901269, /* 74947 (1639) [-1,  0,  0,  0,  0,  1,  0,  1,  0] [ 0,  3,  9] -1 */
    35432650, /* 74948 (1639) [-1,  0,  0,  0,  0, -1,  0, -1,  0] [ 0,  6,  0] -1 */
    17895209, /* 74949 (1639) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  3,  9]  1 */
      776995, /* 74950 (1639) [ 0,  0, -1,  1,  0,  0,  0,  1,  0] [ 0,  3,  3]  1 */
    61772666, /* 74951 (1639) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 9,  9,  6] -1 */
    42704213, /* 74952 (1639) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 3,  0,  9] -1 */
     2312269, /* 74953 (1639) [ 0,  0, -1,  1,  0,  0,  0,  1,  0] [ 0,  9,  9]  1 */
    27646978, /* 74954 (1639) [ 0,  1,  0,  0,  0,  1, -1,  0,  0] [ 9,  9,  0]  1 */
       16484, /* 74955 (1640) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    61663638, /* 74956 (1640) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 9,  9,  0] -1 */
    44125925, /* 74957 (1640) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 3,  6,  9] -1 */
    44771188, /* 74958 (1640) [ 0,  1,  0,  0,  0,  1, -1,  0,  0] [ 3,  9,  6] -1 */
     8565465, /* 74959 (1640) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 3,  0,  3]  1 */
    42695731, /* 74960 (1640) [-1,  0,  0,  0,  0,  1,  0, -1,  0] [ 3,  0,  9] -1 */
    17140694, /* 74961 (1640) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
    19201249, /* 74962 (1640) [ 0,  0,  1, -1,  0,  0,  0, -1,  0] [ 6,  9,  3]  1 */
    43235914, /* 74963 (1640) [ 0,  1,  0,  0,  0,  1, -1,  0,  0] [ 3,  3,  0] -1 */
    26339054, /* 74964 (1640) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 9,  3,  6]  1 */
    53210839, /* 74965 (1640) [ 0, -1,  0,  0,  0,  1,  1,  0,  0] [ 6,  9,  3] -1 */
     9991067, /* 74966 (1640) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 3,  6,  3]  1 */
    61768510, /* 74967 (1640) [-1,  0,  0,  0,  0, -1,  0,  1,  0] [ 9,  9,  6] -1 */
    51139632, /* 74968 (1640) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  6] -1 */
    10105051, /* 74969 (1640) [ 0, -1,  0,  0,  0,  1, -1,  0,  0] [ 3,  6,  9]  1 */
     2319231, /* 74970 (1640) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  9,  9]  1 */
     8569777, /* 74971 (1640) [ 0, -1,  0,  0,  0,  1, -1,  0,  0] [ 3,  0,  3]  1 */
    10100739, /* 74972 (1640) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 3,  6,  9]  1 */
      125508, /* 74973 (1640) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  6]  1 */
    17136274, /* 74974 (1640) [ 0,  1,  0,  0,  0,  1,  1,  0,  0] [ 6,  0,  6]  1 */
    18548796, /* 74975 (1640) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 6,  6,  6]  1 */
    53331727, /* 74976 (1640) [ 0,  0,  1,  0, -1,  0, -1,  0,  0] [ 6,  9,  9] -1 */
    26230026, /* 74977 (1640) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 9,  3,  0]  1 */
    52565882, /* 74978 (1640) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    43240350, /* 74979 (1640) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 3,  3,  0] -1 */
    27765300, /* 74980 (1640) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 9,  9,  6]  1 */
    51028996, /* 74981 (1640) [ 0,  0,  1,  0,  1,  0,  1,  0,  0] [ 6,  0,  0] -1 */
    34783223, /* 74982 (1640) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  3,  3] -1 */
    53206511, /* 74983 (1640) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  9,  3] -1 */
     1426198, /* 74984 (1640) [ 0,  0, -1,  0, -1,  0, -1,  0,  0] [ 0,  6,  0]  1 */
    27642568, /* 74985 (1640) [ 0, -1,  0,  0,  0, -1,  1,  0,  0] [ 9,  9,  0]  1 */
    25584595, /* 74986 (1640) [ 1,  0,  0,  0,  0, -1,  0,  1,  0] [ 9,  0,  3]  1 */
    44769952, /* 74987 (1640) [ 0,  0,  1,  1,  0,  0,  0, -1,  0] [ 3,  9,  6] -1 */
    52570042, /* 74988 (1640) [ 1,  0,  0,  0,  0,  1,  0,  1,  0] [ 6,  6,  6] -1 */
    51034768, /* 74989 (1640) [ 1,  0,  0,  0,  0,  1,  0,  1,  0] [ 6,  0,  0] -1 */
    17781647, /* 74990 (1640) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 6,  3,  3]  1 */
    17009362, /* 74991 (1640) [-1,  0,  0,  0,  0, -1,  0, -1,  0] [ 6,  0,  0]  1 */
    42700323, /* 74992 (1640) [ 0, -1,  0,  1,  0,  0,  0,  0, -1] [ 3,  0,  9] -1 */
    26343490, /* 74993 (1640) [ 0, -1,  0,  0,  0, -1,  1,  0,  0] [ 9,  3,  6]  1 */
    34140982, /* 74994 (1640) [ 0,  0,  1,  0,  1,  0,  1,  0,  0] [ 0,  0,  6] -1 */
    59710549, /* 74995 (1640) [ 0,  1,  0,  0,  0, -1,  1,  0,  0] [ 9,  0,  9] -1 */
      894937, /* 74996 (1640) [ 0,  0, -1,  0,  1,  0,  1,  0,  0] [ 0,  3,  9]  1 */
    26344726, /* 74997 (1640) [ 0,  0, -1, -1,  0,  0,  0,  1,  0] [ 9,  3,  6]  1 */
    26228398, /* 74998 (1640) [ 0,  0,  1,  0,  1,  0, -1,  0,  0] [ 9,  3,  0]  1 */
    59714861, /* 74999 (1640) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 9,  0,  9] -1 */
     9342012, /* 75000 (1640) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 3,  3,  6]  1 */
    26994745, /* 75001 (1640) [ 0,  0, -1,  1,  0,  0,  0, -1,  0] [ 9,  6,  3]  1 */
      779629, /* 75002 (1640) [ 0,  1,  0,  0,  0, -1, -1,  0,  0] [ 0,  3,  3]  1 */
    19202917, /* 75003 (1640) [ 0,  1,  0,  0,  0, -1, -1,  0,  0] [ 6,  9,  3]  1 */
    26234182, /* 75004 (1640) [ 1,  0,  0,  0,  0,  1,  0, -1,  0] [ 9,  3,  0]  1 */
    17777059, /* 75005 (1640) [-1,  0,  0,  0,  0,  1,  0,  1,  0] [ 6,  3,  3]  1 */
    25580003, /* 75006 (1640) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 9,  0,  3]  1 */
    27638132, /* 75007 (1640) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 9,  9,  0]  1 */
     1420426, /* 75008 (1640) [-1,  0,  0,  0,  0, -1,  0, -1,  0] [ 0,  6,  0]  1 */
      777961, /* 75009 (1640) [ 0,  0,  1, -1,  0,  0,  0, -1,  0] [ 0,  3,  3]  1 */
    17908167, /* 75010 (1640) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  3,  9]  1 */
    25689675, /* 75011 (1640) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 9,  0,  9]  1 */
     2313235, /* 75012 (1640) [ 0,  0,  1, -1,  0,  0,  0, -1,  0] [ 0,  9,  9]  1 */
    44650084, /* 75013 (1640) [ 0,  0, -1,  0, -1,  0,  1,  0,  0] [ 3,  9,  0] -1 */
    36322825, /* 75014 (1640) [ 0, -1,  0,  0,  0,  1,  1,  0,  0] [ 0,  9,  9] -1 */
     8691989, /* 75015 (1640) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 3,  0,  9]  1 */
    27115277, /* 75016 (1640) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 9,  6,  9]  1 */
     9340384, /* 75017 (1640) [ 0,  0,  1,  0,  1,  0, -1,  0,  0] [ 3,  3,  6]  1 */
    18439772, /* 75018 (1640) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
     8690701, /* 75019 (1640) [ 0,  0,  1,  0, -1,  0,  1,  0,  0] [ 3,  0,  9]  1 */
     9346168, /* 75020 (1640) [ 1,  0,  0,  0,  0,  1,  0, -1,  0] [ 3,  3,  6]  1 */
    36208821, /* 75021 (1640) [ 0,  1,  0, -1,  0,  0,  0,  0, -1] [ 0,  9,  3] -1 */
    53337619, /* 75022 (1640) [ 1,  0,  0,  0,  0, -1,  0, -1,  0] [ 6,  9,  9] -1 */
    51145300, /* 75023 (1640) [ 0,  0, -1, -1,  0,  0,  0, -1,  0] [ 6,  0,  6] -1 */
    51796453, /* 75024 (1640) [ 0,  0,  1,  0, -1,  0, -1,  0,  0] [ 6,  3,  3] -1 */
    10750118, /* 75025 (1640) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 3,  9,  6]  1 */
    44775624, /* 75026 (1640) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 3,  9,  6] -1 */
    51802345, /* 75027 (1640) [ 1,  0,  0,  0,  0, -1,  0, -1,  0] [ 6,  3,  3] -1 */
    34789219, /* 75028 (1640) [ 0,  0, -1,  1,  0,  0,  0,  1,  0] [ 0,  3,  3] -1 */
     9214844, /* 75029 (1640) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 3,  3,  0]  1 */
    53212507, /* 75030 (1640) [ 0,  0, -1,  1,  0,  0,  0,  1,  0] [ 6,  9,  3] -1 */
    34909743, /* 75031 (1640) [ 0,  1,  0, -1,  0,  0,  0,  0, -1] [ 0,  3,  9] -1 */
    34019842, /* 75032 (1640) [ 0, -1,  0,  0,  0, -1, -1,  0,  0] [ 0,  0,  0] -1 */
    42701611, /* 75033 (1640) [ 0,  0, -1,  0,  1,  0, -1,  0,  0] [ 3,  0,  9] -1 */
    36318497, /* 75034 (1640) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  9,  9] -1 */
    52443130, /* 75035 (1640) [ 0, -1,  0,  0,  0, -1, -1,  0,  0] [ 6,  6,  0] -1 */
    52564270, /* 75036 (1640) [ 0,  0,  1,  0,  1,  0,  1,  0,  0] [ 6,  6,  6] -1 */
     8696581, /* 75037 (1640) [ 1,  0,  0,  0,  0, -1,  0,  1,  0] [ 3,  0,  9]  1 */
    18435352, /* 75038 (1640) [ 0,  1,  0,  0,  0,  1,  1,  0,  0] [ 6,  6,  0]  1 */
    61009627, /* 75039 (1640) [ 0,  1,  0,  0,  0, -1,  1,  0,  0] [ 9,  6,  3] -1 */
    44648456, /* 75040 (1640) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 3,  9,  0] -1 */
    60360124, /* 75041 (1640) [ 0,  1,  0,  0,  0,  1, -1,  0,  0] [ 9,  3,  6] -1 */
      893633, /* 75042 (1640) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 0,  3,  9]  1 */
     1424586, /* 75043 (1640) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 0,  6,  0]  1 */
       10816, /* 75044 (1640) [ 0,  0,  1,  1,  0,  0,  0,  1,  0] [ 0,  0,  0]  1 */
    34015422, /* 75045 (1640) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    18434104, /* 75046 (1640) [ 0,  0,  1,  1,  0,  0,  0,  1,  0] [ 6,  6,  0]  1 */
    52438710, /* 75047 (1640) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
    42584659, /* 75048 (1640) [ 0,  0,  1, -1,  0,  0,  0,  1,  0] [ 3,  0,  3] -1 */
    61007947, /* 75049 (1640) [ 0,  0,  1, -1,  0,  0,  0,  1,  0] [ 9,  6,  3] -1 */
    35441672, /* 75050 (1640) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 0,  6,  0] -1 */
       12064, /* 75051 (1640) [ 0,  1,  0,  0,  0,  1,  1,  0,  0] [ 0,  0,  0]  1 */
    59583745, /* 75052 (1640) [-1,  0,  0,  0,  0,  1,  0, -1,  0] [ 9,  0,  3] -1 */
     1551758, /* 75053 (1640) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
     8571457, /* 75054 (1640) [ 0,  0, -1,  1,  0,  0,  0, -1,  0] [ 3,  0,  3]  1 */
    34146754, /* 75055 (1640) [ 1,  0,  0,  0,  0,  1,  0,  1,  0] [ 0,  0,  6] -1 */
    10754554, /* 75056 (1640) [ 0, -1,  0,  0,  0, -1,  1,  0,  0] [ 3,  9,  6]  1 */
    27763672, /* 75057 (1640) [ 0,  0,  1,  0,  1,  0, -1,  0,  0] [ 9,  9,  6]  1 */
    17902171, /* 75058 (1640) [ 0,  0,  1, -1,  0,  0,  0, -1,  0] [ 6,  3,  9]  1 */
    44644300, /* 75059 (1640) [-1,  0,  0,  0,  0, -1,  0,  1,  0] [ 3,  9,  0] -1 */
     2314903, /* 75060 (1640) [ 0,  1,  0,  0,  0, -1, -1,  0,  0] [ 0,  9,  9]  1 */
    17015134, /* 75061 (1640) [ 0,  0, -1,  0, -1,  0, -1,  0,  0] [ 6,  0,  0]  1 */
    27769456, /* 75062 (1640) [ 1,  0,  0,  0,  0,  1,  0, -1,  0] [ 9,  9,  6]  1 */
      889045, /* 75063 (1640) [-1,  0,  0,  0,  0,  1,  0,  1,  0] [ 0,  3,  9]  1 */
    35445832, /* 75064 (1640) [ 1,  0,  0,  0,  0,  1,  0,  1,  0] [ 0,  6,  0] -1 */
    60358888, /* 75065 (1640) [ 0,  0,  1,  1,  0,  0,  0, -1,  0] [ 9,  3,  6] -1 */
    43994809, /* 75066 (1640) [-1,  0,  0,  0,  0,  1,  0, -1,  0] [ 3,  6,  3] -1 */
    35555116, /* 75067 (1640) [ 0, -1,  0,  0,  0, -1, -1,  0,  0] [ 0,  6,  6] -1 */
    60239020, /* 75068 (1640) [ 0,  0, -1,  0, -1,  0,  1,  0,  0] [ 9,  3,  0] -1 */
    25693987, /* 75069 (1640) [ 0, -1,  0,  0,  0,  1, -1,  0,  0] [ 9,  0,  9]  1 */
     1546090, /* 75070 (1640) [ 0,  0,  1,  1,  0,  0,  0,  1,  0] [ 0,  6,  6]  1 */
    35550696, /* 75071 (1640) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  6] -1 */
    44000689, /* 75072 (1640) [ 0,  0, -1,  0,  1,  0, -1,  0,  0] [ 3,  6,  3] -1 */
     9995659, /* 75073 (1640) [ 1,  0,  0,  0,  0, -1,  0,  1,  0] [ 3,  6,  3]  1 */
    61774294, /* 75074 (1640) [ 0,  0, -1,  0, -1,  0,  1,  0,  0] [ 9,  9,  6] -1 */
    51907433, /* 75075 (1640) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  3,  9] -1 */
    34908439, /* 75076 (1640) [ 0,  0,  1,  0, -1,  0, -1,  0,  0] [ 0,  3,  9] -1 */
    36324493, /* 75077 (1640) [ 0,  0, -1,  1,  0,  0,  0,  1,  0] [ 0,  9,  9] -1 */
    61659202, /* 75078 (1640) [ 0,  1,  0,  0,  0,  1, -1,  0,  0] [ 9,  9,  0] -1 */
    17782951, /* 75079 (1640) [ 0,  0, -1,  0,  1,  0,  1,  0,  0] [ 6,  3,  3]  1 */
    43351006, /* 75080 (1640) [ 0,  0, -1,  0, -1,  0,  1,  0,  0] [ 3,  3,  6] -1 */
    43999401, /* 75081 (1640) [ 0, -1,  0,  1,  0,  0,  0,  0, -1] [ 3,  6,  3] -1 */
    44121613, /* 75082 (1640) [ 0,  1,  0,  0,  0, -1,  1,  0,  0] [ 3,  6,  9] -1 */
     2188123, /* 75083 (1640) [-1,  0,  0,  0,  0,  1,  0,  1,  0] [ 0,  9,  3]  1 */
    60237392, /* 75084 (1640) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 9,  3,  0] -1 */
    25695667, /* 75085 (1640) [ 0,  0, -1,  1,  0,  0,  0, -1,  0] [ 9,  0,  9]  1 */
     2194015, /* 75086 (1640) [ 0,  0, -1,  0,  1,  0,  1,  0,  0] [ 0,  9,  3]  1 */
    17903839, /* 75087 (1640) [ 0,  1,  0,  0,  0, -1, -1,  0,  0] [ 6,  3,  9]  1 */
    52444378, /* 75088 (1640) [ 0,  0, -1, -1,  0,  0,  0, -1,  0] [ 6,  6,  0] -1 */
    19318225, /* 75089 (1640) [ 0,  0, -1,  0,  1,  0,  1,  0,  0] [ 6,  9,  9]  1 */
    42590651, /* 75090 (1640) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 3,  0,  3] -1 */
    27643804, /* 75091 (1640) [ 0,  0, -1, -1,  0,  0,  0,  1,  0] [ 9,  9,  0]  1 */
    44119933, /* 75092 (1640) [ 0,  0,  1, -1,  0,  0,  0,  1,  0] [ 3,  6,  9] -1 */
    61013939, /* 75093 (1640) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 9,  6,  3] -1 */
    60364560, /* 75094 (1640) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 9,  3,  6] -1 */
    61119019, /* 75095 (1640) [-1,  0,  0,  0,  0,  1,  0, -1,  0] [ 9,  6,  9] -1 */
    61657966, /* 75096 (1640) [ 0,  0,  1,  1,  0,  0,  0, -1,  0] [ 9,  9,  0] -1 */
    10106731, /* 75097 (1640) [ 0,  0, -1,  1,  0,  0,  0, -1,  0] [ 3,  6,  9]  1 */
     9219280, /* 75098 (1640) [ 0, -1,  0,  0,  0, -1,  1,  0,  0] [ 3,  3,  0]  1 */
    60233236, /* 75099 (1640) [-1,  0,  0,  0,  0, -1,  0,  1,  0] [ 9,  3,  0] -1 */
    35440060, /* 75100 (1640) [ 0,  0,  1,  0,  1,  0,  1,  0,  0] [ 0,  6,  0] -1 */
      783957, /* 75101 (1640) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  3,  3]  1 */
    26993065, /* 75102 (1640) [ 0, -1,  0,  0,  0,  1, -1,  0,  0] [ 9,  6,  3]  1 */
    19207245, /* 75103 (1640) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  9,  3]  1 */
    18550408, /* 75104 (1640) [ 0,  0, -1,  0, -1,  0, -1,  0,  0] [ 6,  6,  6]  1 */
      127120, /* 75105 (1640) [ 0,  0, -1,  0, -1,  0, -1,  0,  0] [ 0,  0,  6]  1 */
    34787551, /* 75106 (1640) [ 0, -1,  0,  0,  0,  1,  1,  0,  0] [ 0,  3,  3] -1 */
    26988753, /* 75107 (1640) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 9,  6,  3]  1 */
    51144052, /* 75108 (1640) [ 0, -1,  0,  0,  0, -1, -1,  0,  0] [ 6,  0,  6] -1 */
    51911761, /* 75109 (1640) [ 0, -1,  0,  0,  0,  1,  1,  0,  0] [ 6,  3,  9] -1 */
    17013522, /* 75110 (1640) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 6,  0,  0]  1 */
     1547338, /* 75111 (1640) [ 0,  1,  0,  0,  0,  1,  1,  0,  0] [ 0,  6,  6]  1 */
    43349378, /* 75112 (1640) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 3,  3,  6] -1 */
    25578715, /* 75113 (1640) [ 0,  0,  1,  0, -1,  0,  1,  0,  0] [ 9,  0,  3]  1 */
    51030608, /* 75114 (1640) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 6,  0,  0] -1 */
    17135026, /* 75115 (1640) [ 0,  0,  1,  1,  0,  0,  0,  1,  0] [ 6,  0,  6]  1 */
    10641090, /* 75116 (1640) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 3,  9,  0]  1 */
     9220516, /* 75117 (1640) [ 0,  0, -1, -1,  0,  0,  0,  1,  0] [ 3,  3,  0]  1 */
    35556364, /* 75118 (1640) [ 0,  0, -1, -1,  0,  0,  0, -1,  0] [ 0,  6,  6] -1 */
    10755790, /* 75119 (1640) [ 0,  0, -1, -1,  0,  0,  0,  1,  0] [ 3,  9,  6]  1 */
    53333031, /* 75120 (1640) [ 0,  1,  0, -1,  0,  0,  0,  0, -1] [ 6,  9,  9] -1 */
    51797757, /* 75121 (1640) [ 0,  1,  0, -1,  0,  0,  0,  0, -1] [ 6,  3,  3] -1 */
    61124899, /* 75122 (1640) [ 0,  0, -1,  0,  1,  0, -1,  0,  0] [ 9,  6,  9] -1 */
    36207517, /* 75123 (1640) [ 0,  0,  1,  0, -1,  0, -1,  0,  0] [ 0,  9,  3] -1 */
     9989779, /* 75124 (1640) [ 0,  0,  1,  0, -1,  0,  1,  0,  0] [ 3,  6,  3]  1 */
    59589625, /* 75125 (1640) [ 0,  0, -1,  0,  1,  0, -1,  0,  0] [ 9,  0,  3] -1 */
    51913429, /* 75126 (1640) [ 0,  0, -1,  1,  0,  0,  0,  1,  0] [ 6,  3,  9] -1 */
    36213409, /* 75127 (1640) [ 1,  0,  0,  0,  0, -1,  0, -1,  0] [ 0,  9,  3] -1 */
    27119869, /* 75128 (1640) [ 1,  0,  0,  0,  0, -1,  0,  1,  0] [ 9,  6,  9]  1 */
    27113989, /* 75129 (1640) [ 0,  0,  1,  0, -1,  0,  1,  0,  0] [ 9,  6,  9]  1 */
    34142594, /* 75130 (1640) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    43234678, /* 75131 (1640) [ 0,  0,  1,  1,  0,  0,  0, -1,  0] [ 3,  3,  0] -1 */
    43345222, /* 75132 (1640) [-1,  0,  0,  0,  0, -1,  0,  1,  0] [ 3,  3,  6] -1 */
    18544636, /* 75133 (1640) [-1,  0,  0,  0,  0, -1,  0, -1,  0] [ 6,  6,  6]  1 */
    59588337, /* 75134 (1640) [ 0, -1,  0,  1,  0,  0,  0,  0, -1] [ 9,  0,  3] -1 */
    34914331, /* 75135 (1640) [ 1,  0,  0,  0,  0, -1,  0, -1,  0] [ 0,  3,  9] -1 */
    61123611, /* 75136 (1640) [ 0, -1,  0,  1,  0,  0,  0,  0, -1] [ 9,  6,  9] -1 */
      121348, /* 75137 (1640) [-1,  0,  0,  0,  0, -1,  0, -1,  0] [ 0,  0,  6]  1 */
    59708869, /* 75138 (1640) [ 0,  0,  1, -1,  0,  0,  0,  1,  0] [ 9,  0,  9] -1 */
    10639462, /* 75139 (1640) [ 0,  0,  1,  0,  1,  0, -1,  0,  0] [ 3,  9,  0]  1 */
     2192711, /* 75140 (1640) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 0,  9,  3]  1 */
    19316921, /* 75141 (1640) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 6,  9,  9]  1 */
    42586339, /* 75142 (1640) [ 0,  1,  0,  0,  0, -1,  1,  0,  0] [ 3,  0,  3] -1 */
    10645246, /* 75143 (1640) [ 1,  0,  0,  0,  0,  1,  0, -1,  0] [ 3,  9,  0]  1 */
    19312333, /* 75144 (1640) [-1,  0,  0,  0,  0,  1,  0,  1,  0] [ 6,  9,  9]  1 */
    61772666, /* 75145 (1640) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 9,  9,  6] -1 */
    34021090, /* 75146 (1640) [ 0,  0, -1, -1,  0,  0,  0, -1,  0] [ 0,  0,  0] -1 */
       16484, /* 75147 (1641) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
     8565465, /* 75148 (1641) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 3,  0,  3]  1 */
    17140694, /* 75149 (1641) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
     9987177, /* 75150 (1641) [ 0, -1,  0,  1,  0,  0,  0,  0, -1] [ 3,  6,  3]  1 */
    26997403, /* 75151 (1641) [ 0,  1,  0,  0,  0, -1,  1,  0,  0] [ 9,  6,  3]  1 */
    26347900, /* 75152 (1641) [ 0,  1,  0,  0,  0,  1, -1,  0,  0] [ 9,  3,  6]  1 */
    51793663, /* 75153 (1641) [ 0, -1,  0,  0,  0,  1,  1,  0,  0] [ 6,  3,  3] -1 */
        3198, /* 75154 (1641) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    43345166, /* 75155 (1641) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 3,  3,  6] -1 */
    10107709, /* 75156 (1641) [ 0,  0,  1, -1,  0,  0,  0,  1,  0] [ 3,  6,  9]  1 */
    42590707, /* 75157 (1641) [ 1,  0,  0,  0,  0, -1,  0,  1,  0] [ 3,  0,  3] -1 */
    25571521, /* 75158 (1641) [-1,  0,  0,  0,  0,  1,  0, -1,  0] [ 9,  0,  3]  1 */
    17136274, /* 75159 (1641) [ 0,  1,  0,  0,  0,  1,  1,  0,  0] [ 6,  0,  6]  1 */
    53214933, /* 75160 (1641) [ 0,  1,  0, -1,  0,  0,  0,  0, -1] [ 6,  9,  3] -1 */
    26221012, /* 75161 (1641) [-1,  0,  0,  0,  0, -1,  0,  1,  0] [ 9,  3,  0]  1 */
    26230026, /* 75162 (1641) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 9,  3,  0]  1 */
    34024496, /* 75163 (1641) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    52447784, /* 75164 (1641) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 6,  6,  0] -1 */
    36318445, /* 75165 (1641) [-1,  0,  0,  0,  0,  1,  0,  1,  0] [ 0,  9,  9] -1 */
    17018384, /* 75166 (1641) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 6,  0,  0]  1 */
    59590771, /* 75167 (1641) [ 0,  0,  1, -1,  0,  0,  0,  1,  0] [ 9,  0,  3] -1 */
    26228398, /* 75168 (1641) [ 0,  0,  1,  0,  1,  0, -1,  0,  0] [ 9,  3,  0]  1 */
    44121389, /* 75169 (1641) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 3,  6,  9] -1 */
    42577633, /* 75170 (1641) [-1,  0,  0,  0,  0,  1,  0, -1,  0] [ 3,  0,  3] -1 */
    43350838, /* 75171 (1641) [ 0,  0, -1, -1,  0,  0,  0,  1,  0] [ 3,  3,  6] -1 */
     2313235, /* 75172 (1641) [ 0,  0,  1, -1,  0,  0,  0, -1,  0] [ 0,  9,  9]  1 */
     8574115, /* 75173 (1641) [ 0,  1,  0,  0,  0, -1,  1,  0,  0] [ 3,  0,  3]  1 */
    60357118, /* 75174 (1641) [ 0,  0, -1,  0, -1,  0,  1,  0,  0] [ 9,  3,  6] -1 */
    34146806, /* 75175 (1641) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    51911969, /* 75176 (1641) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 6,  3,  9] -1 */
    18439772, /* 75177 (1641) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
     8690701, /* 75178 (1641) [ 0,  0,  1,  0, -1,  0,  1,  0,  0] [ 3,  0,  9]  1 */
     9346168, /* 75179 (1641) [ 1,  0,  0,  0,  0,  1,  0, -1,  0] [ 3,  3,  6]  1 */
    51920443, /* 75180 (1641) [ 1,  0,  0,  0,  0, -1,  0, -1,  0] [ 6,  3,  9] -1 */
    10750118, /* 75181 (1641) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 3,  9,  6]  1 */
    17899537, /* 75182 (1641) [ 0, -1,  0,  0,  0,  1,  1,  0,  0] [ 6,  3,  9]  1 */
    51796297, /* 75183 (1641) [ 0,  0,  1, -1,  0,  0,  0, -1,  0] [ 6,  3,  3] -1 */
    44644244, /* 75184 (1641) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 3,  9,  0] -1 */
    51025954, /* 75185 (1641) [ 0, -1,  0,  0,  0, -1, -1,  0,  0] [ 6,  0,  0] -1 */
     8696581, /* 75186 (1641) [ 1,  0,  0,  0,  0, -1,  0,  1,  0] [ 3,  0,  9]  1 */
    18435352, /* 75187 (1641) [ 0,  1,  0,  0,  0,  1,  1,  0,  0] [ 6,  6,  0]  1 */
    25577401, /* 75188 (1641) [ 0,  0, -1,  0,  1,  0, -1,  0,  0] [ 9,  0,  3]  1 */
      130370, /* 75189 (1641) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 0,  0,  6]  1 */
     8571457, /* 75190 (1641) [ 0,  0, -1,  1,  0,  0,  0, -1,  0] [ 3,  0,  3]  1 */
    18557818, /* 75191 (1641) [ 1,  0,  0,  0,  0,  1,  0,  1,  0] [ 6,  6,  6]  1 */
    10754554, /* 75192 (1641) [ 0, -1,  0,  0,  0, -1,  1,  0,  0] [ 3,  9,  6]  1 */
    52442922, /* 75193 (1641) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 6,  6,  0] -1 */
    36204727, /* 75194 (1641) [ 0, -1,  0,  0,  0,  1,  1,  0,  0] [ 0,  9,  3] -1 */
    25702637, /* 75195 (1641) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 9,  0,  9]  1 */
    35556520, /* 75196 (1641) [ 0,  0, -1,  0, -1,  0, -1,  0,  0] [ 0,  6,  6] -1 */
    34905649, /* 75197 (1641) [ 0, -1,  0,  0,  0,  1,  1,  0,  0] [ 0,  3,  9] -1 */
    27651414, /* 75198 (1641) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 9,  9,  0]  1 */
     9223690, /* 75199 (1641) [ 0,  1,  0,  0,  0,  1, -1,  0,  0] [ 3,  3,  0]  1 */
     9995659, /* 75200 (1641) [ 1,  0,  0,  0,  0, -1,  0,  1,  0] [ 3,  6,  3]  1 */
    53333239, /* 75201 (1641) [ 0,  1,  0,  0,  0, -1, -1,  0,  0] [ 6,  9,  9] -1 */
    42583513, /* 75202 (1641) [ 0,  0, -1,  0,  1,  0, -1,  0,  0] [ 3,  0,  3] -1 */
    43232908, /* 75203 (1641) [ 0,  0, -1,  0, -1,  0,  1,  0,  0] [ 3,  3,  0] -1 */
    19325395, /* 75204 (1641) [ 1,  0,  0,  0,  0, -1,  0, -1,  0] [ 6,  9,  9]  1 */
    42708749, /* 75205 (1641) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 3,  0,  9] -1 */
     2194015, /* 75206 (1641) [ 0,  0, -1,  0,  1,  0,  1,  0,  0] [ 0,  9,  3]  1 */
      897519, /* 75207 (1641) [ 0,  1,  0, -1,  0,  0,  0,  0, -1] [ 0,  3,  9]  1 */
        7618, /* 75208 (1641) [ 0, -1,  0,  0,  0, -1, -1,  0,  0] [ 0,  0,  0]  1 */
    18430906, /* 75209 (1641) [ 0, -1,  0,  0,  0, -1, -1,  0,  0] [ 6,  6,  0]  1 */
    26995723, /* 75210 (1641) [ 0,  0,  1, -1,  0,  0,  0,  1,  0] [ 9,  6,  3]  1 */
    61772890, /* 75211 (1641) [ 0, -1,  0,  0,  0, -1,  1,  0,  0] [ 9,  9,  6] -1 */
    51145456, /* 75212 (1641) [ 0,  0, -1,  0, -1,  0, -1,  0,  0] [ 6,  0,  6] -1 */
     1433608, /* 75213 (1641) [ 1,  0,  0,  0,  0,  1,  0,  1,  0] [ 0,  6,  0]  1 */
     9982585, /* 75214 (1641) [-1,  0,  0,  0,  0,  1,  0, -1,  0] [ 3,  6,  3]  1 */
    10755790, /* 75215 (1641) [ 0,  0, -1, -1,  0,  0,  0,  1,  0] [ 3,  9,  6]  1 */
    36331507, /* 75216 (1641) [ 1,  0,  0,  0,  0, -1,  0, -1,  0] [ 0,  9,  9] -1 */
    53206459, /* 75217 (1641) [-1,  0,  0,  0,  0,  1,  0,  1,  0] [ 6,  9,  3] -1 */
     2310601, /* 75218 (1641) [ 0, -1,  0,  0,  0,  1,  1,  0,  0] [ 0,  9,  9]  1 */
     1538472, /* 75219 (1641) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
    18544636, /* 75220 (1641) [-1,  0,  0,  0,  0, -1,  0, -1,  0] [ 6,  6,  6]  1 */
    34901321, /* 75221 (1641) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  3,  9] -1 */
    53324609, /* 75222 (1641) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  9,  9] -1 */
    27762070, /* 75223 (1641) [ 0,  0, -1,  0, -1,  0,  1,  0,  0] [ 9,  9,  6]  1 */
    61009403, /* 75224 (1641) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 9,  6,  3] -1 */
    17895209, /* 75225 (1641) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  3,  9]  1 */
    44001835, /* 75226 (1641) [ 0,  0,  1, -1,  0,  0,  0,  1,  0] [ 3,  6,  3] -1 */
    19316921, /* 75227 (1641) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 6,  9,  9]  1 */
    19201249, /* 75228 (1641) [ 0,  0,  1, -1,  0,  0,  0, -1,  0] [ 6,  9,  3]  1 */
    26339054, /* 75229 (1641) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 9,  3,  6]  1 */
    51034820, /* 75230 (1641) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  0,  0] -1 */
      125508, /* 75231 (1641) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  6]  1 */
    18548796, /* 75232 (1641) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 6,  6,  6]  1 */
    51913273, /* 75233 (1641) [ 0,  0, -1,  0,  1,  0,  1,  0,  0] [ 6,  3,  9] -1 */
    53213629, /* 75234 (1641) [ 0,  0,  1,  0, -1,  0, -1,  0,  0] [ 6,  9,  3] -1 */
    36323033, /* 75235 (1641) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 0,  9,  9] -1 */
    44771412, /* 75236 (1641) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 3,  9,  6] -1 */
    51914551, /* 75237 (1641) [ 0,  0,  1,  0, -1,  0, -1,  0,  0] [ 6,  3,  9] -1 */
    25584595, /* 75238 (1641) [ 1,  0,  0,  0,  0, -1,  0,  1,  0] [ 9,  0,  3]  1 */
    61663582, /* 75239 (1641) [ 1,  0,  0,  0,  0,  1,  0, -1,  0] [ 9,  9,  0] -1 */
    34783171, /* 75240 (1641) [-1,  0,  0,  0,  0,  1,  0,  1,  0] [ 0,  3,  3] -1 */
    34907317, /* 75241 (1641) [ 0,  0, -1,  1,  0,  0,  0,  1,  0] [ 0,  3,  9] -1 */
    53330605, /* 75242 (1641) [ 0,  0, -1,  1,  0,  0,  0,  1,  0] [ 6,  9,  9] -1 */
    52451944, /* 75243 (1641) [ 1,  0,  0,  0,  0,  1,  0,  1,  0] [ 6,  6,  0] -1 */
    61774126, /* 75244 (1641) [ 0,  0, -1, -1,  0,  0,  0,  1,  0] [ 9,  9,  6] -1 */
    36207361, /* 75245 (1641) [ 0,  0,  1, -1,  0,  0,  0, -1,  0] [ 0,  9,  3] -1 */
    61119075, /* 75246 (1641) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 9,  6,  9] -1 */
    10757728, /* 75247 (1641) [ 0,  0,  1,  1,  0,  0,  0, -1,  0] [ 3,  9,  6]  1 */
    61127725, /* 75248 (1641) [ 0,  1,  0,  0,  0, -1,  1,  0,  0] [ 9,  6,  9] -1 */
    17901205, /* 75249 (1641) [ 0,  0, -1,  1,  0,  0,  0,  1,  0] [ 6,  3,  9]  1 */
    34133520, /* 75250 (1641) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
    26344726, /* 75251 (1641) [ 0,  0, -1, -1,  0,  0,  0,  1,  0] [ 9,  3,  6]  1 */
    34914279, /* 75252 (1641) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  3,  9] -1 */
    53337567, /* 75253 (1641) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  9,  9] -1 */
    44769784, /* 75254 (1641) [ 0,  0,  1,  0,  1,  0, -1,  0,  0] [ 3,  9,  6] -1 */
     9338782, /* 75255 (1641) [ 0,  0, -1,  0, -1,  0,  1,  0,  0] [ 3,  3,  6]  1 */
     1420426, /* 75256 (1641) [-1,  0,  0,  0,  0, -1,  0, -1,  0] [ 0,  6,  0]  1 */
    43240294, /* 75257 (1641) [ 1,  0,  0,  0,  0,  1,  0, -1,  0] [ 3,  3,  0] -1 */
    17908167, /* 75258 (1641) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  3,  9]  1 */
    26225168, /* 75259 (1641) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 9,  3,  0]  1 */
     8691989, /* 75260 (1641) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 3,  0,  9]  1 */
        8866, /* 75261 (1641) [ 0,  0, -1, -1,  0,  0,  0, -1,  0] [ 0,  0,  0]  1 */
    18432154, /* 75262 (1641) [ 0,  0, -1, -1,  0,  0,  0, -1,  0] [ 6,  6,  0]  1 */
    27115277, /* 75263 (1641) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 9,  6,  9]  1 */
    10113701, /* 75264 (1641) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 3,  6,  9]  1 */
    51797965, /* 75265 (1641) [ 0,  1,  0,  0,  0, -1, -1,  0,  0] [ 6,  3,  3] -1 */
    17127408, /* 75266 (1641) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  6]  1 */
     9214844, /* 75267 (1641) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 3,  3,  0]  1 */
    52556808, /* 75268 (1641) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
     1424586, /* 75269 (1641) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 0,  6,  0]  1 */
    59596763, /* 75270 (1641) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 9,  0,  3] -1 */
    17785533, /* 75271 (1641) [ 0,  1,  0, -1,  0,  0,  0,  0, -1] [ 6,  3,  3]  1 */
    59701843, /* 75272 (1641) [-1,  0,  0,  0,  0,  1,  0, -1,  0] [ 9,  0,  9] -1 */
       12064, /* 75273 (1641) [ 0,  1,  0,  0,  0,  1,  1,  0,  0] [ 0,  0,  0]  1 */
    60360348, /* 75274 (1641) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 9,  3,  6] -1 */
    27769456, /* 75275 (1641) [ 1,  0,  0,  0,  0,  1,  0, -1,  0] [ 9,  9,  6]  1 */
      889045, /* 75276 (1641) [-1,  0,  0,  0,  0,  1,  0,  1,  0] [ 0,  3,  9]  1 */
    61776064, /* 75277 (1641) [ 0,  0,  1,  1,  0,  0,  0, -1,  0] [ 9,  9,  6] -1 */
    35558158, /* 75278 (1641) [ 0,  0,  1,  0,  1,  0,  1,  0,  0] [ 0,  6,  6] -1 */
    25693987, /* 75279 (1641) [ 0, -1,  0,  0,  0,  1, -1,  0,  0] [ 9,  0,  9]  1 */
    44648680, /* 75280 (1641) [ 0, -1,  0,  0,  0, -1,  1,  0,  0] [ 3,  9,  0] -1 */
     1546090, /* 75281 (1641) [ 0,  0,  1,  1,  0,  0,  0,  1,  0] [ 0,  6,  6]  1 */
    34015474, /* 75282 (1641) [-1,  0,  0,  0,  0, -1,  0, -1,  0] [ 0,  0,  0] -1 */
    52438762, /* 75283 (1641) [-1,  0,  0,  0,  0, -1,  0, -1,  0] [ 6,  6,  0] -1 */
    53219521, /* 75284 (1641) [ 1,  0,  0,  0,  0, -1,  0, -1,  0] [ 6,  9,  3] -1 */
    10637860, /* 75285 (1641) [ 0,  0, -1,  0, -1,  0,  1,  0,  0] [ 3,  9,  0]  1 */
    60358720, /* 75286 (1641) [ 0,  0,  1,  0,  1,  0, -1,  0,  0] [ 9,  3,  6] -1 */
    19198615, /* 75287 (1641) [ 0, -1,  0,  0,  0,  1,  1,  0,  0] [ 6,  9,  3]  1 */
    34791645, /* 75288 (1641) [ 0,  1,  0, -1,  0,  0,  0,  0, -1] [ 0,  3,  3] -1 */
    44649916, /* 75289 (1641) [ 0,  0, -1, -1,  0,  0,  0,  1,  0] [ 3,  9,  0] -1 */
    51789335, /* 75290 (1641) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  3,  3] -1 */
    36325615, /* 75291 (1641) [ 0,  0,  1,  0, -1,  0, -1,  0,  0] [ 0,  9,  9] -1 */
    61125067, /* 75292 (1641) [ 0,  0, -1,  1,  0,  0,  0, -1,  0] [ 9,  6,  9] -1 */
    59706435, /* 75293 (1641) [ 0, -1,  0,  1,  0,  0,  0,  0, -1] [ 9,  0,  9] -1 */
    19319503, /* 75294 (1641) [ 0,  0,  1,  0, -1,  0, -1,  0,  0] [ 6,  9,  9]  1 */
     2188123, /* 75295 (1641) [-1,  0,  0,  0,  0,  1,  0,  1,  0] [ 0,  9,  3]  1 */
    25695667, /* 75296 (1641) [ 0,  0, -1,  1,  0,  0,  0, -1,  0] [ 9,  0,  9]  1 */
    17903839, /* 75297 (1641) [ 0,  1,  0,  0,  0, -1, -1,  0,  0] [ 6,  3,  9]  1 */
    19318225, /* 75298 (1641) [ 0,  0, -1,  0,  1,  0,  1,  0,  0] [ 6,  9,  9]  1 */
    42700099, /* 75299 (1641) [ 0, -1,  0,  0,  0,  1, -1,  0,  0] [ 3,  0,  9] -1 */
     2306273, /* 75300 (1641) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  9,  9]  1 */
    34019634, /* 75301 (1641) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    43354012, /* 75302 (1641) [ 0,  1,  0,  0,  0,  1, -1,  0,  0] [ 3,  3,  6] -1 */
    35432598, /* 75303 (1641) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  6,  0] -1 */
    17013522, /* 75304 (1641) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 6,  0,  0]  1 */
      134530, /* 75305 (1641) [ 1,  0,  0,  0,  0,  1,  0,  1,  0] [ 0,  0,  6]  1 */
    60237616, /* 75306 (1641) [ 0, -1,  0,  0,  0, -1,  1,  0,  0] [ 9,  3,  0] -1 */
    17135026, /* 75307 (1641) [ 0,  0,  1,  1,  0,  0,  0,  1,  0] [ 6,  0,  6]  1 */
    61656196, /* 75308 (1641) [ 0,  0, -1,  0, -1,  0,  1,  0,  0] [ 9,  9,  0] -1 */
    43236138, /* 75309 (1641) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 3,  3,  0] -1 */
    53211047, /* 75310 (1641) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 6,  9,  3] -1 */
    59707723, /* 75311 (1641) [ 0,  0, -1,  0,  1,  0, -1,  0,  0] [ 9,  0,  9] -1 */
    26226796, /* 75312 (1641) [ 0,  0, -1,  0, -1,  0,  1,  0,  0] [ 9,  3,  0]  1 */
     9989779, /* 75313 (1641) [ 0,  0,  1,  0, -1,  0,  1,  0,  0] [ 3,  6,  3]  1 */
    42701779, /* 75314 (1641) [ 0,  0, -1,  1,  0,  0,  0, -1,  0] [ 3,  0,  9] -1 */
    34909951, /* 75315 (1641) [ 0,  1,  0,  0,  0, -1, -1,  0,  0] [ 0,  3,  9] -1 */
    34141138, /* 75316 (1641) [ 0,  0,  1,  1,  0,  0,  0,  1,  0] [ 0,  0,  6] -1 */
    52564426, /* 75317 (1641) [ 0,  0,  1,  1,  0,  0,  0,  1,  0] [ 6,  6,  6] -1 */
    36324337, /* 75318 (1641) [ 0,  0, -1,  0,  1,  0,  1,  0,  0] [ 0,  9,  9] -1 */
    59583801, /* 75319 (1641) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 9,  0,  3] -1 */
    43352776, /* 75320 (1641) [ 0,  0,  1,  1,  0,  0,  0, -1,  0] [ 3,  3,  6] -1 */
    60233180, /* 75321 (1641) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 9,  3,  0] -1 */
      121348, /* 75322 (1641) [-1,  0,  0,  0,  0, -1,  0, -1,  0] [ 0,  0,  6]  1 */
     2196597, /* 75323 (1641) [ 0,  1,  0, -1,  0,  0,  0,  0, -1] [ 0,  9,  3]  1 */
    51802293, /* 75324 (1641) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  3,  3] -1 */
      896215, /* 75325 (1641) [ 0,  0,  1,  0, -1,  0, -1,  0,  0] [ 0,  3,  9]  1 */
    10645246, /* 75326 (1641) [ 1,  0,  0,  0,  0,  1,  0, -1,  0] [ 3,  9,  0]  1 */
    43234510, /* 75327 (1641) [ 0,  0,  1,  0,  1,  0, -1,  0,  0] [ 3,  3,  0] -1 */
    61781736, /* 75328 (1641) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 9,  9,  6] -1 */
     2312269, /* 75329 (1641) [ 0,  0, -1,  1,  0,  0,  0,  1,  0] [ 0,  9,  9]  1 */
    51147094, /* 75330 (1641) [ 0,  0,  1,  0,  1,  0,  1,  0,  0] [ 6,  0,  6] -1 */
     8572435, /* 75331 (1641) [ 0,  0,  1, -1,  0,  0,  0,  1,  0] [ 3,  0,  3]  1 */
    10105051, /* 75332 (1641) [ 0, -1,  0,  0,  0,  1, -1,  0,  0] [ 3,  6,  9]  1 */
     2319231, /* 75333 (1641) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  9,  9]  1 */
    27001715, /* 75334 (1641) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 9,  6,  3]  1 */
    43358448, /* 75335 (1641) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 3,  3,  6] -1 */
    51795331, /* 75336 (1641) [ 0,  0, -1,  1,  0,  0,  0,  1,  0] [ 6,  3,  3] -1 */
    44766554, /* 75337 (1641) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 3,  9,  6] -1 */
    27765300, /* 75338 (1641) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 9,  9,  6]  1 */
      775327, /* 75339 (1641) [ 0, -1,  0,  0,  0,  1,  1,  0,  0] [ 0,  3,  3]  1 */
    60238852, /* 75340 (1641) [ 0,  0, -1, -1,  0,  0,  0,  1,  0] [ 9,  3,  0] -1 */
    52561228, /* 75341 (1641) [ 0, -1,  0,  0,  0, -1, -1,  0,  0] [ 6,  6,  6] -1 */
    36209029, /* 75342 (1641) [ 0,  1,  0,  0,  0, -1, -1,  0,  0] [ 0,  9,  3] -1 */
    61005513, /* 75343 (1641) [ 0, -1,  0,  1,  0,  0,  0,  0, -1] [ 9,  6,  3] -1 */
    27642568, /* 75344 (1641) [ 0, -1,  0,  0,  0, -1,  1,  0,  0] [ 9,  9,  0]  1 */
    51021534, /* 75345 (1641) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  0,  0] -1 */
    26343490, /* 75346 (1641) [ 0, -1,  0,  0,  0, -1,  1,  0,  0] [ 9,  3,  6]  1 */
    61126045, /* 75347 (1641) [ 0,  0,  1, -1,  0,  0,  0,  1,  0] [ 9,  6,  9] -1 */
    27112675, /* 75348 (1641) [ 0,  0, -1,  0,  1,  0, -1,  0,  0] [ 9,  6,  9]  1 */
    42586115, /* 75349 (1641) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 3,  0,  3] -1 */
     9332998, /* 75350 (1641) [-1,  0,  0,  0,  0, -1,  0,  1,  0] [ 3,  3,  6]  1 */
    51148706, /* 75351 (1641) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 6,  0,  6] -1 */
     9342012, /* 75352 (1641) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 3,  3,  6]  1 */
    44007827, /* 75353 (1641) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 3,  6,  3] -1 */
    35559770, /* 75354 (1641) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 0,  6,  6] -1 */
      902107, /* 75355 (1641) [ 1,  0,  0,  0,  0, -1,  0, -1,  0] [ 0,  3,  9]  1 */
    26234182, /* 75356 (1641) [ 1,  0,  0,  0,  0,  1,  0, -1,  0] [ 9,  3,  0]  1 */
    17777059, /* 75357 (1641) [-1,  0,  0,  0,  0,  1,  0,  1,  0] [ 6,  3,  3]  1 */
    44112907, /* 75358 (1641) [-1,  0,  0,  0,  0,  1,  0, -1,  0] [ 3,  6,  9] -1 */
    35440216, /* 75359 (1641) [ 0,  0,  1,  1,  0,  0,  0,  1,  0] [ 0,  6,  0] -1 */
    25580003, /* 75360 (1641) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 9,  0,  3]  1 */
    27638132, /* 75361 (1641) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 9,  9,  0]  1 */
    44651854, /* 75362 (1641) [ 0,  0,  1,  1,  0,  0,  0, -1,  0] [ 3,  9,  0] -1 */
      777961, /* 75363 (1641) [ 0,  0,  1, -1,  0,  0,  0, -1,  0] [ 0,  3,  3]  1 */
    59709037, /* 75364 (1641) [ 0,  0,  1,  0, -1,  0,  1,  0,  0] [ 9,  0,  9] -1 */
    25689675, /* 75365 (1641) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 9,  0,  9]  1 */
    10758964, /* 75366 (1641) [ 0,  1,  0,  0,  0,  1, -1,  0,  0] [ 3,  9,  6]  1 */
     9340384, /* 75367 (1641) [ 0,  0,  1,  0,  1,  0, -1,  0,  0] [ 3,  3,  6]  1 */
    44118787, /* 75368 (1641) [ 0,  0, -1,  0,  1,  0, -1,  0,  0] [ 3,  6,  9] -1 */
    44762398, /* 75369 (1641) [-1,  0,  0,  0,  0, -1,  0,  1,  0] [ 3,  9,  6] -1 */
    52444534, /* 75370 (1641) [ 0,  0, -1,  0, -1,  0, -1,  0,  0] [ 6,  6,  0] -1 */
      893633, /* 75371 (1641) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 0,  3,  9]  1 */
    44657526, /* 75372 (1641) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 3,  9,  0] -1 */
    42695787, /* 75373 (1641) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 3,  0,  9] -1 */
    59588113, /* 75374 (1641) [ 0, -1,  0,  0,  0,  1, -1,  0,  0] [ 9,  0,  3] -1 */
    19194287, /* 75375 (1641) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  9,  3]  1 */
    60355490, /* 75376 (1641) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 9,  3,  6] -1 */
     1551758, /* 75377 (1641) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
     2314903, /* 75378 (1641) [ 0,  1,  0,  0,  0, -1, -1,  0,  0] [ 0,  9,  9]  1 */
     8688099, /* 75379 (1641) [ 0, -1,  0,  1,  0,  0,  0,  0, -1] [ 3,  0,  9]  1 */
    27111387, /* 75380 (1641) [ 0, -1,  0,  1,  0,  0,  0,  0, -1] [ 9,  6,  9]  1 */
    60240790, /* 75381 (1641) [ 0,  0,  1,  1,  0,  0,  0, -1,  0] [ 9,  3,  0] -1 */
    59714917, /* 75382 (1641) [ 1,  0,  0,  0,  0, -1,  0,  1,  0] [ 9,  0,  9] -1 */
    59589793, /* 75383 (1641) [ 0,  0, -1,  1,  0,  0,  0, -1,  0] [ 9,  0,  3] -1 */
    35554908, /* 75384 (1641) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 0,  6,  6] -1 */
    53212351, /* 75385 (1641) [ 0,  0, -1,  0,  1,  0,  1,  0,  0] [ 6,  9,  3] -1 */
    36200399, /* 75386 (1641) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  9,  3] -1 */
    61777300, /* 75387 (1641) [ 0,  1,  0,  0,  0,  1, -1,  0,  0] [ 9,  9,  6] -1 */
    17782951, /* 75388 (1641) [ 0,  0, -1,  0,  1,  0,  1,  0,  0] [ 6,  3,  3]  1 */
    44117499, /* 75389 (1641) [ 0, -1,  0,  1,  0,  0,  0,  0, -1] [ 3,  6,  9] -1 */
    17784229, /* 75390 (1641) [ 0,  0,  1,  0, -1,  0, -1,  0,  0] [ 6,  3,  3]  1 */
    10763400, /* 75391 (1641) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 3,  9,  6]  1 */
    52562476, /* 75392 (1641) [ 0,  0, -1, -1,  0,  0,  0, -1,  0] [ 6,  6,  6] -1 */
    34028656, /* 75393 (1641) [ 1,  0,  0,  0,  0,  1,  0,  1,  0] [ 0,  0,  0] -1 */
    19200283, /* 75394 (1641) [ 0,  0, -1,  1,  0,  0,  0,  1,  0] [ 6,  9,  3]  1 */
    27643804, /* 75395 (1641) [ 0,  0, -1, -1,  0,  0,  0,  1,  0] [ 9,  9,  0]  1 */
    18552046, /* 75396 (1641) [ 0,  0,  1,  0,  1,  0,  1,  0,  0] [ 6,  6,  6]  1 */
    42704437, /* 75397 (1641) [ 0,  1,  0,  0,  0, -1,  1,  0,  0] [ 3,  0,  9] -1 */
    60351334, /* 75398 (1641) [-1,  0,  0,  0,  0, -1,  0,  1,  0] [ 9,  3,  6] -1 */
    17022544, /* 75399 (1641) [ 1,  0,  0,  0,  0,  1,  0,  1,  0] [ 6,  0,  0]  1 */
     9219280, /* 75400 (1641) [ 0, -1,  0,  0,  0, -1,  1,  0,  0] [ 3,  3,  0]  1 */
    18426486, /* 75401 (1641) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
      783957, /* 75402 (1641) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  3,  3]  1 */
    26993065, /* 75403 (1641) [ 0, -1,  0,  0,  0,  1, -1,  0,  0] [ 9,  6,  3]  1 */
    25698325, /* 75404 (1641) [ 0,  1,  0,  0,  0, -1,  1,  0,  0] [ 9,  0,  9]  1 */
    19207245, /* 75405 (1641) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  9,  3]  1 */
    18550408, /* 75406 (1641) [ 0,  0, -1,  0, -1,  0, -1,  0,  0] [ 6,  6,  6]  1 */
      127120, /* 75407 (1641) [ 0,  0, -1,  0, -1,  0, -1,  0,  0] [ 0,  0,  6]  1 */
    52570094, /* 75408 (1641) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    43231280, /* 75409 (1641) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 3,  3,  0] -1 */
     9220516, /* 75410 (1641) [ 0,  0, -1, -1,  0,  0,  0,  1,  0] [ 3,  3,  0]  1 */
    51915855, /* 75411 (1641) [ 0,  1,  0, -1,  0,  0,  0,  0, -1] [ 6,  3,  9] -1 */
     1542892, /* 75412 (1641) [ 0, -1,  0,  0,  0, -1, -1,  0,  0] [ 0,  6,  6]  1 */
    34142386, /* 75413 (1641) [ 0,  1,  0,  0,  0,  1,  1,  0,  0] [ 0,  0,  6] -1 */
    52565674, /* 75414 (1641) [ 0,  1,  0,  0,  0,  1,  1,  0,  0] [ 6,  6,  6] -1 */
    34790341, /* 75415 (1641) [ 0,  0,  1,  0, -1,  0, -1,  0,  0] [ 0,  3,  3] -1 */
    27119869, /* 75416 (1641) [ 1,  0,  0,  0,  0, -1,  0,  1,  0] [ 9,  6,  9]  1 */
    27113989, /* 75417 (1641) [ 0,  0,  1,  0, -1,  0,  1,  0,  0] [ 9,  6,  9]  1 */
    36206395, /* 75418 (1641) [ 0,  0, -1,  1,  0,  0,  0,  1,  0] [ 0,  9,  3] -1 */
    51029152, /* 75419 (1641) [ 0,  0,  1,  1,  0,  0,  0,  1,  0] [ 6,  0,  0] -1 */
    36213357, /* 75420 (1641) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  9,  3] -1 */
    17790121, /* 75421 (1641) [ 1,  0,  0,  0,  0, -1,  0, -1,  0] [ 6,  3,  3]  1 */
    61000921, /* 75422 (1641) [-1,  0,  0,  0,  0,  1,  0, -1,  0] [ 9,  6,  3] -1 */
    61650412, /* 75423 (1641) [-1,  0,  0,  0,  0, -1,  0,  1,  0] [ 9,  9,  0] -1 */
    61659426, /* 75424 (1641) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 9,  9,  0] -1 */
    53328937, /* 75425 (1641) [ 0, -1,  0,  0,  0,  1,  1,  0,  0] [ 6,  9,  9] -1 */
     9991067, /* 75426 (1641) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 3,  6,  3]  1 */
    44125981, /* 75427 (1641) [ 1,  0,  0,  0,  0, -1,  0,  1,  0] [ 3,  6,  9] -1 */
    44120101, /* 75428 (1641) [ 0,  0,  1,  0, -1,  0,  1,  0,  0] [ 3,  6,  9] -1 */
     8569777, /* 75429 (1641) [ 0, -1,  0,  0,  0,  1, -1,  0,  0] [ 3,  0,  3]  1 */
    10100739, /* 75430 (1641) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 3,  6,  9]  1 */
    35438266, /* 75431 (1641) [ 0,  0, -1, -1,  0,  0,  0, -1,  0] [ 0,  6,  0] -1 */
    26352336, /* 75432 (1641) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 9,  3,  6]  1 */
    27645742, /* 75433 (1641) [ 0,  0,  1,  1,  0,  0,  0, -1,  0] [ 9,  9,  0]  1 */
    61006801, /* 75434 (1641) [ 0,  0, -1,  0,  1,  0, -1,  0,  0] [ 9,  6,  3] -1 */
     1427836, /* 75435 (1641) [ 0,  0,  1,  0,  1,  0,  1,  0,  0] [ 0,  6,  0]  1 */
    51143844, /* 75436 (1641) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 6,  0,  6] -1 */
    26346664, /* 75437 (1641) [ 0,  0,  1,  1,  0,  0,  0, -1,  0] [ 9,  3,  6]  1 */
    43227124, /* 75438 (1641) [-1,  0,  0,  0,  0, -1,  0,  1,  0] [ 3,  3,  0] -1 */
    34787759, /* 75439 (1641) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 0,  3,  3] -1 */
    17131828, /* 75440 (1641) [ 0, -1,  0,  0,  0, -1, -1,  0,  0] [ 6,  0,  6]  1 */
    61657798, /* 75441 (1641) [ 0,  0,  1,  0,  1,  0, -1,  0,  0] [ 9,  9,  0] -1 */
    34796233, /* 75442 (1641) [ 1,  0,  0,  0,  0, -1,  0, -1,  0] [ 0,  3,  3] -1 */
     1426198, /* 75443 (1641) [ 0,  0, -1,  0, -1,  0, -1,  0,  0] [ 0,  6,  0]  1 */
    35445884, /* 75444 (1641) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  6,  0] -1 */
    17781647, /* 75445 (1641) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 6,  3,  3]  1 */
    17009362, /* 75446 (1641) [-1,  0,  0,  0,  0, -1,  0, -1,  0] [ 6,  0,  0]  1 */
    19320807, /* 75447 (1641) [ 0,  1,  0, -1,  0,  0,  0,  0, -1] [ 6,  9,  9]  1 */
    34137940, /* 75448 (1641) [ 0, -1,  0,  0,  0, -1, -1,  0,  0] [ 0,  0,  6] -1 */
      894937, /* 75449 (1641) [ 0,  0, -1,  0,  1,  0,  1,  0,  0] [ 0,  3,  9]  1 */
     2195293, /* 75450 (1641) [ 0,  0,  1,  0, -1,  0, -1,  0,  0] [ 0,  9,  3]  1 */
    26994745, /* 75451 (1641) [ 0,  0, -1,  1,  0,  0,  0, -1,  0] [ 9,  6,  3]  1 */
      779629, /* 75452 (1641) [ 0,  1,  0,  0,  0, -1, -1,  0,  0] [ 0,  3,  3]  1 */
    35441464, /* 75453 (1641) [ 0,  1,  0,  0,  0,  1,  1,  0,  0] [ 0,  6,  0] -1 */
    19202917, /* 75454 (1641) [ 0,  1,  0,  0,  0, -1, -1,  0,  0] [ 6,  9,  3]  1 */
    25576113, /* 75455 (1641) [ 0, -1,  0,  1,  0,  0,  0,  0, -1] [ 9,  0,  3]  1 */
    43999177, /* 75456 (1641) [ 0, -1,  0,  0,  0,  1, -1,  0,  0] [ 3,  6,  3] -1 */
    25696645, /* 75457 (1641) [ 0,  0,  1, -1,  0,  0,  0,  1,  0] [ 9,  0,  9]  1 */
    44775568, /* 75458 (1641) [ 1,  0,  0,  0,  0,  1,  0, -1,  0] [ 3,  9,  6] -1 */
    10109389, /* 75459 (1641) [ 0,  1,  0,  0,  0, -1,  1,  0,  0] [ 3,  6,  9]  1 */
    35563930, /* 75460 (1641) [ 1,  0,  0,  0,  0,  1,  0,  1,  0] [ 0,  6,  6] -1 */
    27760442, /* 75461 (1641) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 9,  9,  6]  1 */
     8578427, /* 75462 (1641) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 3,  0,  3]  1 */
     8683507, /* 75463 (1641) [-1,  0,  0,  0,  0,  1,  0, -1,  0] [ 3,  0,  9]  1 */
    27106795, /* 75464 (1641) [-1,  0,  0,  0,  0,  1,  0, -1,  0] [ 9,  6,  9]  1 */
    36326919, /* 75465 (1641) [ 0,  1,  0, -1,  0,  0,  0,  0, -1] [ 0,  9,  9] -1 */
    27756286, /* 75466 (1641) [-1,  0,  0,  0,  0, -1,  0,  1,  0] [ 9,  9,  6]  1 */
    44000857, /* 75467 (1641) [ 0,  0, -1,  1,  0,  0,  0, -1,  0] [ 3,  6,  3] -1 */
    44653090, /* 75468 (1641) [ 0,  1,  0,  0,  0,  1, -1,  0,  0] [ 3,  9,  0] -1 */
    42582225, /* 75469 (1641) [ 0, -1,  0,  1,  0,  0,  0,  0, -1] [ 3,  0,  3] -1 */
     9337154, /* 75470 (1641) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 3,  3,  6]  1 */
    34022884, /* 75471 (1641) [ 0,  0,  1,  0,  1,  0,  1,  0,  0] [ 0,  0,  0] -1 */
    52446172, /* 75472 (1641) [ 0,  0,  1,  0,  1,  0,  1,  0,  0] [ 6,  6,  0] -1 */
     1544140, /* 75473 (1641) [ 0,  0, -1, -1,  0,  0,  0, -1,  0] [ 0,  6,  6]  1 */
     9228126, /* 75474 (1641) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 3,  3,  0]  1 */
    51027202, /* 75475 (1641) [ 0,  0, -1, -1,  0,  0,  0, -1,  0] [ 6,  0,  0] -1 */
    18553658, /* 75476 (1641) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    59710325, /* 75477 (1641) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 9,  0,  9] -1 */
       10816, /* 75478 (1641) [ 0,  0,  1,  1,  0,  0,  0,  1,  0] [ 0,  0,  0]  1 */
    18434104, /* 75479 (1641) [ 0,  0,  1,  1,  0,  0,  0,  1,  0] [ 6,  6,  0]  1 */
    42702757, /* 75480 (1641) [ 0,  0,  1, -1,  0,  0,  0,  1,  0] [ 3,  0,  9] -1 */
    61132037, /* 75481 (1641) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 9,  6,  9] -1 */
    53331571, /* 75482 (1641) [ 0,  0,  1, -1,  0,  0,  0, -1,  0] [ 6,  9,  9] -1 */
    17016772, /* 75483 (1641) [ 0,  0,  1,  0,  1,  0,  1,  0,  0] [ 6,  0,  0]  1 */
     2201185, /* 75484 (1641) [ 1,  0,  0,  0,  0, -1,  0, -1,  0] [ 0,  9,  3]  1 */
     9222454, /* 75485 (1641) [ 0,  0,  1,  1,  0,  0,  0, -1,  0] [ 3,  3,  0]  1 */
    59592451, /* 75486 (1641) [ 0,  1,  0,  0,  0, -1,  1,  0,  0] [ 9,  0,  3] -1 */
    27763672, /* 75487 (1641) [ 0,  0,  1,  0,  1,  0, -1,  0,  0] [ 9,  9,  6]  1 */
    17902171, /* 75488 (1641) [ 0,  0,  1, -1,  0,  0,  0, -1,  0] [ 6,  3,  9]  1 */
    17015134, /* 75489 (1641) [ 0,  0, -1,  0, -1,  0, -1,  0,  0] [ 6,  0,  0]  1 */
    51152866, /* 75490 (1641) [ 1,  0,  0,  0,  0,  1,  0,  1,  0] [ 6,  0,  6] -1 */
    51030400, /* 75491 (1641) [ 0,  1,  0,  0,  0,  1,  1,  0,  0] [ 6,  0,  0] -1 */
    60364504, /* 75492 (1641) [ 1,  0,  0,  0,  0,  1,  0, -1,  0] [ 9,  3,  6] -1 */
    51907381, /* 75493 (1641) [-1,  0,  0,  0,  0,  1,  0,  1,  0] [ 6,  3,  9] -1 */
    61768454, /* 75494 (1641) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 9,  9,  6] -1 */
    60242026, /* 75495 (1641) [ 0,  1,  0,  0,  0,  1, -1,  0,  0] [ 9,  3,  0] -1 */
    34908283, /* 75496 (1641) [ 0,  0,  1, -1,  0,  0,  0, -1,  0] [ 0,  3,  9] -1 */
    34021246, /* 75497 (1641) [ 0,  0, -1,  0, -1,  0, -1,  0,  0] [ 0,  0,  0] -1 */
    17133076, /* 75498 (1641) [ 0,  0, -1, -1,  0,  0,  0, -1,  0] [ 6,  0,  6]  1 */
    35550748, /* 75499 (1641) [-1,  0,  0,  0,  0, -1,  0, -1,  0] [ 0,  6,  6] -1 */
      770999, /* 75500 (1641) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  3,  3]  1 */
     8689387, /* 75501 (1641) [ 0,  0, -1,  0,  1,  0, -1,  0,  0] [ 3,  0,  9]  1 */
    34139188, /* 75502 (1641) [ 0,  0, -1, -1,  0,  0,  0, -1,  0] [ 0,  0,  6] -1 */
    10106731, /* 75503 (1641) [ 0,  0, -1,  1,  0,  0,  0, -1,  0] [ 3,  6,  9]  1 */
    10636232, /* 75504 (1641) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 3,  9,  0]  1 */
    35437018, /* 75505 (1641) [ 0, -1,  0,  0,  0, -1, -1,  0,  0] [ 0,  6,  0] -1 */
      128758, /* 75506 (1641) [ 0,  0,  1,  0,  1,  0,  1,  0,  0] [ 0,  0,  6]  1 */
    42584827, /* 75507 (1641) [ 0,  0,  1,  0, -1,  0,  1,  0,  0] [ 3,  0,  3] -1 */
    61013995, /* 75508 (1641) [ 1,  0,  0,  0,  0, -1,  0,  1,  0] [ 9,  6,  3] -1 */
    61008115, /* 75509 (1641) [ 0,  0,  1,  0, -1,  0,  1,  0,  0] [ 9,  6,  3] -1 */
     1429448, /* 75510 (1641) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 0,  6,  0]  1 */
    26988753, /* 75511 (1641) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 9,  6,  3]  1 */
     1547338, /* 75512 (1641) [ 0,  1,  0,  0,  0,  1,  1,  0,  0] [ 0,  6,  6]  1 */
    10632076, /* 75513 (1641) [-1,  0,  0,  0,  0, -1,  0,  1,  0] [ 3,  9,  0]  1 */
    25578715, /* 75514 (1641) [ 0,  0,  1,  0, -1,  0,  1,  0,  0] [ 9,  0,  3]  1 */
    10641090, /* 75515 (1641) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 3,  9,  0]  1 */
    34789063, /* 75516 (1641) [ 0,  0, -1,  0,  1,  0,  1,  0,  0] [ 0,  3,  3] -1 */
     9988465, /* 75517 (1641) [ 0,  0, -1,  0,  1,  0, -1,  0,  0] [ 3,  6,  3]  1 */
    43349602, /* 75518 (1641) [ 0, -1,  0,  0,  0, -1,  1,  0,  0] [ 3,  3,  6] -1 */
    10639462, /* 75519 (1641) [ 0,  0,  1,  0,  1,  0, -1,  0,  0] [ 3,  9,  0]  1 */
     2192711, /* 75520 (1641) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 0,  9,  3]  1 */
    44768182, /* 75521 (1641) [ 0,  0, -1,  0, -1,  0,  1,  0,  0] [ 3,  9,  6] -1 */
    43994865, /* 75522 (1641) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 3,  6,  3] -1 */
    61123387, /* 75523 (1641) [ 0, -1,  0,  0,  0,  1, -1,  0,  0] [ 9,  6,  9] -1 */
    51139684, /* 75524 (1641) [-1,  0,  0,  0,  0, -1,  0, -1,  0] [ 6,  0,  6] -1 */
    19312333, /* 75525 (1641) [-1,  0,  0,  0,  0,  1,  0,  1,  0] [ 6,  9,  9]  1 */
      776995, /* 75526 (1641) [ 0,  0, -1,  1,  0,  0,  0,  1,  0] [ 0,  3,  3]  1 */
    60246462, /* 75527 (1641) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 9,  3,  0] -1 */
    44003515, /* 75528 (1641) [ 0,  1,  0,  0,  0, -1,  1,  0,  0] [ 3,  6,  3] -1 */
    61654568, /* 75529 (1641) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 9,  9,  0] -1 */
    27646978, /* 75530 (1641) [ 0,  1,  0,  0,  0,  1, -1,  0,  0] [ 9,  9,  0]  1 */
       16484, /* 75531 (1642) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
       10660, /* 75532 (1642) [ 0,  0,  1,  0,  1,  0,  1,  0,  0] [ 0,  0,  0]  1 */
        9022, /* 75533 (1642) [ 0,  0, -1,  0, -1,  0, -1,  0,  0] [ 0,  0,  0]  1 */
       16320, /* 75534 (1642) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
        3198, /* 75535 (1642) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
       16432, /* 75536 (1642) [ 1,  0,  0,  0,  0,  1,  0,  1,  0] [ 0,  0,  0]  1 */
        3256, /* 75537 (1642) [-1,  0,  0,  0,  0, -1,  0,  1,  0] [ 0,  0,  0]  1 */
    18550570, /* 75538 (1642) [ 0,  0, -1,  0,  1,  0, -1,  0,  0] [ 6,  6,  6]  1 */
    18548796, /* 75539 (1642) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 6,  6,  6]  1 */
        9184, /* 75540 (1642) [ 0,  0, -1,  0,  1,  0, -1,  0,  0] [ 0,  0,  0]  1 */
        7410, /* 75541 (1642) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  0]  1 */
        9352, /* 75542 (1642) [ 0,  0, -1,  1,  0,  0,  0, -1,  0] [ 0,  0,  0]  1 */
    18544746, /* 75543 (1642) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
    18557870, /* 75544 (1642) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
        8872, /* 75545 (1642) [ 0,  0, -1, -1,  0,  0,  0,  1,  0] [ 0,  0,  0]  1 */
       16372, /* 75546 (1642) [ 1,  0,  0,  0,  0, -1,  0, -1,  0] [ 0,  0,  0]  1 */
    18544696, /* 75547 (1642) [-1,  0,  0,  0,  0,  1,  0,  1,  0] [ 6,  6,  6]  1 */
        3250, /* 75548 (1642) [-1,  0,  0,  0,  0, -1,  0, -1,  0] [ 0,  0,  0]  1 */
    18549058, /* 75549 (1642) [ 0, -1,  0,  0,  0,  1, -1,  0,  0] [ 6,  6,  6]  1 */
    18550588, /* 75550 (1642) [ 0,  0, -1,  0,  1,  0,  1,  0,  0] [ 6,  6,  6]  1 */
        9202, /* 75551 (1642) [ 0,  0, -1,  0,  1,  0,  1,  0,  0] [ 0,  0,  0]  1 */
    18553378, /* 75552 (1642) [ 0,  1,  0,  0,  0, -1, -1,  0,  0] [ 6,  6,  6]  1 */
    18552202, /* 75553 (1642) [ 0,  0,  1,  1,  0,  0,  0,  1,  0] [ 6,  6,  6]  1 */
        3304, /* 75554 (1642) [-1,  0,  0,  0,  0,  1,  0, -1,  0] [ 0,  0,  0]  1 */
       10324, /* 75555 (1642) [ 0,  0,  1, -1,  0,  0,  0, -1,  0] [ 0,  0,  0]  1 */
    18550252, /* 75556 (1642) [ 0,  0, -1, -1,  0,  0,  0, -1,  0] [ 6,  6,  6]  1 */
        8866, /* 75557 (1642) [ 0,  0, -1, -1,  0,  0,  0, -1,  0] [ 0,  0,  0]  1 */
    18550426, /* 75558 (1642) [ 0,  0, -1,  0, -1,  0,  1,  0,  0] [ 6,  6,  6]  1 */
    18553170, /* 75559 (1642) [ 0,  1,  0, -1,  0,  0,  0,  0, -1] [ 6,  6,  6]  1 */
    18550744, /* 75560 (1642) [ 0,  0, -1,  1,  0,  0,  0,  1,  0] [ 6,  6,  6]  1 */
        7896, /* 75561 (1642) [ 0, -1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    18553396, /* 75562 (1642) [ 0,  1,  0,  0,  0, -1,  1,  0,  0] [ 6,  6,  6]  1 */
    18549284, /* 75563 (1642) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 6,  6,  6]  1 */
       11786, /* 75564 (1642) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    18557708, /* 75565 (1642) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
        7898, /* 75566 (1642) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    18544748, /* 75567 (1642) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    18553658, /* 75568 (1642) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 6,  6,  6]  1 */
        3310, /* 75569 (1642) [-1,  0,  0,  0,  0,  1,  0,  1,  0] [ 0,  0,  0]  1 */
       10816, /* 75570 (1642) [ 0,  0,  1,  1,  0,  0,  0,  1,  0] [ 0,  0,  0]  1 */
    18553450, /* 75571 (1642) [ 0,  1,  0,  0,  0,  1,  1,  0,  0] [ 6,  6,  6]  1 */
       11992, /* 75572 (1642) [ 0,  1,  0,  0,  0, -1, -1,  0,  0] [ 0,  0,  0]  1 */
       12064, /* 75573 (1642) [ 0,  1,  0,  0,  0,  1,  1,  0,  0] [ 0,  0,  0]  1 */
    18557818, /* 75574 (1642) [ 1,  0,  0,  0,  0,  1,  0,  1,  0] [ 6,  6,  6]  1 */
    18548798, /* 75575 (1642) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    18557868, /* 75576 (1642) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
    18544642, /* 75577 (1642) [-1,  0,  0,  0,  0, -1,  0,  1,  0] [ 6,  6,  6]  1 */
    18553656, /* 75578 (1642) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 6,  6,  6]  1 */
       12270, /* 75579 (1642) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    18552196, /* 75580 (1642) [ 0,  0,  1,  1,  0,  0,  0, -1,  0] [ 6,  6,  6]  1 */
       10498, /* 75581 (1642) [ 0,  0,  1,  0, -1,  0,  1,  0,  0] [ 0,  0,  0]  1 */
        9040, /* 75582 (1642) [ 0,  0, -1,  0, -1,  0,  1,  0,  0] [ 0,  0,  0]  1 */
    18549076, /* 75583 (1642) [ 0, -1,  0,  0,  0,  1,  1,  0,  0] [ 6,  6,  6]  1 */
    18550738, /* 75584 (1642) [ 0,  0, -1,  1,  0,  0,  0, -1,  0] [ 6,  6,  6]  1 */
    18552028, /* 75585 (1642) [ 0,  0,  1,  0,  1,  0, -1,  0,  0] [ 6,  6,  6]  1 */
       11784, /* 75586 (1642) [ 0,  1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    18553172, /* 75587 (1642) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    18557812, /* 75588 (1642) [ 1,  0,  0,  0,  0,  1,  0, -1,  0] [ 6,  6,  6]  1 */
    18551866, /* 75589 (1642) [ 0,  0,  1,  0, -1,  0, -1,  0,  0] [ 6,  6,  6]  1 */
        7672, /* 75590 (1642) [ 0, -1,  0,  0,  0,  1, -1,  0,  0] [ 0,  0,  0]  1 */
       10330, /* 75591 (1642) [ 0,  0,  1, -1,  0,  0,  0,  1,  0] [ 0,  0,  0]  1 */
    18553432, /* 75592 (1642) [ 0,  1,  0,  0,  0,  1, -1,  0,  0] [ 6,  6,  6]  1 */
        3360, /* 75593 (1642) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
       12010, /* 75594 (1642) [ 0,  1,  0,  0,  0, -1,  1,  0,  0] [ 0,  0,  0]  1 */
       12046, /* 75595 (1642) [ 0,  1,  0,  0,  0,  1, -1,  0,  0] [ 0,  0,  0]  1 */
        3362, /* 75596 (1642) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
       12272, /* 75597 (1642) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 0,  0,  0]  1 */
        7412, /* 75598 (1642) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    18544586, /* 75599 (1642) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    18549004, /* 75600 (1642) [ 0, -1,  0,  0,  0, -1, -1,  0,  0] [ 6,  6,  6]  1 */
        7618, /* 75601 (1642) [ 0, -1,  0,  0,  0, -1, -1,  0,  0] [ 0,  0,  0]  1 */
    18552046, /* 75602 (1642) [ 0,  0,  1,  0,  1,  0,  1,  0,  0] [ 6,  6,  6]  1 */
    18557706, /* 75603 (1642) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
    18557764, /* 75604 (1642) [ 1,  0,  0,  0,  0, -1,  0,  1,  0] [ 6,  6,  6]  1 */
    18544584, /* 75605 (1642) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
    18551884, /* 75606 (1642) [ 0,  0,  1,  0, -1,  0,  1,  0,  0] [ 6,  6,  6]  1 */
       16378, /* 75607 (1642) [ 1,  0,  0,  0,  0, -1,  0,  1,  0] [ 0,  0,  0]  1 */
    18550408, /* 75608 (1642) [ 0,  0, -1,  0, -1,  0, -1,  0,  0] [ 6,  6,  6]  1 */
        7690, /* 75609 (1642) [ 0, -1,  0,  0,  0,  1,  1,  0,  0] [ 0,  0,  0]  1 */
       10810, /* 75610 (1642) [ 0,  0,  1,  1,  0,  0,  0, -1,  0] [ 0,  0,  0]  1 */
    18549022, /* 75611 (1642) [ 0, -1,  0,  0,  0, -1,  1,  0,  0] [ 6,  6,  6]  1 */
    18549282, /* 75612 (1642) [ 0, -1,  0,  1,  0,  0,  0,  0, -1] [ 6,  6,  6]  1 */
        7636, /* 75613 (1642) [ 0, -1,  0,  0,  0, -1,  1,  0,  0] [ 0,  0,  0]  1 */
    18557758, /* 75614 (1642) [ 1,  0,  0,  0,  0, -1,  0, -1,  0] [ 6,  6,  6]  1 */
       10480, /* 75615 (1642) [ 0,  0,  1,  0, -1,  0, -1,  0,  0] [ 0,  0,  0]  1 */
    18551716, /* 75616 (1642) [ 0,  0,  1, -1,  0,  0,  0,  1,  0] [ 6,  6,  6]  1 */
    18544636, /* 75617 (1642) [-1,  0,  0,  0,  0, -1,  0, -1,  0] [ 6,  6,  6]  1 */
       10642, /* 75618 (1642) [ 0,  0,  1,  0,  1,  0, -1,  0,  0] [ 0,  0,  0]  1 */
    18550258, /* 75619 (1642) [ 0,  0, -1, -1,  0,  0,  0,  1,  0] [ 6,  6,  6]  1 */
       16426, /* 75620 (1642) [ 1,  0,  0,  0,  0,  1,  0, -1,  0] [ 0,  0,  0]  1 */
       16322, /* 75621 (1642) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
        3200, /* 75622 (1642) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
        9358, /* 75623 (1642) [ 0,  0, -1,  1,  0,  0,  0,  1,  0] [ 0,  0,  0]  1 */
    18544690, /* 75624 (1642) [-1,  0,  0,  0,  0,  1,  0, -1,  0] [ 6,  6,  6]  1 */
    18551710, /* 75625 (1642) [ 0,  0,  1, -1,  0,  0,  0, -1,  0] [ 6,  6,  6]  1 */
       16482, /* 75626 (1642) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
       16484, /* 75627 (1643) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    52562962, /* 75628 (1643) [ 0,  0, -1,  1,  0,  0,  0, -1,  0] [ 6,  6,  6] -1 */
       10660, /* 75629 (1643) [ 0,  0,  1,  0,  1,  0,  1,  0,  0] [ 0,  0,  0]  1 */
        9022, /* 75630 (1643) [ 0,  0, -1,  0, -1,  0, -1,  0,  0] [ 0,  0,  0]  1 */
       16320, /* 75631 (1643) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
        3198, /* 75632 (1643) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
       16432, /* 75633 (1643) [ 1,  0,  0,  0,  0,  1,  0,  1,  0] [ 0,  0,  0]  1 */
    52565394, /* 75634 (1643) [ 0,  1,  0, -1,  0,  0,  0,  0, -1] [ 6,  6,  6] -1 */
        3256, /* 75635 (1643) [-1,  0,  0,  0,  0, -1,  0,  1,  0] [ 0,  0,  0]  1 */
    52562968, /* 75636 (1643) [ 0,  0, -1,  1,  0,  0,  0,  1,  0] [ 6,  6,  6] -1 */
    34020120, /* 75637 (1643) [ 0, -1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    18550570, /* 75638 (1643) [ 0,  0, -1,  0,  1,  0, -1,  0,  0] [ 6,  6,  6]  1 */
    34019896, /* 75639 (1643) [ 0, -1,  0,  0,  0,  1, -1,  0,  0] [ 0,  0,  0] -1 */
    18548796, /* 75640 (1643) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 6,  6,  6]  1 */
    52565620, /* 75641 (1643) [ 0,  1,  0,  0,  0, -1,  1,  0,  0] [ 6,  6,  6] -1 */
        9184, /* 75642 (1643) [ 0,  0, -1,  0,  1,  0, -1,  0,  0] [ 0,  0,  0]  1 */
    34015584, /* 75643 (1643) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    52565656, /* 75644 (1643) [ 0,  1,  0,  0,  0,  1, -1,  0,  0] [ 6,  6,  6] -1 */
        7410, /* 75645 (1643) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    34024234, /* 75646 (1643) [ 0,  1,  0,  0,  0, -1,  1,  0,  0] [ 0,  0,  0] -1 */
    34020122, /* 75647 (1643) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 0,  0,  0] -1 */
        9352, /* 75648 (1643) [ 0,  0, -1,  1,  0,  0,  0, -1,  0] [ 0,  0,  0]  1 */
    52556972, /* 75649 (1643) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    52565882, /* 75650 (1643) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    18544746, /* 75651 (1643) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
    34024496, /* 75652 (1643) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    34023040, /* 75653 (1643) [ 0,  0,  1,  1,  0,  0,  0,  1,  0] [ 0,  0,  0] -1 */
    18557870, /* 75654 (1643) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    52556810, /* 75655 (1643) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
        8872, /* 75656 (1643) [ 0,  0, -1, -1,  0,  0,  0,  1,  0] [ 0,  0,  0]  1 */
    52561228, /* 75657 (1643) [ 0, -1,  0,  0,  0, -1, -1,  0,  0] [ 6,  6,  6] -1 */
    34024288, /* 75658 (1643) [ 0,  1,  0,  0,  0,  1,  1,  0,  0] [ 0,  0,  0] -1 */
    52570042, /* 75659 (1643) [ 1,  0,  0,  0,  0,  1,  0,  1,  0] [ 6,  6,  6] -1 */
       16372, /* 75660 (1643) [ 1,  0,  0,  0,  0, -1,  0, -1,  0] [ 0,  0,  0]  1 */
    18544696, /* 75661 (1643) [-1,  0,  0,  0,  0,  1,  0,  1,  0] [ 6,  6,  6]  1 */
    52561022, /* 75662 (1643) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    52569988, /* 75663 (1643) [ 1,  0,  0,  0,  0, -1,  0,  1,  0] [ 6,  6,  6] -1 */
        3250, /* 75664 (1643) [-1,  0,  0,  0,  0, -1,  0, -1,  0] [ 0,  0,  0]  1 */
    18549058, /* 75665 (1643) [ 0, -1,  0,  0,  0,  1, -1,  0,  0] [ 6,  6,  6]  1 */
    18550588, /* 75666 (1643) [ 0,  0, -1,  0,  1,  0,  1,  0,  0] [ 6,  6,  6]  1 */
    52570092, /* 75667 (1643) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    52556866, /* 75668 (1643) [-1,  0,  0,  0,  0, -1,  0,  1,  0] [ 6,  6,  6] -1 */
        9202, /* 75669 (1643) [ 0,  0, -1,  0,  1,  0,  1,  0,  0] [ 0,  0,  0]  1 */
    18553378, /* 75670 (1643) [ 0,  1,  0,  0,  0, -1, -1,  0,  0] [ 6,  6,  6]  1 */
    52562632, /* 75671 (1643) [ 0,  0, -1,  0, -1,  0, -1,  0,  0] [ 6,  6,  6] -1 */
    34024494, /* 75672 (1643) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    52564420, /* 75673 (1643) [ 0,  0,  1,  1,  0,  0,  0, -1,  0] [ 6,  6,  6] -1 */
    18552202, /* 75674 (1643) [ 0,  0,  1,  1,  0,  0,  0,  1,  0] [ 6,  6,  6]  1 */
    34023034, /* 75675 (1643) [ 0,  0,  1,  1,  0,  0,  0, -1,  0] [ 0,  0,  0] -1 */
        3304, /* 75676 (1643) [-1,  0,  0,  0,  0,  1,  0, -1,  0] [ 0,  0,  0]  1 */
    34021264, /* 75677 (1643) [ 0,  0, -1,  0, -1,  0,  1,  0,  0] [ 0,  0,  0] -1 */
    52561246, /* 75678 (1643) [ 0, -1,  0,  0,  0, -1,  1,  0,  0] [ 6,  6,  6] -1 */
       10324, /* 75679 (1643) [ 0,  0,  1, -1,  0,  0,  0, -1,  0] [ 0,  0,  0]  1 */
    18550252, /* 75680 (1643) [ 0,  0, -1, -1,  0,  0,  0, -1,  0] [ 6,  6,  6]  1 */
    52564252, /* 75681 (1643) [ 0,  0,  1,  0,  1,  0, -1,  0,  0] [ 6,  6,  6] -1 */
        8866, /* 75682 (1643) [ 0,  0, -1, -1,  0,  0,  0, -1,  0] [ 0,  0,  0]  1 */
    34024008, /* 75683 (1643) [ 0,  1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    34022866, /* 75684 (1643) [ 0,  0,  1,  0,  1,  0, -1,  0,  0] [ 0,  0,  0] -1 */
    52565396, /* 75685 (1643) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    52562482, /* 75686 (1643) [ 0,  0, -1, -1,  0,  0,  0,  1,  0] [ 6,  6,  6] -1 */
    52570036, /* 75687 (1643) [ 1,  0,  0,  0,  0,  1,  0, -1,  0] [ 6,  6,  6] -1 */
    52564090, /* 75688 (1643) [ 0,  0,  1,  0, -1,  0, -1,  0,  0] [ 6,  6,  6] -1 */
    18550426, /* 75689 (1643) [ 0,  0, -1,  0, -1,  0,  1,  0,  0] [ 6,  6,  6]  1 */
    34022554, /* 75690 (1643) [ 0,  0,  1, -1,  0,  0,  0,  1,  0] [ 0,  0,  0] -1 */
    34028650, /* 75691 (1643) [ 1,  0,  0,  0,  0,  1,  0, -1,  0] [ 0,  0,  0] -1 */
    34024270, /* 75692 (1643) [ 0,  1,  0,  0,  0,  1, -1,  0,  0] [ 0,  0,  0] -1 */
    34015424, /* 75693 (1643) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    34028708, /* 75694 (1643) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    34021582, /* 75695 (1643) [ 0,  0, -1,  1,  0,  0,  0,  1,  0] [ 0,  0,  0] -1 */
    18553170, /* 75696 (1643) [ 0,  1,  0, -1,  0,  0,  0,  0, -1] [ 6,  6,  6]  1 */
    34015586, /* 75697 (1643) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    34019636, /* 75698 (1643) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    18550744, /* 75699 (1643) [ 0,  0, -1,  1,  0,  0,  0,  1,  0] [ 6,  6,  6]  1 */
        7896, /* 75700 (1643) [ 0, -1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    34028706, /* 75701 (1643) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    18553396, /* 75702 (1643) [ 0,  1,  0,  0,  0, -1,  1,  0,  0] [ 6,  6,  6]  1 */
    34019842, /* 75703 (1643) [ 0, -1,  0,  0,  0, -1, -1,  0,  0] [ 0,  0,  0] -1 */
    52564270, /* 75704 (1643) [ 0,  0,  1,  0,  1,  0,  1,  0,  0] [ 6,  6,  6] -1 */
    18549284, /* 75705 (1643) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 6,  6,  6]  1 */
       11786, /* 75706 (1643) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34022884, /* 75707 (1643) [ 0,  0,  1,  0,  1,  0,  1,  0,  0] [ 0,  0,  0] -1 */
    52569930, /* 75708 (1643) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    18557708, /* 75709 (1643) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
        7898, /* 75710 (1643) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    18544748, /* 75711 (1643) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    34028544, /* 75712 (1643) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    18553658, /* 75713 (1643) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    52556808, /* 75714 (1643) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
        3310, /* 75715 (1643) [-1,  0,  0,  0,  0,  1,  0,  1,  0] [ 0,  0,  0]  1 */
    52564108, /* 75716 (1643) [ 0,  0,  1,  0, -1,  0,  1,  0,  0] [ 6,  6,  6] -1 */
    34028602, /* 75717 (1643) [ 1,  0,  0,  0,  0, -1,  0,  1,  0] [ 0,  0,  0] -1 */
       10816, /* 75718 (1643) [ 0,  0,  1,  1,  0,  0,  0,  1,  0] [ 0,  0,  0]  1 */
    34015422, /* 75719 (1643) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    18553450, /* 75720 (1643) [ 0,  1,  0,  0,  0,  1,  1,  0,  0] [ 6,  6,  6]  1 */
       11992, /* 75721 (1643) [ 0,  1,  0,  0,  0, -1, -1,  0,  0] [ 0,  0,  0]  1 */
       12064, /* 75722 (1643) [ 0,  1,  0,  0,  0,  1,  1,  0,  0] [ 0,  0,  0]  1 */
    18557818, /* 75723 (1643) [ 1,  0,  0,  0,  0,  1,  0,  1,  0] [ 6,  6,  6]  1 */
    52562794, /* 75724 (1643) [ 0,  0, -1,  0,  1,  0, -1,  0,  0] [ 6,  6,  6] -1 */
    34019914, /* 75725 (1643) [ 0, -1,  0,  0,  0,  1,  1,  0,  0] [ 0,  0,  0] -1 */
    52561020, /* 75726 (1643) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    18548798, /* 75727 (1643) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    18557868, /* 75728 (1643) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
    18544642, /* 75729 (1643) [-1,  0,  0,  0,  0, -1,  0,  1,  0] [ 6,  6,  6]  1 */
    52561506, /* 75730 (1643) [ 0, -1,  0,  1,  0,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    34019860, /* 75731 (1643) [ 0, -1,  0,  0,  0, -1,  1,  0,  0] [ 0,  0,  0] -1 */
    18553656, /* 75732 (1643) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 6,  6,  6]  1 */
       12270, /* 75733 (1643) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    18552196, /* 75734 (1643) [ 0,  0,  1,  1,  0,  0,  0, -1,  0] [ 6,  6,  6]  1 */
       10498, /* 75735 (1643) [ 0,  0,  1,  0, -1,  0,  1,  0,  0] [ 0,  0,  0]  1 */
    52569982, /* 75736 (1643) [ 1,  0,  0,  0,  0, -1,  0, -1,  0] [ 6,  6,  6] -1 */
    34022704, /* 75737 (1643) [ 0,  0,  1,  0, -1,  0, -1,  0,  0] [ 0,  0,  0] -1 */
        9040, /* 75738 (1643) [ 0,  0, -1,  0, -1,  0,  1,  0,  0] [ 0,  0,  0]  1 */
    52563940, /* 75739 (1643) [ 0,  0,  1, -1,  0,  0,  0,  1,  0] [ 6,  6,  6] -1 */
    52556860, /* 75740 (1643) [-1,  0,  0,  0,  0, -1,  0, -1,  0] [ 6,  6,  6] -1 */
    18549076, /* 75741 (1643) [ 0, -1,  0,  0,  0,  1,  1,  0,  0] [ 6,  6,  6]  1 */
    34015474, /* 75742 (1643) [-1,  0,  0,  0,  0, -1,  0, -1,  0] [ 0,  0,  0] -1 */
    52562812, /* 75743 (1643) [ 0,  0, -1,  0,  1,  0,  1,  0,  0] [ 6,  6,  6] -1 */
    18550738, /* 75744 (1643) [ 0,  0, -1,  1,  0,  0,  0, -1,  0] [ 6,  6,  6]  1 */
    34028546, /* 75745 (1643) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    52556914, /* 75746 (1643) [-1,  0,  0,  0,  0,  1,  0, -1,  0] [ 6,  6,  6] -1 */
    18552028, /* 75747 (1643) [ 0,  0,  1,  0,  1,  0, -1,  0,  0] [ 6,  6,  6]  1 */
    34015528, /* 75748 (1643) [-1,  0,  0,  0,  0,  1,  0, -1,  0] [ 0,  0,  0] -1 */
       11784, /* 75749 (1643) [ 0,  1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    18553172, /* 75750 (1643) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    52563934, /* 75751 (1643) [ 0,  0,  1, -1,  0,  0,  0, -1,  0] [ 6,  6,  6] -1 */
    34022548, /* 75752 (1643) [ 0,  0,  1, -1,  0,  0,  0, -1,  0] [ 0,  0,  0] -1 */
    18557812, /* 75753 (1643) [ 1,  0,  0,  0,  0,  1,  0, -1,  0] [ 6,  6,  6]  1 */
    18551866, /* 75754 (1643) [ 0,  0,  1,  0, -1,  0, -1,  0,  0] [ 6,  6,  6]  1 */
        7672, /* 75755 (1643) [ 0, -1,  0,  0,  0,  1, -1,  0,  0] [ 0,  0,  0]  1 */
    34022722, /* 75756 (1643) [ 0,  0,  1,  0, -1,  0,  1,  0,  0] [ 0,  0,  0] -1 */
       10330, /* 75757 (1643) [ 0,  0,  1, -1,  0,  0,  0,  1,  0] [ 0,  0,  0]  1 */
    18553432, /* 75758 (1643) [ 0,  1,  0,  0,  0,  1, -1,  0,  0] [ 6,  6,  6]  1 */
        3360, /* 75759 (1643) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
       12010, /* 75760 (1643) [ 0,  1,  0,  0,  0, -1,  1,  0,  0] [ 0,  0,  0]  1 */
       12046, /* 75761 (1643) [ 0,  1,  0,  0,  0,  1, -1,  0,  0] [ 0,  0,  0]  1 */
    34021246, /* 75762 (1643) [ 0,  0, -1,  0, -1,  0, -1,  0,  0] [ 0,  0,  0] -1 */
        3362, /* 75763 (1643) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
       12272, /* 75764 (1643) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    52562476, /* 75765 (1643) [ 0,  0, -1, -1,  0,  0,  0, -1,  0] [ 6,  6,  6] -1 */
    52561300, /* 75766 (1643) [ 0, -1,  0,  0,  0,  1,  1,  0,  0] [ 6,  6,  6] -1 */
    34028656, /* 75767 (1643) [ 1,  0,  0,  0,  0,  1,  0,  1,  0] [ 0,  0,  0] -1 */
        7412, /* 75768 (1643) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    18544586, /* 75769 (1643) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    18549004, /* 75770 (1643) [ 0, -1,  0,  0,  0, -1, -1,  0,  0] [ 6,  6,  6]  1 */
        7618, /* 75771 (1643) [ 0, -1,  0,  0,  0, -1, -1,  0,  0] [ 0,  0,  0]  1 */
    18552046, /* 75772 (1643) [ 0,  0,  1,  0,  1,  0,  1,  0,  0] [ 6,  6,  6]  1 */
    34015480, /* 75773 (1643) [-1,  0,  0,  0,  0, -1,  0,  1,  0] [ 0,  0,  0] -1 */
    18557706, /* 75774 (1643) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
    52562650, /* 75775 (1643) [ 0,  0, -1,  0, -1,  0,  1,  0,  0] [ 6,  6,  6] -1 */
    34021408, /* 75776 (1643) [ 0,  0, -1,  0,  1,  0, -1,  0,  0] [ 0,  0,  0] -1 */
    18557764, /* 75777 (1643) [ 1,  0,  0,  0,  0, -1,  0,  1,  0] [ 6,  6,  6]  1 */
    18544584, /* 75778 (1643) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
    34019634, /* 75779 (1643) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    18551884, /* 75780 (1643) [ 0,  0,  1,  0, -1,  0,  1,  0,  0] [ 6,  6,  6]  1 */
       16378, /* 75781 (1643) [ 1,  0,  0,  0,  0, -1,  0,  1,  0] [ 0,  0,  0]  1 */
    34021576, /* 75782 (1643) [ 0,  0, -1,  1,  0,  0,  0, -1,  0] [ 0,  0,  0] -1 */
    52556970, /* 75783 (1643) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    18550408, /* 75784 (1643) [ 0,  0, -1,  0, -1,  0, -1,  0,  0] [ 6,  6,  6]  1 */
    52570094, /* 75785 (1643) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
        7690, /* 75786 (1643) [ 0, -1,  0,  0,  0,  1,  1,  0,  0] [ 0,  0,  0]  1 */
    34021096, /* 75787 (1643) [ 0,  0, -1, -1,  0,  0,  0,  1,  0] [ 0,  0,  0] -1 */
       10810, /* 75788 (1643) [ 0,  0,  1,  1,  0,  0,  0, -1,  0] [ 0,  0,  0]  1 */
    52561508, /* 75789 (1643) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    34024010, /* 75790 (1643) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    18549022, /* 75791 (1643) [ 0, -1,  0,  0,  0, -1,  1,  0,  0] [ 6,  6,  6]  1 */
    34028596, /* 75792 (1643) [ 1,  0,  0,  0,  0, -1,  0, -1,  0] [ 0,  0,  0] -1 */
    52569932, /* 75793 (1643) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    52556920, /* 75794 (1643) [-1,  0,  0,  0,  0,  1,  0,  1,  0] [ 6,  6,  6] -1 */
        7636, /* 75795 (1643) [ 0, -1,  0,  0,  0, -1,  1,  0,  0] [ 0,  0,  0]  1 */
    18549282, /* 75796 (1643) [ 0, -1,  0,  1,  0,  0,  0,  0, -1] [ 6,  6,  6]  1 */
    34015534, /* 75797 (1643) [-1,  0,  0,  0,  0,  1,  0,  1,  0] [ 0,  0,  0] -1 */
    52561282, /* 75798 (1643) [ 0, -1,  0,  0,  0,  1, -1,  0,  0] [ 6,  6,  6] -1 */
    34021426, /* 75799 (1643) [ 0,  0, -1,  0,  1,  0,  1,  0,  0] [ 0,  0,  0] -1 */
    52565602, /* 75800 (1643) [ 0,  1,  0,  0,  0, -1, -1,  0,  0] [ 6,  6,  6] -1 */
    52565674, /* 75801 (1643) [ 0,  1,  0,  0,  0,  1,  1,  0,  0] [ 6,  6,  6] -1 */
    34024216, /* 75802 (1643) [ 0,  1,  0,  0,  0, -1, -1,  0,  0] [ 0,  0,  0] -1 */
    18557758, /* 75803 (1643) [ 1,  0,  0,  0,  0, -1,  0, -1,  0] [ 6,  6,  6]  1 */
       10480, /* 75804 (1643) [ 0,  0,  1,  0, -1,  0, -1,  0,  0] [ 0,  0,  0]  1 */
    52564426, /* 75805 (1643) [ 0,  0,  1,  1,  0,  0,  0,  1,  0] [ 6,  6,  6] -1 */
    18551716, /* 75806 (1643) [ 0,  0,  1, -1,  0,  0,  0,  1,  0] [ 6,  6,  6]  1 */
    18544636, /* 75807 (1643) [-1,  0,  0,  0,  0, -1,  0, -1,  0] [ 6,  6,  6]  1 */
       10642, /* 75808 (1643) [ 0,  0,  1,  0,  1,  0, -1,  0,  0] [ 0,  0,  0]  1 */
    18550258, /* 75809 (1643) [ 0,  0, -1, -1,  0,  0,  0,  1,  0] [ 6,  6,  6]  1 */
    52565880, /* 75810 (1643) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 6,  6,  6] -1 */
       16426, /* 75811 (1643) [ 1,  0,  0,  0,  0,  1,  0, -1,  0] [ 0,  0,  0]  1 */
       16322, /* 75812 (1643) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
        3200, /* 75813 (1643) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
        9358, /* 75814 (1643) [ 0,  0, -1,  1,  0,  0,  0,  1,  0] [ 0,  0,  0]  1 */
    18544690, /* 75815 (1643) [-1,  0,  0,  0,  0,  1,  0, -1,  0] [ 6,  6,  6]  1 */
    18551710, /* 75816 (1643) [ 0,  0,  1, -1,  0,  0,  0, -1,  0] [ 6,  6,  6]  1 */
    34021090, /* 75817 (1643) [ 0,  0, -1, -1,  0,  0,  0, -1,  0] [ 0,  0,  0] -1 */
       16482, /* 75818 (1643) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
       16484, /* 75819 (1644) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
       10660, /* 75820 (1644) [ 0,  0,  1,  0,  1,  0,  1,  0,  0] [ 0,  0,  0]  1 */
       16320, /* 75821 (1644) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
       16432, /* 75822 (1644) [ 1,  0,  0,  0,  0,  1,  0,  1,  0] [ 0,  0,  0]  1 */
        3256, /* 75823 (1644) [-1,  0,  0,  0,  0, -1,  0,  1,  0] [ 0,  0,  0]  1 */
    52562968, /* 75824 (1644) [ 0,  0, -1,  1,  0,  0,  0,  1,  0] [ 6,  6,  6] -1 */
    18550570, /* 75825 (1644) [ 0,  0, -1,  0,  1,  0, -1,  0,  0] [ 6,  6,  6]  1 */
    52565620, /* 75826 (1644) [ 0,  1,  0,  0,  0, -1,  1,  0,  0] [ 6,  6,  6] -1 */
    52565656, /* 75827 (1644) [ 0,  1,  0,  0,  0,  1, -1,  0,  0] [ 6,  6,  6] -1 */
        9184, /* 75828 (1644) [ 0,  0, -1,  0,  1,  0, -1,  0,  0] [ 0,  0,  0]  1 */
    34024234, /* 75829 (1644) [ 0,  1,  0,  0,  0, -1,  1,  0,  0] [ 0,  0,  0] -1 */
    34020122, /* 75830 (1644) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 0,  0,  0] -1 */
        9352, /* 75831 (1644) [ 0,  0, -1,  1,  0,  0,  0, -1,  0] [ 0,  0,  0]  1 */
    52556972, /* 75832 (1644) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    18544746, /* 75833 (1644) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
    18557870, /* 75834 (1644) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
        8872, /* 75835 (1644) [ 0,  0, -1, -1,  0,  0,  0,  1,  0] [ 0,  0,  0]  1 */
    52561228, /* 75836 (1644) [ 0, -1,  0,  0,  0, -1, -1,  0,  0] [ 6,  6,  6] -1 */
       16372, /* 75837 (1644) [ 1,  0,  0,  0,  0, -1,  0, -1,  0] [ 0,  0,  0]  1 */
    52569988, /* 75838 (1644) [ 1,  0,  0,  0,  0, -1,  0,  1,  0] [ 6,  6,  6] -1 */
    18549058, /* 75839 (1644) [ 0, -1,  0,  0,  0,  1, -1,  0,  0] [ 6,  6,  6]  1 */
    52570092, /* 75840 (1644) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    18553378, /* 75841 (1644) [ 0,  1,  0,  0,  0, -1, -1,  0,  0] [ 6,  6,  6]  1 */
    52562632, /* 75842 (1644) [ 0,  0, -1,  0, -1,  0, -1,  0,  0] [ 6,  6,  6] -1 */
    34024494, /* 75843 (1644) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    52564420, /* 75844 (1644) [ 0,  0,  1,  1,  0,  0,  0, -1,  0] [ 6,  6,  6] -1 */
    18552202, /* 75845 (1644) [ 0,  0,  1,  1,  0,  0,  0,  1,  0] [ 6,  6,  6]  1 */
    34023034, /* 75846 (1644) [ 0,  0,  1,  1,  0,  0,  0, -1,  0] [ 0,  0,  0] -1 */
        3304, /* 75847 (1644) [-1,  0,  0,  0,  0,  1,  0, -1,  0] [ 0,  0,  0]  1 */
       10324, /* 75848 (1644) [ 0,  0,  1, -1,  0,  0,  0, -1,  0] [ 0,  0,  0]  1 */
    52564252, /* 75849 (1644) [ 0,  0,  1,  0,  1,  0, -1,  0,  0] [ 6,  6,  6] -1 */
    34022866, /* 75850 (1644) [ 0,  0,  1,  0,  1,  0, -1,  0,  0] [ 0,  0,  0] -1 */
    52565396, /* 75851 (1644) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    52570036, /* 75852 (1644) [ 1,  0,  0,  0,  0,  1,  0, -1,  0] [ 6,  6,  6] -1 */
    18550426, /* 75853 (1644) [ 0,  0, -1,  0, -1,  0,  1,  0,  0] [ 6,  6,  6]  1 */
    34028650, /* 75854 (1644) [ 1,  0,  0,  0,  0,  1,  0, -1,  0] [ 0,  0,  0] -1 */
    34022554, /* 75855 (1644) [ 0,  0,  1, -1,  0,  0,  0,  1,  0] [ 0,  0,  0] -1 */
    34024270, /* 75856 (1644) [ 0,  1,  0,  0,  0,  1, -1,  0,  0] [ 0,  0,  0] -1 */
    34021582, /* 75857 (1644) [ 0,  0, -1,  1,  0,  0,  0,  1,  0] [ 0,  0,  0] -1 */
    18553170, /* 75858 (1644) [ 0,  1,  0, -1,  0,  0,  0,  0, -1] [ 6,  6,  6]  1 */
    34015586, /* 75859 (1644) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
        7896, /* 75860 (1644) [ 0, -1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    34028706, /* 75861 (1644) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    34019842, /* 75862 (1644) [ 0, -1,  0,  0,  0, -1, -1,  0,  0] [ 0,  0,  0] -1 */
    18553658, /* 75863 (1644) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    52556808, /* 75864 (1644) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    52564108, /* 75865 (1644) [ 0,  0,  1,  0, -1,  0,  1,  0,  0] [ 6,  6,  6] -1 */
    34028602, /* 75866 (1644) [ 1,  0,  0,  0,  0, -1,  0,  1,  0] [ 0,  0,  0] -1 */
       10816, /* 75867 (1644) [ 0,  0,  1,  1,  0,  0,  0,  1,  0] [ 0,  0,  0]  1 */
    34015422, /* 75868 (1644) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    18553450, /* 75869 (1644) [ 0,  1,  0,  0,  0,  1,  1,  0,  0] [ 6,  6,  6]  1 */
       11992, /* 75870 (1644) [ 0,  1,  0,  0,  0, -1, -1,  0,  0] [ 0,  0,  0]  1 */
       12064, /* 75871 (1644) [ 0,  1,  0,  0,  0,  1,  1,  0,  0] [ 0,  0,  0]  1 */
    34019914, /* 75872 (1644) [ 0, -1,  0,  0,  0,  1,  1,  0,  0] [ 0,  0,  0] -1 */
    18557818, /* 75873 (1644) [ 1,  0,  0,  0,  0,  1,  0,  1,  0] [ 6,  6,  6]  1 */
    52561020, /* 75874 (1644) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    18548798, /* 75875 (1644) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    18544642, /* 75876 (1644) [-1,  0,  0,  0,  0, -1,  0,  1,  0] [ 6,  6,  6]  1 */
        9040, /* 75877 (1644) [ 0,  0, -1,  0, -1,  0,  1,  0,  0] [ 0,  0,  0]  1 */
    52563940, /* 75878 (1644) [ 0,  0,  1, -1,  0,  0,  0,  1,  0] [ 6,  6,  6] -1 */
    52556860, /* 75879 (1644) [-1,  0,  0,  0,  0, -1,  0, -1,  0] [ 6,  6,  6] -1 */
    34015474, /* 75880 (1644) [-1,  0,  0,  0,  0, -1,  0, -1,  0] [ 0,  0,  0] -1 */
    52562812, /* 75881 (1644) [ 0,  0, -1,  0,  1,  0,  1,  0,  0] [ 6,  6,  6] -1 */
    18550738, /* 75882 (1644) [ 0,  0, -1,  1,  0,  0,  0, -1,  0] [ 6,  6,  6]  1 */
    34028546, /* 75883 (1644) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
       11784, /* 75884 (1644) [ 0,  1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    18551866, /* 75885 (1644) [ 0,  0,  1,  0, -1,  0, -1,  0,  0] [ 6,  6,  6]  1 */
        7672, /* 75886 (1644) [ 0, -1,  0,  0,  0,  1, -1,  0,  0] [ 0,  0,  0]  1 */
    34022722, /* 75887 (1644) [ 0,  0,  1,  0, -1,  0,  1,  0,  0] [ 0,  0,  0] -1 */
        3360, /* 75888 (1644) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    34021246, /* 75889 (1644) [ 0,  0, -1,  0, -1,  0, -1,  0,  0] [ 0,  0,  0] -1 */
       12272, /* 75890 (1644) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    52562476, /* 75891 (1644) [ 0,  0, -1, -1,  0,  0,  0, -1,  0] [ 6,  6,  6] -1 */
        7412, /* 75892 (1644) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    18544586, /* 75893 (1644) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    18552046, /* 75894 (1644) [ 0,  0,  1,  0,  1,  0,  1,  0,  0] [ 6,  6,  6]  1 */
    18557706, /* 75895 (1644) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
    34019634, /* 75896 (1644) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    52561508, /* 75897 (1644) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    34024010, /* 75898 (1644) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    18549022, /* 75899 (1644) [ 0, -1,  0,  0,  0, -1,  1,  0,  0] [ 6,  6,  6]  1 */
    52569932, /* 75900 (1644) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    52556920, /* 75901 (1644) [-1,  0,  0,  0,  0,  1,  0,  1,  0] [ 6,  6,  6] -1 */
        7636, /* 75902 (1644) [ 0, -1,  0,  0,  0, -1,  1,  0,  0] [ 0,  0,  0]  1 */
    18549282, /* 75903 (1644) [ 0, -1,  0,  1,  0,  0,  0,  0, -1] [ 6,  6,  6]  1 */
    34015534, /* 75904 (1644) [-1,  0,  0,  0,  0,  1,  0,  1,  0] [ 0,  0,  0] -1 */
    34021426, /* 75905 (1644) [ 0,  0, -1,  0,  1,  0,  1,  0,  0] [ 0,  0,  0] -1 */
    18557758, /* 75906 (1644) [ 1,  0,  0,  0,  0, -1,  0, -1,  0] [ 6,  6,  6]  1 */
       10480, /* 75907 (1644) [ 0,  0,  1,  0, -1,  0, -1,  0,  0] [ 0,  0,  0]  1 */
    18550258, /* 75908 (1644) [ 0,  0, -1, -1,  0,  0,  0,  1,  0] [ 6,  6,  6]  1 */
    52565880, /* 75909 (1644) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 6,  6,  6] -1 */
        3200, /* 75910 (1644) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    18544690, /* 75911 (1644) [-1,  0,  0,  0,  0,  1,  0, -1,  0] [ 6,  6,  6]  1 */
    18551710, /* 75912 (1644) [ 0,  0,  1, -1,  0,  0,  0, -1,  0] [ 6,  6,  6]  1 */
    34021090, /* 75913 (1644) [ 0,  0, -1, -1,  0,  0,  0, -1,  0] [ 0,  0,  0] -1 */
    52561300, /* 75914 (1644) [ 0, -1,  0,  0,  0,  1,  1,  0,  0] [ 6,  6,  6] -1 */
       16484, /* 75915 (1645) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
       16320, /* 75916 (1645) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
        3198, /* 75917 (1645) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    52565394, /* 75918 (1645) [ 0,  1,  0, -1,  0,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    34020120, /* 75919 (1645) [ 0, -1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    34020122, /* 75920 (1645) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 0,  0,  0] -1 */
        9352, /* 75921 (1645) [ 0,  0, -1,  1,  0,  0,  0, -1,  0] [ 0,  0,  0]  1 */
    52565882, /* 75922 (1645) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    18544746, /* 75923 (1645) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
    34024496, /* 75924 (1645) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    18557870, /* 75925 (1645) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
        8872, /* 75926 (1645) [ 0,  0, -1, -1,  0,  0,  0,  1,  0] [ 0,  0,  0]  1 */
    52570042, /* 75927 (1645) [ 1,  0,  0,  0,  0,  1,  0,  1,  0] [ 6,  6,  6] -1 */
    52561022, /* 75928 (1645) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    52569988, /* 75929 (1645) [ 1,  0,  0,  0,  0, -1,  0,  1,  0] [ 6,  6,  6] -1 */
    18549058, /* 75930 (1645) [ 0, -1,  0,  0,  0,  1, -1,  0,  0] [ 6,  6,  6]  1 */
    52556866, /* 75931 (1645) [-1,  0,  0,  0,  0, -1,  0,  1,  0] [ 6,  6,  6] -1 */
    18553378, /* 75932 (1645) [ 0,  1,  0,  0,  0, -1, -1,  0,  0] [ 6,  6,  6]  1 */
    52562632, /* 75933 (1645) [ 0,  0, -1,  0, -1,  0, -1,  0,  0] [ 6,  6,  6] -1 */
    34024494, /* 75934 (1645) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    18552202, /* 75935 (1645) [ 0,  0,  1,  1,  0,  0,  0,  1,  0] [ 6,  6,  6]  1 */
    34021264, /* 75936 (1645) [ 0,  0, -1,  0, -1,  0,  1,  0,  0] [ 0,  0,  0] -1 */
       10324, /* 75937 (1645) [ 0,  0,  1, -1,  0,  0,  0, -1,  0] [ 0,  0,  0]  1 */
    18550252, /* 75938 (1645) [ 0,  0, -1, -1,  0,  0,  0, -1,  0] [ 6,  6,  6]  1 */
    52564252, /* 75939 (1645) [ 0,  0,  1,  0,  1,  0, -1,  0,  0] [ 6,  6,  6] -1 */
        8866, /* 75940 (1645) [ 0,  0, -1, -1,  0,  0,  0, -1,  0] [ 0,  0,  0]  1 */
    34024008, /* 75941 (1645) [ 0,  1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    34022866, /* 75942 (1645) [ 0,  0,  1,  0,  1,  0, -1,  0,  0] [ 0,  0,  0] -1 */
    52565396, /* 75943 (1645) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    52570036, /* 75944 (1645) [ 1,  0,  0,  0,  0,  1,  0, -1,  0] [ 6,  6,  6] -1 */
    52564090, /* 75945 (1645) [ 0,  0,  1,  0, -1,  0, -1,  0,  0] [ 6,  6,  6] -1 */
    34028650, /* 75946 (1645) [ 1,  0,  0,  0,  0,  1,  0, -1,  0] [ 0,  0,  0] -1 */
    34019636, /* 75947 (1645) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    18550744, /* 75948 (1645) [ 0,  0, -1,  1,  0,  0,  0,  1,  0] [ 6,  6,  6]  1 */
    18553396, /* 75949 (1645) [ 0,  1,  0,  0,  0, -1,  1,  0,  0] [ 6,  6,  6]  1 */
    52564270, /* 75950 (1645) [ 0,  0,  1,  0,  1,  0,  1,  0,  0] [ 6,  6,  6] -1 */
    34022884, /* 75951 (1645) [ 0,  0,  1,  0,  1,  0,  1,  0,  0] [ 0,  0,  0] -1 */
    18557708, /* 75952 (1645) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    18544748, /* 75953 (1645) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    52564108, /* 75954 (1645) [ 0,  0,  1,  0, -1,  0,  1,  0,  0] [ 6,  6,  6] -1 */
    34028602, /* 75955 (1645) [ 1,  0,  0,  0,  0, -1,  0,  1,  0] [ 0,  0,  0] -1 */
       10816, /* 75956 (1645) [ 0,  0,  1,  1,  0,  0,  0,  1,  0] [ 0,  0,  0]  1 */
    18553450, /* 75957 (1645) [ 0,  1,  0,  0,  0,  1,  1,  0,  0] [ 6,  6,  6]  1 */
       11992, /* 75958 (1645) [ 0,  1,  0,  0,  0, -1, -1,  0,  0] [ 0,  0,  0]  1 */
       12064, /* 75959 (1645) [ 0,  1,  0,  0,  0,  1,  1,  0,  0] [ 0,  0,  0]  1 */
    52562794, /* 75960 (1645) [ 0,  0, -1,  0,  1,  0, -1,  0,  0] [ 6,  6,  6] -1 */
    52561020, /* 75961 (1645) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    18557868, /* 75962 (1645) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
    52561506, /* 75963 (1645) [ 0, -1,  0,  1,  0,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    18552196, /* 75964 (1645) [ 0,  0,  1,  1,  0,  0,  0, -1,  0] [ 6,  6,  6]  1 */
    52569982, /* 75965 (1645) [ 1,  0,  0,  0,  0, -1,  0, -1,  0] [ 6,  6,  6] -1 */
    34022704, /* 75966 (1645) [ 0,  0,  1,  0, -1,  0, -1,  0,  0] [ 0,  0,  0] -1 */
    52556860, /* 75967 (1645) [-1,  0,  0,  0,  0, -1,  0, -1,  0] [ 6,  6,  6] -1 */
    18549076, /* 75968 (1645) [ 0, -1,  0,  0,  0,  1,  1,  0,  0] [ 6,  6,  6]  1 */
    34015474, /* 75969 (1645) [-1,  0,  0,  0,  0, -1,  0, -1,  0] [ 0,  0,  0] -1 */
    52562812, /* 75970 (1645) [ 0,  0, -1,  0,  1,  0,  1,  0,  0] [ 6,  6,  6] -1 */
    18550738, /* 75971 (1645) [ 0,  0, -1,  1,  0,  0,  0, -1,  0] [ 6,  6,  6]  1 */
    52556914, /* 75972 (1645) [-1,  0,  0,  0,  0,  1,  0, -1,  0] [ 6,  6,  6] -1 */
    34015528, /* 75973 (1645) [-1,  0,  0,  0,  0,  1,  0, -1,  0] [ 0,  0,  0] -1 */
        7672, /* 75974 (1645) [ 0, -1,  0,  0,  0,  1, -1,  0,  0] [ 0,  0,  0]  1 */
    34022722, /* 75975 (1645) [ 0,  0,  1,  0, -1,  0,  1,  0,  0] [ 0,  0,  0] -1 */
       10330, /* 75976 (1645) [ 0,  0,  1, -1,  0,  0,  0,  1,  0] [ 0,  0,  0]  1 */
    18553432, /* 75977 (1645) [ 0,  1,  0,  0,  0,  1, -1,  0,  0] [ 6,  6,  6]  1 */
        3360, /* 75978 (1645) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
       12010, /* 75979 (1645) [ 0,  1,  0,  0,  0, -1,  1,  0,  0] [ 0,  0,  0]  1 */
       12046, /* 75980 (1645) [ 0,  1,  0,  0,  0,  1, -1,  0,  0] [ 0,  0,  0]  1 */
    34021246, /* 75981 (1645) [ 0,  0, -1,  0, -1,  0, -1,  0,  0] [ 0,  0,  0] -1 */
        3362, /* 75982 (1645) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34028656, /* 75983 (1645) [ 1,  0,  0,  0,  0,  1,  0,  1,  0] [ 0,  0,  0] -1 */
    18544586, /* 75984 (1645) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    18549004, /* 75985 (1645) [ 0, -1,  0,  0,  0, -1, -1,  0,  0] [ 6,  6,  6]  1 */
        7618, /* 75986 (1645) [ 0, -1,  0,  0,  0, -1, -1,  0,  0] [ 0,  0,  0]  1 */
    34015480, /* 75987 (1645) [-1,  0,  0,  0,  0, -1,  0,  1,  0] [ 0,  0,  0] -1 */
    18557706, /* 75988 (1645) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
    52562650, /* 75989 (1645) [ 0,  0, -1,  0, -1,  0,  1,  0,  0] [ 6,  6,  6] -1 */
    34021408, /* 75990 (1645) [ 0,  0, -1,  0,  1,  0, -1,  0,  0] [ 0,  0,  0] -1 */
    18544584, /* 75991 (1645) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
    34019634, /* 75992 (1645) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  0] -1 */
        7690, /* 75993 (1645) [ 0, -1,  0,  0,  0,  1,  1,  0,  0] [ 0,  0,  0]  1 */
       10810, /* 75994 (1645) [ 0,  0,  1,  1,  0,  0,  0, -1,  0] [ 0,  0,  0]  1 */
    52561508, /* 75995 (1645) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    34024010, /* 75996 (1645) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    18549022, /* 75997 (1645) [ 0, -1,  0,  0,  0, -1,  1,  0,  0] [ 6,  6,  6]  1 */
    34028596, /* 75998 (1645) [ 1,  0,  0,  0,  0, -1,  0, -1,  0] [ 0,  0,  0] -1 */
    52556920, /* 75999 (1645) [-1,  0,  0,  0,  0,  1,  0,  1,  0] [ 6,  6,  6] -1 */
        7636, /* 76000 (1645) [ 0, -1,  0,  0,  0, -1,  1,  0,  0] [ 0,  0,  0]  1 */
    34015534, /* 76001 (1645) [-1,  0,  0,  0,  0,  1,  0,  1,  0] [ 0,  0,  0] -1 */
    34021426, /* 76002 (1645) [ 0,  0, -1,  0,  1,  0,  1,  0,  0] [ 0,  0,  0] -1 */
    18551716, /* 76003 (1645) [ 0,  0,  1, -1,  0,  0,  0,  1,  0] [ 6,  6,  6]  1 */
    18550258, /* 76004 (1645) [ 0,  0, -1, -1,  0,  0,  0,  1,  0] [ 6,  6,  6]  1 */
    52565880, /* 76005 (1645) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 6,  6,  6] -1 */
       16322, /* 76006 (1645) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
        3200, /* 76007 (1645) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
        9358, /* 76008 (1645) [ 0,  0, -1,  1,  0,  0,  0,  1,  0] [ 0,  0,  0]  1 */
    18551710, /* 76009 (1645) [ 0,  0,  1, -1,  0,  0,  0, -1,  0] [ 6,  6,  6]  1 */
       16482, /* 76010 (1645) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
       16484, /* 76011 (1646) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
        9022, /* 76012 (1646) [ 0,  0, -1,  0, -1,  0, -1,  0,  0] [ 0,  0,  0]  1 */
       16320, /* 76013 (1646) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    52565394, /* 76014 (1646) [ 0,  1,  0, -1,  0,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    52562968, /* 76015 (1646) [ 0,  0, -1,  1,  0,  0,  0,  1,  0] [ 6,  6,  6] -1 */
    34020120, /* 76016 (1646) [ 0, -1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    18548796, /* 76017 (1646) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 6,  6,  6]  1 */
    52565620, /* 76018 (1646) [ 0,  1,  0,  0,  0, -1,  1,  0,  0] [ 6,  6,  6] -1 */
    52565656, /* 76019 (1646) [ 0,  1,  0,  0,  0,  1, -1,  0,  0] [ 6,  6,  6] -1 */
        7410, /* 76020 (1646) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    34024234, /* 76021 (1646) [ 0,  1,  0,  0,  0, -1,  1,  0,  0] [ 0,  0,  0] -1 */
        9352, /* 76022 (1646) [ 0,  0, -1,  1,  0,  0,  0, -1,  0] [ 0,  0,  0]  1 */
    52556972, /* 76023 (1646) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    52565882, /* 76024 (1646) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    18544746, /* 76025 (1646) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
    34024496, /* 76026 (1646) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    18557870, /* 76027 (1646) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
        8872, /* 76028 (1646) [ 0,  0, -1, -1,  0,  0,  0,  1,  0] [ 0,  0,  0]  1 */
    52561228, /* 76029 (1646) [ 0, -1,  0,  0,  0, -1, -1,  0,  0] [ 6,  6,  6] -1 */
    52570042, /* 76030 (1646) [ 1,  0,  0,  0,  0,  1,  0,  1,  0] [ 6,  6,  6] -1 */
    18544696, /* 76031 (1646) [-1,  0,  0,  0,  0,  1,  0,  1,  0] [ 6,  6,  6]  1 */
    52561022, /* 76032 (1646) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 6,  6,  6] -1 */
        3250, /* 76033 (1646) [-1,  0,  0,  0,  0, -1,  0, -1,  0] [ 0,  0,  0]  1 */
    52570092, /* 76034 (1646) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    18550588, /* 76035 (1646) [ 0,  0, -1,  0,  1,  0,  1,  0,  0] [ 6,  6,  6]  1 */
    18549058, /* 76036 (1646) [ 0, -1,  0,  0,  0,  1, -1,  0,  0] [ 6,  6,  6]  1 */
    52556866, /* 76037 (1646) [-1,  0,  0,  0,  0, -1,  0,  1,  0] [ 6,  6,  6] -1 */
        9202, /* 76038 (1646) [ 0,  0, -1,  0,  1,  0,  1,  0,  0] [ 0,  0,  0]  1 */
    18553378, /* 76039 (1646) [ 0,  1,  0,  0,  0, -1, -1,  0,  0] [ 6,  6,  6]  1 */
    52564420, /* 76040 (1646) [ 0,  0,  1,  1,  0,  0,  0, -1,  0] [ 6,  6,  6] -1 */
    18552202, /* 76041 (1646) [ 0,  0,  1,  1,  0,  0,  0,  1,  0] [ 6,  6,  6]  1 */
    34023034, /* 76042 (1646) [ 0,  0,  1,  1,  0,  0,  0, -1,  0] [ 0,  0,  0] -1 */
    34021264, /* 76043 (1646) [ 0,  0, -1,  0, -1,  0,  1,  0,  0] [ 0,  0,  0] -1 */
       10324, /* 76044 (1646) [ 0,  0,  1, -1,  0,  0,  0, -1,  0] [ 0,  0,  0]  1 */
    34024008, /* 76045 (1646) [ 0,  1,  0, -1,  0,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    52564090, /* 76046 (1646) [ 0,  0,  1,  0, -1,  0, -1,  0,  0] [ 6,  6,  6] -1 */
    34022554, /* 76047 (1646) [ 0,  0,  1, -1,  0,  0,  0,  1,  0] [ 0,  0,  0] -1 */
    34024270, /* 76048 (1646) [ 0,  1,  0,  0,  0,  1, -1,  0,  0] [ 0,  0,  0] -1 */
    34021582, /* 76049 (1646) [ 0,  0, -1,  1,  0,  0,  0,  1,  0] [ 0,  0,  0] -1 */
    34015586, /* 76050 (1646) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    34019636, /* 76051 (1646) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    34028706, /* 76052 (1646) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    34019842, /* 76053 (1646) [ 0, -1,  0,  0,  0, -1, -1,  0,  0] [ 0,  0,  0] -1 */
    52564270, /* 76054 (1646) [ 0,  0,  1,  0,  1,  0,  1,  0,  0] [ 6,  6,  6] -1 */
    18549284, /* 76055 (1646) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 6,  6,  6]  1 */
       11786, /* 76056 (1646) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    34022884, /* 76057 (1646) [ 0,  0,  1,  0,  1,  0,  1,  0,  0] [ 0,  0,  0] -1 */
        7898, /* 76058 (1646) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    52556808, /* 76059 (1646) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
        3310, /* 76060 (1646) [-1,  0,  0,  0,  0,  1,  0,  1,  0] [ 0,  0,  0]  1 */
       10816, /* 76061 (1646) [ 0,  0,  1,  1,  0,  0,  0,  1,  0] [ 0,  0,  0]  1 */
    34015422, /* 76062 (1646) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    18553450, /* 76063 (1646) [ 0,  1,  0,  0,  0,  1,  1,  0,  0] [ 6,  6,  6]  1 */
       11992, /* 76064 (1646) [ 0,  1,  0,  0,  0, -1, -1,  0,  0] [ 0,  0,  0]  1 */
       12064, /* 76065 (1646) [ 0,  1,  0,  0,  0,  1,  1,  0,  0] [ 0,  0,  0]  1 */
    34019914, /* 76066 (1646) [ 0, -1,  0,  0,  0,  1,  1,  0,  0] [ 0,  0,  0] -1 */
    52562794, /* 76067 (1646) [ 0,  0, -1,  0,  1,  0, -1,  0,  0] [ 6,  6,  6] -1 */
    52561506, /* 76068 (1646) [ 0, -1,  0,  1,  0,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    18553656, /* 76069 (1646) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 6,  6,  6]  1 */
       12270, /* 76070 (1646) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    52569982, /* 76071 (1646) [ 1,  0,  0,  0,  0, -1,  0, -1,  0] [ 6,  6,  6] -1 */
    34022704, /* 76072 (1646) [ 0,  0,  1,  0, -1,  0, -1,  0,  0] [ 0,  0,  0] -1 */
    52563940, /* 76073 (1646) [ 0,  0,  1, -1,  0,  0,  0,  1,  0] [ 6,  6,  6] -1 */
    18550738, /* 76074 (1646) [ 0,  0, -1,  1,  0,  0,  0, -1,  0] [ 6,  6,  6]  1 */
    34028546, /* 76075 (1646) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    52556914, /* 76076 (1646) [-1,  0,  0,  0,  0,  1,  0, -1,  0] [ 6,  6,  6] -1 */
    18552028, /* 76077 (1646) [ 0,  0,  1,  0,  1,  0, -1,  0,  0] [ 6,  6,  6]  1 */
    34015528, /* 76078 (1646) [-1,  0,  0,  0,  0,  1,  0, -1,  0] [ 0,  0,  0] -1 */
    18553172, /* 76079 (1646) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    18557812, /* 76080 (1646) [ 1,  0,  0,  0,  0,  1,  0, -1,  0] [ 6,  6,  6]  1 */
        7672, /* 76081 (1646) [ 0, -1,  0,  0,  0,  1, -1,  0,  0] [ 0,  0,  0]  1 */
        3360, /* 76082 (1646) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
    52562476, /* 76083 (1646) [ 0,  0, -1, -1,  0,  0,  0, -1,  0] [ 6,  6,  6] -1 */
    52561300, /* 76084 (1646) [ 0, -1,  0,  0,  0,  1,  1,  0,  0] [ 6,  6,  6] -1 */
    34028656, /* 76085 (1646) [ 1,  0,  0,  0,  0,  1,  0,  1,  0] [ 0,  0,  0] -1 */
    18544586, /* 76086 (1646) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    34015480, /* 76087 (1646) [-1,  0,  0,  0,  0, -1,  0,  1,  0] [ 0,  0,  0] -1 */
    18557706, /* 76088 (1646) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
    52562650, /* 76089 (1646) [ 0,  0, -1,  0, -1,  0,  1,  0,  0] [ 6,  6,  6] -1 */
    34021408, /* 76090 (1646) [ 0,  0, -1,  0,  1,  0, -1,  0,  0] [ 0,  0,  0] -1 */
    18557764, /* 76091 (1646) [ 1,  0,  0,  0,  0, -1,  0,  1,  0] [ 6,  6,  6]  1 */
    18551884, /* 76092 (1646) [ 0,  0,  1,  0, -1,  0,  1,  0,  0] [ 6,  6,  6]  1 */
       16378, /* 76093 (1646) [ 1,  0,  0,  0,  0, -1,  0,  1,  0] [ 0,  0,  0]  1 */
    18550408, /* 76094 (1646) [ 0,  0, -1,  0, -1,  0, -1,  0,  0] [ 6,  6,  6]  1 */
    18549022, /* 76095 (1646) [ 0, -1,  0,  0,  0, -1,  1,  0,  0] [ 6,  6,  6]  1 */
    34028596, /* 76096 (1646) [ 1,  0,  0,  0,  0, -1,  0, -1,  0] [ 0,  0,  0] -1 */
    52569932, /* 76097 (1646) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
        7636, /* 76098 (1646) [ 0, -1,  0,  0,  0, -1,  1,  0,  0] [ 0,  0,  0]  1 */
    18544636, /* 76099 (1646) [-1,  0,  0,  0,  0, -1,  0, -1,  0] [ 6,  6,  6]  1 */
       10642, /* 76100 (1646) [ 0,  0,  1,  0,  1,  0, -1,  0,  0] [ 0,  0,  0]  1 */
    18550258, /* 76101 (1646) [ 0,  0, -1, -1,  0,  0,  0,  1,  0] [ 6,  6,  6]  1 */
       16426, /* 76102 (1646) [ 1,  0,  0,  0,  0,  1,  0, -1,  0] [ 0,  0,  0]  1 */
        3200, /* 76103 (1646) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    18551710, /* 76104 (1646) [ 0,  0,  1, -1,  0,  0,  0, -1,  0] [ 6,  6,  6]  1 */
    34021090, /* 76105 (1646) [ 0,  0, -1, -1,  0,  0,  0, -1,  0] [ 0,  0,  0] -1 */
       10498, /* 76106 (1646) [ 0,  0,  1,  0, -1,  0,  1,  0,  0] [ 0,  0,  0]  1 */
       16484, /* 76107 (1647) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
      134418, /* 76108 (1647) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  6]  1 */
    27701877, /* 76109 (1647) [ 0, -1,  0,  1,  0,  0,  0,  0, -1] [ 9,  9,  3]  1 */
     1429222, /* 76110 (1647) [ 0,  1,  0,  0,  0,  1, -1,  0,  0] [ 0,  6,  0]  1 */
        3198, /* 76111 (1647) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
     1420376, /* 76112 (1647) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  0]  1 */
     1433658, /* 76113 (1647) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  0]  1 */
    18557870, /* 76114 (1647) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
     9405169, /* 76115 (1647) [ 1,  0,  0,  0,  0, -1,  0,  1,  0] [ 3,  3,  9]  1 */
     9399289, /* 76116 (1647) [ 0,  0,  1,  0, -1,  0,  1,  0,  0] [ 3,  3,  9]  1 */
    10691179, /* 76117 (1647) [-1,  0,  0,  0,  0,  1,  0,  1,  0] [ 3,  9,  3]  1 */
    27821101, /* 76118 (1647) [ 0,  0, -1,  0, -1,  0, -1,  0,  0] [ 9,  9,  9]  1 */
    17135020, /* 76119 (1647) [ 0,  0,  1,  1,  0,  0,  0, -1,  0] [ 6,  0,  6]  1 */
    10697071, /* 76120 (1647) [ 0,  0, -1,  0,  1,  0,  1,  0,  0] [ 3,  9,  3]  1 */
    26411275, /* 76121 (1647) [ 1,  0,  0,  0,  0, -1,  0, -1,  0] [ 9,  3,  9]  1 */
    27828511, /* 76122 (1647) [ 1,  0,  0,  0,  0,  1,  0,  1,  0] [ 9,  9,  9]  1 */
     9282965, /* 76123 (1647) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 3,  3,  3]  1 */
      130090, /* 76124 (1647) [ 0,  1,  0,  0,  0, -1, -1,  0,  0] [ 0,  0,  6]  1 */
     1424812, /* 76125 (1647) [ 0, -1,  0,  0,  0, -1,  1,  0,  0] [ 0,  6,  0]  1 */
    26398213, /* 76126 (1647) [-1,  0,  0,  0,  0,  1,  0,  1,  0] [ 9,  3,  9]  1 */
    18433612, /* 76127 (1647) [ 0,  0,  1, -1,  0,  0,  0, -1,  0] [ 6,  6,  0]  1 */
    18552202, /* 76128 (1647) [ 0,  0,  1,  1,  0,  0,  0,  1,  0] [ 6,  6,  6]  1 */
     9281353, /* 76129 (1647) [ 0,  0,  1,  0,  1,  0,  1,  0,  0] [ 3,  3,  3]  1 */
    17131846, /* 76130 (1647) [ 0, -1,  0,  0,  0, -1,  1,  0,  0] [ 6,  0,  6]  1 */
      128422, /* 76131 (1647) [ 0,  0,  1, -1,  0,  0,  0, -1,  0] [ 0,  0,  6]  1 */
     1538634, /* 76132 (1647) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
    26284217, /* 76133 (1647) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 9,  3,  3]  1 */
    18550252, /* 76134 (1647) [ 0,  0, -1, -1,  0,  0,  0, -1,  0] [ 6,  6,  6]  1 */
     9400577, /* 76135 (1647) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 3,  3,  9]  1 */
        8866, /* 76136 (1647) [ 0,  0, -1, -1,  0,  0,  0, -1,  0] [ 0,  0,  0]  1 */
    26280061, /* 76137 (1647) [-1,  0,  0,  0,  0, -1,  0,  1,  0] [ 9,  3,  3]  1 */
    10815007, /* 76138 (1647) [ 0,  0, -1,  0, -1,  0,  1,  0,  0] [ 3,  9,  9]  1 */
     9392095, /* 76139 (1647) [-1,  0,  0,  0,  0,  1,  0, -1,  0] [ 3,  3,  9]  1 */
    10699653, /* 76140 (1647) [ 0,  1,  0, -1,  0,  0,  0,  0, -1] [ 3,  9,  3]  1 */
    27822739, /* 76141 (1647) [ 0,  0,  1,  0,  1,  0,  1,  0,  0] [ 9,  9,  9]  1 */
    17140692, /* 76142 (1647) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6]  1 */
    17016442, /* 76143 (1647) [ 0,  0,  1, -1,  0,  0,  0,  1,  0] [ 6,  0,  0]  1 */
    17009472, /* 76144 (1647) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  0]  1 */
    10816609, /* 76145 (1647) [ 0,  0,  1,  0,  1,  0, -1,  0,  0] [ 3,  9,  9]  1 */
    17018122, /* 76146 (1647) [ 0,  1,  0,  0,  0, -1,  1,  0,  0] [ 6,  0,  0]  1 */
    10695767, /* 76147 (1647) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 3,  9,  3]  1 */
    18435280, /* 76148 (1647) [ 0,  1,  0,  0,  0, -1, -1,  0,  0] [ 6,  6,  0]  1 */
    26404105, /* 76149 (1647) [ 0,  0, -1,  0,  1,  0,  1,  0,  0] [ 9,  3,  9]  1 */
    27819489, /* 76150 (1647) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 9,  9,  9]  1 */
       10816, /* 76151 (1647) [ 0,  0,  1,  1,  0,  0,  0,  1,  0] [ 0,  0,  0]  1 */
    17013784, /* 76152 (1647) [ 0, -1,  0,  0,  0,  1, -1,  0,  0] [ 6,  0,  0]  1 */
     9397975, /* 76153 (1647) [ 0,  0, -1,  0,  1,  0, -1,  0,  0] [ 3,  3,  9]  1 */
    18553450, /* 76154 (1647) [ 0,  1,  0,  0,  0,  1,  1,  0,  0] [ 6,  6,  6]  1 */
    26293231, /* 76155 (1647) [ 1,  0,  0,  0,  0,  1,  0, -1,  0] [ 9,  3,  3]  1 */
       12064, /* 76156 (1647) [ 0,  1,  0,  0,  0,  1,  1,  0,  0] [ 0,  0,  0]  1 */
     1426048, /* 76157 (1647) [ 0,  0, -1, -1,  0,  0,  0,  1,  0] [ 0,  6,  0]  1 */
    10818237, /* 76158 (1647) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 3,  9,  9]  1 */
     1545604, /* 76159 (1647) [ 0,  0,  1, -1,  0,  0,  0,  1,  0] [ 0,  6,  6]  1 */
     9287125, /* 76160 (1647) [ 1,  0,  0,  0,  0,  1,  0,  1,  0] [ 3,  3,  3]  1 */
     1542946, /* 76161 (1647) [ 0, -1,  0,  0,  0,  1, -1,  0,  0] [ 0,  6,  6]  1 */
    17133082, /* 76162 (1647) [ 0,  0, -1, -1,  0,  0,  0,  1,  0] [ 6,  0,  6]  1 */
     9278103, /* 76163 (1647) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 3,  3,  3]  1 */
      125788, /* 76164 (1647) [ 0, -1,  0,  0,  0,  1,  1,  0,  0] [ 0,  0,  6]  1 */
    26285845, /* 76165 (1647) [ 0,  0, -1,  0, -1,  0,  1,  0,  0] [ 9,  3,  3]  1 */
    27815329, /* 76166 (1647) [-1,  0,  0,  0,  0, -1,  0, -1,  0] [ 9,  9,  9]  1 */
    27697285, /* 76167 (1647) [-1,  0,  0,  0,  0,  1,  0, -1,  0] [ 9,  9,  3]  1 */
    17015464, /* 76168 (1647) [ 0,  0, -1,  1,  0,  0,  0, -1,  0] [ 6,  0,  0]  1 */
    27704479, /* 76169 (1647) [ 0,  0,  1,  0, -1,  0,  1,  0,  0] [ 9,  9,  3]  1 */
    17022434, /* 76170 (1647) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  0]  1 */
    10698349, /* 76171 (1647) [ 0,  0,  1,  0, -1,  0, -1,  0,  0] [ 3,  9,  3]  1 */
    18426650, /* 76172 (1647) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    26402801, /* 76173 (1647) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 9,  3,  9]  1 */
    26406687, /* 76174 (1647) [ 0,  1,  0, -1,  0,  0,  0,  0, -1] [ 9,  3,  9]  1 */
      121460, /* 76175 (1647) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6]  1 */
    18549004, /* 76176 (1647) [ 0, -1,  0,  0,  0, -1, -1,  0,  0] [ 6,  6,  6]  1 */
        7618, /* 76177 (1647) [ 0, -1,  0,  0,  0, -1, -1,  0,  0] [ 0,  0,  0]  1 */
    10813379, /* 76178 (1647) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 3,  9,  9]  1 */
     1547284, /* 76179 (1647) [ 0,  1,  0,  0,  0, -1,  1,  0,  0] [ 0,  6,  6]  1 */
    18439608, /* 76180 (1647) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
    18544584, /* 76181 (1647) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
     9396687, /* 76182 (1647) [ 0, -1,  0,  1,  0,  0,  0,  0, -1] [ 3,  3,  9]  1 */
    10809223, /* 76183 (1647) [-1,  0,  0,  0,  0, -1,  0,  1,  0] [ 3,  9,  9]  1 */
     1551596, /* 76184 (1647) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
    26289075, /* 76185 (1647) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 9,  3,  3]  1 */
     9279715, /* 76186 (1647) [ 0,  0, -1,  0, -1,  0, -1,  0,  0] [ 3,  3,  3]  1 */
    27705767, /* 76187 (1647) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 9,  9,  3]  1 */
    17136256, /* 76188 (1647) [ 0,  1,  0,  0,  0,  1, -1,  0,  0] [ 6,  0,  6]  1 */
    17127410, /* 76189 (1647) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
    18430978, /* 76190 (1647) [ 0, -1,  0,  0,  0,  1,  1,  0,  0] [ 6,  6,  0]  1 */
    27824351, /* 76191 (1647) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 9,  9,  9]  1 */
    10704241, /* 76192 (1647) [ 1,  0,  0,  0,  0, -1,  0, -1,  0] [ 3,  9,  3]  1 */
    26287447, /* 76193 (1647) [ 0,  0,  1,  0,  1,  0, -1,  0,  0] [ 9,  3,  3]  1 */
    27710359, /* 76194 (1647) [ 1,  0,  0,  0,  0, -1,  0,  1,  0] [ 9,  9,  3]  1 */
     1427986, /* 76195 (1647) [ 0,  0,  1,  1,  0,  0,  0, -1,  0] [ 0,  6,  0]  1 */
    26405383, /* 76196 (1647) [ 0,  0,  1,  0, -1,  0, -1,  0,  0] [ 9,  3,  9]  1 */
    18432646, /* 76197 (1647) [ 0,  0, -1,  1,  0,  0,  0,  1,  0] [ 6,  6,  0]  1 */
    10822393, /* 76198 (1647) [ 1,  0,  0,  0,  0,  1,  0, -1,  0] [ 3,  9,  9]  1 */
    27703165, /* 76199 (1647) [ 0,  0, -1,  0,  1,  0, -1,  0,  0] [ 9,  9,  3]  1 */
     9273943, /* 76200 (1647) [-1,  0,  0,  0,  0, -1,  0, -1,  0] [ 3,  3,  3]  1 */
     1544626, /* 76201 (1647) [ 0,  0, -1,  1,  0,  0,  0, -1,  0] [ 0,  6,  6]  1 */
      127456, /* 76202 (1647) [ 0,  0, -1,  1,  0,  0,  0,  1,  0] [ 0,  0,  6]  1 */
       16484, /* 76203 (1648) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    43404319, /* 76204 (1648) [-1,  0,  0,  0,  0,  1,  0, -1,  0] [ 3,  3,  9] -1 */
      134418, /* 76205 (1648) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  6]  1 */
    27701877, /* 76206 (1648) [ 0, -1,  0,  1,  0,  0,  0,  0, -1] [ 9,  9,  3]  1 */
    44711877, /* 76207 (1648) [ 0,  1,  0, -1,  0,  0,  0,  0, -1] [ 3,  9,  3] -1 */
    61716703, /* 76208 (1648) [ 0,  0,  1,  0, -1,  0,  1,  0,  0] [ 9,  9,  3] -1 */
        3198, /* 76209 (1648) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
     1420376, /* 76210 (1648) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  0]  1 */
     1429222, /* 76211 (1648) [ 0,  1,  0,  0,  0,  1, -1,  0,  0] [ 0,  6,  0]  1 */
    51034658, /* 76212 (1648) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  0] -1 */
    44828833, /* 76213 (1648) [ 0,  0,  1,  0,  1,  0, -1,  0,  0] [ 3,  9,  9] -1 */
    60415025, /* 76214 (1648) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 9,  3,  9] -1 */
    60418911, /* 76215 (1648) [ 0,  1,  0, -1,  0,  0,  0,  0, -1] [ 9,  3,  9] -1 */
     1433658, /* 76216 (1648) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  0]  1 */
    34133684, /* 76217 (1648) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    61831713, /* 76218 (1648) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 9,  9,  9] -1 */
    34023040, /* 76219 (1648) [ 0,  0,  1,  1,  0,  0,  0,  1,  0] [ 0,  0,  0] -1 */
    43410199, /* 76220 (1648) [ 0,  0, -1,  0,  1,  0, -1,  0,  0] [ 3,  3,  9] -1 */
    18557870, /* 76221 (1648) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
     9405169, /* 76222 (1648) [ 1,  0,  0,  0,  0, -1,  0,  1,  0] [ 3,  3,  9]  1 */
    52561228, /* 76223 (1648) [ 0, -1,  0,  0,  0, -1, -1,  0,  0] [ 6,  6,  6] -1 */
     9399289, /* 76224 (1648) [ 0,  0,  1,  0, -1,  0,  1,  0,  0] [ 3,  3,  9]  1 */
    34024288, /* 76225 (1648) [ 0,  1,  0,  0,  0,  1,  1,  0,  0] [ 0,  0,  0] -1 */
    10691179, /* 76226 (1648) [-1,  0,  0,  0,  0,  1,  0,  1,  0] [ 3,  9,  3]  1 */
    27821101, /* 76227 (1648) [ 0,  0, -1,  0, -1,  0, -1,  0,  0] [ 9,  9,  9]  1 */
    17135020, /* 76228 (1648) [ 0,  0,  1,  1,  0,  0,  0, -1,  0] [ 6,  0,  6]  1 */
    10697071, /* 76229 (1648) [ 0,  0, -1,  0,  1,  0,  1,  0,  0] [ 3,  9,  3]  1 */
    43408911, /* 76230 (1648) [ 0, -1,  0,  1,  0,  0,  0,  0, -1] [ 3,  3,  9] -1 */
    26411275, /* 76231 (1648) [ 1,  0,  0,  0,  0, -1,  0, -1,  0] [ 9,  3,  9]  1 */
    27828511, /* 76232 (1648) [ 1,  0,  0,  0,  0,  1,  0,  1,  0] [ 9,  9,  9]  1 */
     9282965, /* 76233 (1648) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 3,  3,  3]  1 */
    35563820, /* 76234 (1648) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
    43291939, /* 76235 (1648) [ 0,  0, -1,  0, -1,  0, -1,  0,  0] [ 3,  3,  3] -1 */
      130090, /* 76236 (1648) [ 0,  1,  0,  0,  0, -1, -1,  0,  0] [ 0,  0,  6]  1 */
    26398213, /* 76237 (1648) [-1,  0,  0,  0,  0,  1,  0,  1,  0] [ 9,  3,  9]  1 */
     1424812, /* 76238 (1648) [ 0, -1,  0,  0,  0, -1,  1,  0,  0] [ 0,  6,  0]  1 */
    61717991, /* 76239 (1648) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 9,  9,  3] -1 */
    35555170, /* 76240 (1648) [ 0, -1,  0,  0,  0,  1, -1,  0,  0] [ 0,  6,  6] -1 */
    18433612, /* 76241 (1648) [ 0,  0,  1, -1,  0,  0,  0, -1,  0] [ 6,  6,  0]  1 */
    18552202, /* 76242 (1648) [ 0,  0,  1,  1,  0,  0,  0,  1,  0] [ 6,  6,  6]  1 */
     9281353, /* 76243 (1648) [ 0,  0,  1,  0,  1,  0,  1,  0,  0] [ 3,  3,  3]  1 */
    52443202, /* 76244 (1648) [ 0, -1,  0,  0,  0,  1,  1,  0,  0] [ 6,  6,  0] -1 */
    17131846, /* 76245 (1648) [ 0, -1,  0,  0,  0, -1,  1,  0,  0] [ 6,  0,  6]  1 */
      128422, /* 76246 (1648) [ 0,  0,  1, -1,  0,  0,  0, -1,  0] [ 0,  0,  6]  1 */
    43290327, /* 76247 (1648) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 3,  3,  3] -1 */
     1538634, /* 76248 (1648) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
    26284217, /* 76249 (1648) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 9,  3,  3]  1 */
    34138012, /* 76250 (1648) [ 0, -1,  0,  0,  0,  1,  1,  0,  0] [ 0,  0,  6] -1 */
    60298069, /* 76251 (1648) [ 0,  0, -1,  0, -1,  0,  1,  0,  0] [ 9,  3,  3] -1 */
    61827553, /* 76252 (1648) [-1,  0,  0,  0,  0, -1,  0, -1,  0] [ 9,  9,  9] -1 */
    61709509, /* 76253 (1648) [-1,  0,  0,  0,  0,  1,  0, -1,  0] [ 9,  9,  3] -1 */
    51027688, /* 76254 (1648) [ 0,  0, -1,  1,  0,  0,  0, -1,  0] [ 6,  0,  0] -1 */
    18550252, /* 76255 (1648) [ 0,  0, -1, -1,  0,  0,  0, -1,  0] [ 6,  6,  6]  1 */
     9400577, /* 76256 (1648) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 3,  3,  9]  1 */
    61722583, /* 76257 (1648) [ 1,  0,  0,  0,  0, -1,  0,  1,  0] [ 9,  9,  3] -1 */
        8866, /* 76258 (1648) [ 0,  0, -1, -1,  0,  0,  0, -1,  0] [ 0,  0,  0]  1 */
    26280061, /* 76259 (1648) [-1,  0,  0,  0,  0, -1,  0,  1,  0] [ 9,  3,  3]  1 */
    10815007, /* 76260 (1648) [ 0,  0, -1,  0, -1,  0,  1,  0,  0] [ 3,  9,  9]  1 */
    44710573, /* 76261 (1648) [ 0,  0,  1,  0, -1,  0, -1,  0,  0] [ 3,  9,  3] -1 */
    52438874, /* 76262 (1648) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
     9392095, /* 76263 (1648) [-1,  0,  0,  0,  0,  1,  0, -1,  0] [ 3,  3,  9]  1 */
    61715389, /* 76264 (1648) [ 0,  0, -1,  0,  1,  0, -1,  0,  0] [ 9,  9,  3] -1 */
    43286167, /* 76265 (1648) [-1,  0,  0,  0,  0, -1,  0, -1,  0] [ 3,  3,  3] -1 */
    35556850, /* 76266 (1648) [ 0,  0, -1,  1,  0,  0,  0, -1,  0] [ 0,  6,  6] -1 */
    34139680, /* 76267 (1648) [ 0,  0, -1,  1,  0,  0,  0,  1,  0] [ 0,  0,  6] -1 */
    10699653, /* 76268 (1648) [ 0,  1,  0, -1,  0,  0,  0,  0, -1] [ 3,  9,  3]  1 */
    34028708, /* 76269 (1648) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0] -1 */
    27822739, /* 76270 (1648) [ 0,  0,  1,  0,  1,  0,  1,  0,  0] [ 9,  9,  9]  1 */
    17140692, /* 76271 (1648) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6]  1 */
    17016442, /* 76272 (1648) [ 0,  0,  1, -1,  0,  0,  0,  1,  0] [ 6,  0,  0]  1 */
    17009472, /* 76273 (1648) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  0]  1 */
    10816609, /* 76274 (1648) [ 0,  0,  1,  0,  1,  0, -1,  0,  0] [ 3,  9,  9]  1 */
    17018122, /* 76275 (1648) [ 0,  1,  0,  0,  0, -1,  1,  0,  0] [ 6,  0,  0]  1 */
    10695767, /* 76276 (1648) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 3,  9,  3]  1 */
    34019842, /* 76277 (1648) [ 0, -1,  0,  0,  0, -1, -1,  0,  0] [ 0,  0,  0] -1 */
    34146642, /* 76278 (1648) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  6] -1 */
    26404105, /* 76279 (1648) [ 0,  0, -1,  0,  1,  0,  1,  0,  0] [ 9,  3,  9]  1 */
    18435280, /* 76280 (1648) [ 0,  1,  0,  0,  0, -1, -1,  0,  0] [ 6,  6,  0]  1 */
    44825603, /* 76281 (1648) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 3,  9,  9] -1 */
    35559508, /* 76282 (1648) [ 0,  1,  0,  0,  0, -1,  1,  0,  0] [ 0,  6,  6] -1 */
    52451832, /* 76283 (1648) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0] -1 */
    52556808, /* 76284 (1648) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    61714101, /* 76285 (1648) [ 0, -1,  0,  1,  0,  0,  0,  0, -1] [ 9,  9,  3] -1 */
    27819489, /* 76286 (1648) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 9,  9,  9]  1 */
       10816, /* 76287 (1648) [ 0,  0,  1,  1,  0,  0,  0,  1,  0] [ 0,  0,  0]  1 */
    34015422, /* 76288 (1648) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    17013784, /* 76289 (1648) [ 0, -1,  0,  0,  0,  1, -1,  0,  0] [ 6,  0,  0]  1 */
     9397975, /* 76290 (1648) [ 0,  0, -1,  0,  1,  0, -1,  0,  0] [ 3,  3,  9]  1 */
    60301299, /* 76291 (1648) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 9,  3,  3] -1 */
    44821447, /* 76292 (1648) [-1,  0,  0,  0,  0, -1,  0,  1,  0] [ 3,  9,  9] -1 */
    51148480, /* 76293 (1648) [ 0,  1,  0,  0,  0,  1, -1,  0,  0] [ 6,  0,  6] -1 */
    18553450, /* 76294 (1648) [ 0,  1,  0,  0,  0,  1,  1,  0,  0] [ 6,  6,  6]  1 */
    26293231, /* 76295 (1648) [ 1,  0,  0,  0,  0,  1,  0, -1,  0] [ 9,  3,  3]  1 */
    51139634, /* 76296 (1648) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6] -1 */
       12064, /* 76297 (1648) [ 0,  1,  0,  0,  0,  1,  1,  0,  0] [ 0,  0,  0]  1 */
     1426048, /* 76298 (1648) [ 0,  0, -1, -1,  0,  0,  0,  1,  0] [ 0,  6,  0]  1 */
    10818237, /* 76299 (1648) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 3,  9,  9]  1 */
     1545604, /* 76300 (1648) [ 0,  0,  1, -1,  0,  0,  0,  1,  0] [ 0,  6,  6]  1 */
     9287125, /* 76301 (1648) [ 1,  0,  0,  0,  0,  1,  0,  1,  0] [ 3,  3,  3]  1 */
    61836575, /* 76302 (1648) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 9,  9,  9] -1 */
     1542946, /* 76303 (1648) [ 0, -1,  0,  0,  0,  1, -1,  0,  0] [ 0,  6,  6]  1 */
    17133082, /* 76304 (1648) [ 0,  0, -1, -1,  0,  0,  0,  1,  0] [ 6,  0,  6]  1 */
    43417393, /* 76305 (1648) [ 1,  0,  0,  0,  0, -1,  0,  1,  0] [ 3,  3,  9] -1 */
    44716465, /* 76306 (1648) [ 1,  0,  0,  0,  0, -1,  0, -1,  0] [ 3,  9,  3] -1 */
    60299671, /* 76307 (1648) [ 0,  0,  1,  0,  1,  0, -1,  0,  0] [ 9,  3,  3] -1 */
     9278103, /* 76308 (1648) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 3,  3,  3]  1 */
    44709295, /* 76309 (1648) [ 0,  0, -1,  0,  1,  0,  1,  0,  0] [ 3,  9,  3] -1 */
    35440210, /* 76310 (1648) [ 0,  0,  1,  1,  0,  0,  0, -1,  0] [ 0,  6,  0] -1 */
      125788, /* 76311 (1648) [ 0, -1,  0,  0,  0,  1,  1,  0,  0] [ 0,  0,  6]  1 */
    52444870, /* 76312 (1648) [ 0,  0, -1,  1,  0,  0,  0,  1,  0] [ 6,  6,  0] -1 */
    60417607, /* 76313 (1648) [ 0,  0,  1,  0, -1,  0, -1,  0,  0] [ 9,  3,  9] -1 */
    60423499, /* 76314 (1648) [ 1,  0,  0,  0,  0, -1,  0, -1,  0] [ 9,  3,  9] -1 */
    43295189, /* 76315 (1648) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 3,  3,  3] -1 */
    26285845, /* 76316 (1648) [ 0,  0, -1,  0, -1,  0,  1,  0,  0] [ 9,  3,  3]  1 */
    27815329, /* 76317 (1648) [-1,  0,  0,  0,  0, -1,  0, -1,  0] [ 9,  9,  9]  1 */
    44834617, /* 76318 (1648) [ 1,  0,  0,  0,  0,  1,  0, -1,  0] [ 3,  9,  9] -1 */
    17015464, /* 76319 (1648) [ 0,  0, -1,  1,  0,  0,  0, -1,  0] [ 6,  0,  0]  1 */
    35437036, /* 76320 (1648) [ 0, -1,  0,  0,  0, -1,  1,  0,  0] [ 0,  6,  0] -1 */
    27697285, /* 76321 (1648) [-1,  0,  0,  0,  0,  1,  0, -1,  0] [ 9,  9,  3]  1 */
    27704479, /* 76322 (1648) [ 0,  0,  1,  0, -1,  0,  1,  0,  0] [ 9,  9,  3]  1 */
    34140646, /* 76323 (1648) [ 0,  0,  1, -1,  0,  0,  0, -1,  0] [ 0,  0,  6] -1 */
    17022434, /* 76324 (1648) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  0]  1 */
    10698349, /* 76325 (1648) [ 0,  0,  1,  0, -1,  0, -1,  0,  0] [ 3,  9,  3]  1 */
    18426650, /* 76326 (1648) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
    26402801, /* 76327 (1648) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 9,  3,  9]  1 */
    26406687, /* 76328 (1648) [ 0,  1,  0, -1,  0,  0,  0,  0, -1] [ 9,  3,  9]  1 */
      121460, /* 76329 (1648) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6]  1 */
    35441446, /* 76330 (1648) [ 0,  1,  0,  0,  0,  1, -1,  0,  0] [ 0,  6,  0] -1 */
    52562476, /* 76331 (1648) [ 0,  0, -1, -1,  0,  0,  0, -1,  0] [ 6,  6,  6] -1 */
    35432600, /* 76332 (1648) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  0] -1 */
    60292285, /* 76333 (1648) [-1,  0,  0,  0,  0, -1,  0,  1,  0] [ 9,  3,  3] -1 */
    44827231, /* 76334 (1648) [ 0,  0, -1,  0, -1,  0,  1,  0,  0] [ 3,  9,  9] -1 */
    18549004, /* 76335 (1648) [ 0, -1,  0,  0,  0, -1, -1,  0,  0] [ 6,  6,  6]  1 */
        7618, /* 76336 (1648) [ 0, -1,  0,  0,  0, -1, -1,  0,  0] [ 0,  0,  0]  1 */
    10813379, /* 76337 (1648) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 3,  9,  9]  1 */
    35445882, /* 76338 (1648) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  0] -1 */
     1547284, /* 76339 (1648) [ 0,  1,  0,  0,  0, -1,  1,  0,  0] [ 0,  6,  6]  1 */
    18439608, /* 76340 (1648) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
    18544584, /* 76341 (1648) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
     9396687, /* 76342 (1648) [ 0, -1,  0,  1,  0,  0,  0,  0, -1] [ 3,  3,  9]  1 */
    10809223, /* 76343 (1648) [-1,  0,  0,  0,  0, -1,  0,  1,  0] [ 3,  9,  9]  1 */
     1551596, /* 76344 (1648) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
    26289075, /* 76345 (1648) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 9,  3,  3]  1 */
     9279715, /* 76346 (1648) [ 0,  0, -1,  0, -1,  0, -1,  0,  0] [ 3,  3,  3]  1 */
    61834963, /* 76347 (1648) [ 0,  0,  1,  0,  1,  0,  1,  0,  0] [ 9,  9,  9] -1 */
    27705767, /* 76348 (1648) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 9,  9,  3]  1 */
    17136256, /* 76349 (1648) [ 0,  1,  0,  0,  0,  1, -1,  0,  0] [ 6,  0,  6]  1 */
    17127410, /* 76350 (1648) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
    51152916, /* 76351 (1648) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6] -1 */
    51028666, /* 76352 (1648) [ 0,  0,  1, -1,  0,  0,  0,  1,  0] [ 6,  0,  0] -1 */
    51021696, /* 76353 (1648) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  0] -1 */
    52570094, /* 76354 (1648) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6] -1 */
    51030346, /* 76355 (1648) [ 0,  1,  0,  0,  0, -1,  1,  0,  0] [ 6,  0,  0] -1 */
    18430978, /* 76356 (1648) [ 0, -1,  0,  0,  0,  1,  1,  0,  0] [ 6,  6,  0]  1 */
    44707991, /* 76357 (1648) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 3,  9,  3] -1 */
    43411513, /* 76358 (1648) [ 0,  0,  1,  0, -1,  0,  1,  0,  0] [ 3,  3,  9] -1 */
    44703403, /* 76359 (1648) [-1,  0,  0,  0,  0,  1,  0,  1,  0] [ 3,  9,  3] -1 */
    61833325, /* 76360 (1648) [ 0,  0, -1,  0, -1,  0, -1,  0,  0] [ 9,  9,  9] -1 */
    52447504, /* 76361 (1648) [ 0,  1,  0,  0,  0, -1, -1,  0,  0] [ 6,  6,  0] -1 */
    60416329, /* 76362 (1648) [ 0,  0, -1,  0,  1,  0,  1,  0,  0] [ 9,  3,  9] -1 */
    51147244, /* 76363 (1648) [ 0,  0,  1,  1,  0,  0,  0, -1,  0] [ 6,  0,  6] -1 */
    27824351, /* 76364 (1648) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 9,  9,  9]  1 */
    61840735, /* 76365 (1648) [ 1,  0,  0,  0,  0,  1,  0,  1,  0] [ 9,  9,  9] -1 */
    51026008, /* 76366 (1648) [ 0, -1,  0,  0,  0,  1, -1,  0,  0] [ 6,  0,  0] -1 */
    34142314, /* 76367 (1648) [ 0,  1,  0,  0,  0, -1, -1,  0,  0] [ 0,  0,  6] -1 */
    60410437, /* 76368 (1648) [-1,  0,  0,  0,  0,  1,  0,  1,  0] [ 9,  3,  9] -1 */
    52565674, /* 76369 (1648) [ 0,  1,  0,  0,  0,  1,  1,  0,  0] [ 6,  6,  6] -1 */
    60305455, /* 76370 (1648) [ 1,  0,  0,  0,  0,  1,  0, -1,  0] [ 9,  3,  3] -1 */
    10704241, /* 76371 (1648) [ 1,  0,  0,  0,  0, -1,  0, -1,  0] [ 3,  9,  3]  1 */
    52445836, /* 76372 (1648) [ 0,  0,  1, -1,  0,  0,  0, -1,  0] [ 6,  6,  0] -1 */
    26287447, /* 76373 (1648) [ 0,  0,  1,  0,  1,  0, -1,  0,  0] [ 9,  3,  3]  1 */
    52564426, /* 76374 (1648) [ 0,  0,  1,  1,  0,  0,  0,  1,  0] [ 6,  6,  6] -1 */
    43293577, /* 76375 (1648) [ 0,  0,  1,  0,  1,  0,  1,  0,  0] [ 3,  3,  3] -1 */
    35438272, /* 76376 (1648) [ 0,  0, -1, -1,  0,  0,  0,  1,  0] [ 0,  6,  0] -1 */
    27710359, /* 76377 (1648) [ 1,  0,  0,  0,  0, -1,  0,  1,  0] [ 9,  9,  3]  1 */
     1427986, /* 76378 (1648) [ 0,  0,  1,  1,  0,  0,  0, -1,  0] [ 0,  6,  0]  1 */
    51144070, /* 76379 (1648) [ 0, -1,  0,  0,  0, -1,  1,  0,  0] [ 6,  0,  6] -1 */
    44830461, /* 76380 (1648) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 3,  9,  9] -1 */
    18432646, /* 76381 (1648) [ 0,  0, -1,  1,  0,  0,  0,  1,  0] [ 6,  6,  0]  1 */
    26405383, /* 76382 (1648) [ 0,  0,  1,  0, -1,  0, -1,  0,  0] [ 9,  3,  9]  1 */
    35557828, /* 76383 (1648) [ 0,  0,  1, -1,  0,  0,  0,  1,  0] [ 0,  6,  6] -1 */
    10822393, /* 76384 (1648) [ 1,  0,  0,  0,  0,  1,  0, -1,  0] [ 3,  9,  9]  1 */
    35550858, /* 76385 (1648) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6] -1 */
    60296441, /* 76386 (1648) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 9,  3,  3] -1 */
    43299349, /* 76387 (1648) [ 1,  0,  0,  0,  0,  1,  0,  1,  0] [ 3,  3,  3] -1 */
    27703165, /* 76388 (1648) [ 0,  0, -1,  0,  1,  0, -1,  0,  0] [ 9,  9,  3]  1 */
     9273943, /* 76389 (1648) [-1,  0,  0,  0,  0, -1,  0, -1,  0] [ 3,  3,  3]  1 */
    51145306, /* 76390 (1648) [ 0,  0, -1, -1,  0,  0,  0,  1,  0] [ 6,  0,  6] -1 */
     1544626, /* 76391 (1648) [ 0,  0, -1,  1,  0,  0,  0, -1,  0] [ 0,  6,  6]  1 */
      127456, /* 76392 (1648) [ 0,  0, -1,  1,  0,  0,  0,  1,  0] [ 0,  0,  6]  1 */
    43412801, /* 76393 (1648) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 3,  3,  9] -1 */
    34021090, /* 76394 (1648) [ 0,  0, -1, -1,  0,  0,  0, -1,  0] [ 0,  0,  0] -1 */
       16484, /* 76395 (1649) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
      134418, /* 76396 (1649) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  6]  1 */
    27701877, /* 76397 (1649) [ 0, -1,  0,  1,  0,  0,  0,  0, -1] [ 9,  9,  3]  1 */
    61716703, /* 76398 (1649) [ 0,  0,  1,  0, -1,  0,  1,  0,  0] [ 9,  9,  3] -1 */
     1420376, /* 76399 (1649) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  0]  1 */
    51034658, /* 76400 (1649) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  0] -1 */
    44828833, /* 76401 (1649) [ 0,  0,  1,  0,  1,  0, -1,  0,  0] [ 3,  9,  9] -1 */
    60415025, /* 76402 (1649) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 9,  3,  9] -1 */
    34133684, /* 76403 (1649) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    61831713, /* 76404 (1649) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 9,  9,  9] -1 */
    18557870, /* 76405 (1649) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    52561228, /* 76406 (1649) [ 0, -1,  0,  0,  0, -1, -1,  0,  0] [ 6,  6,  6] -1 */
    26411275, /* 76407 (1649) [ 1,  0,  0,  0,  0, -1,  0, -1,  0] [ 9,  3,  9]  1 */
    27828511, /* 76408 (1649) [ 1,  0,  0,  0,  0,  1,  0,  1,  0] [ 9,  9,  9]  1 */
     9282965, /* 76409 (1649) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 3,  3,  3]  1 */
    35563820, /* 76410 (1649) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
    43291939, /* 76411 (1649) [ 0,  0, -1,  0, -1,  0, -1,  0,  0] [ 3,  3,  3] -1 */
      130090, /* 76412 (1649) [ 0,  1,  0,  0,  0, -1, -1,  0,  0] [ 0,  0,  6]  1 */
     1424812, /* 76413 (1649) [ 0, -1,  0,  0,  0, -1,  1,  0,  0] [ 0,  6,  0]  1 */
    61717991, /* 76414 (1649) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 9,  9,  3] -1 */
    18433612, /* 76415 (1649) [ 0,  0,  1, -1,  0,  0,  0, -1,  0] [ 6,  6,  0]  1 */
    18552202, /* 76416 (1649) [ 0,  0,  1,  1,  0,  0,  0,  1,  0] [ 6,  6,  6]  1 */
     9281353, /* 76417 (1649) [ 0,  0,  1,  0,  1,  0,  1,  0,  0] [ 3,  3,  3]  1 */
    52443202, /* 76418 (1649) [ 0, -1,  0,  0,  0,  1,  1,  0,  0] [ 6,  6,  0] -1 */
    17131846, /* 76419 (1649) [ 0, -1,  0,  0,  0, -1,  1,  0,  0] [ 6,  0,  6]  1 */
      128422, /* 76420 (1649) [ 0,  0,  1, -1,  0,  0,  0, -1,  0] [ 0,  0,  6]  1 */
    43290327, /* 76421 (1649) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 3,  3,  3] -1 */
     1538634, /* 76422 (1649) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
    26284217, /* 76423 (1649) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 9,  3,  3]  1 */
    34138012, /* 76424 (1649) [ 0, -1,  0,  0,  0,  1,  1,  0,  0] [ 0,  0,  6] -1 */
    61827553, /* 76425 (1649) [-1,  0,  0,  0,  0, -1,  0, -1,  0] [ 9,  9,  9] -1 */
    61722583, /* 76426 (1649) [ 1,  0,  0,  0,  0, -1,  0,  1,  0] [ 9,  9,  3] -1 */
    26280061, /* 76427 (1649) [-1,  0,  0,  0,  0, -1,  0,  1,  0] [ 9,  3,  3]  1 */
    10815007, /* 76428 (1649) [ 0,  0, -1,  0, -1,  0,  1,  0,  0] [ 3,  9,  9]  1 */
    52438874, /* 76429 (1649) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
     9392095, /* 76430 (1649) [-1,  0,  0,  0,  0,  1,  0, -1,  0] [ 3,  3,  9]  1 */
    43286167, /* 76431 (1649) [-1,  0,  0,  0,  0, -1,  0, -1,  0] [ 3,  3,  3] -1 */
    34139680, /* 76432 (1649) [ 0,  0, -1,  1,  0,  0,  0,  1,  0] [ 0,  0,  6] -1 */
    10699653, /* 76433 (1649) [ 0,  1,  0, -1,  0,  0,  0,  0, -1] [ 3,  9,  3]  1 */
    27822739, /* 76434 (1649) [ 0,  0,  1,  0,  1,  0,  1,  0,  0] [ 9,  9,  9]  1 */
    17009472, /* 76435 (1649) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  0]  1 */
    34019842, /* 76436 (1649) [ 0, -1,  0,  0,  0, -1, -1,  0,  0] [ 0,  0,  0] -1 */
    18435280, /* 76437 (1649) [ 0,  1,  0,  0,  0, -1, -1,  0,  0] [ 6,  6,  0]  1 */
    35559508, /* 76438 (1649) [ 0,  1,  0,  0,  0, -1,  1,  0,  0] [ 0,  6,  6] -1 */
    52556808, /* 76439 (1649) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
       10816, /* 76440 (1649) [ 0,  0,  1,  1,  0,  0,  0,  1,  0] [ 0,  0,  0]  1 */
    34015422, /* 76441 (1649) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    60301299, /* 76442 (1649) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 9,  3,  3] -1 */
     9397975, /* 76443 (1649) [ 0,  0, -1,  0,  1,  0, -1,  0,  0] [ 3,  3,  9]  1 */
    17013784, /* 76444 (1649) [ 0, -1,  0,  0,  0,  1, -1,  0,  0] [ 6,  0,  0]  1 */
    51148480, /* 76445 (1649) [ 0,  1,  0,  0,  0,  1, -1,  0,  0] [ 6,  0,  6] -1 */
    18553450, /* 76446 (1649) [ 0,  1,  0,  0,  0,  1,  1,  0,  0] [ 6,  6,  6]  1 */
       12064, /* 76447 (1649) [ 0,  1,  0,  0,  0,  1,  1,  0,  0] [ 0,  0,  0]  1 */
     1426048, /* 76448 (1649) [ 0,  0, -1, -1,  0,  0,  0,  1,  0] [ 0,  6,  0]  1 */
     9287125, /* 76449 (1649) [ 1,  0,  0,  0,  0,  1,  0,  1,  0] [ 3,  3,  3]  1 */
     1542946, /* 76450 (1649) [ 0, -1,  0,  0,  0,  1, -1,  0,  0] [ 0,  6,  6]  1 */
    17133082, /* 76451 (1649) [ 0,  0, -1, -1,  0,  0,  0,  1,  0] [ 6,  0,  6]  1 */
    43417393, /* 76452 (1649) [ 1,  0,  0,  0,  0, -1,  0,  1,  0] [ 3,  3,  9] -1 */
    60299671, /* 76453 (1649) [ 0,  0,  1,  0,  1,  0, -1,  0,  0] [ 9,  3,  3] -1 */
    44709295, /* 76454 (1649) [ 0,  0, -1,  0,  1,  0,  1,  0,  0] [ 3,  9,  3] -1 */
    35440210, /* 76455 (1649) [ 0,  0,  1,  1,  0,  0,  0, -1,  0] [ 0,  6,  0] -1 */
    52444870, /* 76456 (1649) [ 0,  0, -1,  1,  0,  0,  0,  1,  0] [ 6,  6,  0] -1 */
    44834617, /* 76457 (1649) [ 1,  0,  0,  0,  0,  1,  0, -1,  0] [ 3,  9,  9] -1 */
    26285845, /* 76458 (1649) [ 0,  0, -1,  0, -1,  0,  1,  0,  0] [ 9,  3,  3]  1 */
    27697285, /* 76459 (1649) [-1,  0,  0,  0,  0,  1,  0, -1,  0] [ 9,  9,  3]  1 */
    17015464, /* 76460 (1649) [ 0,  0, -1,  1,  0,  0,  0, -1,  0] [ 6,  0,  0]  1 */
    10698349, /* 76461 (1649) [ 0,  0,  1,  0, -1,  0, -1,  0,  0] [ 3,  9,  3]  1 */
    26406687, /* 76462 (1649) [ 0,  1,  0, -1,  0,  0,  0,  0, -1] [ 9,  3,  9]  1 */
    35441446, /* 76463 (1649) [ 0,  1,  0,  0,  0,  1, -1,  0,  0] [ 0,  6,  0] -1 */
    52562476, /* 76464 (1649) [ 0,  0, -1, -1,  0,  0,  0, -1,  0] [ 6,  6,  6] -1 */
    10813379, /* 76465 (1649) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 3,  9,  9]  1 */
    35445882, /* 76466 (1649) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  0] -1 */
    18439608, /* 76467 (1649) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
     9396687, /* 76468 (1649) [ 0, -1,  0,  1,  0,  0,  0,  0, -1] [ 3,  3,  9]  1 */
    10809223, /* 76469 (1649) [-1,  0,  0,  0,  0, -1,  0,  1,  0] [ 3,  9,  9]  1 */
    17127410, /* 76470 (1649) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
    51152916, /* 76471 (1649) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6] -1 */
    51028666, /* 76472 (1649) [ 0,  0,  1, -1,  0,  0,  0,  1,  0] [ 6,  0,  0] -1 */
    51030346, /* 76473 (1649) [ 0,  1,  0,  0,  0, -1,  1,  0,  0] [ 6,  0,  0] -1 */
    44707991, /* 76474 (1649) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 3,  9,  3] -1 */
    43411513, /* 76475 (1649) [ 0,  0,  1,  0, -1,  0,  1,  0,  0] [ 3,  3,  9] -1 */
    44703403, /* 76476 (1649) [-1,  0,  0,  0,  0,  1,  0,  1,  0] [ 3,  9,  3] -1 */
    61833325, /* 76477 (1649) [ 0,  0, -1,  0, -1,  0, -1,  0,  0] [ 9,  9,  9] -1 */
    60416329, /* 76478 (1649) [ 0,  0, -1,  0,  1,  0,  1,  0,  0] [ 9,  3,  9] -1 */
    51147244, /* 76479 (1649) [ 0,  0,  1,  1,  0,  0,  0, -1,  0] [ 6,  0,  6] -1 */
    27824351, /* 76480 (1649) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 9,  9,  9]  1 */
    60410437, /* 76481 (1649) [-1,  0,  0,  0,  0,  1,  0,  1,  0] [ 9,  3,  9] -1 */
    60305455, /* 76482 (1649) [ 1,  0,  0,  0,  0,  1,  0, -1,  0] [ 9,  3,  3] -1 */
    10704241, /* 76483 (1649) [ 1,  0,  0,  0,  0, -1,  0, -1,  0] [ 3,  9,  3]  1 */
    44830461, /* 76484 (1649) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 3,  9,  9] -1 */
    26405383, /* 76485 (1649) [ 0,  0,  1,  0, -1,  0, -1,  0,  0] [ 9,  3,  9]  1 */
    35557828, /* 76486 (1649) [ 0,  0,  1, -1,  0,  0,  0,  1,  0] [ 0,  6,  6] -1 */
    27703165, /* 76487 (1649) [ 0,  0, -1,  0,  1,  0, -1,  0,  0] [ 9,  9,  3]  1 */
     1544626, /* 76488 (1649) [ 0,  0, -1,  1,  0,  0,  0, -1,  0] [ 0,  6,  6]  1 */
    43412801, /* 76489 (1649) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 3,  3,  9] -1 */
    34021090, /* 76490 (1649) [ 0,  0, -1, -1,  0,  0,  0, -1,  0] [ 0,  0,  0] -1 */
       16484, /* 76491 (1650) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    43404319, /* 76492 (1650) [-1,  0,  0,  0,  0,  1,  0, -1,  0] [ 3,  3,  9] -1 */
      134418, /* 76493 (1650) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  6]  1 */
    44711877, /* 76494 (1650) [ 0,  1,  0, -1,  0,  0,  0,  0, -1] [ 3,  9,  3] -1 */
    61716703, /* 76495 (1650) [ 0,  0,  1,  0, -1,  0,  1,  0,  0] [ 9,  9,  3] -1 */
        3198, /* 76496 (1650) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0]  1 */
     1420376, /* 76497 (1650) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  0]  1 */
     1429222, /* 76498 (1650) [ 0,  1,  0,  0,  0,  1, -1,  0,  0] [ 0,  6,  0]  1 */
    44828833, /* 76499 (1650) [ 0,  0,  1,  0,  1,  0, -1,  0,  0] [ 3,  9,  9] -1 */
    60415025, /* 76500 (1650) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 9,  3,  9] -1 */
    60418911, /* 76501 (1650) [ 0,  1,  0, -1,  0,  0,  0,  0, -1] [ 9,  3,  9] -1 */
     1433658, /* 76502 (1650) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  0]  1 */
    61831713, /* 76503 (1650) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 9,  9,  9] -1 */
    43410199, /* 76504 (1650) [ 0,  0, -1,  0,  1,  0, -1,  0,  0] [ 3,  3,  9] -1 */
    18557870, /* 76505 (1650) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
    17135020, /* 76506 (1650) [ 0,  0,  1,  1,  0,  0,  0, -1,  0] [ 6,  0,  6]  1 */
    43408911, /* 76507 (1650) [ 0, -1,  0,  1,  0,  0,  0,  0, -1] [ 3,  3,  9] -1 */
    43291939, /* 76508 (1650) [ 0,  0, -1,  0, -1,  0, -1,  0,  0] [ 3,  3,  3] -1 */
      130090, /* 76509 (1650) [ 0,  1,  0,  0,  0, -1, -1,  0,  0] [ 0,  0,  6]  1 */
     1424812, /* 76510 (1650) [ 0, -1,  0,  0,  0, -1,  1,  0,  0] [ 0,  6,  0]  1 */
    61717991, /* 76511 (1650) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 9,  9,  3] -1 */
    18433612, /* 76512 (1650) [ 0,  0,  1, -1,  0,  0,  0, -1,  0] [ 6,  6,  0]  1 */
    18552202, /* 76513 (1650) [ 0,  0,  1,  1,  0,  0,  0,  1,  0] [ 6,  6,  6]  1 */
    17131846, /* 76514 (1650) [ 0, -1,  0,  0,  0, -1,  1,  0,  0] [ 6,  0,  6]  1 */
      128422, /* 76515 (1650) [ 0,  0,  1, -1,  0,  0,  0, -1,  0] [ 0,  0,  6]  1 */
    43290327, /* 76516 (1650) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 3,  3,  3] -1 */
     1538634, /* 76517 (1650) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
    60298069, /* 76518 (1650) [ 0,  0, -1,  0, -1,  0,  1,  0,  0] [ 9,  3,  3] -1 */
    61827553, /* 76519 (1650) [-1,  0,  0,  0,  0, -1,  0, -1,  0] [ 9,  9,  9] -1 */
    61709509, /* 76520 (1650) [-1,  0,  0,  0,  0,  1,  0, -1,  0] [ 9,  9,  3] -1 */
    18550252, /* 76521 (1650) [ 0,  0, -1, -1,  0,  0,  0, -1,  0] [ 6,  6,  6]  1 */
    61722583, /* 76522 (1650) [ 1,  0,  0,  0,  0, -1,  0,  1,  0] [ 9,  9,  3] -1 */
        8866, /* 76523 (1650) [ 0,  0, -1, -1,  0,  0,  0, -1,  0] [ 0,  0,  0]  1 */
    44710573, /* 76524 (1650) [ 0,  0,  1,  0, -1,  0, -1,  0,  0] [ 3,  9,  3] -1 */
    61715389, /* 76525 (1650) [ 0,  0, -1,  0,  1,  0, -1,  0,  0] [ 9,  9,  3] -1 */
    43286167, /* 76526 (1650) [-1,  0,  0,  0,  0, -1,  0, -1,  0] [ 3,  3,  3] -1 */
    17140692, /* 76527 (1650) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6]  1 */
    17016442, /* 76528 (1650) [ 0,  0,  1, -1,  0,  0,  0,  1,  0] [ 6,  0,  0]  1 */
    17009472, /* 76529 (1650) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  0]  1 */
    17018122, /* 76530 (1650) [ 0,  1,  0,  0,  0, -1,  1,  0,  0] [ 6,  0,  0]  1 */
    18435280, /* 76531 (1650) [ 0,  1,  0,  0,  0, -1, -1,  0,  0] [ 6,  6,  0]  1 */
    44825603, /* 76532 (1650) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 3,  9,  9] -1 */
    61714101, /* 76533 (1650) [ 0, -1,  0,  1,  0,  0,  0,  0, -1] [ 9,  9,  3] -1 */
    44821447, /* 76534 (1650) [-1,  0,  0,  0,  0, -1,  0,  1,  0] [ 3,  9,  9] -1 */
       10816, /* 76535 (1650) [ 0,  0,  1,  1,  0,  0,  0,  1,  0] [ 0,  0,  0]  1 */
    17013784, /* 76536 (1650) [ 0, -1,  0,  0,  0,  1, -1,  0,  0] [ 6,  0,  0]  1 */
    60301299, /* 76537 (1650) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 9,  3,  3] -1 */
    18553450, /* 76538 (1650) [ 0,  1,  0,  0,  0,  1,  1,  0,  0] [ 6,  6,  6]  1 */
       12064, /* 76539 (1650) [ 0,  1,  0,  0,  0,  1,  1,  0,  0] [ 0,  0,  0]  1 */
     1426048, /* 76540 (1650) [ 0,  0, -1, -1,  0,  0,  0,  1,  0] [ 0,  6,  0]  1 */
     1545604, /* 76541 (1650) [ 0,  0,  1, -1,  0,  0,  0,  1,  0] [ 0,  6,  6]  1 */
    61836575, /* 76542 (1650) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 9,  9,  9] -1 */
     1542946, /* 76543 (1650) [ 0, -1,  0,  0,  0,  1, -1,  0,  0] [ 0,  6,  6]  1 */
    17133082, /* 76544 (1650) [ 0,  0, -1, -1,  0,  0,  0,  1,  0] [ 6,  0,  6]  1 */
    43417393, /* 76545 (1650) [ 1,  0,  0,  0,  0, -1,  0,  1,  0] [ 3,  3,  9] -1 */
    44716465, /* 76546 (1650) [ 1,  0,  0,  0,  0, -1,  0, -1,  0] [ 3,  9,  3] -1 */
    60299671, /* 76547 (1650) [ 0,  0,  1,  0,  1,  0, -1,  0,  0] [ 9,  3,  3] -1 */
    44709295, /* 76548 (1650) [ 0,  0, -1,  0,  1,  0,  1,  0,  0] [ 3,  9,  3] -1 */
    60417607, /* 76549 (1650) [ 0,  0,  1,  0, -1,  0, -1,  0,  0] [ 9,  3,  9] -1 */
      125788, /* 76550 (1650) [ 0, -1,  0,  0,  0,  1,  1,  0,  0] [ 0,  0,  6]  1 */
    60423499, /* 76551 (1650) [ 1,  0,  0,  0,  0, -1,  0, -1,  0] [ 9,  3,  9] -1 */
    43295189, /* 76552 (1650) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 3,  3,  3] -1 */
    44834617, /* 76553 (1650) [ 1,  0,  0,  0,  0,  1,  0, -1,  0] [ 3,  9,  9] -1 */
    17015464, /* 76554 (1650) [ 0,  0, -1,  1,  0,  0,  0, -1,  0] [ 6,  0,  0]  1 */
    17022434, /* 76555 (1650) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  0]  1 */
    18426650, /* 76556 (1650) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0]  1 */
      121460, /* 76557 (1650) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6]  1 */
    60292285, /* 76558 (1650) [-1,  0,  0,  0,  0, -1,  0,  1,  0] [ 9,  3,  3] -1 */
    44827231, /* 76559 (1650) [ 0,  0, -1,  0, -1,  0,  1,  0,  0] [ 3,  9,  9] -1 */
    18549004, /* 76560 (1650) [ 0, -1,  0,  0,  0, -1, -1,  0,  0] [ 6,  6,  6]  1 */
        7618, /* 76561 (1650) [ 0, -1,  0,  0,  0, -1, -1,  0,  0] [ 0,  0,  0]  1 */
     1547284, /* 76562 (1650) [ 0,  1,  0,  0,  0, -1,  1,  0,  0] [ 0,  6,  6]  1 */
    18439608, /* 76563 (1650) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
    18544584, /* 76564 (1650) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6]  1 */
    61834963, /* 76565 (1650) [ 0,  0,  1,  0,  1,  0,  1,  0,  0] [ 9,  9,  9] -1 */
     1551596, /* 76566 (1650) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6]  1 */
    17136256, /* 76567 (1650) [ 0,  1,  0,  0,  0,  1, -1,  0,  0] [ 6,  0,  6]  1 */
    17127410, /* 76568 (1650) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
    18430978, /* 76569 (1650) [ 0, -1,  0,  0,  0,  1,  1,  0,  0] [ 6,  6,  0]  1 */
    44707991, /* 76570 (1650) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 3,  9,  3] -1 */
    43411513, /* 76571 (1650) [ 0,  0,  1,  0, -1,  0,  1,  0,  0] [ 3,  3,  9] -1 */
    44703403, /* 76572 (1650) [-1,  0,  0,  0,  0,  1,  0,  1,  0] [ 3,  9,  3] -1 */
    61833325, /* 76573 (1650) [ 0,  0, -1,  0, -1,  0, -1,  0,  0] [ 9,  9,  9] -1 */
    60416329, /* 76574 (1650) [ 0,  0, -1,  0,  1,  0,  1,  0,  0] [ 9,  3,  9] -1 */
    61840735, /* 76575 (1650) [ 1,  0,  0,  0,  0,  1,  0,  1,  0] [ 9,  9,  9] -1 */
    60410437, /* 76576 (1650) [-1,  0,  0,  0,  0,  1,  0,  1,  0] [ 9,  3,  9] -1 */
    60305455, /* 76577 (1650) [ 1,  0,  0,  0,  0,  1,  0, -1,  0] [ 9,  3,  3] -1 */
    43293577, /* 76578 (1650) [ 0,  0,  1,  0,  1,  0,  1,  0,  0] [ 3,  3,  3] -1 */
     1427986, /* 76579 (1650) [ 0,  0,  1,  1,  0,  0,  0, -1,  0] [ 0,  6,  0]  1 */
    44830461, /* 76580 (1650) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 3,  9,  9] -1 */
    18432646, /* 76581 (1650) [ 0,  0, -1,  1,  0,  0,  0,  1,  0] [ 6,  6,  0]  1 */
    60296441, /* 76582 (1650) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 9,  3,  3] -1 */
    43299349, /* 76583 (1650) [ 1,  0,  0,  0,  0,  1,  0,  1,  0] [ 3,  3,  3] -1 */
     1544626, /* 76584 (1650) [ 0,  0, -1,  1,  0,  0,  0, -1,  0] [ 0,  6,  6]  1 */
      127456, /* 76585 (1650) [ 0,  0, -1,  1,  0,  0,  0,  1,  0] [ 0,  0,  6]  1 */
    43412801, /* 76586 (1650) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 3,  3,  9] -1 */
       16484, /* 76587 (1651) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  0]  1 */
    43404319, /* 76588 (1651) [-1,  0,  0,  0,  0,  1,  0, -1,  0] [ 3,  3,  9] -1 */
      134418, /* 76589 (1651) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  6]  1 */
    44711877, /* 76590 (1651) [ 0,  1,  0, -1,  0,  0,  0,  0, -1] [ 3,  9,  3] -1 */
     1420376, /* 76591 (1651) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  0]  1 */
    51034658, /* 76592 (1651) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  0] -1 */
    60418911, /* 76593 (1651) [ 0,  1,  0, -1,  0,  0,  0,  0, -1] [ 9,  3,  9] -1 */
    34133684, /* 76594 (1651) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 0,  0,  6] -1 */
    43410199, /* 76595 (1651) [ 0,  0, -1,  0,  1,  0, -1,  0,  0] [ 3,  3,  9] -1 */
    18557870, /* 76596 (1651) [ 1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  6]  1 */
     9405169, /* 76597 (1651) [ 1,  0,  0,  0,  0, -1,  0,  1,  0] [ 3,  3,  9]  1 */
    52561228, /* 76598 (1651) [ 0, -1,  0,  0,  0, -1, -1,  0,  0] [ 6,  6,  6] -1 */
     9399289, /* 76599 (1651) [ 0,  0,  1,  0, -1,  0,  1,  0,  0] [ 3,  3,  9]  1 */
    10691179, /* 76600 (1651) [-1,  0,  0,  0,  0,  1,  0,  1,  0] [ 3,  9,  3]  1 */
    27821101, /* 76601 (1651) [ 0,  0, -1,  0, -1,  0, -1,  0,  0] [ 9,  9,  9]  1 */
    10697071, /* 76602 (1651) [ 0,  0, -1,  0,  1,  0,  1,  0,  0] [ 3,  9,  3]  1 */
    43408911, /* 76603 (1651) [ 0, -1,  0,  1,  0,  0,  0,  0, -1] [ 3,  3,  9] -1 */
    35563820, /* 76604 (1651) [ 1,  0,  0,  0, -1,  0,  0,  0,  1] [ 0,  6,  6] -1 */
      130090, /* 76605 (1651) [ 0,  1,  0,  0,  0, -1, -1,  0,  0] [ 0,  0,  6]  1 */
    26398213, /* 76606 (1651) [-1,  0,  0,  0,  0,  1,  0,  1,  0] [ 9,  3,  9]  1 */
     1424812, /* 76607 (1651) [ 0, -1,  0,  0,  0, -1,  1,  0,  0] [ 0,  6,  0]  1 */
    18433612, /* 76608 (1651) [ 0,  0,  1, -1,  0,  0,  0, -1,  0] [ 6,  6,  0]  1 */
    18552202, /* 76609 (1651) [ 0,  0,  1,  1,  0,  0,  0,  1,  0] [ 6,  6,  6]  1 */
    52443202, /* 76610 (1651) [ 0, -1,  0,  0,  0,  1,  1,  0,  0] [ 6,  6,  0] -1 */
    17131846, /* 76611 (1651) [ 0, -1,  0,  0,  0, -1,  1,  0,  0] [ 6,  0,  6]  1 */
      128422, /* 76612 (1651) [ 0,  0,  1, -1,  0,  0,  0, -1,  0] [ 0,  0,  6]  1 */
     1538634, /* 76613 (1651) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  6]  1 */
    34138012, /* 76614 (1651) [ 0, -1,  0,  0,  0,  1,  1,  0,  0] [ 0,  0,  6] -1 */
    60298069, /* 76615 (1651) [ 0,  0, -1,  0, -1,  0,  1,  0,  0] [ 9,  3,  3] -1 */
    61709509, /* 76616 (1651) [-1,  0,  0,  0,  0,  1,  0, -1,  0] [ 9,  9,  3] -1 */
     9400577, /* 76617 (1651) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 3,  3,  9]  1 */
    44710573, /* 76618 (1651) [ 0,  0,  1,  0, -1,  0, -1,  0,  0] [ 3,  9,  3] -1 */
    52438874, /* 76619 (1651) [-1,  0,  0,  0,  1,  0,  0,  0,  1] [ 6,  6,  0] -1 */
    61715389, /* 76620 (1651) [ 0,  0, -1,  0,  1,  0, -1,  0,  0] [ 9,  9,  3] -1 */
    34139680, /* 76621 (1651) [ 0,  0, -1,  1,  0,  0,  0,  1,  0] [ 0,  0,  6] -1 */
    17009472, /* 76622 (1651) [-1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  0]  1 */
    10816609, /* 76623 (1651) [ 0,  0,  1,  0,  1,  0, -1,  0,  0] [ 3,  9,  9]  1 */
    10695767, /* 76624 (1651) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 3,  9,  3]  1 */
    34019842, /* 76625 (1651) [ 0, -1,  0,  0,  0, -1, -1,  0,  0] [ 0,  0,  0] -1 */
    18435280, /* 76626 (1651) [ 0,  1,  0,  0,  0, -1, -1,  0,  0] [ 6,  6,  0]  1 */
    26404105, /* 76627 (1651) [ 0,  0, -1,  0,  1,  0,  1,  0,  0] [ 9,  3,  9]  1 */
    44825603, /* 76628 (1651) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 3,  9,  9] -1 */
    35559508, /* 76629 (1651) [ 0,  1,  0,  0,  0, -1,  1,  0,  0] [ 0,  6,  6] -1 */
    52556808, /* 76630 (1651) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  6] -1 */
    61714101, /* 76631 (1651) [ 0, -1,  0,  1,  0,  0,  0,  0, -1] [ 9,  9,  3] -1 */
    27819489, /* 76632 (1651) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 9,  9,  9]  1 */
       10816, /* 76633 (1651) [ 0,  0,  1,  1,  0,  0,  0,  1,  0] [ 0,  0,  0]  1 */
    34015422, /* 76634 (1651) [-1,  0,  0,  0, -1,  0,  0,  0, -1] [ 0,  0,  0] -1 */
    17013784, /* 76635 (1651) [ 0, -1,  0,  0,  0,  1, -1,  0,  0] [ 6,  0,  0]  1 */
    44821447, /* 76636 (1651) [-1,  0,  0,  0,  0, -1,  0,  1,  0] [ 3,  9,  9] -1 */
    51148480, /* 76637 (1651) [ 0,  1,  0,  0,  0,  1, -1,  0,  0] [ 6,  0,  6] -1 */
    18553450, /* 76638 (1651) [ 0,  1,  0,  0,  0,  1,  1,  0,  0] [ 6,  6,  6]  1 */
    26293231, /* 76639 (1651) [ 1,  0,  0,  0,  0,  1,  0, -1,  0] [ 9,  3,  3]  1 */
       12064, /* 76640 (1651) [ 0,  1,  0,  0,  0,  1,  1,  0,  0] [ 0,  0,  0]  1 */
     1426048, /* 76641 (1651) [ 0,  0, -1, -1,  0,  0,  0,  1,  0] [ 0,  6,  0]  1 */
    10818237, /* 76642 (1651) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 3,  9,  9]  1 */
    61836575, /* 76643 (1651) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 9,  9,  9] -1 */
     1542946, /* 76644 (1651) [ 0, -1,  0,  0,  0,  1, -1,  0,  0] [ 0,  6,  6]  1 */
    17133082, /* 76645 (1651) [ 0,  0, -1, -1,  0,  0,  0,  1,  0] [ 6,  0,  6]  1 */
    44716465, /* 76646 (1651) [ 1,  0,  0,  0,  0, -1,  0, -1,  0] [ 3,  9,  3] -1 */
     9278103, /* 76647 (1651) [ 0, -1,  0, -1,  0,  0,  0,  0, -1] [ 3,  3,  3]  1 */
    35440210, /* 76648 (1651) [ 0,  0,  1,  1,  0,  0,  0, -1,  0] [ 0,  6,  0] -1 */
    60417607, /* 76649 (1651) [ 0,  0,  1,  0, -1,  0, -1,  0,  0] [ 9,  3,  9] -1 */
    52444870, /* 76650 (1651) [ 0,  0, -1,  1,  0,  0,  0,  1,  0] [ 6,  6,  0] -1 */
    60423499, /* 76651 (1651) [ 1,  0,  0,  0,  0, -1,  0, -1,  0] [ 9,  3,  9] -1 */
    43295189, /* 76652 (1651) [ 0,  1,  0,  1,  0,  0,  0,  0,  1] [ 3,  3,  3] -1 */
    27815329, /* 76653 (1651) [-1,  0,  0,  0,  0, -1,  0, -1,  0] [ 9,  9,  9]  1 */
    17015464, /* 76654 (1651) [ 0,  0, -1,  1,  0,  0,  0, -1,  0] [ 6,  0,  0]  1 */
    27704479, /* 76655 (1651) [ 0,  0,  1,  0, -1,  0,  1,  0,  0] [ 9,  9,  3]  1 */
    26402801, /* 76656 (1651) [ 0, -1,  0,  1,  0,  0,  0,  0,  1] [ 9,  3,  9]  1 */
    35441446, /* 76657 (1651) [ 0,  1,  0,  0,  0,  1, -1,  0,  0] [ 0,  6,  0] -1 */
    52562476, /* 76658 (1651) [ 0,  0, -1, -1,  0,  0,  0, -1,  0] [ 6,  6,  6] -1 */
    60292285, /* 76659 (1651) [-1,  0,  0,  0,  0, -1,  0,  1,  0] [ 9,  3,  3] -1 */
    44827231, /* 76660 (1651) [ 0,  0, -1,  0, -1,  0,  1,  0,  0] [ 3,  9,  9] -1 */
    35445882, /* 76661 (1651) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 0,  6,  0] -1 */
    18439608, /* 76662 (1651) [ 1,  0,  0,  0, -1,  0,  0,  0, -1] [ 6,  6,  0]  1 */
    61834963, /* 76663 (1651) [ 0,  0,  1,  0,  1,  0,  1,  0,  0] [ 9,  9,  9] -1 */
    26289075, /* 76664 (1651) [ 0,  1,  0,  1,  0,  0,  0,  0, -1] [ 9,  3,  3]  1 */
     9279715, /* 76665 (1651) [ 0,  0, -1,  0, -1,  0, -1,  0,  0] [ 3,  3,  3]  1 */
    27705767, /* 76666 (1651) [ 0,  1,  0, -1,  0,  0,  0,  0,  1] [ 9,  9,  3]  1 */
    17127410, /* 76667 (1651) [-1,  0,  0,  0, -1,  0,  0,  0,  1] [ 6,  0,  6]  1 */
    51152916, /* 76668 (1651) [ 1,  0,  0,  0,  1,  0,  0,  0, -1] [ 6,  0,  6] -1 */
    51028666, /* 76669 (1651) [ 0,  0,  1, -1,  0,  0,  0,  1,  0] [ 6,  0,  0] -1 */
    51030346, /* 76670 (1651) [ 0,  1,  0,  0,  0, -1,  1,  0,  0] [ 6,  0,  0] -1 */
    51147244, /* 76671 (1651) [ 0,  0,  1,  1,  0,  0,  0, -1,  0] [ 6,  0,  6] -1 */
    61840735, /* 76672 (1651) [ 1,  0,  0,  0,  0,  1,  0,  1,  0] [ 9,  9,  9] -1 */
    26287447, /* 76673 (1651) [ 0,  0,  1,  0,  1,  0, -1,  0,  0] [ 9,  3,  3]  1 */
    43293577, /* 76674 (1651) [ 0,  0,  1,  0,  1,  0,  1,  0,  0] [ 3,  3,  3] -1 */
    27710359, /* 76675 (1651) [ 1,  0,  0,  0,  0, -1,  0,  1,  0] [ 9,  9,  3]  1 */
    35557828, /* 76676 (1651) [ 0,  0,  1, -1,  0,  0,  0,  1,  0] [ 0,  6,  6] -1 */
    10822393, /* 76677 (1651) [ 1,  0,  0,  0,  0,  1,  0, -1,  0] [ 3,  9,  9]  1 */
    60296441, /* 76678 (1651) [ 0, -1,  0, -1,  0,  0,  0,  0,  1] [ 9,  3,  3] -1 */
    43299349, /* 76679 (1651) [ 1,  0,  0,  0,  0,  1,  0,  1,  0] [ 3,  3,  3] -1 */
     9273943, /* 76680 (1651) [-1,  0,  0,  0,  0, -1,  0, -1,  0] [ 3,  3,  3]  1 */
     1544626, /* 76681 (1651) [ 0,  0, -1,  1,  0,  0,  0, -1,  0] [ 0,  6,  6]  1 */
    34021090, /* 76682 (1651) [ 0,  0, -1, -1,  0,  0,  0, -1,  0] [ 0,  0,  0] -1 */
};
/* clang-format on */

static void msgdb_get_magnetic_operation(int rot[3][3], double trans[3],
                                         int *timerev, const int op_number) {
    int enc;
    enc = magnetic_symmetry_operations[op_number];

    /* timerev=1 for anti operation, timerev=0 for ordinary operation */
    /* 34012224 = 3^9 * 12^3 */
    *timerev = enc / 34012224;
    spgdb_decode_symmetry(rot, trans, enc % 34012224);
}

static void msgdb_get_operation_index(int indices[2], const int uni_number,
                                      const int hall_number_offset) {
    /* hall_number_offset: offset from the first Hall number to a given one */
    indices[0] =
        magnetic_spacegroup_operation_index[uni_number][hall_number_offset][0];
    indices[1] =
        magnetic_spacegroup_operation_index[uni_number][hall_number_offset][1];
}

MagneticSymmetry *msgdb_get_spacegroup_operations(const int uni_number,
                                                  const int hall_number) {
    int hall_number_offset;
    int operation_index[2];
    MagneticSymmetry *symmetry;

    int i;
    int rot[3][3];
    double trans[3];
    int timerev;

    hall_number_offset = get_hall_number_offset(uni_number, hall_number);
    if (hall_number_offset == -1) {
        return NULL;
    }

    msgdb_get_operation_index(operation_index, uni_number, hall_number_offset);
    debug_print(
        "Load operations with UNI=%d, hall=%d: hall_number_offset=%d order=%d "
        "starts=%d\n",
        uni_number, hall_number, hall_number_offset, operation_index[0],
        operation_index[1]);

    if ((symmetry = sym_alloc_magnetic_symmetry(operation_index[0])) == NULL) {
        return NULL;
    }

    for (i = 0; i < operation_index[0]; i++) {
        msgdb_get_magnetic_operation(rot, trans, &timerev,
                                     operation_index[1] + i);
        mat_copy_matrix_i3(symmetry->rot[i], rot);
        mat_copy_vector_d3(symmetry->trans[i], trans);
        symmetry->timerev[i] = timerev;
    }

    return symmetry;
}

static const int alternative_transformations[][18][7] = {
    {{0}}, /* dummy */
    {
        {0}, /* UNI=1, Hall=1 */
    },
    {
        {0}, /* UNI=2, Hall=1 */
    },
    {
        {30, 90, 111, 810, 2301, 6831, 0}, /* UNI=3, Hall=1 */
    },
    {
        {0}, /* UNI=4, Hall=2 */
    },
    {
        {0}, /* UNI=5, Hall=2 */
    },
    {
        {0}, /* UNI=6, Hall=2 */
    },
    {
        {30, 90, 111, 810, 2301, 6831, 0}, /* UNI=7, Hall=2 */
    },
    {
        {0}, /* UNI=8, Hall=3 */
        {0}, /* UNI=8, Hall=4 */
        {0}, /* UNI=8, Hall=5 */
    },
    {
        {0}, /* UNI=9, Hall=3 */
        {0}, /* UNI=9, Hall=4 */
        {0}, /* UNI=9, Hall=5 */
    },
    {
        {0}, /* UNI=10, Hall=3 */
        {0}, /* UNI=10, Hall=4 */
        {0}, /* UNI=10, Hall=5 */
    },
    {
        {2461, 3191, 0}, /* UNI=11, Hall=3 */
        {849, 7329, 0},  /* UNI=11, Hall=4 */
        {3169, 3249, 0}, /* UNI=11, Hall=5 */
    },
    {
        {0}, /* UNI=12, Hall=3 */
        {0}, /* UNI=12, Hall=4 */
        {0}, /* UNI=12, Hall=5 */
    },
    {
        {2461, 3191, 0}, /* UNI=13, Hall=3 */
        {849, 7329, 0},  /* UNI=13, Hall=4 */
        {3169, 3249, 0}, /* UNI=13, Hall=5 */
    },
    {
        {0}, /* UNI=14, Hall=6 */
        {0}, /* UNI=14, Hall=7 */
        {0}, /* UNI=14, Hall=8 */
    },
    {
        {0}, /* UNI=15, Hall=6 */
        {0}, /* UNI=15, Hall=7 */
        {0}, /* UNI=15, Hall=8 */
    },
    {
        {0}, /* UNI=16, Hall=6 */
        {0}, /* UNI=16, Hall=7 */
        {0}, /* UNI=16, Hall=8 */
    },
    {
        {2461, 3191, 0}, /* UNI=17, Hall=6 */
        {849, 7329, 0},  /* UNI=17, Hall=7 */
        {3169, 3249, 0}, /* UNI=17, Hall=8 */
    },
    {
        {0}, /* UNI=18, Hall=6 */
        {0}, /* UNI=18, Hall=7 */
        {0}, /* UNI=18, Hall=8 */
    },
    {
        {2461, 3191, 0}, /* UNI=19, Hall=6 */
        {849, 7329, 0},  /* UNI=19, Hall=7 */
        {3169, 3249, 0}, /* UNI=19, Hall=8 */
    },
    {
        {0}, /* UNI=20, Hall=9 */
        {0}, /* UNI=20, Hall=10 */
        {0}, /* UNI=20, Hall=11 */
        {0}, /* UNI=20, Hall=12 */
        {0}, /* UNI=20, Hall=13 */
        {0}, /* UNI=20, Hall=14 */
        {0}, /* UNI=20, Hall=15 */
        {0}, /* UNI=20, Hall=16 */
        {0}, /* UNI=20, Hall=17 */
    },
    {
        {0}, /* UNI=21, Hall=9 */
        {0}, /* UNI=21, Hall=10 */
        {0}, /* UNI=21, Hall=11 */
        {0}, /* UNI=21, Hall=12 */
        {0}, /* UNI=21, Hall=13 */
        {0}, /* UNI=21, Hall=14 */
        {0}, /* UNI=21, Hall=15 */
        {0}, /* UNI=21, Hall=16 */
        {0}, /* UNI=21, Hall=17 */
    },
    {
        {0}, /* UNI=22, Hall=9 */
        {0}, /* UNI=22, Hall=10 */
        {0}, /* UNI=22, Hall=11 */
        {0}, /* UNI=22, Hall=12 */
        {0}, /* UNI=22, Hall=13 */
        {0}, /* UNI=22, Hall=14 */
        {0}, /* UNI=22, Hall=15 */
        {0}, /* UNI=22, Hall=16 */
        {0}, /* UNI=22, Hall=17 */
    },
    {
        {2471, 0}, /* UNI=23, Hall=9 */
        {3191, 0}, /* UNI=23, Hall=10 */
        {9022, 0}, /* UNI=23, Hall=11 */
        {2957, 0}, /* UNI=23, Hall=12 */
        {1013, 0}, /* UNI=23, Hall=13 */
        {7410, 0}, /* UNI=23, Hall=14 */
        {3197, 0}, /* UNI=23, Hall=15 */
        {3173, 0}, /* UNI=23, Hall=16 */
        {3250, 0}, /* UNI=23, Hall=17 */
    },
    {
        {0}, /* UNI=24, Hall=9 */
        {0}, /* UNI=24, Hall=10 */
        {0}, /* UNI=24, Hall=11 */
        {0}, /* UNI=24, Hall=12 */
        {0}, /* UNI=24, Hall=13 */
        {0}, /* UNI=24, Hall=14 */
        {0}, /* UNI=24, Hall=15 */
        {0}, /* UNI=24, Hall=16 */
        {0}, /* UNI=24, Hall=17 */
    },
    {
        {0}, /* UNI=25, Hall=18 */
        {0}, /* UNI=25, Hall=19 */
        {0}, /* UNI=25, Hall=20 */
    },
    {
        {0}, /* UNI=26, Hall=18 */
        {0}, /* UNI=26, Hall=19 */
        {0}, /* UNI=26, Hall=20 */
    },
    {
        {0}, /* UNI=27, Hall=18 */
        {0}, /* UNI=27, Hall=19 */
        {0}, /* UNI=27, Hall=20 */
    },
    {
        {2461, 3191, 0}, /* UNI=28, Hall=18 */
        {849, 7329, 0},  /* UNI=28, Hall=19 */
        {3169, 3249, 0}, /* UNI=28, Hall=20 */
    },
    {
        {0}, /* UNI=29, Hall=18 */
        {0}, /* UNI=29, Hall=19 */
        {0}, /* UNI=29, Hall=20 */
    },
    {
        {2461, 3191, 0}, /* UNI=30, Hall=18 */
        {849, 7329, 0},  /* UNI=30, Hall=19 */
        {3169, 3249, 0}, /* UNI=30, Hall=20 */
    },
    {
        {0}, /* UNI=31, Hall=21 */
        {0}, /* UNI=31, Hall=22 */
        {0}, /* UNI=31, Hall=23 */
        {0}, /* UNI=31, Hall=24 */
        {0}, /* UNI=31, Hall=25 */
        {0}, /* UNI=31, Hall=26 */
        {0}, /* UNI=31, Hall=27 */
        {0}, /* UNI=31, Hall=28 */
        {0}, /* UNI=31, Hall=29 */
    },
    {
        {0}, /* UNI=32, Hall=21 */
        {0}, /* UNI=32, Hall=22 */
        {0}, /* UNI=32, Hall=23 */
        {0}, /* UNI=32, Hall=24 */
        {0}, /* UNI=32, Hall=25 */
        {0}, /* UNI=32, Hall=26 */
        {0}, /* UNI=32, Hall=27 */
        {0}, /* UNI=32, Hall=28 */
        {0}, /* UNI=32, Hall=29 */
    },
    {
        {0}, /* UNI=33, Hall=21 */
        {0}, /* UNI=33, Hall=22 */
        {0}, /* UNI=33, Hall=23 */
        {0}, /* UNI=33, Hall=24 */
        {0}, /* UNI=33, Hall=25 */
        {0}, /* UNI=33, Hall=26 */
        {0}, /* UNI=33, Hall=27 */
        {0}, /* UNI=33, Hall=28 */
        {0}, /* UNI=33, Hall=29 */
    },
    {
        {3191, 0}, /* UNI=34, Hall=21 */
        {9022, 0}, /* UNI=34, Hall=22 */
        {2471, 0}, /* UNI=34, Hall=23 */
        {1013, 0}, /* UNI=34, Hall=24 */
        {7410, 0}, /* UNI=34, Hall=25 */
        {2957, 0}, /* UNI=34, Hall=26 */
        {3173, 0}, /* UNI=34, Hall=27 */
        {3250, 0}, /* UNI=34, Hall=28 */
        {3197, 0}, /* UNI=34, Hall=29 */
    },
    {
        {0}, /* UNI=35, Hall=21 */
        {0}, /* UNI=35, Hall=22 */
        {0}, /* UNI=35, Hall=23 */
        {0}, /* UNI=35, Hall=24 */
        {0}, /* UNI=35, Hall=25 */
        {0}, /* UNI=35, Hall=26 */
        {0}, /* UNI=35, Hall=27 */
        {0}, /* UNI=35, Hall=28 */
        {0}, /* UNI=35, Hall=29 */
    },
    {
        {0}, /* UNI=36, Hall=21 */
        {0}, /* UNI=36, Hall=22 */
        {0}, /* UNI=36, Hall=23 */
        {0}, /* UNI=36, Hall=24 */
        {0}, /* UNI=36, Hall=25 */
        {0}, /* UNI=36, Hall=26 */
        {0}, /* UNI=36, Hall=27 */
        {0}, /* UNI=36, Hall=28 */
        {0}, /* UNI=36, Hall=29 */
    },
    {
        {3191, 0}, /* UNI=37, Hall=21 */
        {9022, 0}, /* UNI=37, Hall=22 */
        {2471, 0}, /* UNI=37, Hall=23 */
        {1013, 0}, /* UNI=37, Hall=24 */
        {7410, 0}, /* UNI=37, Hall=25 */
        {2957, 0}, /* UNI=37, Hall=26 */
        {3173, 0}, /* UNI=37, Hall=27 */
        {3250, 0}, /* UNI=37, Hall=28 */
        {3197, 0}, /* UNI=37, Hall=29 */
    },
    {
        {0}, /* UNI=38, Hall=21 */
        {0}, /* UNI=38, Hall=22 */
        {0}, /* UNI=38, Hall=23 */
        {0}, /* UNI=38, Hall=24 */
        {0}, /* UNI=38, Hall=25 */
        {0}, /* UNI=38, Hall=26 */
        {0}, /* UNI=38, Hall=27 */
        {0}, /* UNI=38, Hall=28 */
        {0}, /* UNI=38, Hall=29 */
    },
    {
        {0}, /* UNI=39, Hall=30 */
        {0}, /* UNI=39, Hall=31 */
        {0}, /* UNI=39, Hall=32 */
        {0}, /* UNI=39, Hall=33 */
        {0}, /* UNI=39, Hall=34 */
        {0}, /* UNI=39, Hall=35 */
        {0}, /* UNI=39, Hall=36 */
        {0}, /* UNI=39, Hall=37 */
        {0}, /* UNI=39, Hall=38 */
    },
    {
        {0}, /* UNI=40, Hall=30 */
        {0}, /* UNI=40, Hall=31 */
        {0}, /* UNI=40, Hall=32 */
        {0}, /* UNI=40, Hall=33 */
        {0}, /* UNI=40, Hall=34 */
        {0}, /* UNI=40, Hall=35 */
        {0}, /* UNI=40, Hall=36 */
        {0}, /* UNI=40, Hall=37 */
        {0}, /* UNI=40, Hall=38 */
    },
    {
        {0}, /* UNI=41, Hall=30 */
        {0}, /* UNI=41, Hall=31 */
        {0}, /* UNI=41, Hall=32 */
        {0}, /* UNI=41, Hall=33 */
        {0}, /* UNI=41, Hall=34 */
        {0}, /* UNI=41, Hall=35 */
        {0}, /* UNI=41, Hall=36 */
        {0}, /* UNI=41, Hall=37 */
        {0}, /* UNI=41, Hall=38 */
    },
    {
        {2471, 0}, /* UNI=42, Hall=30 */
        {3191, 0}, /* UNI=42, Hall=31 */
        {9022, 0}, /* UNI=42, Hall=32 */
        {2957, 0}, /* UNI=42, Hall=33 */
        {1013, 0}, /* UNI=42, Hall=34 */
        {7410, 0}, /* UNI=42, Hall=35 */
        {3197, 0}, /* UNI=42, Hall=36 */
        {3173, 0}, /* UNI=42, Hall=37 */
        {3250, 0}, /* UNI=42, Hall=38 */
    },
    {
        {0}, /* UNI=43, Hall=30 */
        {0}, /* UNI=43, Hall=31 */
        {0}, /* UNI=43, Hall=32 */
        {0}, /* UNI=43, Hall=33 */
        {0}, /* UNI=43, Hall=34 */
        {0}, /* UNI=43, Hall=35 */
        {0}, /* UNI=43, Hall=36 */
        {0}, /* UNI=43, Hall=37 */
        {0}, /* UNI=43, Hall=38 */
    },
    {
        {0}, /* UNI=44, Hall=39 */
        {0}, /* UNI=44, Hall=40 */
        {0}, /* UNI=44, Hall=41 */
        {0}, /* UNI=44, Hall=42 */
        {0}, /* UNI=44, Hall=43 */
        {0}, /* UNI=44, Hall=44 */
        {0}, /* UNI=44, Hall=45 */
        {0}, /* UNI=44, Hall=46 */
        {0}, /* UNI=44, Hall=47 */
        {0}, /* UNI=44, Hall=48 */
        {0}, /* UNI=44, Hall=49 */
        {0}, /* UNI=44, Hall=50 */
        {0}, /* UNI=44, Hall=51 */
        {0}, /* UNI=44, Hall=52 */
        {0}, /* UNI=44, Hall=53 */
        {0}, /* UNI=44, Hall=54 */
        {0}, /* UNI=44, Hall=55 */
        {0}, /* UNI=44, Hall=56 */
    },
    {
        {0}, /* UNI=45, Hall=39 */
        {0}, /* UNI=45, Hall=40 */
        {0}, /* UNI=45, Hall=41 */
        {0}, /* UNI=45, Hall=42 */
        {0}, /* UNI=45, Hall=43 */
        {0}, /* UNI=45, Hall=44 */
        {0}, /* UNI=45, Hall=45 */
        {0}, /* UNI=45, Hall=46 */
        {0}, /* UNI=45, Hall=47 */
        {0}, /* UNI=45, Hall=48 */
        {0}, /* UNI=45, Hall=49 */
        {0}, /* UNI=45, Hall=50 */
        {0}, /* UNI=45, Hall=51 */
        {0}, /* UNI=45, Hall=52 */
        {0}, /* UNI=45, Hall=53 */
        {0}, /* UNI=45, Hall=54 */
        {0}, /* UNI=45, Hall=55 */
        {0}, /* UNI=45, Hall=56 */
    },
    {
        {0}, /* UNI=46, Hall=39 */
        {0}, /* UNI=46, Hall=40 */
        {0}, /* UNI=46, Hall=41 */
        {0}, /* UNI=46, Hall=42 */
        {0}, /* UNI=46, Hall=43 */
        {0}, /* UNI=46, Hall=44 */
        {0}, /* UNI=46, Hall=45 */
        {0}, /* UNI=46, Hall=46 */
        {0}, /* UNI=46, Hall=47 */
        {0}, /* UNI=46, Hall=48 */
        {0}, /* UNI=46, Hall=49 */
        {0}, /* UNI=46, Hall=50 */
        {0}, /* UNI=46, Hall=51 */
        {0}, /* UNI=46, Hall=52 */
        {0}, /* UNI=46, Hall=53 */
        {0}, /* UNI=46, Hall=54 */
        {0}, /* UNI=46, Hall=55 */
        {0}, /* UNI=46, Hall=56 */
    },
    {
        {711059, 0},  /* UNI=47, Hall=39 */
        {711779, 0},  /* UNI=47, Hall=40 */
        {717610, 0},  /* UNI=47, Hall=41 */
        {711779, 0},  /* UNI=47, Hall=42 */
        {711059, 0},  /* UNI=47, Hall=43 */
        {717610, 0},  /* UNI=47, Hall=44 */
        {62006, 0},   /* UNI=47, Hall=45 */
        {60062, 0},   /* UNI=47, Hall=46 */
        {66459, 0},   /* UNI=47, Hall=47 */
        {60062, 0},   /* UNI=47, Hall=48 */
        {62006, 0},   /* UNI=47, Hall=49 */
        {66459, 0},   /* UNI=47, Hall=50 */
        {8506253, 0}, /* UNI=47, Hall=51 */
        {8506229, 0}, /* UNI=47, Hall=52 */
        {8506306, 0}, /* UNI=47, Hall=53 */
        {8506229, 0}, /* UNI=47, Hall=54 */
        {8506253, 0}, /* UNI=47, Hall=55 */
        {8506306, 0}, /* UNI=47, Hall=56 */
    },
    {
        {0}, /* UNI=48, Hall=39 */
        {0}, /* UNI=48, Hall=40 */
        {0}, /* UNI=48, Hall=41 */
        {0}, /* UNI=48, Hall=42 */
        {0}, /* UNI=48, Hall=43 */
        {0}, /* UNI=48, Hall=44 */
        {0}, /* UNI=48, Hall=45 */
        {0}, /* UNI=48, Hall=46 */
        {0}, /* UNI=48, Hall=47 */
        {0}, /* UNI=48, Hall=48 */
        {0}, /* UNI=48, Hall=49 */
        {0}, /* UNI=48, Hall=50 */
        {0}, /* UNI=48, Hall=51 */
        {0}, /* UNI=48, Hall=52 */
        {0}, /* UNI=48, Hall=53 */
        {0}, /* UNI=48, Hall=54 */
        {0}, /* UNI=48, Hall=55 */
        {0}, /* UNI=48, Hall=56 */
    },
    {
        {0}, /* UNI=49, Hall=57 */
        {0}, /* UNI=49, Hall=58 */
        {0}, /* UNI=49, Hall=59 */
    },
    {
        {0}, /* UNI=50, Hall=57 */
        {0}, /* UNI=50, Hall=58 */
        {0}, /* UNI=50, Hall=59 */
    },
    {
        {0}, /* UNI=51, Hall=57 */
        {0}, /* UNI=51, Hall=58 */
        {0}, /* UNI=51, Hall=59 */
    },
    {
        {0}, /* UNI=52, Hall=57 */
        {0}, /* UNI=52, Hall=58 */
        {0}, /* UNI=52, Hall=59 */
    },
    {
        {0}, /* UNI=53, Hall=57 */
        {0}, /* UNI=53, Hall=58 */
        {0}, /* UNI=53, Hall=59 */
    },
    {
        {2461, 3191, 0}, /* UNI=54, Hall=57 */
        {849, 7329, 0},  /* UNI=54, Hall=58 */
        {3169, 3249, 0}, /* UNI=54, Hall=59 */
    },
    {
        {0}, /* UNI=55, Hall=57 */
        {0}, /* UNI=55, Hall=58 */
        {0}, /* UNI=55, Hall=59 */
    },
    {
        {2461, 3191, 0}, /* UNI=56, Hall=57 */
        {849, 7329, 0},  /* UNI=56, Hall=58 */
        {3169, 3249, 0}, /* UNI=56, Hall=59 */
    },
    {
        {0}, /* UNI=57, Hall=60 */
        {0}, /* UNI=57, Hall=61 */
        {0}, /* UNI=57, Hall=62 */
    },
    {
        {0}, /* UNI=58, Hall=60 */
        {0}, /* UNI=58, Hall=61 */
        {0}, /* UNI=58, Hall=62 */
    },
    {
        {0}, /* UNI=59, Hall=60 */
        {0}, /* UNI=59, Hall=61 */
        {0}, /* UNI=59, Hall=62 */
    },
    {
        {0}, /* UNI=60, Hall=60 */
        {0}, /* UNI=60, Hall=61 */
        {0}, /* UNI=60, Hall=62 */
    },
    {
        {0}, /* UNI=61, Hall=60 */
        {0}, /* UNI=61, Hall=61 */
        {0}, /* UNI=61, Hall=62 */
    },
    {
        {2461, 3191, 0}, /* UNI=62, Hall=60 */
        {849, 7329, 0},  /* UNI=62, Hall=61 */
        {3169, 3249, 0}, /* UNI=62, Hall=62 */
    },
    {
        {0}, /* UNI=63, Hall=60 */
        {0}, /* UNI=63, Hall=61 */
        {0}, /* UNI=63, Hall=62 */
    },
    {
        {2461, 3191, 0}, /* UNI=64, Hall=60 */
        {849, 7329, 0},  /* UNI=64, Hall=61 */
        {3169, 3249, 0}, /* UNI=64, Hall=62 */
    },
    {
        {0}, /* UNI=65, Hall=63 */
        {0}, /* UNI=65, Hall=64 */
        {0}, /* UNI=65, Hall=65 */
        {0}, /* UNI=65, Hall=66 */
        {0}, /* UNI=65, Hall=67 */
        {0}, /* UNI=65, Hall=68 */
        {0}, /* UNI=65, Hall=69 */
        {0}, /* UNI=65, Hall=70 */
        {0}, /* UNI=65, Hall=71 */
    },
    {
        {0}, /* UNI=66, Hall=63 */
        {0}, /* UNI=66, Hall=64 */
        {0}, /* UNI=66, Hall=65 */
        {0}, /* UNI=66, Hall=66 */
        {0}, /* UNI=66, Hall=67 */
        {0}, /* UNI=66, Hall=68 */
        {0}, /* UNI=66, Hall=69 */
        {0}, /* UNI=66, Hall=70 */
        {0}, /* UNI=66, Hall=71 */
    },
    {
        {0}, /* UNI=67, Hall=63 */
        {0}, /* UNI=67, Hall=64 */
        {0}, /* UNI=67, Hall=65 */
        {0}, /* UNI=67, Hall=66 */
        {0}, /* UNI=67, Hall=67 */
        {0}, /* UNI=67, Hall=68 */
        {0}, /* UNI=67, Hall=69 */
        {0}, /* UNI=67, Hall=70 */
        {0}, /* UNI=67, Hall=71 */
    },
    {
        {0}, /* UNI=68, Hall=63 */
        {0}, /* UNI=68, Hall=64 */
        {0}, /* UNI=68, Hall=65 */
        {0}, /* UNI=68, Hall=66 */
        {0}, /* UNI=68, Hall=67 */
        {0}, /* UNI=68, Hall=68 */
        {0}, /* UNI=68, Hall=69 */
        {0}, /* UNI=68, Hall=70 */
        {0}, /* UNI=68, Hall=71 */
    },
    {
        {0}, /* UNI=69, Hall=63 */
        {0}, /* UNI=69, Hall=64 */
        {0}, /* UNI=69, Hall=65 */
        {0}, /* UNI=69, Hall=66 */
        {0}, /* UNI=69, Hall=67 */
        {0}, /* UNI=69, Hall=68 */
        {0}, /* UNI=69, Hall=69 */
        {0}, /* UNI=69, Hall=70 */
        {0}, /* UNI=69, Hall=71 */
    },
    {
        {2471, 0}, /* UNI=70, Hall=63 */
        {3191, 0}, /* UNI=70, Hall=64 */
        {9022, 0}, /* UNI=70, Hall=65 */
        {2957, 0}, /* UNI=70, Hall=66 */
        {1013, 0}, /* UNI=70, Hall=67 */
        {7410, 0}, /* UNI=70, Hall=68 */
        {3197, 0}, /* UNI=70, Hall=69 */
        {3173, 0}, /* UNI=70, Hall=70 */
        {3250, 0}, /* UNI=70, Hall=71 */
    },
    {
        {0}, /* UNI=71, Hall=63 */
        {0}, /* UNI=71, Hall=64 */
        {0}, /* UNI=71, Hall=65 */
        {0}, /* UNI=71, Hall=66 */
        {0}, /* UNI=71, Hall=67 */
        {0}, /* UNI=71, Hall=68 */
        {0}, /* UNI=71, Hall=69 */
        {0}, /* UNI=71, Hall=70 */
        {0}, /* UNI=71, Hall=71 */
    },
    {
        {0}, /* UNI=72, Hall=72 */
        {0}, /* UNI=72, Hall=73 */
        {0}, /* UNI=72, Hall=74 */
        {0}, /* UNI=72, Hall=75 */
        {0}, /* UNI=72, Hall=76 */
        {0}, /* UNI=72, Hall=77 */
        {0}, /* UNI=72, Hall=78 */
        {0}, /* UNI=72, Hall=79 */
        {0}, /* UNI=72, Hall=80 */
    },
    {
        {0}, /* UNI=73, Hall=72 */
        {0}, /* UNI=73, Hall=73 */
        {0}, /* UNI=73, Hall=74 */
        {0}, /* UNI=73, Hall=75 */
        {0}, /* UNI=73, Hall=76 */
        {0}, /* UNI=73, Hall=77 */
        {0}, /* UNI=73, Hall=78 */
        {0}, /* UNI=73, Hall=79 */
        {0}, /* UNI=73, Hall=80 */
    },
    {
        {0}, /* UNI=74, Hall=72 */
        {0}, /* UNI=74, Hall=73 */
        {0}, /* UNI=74, Hall=74 */
        {0}, /* UNI=74, Hall=75 */
        {0}, /* UNI=74, Hall=76 */
        {0}, /* UNI=74, Hall=77 */
        {0}, /* UNI=74, Hall=78 */
        {0}, /* UNI=74, Hall=79 */
        {0}, /* UNI=74, Hall=80 */
    },
    {
        {0}, /* UNI=75, Hall=72 */
        {0}, /* UNI=75, Hall=73 */
        {0}, /* UNI=75, Hall=74 */
        {0}, /* UNI=75, Hall=75 */
        {0}, /* UNI=75, Hall=76 */
        {0}, /* UNI=75, Hall=77 */
        {0}, /* UNI=75, Hall=78 */
        {0}, /* UNI=75, Hall=79 */
        {0}, /* UNI=75, Hall=80 */
    },
    {
        {0}, /* UNI=76, Hall=72 */
        {0}, /* UNI=76, Hall=73 */
        {0}, /* UNI=76, Hall=74 */
        {0}, /* UNI=76, Hall=75 */
        {0}, /* UNI=76, Hall=76 */
        {0}, /* UNI=76, Hall=77 */
        {0}, /* UNI=76, Hall=78 */
        {0}, /* UNI=76, Hall=79 */
        {0}, /* UNI=76, Hall=80 */
    },
    {
        {3191, 0}, /* UNI=77, Hall=72 */
        {9022, 0}, /* UNI=77, Hall=73 */
        {2471, 0}, /* UNI=77, Hall=74 */
        {1013, 0}, /* UNI=77, Hall=75 */
        {7410, 0}, /* UNI=77, Hall=76 */
        {2957, 0}, /* UNI=77, Hall=77 */
        {3173, 0}, /* UNI=77, Hall=78 */
        {3250, 0}, /* UNI=77, Hall=79 */
        {3197, 0}, /* UNI=77, Hall=80 */
    },
    {
        {0}, /* UNI=78, Hall=72 */
        {0}, /* UNI=78, Hall=73 */
        {0}, /* UNI=78, Hall=74 */
        {0}, /* UNI=78, Hall=75 */
        {0}, /* UNI=78, Hall=76 */
        {0}, /* UNI=78, Hall=77 */
        {0}, /* UNI=78, Hall=78 */
        {0}, /* UNI=78, Hall=79 */
        {0}, /* UNI=78, Hall=80 */
    },
    {
        {0}, /* UNI=79, Hall=72 */
        {0}, /* UNI=79, Hall=73 */
        {0}, /* UNI=79, Hall=74 */
        {0}, /* UNI=79, Hall=75 */
        {0}, /* UNI=79, Hall=76 */
        {0}, /* UNI=79, Hall=77 */
        {0}, /* UNI=79, Hall=78 */
        {0}, /* UNI=79, Hall=79 */
        {0}, /* UNI=79, Hall=80 */
    },
    {
        {0}, /* UNI=80, Hall=72 */
        {0}, /* UNI=80, Hall=73 */
        {0}, /* UNI=80, Hall=74 */
        {0}, /* UNI=80, Hall=75 */
        {0}, /* UNI=80, Hall=76 */
        {0}, /* UNI=80, Hall=77 */
        {0}, /* UNI=80, Hall=78 */
        {0}, /* UNI=80, Hall=79 */
        {0}, /* UNI=80, Hall=80 */
    },
    {
        {3191, 0}, /* UNI=81, Hall=72 */
        {9022, 0}, /* UNI=81, Hall=73 */
        {2471, 0}, /* UNI=81, Hall=74 */
        {1013, 0}, /* UNI=81, Hall=75 */
        {7410, 0}, /* UNI=81, Hall=76 */
        {2957, 0}, /* UNI=81, Hall=77 */
        {3173, 0}, /* UNI=81, Hall=78 */
        {3250, 0}, /* UNI=81, Hall=79 */
        {3197, 0}, /* UNI=81, Hall=80 */
    },
    {
        {0}, /* UNI=82, Hall=81 */
        {0}, /* UNI=82, Hall=82 */
        {0}, /* UNI=82, Hall=83 */
        {0}, /* UNI=82, Hall=84 */
        {0}, /* UNI=82, Hall=85 */
        {0}, /* UNI=82, Hall=86 */
        {0}, /* UNI=82, Hall=87 */
        {0}, /* UNI=82, Hall=88 */
        {0}, /* UNI=82, Hall=89 */
    },
    {
        {0}, /* UNI=83, Hall=81 */
        {0}, /* UNI=83, Hall=82 */
        {0}, /* UNI=83, Hall=83 */
        {0}, /* UNI=83, Hall=84 */
        {0}, /* UNI=83, Hall=85 */
        {0}, /* UNI=83, Hall=86 */
        {0}, /* UNI=83, Hall=87 */
        {0}, /* UNI=83, Hall=88 */
        {0}, /* UNI=83, Hall=89 */
    },
    {
        {0}, /* UNI=84, Hall=81 */
        {0}, /* UNI=84, Hall=82 */
        {0}, /* UNI=84, Hall=83 */
        {0}, /* UNI=84, Hall=84 */
        {0}, /* UNI=84, Hall=85 */
        {0}, /* UNI=84, Hall=86 */
        {0}, /* UNI=84, Hall=87 */
        {0}, /* UNI=84, Hall=88 */
        {0}, /* UNI=84, Hall=89 */
    },
    {
        {0}, /* UNI=85, Hall=81 */
        {0}, /* UNI=85, Hall=82 */
        {0}, /* UNI=85, Hall=83 */
        {0}, /* UNI=85, Hall=84 */
        {0}, /* UNI=85, Hall=85 */
        {0}, /* UNI=85, Hall=86 */
        {0}, /* UNI=85, Hall=87 */
        {0}, /* UNI=85, Hall=88 */
        {0}, /* UNI=85, Hall=89 */
    },
    {
        {0}, /* UNI=86, Hall=81 */
        {0}, /* UNI=86, Hall=82 */
        {0}, /* UNI=86, Hall=83 */
        {0}, /* UNI=86, Hall=84 */
        {0}, /* UNI=86, Hall=85 */
        {0}, /* UNI=86, Hall=86 */
        {0}, /* UNI=86, Hall=87 */
        {0}, /* UNI=86, Hall=88 */
        {0}, /* UNI=86, Hall=89 */
    },
    {
        {3191, 0}, /* UNI=87, Hall=81 */
        {9022, 0}, /* UNI=87, Hall=82 */
        {2471, 0}, /* UNI=87, Hall=83 */
        {1013, 0}, /* UNI=87, Hall=84 */
        {7410, 0}, /* UNI=87, Hall=85 */
        {2957, 0}, /* UNI=87, Hall=86 */
        {3173, 0}, /* UNI=87, Hall=87 */
        {3250, 0}, /* UNI=87, Hall=88 */
        {3197, 0}, /* UNI=87, Hall=89 */
    },
    {
        {0}, /* UNI=88, Hall=81 */
        {0}, /* UNI=88, Hall=82 */
        {0}, /* UNI=88, Hall=83 */
        {0}, /* UNI=88, Hall=84 */
        {0}, /* UNI=88, Hall=85 */
        {0}, /* UNI=88, Hall=86 */
        {0}, /* UNI=88, Hall=87 */
        {0}, /* UNI=88, Hall=88 */
        {0}, /* UNI=88, Hall=89 */
    },
    {
        {0}, /* UNI=89, Hall=81 */
        {0}, /* UNI=89, Hall=82 */
        {0}, /* UNI=89, Hall=83 */
        {0}, /* UNI=89, Hall=84 */
        {0}, /* UNI=89, Hall=85 */
        {0}, /* UNI=89, Hall=86 */
        {0}, /* UNI=89, Hall=87 */
        {0}, /* UNI=89, Hall=88 */
        {0}, /* UNI=89, Hall=89 */
    },
    {
        {0}, /* UNI=90, Hall=81 */
        {0}, /* UNI=90, Hall=82 */
        {0}, /* UNI=90, Hall=83 */
        {0}, /* UNI=90, Hall=84 */
        {0}, /* UNI=90, Hall=85 */
        {0}, /* UNI=90, Hall=86 */
        {0}, /* UNI=90, Hall=87 */
        {0}, /* UNI=90, Hall=88 */
        {0}, /* UNI=90, Hall=89 */
    },
    {
        {3191, 0}, /* UNI=91, Hall=81 */
        {9022, 0}, /* UNI=91, Hall=82 */
        {2471, 0}, /* UNI=91, Hall=83 */
        {1013, 0}, /* UNI=91, Hall=84 */
        {7410, 0}, /* UNI=91, Hall=85 */
        {2957, 0}, /* UNI=91, Hall=86 */
        {3173, 0}, /* UNI=91, Hall=87 */
        {3250, 0}, /* UNI=91, Hall=88 */
        {3197, 0}, /* UNI=91, Hall=89 */
    },
    {
        {0}, /* UNI=92, Hall=90 */
        {0}, /* UNI=92, Hall=91 */
        {0}, /* UNI=92, Hall=92 */
        {0}, /* UNI=92, Hall=93 */
        {0}, /* UNI=92, Hall=94 */
        {0}, /* UNI=92, Hall=95 */
        {0}, /* UNI=92, Hall=96 */
        {0}, /* UNI=92, Hall=97 */
        {0}, /* UNI=92, Hall=98 */
        {0}, /* UNI=92, Hall=99 */
        {0}, /* UNI=92, Hall=100 */
        {0}, /* UNI=92, Hall=101 */
        {0}, /* UNI=92, Hall=102 */
        {0}, /* UNI=92, Hall=103 */
        {0}, /* UNI=92, Hall=104 */
        {0}, /* UNI=92, Hall=105 */
        {0}, /* UNI=92, Hall=106 */
        {0}, /* UNI=92, Hall=107 */
    },
    {
        {0}, /* UNI=93, Hall=90 */
        {0}, /* UNI=93, Hall=91 */
        {0}, /* UNI=93, Hall=92 */
        {0}, /* UNI=93, Hall=93 */
        {0}, /* UNI=93, Hall=94 */
        {0}, /* UNI=93, Hall=95 */
        {0}, /* UNI=93, Hall=96 */
        {0}, /* UNI=93, Hall=97 */
        {0}, /* UNI=93, Hall=98 */
        {0}, /* UNI=93, Hall=99 */
        {0}, /* UNI=93, Hall=100 */
        {0}, /* UNI=93, Hall=101 */
        {0}, /* UNI=93, Hall=102 */
        {0}, /* UNI=93, Hall=103 */
        {0}, /* UNI=93, Hall=104 */
        {0}, /* UNI=93, Hall=105 */
        {0}, /* UNI=93, Hall=106 */
        {0}, /* UNI=93, Hall=107 */
    },
    {
        {0}, /* UNI=94, Hall=90 */
        {0}, /* UNI=94, Hall=91 */
        {0}, /* UNI=94, Hall=92 */
        {0}, /* UNI=94, Hall=93 */
        {0}, /* UNI=94, Hall=94 */
        {0}, /* UNI=94, Hall=95 */
        {0}, /* UNI=94, Hall=96 */
        {0}, /* UNI=94, Hall=97 */
        {0}, /* UNI=94, Hall=98 */
        {0}, /* UNI=94, Hall=99 */
        {0}, /* UNI=94, Hall=100 */
        {0}, /* UNI=94, Hall=101 */
        {0}, /* UNI=94, Hall=102 */
        {0}, /* UNI=94, Hall=103 */
        {0}, /* UNI=94, Hall=104 */
        {0}, /* UNI=94, Hall=105 */
        {0}, /* UNI=94, Hall=106 */
        {0}, /* UNI=94, Hall=107 */
    },
    {
        {0}, /* UNI=95, Hall=90 */
        {0}, /* UNI=95, Hall=91 */
        {0}, /* UNI=95, Hall=92 */
        {0}, /* UNI=95, Hall=93 */
        {0}, /* UNI=95, Hall=94 */
        {0}, /* UNI=95, Hall=95 */
        {0}, /* UNI=95, Hall=96 */
        {0}, /* UNI=95, Hall=97 */
        {0}, /* UNI=95, Hall=98 */
        {0}, /* UNI=95, Hall=99 */
        {0}, /* UNI=95, Hall=100 */
        {0}, /* UNI=95, Hall=101 */
        {0}, /* UNI=95, Hall=102 */
        {0}, /* UNI=95, Hall=103 */
        {0}, /* UNI=95, Hall=104 */
        {0}, /* UNI=95, Hall=105 */
        {0}, /* UNI=95, Hall=106 */
        {0}, /* UNI=95, Hall=107 */
    },
    {
        {0}, /* UNI=96, Hall=90 */
        {0}, /* UNI=96, Hall=91 */
        {0}, /* UNI=96, Hall=92 */
        {0}, /* UNI=96, Hall=93 */
        {0}, /* UNI=96, Hall=94 */
        {0}, /* UNI=96, Hall=95 */
        {0}, /* UNI=96, Hall=96 */
        {0}, /* UNI=96, Hall=97 */
        {0}, /* UNI=96, Hall=98 */
        {0}, /* UNI=96, Hall=99 */
        {0}, /* UNI=96, Hall=100 */
        {0}, /* UNI=96, Hall=101 */
        {0}, /* UNI=96, Hall=102 */
        {0}, /* UNI=96, Hall=103 */
        {0}, /* UNI=96, Hall=104 */
        {0}, /* UNI=96, Hall=105 */
        {0}, /* UNI=96, Hall=106 */
        {0}, /* UNI=96, Hall=107 */
    },
    {
        {9214115, 0}, /* UNI=97, Hall=90 */
        {770828, 0},  /* UNI=97, Hall=91 */
        {9279715, 0}, /* UNI=97, Hall=92 */
        {770828, 0},  /* UNI=97, Hall=93 */
        {9214115, 0}, /* UNI=97, Hall=94 */
        {9279715, 0}, /* UNI=97, Hall=95 */
        {770594, 0},  /* UNI=97, Hall=96 */
        {8563118, 0}, /* UNI=97, Hall=97 */
        {9278103, 0}, /* UNI=97, Hall=98 */
        {8563118, 0}, /* UNI=97, Hall=99 */
        {770594, 0},  /* UNI=97, Hall=100 */
        {9278103, 0}, /* UNI=97, Hall=101 */
        {8565302, 0}, /* UNI=97, Hall=102 */
        {9214817, 0}, /* UNI=97, Hall=103 */
        {9273943, 0}, /* UNI=97, Hall=104 */
        {9214817, 0}, /* UNI=97, Hall=105 */
        {8565302, 0}, /* UNI=97, Hall=106 */
        {9273943, 0}, /* UNI=97, Hall=107 */
    },
    {
        {0}, /* UNI=98, Hall=90 */
        {0}, /* UNI=98, Hall=91 */
        {0}, /* UNI=98, Hall=92 */
        {0}, /* UNI=98, Hall=93 */
        {0}, /* UNI=98, Hall=94 */
        {0}, /* UNI=98, Hall=95 */
        {0}, /* UNI=98, Hall=96 */
        {0}, /* UNI=98, Hall=97 */
        {0}, /* UNI=98, Hall=98 */
        {0}, /* UNI=98, Hall=99 */
        {0}, /* UNI=98, Hall=100 */
        {0}, /* UNI=98, Hall=101 */
        {0}, /* UNI=98, Hall=102 */
        {0}, /* UNI=98, Hall=103 */
        {0}, /* UNI=98, Hall=104 */
        {0}, /* UNI=98, Hall=105 */
        {0}, /* UNI=98, Hall=106 */
        {0}, /* UNI=98, Hall=107 */
    },
    {
        {0}, /* UNI=99, Hall=108 */
    },
    {
        {0}, /* UNI=100, Hall=108 */
    },
    {
        {3250, 7410, 0}, /* UNI=101, Hall=108 */
    },
    {
        {7410, 8872, 0}, /* UNI=102, Hall=108 */
    },
    {
        {3250, 7636, 0}, /* UNI=103, Hall=108 */
    },
    {
        {0}, /* UNI=104, Hall=108 */
    },
    {
        {0}, /* UNI=105, Hall=109 */
        {0}, /* UNI=105, Hall=110 */
        {0}, /* UNI=105, Hall=111 */
    },
    {
        {0}, /* UNI=106, Hall=109 */
        {0}, /* UNI=106, Hall=110 */
        {0}, /* UNI=106, Hall=111 */
    },
    {
        {0}, /* UNI=107, Hall=109 */
        {0}, /* UNI=107, Hall=110 */
        {0}, /* UNI=107, Hall=111 */
    },
    {
        {66459, 0},   /* UNI=108, Hall=109 */
        {8506306, 0}, /* UNI=108, Hall=110 */
        {717610, 0},  /* UNI=108, Hall=111 */
    },
    {
        {66459, 0},   /* UNI=109, Hall=109 */
        {8506306, 0}, /* UNI=109, Hall=110 */
        {717610, 0},  /* UNI=109, Hall=111 */
    },
    {
        {0}, /* UNI=110, Hall=109 */
        {0}, /* UNI=110, Hall=110 */
        {0}, /* UNI=110, Hall=111 */
    },
    {
        {66459, 0},   /* UNI=111, Hall=109 */
        {8506306, 0}, /* UNI=111, Hall=110 */
        {717610, 0},  /* UNI=111, Hall=111 */
    },
    {
        {0}, /* UNI=112, Hall=109 */
        {0}, /* UNI=112, Hall=110 */
        {0}, /* UNI=112, Hall=111 */
    },
    {
        {0}, /* UNI=113, Hall=109 */
        {0}, /* UNI=113, Hall=110 */
        {0}, /* UNI=113, Hall=111 */
    },
    {
        {0}, /* UNI=114, Hall=112 */
        {0}, /* UNI=114, Hall=113 */
        {0}, /* UNI=114, Hall=114 */
    },
    {
        {0}, /* UNI=115, Hall=112 */
        {0}, /* UNI=115, Hall=113 */
        {0}, /* UNI=115, Hall=114 */
    },
    {
        {0}, /* UNI=116, Hall=112 */
        {0}, /* UNI=116, Hall=113 */
        {0}, /* UNI=116, Hall=114 */
    },
    {
        {7410, 0}, /* UNI=117, Hall=112 */
        {3250, 0}, /* UNI=117, Hall=113 */
        {9022, 0}, /* UNI=117, Hall=114 */
    },
    {
        {7410, 0}, /* UNI=118, Hall=112 */
        {3250, 0}, /* UNI=118, Hall=113 */
        {9022, 0}, /* UNI=118, Hall=114 */
    },
    {
        {0}, /* UNI=119, Hall=112 */
        {0}, /* UNI=119, Hall=113 */
        {0}, /* UNI=119, Hall=114 */
    },
    {
        {7410, 0}, /* UNI=120, Hall=112 */
        {3250, 0}, /* UNI=120, Hall=113 */
        {9022, 0}, /* UNI=120, Hall=114 */
    },
    {
        {0}, /* UNI=121, Hall=112 */
        {0}, /* UNI=121, Hall=113 */
        {0}, /* UNI=121, Hall=114 */
    },
    {
        {0}, /* UNI=122, Hall=112 */
        {0}, /* UNI=122, Hall=113 */
        {0}, /* UNI=122, Hall=114 */
    },
    {
        {0}, /* UNI=123, Hall=115 */
    },
    {
        {0}, /* UNI=124, Hall=115 */
    },
    {
        {9273943, 7636, 0}, /* UNI=125, Hall=115 */
    },
    {
        {9273943, 7636, 0}, /* UNI=126, Hall=115 */
    },
    {
        {9273943, 7636, 0}, /* UNI=127, Hall=115 */
    },
    {
        {0}, /* UNI=128, Hall=115 */
    },
    {
        {0}, /* UNI=129, Hall=116 */
        {0}, /* UNI=129, Hall=117 */
        {0}, /* UNI=129, Hall=118 */
    },
    {
        {0}, /* UNI=130, Hall=116 */
        {0}, /* UNI=130, Hall=117 */
        {0}, /* UNI=130, Hall=118 */
    },
    {
        {0}, /* UNI=131, Hall=116 */
        {0}, /* UNI=131, Hall=117 */
        {0}, /* UNI=131, Hall=118 */
    },
    {
        {66459, 0},   /* UNI=132, Hall=116 */
        {8506306, 0}, /* UNI=132, Hall=117 */
        {717610, 0},  /* UNI=132, Hall=118 */
    },
    {
        {0}, /* UNI=133, Hall=116 */
        {0}, /* UNI=133, Hall=117 */
        {0}, /* UNI=133, Hall=118 */
    },
    {
        {0}, /* UNI=134, Hall=116 */
        {0}, /* UNI=134, Hall=117 */
        {0}, /* UNI=134, Hall=118 */
    },
    {
        {0}, /* UNI=135, Hall=116 */
        {0}, /* UNI=135, Hall=117 */
        {0}, /* UNI=135, Hall=118 */
    },
    {
        {0}, /* UNI=136, Hall=119 */
        {0}, /* UNI=136, Hall=120 */
        {0}, /* UNI=136, Hall=121 */
    },
    {
        {0}, /* UNI=137, Hall=119 */
        {0}, /* UNI=137, Hall=120 */
        {0}, /* UNI=137, Hall=121 */
    },
    {
        {0}, /* UNI=138, Hall=119 */
        {0}, /* UNI=138, Hall=120 */
        {0}, /* UNI=138, Hall=121 */
    },
    {
        {7410, 0}, /* UNI=139, Hall=119 */
        {3250, 0}, /* UNI=139, Hall=120 */
        {9022, 0}, /* UNI=139, Hall=121 */
    },
    {
        {0}, /* UNI=140, Hall=119 */
        {0}, /* UNI=140, Hall=120 */
        {0}, /* UNI=140, Hall=121 */
    },
    {
        {0}, /* UNI=141, Hall=119 */
        {0}, /* UNI=141, Hall=120 */
        {0}, /* UNI=141, Hall=121 */
    },
    {
        {0}, /* UNI=142, Hall=119 */
        {0}, /* UNI=142, Hall=120 */
        {0}, /* UNI=142, Hall=121 */
    },
    {
        {0}, /* UNI=143, Hall=122 */
    },
    {
        {0}, /* UNI=144, Hall=122 */
    },
    {
        {3250, 7636, 0}, /* UNI=145, Hall=122 */
    },
    {
        {0}, /* UNI=146, Hall=122 */
    },
    {
        {0}, /* UNI=147, Hall=123 */
    },
    {
        {0}, /* UNI=148, Hall=123 */
    },
    {
        {3250, 7636, 0}, /* UNI=149, Hall=123 */
    },
    {
        {3250, 7636, 0}, /* UNI=150, Hall=123 */
    },
    {
        {0}, /* UNI=151, Hall=124 */
    },
    {
        {0}, /* UNI=152, Hall=124 */
    },
    {
        {9273943, 7636, 0}, /* UNI=153, Hall=124 */
    },
    {
        {9273943, 7636, 0}, /* UNI=154, Hall=124 */
    },
    {
        {0}, /* UNI=155, Hall=125 */
        {0}, /* UNI=155, Hall=126 */
        {0}, /* UNI=155, Hall=127 */
    },
    {
        {0}, /* UNI=156, Hall=125 */
        {0}, /* UNI=156, Hall=126 */
        {0}, /* UNI=156, Hall=127 */
    },
    {
        {7410, 0}, /* UNI=157, Hall=125 */
        {3250, 0}, /* UNI=157, Hall=126 */
        {9022, 0}, /* UNI=157, Hall=127 */
    },
    {
        {0}, /* UNI=158, Hall=125 */
        {0}, /* UNI=158, Hall=126 */
        {0}, /* UNI=158, Hall=127 */
    },
    {
        {0}, /* UNI=159, Hall=125 */
        {0}, /* UNI=159, Hall=126 */
        {0}, /* UNI=159, Hall=127 */
    },
    {
        {7410, 0}, /* UNI=160, Hall=125 */
        {3250, 0}, /* UNI=160, Hall=126 */
        {9022, 0}, /* UNI=160, Hall=127 */
    },
    {
        {0}, /* UNI=161, Hall=125 */
        {0}, /* UNI=161, Hall=126 */
        {0}, /* UNI=161, Hall=127 */
    },
    {
        {7410, 0}, /* UNI=162, Hall=125 */
        {3250, 0}, /* UNI=162, Hall=126 */
        {9022, 0}, /* UNI=162, Hall=127 */
    },
    {
        {0}, /* UNI=163, Hall=125 */
        {0}, /* UNI=163, Hall=126 */
        {0}, /* UNI=163, Hall=127 */
    },
    {
        {0}, /* UNI=164, Hall=128 */
        {0}, /* UNI=164, Hall=129 */
        {0}, /* UNI=164, Hall=130 */
        {0}, /* UNI=164, Hall=131 */
        {0}, /* UNI=164, Hall=132 */
        {0}, /* UNI=164, Hall=133 */
    },
    {
        {0}, /* UNI=165, Hall=128 */
        {0}, /* UNI=165, Hall=129 */
        {0}, /* UNI=165, Hall=130 */
        {0}, /* UNI=165, Hall=131 */
        {0}, /* UNI=165, Hall=132 */
        {0}, /* UNI=165, Hall=133 */
    },
    {
        {0}, /* UNI=166, Hall=128 */
        {0}, /* UNI=166, Hall=129 */
        {0}, /* UNI=166, Hall=130 */
        {0}, /* UNI=166, Hall=131 */
        {0}, /* UNI=166, Hall=132 */
        {0}, /* UNI=166, Hall=133 */
    },
    {
        {0}, /* UNI=167, Hall=128 */
        {0}, /* UNI=167, Hall=129 */
        {0}, /* UNI=167, Hall=130 */
        {0}, /* UNI=167, Hall=131 */
        {0}, /* UNI=167, Hall=132 */
        {0}, /* UNI=167, Hall=133 */
    },
    {
        {0}, /* UNI=168, Hall=128 */
        {0}, /* UNI=168, Hall=129 */
        {0}, /* UNI=168, Hall=130 */
        {0}, /* UNI=168, Hall=131 */
        {0}, /* UNI=168, Hall=132 */
        {0}, /* UNI=168, Hall=133 */
    },
    {
        {0}, /* UNI=169, Hall=128 */
        {0}, /* UNI=169, Hall=129 */
        {0}, /* UNI=169, Hall=130 */
        {0}, /* UNI=169, Hall=131 */
        {0}, /* UNI=169, Hall=132 */
        {0}, /* UNI=169, Hall=133 */
    },
    {
        {0}, /* UNI=170, Hall=128 */
        {0}, /* UNI=170, Hall=129 */
        {0}, /* UNI=170, Hall=130 */
        {0}, /* UNI=170, Hall=131 */
        {0}, /* UNI=170, Hall=132 */
        {0}, /* UNI=170, Hall=133 */
    },
    {
        {0}, /* UNI=171, Hall=128 */
        {0}, /* UNI=171, Hall=129 */
        {0}, /* UNI=171, Hall=130 */
        {0}, /* UNI=171, Hall=131 */
        {0}, /* UNI=171, Hall=132 */
        {0}, /* UNI=171, Hall=133 */
    },
    {
        {0}, /* UNI=172, Hall=128 */
        {0}, /* UNI=172, Hall=129 */
        {0}, /* UNI=172, Hall=130 */
        {0}, /* UNI=172, Hall=131 */
        {0}, /* UNI=172, Hall=132 */
        {0}, /* UNI=172, Hall=133 */
    },
    {
        {0}, /* UNI=173, Hall=128 */
        {0}, /* UNI=173, Hall=129 */
        {0}, /* UNI=173, Hall=130 */
        {0}, /* UNI=173, Hall=131 */
        {0}, /* UNI=173, Hall=132 */
        {0}, /* UNI=173, Hall=133 */
    },
    {
        {0}, /* UNI=174, Hall=128 */
        {0}, /* UNI=174, Hall=129 */
        {0}, /* UNI=174, Hall=130 */
        {0}, /* UNI=174, Hall=131 */
        {0}, /* UNI=174, Hall=132 */
        {0}, /* UNI=174, Hall=133 */
    },
    {
        {0}, /* UNI=175, Hall=128 */
        {0}, /* UNI=175, Hall=129 */
        {0}, /* UNI=175, Hall=130 */
        {0}, /* UNI=175, Hall=131 */
        {0}, /* UNI=175, Hall=132 */
        {0}, /* UNI=175, Hall=133 */
    },
    {
        {0}, /* UNI=176, Hall=134 */
        {0}, /* UNI=176, Hall=135 */
        {0}, /* UNI=176, Hall=136 */
    },
    {
        {0}, /* UNI=177, Hall=134 */
        {0}, /* UNI=177, Hall=135 */
        {0}, /* UNI=177, Hall=136 */
    },
    {
        {7410, 0}, /* UNI=178, Hall=134 */
        {3250, 0}, /* UNI=178, Hall=135 */
        {9022, 0}, /* UNI=178, Hall=136 */
    },
    {
        {0}, /* UNI=179, Hall=134 */
        {0}, /* UNI=179, Hall=135 */
        {0}, /* UNI=179, Hall=136 */
    },
    {
        {0}, /* UNI=180, Hall=134 */
        {0}, /* UNI=180, Hall=135 */
        {0}, /* UNI=180, Hall=136 */
    },
    {
        {7410, 0}, /* UNI=181, Hall=134 */
        {3250, 0}, /* UNI=181, Hall=135 */
        {9022, 0}, /* UNI=181, Hall=136 */
    },
    {
        {0}, /* UNI=182, Hall=134 */
        {0}, /* UNI=182, Hall=135 */
        {0}, /* UNI=182, Hall=136 */
    },
    {
        {7410, 0}, /* UNI=183, Hall=134 */
        {3250, 0}, /* UNI=183, Hall=135 */
        {9022, 0}, /* UNI=183, Hall=136 */
    },
    {
        {0}, /* UNI=184, Hall=134 */
        {0}, /* UNI=184, Hall=135 */
        {0}, /* UNI=184, Hall=136 */
    },
    {
        {0}, /* UNI=185, Hall=137 */
        {0}, /* UNI=185, Hall=138 */
        {0}, /* UNI=185, Hall=139 */
        {0}, /* UNI=185, Hall=140 */
        {0}, /* UNI=185, Hall=141 */
        {0}, /* UNI=185, Hall=142 */
    },
    {
        {0}, /* UNI=186, Hall=137 */
        {0}, /* UNI=186, Hall=138 */
        {0}, /* UNI=186, Hall=139 */
        {0}, /* UNI=186, Hall=140 */
        {0}, /* UNI=186, Hall=141 */
        {0}, /* UNI=186, Hall=142 */
    },
    {
        {0}, /* UNI=187, Hall=137 */
        {0}, /* UNI=187, Hall=138 */
        {0}, /* UNI=187, Hall=139 */
        {0}, /* UNI=187, Hall=140 */
        {0}, /* UNI=187, Hall=141 */
        {0}, /* UNI=187, Hall=142 */
    },
    {
        {0}, /* UNI=188, Hall=137 */
        {0}, /* UNI=188, Hall=138 */
        {0}, /* UNI=188, Hall=139 */
        {0}, /* UNI=188, Hall=140 */
        {0}, /* UNI=188, Hall=141 */
        {0}, /* UNI=188, Hall=142 */
    },
    {
        {0}, /* UNI=189, Hall=137 */
        {0}, /* UNI=189, Hall=138 */
        {0}, /* UNI=189, Hall=139 */
        {0}, /* UNI=189, Hall=140 */
        {0}, /* UNI=189, Hall=141 */
        {0}, /* UNI=189, Hall=142 */
    },
    {
        {0}, /* UNI=190, Hall=137 */
        {0}, /* UNI=190, Hall=138 */
        {0}, /* UNI=190, Hall=139 */
        {0}, /* UNI=190, Hall=140 */
        {0}, /* UNI=190, Hall=141 */
        {0}, /* UNI=190, Hall=142 */
    },
    {
        {0}, /* UNI=191, Hall=137 */
        {0}, /* UNI=191, Hall=138 */
        {0}, /* UNI=191, Hall=139 */
        {0}, /* UNI=191, Hall=140 */
        {0}, /* UNI=191, Hall=141 */
        {0}, /* UNI=191, Hall=142 */
    },
    {
        {0}, /* UNI=192, Hall=137 */
        {0}, /* UNI=192, Hall=138 */
        {0}, /* UNI=192, Hall=139 */
        {0}, /* UNI=192, Hall=140 */
        {0}, /* UNI=192, Hall=141 */
        {0}, /* UNI=192, Hall=142 */
    },
    {
        {0}, /* UNI=193, Hall=137 */
        {0}, /* UNI=193, Hall=138 */
        {0}, /* UNI=193, Hall=139 */
        {0}, /* UNI=193, Hall=140 */
        {0}, /* UNI=193, Hall=141 */
        {0}, /* UNI=193, Hall=142 */
    },
    {
        {0}, /* UNI=194, Hall=137 */
        {0}, /* UNI=194, Hall=138 */
        {0}, /* UNI=194, Hall=139 */
        {0}, /* UNI=194, Hall=140 */
        {0}, /* UNI=194, Hall=141 */
        {0}, /* UNI=194, Hall=142 */
    },
    {
        {0}, /* UNI=195, Hall=137 */
        {0}, /* UNI=195, Hall=138 */
        {0}, /* UNI=195, Hall=139 */
        {0}, /* UNI=195, Hall=140 */
        {0}, /* UNI=195, Hall=141 */
        {0}, /* UNI=195, Hall=142 */
    },
    {
        {0}, /* UNI=196, Hall=137 */
        {0}, /* UNI=196, Hall=138 */
        {0}, /* UNI=196, Hall=139 */
        {0}, /* UNI=196, Hall=140 */
        {0}, /* UNI=196, Hall=141 */
        {0}, /* UNI=196, Hall=142 */
    },
    {
        {0}, /* UNI=197, Hall=143 */
        {0}, /* UNI=197, Hall=144 */
        {0}, /* UNI=197, Hall=145 */
        {0}, /* UNI=197, Hall=146 */
        {0}, /* UNI=197, Hall=147 */
        {0}, /* UNI=197, Hall=148 */
    },
    {
        {0}, /* UNI=198, Hall=143 */
        {0}, /* UNI=198, Hall=144 */
        {0}, /* UNI=198, Hall=145 */
        {0}, /* UNI=198, Hall=146 */
        {0}, /* UNI=198, Hall=147 */
        {0}, /* UNI=198, Hall=148 */
    },
    {
        {0}, /* UNI=199, Hall=143 */
        {0}, /* UNI=199, Hall=144 */
        {0}, /* UNI=199, Hall=145 */
        {0}, /* UNI=199, Hall=146 */
        {0}, /* UNI=199, Hall=147 */
        {0}, /* UNI=199, Hall=148 */
    },
    {
        {0}, /* UNI=200, Hall=143 */
        {0}, /* UNI=200, Hall=144 */
        {0}, /* UNI=200, Hall=145 */
        {0}, /* UNI=200, Hall=146 */
        {0}, /* UNI=200, Hall=147 */
        {0}, /* UNI=200, Hall=148 */
    },
    {
        {0}, /* UNI=201, Hall=143 */
        {0}, /* UNI=201, Hall=144 */
        {0}, /* UNI=201, Hall=145 */
        {0}, /* UNI=201, Hall=146 */
        {0}, /* UNI=201, Hall=147 */
        {0}, /* UNI=201, Hall=148 */
    },
    {
        {0}, /* UNI=202, Hall=143 */
        {0}, /* UNI=202, Hall=144 */
        {0}, /* UNI=202, Hall=145 */
        {0}, /* UNI=202, Hall=146 */
        {0}, /* UNI=202, Hall=147 */
        {0}, /* UNI=202, Hall=148 */
    },
    {
        {0}, /* UNI=203, Hall=143 */
        {0}, /* UNI=203, Hall=144 */
        {0}, /* UNI=203, Hall=145 */
        {0}, /* UNI=203, Hall=146 */
        {0}, /* UNI=203, Hall=147 */
        {0}, /* UNI=203, Hall=148 */
    },
    {
        {0}, /* UNI=204, Hall=143 */
        {0}, /* UNI=204, Hall=144 */
        {0}, /* UNI=204, Hall=145 */
        {0}, /* UNI=204, Hall=146 */
        {0}, /* UNI=204, Hall=147 */
        {0}, /* UNI=204, Hall=148 */
    },
    {
        {0}, /* UNI=205, Hall=143 */
        {0}, /* UNI=205, Hall=144 */
        {0}, /* UNI=205, Hall=145 */
        {0}, /* UNI=205, Hall=146 */
        {0}, /* UNI=205, Hall=147 */
        {0}, /* UNI=205, Hall=148 */
    },
    {
        {0}, /* UNI=206, Hall=143 */
        {0}, /* UNI=206, Hall=144 */
        {0}, /* UNI=206, Hall=145 */
        {0}, /* UNI=206, Hall=146 */
        {0}, /* UNI=206, Hall=147 */
        {0}, /* UNI=206, Hall=148 */
    },
    {
        {0}, /* UNI=207, Hall=143 */
        {0}, /* UNI=207, Hall=144 */
        {0}, /* UNI=207, Hall=145 */
        {0}, /* UNI=207, Hall=146 */
        {0}, /* UNI=207, Hall=147 */
        {0}, /* UNI=207, Hall=148 */
    },
    {
        {0}, /* UNI=208, Hall=143 */
        {0}, /* UNI=208, Hall=144 */
        {0}, /* UNI=208, Hall=145 */
        {0}, /* UNI=208, Hall=146 */
        {0}, /* UNI=208, Hall=147 */
        {0}, /* UNI=208, Hall=148 */
    },
    {
        {0}, /* UNI=209, Hall=149 */
        {0}, /* UNI=209, Hall=150 */
        {0}, /* UNI=209, Hall=151 */
        {0}, /* UNI=209, Hall=152 */
        {0}, /* UNI=209, Hall=153 */
        {0}, /* UNI=209, Hall=154 */
    },
    {
        {0}, /* UNI=210, Hall=149 */
        {0}, /* UNI=210, Hall=150 */
        {0}, /* UNI=210, Hall=151 */
        {0}, /* UNI=210, Hall=152 */
        {0}, /* UNI=210, Hall=153 */
        {0}, /* UNI=210, Hall=154 */
    },
    {
        {0}, /* UNI=211, Hall=149 */
        {0}, /* UNI=211, Hall=150 */
        {0}, /* UNI=211, Hall=151 */
        {0}, /* UNI=211, Hall=152 */
        {0}, /* UNI=211, Hall=153 */
        {0}, /* UNI=211, Hall=154 */
    },
    {
        {0}, /* UNI=212, Hall=149 */
        {0}, /* UNI=212, Hall=150 */
        {0}, /* UNI=212, Hall=151 */
        {0}, /* UNI=212, Hall=152 */
        {0}, /* UNI=212, Hall=153 */
        {0}, /* UNI=212, Hall=154 */
    },
    {
        {0}, /* UNI=213, Hall=149 */
        {0}, /* UNI=213, Hall=150 */
        {0}, /* UNI=213, Hall=151 */
        {0}, /* UNI=213, Hall=152 */
        {0}, /* UNI=213, Hall=153 */
        {0}, /* UNI=213, Hall=154 */
    },
    {
        {0}, /* UNI=214, Hall=149 */
        {0}, /* UNI=214, Hall=150 */
        {0}, /* UNI=214, Hall=151 */
        {0}, /* UNI=214, Hall=152 */
        {0}, /* UNI=214, Hall=153 */
        {0}, /* UNI=214, Hall=154 */
    },
    {
        {0}, /* UNI=215, Hall=149 */
        {0}, /* UNI=215, Hall=150 */
        {0}, /* UNI=215, Hall=151 */
        {0}, /* UNI=215, Hall=152 */
        {0}, /* UNI=215, Hall=153 */
        {0}, /* UNI=215, Hall=154 */
    },
    {
        {0}, /* UNI=216, Hall=149 */
        {0}, /* UNI=216, Hall=150 */
        {0}, /* UNI=216, Hall=151 */
        {0}, /* UNI=216, Hall=152 */
        {0}, /* UNI=216, Hall=153 */
        {0}, /* UNI=216, Hall=154 */
    },
    {
        {0}, /* UNI=217, Hall=149 */
        {0}, /* UNI=217, Hall=150 */
        {0}, /* UNI=217, Hall=151 */
        {0}, /* UNI=217, Hall=152 */
        {0}, /* UNI=217, Hall=153 */
        {0}, /* UNI=217, Hall=154 */
    },
    {
        {0}, /* UNI=218, Hall=149 */
        {0}, /* UNI=218, Hall=150 */
        {0}, /* UNI=218, Hall=151 */
        {0}, /* UNI=218, Hall=152 */
        {0}, /* UNI=218, Hall=153 */
        {0}, /* UNI=218, Hall=154 */
    },
    {
        {0}, /* UNI=219, Hall=149 */
        {0}, /* UNI=219, Hall=150 */
        {0}, /* UNI=219, Hall=151 */
        {0}, /* UNI=219, Hall=152 */
        {0}, /* UNI=219, Hall=153 */
        {0}, /* UNI=219, Hall=154 */
    },
    {
        {0}, /* UNI=220, Hall=149 */
        {0}, /* UNI=220, Hall=150 */
        {0}, /* UNI=220, Hall=151 */
        {0}, /* UNI=220, Hall=152 */
        {0}, /* UNI=220, Hall=153 */
        {0}, /* UNI=220, Hall=154 */
    },
    {
        {0}, /* UNI=221, Hall=155 */
        {0}, /* UNI=221, Hall=156 */
        {0}, /* UNI=221, Hall=157 */
        {0}, /* UNI=221, Hall=158 */
        {0}, /* UNI=221, Hall=159 */
        {0}, /* UNI=221, Hall=160 */
    },
    {
        {0}, /* UNI=222, Hall=155 */
        {0}, /* UNI=222, Hall=156 */
        {0}, /* UNI=222, Hall=157 */
        {0}, /* UNI=222, Hall=158 */
        {0}, /* UNI=222, Hall=159 */
        {0}, /* UNI=222, Hall=160 */
    },
    {
        {0}, /* UNI=223, Hall=155 */
        {0}, /* UNI=223, Hall=156 */
        {0}, /* UNI=223, Hall=157 */
        {0}, /* UNI=223, Hall=158 */
        {0}, /* UNI=223, Hall=159 */
        {0}, /* UNI=223, Hall=160 */
    },
    {
        {0}, /* UNI=224, Hall=155 */
        {0}, /* UNI=224, Hall=156 */
        {0}, /* UNI=224, Hall=157 */
        {0}, /* UNI=224, Hall=158 */
        {0}, /* UNI=224, Hall=159 */
        {0}, /* UNI=224, Hall=160 */
    },
    {
        {0}, /* UNI=225, Hall=155 */
        {0}, /* UNI=225, Hall=156 */
        {0}, /* UNI=225, Hall=157 */
        {0}, /* UNI=225, Hall=158 */
        {0}, /* UNI=225, Hall=159 */
        {0}, /* UNI=225, Hall=160 */
    },
    {
        {0}, /* UNI=226, Hall=155 */
        {0}, /* UNI=226, Hall=156 */
        {0}, /* UNI=226, Hall=157 */
        {0}, /* UNI=226, Hall=158 */
        {0}, /* UNI=226, Hall=159 */
        {0}, /* UNI=226, Hall=160 */
    },
    {
        {0}, /* UNI=227, Hall=155 */
        {0}, /* UNI=227, Hall=156 */
        {0}, /* UNI=227, Hall=157 */
        {0}, /* UNI=227, Hall=158 */
        {0}, /* UNI=227, Hall=159 */
        {0}, /* UNI=227, Hall=160 */
    },
    {
        {0}, /* UNI=228, Hall=155 */
        {0}, /* UNI=228, Hall=156 */
        {0}, /* UNI=228, Hall=157 */
        {0}, /* UNI=228, Hall=158 */
        {0}, /* UNI=228, Hall=159 */
        {0}, /* UNI=228, Hall=160 */
    },
    {
        {0}, /* UNI=229, Hall=155 */
        {0}, /* UNI=229, Hall=156 */
        {0}, /* UNI=229, Hall=157 */
        {0}, /* UNI=229, Hall=158 */
        {0}, /* UNI=229, Hall=159 */
        {0}, /* UNI=229, Hall=160 */
    },
    {
        {0}, /* UNI=230, Hall=155 */
        {0}, /* UNI=230, Hall=156 */
        {0}, /* UNI=230, Hall=157 */
        {0}, /* UNI=230, Hall=158 */
        {0}, /* UNI=230, Hall=159 */
        {0}, /* UNI=230, Hall=160 */
    },
    {
        {0}, /* UNI=231, Hall=155 */
        {0}, /* UNI=231, Hall=156 */
        {0}, /* UNI=231, Hall=157 */
        {0}, /* UNI=231, Hall=158 */
        {0}, /* UNI=231, Hall=159 */
        {0}, /* UNI=231, Hall=160 */
    },
    {
        {0}, /* UNI=232, Hall=155 */
        {0}, /* UNI=232, Hall=156 */
        {0}, /* UNI=232, Hall=157 */
        {0}, /* UNI=232, Hall=158 */
        {0}, /* UNI=232, Hall=159 */
        {0}, /* UNI=232, Hall=160 */
    },
    {
        {0}, /* UNI=233, Hall=161 */
        {0}, /* UNI=233, Hall=162 */
        {0}, /* UNI=233, Hall=163 */
    },
    {
        {0}, /* UNI=234, Hall=161 */
        {0}, /* UNI=234, Hall=162 */
        {0}, /* UNI=234, Hall=163 */
    },
    {
        {7410, 0}, /* UNI=235, Hall=161 */
        {3250, 0}, /* UNI=235, Hall=162 */
        {9022, 0}, /* UNI=235, Hall=163 */
    },
    {
        {0}, /* UNI=236, Hall=161 */
        {0}, /* UNI=236, Hall=162 */
        {0}, /* UNI=236, Hall=163 */
    },
    {
        {0}, /* UNI=237, Hall=161 */
        {0}, /* UNI=237, Hall=162 */
        {0}, /* UNI=237, Hall=163 */
    },
    {
        {7410, 0}, /* UNI=238, Hall=161 */
        {3250, 0}, /* UNI=238, Hall=162 */
        {9022, 0}, /* UNI=238, Hall=163 */
    },
    {
        {0}, /* UNI=239, Hall=161 */
        {0}, /* UNI=239, Hall=162 */
        {0}, /* UNI=239, Hall=163 */
    },
    {
        {7410, 0}, /* UNI=240, Hall=161 */
        {3250, 0}, /* UNI=240, Hall=162 */
        {9022, 0}, /* UNI=240, Hall=163 */
    },
    {
        {0}, /* UNI=241, Hall=161 */
        {0}, /* UNI=241, Hall=162 */
        {0}, /* UNI=241, Hall=163 */
    },
    {
        {0}, /* UNI=242, Hall=164 */
        {0}, /* UNI=242, Hall=165 */
        {0}, /* UNI=242, Hall=166 */
        {0}, /* UNI=242, Hall=167 */
        {0}, /* UNI=242, Hall=168 */
        {0}, /* UNI=242, Hall=169 */
    },
    {
        {0}, /* UNI=243, Hall=164 */
        {0}, /* UNI=243, Hall=165 */
        {0}, /* UNI=243, Hall=166 */
        {0}, /* UNI=243, Hall=167 */
        {0}, /* UNI=243, Hall=168 */
        {0}, /* UNI=243, Hall=169 */
    },
    {
        {0}, /* UNI=244, Hall=164 */
        {0}, /* UNI=244, Hall=165 */
        {0}, /* UNI=244, Hall=166 */
        {0}, /* UNI=244, Hall=167 */
        {0}, /* UNI=244, Hall=168 */
        {0}, /* UNI=244, Hall=169 */
    },
    {
        {0}, /* UNI=245, Hall=164 */
        {0}, /* UNI=245, Hall=165 */
        {0}, /* UNI=245, Hall=166 */
        {0}, /* UNI=245, Hall=167 */
        {0}, /* UNI=245, Hall=168 */
        {0}, /* UNI=245, Hall=169 */
    },
    {
        {0}, /* UNI=246, Hall=164 */
        {0}, /* UNI=246, Hall=165 */
        {0}, /* UNI=246, Hall=166 */
        {0}, /* UNI=246, Hall=167 */
        {0}, /* UNI=246, Hall=168 */
        {0}, /* UNI=246, Hall=169 */
    },
    {
        {0}, /* UNI=247, Hall=164 */
        {0}, /* UNI=247, Hall=165 */
        {0}, /* UNI=247, Hall=166 */
        {0}, /* UNI=247, Hall=167 */
        {0}, /* UNI=247, Hall=168 */
        {0}, /* UNI=247, Hall=169 */
    },
    {
        {0}, /* UNI=248, Hall=164 */
        {0}, /* UNI=248, Hall=165 */
        {0}, /* UNI=248, Hall=166 */
        {0}, /* UNI=248, Hall=167 */
        {0}, /* UNI=248, Hall=168 */
        {0}, /* UNI=248, Hall=169 */
    },
    {
        {0}, /* UNI=249, Hall=164 */
        {0}, /* UNI=249, Hall=165 */
        {0}, /* UNI=249, Hall=166 */
        {0}, /* UNI=249, Hall=167 */
        {0}, /* UNI=249, Hall=168 */
        {0}, /* UNI=249, Hall=169 */
    },
    {
        {0}, /* UNI=250, Hall=164 */
        {0}, /* UNI=250, Hall=165 */
        {0}, /* UNI=250, Hall=166 */
        {0}, /* UNI=250, Hall=167 */
        {0}, /* UNI=250, Hall=168 */
        {0}, /* UNI=250, Hall=169 */
    },
    {
        {0}, /* UNI=251, Hall=164 */
        {0}, /* UNI=251, Hall=165 */
        {0}, /* UNI=251, Hall=166 */
        {0}, /* UNI=251, Hall=167 */
        {0}, /* UNI=251, Hall=168 */
        {0}, /* UNI=251, Hall=169 */
    },
    {
        {0}, /* UNI=252, Hall=164 */
        {0}, /* UNI=252, Hall=165 */
        {0}, /* UNI=252, Hall=166 */
        {0}, /* UNI=252, Hall=167 */
        {0}, /* UNI=252, Hall=168 */
        {0}, /* UNI=252, Hall=169 */
    },
    {
        {0}, /* UNI=253, Hall=164 */
        {0}, /* UNI=253, Hall=165 */
        {0}, /* UNI=253, Hall=166 */
        {0}, /* UNI=253, Hall=167 */
        {0}, /* UNI=253, Hall=168 */
        {0}, /* UNI=253, Hall=169 */
    },
    {
        {0}, /* UNI=254, Hall=170 */
        {0}, /* UNI=254, Hall=171 */
        {0}, /* UNI=254, Hall=172 */
    },
    {
        {0}, /* UNI=255, Hall=170 */
        {0}, /* UNI=255, Hall=171 */
        {0}, /* UNI=255, Hall=172 */
    },
    {
        {7410, 0}, /* UNI=256, Hall=170 */
        {3250, 0}, /* UNI=256, Hall=171 */
        {9022, 0}, /* UNI=256, Hall=172 */
    },
    {
        {0}, /* UNI=257, Hall=170 */
        {0}, /* UNI=257, Hall=171 */
        {0}, /* UNI=257, Hall=172 */
    },
    {
        {7410, 0}, /* UNI=258, Hall=170 */
        {3250, 0}, /* UNI=258, Hall=171 */
        {9022, 0}, /* UNI=258, Hall=172 */
    },
    {
        {0}, /* UNI=259, Hall=170 */
        {0}, /* UNI=259, Hall=171 */
        {0}, /* UNI=259, Hall=172 */
    },
    {
        {7410, 0}, /* UNI=260, Hall=170 */
        {3250, 0}, /* UNI=260, Hall=171 */
        {9022, 0}, /* UNI=260, Hall=172 */
    },
    {
        {0}, /* UNI=261, Hall=170 */
        {0}, /* UNI=261, Hall=171 */
        {0}, /* UNI=261, Hall=172 */
    },
    {
        {0}, /* UNI=262, Hall=170 */
        {0}, /* UNI=262, Hall=171 */
        {0}, /* UNI=262, Hall=172 */
    },
    {
        {0}, /* UNI=263, Hall=173 */
        {0}, /* UNI=263, Hall=174 */
        {0}, /* UNI=263, Hall=175 */
    },
    {
        {0}, /* UNI=264, Hall=173 */
        {0}, /* UNI=264, Hall=174 */
        {0}, /* UNI=264, Hall=175 */
    },
    {
        {7410, 0}, /* UNI=265, Hall=173 */
        {3250, 0}, /* UNI=265, Hall=174 */
        {9022, 0}, /* UNI=265, Hall=175 */
    },
    {
        {0}, /* UNI=266, Hall=173 */
        {0}, /* UNI=266, Hall=174 */
        {0}, /* UNI=266, Hall=175 */
    },
    {
        {0}, /* UNI=267, Hall=173 */
        {0}, /* UNI=267, Hall=174 */
        {0}, /* UNI=267, Hall=175 */
    },
    {
        {0}, /* UNI=268, Hall=173 */
        {0}, /* UNI=268, Hall=174 */
        {0}, /* UNI=268, Hall=175 */
    },
    {
        {0}, /* UNI=269, Hall=173 */
        {0}, /* UNI=269, Hall=174 */
        {0}, /* UNI=269, Hall=175 */
    },
    {
        {0}, /* UNI=270, Hall=176 */
        {0}, /* UNI=270, Hall=177 */
        {0}, /* UNI=270, Hall=178 */
        {0}, /* UNI=270, Hall=179 */
        {0}, /* UNI=270, Hall=180 */
        {0}, /* UNI=270, Hall=181 */
    },
    {
        {0}, /* UNI=271, Hall=176 */
        {0}, /* UNI=271, Hall=177 */
        {0}, /* UNI=271, Hall=178 */
        {0}, /* UNI=271, Hall=179 */
        {0}, /* UNI=271, Hall=180 */
        {0}, /* UNI=271, Hall=181 */
    },
    {
        {0}, /* UNI=272, Hall=176 */
        {0}, /* UNI=272, Hall=177 */
        {0}, /* UNI=272, Hall=178 */
        {0}, /* UNI=272, Hall=179 */
        {0}, /* UNI=272, Hall=180 */
        {0}, /* UNI=272, Hall=181 */
    },
    {
        {0}, /* UNI=273, Hall=176 */
        {0}, /* UNI=273, Hall=177 */
        {0}, /* UNI=273, Hall=178 */
        {0}, /* UNI=273, Hall=179 */
        {0}, /* UNI=273, Hall=180 */
        {0}, /* UNI=273, Hall=181 */
    },
    {
        {0}, /* UNI=274, Hall=176 */
        {0}, /* UNI=274, Hall=177 */
        {0}, /* UNI=274, Hall=178 */
        {0}, /* UNI=274, Hall=179 */
        {0}, /* UNI=274, Hall=180 */
        {0}, /* UNI=274, Hall=181 */
    },
    {
        {0}, /* UNI=275, Hall=176 */
        {0}, /* UNI=275, Hall=177 */
        {0}, /* UNI=275, Hall=178 */
        {0}, /* UNI=275, Hall=179 */
        {0}, /* UNI=275, Hall=180 */
        {0}, /* UNI=275, Hall=181 */
    },
    {
        {0}, /* UNI=276, Hall=176 */
        {0}, /* UNI=276, Hall=177 */
        {0}, /* UNI=276, Hall=178 */
        {0}, /* UNI=276, Hall=179 */
        {0}, /* UNI=276, Hall=180 */
        {0}, /* UNI=276, Hall=181 */
    },
    {
        {0}, /* UNI=277, Hall=176 */
        {0}, /* UNI=277, Hall=177 */
        {0}, /* UNI=277, Hall=178 */
        {0}, /* UNI=277, Hall=179 */
        {0}, /* UNI=277, Hall=180 */
        {0}, /* UNI=277, Hall=181 */
    },
    {
        {0}, /* UNI=278, Hall=182 */
        {0}, /* UNI=278, Hall=183 */
        {0}, /* UNI=278, Hall=184 */
    },
    {
        {0}, /* UNI=279, Hall=182 */
        {0}, /* UNI=279, Hall=183 */
        {0}, /* UNI=279, Hall=184 */
    },
    {
        {7410, 0}, /* UNI=280, Hall=182 */
        {3250, 0}, /* UNI=280, Hall=183 */
        {9022, 0}, /* UNI=280, Hall=184 */
    },
    {
        {0}, /* UNI=281, Hall=182 */
        {0}, /* UNI=281, Hall=183 */
        {0}, /* UNI=281, Hall=184 */
    },
    {
        {0}, /* UNI=282, Hall=182 */
        {0}, /* UNI=282, Hall=183 */
        {0}, /* UNI=282, Hall=184 */
    },
    {
        {0}, /* UNI=283, Hall=182 */
        {0}, /* UNI=283, Hall=183 */
        {0}, /* UNI=283, Hall=184 */
    },
    {
        {0}, /* UNI=284, Hall=182 */
        {0}, /* UNI=284, Hall=183 */
        {0}, /* UNI=284, Hall=184 */
    },
    {
        {0}, /* UNI=285, Hall=185 */
        {0}, /* UNI=285, Hall=186 */
        {0}, /* UNI=285, Hall=187 */
        {0}, /* UNI=285, Hall=188 */
        {0}, /* UNI=285, Hall=189 */
        {0}, /* UNI=285, Hall=190 */
    },
    {
        {0}, /* UNI=286, Hall=185 */
        {0}, /* UNI=286, Hall=186 */
        {0}, /* UNI=286, Hall=187 */
        {0}, /* UNI=286, Hall=188 */
        {0}, /* UNI=286, Hall=189 */
        {0}, /* UNI=286, Hall=190 */
    },
    {
        {0}, /* UNI=287, Hall=185 */
        {0}, /* UNI=287, Hall=186 */
        {0}, /* UNI=287, Hall=187 */
        {0}, /* UNI=287, Hall=188 */
        {0}, /* UNI=287, Hall=189 */
        {0}, /* UNI=287, Hall=190 */
    },
    {
        {0}, /* UNI=288, Hall=185 */
        {0}, /* UNI=288, Hall=186 */
        {0}, /* UNI=288, Hall=187 */
        {0}, /* UNI=288, Hall=188 */
        {0}, /* UNI=288, Hall=189 */
        {0}, /* UNI=288, Hall=190 */
    },
    {
        {0}, /* UNI=289, Hall=185 */
        {0}, /* UNI=289, Hall=186 */
        {0}, /* UNI=289, Hall=187 */
        {0}, /* UNI=289, Hall=188 */
        {0}, /* UNI=289, Hall=189 */
        {0}, /* UNI=289, Hall=190 */
    },
    {
        {0}, /* UNI=290, Hall=185 */
        {0}, /* UNI=290, Hall=186 */
        {0}, /* UNI=290, Hall=187 */
        {0}, /* UNI=290, Hall=188 */
        {0}, /* UNI=290, Hall=189 */
        {0}, /* UNI=290, Hall=190 */
    },
    {
        {0}, /* UNI=291, Hall=185 */
        {0}, /* UNI=291, Hall=186 */
        {0}, /* UNI=291, Hall=187 */
        {0}, /* UNI=291, Hall=188 */
        {0}, /* UNI=291, Hall=189 */
        {0}, /* UNI=291, Hall=190 */
    },
    {
        {0}, /* UNI=292, Hall=185 */
        {0}, /* UNI=292, Hall=186 */
        {0}, /* UNI=292, Hall=187 */
        {0}, /* UNI=292, Hall=188 */
        {0}, /* UNI=292, Hall=189 */
        {0}, /* UNI=292, Hall=190 */
    },
    {
        {0}, /* UNI=293, Hall=191 */
        {0}, /* UNI=293, Hall=192 */
        {0}, /* UNI=293, Hall=193 */
        {0}, /* UNI=293, Hall=194 */
        {0}, /* UNI=293, Hall=195 */
        {0}, /* UNI=293, Hall=196 */
    },
    {
        {0}, /* UNI=294, Hall=191 */
        {0}, /* UNI=294, Hall=192 */
        {0}, /* UNI=294, Hall=193 */
        {0}, /* UNI=294, Hall=194 */
        {0}, /* UNI=294, Hall=195 */
        {0}, /* UNI=294, Hall=196 */
    },
    {
        {0}, /* UNI=295, Hall=191 */
        {0}, /* UNI=295, Hall=192 */
        {0}, /* UNI=295, Hall=193 */
        {0}, /* UNI=295, Hall=194 */
        {0}, /* UNI=295, Hall=195 */
        {0}, /* UNI=295, Hall=196 */
    },
    {
        {0}, /* UNI=296, Hall=191 */
        {0}, /* UNI=296, Hall=192 */
        {0}, /* UNI=296, Hall=193 */
        {0}, /* UNI=296, Hall=194 */
        {0}, /* UNI=296, Hall=195 */
        {0}, /* UNI=296, Hall=196 */
    },
    {
        {0}, /* UNI=297, Hall=191 */
        {0}, /* UNI=297, Hall=192 */
        {0}, /* UNI=297, Hall=193 */
        {0}, /* UNI=297, Hall=194 */
        {0}, /* UNI=297, Hall=195 */
        {0}, /* UNI=297, Hall=196 */
    },
    {
        {0}, /* UNI=298, Hall=191 */
        {0}, /* UNI=298, Hall=192 */
        {0}, /* UNI=298, Hall=193 */
        {0}, /* UNI=298, Hall=194 */
        {0}, /* UNI=298, Hall=195 */
        {0}, /* UNI=298, Hall=196 */
    },
    {
        {0}, /* UNI=299, Hall=191 */
        {0}, /* UNI=299, Hall=192 */
        {0}, /* UNI=299, Hall=193 */
        {0}, /* UNI=299, Hall=194 */
        {0}, /* UNI=299, Hall=195 */
        {0}, /* UNI=299, Hall=196 */
    },
    {
        {0}, /* UNI=300, Hall=191 */
        {0}, /* UNI=300, Hall=192 */
        {0}, /* UNI=300, Hall=193 */
        {0}, /* UNI=300, Hall=194 */
        {0}, /* UNI=300, Hall=195 */
        {0}, /* UNI=300, Hall=196 */
    },
    {
        {0}, /* UNI=301, Hall=197 */
        {0}, /* UNI=301, Hall=198 */
        {0}, /* UNI=301, Hall=199 */
        {0}, /* UNI=301, Hall=200 */
        {0}, /* UNI=301, Hall=201 */
        {0}, /* UNI=301, Hall=202 */
    },
    {
        {0}, /* UNI=302, Hall=197 */
        {0}, /* UNI=302, Hall=198 */
        {0}, /* UNI=302, Hall=199 */
        {0}, /* UNI=302, Hall=200 */
        {0}, /* UNI=302, Hall=201 */
        {0}, /* UNI=302, Hall=202 */
    },
    {
        {0}, /* UNI=303, Hall=197 */
        {0}, /* UNI=303, Hall=198 */
        {0}, /* UNI=303, Hall=199 */
        {0}, /* UNI=303, Hall=200 */
        {0}, /* UNI=303, Hall=201 */
        {0}, /* UNI=303, Hall=202 */
    },
    {
        {0}, /* UNI=304, Hall=197 */
        {0}, /* UNI=304, Hall=198 */
        {0}, /* UNI=304, Hall=199 */
        {0}, /* UNI=304, Hall=200 */
        {0}, /* UNI=304, Hall=201 */
        {0}, /* UNI=304, Hall=202 */
    },
    {
        {0}, /* UNI=305, Hall=197 */
        {0}, /* UNI=305, Hall=198 */
        {0}, /* UNI=305, Hall=199 */
        {0}, /* UNI=305, Hall=200 */
        {0}, /* UNI=305, Hall=201 */
        {0}, /* UNI=305, Hall=202 */
    },
    {
        {0}, /* UNI=306, Hall=197 */
        {0}, /* UNI=306, Hall=198 */
        {0}, /* UNI=306, Hall=199 */
        {0}, /* UNI=306, Hall=200 */
        {0}, /* UNI=306, Hall=201 */
        {0}, /* UNI=306, Hall=202 */
    },
    {
        {0}, /* UNI=307, Hall=197 */
        {0}, /* UNI=307, Hall=198 */
        {0}, /* UNI=307, Hall=199 */
        {0}, /* UNI=307, Hall=200 */
        {0}, /* UNI=307, Hall=201 */
        {0}, /* UNI=307, Hall=202 */
    },
    {
        {0}, /* UNI=308, Hall=197 */
        {0}, /* UNI=308, Hall=198 */
        {0}, /* UNI=308, Hall=199 */
        {0}, /* UNI=308, Hall=200 */
        {0}, /* UNI=308, Hall=201 */
        {0}, /* UNI=308, Hall=202 */
    },
    {
        {0}, /* UNI=309, Hall=203 */
        {0}, /* UNI=309, Hall=204 */
        {0}, /* UNI=309, Hall=205 */
        {0}, /* UNI=309, Hall=206 */
        {0}, /* UNI=309, Hall=207 */
        {0}, /* UNI=309, Hall=208 */
    },
    {
        {0}, /* UNI=310, Hall=203 */
        {0}, /* UNI=310, Hall=204 */
        {0}, /* UNI=310, Hall=205 */
        {0}, /* UNI=310, Hall=206 */
        {0}, /* UNI=310, Hall=207 */
        {0}, /* UNI=310, Hall=208 */
    },
    {
        {0}, /* UNI=311, Hall=203 */
        {0}, /* UNI=311, Hall=204 */
        {0}, /* UNI=311, Hall=205 */
        {0}, /* UNI=311, Hall=206 */
        {0}, /* UNI=311, Hall=207 */
        {0}, /* UNI=311, Hall=208 */
    },
    {
        {0}, /* UNI=312, Hall=203 */
        {0}, /* UNI=312, Hall=204 */
        {0}, /* UNI=312, Hall=205 */
        {0}, /* UNI=312, Hall=206 */
        {0}, /* UNI=312, Hall=207 */
        {0}, /* UNI=312, Hall=208 */
    },
    {
        {0}, /* UNI=313, Hall=203 */
        {0}, /* UNI=313, Hall=204 */
        {0}, /* UNI=313, Hall=205 */
        {0}, /* UNI=313, Hall=206 */
        {0}, /* UNI=313, Hall=207 */
        {0}, /* UNI=313, Hall=208 */
    },
    {
        {0}, /* UNI=314, Hall=203 */
        {0}, /* UNI=314, Hall=204 */
        {0}, /* UNI=314, Hall=205 */
        {0}, /* UNI=314, Hall=206 */
        {0}, /* UNI=314, Hall=207 */
        {0}, /* UNI=314, Hall=208 */
    },
    {
        {0}, /* UNI=315, Hall=203 */
        {0}, /* UNI=315, Hall=204 */
        {0}, /* UNI=315, Hall=205 */
        {0}, /* UNI=315, Hall=206 */
        {0}, /* UNI=315, Hall=207 */
        {0}, /* UNI=315, Hall=208 */
    },
    {
        {0}, /* UNI=316, Hall=203 */
        {0}, /* UNI=316, Hall=204 */
        {0}, /* UNI=316, Hall=205 */
        {0}, /* UNI=316, Hall=206 */
        {0}, /* UNI=316, Hall=207 */
        {0}, /* UNI=316, Hall=208 */
    },
    {
        {0}, /* UNI=317, Hall=209 */
        {0}, /* UNI=317, Hall=210 */
        {0}, /* UNI=317, Hall=211 */
    },
    {
        {0}, /* UNI=318, Hall=209 */
        {0}, /* UNI=318, Hall=210 */
        {0}, /* UNI=318, Hall=211 */
    },
    {
        {7410, 0}, /* UNI=319, Hall=209 */
        {3250, 0}, /* UNI=319, Hall=210 */
        {9022, 0}, /* UNI=319, Hall=211 */
    },
    {
        {0}, /* UNI=320, Hall=209 */
        {0}, /* UNI=320, Hall=210 */
        {0}, /* UNI=320, Hall=211 */
    },
    {
        {0}, /* UNI=321, Hall=209 */
        {0}, /* UNI=321, Hall=210 */
        {0}, /* UNI=321, Hall=211 */
    },
    {
        {0}, /* UNI=322, Hall=212 */
        {0}, /* UNI=322, Hall=213 */
        {0}, /* UNI=322, Hall=214 */
    },
    {
        {0}, /* UNI=323, Hall=212 */
        {0}, /* UNI=323, Hall=213 */
        {0}, /* UNI=323, Hall=214 */
    },
    {
        {9219054, 0}, /* UNI=324, Hall=212 */
        {770887, 0},  /* UNI=324, Hall=213 */
        {8571127, 0}, /* UNI=324, Hall=214 */
    },
    {
        {0}, /* UNI=325, Hall=212 */
        {0}, /* UNI=325, Hall=213 */
        {0}, /* UNI=325, Hall=214 */
    },
    {
        {0}, /* UNI=326, Hall=212 */
        {0}, /* UNI=326, Hall=213 */
        {0}, /* UNI=326, Hall=214 */
    },
    {
        {0}, /* UNI=327, Hall=215 */
        {0}, /* UNI=327, Hall=216 */
        {0}, /* UNI=327, Hall=217 */
    },
    {
        {0}, /* UNI=328, Hall=215 */
        {0}, /* UNI=328, Hall=216 */
        {0}, /* UNI=328, Hall=217 */
    },
    {
        {7410, 0}, /* UNI=329, Hall=215 */
        {3250, 0}, /* UNI=329, Hall=216 */
        {9022, 0}, /* UNI=329, Hall=217 */
    },
    {
        {0}, /* UNI=330, Hall=215 */
        {0}, /* UNI=330, Hall=216 */
        {0}, /* UNI=330, Hall=217 */
    },
    {
        {0}, /* UNI=331, Hall=215 */
        {0}, /* UNI=331, Hall=216 */
        {0}, /* UNI=331, Hall=217 */
    },
    {
        {7410, 0}, /* UNI=332, Hall=215 */
        {3250, 0}, /* UNI=332, Hall=216 */
        {9022, 0}, /* UNI=332, Hall=217 */
    },
    {
        {0}, /* UNI=333, Hall=218 */
        {0}, /* UNI=333, Hall=219 */
        {0}, /* UNI=333, Hall=220 */
    },
    {
        {0}, /* UNI=334, Hall=218 */
        {0}, /* UNI=334, Hall=219 */
        {0}, /* UNI=334, Hall=220 */
    },
    {
        {7410, 0}, /* UNI=335, Hall=218 */
        {3250, 0}, /* UNI=335, Hall=219 */
        {9022, 0}, /* UNI=335, Hall=220 */
    },
    {
        {0}, /* UNI=336, Hall=218 */
        {0}, /* UNI=336, Hall=219 */
        {0}, /* UNI=336, Hall=220 */
    },
    {
        {0}, /* UNI=337, Hall=218 */
        {0}, /* UNI=337, Hall=219 */
        {0}, /* UNI=337, Hall=220 */
    },
    {
        {7410, 0}, /* UNI=338, Hall=218 */
        {3250, 0}, /* UNI=338, Hall=219 */
        {9022, 0}, /* UNI=338, Hall=220 */
    },
    {
        {0}, /* UNI=339, Hall=221 */
        {0}, /* UNI=339, Hall=222 */
        {0}, /* UNI=339, Hall=223 */
        {0}, /* UNI=339, Hall=224 */
        {0}, /* UNI=339, Hall=225 */
        {0}, /* UNI=339, Hall=226 */
    },
    {
        {0}, /* UNI=340, Hall=221 */
        {0}, /* UNI=340, Hall=222 */
        {0}, /* UNI=340, Hall=223 */
        {0}, /* UNI=340, Hall=224 */
        {0}, /* UNI=340, Hall=225 */
        {0}, /* UNI=340, Hall=226 */
    },
    {
        {0}, /* UNI=341, Hall=221 */
        {0}, /* UNI=341, Hall=222 */
        {0}, /* UNI=341, Hall=223 */
        {0}, /* UNI=341, Hall=224 */
        {0}, /* UNI=341, Hall=225 */
        {0}, /* UNI=341, Hall=226 */
    },
    {
        {0}, /* UNI=342, Hall=221 */
        {0}, /* UNI=342, Hall=222 */
        {0}, /* UNI=342, Hall=223 */
        {0}, /* UNI=342, Hall=224 */
        {0}, /* UNI=342, Hall=225 */
        {0}, /* UNI=342, Hall=226 */
    },
    {
        {0}, /* UNI=343, Hall=221 */
        {0}, /* UNI=343, Hall=222 */
        {0}, /* UNI=343, Hall=223 */
        {0}, /* UNI=343, Hall=224 */
        {0}, /* UNI=343, Hall=225 */
        {0}, /* UNI=343, Hall=226 */
    },
    {
        {0}, /* UNI=344, Hall=221 */
        {0}, /* UNI=344, Hall=222 */
        {0}, /* UNI=344, Hall=223 */
        {0}, /* UNI=344, Hall=224 */
        {0}, /* UNI=344, Hall=225 */
        {0}, /* UNI=344, Hall=226 */
    },
    {
        {0}, /* UNI=345, Hall=221 */
        {0}, /* UNI=345, Hall=222 */
        {0}, /* UNI=345, Hall=223 */
        {0}, /* UNI=345, Hall=224 */
        {0}, /* UNI=345, Hall=225 */
        {0}, /* UNI=345, Hall=226 */
    },
    {
        {0}, /* UNI=346, Hall=221 */
        {0}, /* UNI=346, Hall=222 */
        {0}, /* UNI=346, Hall=223 */
        {0}, /* UNI=346, Hall=224 */
        {0}, /* UNI=346, Hall=225 */
        {0}, /* UNI=346, Hall=226 */
    },
    {
        {0}, /* UNI=347, Hall=227 */
    },
    {
        {0}, /* UNI=348, Hall=227 */
    },
    {
        {7410, 8872, 0}, /* UNI=349, Hall=227 */
    },
    {
        {3250, 7636, 0}, /* UNI=350, Hall=227 */
    },
    {
        {0}, /* UNI=351, Hall=227 */
    },
    {
        {7410, 8872, 0}, /* UNI=352, Hall=227 */
    },
    {
        {3250, 7636, 0}, /* UNI=353, Hall=227 */
    },
    {
        {0}, /* UNI=354, Hall=227 */
    },
    {
        {0}, /* UNI=355, Hall=228 */
        {0}, /* UNI=355, Hall=229 */
    },
    {
        {0}, /* UNI=356, Hall=228 */
        {0}, /* UNI=356, Hall=229 */
    },
    {
        {7410, 8872, 0}, /* UNI=357, Hall=228 */
        {7410, 8872, 0}, /* UNI=357, Hall=229 */
    },
    {
        {3250, 7636, 0}, /* UNI=358, Hall=228 */
        {3250, 7636, 0}, /* UNI=358, Hall=229 */
    },
    {
        {0}, /* UNI=359, Hall=228 */
        {0}, /* UNI=359, Hall=229 */
    },
    {
        {3250, 7636, 0}, /* UNI=360, Hall=228 */
        {3250, 7636, 0}, /* UNI=360, Hall=229 */
    },
    {
        {3250, 7636, 0}, /* UNI=361, Hall=228 */
        {3250, 7636, 0}, /* UNI=361, Hall=229 */
    },
    {
        {0}, /* UNI=362, Hall=228 */
        {0}, /* UNI=362, Hall=229 */
    },
    {
        {0}, /* UNI=363, Hall=230 */
        {0}, /* UNI=363, Hall=231 */
        {0}, /* UNI=363, Hall=232 */
    },
    {
        {0}, /* UNI=364, Hall=230 */
        {0}, /* UNI=364, Hall=231 */
        {0}, /* UNI=364, Hall=232 */
    },
    {
        {7410, 0}, /* UNI=365, Hall=230 */
        {3250, 0}, /* UNI=365, Hall=231 */
        {9022, 0}, /* UNI=365, Hall=232 */
    },
    {
        {0}, /* UNI=366, Hall=230 */
        {0}, /* UNI=366, Hall=231 */
        {0}, /* UNI=366, Hall=232 */
    },
    {
        {0}, /* UNI=367, Hall=230 */
        {0}, /* UNI=367, Hall=231 */
        {0}, /* UNI=367, Hall=232 */
    },
    {
        {7410, 0}, /* UNI=368, Hall=230 */
        {3250, 0}, /* UNI=368, Hall=231 */
        {9022, 0}, /* UNI=368, Hall=232 */
    },
    {
        {0}, /* UNI=369, Hall=230 */
        {0}, /* UNI=369, Hall=231 */
        {0}, /* UNI=369, Hall=232 */
    },
    {
        {7410, 0}, /* UNI=370, Hall=230 */
        {3250, 0}, /* UNI=370, Hall=231 */
        {9022, 0}, /* UNI=370, Hall=232 */
    },
    {
        {0}, /* UNI=371, Hall=230 */
        {0}, /* UNI=371, Hall=231 */
        {0}, /* UNI=371, Hall=232 */
    },
    {
        {7410, 0}, /* UNI=372, Hall=230 */
        {3250, 0}, /* UNI=372, Hall=231 */
        {9022, 0}, /* UNI=372, Hall=232 */
    },
    {
        {0}, /* UNI=373, Hall=230 */
        {0}, /* UNI=373, Hall=231 */
        {0}, /* UNI=373, Hall=232 */
    },
    {
        {0}, /* UNI=374, Hall=230 */
        {0}, /* UNI=374, Hall=231 */
        {0}, /* UNI=374, Hall=232 */
    },
    {
        {0}, /* UNI=375, Hall=233 */
        {0}, /* UNI=375, Hall=234 */
        {0}, /* UNI=375, Hall=235 */
        {0}, /* UNI=375, Hall=236 */
        {0}, /* UNI=375, Hall=237 */
        {0}, /* UNI=375, Hall=238 */
    },
    {
        {0}, /* UNI=376, Hall=233 */
        {0}, /* UNI=376, Hall=234 */
        {0}, /* UNI=376, Hall=235 */
        {0}, /* UNI=376, Hall=236 */
        {0}, /* UNI=376, Hall=237 */
        {0}, /* UNI=376, Hall=238 */
    },
    {
        {7410, 0}, /* UNI=377, Hall=233 */
        {7410, 0}, /* UNI=377, Hall=234 */
        {3250, 0}, /* UNI=377, Hall=235 */
        {3250, 0}, /* UNI=377, Hall=236 */
        {9022, 0}, /* UNI=377, Hall=237 */
        {9022, 0}, /* UNI=377, Hall=238 */
    },
    {
        {0}, /* UNI=378, Hall=233 */
        {0}, /* UNI=378, Hall=234 */
        {0}, /* UNI=378, Hall=235 */
        {0}, /* UNI=378, Hall=236 */
        {0}, /* UNI=378, Hall=237 */
        {0}, /* UNI=378, Hall=238 */
    },
    {
        {0}, /* UNI=379, Hall=233 */
        {0}, /* UNI=379, Hall=234 */
        {0}, /* UNI=379, Hall=235 */
        {0}, /* UNI=379, Hall=236 */
        {0}, /* UNI=379, Hall=237 */
        {0}, /* UNI=379, Hall=238 */
    },
    {
        {7410, 0}, /* UNI=380, Hall=233 */
        {7410, 0}, /* UNI=380, Hall=234 */
        {3250, 0}, /* UNI=380, Hall=235 */
        {3250, 0}, /* UNI=380, Hall=236 */
        {9022, 0}, /* UNI=380, Hall=237 */
        {9022, 0}, /* UNI=380, Hall=238 */
    },
    {
        {0}, /* UNI=381, Hall=233 */
        {0}, /* UNI=381, Hall=234 */
        {0}, /* UNI=381, Hall=235 */
        {0}, /* UNI=381, Hall=236 */
        {0}, /* UNI=381, Hall=237 */
        {0}, /* UNI=381, Hall=238 */
    },
    {
        {7410, 0}, /* UNI=382, Hall=233 */
        {7410, 0}, /* UNI=382, Hall=234 */
        {3250, 0}, /* UNI=382, Hall=235 */
        {3250, 0}, /* UNI=382, Hall=236 */
        {9022, 0}, /* UNI=382, Hall=237 */
        {9022, 0}, /* UNI=382, Hall=238 */
    },
    {
        {0}, /* UNI=383, Hall=233 */
        {0}, /* UNI=383, Hall=234 */
        {0}, /* UNI=383, Hall=235 */
        {0}, /* UNI=383, Hall=236 */
        {0}, /* UNI=383, Hall=237 */
        {0}, /* UNI=383, Hall=238 */
    },
    {
        {7410, 0}, /* UNI=384, Hall=233 */
        {7410, 0}, /* UNI=384, Hall=234 */
        {3250, 0}, /* UNI=384, Hall=235 */
        {3250, 0}, /* UNI=384, Hall=236 */
        {9022, 0}, /* UNI=384, Hall=237 */
        {9022, 0}, /* UNI=384, Hall=238 */
    },
    {
        {0}, /* UNI=385, Hall=233 */
        {0}, /* UNI=385, Hall=234 */
        {0}, /* UNI=385, Hall=235 */
        {0}, /* UNI=385, Hall=236 */
        {0}, /* UNI=385, Hall=237 */
        {0}, /* UNI=385, Hall=238 */
    },
    {
        {0}, /* UNI=386, Hall=233 */
        {0}, /* UNI=386, Hall=234 */
        {0}, /* UNI=386, Hall=235 */
        {0}, /* UNI=386, Hall=236 */
        {0}, /* UNI=386, Hall=237 */
        {0}, /* UNI=386, Hall=238 */
    },
    {
        {0}, /* UNI=387, Hall=239 */
        {0}, /* UNI=387, Hall=240 */
        {0}, /* UNI=387, Hall=241 */
        {0}, /* UNI=387, Hall=242 */
        {0}, /* UNI=387, Hall=243 */
        {0}, /* UNI=387, Hall=244 */
    },
    {
        {0}, /* UNI=388, Hall=239 */
        {0}, /* UNI=388, Hall=240 */
        {0}, /* UNI=388, Hall=241 */
        {0}, /* UNI=388, Hall=242 */
        {0}, /* UNI=388, Hall=243 */
        {0}, /* UNI=388, Hall=244 */
    },
    {
        {0}, /* UNI=389, Hall=239 */
        {0}, /* UNI=389, Hall=240 */
        {0}, /* UNI=389, Hall=241 */
        {0}, /* UNI=389, Hall=242 */
        {0}, /* UNI=389, Hall=243 */
        {0}, /* UNI=389, Hall=244 */
    },
    {
        {0}, /* UNI=390, Hall=239 */
        {0}, /* UNI=390, Hall=240 */
        {0}, /* UNI=390, Hall=241 */
        {0}, /* UNI=390, Hall=242 */
        {0}, /* UNI=390, Hall=243 */
        {0}, /* UNI=390, Hall=244 */
    },
    {
        {0}, /* UNI=391, Hall=239 */
        {0}, /* UNI=391, Hall=240 */
        {0}, /* UNI=391, Hall=241 */
        {0}, /* UNI=391, Hall=242 */
        {0}, /* UNI=391, Hall=243 */
        {0}, /* UNI=391, Hall=244 */
    },
    {
        {0}, /* UNI=392, Hall=239 */
        {0}, /* UNI=392, Hall=240 */
        {0}, /* UNI=392, Hall=241 */
        {0}, /* UNI=392, Hall=242 */
        {0}, /* UNI=392, Hall=243 */
        {0}, /* UNI=392, Hall=244 */
    },
    {
        {0}, /* UNI=393, Hall=239 */
        {0}, /* UNI=393, Hall=240 */
        {0}, /* UNI=393, Hall=241 */
        {0}, /* UNI=393, Hall=242 */
        {0}, /* UNI=393, Hall=243 */
        {0}, /* UNI=393, Hall=244 */
    },
    {
        {0}, /* UNI=394, Hall=239 */
        {0}, /* UNI=394, Hall=240 */
        {0}, /* UNI=394, Hall=241 */
        {0}, /* UNI=394, Hall=242 */
        {0}, /* UNI=394, Hall=243 */
        {0}, /* UNI=394, Hall=244 */
    },
    {
        {0}, /* UNI=395, Hall=239 */
        {0}, /* UNI=395, Hall=240 */
        {0}, /* UNI=395, Hall=241 */
        {0}, /* UNI=395, Hall=242 */
        {0}, /* UNI=395, Hall=243 */
        {0}, /* UNI=395, Hall=244 */
    },
    {
        {0}, /* UNI=396, Hall=239 */
        {0}, /* UNI=396, Hall=240 */
        {0}, /* UNI=396, Hall=241 */
        {0}, /* UNI=396, Hall=242 */
        {0}, /* UNI=396, Hall=243 */
        {0}, /* UNI=396, Hall=244 */
    },
    {
        {0}, /* UNI=397, Hall=239 */
        {0}, /* UNI=397, Hall=240 */
        {0}, /* UNI=397, Hall=241 */
        {0}, /* UNI=397, Hall=242 */
        {0}, /* UNI=397, Hall=243 */
        {0}, /* UNI=397, Hall=244 */
    },
    {
        {0}, /* UNI=398, Hall=239 */
        {0}, /* UNI=398, Hall=240 */
        {0}, /* UNI=398, Hall=241 */
        {0}, /* UNI=398, Hall=242 */
        {0}, /* UNI=398, Hall=243 */
        {0}, /* UNI=398, Hall=244 */
    },
    {
        {0}, /* UNI=399, Hall=239 */
        {0}, /* UNI=399, Hall=240 */
        {0}, /* UNI=399, Hall=241 */
        {0}, /* UNI=399, Hall=242 */
        {0}, /* UNI=399, Hall=243 */
        {0}, /* UNI=399, Hall=244 */
    },
    {
        {0}, /* UNI=400, Hall=239 */
        {0}, /* UNI=400, Hall=240 */
        {0}, /* UNI=400, Hall=241 */
        {0}, /* UNI=400, Hall=242 */
        {0}, /* UNI=400, Hall=243 */
        {0}, /* UNI=400, Hall=244 */
    },
    {
        {0}, /* UNI=401, Hall=239 */
        {0}, /* UNI=401, Hall=240 */
        {0}, /* UNI=401, Hall=241 */
        {0}, /* UNI=401, Hall=242 */
        {0}, /* UNI=401, Hall=243 */
        {0}, /* UNI=401, Hall=244 */
    },
    {
        {0}, /* UNI=402, Hall=239 */
        {0}, /* UNI=402, Hall=240 */
        {0}, /* UNI=402, Hall=241 */
        {0}, /* UNI=402, Hall=242 */
        {0}, /* UNI=402, Hall=243 */
        {0}, /* UNI=402, Hall=244 */
    },
    {
        {0}, /* UNI=403, Hall=245 */
        {0}, /* UNI=403, Hall=246 */
        {0}, /* UNI=403, Hall=247 */
        {0}, /* UNI=403, Hall=248 */
        {0}, /* UNI=403, Hall=249 */
        {0}, /* UNI=403, Hall=250 */
    },
    {
        {0}, /* UNI=404, Hall=245 */
        {0}, /* UNI=404, Hall=246 */
        {0}, /* UNI=404, Hall=247 */
        {0}, /* UNI=404, Hall=248 */
        {0}, /* UNI=404, Hall=249 */
        {0}, /* UNI=404, Hall=250 */
    },
    {
        {0}, /* UNI=405, Hall=245 */
        {0}, /* UNI=405, Hall=246 */
        {0}, /* UNI=405, Hall=247 */
        {0}, /* UNI=405, Hall=248 */
        {0}, /* UNI=405, Hall=249 */
        {0}, /* UNI=405, Hall=250 */
    },
    {
        {0}, /* UNI=406, Hall=245 */
        {0}, /* UNI=406, Hall=246 */
        {0}, /* UNI=406, Hall=247 */
        {0}, /* UNI=406, Hall=248 */
        {0}, /* UNI=406, Hall=249 */
        {0}, /* UNI=406, Hall=250 */
    },
    {
        {0}, /* UNI=407, Hall=245 */
        {0}, /* UNI=407, Hall=246 */
        {0}, /* UNI=407, Hall=247 */
        {0}, /* UNI=407, Hall=248 */
        {0}, /* UNI=407, Hall=249 */
        {0}, /* UNI=407, Hall=250 */
    },
    {
        {0}, /* UNI=408, Hall=245 */
        {0}, /* UNI=408, Hall=246 */
        {0}, /* UNI=408, Hall=247 */
        {0}, /* UNI=408, Hall=248 */
        {0}, /* UNI=408, Hall=249 */
        {0}, /* UNI=408, Hall=250 */
    },
    {
        {0}, /* UNI=409, Hall=245 */
        {0}, /* UNI=409, Hall=246 */
        {0}, /* UNI=409, Hall=247 */
        {0}, /* UNI=409, Hall=248 */
        {0}, /* UNI=409, Hall=249 */
        {0}, /* UNI=409, Hall=250 */
    },
    {
        {0}, /* UNI=410, Hall=245 */
        {0}, /* UNI=410, Hall=246 */
        {0}, /* UNI=410, Hall=247 */
        {0}, /* UNI=410, Hall=248 */
        {0}, /* UNI=410, Hall=249 */
        {0}, /* UNI=410, Hall=250 */
    },
    {
        {0}, /* UNI=411, Hall=245 */
        {0}, /* UNI=411, Hall=246 */
        {0}, /* UNI=411, Hall=247 */
        {0}, /* UNI=411, Hall=248 */
        {0}, /* UNI=411, Hall=249 */
        {0}, /* UNI=411, Hall=250 */
    },
    {
        {0}, /* UNI=412, Hall=245 */
        {0}, /* UNI=412, Hall=246 */
        {0}, /* UNI=412, Hall=247 */
        {0}, /* UNI=412, Hall=248 */
        {0}, /* UNI=412, Hall=249 */
        {0}, /* UNI=412, Hall=250 */
    },
    {
        {0}, /* UNI=413, Hall=245 */
        {0}, /* UNI=413, Hall=246 */
        {0}, /* UNI=413, Hall=247 */
        {0}, /* UNI=413, Hall=248 */
        {0}, /* UNI=413, Hall=249 */
        {0}, /* UNI=413, Hall=250 */
    },
    {
        {0}, /* UNI=414, Hall=245 */
        {0}, /* UNI=414, Hall=246 */
        {0}, /* UNI=414, Hall=247 */
        {0}, /* UNI=414, Hall=248 */
        {0}, /* UNI=414, Hall=249 */
        {0}, /* UNI=414, Hall=250 */
    },
    {
        {0}, /* UNI=415, Hall=245 */
        {0}, /* UNI=415, Hall=246 */
        {0}, /* UNI=415, Hall=247 */
        {0}, /* UNI=415, Hall=248 */
        {0}, /* UNI=415, Hall=249 */
        {0}, /* UNI=415, Hall=250 */
    },
    {
        {0}, /* UNI=416, Hall=245 */
        {0}, /* UNI=416, Hall=246 */
        {0}, /* UNI=416, Hall=247 */
        {0}, /* UNI=416, Hall=248 */
        {0}, /* UNI=416, Hall=249 */
        {0}, /* UNI=416, Hall=250 */
    },
    {
        {0}, /* UNI=417, Hall=245 */
        {0}, /* UNI=417, Hall=246 */
        {0}, /* UNI=417, Hall=247 */
        {0}, /* UNI=417, Hall=248 */
        {0}, /* UNI=417, Hall=249 */
        {0}, /* UNI=417, Hall=250 */
    },
    {
        {0}, /* UNI=418, Hall=245 */
        {0}, /* UNI=418, Hall=246 */
        {0}, /* UNI=418, Hall=247 */
        {0}, /* UNI=418, Hall=248 */
        {0}, /* UNI=418, Hall=249 */
        {0}, /* UNI=418, Hall=250 */
    },
    {
        {0}, /* UNI=419, Hall=251 */
        {0}, /* UNI=419, Hall=252 */
        {0}, /* UNI=419, Hall=253 */
        {0}, /* UNI=419, Hall=254 */
        {0}, /* UNI=419, Hall=255 */
        {0}, /* UNI=419, Hall=256 */
    },
    {
        {0}, /* UNI=420, Hall=251 */
        {0}, /* UNI=420, Hall=252 */
        {0}, /* UNI=420, Hall=253 */
        {0}, /* UNI=420, Hall=254 */
        {0}, /* UNI=420, Hall=255 */
        {0}, /* UNI=420, Hall=256 */
    },
    {
        {0}, /* UNI=421, Hall=251 */
        {0}, /* UNI=421, Hall=252 */
        {0}, /* UNI=421, Hall=253 */
        {0}, /* UNI=421, Hall=254 */
        {0}, /* UNI=421, Hall=255 */
        {0}, /* UNI=421, Hall=256 */
    },
    {
        {0}, /* UNI=422, Hall=251 */
        {0}, /* UNI=422, Hall=252 */
        {0}, /* UNI=422, Hall=253 */
        {0}, /* UNI=422, Hall=254 */
        {0}, /* UNI=422, Hall=255 */
        {0}, /* UNI=422, Hall=256 */
    },
    {
        {0}, /* UNI=423, Hall=251 */
        {0}, /* UNI=423, Hall=252 */
        {0}, /* UNI=423, Hall=253 */
        {0}, /* UNI=423, Hall=254 */
        {0}, /* UNI=423, Hall=255 */
        {0}, /* UNI=423, Hall=256 */
    },
    {
        {0}, /* UNI=424, Hall=251 */
        {0}, /* UNI=424, Hall=252 */
        {0}, /* UNI=424, Hall=253 */
        {0}, /* UNI=424, Hall=254 */
        {0}, /* UNI=424, Hall=255 */
        {0}, /* UNI=424, Hall=256 */
    },
    {
        {0}, /* UNI=425, Hall=251 */
        {0}, /* UNI=425, Hall=252 */
        {0}, /* UNI=425, Hall=253 */
        {0}, /* UNI=425, Hall=254 */
        {0}, /* UNI=425, Hall=255 */
        {0}, /* UNI=425, Hall=256 */
    },
    {
        {0}, /* UNI=426, Hall=251 */
        {0}, /* UNI=426, Hall=252 */
        {0}, /* UNI=426, Hall=253 */
        {0}, /* UNI=426, Hall=254 */
        {0}, /* UNI=426, Hall=255 */
        {0}, /* UNI=426, Hall=256 */
    },
    {
        {0}, /* UNI=427, Hall=251 */
        {0}, /* UNI=427, Hall=252 */
        {0}, /* UNI=427, Hall=253 */
        {0}, /* UNI=427, Hall=254 */
        {0}, /* UNI=427, Hall=255 */
        {0}, /* UNI=427, Hall=256 */
    },
    {
        {0}, /* UNI=428, Hall=251 */
        {0}, /* UNI=428, Hall=252 */
        {0}, /* UNI=428, Hall=253 */
        {0}, /* UNI=428, Hall=254 */
        {0}, /* UNI=428, Hall=255 */
        {0}, /* UNI=428, Hall=256 */
    },
    {
        {0}, /* UNI=429, Hall=251 */
        {0}, /* UNI=429, Hall=252 */
        {0}, /* UNI=429, Hall=253 */
        {0}, /* UNI=429, Hall=254 */
        {0}, /* UNI=429, Hall=255 */
        {0}, /* UNI=429, Hall=256 */
    },
    {
        {0}, /* UNI=430, Hall=251 */
        {0}, /* UNI=430, Hall=252 */
        {0}, /* UNI=430, Hall=253 */
        {0}, /* UNI=430, Hall=254 */
        {0}, /* UNI=430, Hall=255 */
        {0}, /* UNI=430, Hall=256 */
    },
    {
        {0}, /* UNI=431, Hall=251 */
        {0}, /* UNI=431, Hall=252 */
        {0}, /* UNI=431, Hall=253 */
        {0}, /* UNI=431, Hall=254 */
        {0}, /* UNI=431, Hall=255 */
        {0}, /* UNI=431, Hall=256 */
    },
    {
        {0}, /* UNI=432, Hall=251 */
        {0}, /* UNI=432, Hall=252 */
        {0}, /* UNI=432, Hall=253 */
        {0}, /* UNI=432, Hall=254 */
        {0}, /* UNI=432, Hall=255 */
        {0}, /* UNI=432, Hall=256 */
    },
    {
        {0}, /* UNI=433, Hall=251 */
        {0}, /* UNI=433, Hall=252 */
        {0}, /* UNI=433, Hall=253 */
        {0}, /* UNI=433, Hall=254 */
        {0}, /* UNI=433, Hall=255 */
        {0}, /* UNI=433, Hall=256 */
    },
    {
        {0}, /* UNI=434, Hall=251 */
        {0}, /* UNI=434, Hall=252 */
        {0}, /* UNI=434, Hall=253 */
        {0}, /* UNI=434, Hall=254 */
        {0}, /* UNI=434, Hall=255 */
        {0}, /* UNI=434, Hall=256 */
    },
    {
        {0}, /* UNI=435, Hall=257 */
        {0}, /* UNI=435, Hall=258 */
        {0}, /* UNI=435, Hall=259 */
        {0}, /* UNI=435, Hall=260 */
        {0}, /* UNI=435, Hall=261 */
        {0}, /* UNI=435, Hall=262 */
    },
    {
        {0}, /* UNI=436, Hall=257 */
        {0}, /* UNI=436, Hall=258 */
        {0}, /* UNI=436, Hall=259 */
        {0}, /* UNI=436, Hall=260 */
        {0}, /* UNI=436, Hall=261 */
        {0}, /* UNI=436, Hall=262 */
    },
    {
        {0}, /* UNI=437, Hall=257 */
        {0}, /* UNI=437, Hall=258 */
        {0}, /* UNI=437, Hall=259 */
        {0}, /* UNI=437, Hall=260 */
        {0}, /* UNI=437, Hall=261 */
        {0}, /* UNI=437, Hall=262 */
    },
    {
        {0}, /* UNI=438, Hall=257 */
        {0}, /* UNI=438, Hall=258 */
        {0}, /* UNI=438, Hall=259 */
        {0}, /* UNI=438, Hall=260 */
        {0}, /* UNI=438, Hall=261 */
        {0}, /* UNI=438, Hall=262 */
    },
    {
        {0}, /* UNI=439, Hall=257 */
        {0}, /* UNI=439, Hall=258 */
        {0}, /* UNI=439, Hall=259 */
        {0}, /* UNI=439, Hall=260 */
        {0}, /* UNI=439, Hall=261 */
        {0}, /* UNI=439, Hall=262 */
    },
    {
        {0}, /* UNI=440, Hall=257 */
        {0}, /* UNI=440, Hall=258 */
        {0}, /* UNI=440, Hall=259 */
        {0}, /* UNI=440, Hall=260 */
        {0}, /* UNI=440, Hall=261 */
        {0}, /* UNI=440, Hall=262 */
    },
    {
        {0}, /* UNI=441, Hall=257 */
        {0}, /* UNI=441, Hall=258 */
        {0}, /* UNI=441, Hall=259 */
        {0}, /* UNI=441, Hall=260 */
        {0}, /* UNI=441, Hall=261 */
        {0}, /* UNI=441, Hall=262 */
    },
    {
        {0}, /* UNI=442, Hall=257 */
        {0}, /* UNI=442, Hall=258 */
        {0}, /* UNI=442, Hall=259 */
        {0}, /* UNI=442, Hall=260 */
        {0}, /* UNI=442, Hall=261 */
        {0}, /* UNI=442, Hall=262 */
    },
    {
        {0}, /* UNI=443, Hall=257 */
        {0}, /* UNI=443, Hall=258 */
        {0}, /* UNI=443, Hall=259 */
        {0}, /* UNI=443, Hall=260 */
        {0}, /* UNI=443, Hall=261 */
        {0}, /* UNI=443, Hall=262 */
    },
    {
        {0}, /* UNI=444, Hall=257 */
        {0}, /* UNI=444, Hall=258 */
        {0}, /* UNI=444, Hall=259 */
        {0}, /* UNI=444, Hall=260 */
        {0}, /* UNI=444, Hall=261 */
        {0}, /* UNI=444, Hall=262 */
    },
    {
        {0}, /* UNI=445, Hall=257 */
        {0}, /* UNI=445, Hall=258 */
        {0}, /* UNI=445, Hall=259 */
        {0}, /* UNI=445, Hall=260 */
        {0}, /* UNI=445, Hall=261 */
        {0}, /* UNI=445, Hall=262 */
    },
    {
        {0}, /* UNI=446, Hall=257 */
        {0}, /* UNI=446, Hall=258 */
        {0}, /* UNI=446, Hall=259 */
        {0}, /* UNI=446, Hall=260 */
        {0}, /* UNI=446, Hall=261 */
        {0}, /* UNI=446, Hall=262 */
    },
    {
        {0}, /* UNI=447, Hall=257 */
        {0}, /* UNI=447, Hall=258 */
        {0}, /* UNI=447, Hall=259 */
        {0}, /* UNI=447, Hall=260 */
        {0}, /* UNI=447, Hall=261 */
        {0}, /* UNI=447, Hall=262 */
    },
    {
        {0}, /* UNI=448, Hall=257 */
        {0}, /* UNI=448, Hall=258 */
        {0}, /* UNI=448, Hall=259 */
        {0}, /* UNI=448, Hall=260 */
        {0}, /* UNI=448, Hall=261 */
        {0}, /* UNI=448, Hall=262 */
    },
    {
        {0}, /* UNI=449, Hall=257 */
        {0}, /* UNI=449, Hall=258 */
        {0}, /* UNI=449, Hall=259 */
        {0}, /* UNI=449, Hall=260 */
        {0}, /* UNI=449, Hall=261 */
        {0}, /* UNI=449, Hall=262 */
    },
    {
        {0}, /* UNI=450, Hall=257 */
        {0}, /* UNI=450, Hall=258 */
        {0}, /* UNI=450, Hall=259 */
        {0}, /* UNI=450, Hall=260 */
        {0}, /* UNI=450, Hall=261 */
        {0}, /* UNI=450, Hall=262 */
    },
    {
        {0}, /* UNI=451, Hall=263 */
        {0}, /* UNI=451, Hall=264 */
        {0}, /* UNI=451, Hall=265 */
    },
    {
        {0}, /* UNI=452, Hall=263 */
        {0}, /* UNI=452, Hall=264 */
        {0}, /* UNI=452, Hall=265 */
    },
    {
        {7410, 0}, /* UNI=453, Hall=263 */
        {3250, 0}, /* UNI=453, Hall=264 */
        {9022, 0}, /* UNI=453, Hall=265 */
    },
    {
        {0}, /* UNI=454, Hall=263 */
        {0}, /* UNI=454, Hall=264 */
        {0}, /* UNI=454, Hall=265 */
    },
    {
        {0}, /* UNI=455, Hall=263 */
        {0}, /* UNI=455, Hall=264 */
        {0}, /* UNI=455, Hall=265 */
    },
    {
        {7410, 0}, /* UNI=456, Hall=263 */
        {3250, 0}, /* UNI=456, Hall=264 */
        {9022, 0}, /* UNI=456, Hall=265 */
    },
    {
        {0}, /* UNI=457, Hall=263 */
        {0}, /* UNI=457, Hall=264 */
        {0}, /* UNI=457, Hall=265 */
    },
    {
        {7410, 0}, /* UNI=458, Hall=263 */
        {3250, 0}, /* UNI=458, Hall=264 */
        {9022, 0}, /* UNI=458, Hall=265 */
    },
    {
        {0}, /* UNI=459, Hall=263 */
        {0}, /* UNI=459, Hall=264 */
        {0}, /* UNI=459, Hall=265 */
    },
    {
        {7410, 0}, /* UNI=460, Hall=263 */
        {3250, 0}, /* UNI=460, Hall=264 */
        {9022, 0}, /* UNI=460, Hall=265 */
    },
    {
        {0}, /* UNI=461, Hall=263 */
        {0}, /* UNI=461, Hall=264 */
        {0}, /* UNI=461, Hall=265 */
    },
    {
        {0}, /* UNI=462, Hall=263 */
        {0}, /* UNI=462, Hall=264 */
        {0}, /* UNI=462, Hall=265 */
    },
    {
        {0}, /* UNI=463, Hall=266 */
        {0}, /* UNI=463, Hall=267 */
        {0}, /* UNI=463, Hall=268 */
    },
    {
        {0}, /* UNI=464, Hall=266 */
        {0}, /* UNI=464, Hall=267 */
        {0}, /* UNI=464, Hall=268 */
    },
    {
        {7410, 0}, /* UNI=465, Hall=266 */
        {3250, 0}, /* UNI=465, Hall=267 */
        {9022, 0}, /* UNI=465, Hall=268 */
    },
    {
        {0}, /* UNI=466, Hall=266 */
        {0}, /* UNI=466, Hall=267 */
        {0}, /* UNI=466, Hall=268 */
    },
    {
        {0}, /* UNI=467, Hall=266 */
        {0}, /* UNI=467, Hall=267 */
        {0}, /* UNI=467, Hall=268 */
    },
    {
        {7410, 0}, /* UNI=468, Hall=266 */
        {3250, 0}, /* UNI=468, Hall=267 */
        {9022, 0}, /* UNI=468, Hall=268 */
    },
    {
        {0}, /* UNI=469, Hall=266 */
        {0}, /* UNI=469, Hall=267 */
        {0}, /* UNI=469, Hall=268 */
    },
    {
        {7410, 0}, /* UNI=470, Hall=266 */
        {3250, 0}, /* UNI=470, Hall=267 */
        {9022, 0}, /* UNI=470, Hall=268 */
    },
    {
        {0}, /* UNI=471, Hall=266 */
        {0}, /* UNI=471, Hall=267 */
        {0}, /* UNI=471, Hall=268 */
    },
    {
        {7410, 0}, /* UNI=472, Hall=266 */
        {3250, 0}, /* UNI=472, Hall=267 */
        {9022, 0}, /* UNI=472, Hall=268 */
    },
    {
        {0}, /* UNI=473, Hall=266 */
        {0}, /* UNI=473, Hall=267 */
        {0}, /* UNI=473, Hall=268 */
    },
    {
        {0}, /* UNI=474, Hall=266 */
        {0}, /* UNI=474, Hall=267 */
        {0}, /* UNI=474, Hall=268 */
    },
    {
        {0}, /* UNI=475, Hall=269 */
        {0}, /* UNI=475, Hall=270 */
        {0}, /* UNI=475, Hall=271 */
        {0}, /* UNI=475, Hall=272 */
        {0}, /* UNI=475, Hall=273 */
        {0}, /* UNI=475, Hall=274 */
    },
    {
        {0}, /* UNI=476, Hall=269 */
        {0}, /* UNI=476, Hall=270 */
        {0}, /* UNI=476, Hall=271 */
        {0}, /* UNI=476, Hall=272 */
        {0}, /* UNI=476, Hall=273 */
        {0}, /* UNI=476, Hall=274 */
    },
    {
        {0}, /* UNI=477, Hall=269 */
        {0}, /* UNI=477, Hall=270 */
        {0}, /* UNI=477, Hall=271 */
        {0}, /* UNI=477, Hall=272 */
        {0}, /* UNI=477, Hall=273 */
        {0}, /* UNI=477, Hall=274 */
    },
    {
        {0}, /* UNI=478, Hall=269 */
        {0}, /* UNI=478, Hall=270 */
        {0}, /* UNI=478, Hall=271 */
        {0}, /* UNI=478, Hall=272 */
        {0}, /* UNI=478, Hall=273 */
        {0}, /* UNI=478, Hall=274 */
    },
    {
        {0}, /* UNI=479, Hall=269 */
        {0}, /* UNI=479, Hall=270 */
        {0}, /* UNI=479, Hall=271 */
        {0}, /* UNI=479, Hall=272 */
        {0}, /* UNI=479, Hall=273 */
        {0}, /* UNI=479, Hall=274 */
    },
    {
        {0}, /* UNI=480, Hall=269 */
        {0}, /* UNI=480, Hall=270 */
        {0}, /* UNI=480, Hall=271 */
        {0}, /* UNI=480, Hall=272 */
        {0}, /* UNI=480, Hall=273 */
        {0}, /* UNI=480, Hall=274 */
    },
    {
        {0}, /* UNI=481, Hall=269 */
        {0}, /* UNI=481, Hall=270 */
        {0}, /* UNI=481, Hall=271 */
        {0}, /* UNI=481, Hall=272 */
        {0}, /* UNI=481, Hall=273 */
        {0}, /* UNI=481, Hall=274 */
    },
    {
        {0}, /* UNI=482, Hall=269 */
        {0}, /* UNI=482, Hall=270 */
        {0}, /* UNI=482, Hall=271 */
        {0}, /* UNI=482, Hall=272 */
        {0}, /* UNI=482, Hall=273 */
        {0}, /* UNI=482, Hall=274 */
    },
    {
        {0}, /* UNI=483, Hall=269 */
        {0}, /* UNI=483, Hall=270 */
        {0}, /* UNI=483, Hall=271 */
        {0}, /* UNI=483, Hall=272 */
        {0}, /* UNI=483, Hall=273 */
        {0}, /* UNI=483, Hall=274 */
    },
    {
        {0}, /* UNI=484, Hall=269 */
        {0}, /* UNI=484, Hall=270 */
        {0}, /* UNI=484, Hall=271 */
        {0}, /* UNI=484, Hall=272 */
        {0}, /* UNI=484, Hall=273 */
        {0}, /* UNI=484, Hall=274 */
    },
    {
        {0}, /* UNI=485, Hall=269 */
        {0}, /* UNI=485, Hall=270 */
        {0}, /* UNI=485, Hall=271 */
        {0}, /* UNI=485, Hall=272 */
        {0}, /* UNI=485, Hall=273 */
        {0}, /* UNI=485, Hall=274 */
    },
    {
        {0}, /* UNI=486, Hall=269 */
        {0}, /* UNI=486, Hall=270 */
        {0}, /* UNI=486, Hall=271 */
        {0}, /* UNI=486, Hall=272 */
        {0}, /* UNI=486, Hall=273 */
        {0}, /* UNI=486, Hall=274 */
    },
    {
        {0}, /* UNI=487, Hall=269 */
        {0}, /* UNI=487, Hall=270 */
        {0}, /* UNI=487, Hall=271 */
        {0}, /* UNI=487, Hall=272 */
        {0}, /* UNI=487, Hall=273 */
        {0}, /* UNI=487, Hall=274 */
    },
    {
        {0}, /* UNI=488, Hall=269 */
        {0}, /* UNI=488, Hall=270 */
        {0}, /* UNI=488, Hall=271 */
        {0}, /* UNI=488, Hall=272 */
        {0}, /* UNI=488, Hall=273 */
        {0}, /* UNI=488, Hall=274 */
    },
    {
        {0}, /* UNI=489, Hall=269 */
        {0}, /* UNI=489, Hall=270 */
        {0}, /* UNI=489, Hall=271 */
        {0}, /* UNI=489, Hall=272 */
        {0}, /* UNI=489, Hall=273 */
        {0}, /* UNI=489, Hall=274 */
    },
    {
        {0}, /* UNI=490, Hall=269 */
        {0}, /* UNI=490, Hall=270 */
        {0}, /* UNI=490, Hall=271 */
        {0}, /* UNI=490, Hall=272 */
        {0}, /* UNI=490, Hall=273 */
        {0}, /* UNI=490, Hall=274 */
    },
    {
        {0}, /* UNI=491, Hall=275 */
        {0}, /* UNI=491, Hall=276 */
        {0}, /* UNI=491, Hall=277 */
    },
    {
        {0}, /* UNI=492, Hall=275 */
        {0}, /* UNI=492, Hall=276 */
        {0}, /* UNI=492, Hall=277 */
    },
    {
        {7410, 0}, /* UNI=493, Hall=275 */
        {3250, 0}, /* UNI=493, Hall=276 */
        {9022, 0}, /* UNI=493, Hall=277 */
    },
    {
        {0}, /* UNI=494, Hall=275 */
        {0}, /* UNI=494, Hall=276 */
        {0}, /* UNI=494, Hall=277 */
    },
    {
        {0}, /* UNI=495, Hall=275 */
        {0}, /* UNI=495, Hall=276 */
        {0}, /* UNI=495, Hall=277 */
    },
    {
        {7410, 0}, /* UNI=496, Hall=275 */
        {3250, 0}, /* UNI=496, Hall=276 */
        {9022, 0}, /* UNI=496, Hall=277 */
    },
    {
        {0}, /* UNI=497, Hall=275 */
        {0}, /* UNI=497, Hall=276 */
        {0}, /* UNI=497, Hall=277 */
    },
    {
        {7410, 0}, /* UNI=498, Hall=275 */
        {3250, 0}, /* UNI=498, Hall=276 */
        {9022, 0}, /* UNI=498, Hall=277 */
    },
    {
        {0}, /* UNI=499, Hall=275 */
        {0}, /* UNI=499, Hall=276 */
        {0}, /* UNI=499, Hall=277 */
    },
    {
        {7410, 0}, /* UNI=500, Hall=275 */
        {3250, 0}, /* UNI=500, Hall=276 */
        {9022, 0}, /* UNI=500, Hall=277 */
    },
    {
        {0}, /* UNI=501, Hall=275 */
        {0}, /* UNI=501, Hall=276 */
        {0}, /* UNI=501, Hall=277 */
    },
    {
        {0}, /* UNI=502, Hall=275 */
        {0}, /* UNI=502, Hall=276 */
        {0}, /* UNI=502, Hall=277 */
    },
    {
        {0}, /* UNI=503, Hall=278 */
        {0}, /* UNI=503, Hall=279 */
        {0}, /* UNI=503, Hall=280 */
        {0}, /* UNI=503, Hall=281 */
        {0}, /* UNI=503, Hall=282 */
        {0}, /* UNI=503, Hall=283 */
    },
    {
        {0}, /* UNI=504, Hall=278 */
        {0}, /* UNI=504, Hall=279 */
        {0}, /* UNI=504, Hall=280 */
        {0}, /* UNI=504, Hall=281 */
        {0}, /* UNI=504, Hall=282 */
        {0}, /* UNI=504, Hall=283 */
    },
    {
        {7410, 0}, /* UNI=505, Hall=278 */
        {7410, 0}, /* UNI=505, Hall=279 */
        {3250, 0}, /* UNI=505, Hall=280 */
        {3250, 0}, /* UNI=505, Hall=281 */
        {9022, 0}, /* UNI=505, Hall=282 */
        {9022, 0}, /* UNI=505, Hall=283 */
    },
    {
        {0}, /* UNI=506, Hall=278 */
        {0}, /* UNI=506, Hall=279 */
        {0}, /* UNI=506, Hall=280 */
        {0}, /* UNI=506, Hall=281 */
        {0}, /* UNI=506, Hall=282 */
        {0}, /* UNI=506, Hall=283 */
    },
    {
        {0}, /* UNI=507, Hall=278 */
        {0}, /* UNI=507, Hall=279 */
        {0}, /* UNI=507, Hall=280 */
        {0}, /* UNI=507, Hall=281 */
        {0}, /* UNI=507, Hall=282 */
        {0}, /* UNI=507, Hall=283 */
    },
    {
        {7410, 0}, /* UNI=508, Hall=278 */
        {7410, 0}, /* UNI=508, Hall=279 */
        {3250, 0}, /* UNI=508, Hall=280 */
        {3250, 0}, /* UNI=508, Hall=281 */
        {9022, 0}, /* UNI=508, Hall=282 */
        {9022, 0}, /* UNI=508, Hall=283 */
    },
    {
        {0}, /* UNI=509, Hall=278 */
        {0}, /* UNI=509, Hall=279 */
        {0}, /* UNI=509, Hall=280 */
        {0}, /* UNI=509, Hall=281 */
        {0}, /* UNI=509, Hall=282 */
        {0}, /* UNI=509, Hall=283 */
    },
    {
        {7410, 0}, /* UNI=510, Hall=278 */
        {7410, 0}, /* UNI=510, Hall=279 */
        {3250, 0}, /* UNI=510, Hall=280 */
        {3250, 0}, /* UNI=510, Hall=281 */
        {9022, 0}, /* UNI=510, Hall=282 */
        {9022, 0}, /* UNI=510, Hall=283 */
    },
    {
        {0}, /* UNI=511, Hall=278 */
        {0}, /* UNI=511, Hall=279 */
        {0}, /* UNI=511, Hall=280 */
        {0}, /* UNI=511, Hall=281 */
        {0}, /* UNI=511, Hall=282 */
        {0}, /* UNI=511, Hall=283 */
    },
    {
        {7410, 0}, /* UNI=512, Hall=278 */
        {7410, 0}, /* UNI=512, Hall=279 */
        {3250, 0}, /* UNI=512, Hall=280 */
        {3250, 0}, /* UNI=512, Hall=281 */
        {9022, 0}, /* UNI=512, Hall=282 */
        {9022, 0}, /* UNI=512, Hall=283 */
    },
    {
        {0}, /* UNI=513, Hall=278 */
        {0}, /* UNI=513, Hall=279 */
        {0}, /* UNI=513, Hall=280 */
        {0}, /* UNI=513, Hall=281 */
        {0}, /* UNI=513, Hall=282 */
        {0}, /* UNI=513, Hall=283 */
    },
    {
        {0}, /* UNI=514, Hall=278 */
        {0}, /* UNI=514, Hall=279 */
        {0}, /* UNI=514, Hall=280 */
        {0}, /* UNI=514, Hall=281 */
        {0}, /* UNI=514, Hall=282 */
        {0}, /* UNI=514, Hall=283 */
    },
    {
        {0}, /* UNI=515, Hall=284 */
        {0}, /* UNI=515, Hall=285 */
        {0}, /* UNI=515, Hall=286 */
        {0}, /* UNI=515, Hall=287 */
        {0}, /* UNI=515, Hall=288 */
        {0}, /* UNI=515, Hall=289 */
    },
    {
        {0}, /* UNI=516, Hall=284 */
        {0}, /* UNI=516, Hall=285 */
        {0}, /* UNI=516, Hall=286 */
        {0}, /* UNI=516, Hall=287 */
        {0}, /* UNI=516, Hall=288 */
        {0}, /* UNI=516, Hall=289 */
    },
    {
        {0}, /* UNI=517, Hall=284 */
        {0}, /* UNI=517, Hall=285 */
        {0}, /* UNI=517, Hall=286 */
        {0}, /* UNI=517, Hall=287 */
        {0}, /* UNI=517, Hall=288 */
        {0}, /* UNI=517, Hall=289 */
    },
    {
        {0}, /* UNI=518, Hall=284 */
        {0}, /* UNI=518, Hall=285 */
        {0}, /* UNI=518, Hall=286 */
        {0}, /* UNI=518, Hall=287 */
        {0}, /* UNI=518, Hall=288 */
        {0}, /* UNI=518, Hall=289 */
    },
    {
        {0}, /* UNI=519, Hall=284 */
        {0}, /* UNI=519, Hall=285 */
        {0}, /* UNI=519, Hall=286 */
        {0}, /* UNI=519, Hall=287 */
        {0}, /* UNI=519, Hall=288 */
        {0}, /* UNI=519, Hall=289 */
    },
    {
        {0}, /* UNI=520, Hall=284 */
        {0}, /* UNI=520, Hall=285 */
        {0}, /* UNI=520, Hall=286 */
        {0}, /* UNI=520, Hall=287 */
        {0}, /* UNI=520, Hall=288 */
        {0}, /* UNI=520, Hall=289 */
    },
    {
        {0}, /* UNI=521, Hall=284 */
        {0}, /* UNI=521, Hall=285 */
        {0}, /* UNI=521, Hall=286 */
        {0}, /* UNI=521, Hall=287 */
        {0}, /* UNI=521, Hall=288 */
        {0}, /* UNI=521, Hall=289 */
    },
    {
        {0}, /* UNI=522, Hall=284 */
        {0}, /* UNI=522, Hall=285 */
        {0}, /* UNI=522, Hall=286 */
        {0}, /* UNI=522, Hall=287 */
        {0}, /* UNI=522, Hall=288 */
        {0}, /* UNI=522, Hall=289 */
    },
    {
        {0}, /* UNI=523, Hall=284 */
        {0}, /* UNI=523, Hall=285 */
        {0}, /* UNI=523, Hall=286 */
        {0}, /* UNI=523, Hall=287 */
        {0}, /* UNI=523, Hall=288 */
        {0}, /* UNI=523, Hall=289 */
    },
    {
        {0}, /* UNI=524, Hall=284 */
        {0}, /* UNI=524, Hall=285 */
        {0}, /* UNI=524, Hall=286 */
        {0}, /* UNI=524, Hall=287 */
        {0}, /* UNI=524, Hall=288 */
        {0}, /* UNI=524, Hall=289 */
    },
    {
        {0}, /* UNI=525, Hall=284 */
        {0}, /* UNI=525, Hall=285 */
        {0}, /* UNI=525, Hall=286 */
        {0}, /* UNI=525, Hall=287 */
        {0}, /* UNI=525, Hall=288 */
        {0}, /* UNI=525, Hall=289 */
    },
    {
        {0}, /* UNI=526, Hall=284 */
        {0}, /* UNI=526, Hall=285 */
        {0}, /* UNI=526, Hall=286 */
        {0}, /* UNI=526, Hall=287 */
        {0}, /* UNI=526, Hall=288 */
        {0}, /* UNI=526, Hall=289 */
    },
    {
        {0}, /* UNI=527, Hall=284 */
        {0}, /* UNI=527, Hall=285 */
        {0}, /* UNI=527, Hall=286 */
        {0}, /* UNI=527, Hall=287 */
        {0}, /* UNI=527, Hall=288 */
        {0}, /* UNI=527, Hall=289 */
    },
    {
        {0}, /* UNI=528, Hall=284 */
        {0}, /* UNI=528, Hall=285 */
        {0}, /* UNI=528, Hall=286 */
        {0}, /* UNI=528, Hall=287 */
        {0}, /* UNI=528, Hall=288 */
        {0}, /* UNI=528, Hall=289 */
    },
    {
        {0}, /* UNI=529, Hall=284 */
        {0}, /* UNI=529, Hall=285 */
        {0}, /* UNI=529, Hall=286 */
        {0}, /* UNI=529, Hall=287 */
        {0}, /* UNI=529, Hall=288 */
        {0}, /* UNI=529, Hall=289 */
    },
    {
        {0}, /* UNI=530, Hall=284 */
        {0}, /* UNI=530, Hall=285 */
        {0}, /* UNI=530, Hall=286 */
        {0}, /* UNI=530, Hall=287 */
        {0}, /* UNI=530, Hall=288 */
        {0}, /* UNI=530, Hall=289 */
    },
    {
        {0}, /* UNI=531, Hall=290 */
        {0}, /* UNI=531, Hall=291 */
    },
    {
        {0}, /* UNI=532, Hall=290 */
        {0}, /* UNI=532, Hall=291 */
    },
    {
        {7636, 8872, 0}, /* UNI=533, Hall=290 */
        {7636, 8872, 0}, /* UNI=533, Hall=291 */
    },
    {
        {7636, 8872, 0}, /* UNI=534, Hall=290 */
        {7636, 8872, 0}, /* UNI=534, Hall=291 */
    },
    {
        {0}, /* UNI=535, Hall=290 */
        {0}, /* UNI=535, Hall=291 */
    },
    {
        {7636, 8872, 0}, /* UNI=536, Hall=290 */
        {7636, 8872, 0}, /* UNI=536, Hall=291 */
    },
    {
        {7636, 8872, 0}, /* UNI=537, Hall=290 */
        {7636, 8872, 0}, /* UNI=537, Hall=291 */
    },
    {
        {0}, /* UNI=538, Hall=290 */
        {0}, /* UNI=538, Hall=291 */
    },
    {
        {0}, /* UNI=539, Hall=292 */
        {0}, /* UNI=539, Hall=293 */
        {0}, /* UNI=539, Hall=294 */
        {0}, /* UNI=539, Hall=295 */
        {0}, /* UNI=539, Hall=296 */
        {0}, /* UNI=539, Hall=297 */
    },
    {
        {0}, /* UNI=540, Hall=292 */
        {0}, /* UNI=540, Hall=293 */
        {0}, /* UNI=540, Hall=294 */
        {0}, /* UNI=540, Hall=295 */
        {0}, /* UNI=540, Hall=296 */
        {0}, /* UNI=540, Hall=297 */
    },
    {
        {0}, /* UNI=541, Hall=292 */
        {0}, /* UNI=541, Hall=293 */
        {0}, /* UNI=541, Hall=294 */
        {0}, /* UNI=541, Hall=295 */
        {0}, /* UNI=541, Hall=296 */
        {0}, /* UNI=541, Hall=297 */
    },
    {
        {0}, /* UNI=542, Hall=292 */
        {0}, /* UNI=542, Hall=293 */
        {0}, /* UNI=542, Hall=294 */
        {0}, /* UNI=542, Hall=295 */
        {0}, /* UNI=542, Hall=296 */
        {0}, /* UNI=542, Hall=297 */
    },
    {
        {0}, /* UNI=543, Hall=292 */
        {0}, /* UNI=543, Hall=293 */
        {0}, /* UNI=543, Hall=294 */
        {0}, /* UNI=543, Hall=295 */
        {0}, /* UNI=543, Hall=296 */
        {0}, /* UNI=543, Hall=297 */
    },
    {
        {0}, /* UNI=544, Hall=292 */
        {0}, /* UNI=544, Hall=293 */
        {0}, /* UNI=544, Hall=294 */
        {0}, /* UNI=544, Hall=295 */
        {0}, /* UNI=544, Hall=296 */
        {0}, /* UNI=544, Hall=297 */
    },
    {
        {0}, /* UNI=545, Hall=292 */
        {0}, /* UNI=545, Hall=293 */
        {0}, /* UNI=545, Hall=294 */
        {0}, /* UNI=545, Hall=295 */
        {0}, /* UNI=545, Hall=296 */
        {0}, /* UNI=545, Hall=297 */
    },
    {
        {0}, /* UNI=546, Hall=292 */
        {0}, /* UNI=546, Hall=293 */
        {0}, /* UNI=546, Hall=294 */
        {0}, /* UNI=546, Hall=295 */
        {0}, /* UNI=546, Hall=296 */
        {0}, /* UNI=546, Hall=297 */
    },
    {
        {0}, /* UNI=547, Hall=292 */
        {0}, /* UNI=547, Hall=293 */
        {0}, /* UNI=547, Hall=294 */
        {0}, /* UNI=547, Hall=295 */
        {0}, /* UNI=547, Hall=296 */
        {0}, /* UNI=547, Hall=297 */
    },
    {
        {0}, /* UNI=548, Hall=292 */
        {0}, /* UNI=548, Hall=293 */
        {0}, /* UNI=548, Hall=294 */
        {0}, /* UNI=548, Hall=295 */
        {0}, /* UNI=548, Hall=296 */
        {0}, /* UNI=548, Hall=297 */
    },
    {
        {0}, /* UNI=549, Hall=292 */
        {0}, /* UNI=549, Hall=293 */
        {0}, /* UNI=549, Hall=294 */
        {0}, /* UNI=549, Hall=295 */
        {0}, /* UNI=549, Hall=296 */
        {0}, /* UNI=549, Hall=297 */
    },
    {
        {0}, /* UNI=550, Hall=292 */
        {0}, /* UNI=550, Hall=293 */
        {0}, /* UNI=550, Hall=294 */
        {0}, /* UNI=550, Hall=295 */
        {0}, /* UNI=550, Hall=296 */
        {0}, /* UNI=550, Hall=297 */
    },
    {
        {0}, /* UNI=551, Hall=292 */
        {0}, /* UNI=551, Hall=293 */
        {0}, /* UNI=551, Hall=294 */
        {0}, /* UNI=551, Hall=295 */
        {0}, /* UNI=551, Hall=296 */
        {0}, /* UNI=551, Hall=297 */
    },
    {
        {0}, /* UNI=552, Hall=292 */
        {0}, /* UNI=552, Hall=293 */
        {0}, /* UNI=552, Hall=294 */
        {0}, /* UNI=552, Hall=295 */
        {0}, /* UNI=552, Hall=296 */
        {0}, /* UNI=552, Hall=297 */
    },
    {
        {0}, /* UNI=553, Hall=292 */
        {0}, /* UNI=553, Hall=293 */
        {0}, /* UNI=553, Hall=294 */
        {0}, /* UNI=553, Hall=295 */
        {0}, /* UNI=553, Hall=296 */
        {0}, /* UNI=553, Hall=297 */
    },
    {
        {0}, /* UNI=554, Hall=292 */
        {0}, /* UNI=554, Hall=293 */
        {0}, /* UNI=554, Hall=294 */
        {0}, /* UNI=554, Hall=295 */
        {0}, /* UNI=554, Hall=296 */
        {0}, /* UNI=554, Hall=297 */
    },
    {
        {0}, /* UNI=555, Hall=298 */
        {0}, /* UNI=555, Hall=299 */
        {0}, /* UNI=555, Hall=300 */
        {0}, /* UNI=555, Hall=301 */
        {0}, /* UNI=555, Hall=302 */
        {0}, /* UNI=555, Hall=303 */
    },
    {
        {0}, /* UNI=556, Hall=298 */
        {0}, /* UNI=556, Hall=299 */
        {0}, /* UNI=556, Hall=300 */
        {0}, /* UNI=556, Hall=301 */
        {0}, /* UNI=556, Hall=302 */
        {0}, /* UNI=556, Hall=303 */
    },
    {
        {0}, /* UNI=557, Hall=298 */
        {0}, /* UNI=557, Hall=299 */
        {0}, /* UNI=557, Hall=300 */
        {0}, /* UNI=557, Hall=301 */
        {0}, /* UNI=557, Hall=302 */
        {0}, /* UNI=557, Hall=303 */
    },
    {
        {0}, /* UNI=558, Hall=298 */
        {0}, /* UNI=558, Hall=299 */
        {0}, /* UNI=558, Hall=300 */
        {0}, /* UNI=558, Hall=301 */
        {0}, /* UNI=558, Hall=302 */
        {0}, /* UNI=558, Hall=303 */
    },
    {
        {0}, /* UNI=559, Hall=298 */
        {0}, /* UNI=559, Hall=299 */
        {0}, /* UNI=559, Hall=300 */
        {0}, /* UNI=559, Hall=301 */
        {0}, /* UNI=559, Hall=302 */
        {0}, /* UNI=559, Hall=303 */
    },
    {
        {0}, /* UNI=560, Hall=298 */
        {0}, /* UNI=560, Hall=299 */
        {0}, /* UNI=560, Hall=300 */
        {0}, /* UNI=560, Hall=301 */
        {0}, /* UNI=560, Hall=302 */
        {0}, /* UNI=560, Hall=303 */
    },
    {
        {0}, /* UNI=561, Hall=298 */
        {0}, /* UNI=561, Hall=299 */
        {0}, /* UNI=561, Hall=300 */
        {0}, /* UNI=561, Hall=301 */
        {0}, /* UNI=561, Hall=302 */
        {0}, /* UNI=561, Hall=303 */
    },
    {
        {0}, /* UNI=562, Hall=298 */
        {0}, /* UNI=562, Hall=299 */
        {0}, /* UNI=562, Hall=300 */
        {0}, /* UNI=562, Hall=301 */
        {0}, /* UNI=562, Hall=302 */
        {0}, /* UNI=562, Hall=303 */
    },
    {
        {0}, /* UNI=563, Hall=298 */
        {0}, /* UNI=563, Hall=299 */
        {0}, /* UNI=563, Hall=300 */
        {0}, /* UNI=563, Hall=301 */
        {0}, /* UNI=563, Hall=302 */
        {0}, /* UNI=563, Hall=303 */
    },
    {
        {0}, /* UNI=564, Hall=298 */
        {0}, /* UNI=564, Hall=299 */
        {0}, /* UNI=564, Hall=300 */
        {0}, /* UNI=564, Hall=301 */
        {0}, /* UNI=564, Hall=302 */
        {0}, /* UNI=564, Hall=303 */
    },
    {
        {0}, /* UNI=565, Hall=298 */
        {0}, /* UNI=565, Hall=299 */
        {0}, /* UNI=565, Hall=300 */
        {0}, /* UNI=565, Hall=301 */
        {0}, /* UNI=565, Hall=302 */
        {0}, /* UNI=565, Hall=303 */
    },
    {
        {0}, /* UNI=566, Hall=298 */
        {0}, /* UNI=566, Hall=299 */
        {0}, /* UNI=566, Hall=300 */
        {0}, /* UNI=566, Hall=301 */
        {0}, /* UNI=566, Hall=302 */
        {0}, /* UNI=566, Hall=303 */
    },
    {
        {0}, /* UNI=567, Hall=304 */
        {0}, /* UNI=567, Hall=305 */
        {0}, /* UNI=567, Hall=306 */
        {0}, /* UNI=567, Hall=307 */
        {0}, /* UNI=567, Hall=308 */
        {0}, /* UNI=567, Hall=309 */
    },
    {
        {0}, /* UNI=568, Hall=304 */
        {0}, /* UNI=568, Hall=305 */
        {0}, /* UNI=568, Hall=306 */
        {0}, /* UNI=568, Hall=307 */
        {0}, /* UNI=568, Hall=308 */
        {0}, /* UNI=568, Hall=309 */
    },
    {
        {0}, /* UNI=569, Hall=304 */
        {0}, /* UNI=569, Hall=305 */
        {0}, /* UNI=569, Hall=306 */
        {0}, /* UNI=569, Hall=307 */
        {0}, /* UNI=569, Hall=308 */
        {0}, /* UNI=569, Hall=309 */
    },
    {
        {0}, /* UNI=570, Hall=304 */
        {0}, /* UNI=570, Hall=305 */
        {0}, /* UNI=570, Hall=306 */
        {0}, /* UNI=570, Hall=307 */
        {0}, /* UNI=570, Hall=308 */
        {0}, /* UNI=570, Hall=309 */
    },
    {
        {0}, /* UNI=571, Hall=304 */
        {0}, /* UNI=571, Hall=305 */
        {0}, /* UNI=571, Hall=306 */
        {0}, /* UNI=571, Hall=307 */
        {0}, /* UNI=571, Hall=308 */
        {0}, /* UNI=571, Hall=309 */
    },
    {
        {0}, /* UNI=572, Hall=304 */
        {0}, /* UNI=572, Hall=305 */
        {0}, /* UNI=572, Hall=306 */
        {0}, /* UNI=572, Hall=307 */
        {0}, /* UNI=572, Hall=308 */
        {0}, /* UNI=572, Hall=309 */
    },
    {
        {0}, /* UNI=573, Hall=304 */
        {0}, /* UNI=573, Hall=305 */
        {0}, /* UNI=573, Hall=306 */
        {0}, /* UNI=573, Hall=307 */
        {0}, /* UNI=573, Hall=308 */
        {0}, /* UNI=573, Hall=309 */
    },
    {
        {0}, /* UNI=574, Hall=304 */
        {0}, /* UNI=574, Hall=305 */
        {0}, /* UNI=574, Hall=306 */
        {0}, /* UNI=574, Hall=307 */
        {0}, /* UNI=574, Hall=308 */
        {0}, /* UNI=574, Hall=309 */
    },
    {
        {0}, /* UNI=575, Hall=304 */
        {0}, /* UNI=575, Hall=305 */
        {0}, /* UNI=575, Hall=306 */
        {0}, /* UNI=575, Hall=307 */
        {0}, /* UNI=575, Hall=308 */
        {0}, /* UNI=575, Hall=309 */
    },
    {
        {0}, /* UNI=576, Hall=304 */
        {0}, /* UNI=576, Hall=305 */
        {0}, /* UNI=576, Hall=306 */
        {0}, /* UNI=576, Hall=307 */
        {0}, /* UNI=576, Hall=308 */
        {0}, /* UNI=576, Hall=309 */
    },
    {
        {0}, /* UNI=577, Hall=304 */
        {0}, /* UNI=577, Hall=305 */
        {0}, /* UNI=577, Hall=306 */
        {0}, /* UNI=577, Hall=307 */
        {0}, /* UNI=577, Hall=308 */
        {0}, /* UNI=577, Hall=309 */
    },
    {
        {0}, /* UNI=578, Hall=304 */
        {0}, /* UNI=578, Hall=305 */
        {0}, /* UNI=578, Hall=306 */
        {0}, /* UNI=578, Hall=307 */
        {0}, /* UNI=578, Hall=308 */
        {0}, /* UNI=578, Hall=309 */
    },
    {
        {0}, /* UNI=579, Hall=310 */
        {0}, /* UNI=579, Hall=311 */
        {0}, /* UNI=579, Hall=312 */
    },
    {
        {0}, /* UNI=580, Hall=310 */
        {0}, /* UNI=580, Hall=311 */
        {0}, /* UNI=580, Hall=312 */
    },
    {
        {7410, 0}, /* UNI=581, Hall=310 */
        {3250, 0}, /* UNI=581, Hall=311 */
        {9022, 0}, /* UNI=581, Hall=312 */
    },
    {
        {0}, /* UNI=582, Hall=310 */
        {0}, /* UNI=582, Hall=311 */
        {0}, /* UNI=582, Hall=312 */
    },
    {
        {0}, /* UNI=583, Hall=310 */
        {0}, /* UNI=583, Hall=311 */
        {0}, /* UNI=583, Hall=312 */
    },
    {
        {7410, 0}, /* UNI=584, Hall=310 */
        {3250, 0}, /* UNI=584, Hall=311 */
        {9022, 0}, /* UNI=584, Hall=312 */
    },
    {
        {0}, /* UNI=585, Hall=310 */
        {0}, /* UNI=585, Hall=311 */
        {0}, /* UNI=585, Hall=312 */
    },
    {
        {0}, /* UNI=586, Hall=310 */
        {0}, /* UNI=586, Hall=311 */
        {0}, /* UNI=586, Hall=312 */
    },
    {
        {0}, /* UNI=587, Hall=310 */
        {0}, /* UNI=587, Hall=311 */
        {0}, /* UNI=587, Hall=312 */
    },
    {
        {0}, /* UNI=588, Hall=310 */
        {0}, /* UNI=588, Hall=311 */
        {0}, /* UNI=588, Hall=312 */
    },
    {
        {0}, /* UNI=589, Hall=313 */
        {0}, /* UNI=589, Hall=314 */
        {0}, /* UNI=589, Hall=315 */
    },
    {
        {0}, /* UNI=590, Hall=313 */
        {0}, /* UNI=590, Hall=314 */
        {0}, /* UNI=590, Hall=315 */
    },
    {
        {7410, 0}, /* UNI=591, Hall=313 */
        {3250, 0}, /* UNI=591, Hall=314 */
        {9022, 0}, /* UNI=591, Hall=315 */
    },
    {
        {0}, /* UNI=592, Hall=313 */
        {0}, /* UNI=592, Hall=314 */
        {0}, /* UNI=592, Hall=315 */
    },
    {
        {0}, /* UNI=593, Hall=313 */
        {0}, /* UNI=593, Hall=314 */
        {0}, /* UNI=593, Hall=315 */
    },
    {
        {7410, 0}, /* UNI=594, Hall=313 */
        {3250, 0}, /* UNI=594, Hall=314 */
        {9022, 0}, /* UNI=594, Hall=315 */
    },
    {
        {0}, /* UNI=595, Hall=313 */
        {0}, /* UNI=595, Hall=314 */
        {0}, /* UNI=595, Hall=315 */
    },
    {
        {0}, /* UNI=596, Hall=313 */
        {0}, /* UNI=596, Hall=314 */
        {0}, /* UNI=596, Hall=315 */
    },
    {
        {0}, /* UNI=597, Hall=313 */
        {0}, /* UNI=597, Hall=314 */
        {0}, /* UNI=597, Hall=315 */
    },
    {
        {0}, /* UNI=598, Hall=313 */
        {0}, /* UNI=598, Hall=314 */
        {0}, /* UNI=598, Hall=315 */
    },
    {
        {0}, /* UNI=599, Hall=316 */
        {0}, /* UNI=599, Hall=317 */
        {0}, /* UNI=599, Hall=318 */
        {0}, /* UNI=599, Hall=319 */
        {0}, /* UNI=599, Hall=320 */
        {0}, /* UNI=599, Hall=321 */
    },
    {
        {0}, /* UNI=600, Hall=316 */
        {0}, /* UNI=600, Hall=317 */
        {0}, /* UNI=600, Hall=318 */
        {0}, /* UNI=600, Hall=319 */
        {0}, /* UNI=600, Hall=320 */
        {0}, /* UNI=600, Hall=321 */
    },
    {
        {9219054, 0}, /* UNI=601, Hall=316 */
        {9219054, 0}, /* UNI=601, Hall=317 */
        {770887, 0},  /* UNI=601, Hall=318 */
        {770887, 0},  /* UNI=601, Hall=319 */
        {8571127, 0}, /* UNI=601, Hall=320 */
        {8571127, 0}, /* UNI=601, Hall=321 */
    },
    {
        {0}, /* UNI=602, Hall=316 */
        {0}, /* UNI=602, Hall=317 */
        {0}, /* UNI=602, Hall=318 */
        {0}, /* UNI=602, Hall=319 */
        {0}, /* UNI=602, Hall=320 */
        {0}, /* UNI=602, Hall=321 */
    },
    {
        {0}, /* UNI=603, Hall=316 */
        {0}, /* UNI=603, Hall=317 */
        {0}, /* UNI=603, Hall=318 */
        {0}, /* UNI=603, Hall=319 */
        {0}, /* UNI=603, Hall=320 */
        {0}, /* UNI=603, Hall=321 */
    },
    {
        {9219054, 0}, /* UNI=604, Hall=316 */
        {9219054, 0}, /* UNI=604, Hall=317 */
        {770887, 0},  /* UNI=604, Hall=318 */
        {770887, 0},  /* UNI=604, Hall=319 */
        {8571127, 0}, /* UNI=604, Hall=320 */
        {8571127, 0}, /* UNI=604, Hall=321 */
    },
    {
        {0}, /* UNI=605, Hall=316 */
        {0}, /* UNI=605, Hall=317 */
        {0}, /* UNI=605, Hall=318 */
        {0}, /* UNI=605, Hall=319 */
        {0}, /* UNI=605, Hall=320 */
        {0}, /* UNI=605, Hall=321 */
    },
    {
        {0}, /* UNI=606, Hall=316 */
        {0}, /* UNI=606, Hall=317 */
        {0}, /* UNI=606, Hall=318 */
        {0}, /* UNI=606, Hall=319 */
        {0}, /* UNI=606, Hall=320 */
        {0}, /* UNI=606, Hall=321 */
    },
    {
        {0}, /* UNI=607, Hall=316 */
        {0}, /* UNI=607, Hall=317 */
        {0}, /* UNI=607, Hall=318 */
        {0}, /* UNI=607, Hall=319 */
        {0}, /* UNI=607, Hall=320 */
        {0}, /* UNI=607, Hall=321 */
    },
    {
        {0}, /* UNI=608, Hall=316 */
        {0}, /* UNI=608, Hall=317 */
        {0}, /* UNI=608, Hall=318 */
        {0}, /* UNI=608, Hall=319 */
        {0}, /* UNI=608, Hall=320 */
        {0}, /* UNI=608, Hall=321 */
    },
    {
        {0}, /* UNI=609, Hall=322 */
        {0}, /* UNI=609, Hall=323 */
        {0}, /* UNI=609, Hall=324 */
        {0}, /* UNI=609, Hall=325 */
        {0}, /* UNI=609, Hall=326 */
        {0}, /* UNI=609, Hall=327 */
        {0}, /* UNI=609, Hall=328 */
        {0}, /* UNI=609, Hall=329 */
        {0}, /* UNI=609, Hall=330 */
        {0}, /* UNI=609, Hall=331 */
        {0}, /* UNI=609, Hall=332 */
        {0}, /* UNI=609, Hall=333 */
    },
    {
        {0}, /* UNI=610, Hall=322 */
        {0}, /* UNI=610, Hall=323 */
        {0}, /* UNI=610, Hall=324 */
        {0}, /* UNI=610, Hall=325 */
        {0}, /* UNI=610, Hall=326 */
        {0}, /* UNI=610, Hall=327 */
        {0}, /* UNI=610, Hall=328 */
        {0}, /* UNI=610, Hall=329 */
        {0}, /* UNI=610, Hall=330 */
        {0}, /* UNI=610, Hall=331 */
        {0}, /* UNI=610, Hall=332 */
        {0}, /* UNI=610, Hall=333 */
    },
    {
        {7410, 0},    /* UNI=611, Hall=322 */
        {9219054, 0}, /* UNI=611, Hall=323 */
        {7410, 0},    /* UNI=611, Hall=324 */
        {9219054, 0}, /* UNI=611, Hall=325 */
        {3250, 0},    /* UNI=611, Hall=326 */
        {770887, 0},  /* UNI=611, Hall=327 */
        {3250, 0},    /* UNI=611, Hall=328 */
        {770887, 0},  /* UNI=611, Hall=329 */
        {9022, 0},    /* UNI=611, Hall=330 */
        {8571127, 0}, /* UNI=611, Hall=331 */
        {9022, 0},    /* UNI=611, Hall=332 */
        {8571127, 0}, /* UNI=611, Hall=333 */
    },
    {
        {0}, /* UNI=612, Hall=322 */
        {0}, /* UNI=612, Hall=323 */
        {0}, /* UNI=612, Hall=324 */
        {0}, /* UNI=612, Hall=325 */
        {0}, /* UNI=612, Hall=326 */
        {0}, /* UNI=612, Hall=327 */
        {0}, /* UNI=612, Hall=328 */
        {0}, /* UNI=612, Hall=329 */
        {0}, /* UNI=612, Hall=330 */
        {0}, /* UNI=612, Hall=331 */
        {0}, /* UNI=612, Hall=332 */
        {0}, /* UNI=612, Hall=333 */
    },
    {
        {0}, /* UNI=613, Hall=322 */
        {0}, /* UNI=613, Hall=323 */
        {0}, /* UNI=613, Hall=324 */
        {0}, /* UNI=613, Hall=325 */
        {0}, /* UNI=613, Hall=326 */
        {0}, /* UNI=613, Hall=327 */
        {0}, /* UNI=613, Hall=328 */
        {0}, /* UNI=613, Hall=329 */
        {0}, /* UNI=613, Hall=330 */
        {0}, /* UNI=613, Hall=331 */
        {0}, /* UNI=613, Hall=332 */
        {0}, /* UNI=613, Hall=333 */
    },
    {
        {7410, 0},    /* UNI=614, Hall=322 */
        {9219054, 0}, /* UNI=614, Hall=323 */
        {7410, 0},    /* UNI=614, Hall=324 */
        {9219054, 0}, /* UNI=614, Hall=325 */
        {3250, 0},    /* UNI=614, Hall=326 */
        {770887, 0},  /* UNI=614, Hall=327 */
        {3250, 0},    /* UNI=614, Hall=328 */
        {770887, 0},  /* UNI=614, Hall=329 */
        {9022, 0},    /* UNI=614, Hall=330 */
        {8571127, 0}, /* UNI=614, Hall=331 */
        {9022, 0},    /* UNI=614, Hall=332 */
        {8571127, 0}, /* UNI=614, Hall=333 */
    },
    {
        {0}, /* UNI=615, Hall=322 */
        {0}, /* UNI=615, Hall=323 */
        {0}, /* UNI=615, Hall=324 */
        {0}, /* UNI=615, Hall=325 */
        {0}, /* UNI=615, Hall=326 */
        {0}, /* UNI=615, Hall=327 */
        {0}, /* UNI=615, Hall=328 */
        {0}, /* UNI=615, Hall=329 */
        {0}, /* UNI=615, Hall=330 */
        {0}, /* UNI=615, Hall=331 */
        {0}, /* UNI=615, Hall=332 */
        {0}, /* UNI=615, Hall=333 */
    },
    {
        {0}, /* UNI=616, Hall=322 */
        {0}, /* UNI=616, Hall=323 */
        {0}, /* UNI=616, Hall=324 */
        {0}, /* UNI=616, Hall=325 */
        {0}, /* UNI=616, Hall=326 */
        {0}, /* UNI=616, Hall=327 */
        {0}, /* UNI=616, Hall=328 */
        {0}, /* UNI=616, Hall=329 */
        {0}, /* UNI=616, Hall=330 */
        {0}, /* UNI=616, Hall=331 */
        {0}, /* UNI=616, Hall=332 */
        {0}, /* UNI=616, Hall=333 */
    },
    {
        {0}, /* UNI=617, Hall=322 */
        {0}, /* UNI=617, Hall=323 */
        {0}, /* UNI=617, Hall=324 */
        {0}, /* UNI=617, Hall=325 */
        {0}, /* UNI=617, Hall=326 */
        {0}, /* UNI=617, Hall=327 */
        {0}, /* UNI=617, Hall=328 */
        {0}, /* UNI=617, Hall=329 */
        {0}, /* UNI=617, Hall=330 */
        {0}, /* UNI=617, Hall=331 */
        {0}, /* UNI=617, Hall=332 */
        {0}, /* UNI=617, Hall=333 */
    },
    {
        {0}, /* UNI=618, Hall=322 */
        {0}, /* UNI=618, Hall=323 */
        {0}, /* UNI=618, Hall=324 */
        {0}, /* UNI=618, Hall=325 */
        {0}, /* UNI=618, Hall=326 */
        {0}, /* UNI=618, Hall=327 */
        {0}, /* UNI=618, Hall=328 */
        {0}, /* UNI=618, Hall=329 */
        {0}, /* UNI=618, Hall=330 */
        {0}, /* UNI=618, Hall=331 */
        {0}, /* UNI=618, Hall=332 */
        {0}, /* UNI=618, Hall=333 */
    },
    {
        {0}, /* UNI=619, Hall=334 */
    },
    {
        {0}, /* UNI=620, Hall=334 */
    },
    {
        {7410, 8872, 0}, /* UNI=621, Hall=334 */
    },
    {
        {3250, 7636, 0}, /* UNI=622, Hall=334 */
    },
    {
        {0}, /* UNI=623, Hall=334 */
    },
    {
        {0}, /* UNI=624, Hall=334 */
    },
    {
        {0}, /* UNI=625, Hall=335 */
        {0}, /* UNI=625, Hall=336 */
    },
    {
        {0}, /* UNI=626, Hall=335 */
        {0}, /* UNI=626, Hall=336 */
    },
    {
        {9278103, 8872, 0}, /* UNI=627, Hall=335 */
        {7410, 9220516, 0}, /* UNI=627, Hall=336 */
    },
    {
        {9273943, 7636, 0}, /* UNI=628, Hall=335 */
        {3250, 9219280, 0}, /* UNI=628, Hall=336 */
    },
    {
        {0}, /* UNI=629, Hall=335 */
        {0}, /* UNI=629, Hall=336 */
    },
    {
        {0}, /* UNI=630, Hall=335 */
        {0}, /* UNI=630, Hall=336 */
    },
    {
        {0}, /* UNI=631, Hall=337 */
    },
    {
        {0}, /* UNI=632, Hall=337 */
    },
    {
        {7410, 8872, 0}, /* UNI=633, Hall=337 */
    },
    {
        {3250, 7636, 0}, /* UNI=634, Hall=337 */
    },
    {
        {0}, /* UNI=635, Hall=337 */
    },
    {
        {3250, 7636, 0}, /* UNI=636, Hall=337 */
    },
    {
        {0}, /* UNI=637, Hall=338 */
        {0}, /* UNI=637, Hall=339 */
        {0}, /* UNI=637, Hall=340 */
    },
    {
        {0}, /* UNI=638, Hall=338 */
        {0}, /* UNI=638, Hall=339 */
        {0}, /* UNI=638, Hall=340 */
    },
    {
        {7410, 0}, /* UNI=639, Hall=338 */
        {3250, 0}, /* UNI=639, Hall=339 */
        {9022, 0}, /* UNI=639, Hall=340 */
    },
    {
        {0}, /* UNI=640, Hall=338 */
        {0}, /* UNI=640, Hall=339 */
        {0}, /* UNI=640, Hall=340 */
    },
    {
        {0}, /* UNI=641, Hall=338 */
        {0}, /* UNI=641, Hall=339 */
        {0}, /* UNI=641, Hall=340 */
    },
    {
        {7410, 0}, /* UNI=642, Hall=338 */
        {3250, 0}, /* UNI=642, Hall=339 */
        {9022, 0}, /* UNI=642, Hall=340 */
    },
    {
        {0}, /* UNI=643, Hall=338 */
        {0}, /* UNI=643, Hall=339 */
        {0}, /* UNI=643, Hall=340 */
    },
    {
        {0}, /* UNI=644, Hall=338 */
        {0}, /* UNI=644, Hall=339 */
        {0}, /* UNI=644, Hall=340 */
    },
    {
        {7410, 0}, /* UNI=645, Hall=338 */
        {3250, 0}, /* UNI=645, Hall=339 */
        {9022, 0}, /* UNI=645, Hall=340 */
    },
    {
        {0}, /* UNI=646, Hall=341 */
        {0}, /* UNI=646, Hall=342 */
    },
    {
        {0}, /* UNI=647, Hall=341 */
        {0}, /* UNI=647, Hall=342 */
    },
    {
        {9278103, 8872, 0},    /* UNI=648, Hall=341 */
        {9273943, 9278103, 0}, /* UNI=648, Hall=342 */
    },
    {
        {9273943, 7636, 0}, /* UNI=649, Hall=341 */
        {9273943, 7636, 0}, /* UNI=649, Hall=342 */
    },
    {
        {0}, /* UNI=650, Hall=341 */
        {0}, /* UNI=650, Hall=342 */
    },
    {
        {9273943, 7636, 0}, /* UNI=651, Hall=341 */
        {9273943, 7636, 0}, /* UNI=651, Hall=342 */
    },
    {
        {0}, /* UNI=652, Hall=343 */
        {0}, /* UNI=652, Hall=344 */
        {0}, /* UNI=652, Hall=345 */
        {0}, /* UNI=652, Hall=346 */
        {0}, /* UNI=652, Hall=347 */
        {0}, /* UNI=652, Hall=348 */
    },
    {
        {0}, /* UNI=653, Hall=343 */
        {0}, /* UNI=653, Hall=344 */
        {0}, /* UNI=653, Hall=345 */
        {0}, /* UNI=653, Hall=346 */
        {0}, /* UNI=653, Hall=347 */
        {0}, /* UNI=653, Hall=348 */
    },
    {
        {9278103, 0}, /* UNI=654, Hall=343 */
        {9278103, 0}, /* UNI=654, Hall=344 */
        {9273943, 0}, /* UNI=654, Hall=345 */
        {9273943, 0}, /* UNI=654, Hall=346 */
        {9279715, 0}, /* UNI=654, Hall=347 */
        {9279715, 0}, /* UNI=654, Hall=348 */
    },
    {
        {0}, /* UNI=655, Hall=343 */
        {0}, /* UNI=655, Hall=344 */
        {0}, /* UNI=655, Hall=345 */
        {0}, /* UNI=655, Hall=346 */
        {0}, /* UNI=655, Hall=347 */
        {0}, /* UNI=655, Hall=348 */
    },
    {
        {0}, /* UNI=656, Hall=343 */
        {0}, /* UNI=656, Hall=344 */
        {0}, /* UNI=656, Hall=345 */
        {0}, /* UNI=656, Hall=346 */
        {0}, /* UNI=656, Hall=347 */
        {0}, /* UNI=656, Hall=348 */
    },
    {
        {9278103, 0}, /* UNI=657, Hall=343 */
        {9278103, 0}, /* UNI=657, Hall=344 */
        {9273943, 0}, /* UNI=657, Hall=345 */
        {9273943, 0}, /* UNI=657, Hall=346 */
        {9279715, 0}, /* UNI=657, Hall=347 */
        {9279715, 0}, /* UNI=657, Hall=348 */
    },
    {
        {0}, /* UNI=658, Hall=343 */
        {0}, /* UNI=658, Hall=344 */
        {0}, /* UNI=658, Hall=345 */
        {0}, /* UNI=658, Hall=346 */
        {0}, /* UNI=658, Hall=347 */
        {0}, /* UNI=658, Hall=348 */
    },
    {
        {0}, /* UNI=659, Hall=343 */
        {0}, /* UNI=659, Hall=344 */
        {0}, /* UNI=659, Hall=345 */
        {0}, /* UNI=659, Hall=346 */
        {0}, /* UNI=659, Hall=347 */
        {0}, /* UNI=659, Hall=348 */
    },
    {
        {9278103, 0}, /* UNI=660, Hall=343 */
        {9278103, 0}, /* UNI=660, Hall=344 */
        {9273943, 0}, /* UNI=660, Hall=345 */
        {9273943, 0}, /* UNI=660, Hall=346 */
        {9279715, 0}, /* UNI=660, Hall=347 */
        {9279715, 0}, /* UNI=660, Hall=348 */
    },
    {
        {0}, /* UNI=661, Hall=349 */
    },
    {
        {0}, /* UNI=662, Hall=349 */
    },
    {
        {0}, /* UNI=663, Hall=349 */
    },
    {
        {0}, /* UNI=664, Hall=349 */
    },
    {
        {0}, /* UNI=665, Hall=349 */
    },
    {
        {0}, /* UNI=666, Hall=349 */
    },
    {
        {0}, /* UNI=667, Hall=350 */
    },
    {
        {0}, /* UNI=668, Hall=350 */
    },
    {
        {0}, /* UNI=669, Hall=350 */
    },
    {
        {0}, /* UNI=670, Hall=350 */
    },
    {
        {0}, /* UNI=671, Hall=350 */
    },
    {
        {0}, /* UNI=672, Hall=350 */
    },
    {
        {0}, /* UNI=673, Hall=351 */
    },
    {
        {0}, /* UNI=674, Hall=351 */
    },
    {
        {0}, /* UNI=675, Hall=351 */
    },
    {
        {0}, /* UNI=676, Hall=351 */
    },
    {
        {0}, /* UNI=677, Hall=351 */
    },
    {
        {0}, /* UNI=678, Hall=351 */
    },
    {
        {0}, /* UNI=679, Hall=352 */
    },
    {
        {0}, /* UNI=680, Hall=352 */
    },
    {
        {0}, /* UNI=681, Hall=352 */
    },
    {
        {0}, /* UNI=682, Hall=352 */
    },
    {
        {0}, /* UNI=683, Hall=352 */
    },
    {
        {0}, /* UNI=684, Hall=352 */
    },
    {
        {0}, /* UNI=685, Hall=353 */
    },
    {
        {0}, /* UNI=686, Hall=353 */
    },
    {
        {0}, /* UNI=687, Hall=353 */
    },
    {
        {0}, /* UNI=688, Hall=353 */
    },
    {
        {0}, /* UNI=689, Hall=354 */
    },
    {
        {0}, /* UNI=690, Hall=354 */
    },
    {
        {0}, /* UNI=691, Hall=354 */
    },
    {
        {0}, /* UNI=692, Hall=354 */
    },
    {
        {0}, /* UNI=693, Hall=355 */
    },
    {
        {0}, /* UNI=694, Hall=355 */
    },
    {
        {0}, /* UNI=695, Hall=355 */
    },
    {
        {0}, /* UNI=696, Hall=355 */
    },
    {
        {0}, /* UNI=697, Hall=355 */
    },
    {
        {0}, /* UNI=698, Hall=355 */
    },
    {
        {0}, /* UNI=699, Hall=356 */
    },
    {
        {0}, /* UNI=700, Hall=356 */
    },
    {
        {0}, /* UNI=701, Hall=356 */
    },
    {
        {0}, /* UNI=702, Hall=356 */
    },
    {
        {0}, /* UNI=703, Hall=357 */
    },
    {
        {0}, /* UNI=704, Hall=357 */
    },
    {
        {0}, /* UNI=705, Hall=357 */
    },
    {
        {0}, /* UNI=706, Hall=357 */
    },
    {
        {0}, /* UNI=707, Hall=357 */
    },
    {
        {0}, /* UNI=708, Hall=357 */
    },
    {
        {0}, /* UNI=709, Hall=357 */
    },
    {
        {0}, /* UNI=710, Hall=357 */
    },
    {
        {0}, /* UNI=711, Hall=358 */
    },
    {
        {0}, /* UNI=712, Hall=358 */
    },
    {
        {0}, /* UNI=713, Hall=358 */
    },
    {
        {0}, /* UNI=714, Hall=358 */
    },
    {
        {0}, /* UNI=715, Hall=358 */
    },
    {
        {0}, /* UNI=716, Hall=358 */
    },
    {
        {0}, /* UNI=717, Hall=358 */
    },
    {
        {0}, /* UNI=718, Hall=358 */
    },
    {
        {0}, /* UNI=719, Hall=359 */
        {0}, /* UNI=719, Hall=360 */
    },
    {
        {0}, /* UNI=720, Hall=359 */
        {0}, /* UNI=720, Hall=360 */
    },
    {
        {0}, /* UNI=721, Hall=359 */
        {0}, /* UNI=721, Hall=360 */
    },
    {
        {0}, /* UNI=722, Hall=359 */
        {0}, /* UNI=722, Hall=360 */
    },
    {
        {0}, /* UNI=723, Hall=359 */
        {0}, /* UNI=723, Hall=360 */
    },
    {
        {0}, /* UNI=724, Hall=359 */
        {0}, /* UNI=724, Hall=360 */
    },
    {
        {0}, /* UNI=725, Hall=359 */
        {0}, /* UNI=725, Hall=360 */
    },
    {
        {0}, /* UNI=726, Hall=359 */
        {0}, /* UNI=726, Hall=360 */
    },
    {
        {0}, /* UNI=727, Hall=361 */
        {0}, /* UNI=727, Hall=362 */
    },
    {
        {0}, /* UNI=728, Hall=361 */
        {0}, /* UNI=728, Hall=362 */
    },
    {
        {0}, /* UNI=729, Hall=361 */
        {0}, /* UNI=729, Hall=362 */
    },
    {
        {0}, /* UNI=730, Hall=361 */
        {0}, /* UNI=730, Hall=362 */
    },
    {
        {0}, /* UNI=731, Hall=361 */
        {0}, /* UNI=731, Hall=362 */
    },
    {
        {0}, /* UNI=732, Hall=361 */
        {0}, /* UNI=732, Hall=362 */
    },
    {
        {0}, /* UNI=733, Hall=361 */
        {0}, /* UNI=733, Hall=362 */
    },
    {
        {0}, /* UNI=734, Hall=361 */
        {0}, /* UNI=734, Hall=362 */
    },
    {
        {0}, /* UNI=735, Hall=363 */
    },
    {
        {0}, /* UNI=736, Hall=363 */
    },
    {
        {0}, /* UNI=737, Hall=363 */
    },
    {
        {0}, /* UNI=738, Hall=363 */
    },
    {
        {0}, /* UNI=739, Hall=363 */
    },
    {
        {0}, /* UNI=740, Hall=363 */
    },
    {
        {0}, /* UNI=741, Hall=364 */
        {0}, /* UNI=741, Hall=365 */
    },
    {
        {0}, /* UNI=742, Hall=364 */
        {0}, /* UNI=742, Hall=365 */
    },
    {
        {0}, /* UNI=743, Hall=364 */
        {0}, /* UNI=743, Hall=365 */
    },
    {
        {0}, /* UNI=744, Hall=364 */
        {0}, /* UNI=744, Hall=365 */
    },
    {
        {0}, /* UNI=745, Hall=364 */
        {0}, /* UNI=745, Hall=365 */
    },
    {
        {0}, /* UNI=746, Hall=364 */
        {0}, /* UNI=746, Hall=365 */
    },
    {
        {0}, /* UNI=747, Hall=366 */
    },
    {
        {0}, /* UNI=748, Hall=366 */
    },
    {
        {0}, /* UNI=749, Hall=366 */
    },
    {
        {0}, /* UNI=750, Hall=366 */
    },
    {
        {0}, /* UNI=751, Hall=366 */
    },
    {
        {0}, /* UNI=752, Hall=366 */
    },
    {
        {0}, /* UNI=753, Hall=366 */
    },
    {
        {0}, /* UNI=754, Hall=366 */
    },
    {
        {0}, /* UNI=755, Hall=367 */
    },
    {
        {0}, /* UNI=756, Hall=367 */
    },
    {
        {0}, /* UNI=757, Hall=367 */
    },
    {
        {0}, /* UNI=758, Hall=367 */
    },
    {
        {0}, /* UNI=759, Hall=367 */
    },
    {
        {0}, /* UNI=760, Hall=367 */
    },
    {
        {0}, /* UNI=761, Hall=367 */
    },
    {
        {0}, /* UNI=762, Hall=367 */
    },
    {
        {0}, /* UNI=763, Hall=368 */
    },
    {
        {0}, /* UNI=764, Hall=368 */
    },
    {
        {0}, /* UNI=765, Hall=368 */
    },
    {
        {0}, /* UNI=766, Hall=368 */
    },
    {
        {0}, /* UNI=767, Hall=368 */
    },
    {
        {0}, /* UNI=768, Hall=368 */
    },
    {
        {0}, /* UNI=769, Hall=368 */
    },
    {
        {0}, /* UNI=770, Hall=368 */
    },
    {
        {0}, /* UNI=771, Hall=369 */
    },
    {
        {0}, /* UNI=772, Hall=369 */
    },
    {
        {0}, /* UNI=773, Hall=369 */
    },
    {
        {0}, /* UNI=774, Hall=369 */
    },
    {
        {0}, /* UNI=775, Hall=369 */
    },
    {
        {0}, /* UNI=776, Hall=369 */
    },
    {
        {0}, /* UNI=777, Hall=369 */
    },
    {
        {0}, /* UNI=778, Hall=369 */
    },
    {
        {0}, /* UNI=779, Hall=370 */
    },
    {
        {0}, /* UNI=780, Hall=370 */
    },
    {
        {0}, /* UNI=781, Hall=370 */
    },
    {
        {0}, /* UNI=782, Hall=370 */
    },
    {
        {0}, /* UNI=783, Hall=370 */
    },
    {
        {0}, /* UNI=784, Hall=370 */
    },
    {
        {0}, /* UNI=785, Hall=370 */
    },
    {
        {0}, /* UNI=786, Hall=370 */
    },
    {
        {0}, /* UNI=787, Hall=371 */
    },
    {
        {0}, /* UNI=788, Hall=371 */
    },
    {
        {0}, /* UNI=789, Hall=371 */
    },
    {
        {0}, /* UNI=790, Hall=371 */
    },
    {
        {0}, /* UNI=791, Hall=371 */
    },
    {
        {0}, /* UNI=792, Hall=371 */
    },
    {
        {0}, /* UNI=793, Hall=371 */
    },
    {
        {0}, /* UNI=794, Hall=371 */
    },
    {
        {0}, /* UNI=795, Hall=372 */
    },
    {
        {0}, /* UNI=796, Hall=372 */
    },
    {
        {0}, /* UNI=797, Hall=372 */
    },
    {
        {0}, /* UNI=798, Hall=372 */
    },
    {
        {0}, /* UNI=799, Hall=372 */
    },
    {
        {0}, /* UNI=800, Hall=372 */
    },
    {
        {0}, /* UNI=801, Hall=372 */
    },
    {
        {0}, /* UNI=802, Hall=372 */
    },
    {
        {0}, /* UNI=803, Hall=373 */
    },
    {
        {0}, /* UNI=804, Hall=373 */
    },
    {
        {0}, /* UNI=805, Hall=373 */
    },
    {
        {0}, /* UNI=806, Hall=373 */
    },
    {
        {0}, /* UNI=807, Hall=373 */
    },
    {
        {0}, /* UNI=808, Hall=373 */
    },
    {
        {0}, /* UNI=809, Hall=373 */
    },
    {
        {0}, /* UNI=810, Hall=373 */
    },
    {
        {0}, /* UNI=811, Hall=374 */
    },
    {
        {0}, /* UNI=812, Hall=374 */
    },
    {
        {0}, /* UNI=813, Hall=374 */
    },
    {
        {0}, /* UNI=814, Hall=374 */
    },
    {
        {0}, /* UNI=815, Hall=374 */
    },
    {
        {0}, /* UNI=816, Hall=374 */
    },
    {
        {0}, /* UNI=817, Hall=375 */
    },
    {
        {0}, /* UNI=818, Hall=375 */
    },
    {
        {0}, /* UNI=819, Hall=375 */
    },
    {
        {0}, /* UNI=820, Hall=375 */
    },
    {
        {0}, /* UNI=821, Hall=375 */
    },
    {
        {0}, /* UNI=822, Hall=375 */
    },
    {
        {0}, /* UNI=823, Hall=376 */
    },
    {
        {0}, /* UNI=824, Hall=376 */
    },
    {
        {0}, /* UNI=825, Hall=376 */
    },
    {
        {0}, /* UNI=826, Hall=376 */
    },
    {
        {0}, /* UNI=827, Hall=376 */
    },
    {
        {0}, /* UNI=828, Hall=376 */
    },
    {
        {0}, /* UNI=829, Hall=376 */
    },
    {
        {0}, /* UNI=830, Hall=376 */
    },
    {
        {0}, /* UNI=831, Hall=377 */
    },
    {
        {0}, /* UNI=832, Hall=377 */
    },
    {
        {0}, /* UNI=833, Hall=377 */
    },
    {
        {0}, /* UNI=834, Hall=377 */
    },
    {
        {0}, /* UNI=835, Hall=377 */
    },
    {
        {0}, /* UNI=836, Hall=377 */
    },
    {
        {0}, /* UNI=837, Hall=377 */
    },
    {
        {0}, /* UNI=838, Hall=377 */
    },
    {
        {0}, /* UNI=839, Hall=378 */
    },
    {
        {0}, /* UNI=840, Hall=378 */
    },
    {
        {0}, /* UNI=841, Hall=378 */
    },
    {
        {0}, /* UNI=842, Hall=378 */
    },
    {
        {0}, /* UNI=843, Hall=378 */
    },
    {
        {0}, /* UNI=844, Hall=378 */
    },
    {
        {0}, /* UNI=845, Hall=378 */
    },
    {
        {0}, /* UNI=846, Hall=378 */
    },
    {
        {0}, /* UNI=847, Hall=379 */
    },
    {
        {0}, /* UNI=848, Hall=379 */
    },
    {
        {0}, /* UNI=849, Hall=379 */
    },
    {
        {0}, /* UNI=850, Hall=379 */
    },
    {
        {0}, /* UNI=851, Hall=379 */
    },
    {
        {0}, /* UNI=852, Hall=379 */
    },
    {
        {0}, /* UNI=853, Hall=379 */
    },
    {
        {0}, /* UNI=854, Hall=379 */
    },
    {
        {0}, /* UNI=855, Hall=380 */
    },
    {
        {0}, /* UNI=856, Hall=380 */
    },
    {
        {0}, /* UNI=857, Hall=380 */
    },
    {
        {0}, /* UNI=858, Hall=380 */
    },
    {
        {0}, /* UNI=859, Hall=380 */
    },
    {
        {0}, /* UNI=860, Hall=380 */
    },
    {
        {0}, /* UNI=861, Hall=380 */
    },
    {
        {0}, /* UNI=862, Hall=380 */
    },
    {
        {0}, /* UNI=863, Hall=381 */
    },
    {
        {0}, /* UNI=864, Hall=381 */
    },
    {
        {0}, /* UNI=865, Hall=381 */
    },
    {
        {0}, /* UNI=866, Hall=381 */
    },
    {
        {0}, /* UNI=867, Hall=381 */
    },
    {
        {0}, /* UNI=868, Hall=381 */
    },
    {
        {0}, /* UNI=869, Hall=381 */
    },
    {
        {0}, /* UNI=870, Hall=381 */
    },
    {
        {0}, /* UNI=871, Hall=382 */
    },
    {
        {0}, /* UNI=872, Hall=382 */
    },
    {
        {0}, /* UNI=873, Hall=382 */
    },
    {
        {0}, /* UNI=874, Hall=382 */
    },
    {
        {0}, /* UNI=875, Hall=382 */
    },
    {
        {0}, /* UNI=876, Hall=382 */
    },
    {
        {0}, /* UNI=877, Hall=382 */
    },
    {
        {0}, /* UNI=878, Hall=382 */
    },
    {
        {0}, /* UNI=879, Hall=383 */
    },
    {
        {0}, /* UNI=880, Hall=383 */
    },
    {
        {0}, /* UNI=881, Hall=383 */
    },
    {
        {0}, /* UNI=882, Hall=383 */
    },
    {
        {0}, /* UNI=883, Hall=383 */
    },
    {
        {0}, /* UNI=884, Hall=383 */
    },
    {
        {0}, /* UNI=885, Hall=383 */
    },
    {
        {0}, /* UNI=886, Hall=383 */
    },
    {
        {0}, /* UNI=887, Hall=384 */
    },
    {
        {0}, /* UNI=888, Hall=384 */
    },
    {
        {0}, /* UNI=889, Hall=384 */
    },
    {
        {0}, /* UNI=890, Hall=384 */
    },
    {
        {0}, /* UNI=891, Hall=384 */
    },
    {
        {0}, /* UNI=892, Hall=384 */
    },
    {
        {0}, /* UNI=893, Hall=385 */
    },
    {
        {0}, /* UNI=894, Hall=385 */
    },
    {
        {0}, /* UNI=895, Hall=385 */
    },
    {
        {0}, /* UNI=896, Hall=385 */
    },
    {
        {0}, /* UNI=897, Hall=385 */
    },
    {
        {0}, /* UNI=898, Hall=385 */
    },
    {
        {0}, /* UNI=899, Hall=386 */
    },
    {
        {0}, /* UNI=900, Hall=386 */
    },
    {
        {0}, /* UNI=901, Hall=386 */
    },
    {
        {0}, /* UNI=902, Hall=386 */
    },
    {
        {0}, /* UNI=903, Hall=386 */
    },
    {
        {0}, /* UNI=904, Hall=386 */
    },
    {
        {0}, /* UNI=905, Hall=387 */
    },
    {
        {0}, /* UNI=906, Hall=387 */
    },
    {
        {0}, /* UNI=907, Hall=387 */
    },
    {
        {0}, /* UNI=908, Hall=387 */
    },
    {
        {0}, /* UNI=909, Hall=387 */
    },
    {
        {0}, /* UNI=910, Hall=387 */
    },
    {
        {0}, /* UNI=911, Hall=388 */
    },
    {
        {0}, /* UNI=912, Hall=388 */
    },
    {
        {0}, /* UNI=913, Hall=388 */
    },
    {
        {0}, /* UNI=914, Hall=388 */
    },
    {
        {0}, /* UNI=915, Hall=388 */
    },
    {
        {0}, /* UNI=916, Hall=388 */
    },
    {
        {0}, /* UNI=917, Hall=388 */
    },
    {
        {0}, /* UNI=918, Hall=388 */
    },
    {
        {0}, /* UNI=919, Hall=389 */
    },
    {
        {0}, /* UNI=920, Hall=389 */
    },
    {
        {0}, /* UNI=921, Hall=389 */
    },
    {
        {0}, /* UNI=922, Hall=389 */
    },
    {
        {0}, /* UNI=923, Hall=389 */
    },
    {
        {0}, /* UNI=924, Hall=389 */
    },
    {
        {0}, /* UNI=925, Hall=389 */
    },
    {
        {0}, /* UNI=926, Hall=389 */
    },
    {
        {0}, /* UNI=927, Hall=390 */
    },
    {
        {0}, /* UNI=928, Hall=390 */
    },
    {
        {0}, /* UNI=929, Hall=390 */
    },
    {
        {0}, /* UNI=930, Hall=390 */
    },
    {
        {0}, /* UNI=931, Hall=390 */
    },
    {
        {0}, /* UNI=932, Hall=390 */
    },
    {
        {0}, /* UNI=933, Hall=390 */
    },
    {
        {0}, /* UNI=934, Hall=390 */
    },
    {
        {0}, /* UNI=935, Hall=391 */
    },
    {
        {0}, /* UNI=936, Hall=391 */
    },
    {
        {0}, /* UNI=937, Hall=391 */
    },
    {
        {0}, /* UNI=938, Hall=391 */
    },
    {
        {0}, /* UNI=939, Hall=391 */
    },
    {
        {0}, /* UNI=940, Hall=391 */
    },
    {
        {0}, /* UNI=941, Hall=391 */
    },
    {
        {0}, /* UNI=942, Hall=391 */
    },
    {
        {0}, /* UNI=943, Hall=392 */
    },
    {
        {0}, /* UNI=944, Hall=392 */
    },
    {
        {0}, /* UNI=945, Hall=392 */
    },
    {
        {0}, /* UNI=946, Hall=392 */
    },
    {
        {0}, /* UNI=947, Hall=392 */
    },
    {
        {0}, /* UNI=948, Hall=392 */
    },
    {
        {0}, /* UNI=949, Hall=392 */
    },
    {
        {0}, /* UNI=950, Hall=392 */
    },
    {
        {0}, /* UNI=951, Hall=393 */
    },
    {
        {0}, /* UNI=952, Hall=393 */
    },
    {
        {0}, /* UNI=953, Hall=393 */
    },
    {
        {0}, /* UNI=954, Hall=393 */
    },
    {
        {0}, /* UNI=955, Hall=393 */
    },
    {
        {0}, /* UNI=956, Hall=393 */
    },
    {
        {0}, /* UNI=957, Hall=393 */
    },
    {
        {0}, /* UNI=958, Hall=393 */
    },
    {
        {0}, /* UNI=959, Hall=394 */
    },
    {
        {0}, /* UNI=960, Hall=394 */
    },
    {
        {0}, /* UNI=961, Hall=394 */
    },
    {
        {0}, /* UNI=962, Hall=394 */
    },
    {
        {0}, /* UNI=963, Hall=394 */
    },
    {
        {0}, /* UNI=964, Hall=394 */
    },
    {
        {0}, /* UNI=965, Hall=394 */
    },
    {
        {0}, /* UNI=966, Hall=394 */
    },
    {
        {0}, /* UNI=967, Hall=395 */
    },
    {
        {0}, /* UNI=968, Hall=395 */
    },
    {
        {0}, /* UNI=969, Hall=395 */
    },
    {
        {0}, /* UNI=970, Hall=395 */
    },
    {
        {0}, /* UNI=971, Hall=395 */
    },
    {
        {0}, /* UNI=972, Hall=395 */
    },
    {
        {0}, /* UNI=973, Hall=395 */
    },
    {
        {0}, /* UNI=974, Hall=395 */
    },
    {
        {0}, /* UNI=975, Hall=396 */
    },
    {
        {0}, /* UNI=976, Hall=396 */
    },
    {
        {0}, /* UNI=977, Hall=396 */
    },
    {
        {0}, /* UNI=978, Hall=396 */
    },
    {
        {0}, /* UNI=979, Hall=396 */
    },
    {
        {0}, /* UNI=980, Hall=396 */
    },
    {
        {0}, /* UNI=981, Hall=397 */
    },
    {
        {0}, /* UNI=982, Hall=397 */
    },
    {
        {0}, /* UNI=983, Hall=397 */
    },
    {
        {0}, /* UNI=984, Hall=397 */
    },
    {
        {0}, /* UNI=985, Hall=397 */
    },
    {
        {0}, /* UNI=986, Hall=397 */
    },
    {
        {0}, /* UNI=987, Hall=398 */
    },
    {
        {0}, /* UNI=988, Hall=398 */
    },
    {
        {0}, /* UNI=989, Hall=398 */
    },
    {
        {0}, /* UNI=990, Hall=398 */
    },
    {
        {0}, /* UNI=991, Hall=398 */
    },
    {
        {0}, /* UNI=992, Hall=398 */
    },
    {
        {0}, /* UNI=993, Hall=399 */
    },
    {
        {0}, /* UNI=994, Hall=399 */
    },
    {
        {0}, /* UNI=995, Hall=399 */
    },
    {
        {0}, /* UNI=996, Hall=399 */
    },
    {
        {0}, /* UNI=997, Hall=399 */
    },
    {
        {0}, /* UNI=998, Hall=399 */
    },
    {
        {0}, /* UNI=999, Hall=400 */
    },
    {
        {0}, /* UNI=1000, Hall=400 */
    },
    {
        {0}, /* UNI=1001, Hall=400 */
    },
    {
        {0}, /* UNI=1002, Hall=400 */
    },
    {
        {0}, /* UNI=1003, Hall=400 */
    },
    {
        {0}, /* UNI=1004, Hall=400 */
    },
    {
        {0}, /* UNI=1005, Hall=400 */
    },
    {
        {0}, /* UNI=1006, Hall=400 */
    },
    {
        {0}, /* UNI=1007, Hall=400 */
    },
    {
        {0}, /* UNI=1008, Hall=400 */
    },
    {
        {0}, /* UNI=1009, Hall=400 */
    },
    {
        {0}, /* UNI=1010, Hall=400 */
    },
    {
        {0}, /* UNI=1011, Hall=401 */
    },
    {
        {0}, /* UNI=1012, Hall=401 */
    },
    {
        {0}, /* UNI=1013, Hall=401 */
    },
    {
        {0}, /* UNI=1014, Hall=401 */
    },
    {
        {0}, /* UNI=1015, Hall=401 */
    },
    {
        {0}, /* UNI=1016, Hall=401 */
    },
    {
        {0}, /* UNI=1017, Hall=401 */
    },
    {
        {0}, /* UNI=1018, Hall=401 */
    },
    {
        {0}, /* UNI=1019, Hall=401 */
    },
    {
        {0}, /* UNI=1020, Hall=401 */
    },
    {
        {0}, /* UNI=1021, Hall=401 */
    },
    {
        {0}, /* UNI=1022, Hall=401 */
    },
    {
        {0}, /* UNI=1023, Hall=402 */
        {0}, /* UNI=1023, Hall=403 */
    },
    {
        {0}, /* UNI=1024, Hall=402 */
        {0}, /* UNI=1024, Hall=403 */
    },
    {
        {0}, /* UNI=1025, Hall=402 */
        {0}, /* UNI=1025, Hall=403 */
    },
    {
        {0}, /* UNI=1026, Hall=402 */
        {0}, /* UNI=1026, Hall=403 */
    },
    {
        {0}, /* UNI=1027, Hall=402 */
        {0}, /* UNI=1027, Hall=403 */
    },
    {
        {0}, /* UNI=1028, Hall=402 */
        {0}, /* UNI=1028, Hall=403 */
    },
    {
        {0}, /* UNI=1029, Hall=402 */
        {0}, /* UNI=1029, Hall=403 */
    },
    {
        {0}, /* UNI=1030, Hall=402 */
        {0}, /* UNI=1030, Hall=403 */
    },
    {
        {0}, /* UNI=1031, Hall=402 */
        {0}, /* UNI=1031, Hall=403 */
    },
    {
        {0}, /* UNI=1032, Hall=402 */
        {0}, /* UNI=1032, Hall=403 */
    },
    {
        {0}, /* UNI=1033, Hall=402 */
        {0}, /* UNI=1033, Hall=403 */
    },
    {
        {0}, /* UNI=1034, Hall=402 */
        {0}, /* UNI=1034, Hall=403 */
    },
    {
        {0}, /* UNI=1035, Hall=404 */
        {0}, /* UNI=1035, Hall=405 */
    },
    {
        {0}, /* UNI=1036, Hall=404 */
        {0}, /* UNI=1036, Hall=405 */
    },
    {
        {0}, /* UNI=1037, Hall=404 */
        {0}, /* UNI=1037, Hall=405 */
    },
    {
        {0}, /* UNI=1038, Hall=404 */
        {0}, /* UNI=1038, Hall=405 */
    },
    {
        {0}, /* UNI=1039, Hall=404 */
        {0}, /* UNI=1039, Hall=405 */
    },
    {
        {0}, /* UNI=1040, Hall=404 */
        {0}, /* UNI=1040, Hall=405 */
    },
    {
        {0}, /* UNI=1041, Hall=404 */
        {0}, /* UNI=1041, Hall=405 */
    },
    {
        {0}, /* UNI=1042, Hall=404 */
        {0}, /* UNI=1042, Hall=405 */
    },
    {
        {0}, /* UNI=1043, Hall=404 */
        {0}, /* UNI=1043, Hall=405 */
    },
    {
        {0}, /* UNI=1044, Hall=404 */
        {0}, /* UNI=1044, Hall=405 */
    },
    {
        {0}, /* UNI=1045, Hall=404 */
        {0}, /* UNI=1045, Hall=405 */
    },
    {
        {0}, /* UNI=1046, Hall=404 */
        {0}, /* UNI=1046, Hall=405 */
    },
    {
        {0}, /* UNI=1047, Hall=406 */
    },
    {
        {0}, /* UNI=1048, Hall=406 */
    },
    {
        {0}, /* UNI=1049, Hall=406 */
    },
    {
        {0}, /* UNI=1050, Hall=406 */
    },
    {
        {0}, /* UNI=1051, Hall=406 */
    },
    {
        {0}, /* UNI=1052, Hall=406 */
    },
    {
        {0}, /* UNI=1053, Hall=406 */
    },
    {
        {0}, /* UNI=1054, Hall=406 */
    },
    {
        {0}, /* UNI=1055, Hall=406 */
    },
    {
        {0}, /* UNI=1056, Hall=406 */
    },
    {
        {0}, /* UNI=1057, Hall=406 */
    },
    {
        {0}, /* UNI=1058, Hall=406 */
    },
    {
        {0}, /* UNI=1059, Hall=407 */
    },
    {
        {0}, /* UNI=1060, Hall=407 */
    },
    {
        {0}, /* UNI=1061, Hall=407 */
    },
    {
        {0}, /* UNI=1062, Hall=407 */
    },
    {
        {0}, /* UNI=1063, Hall=407 */
    },
    {
        {0}, /* UNI=1064, Hall=407 */
    },
    {
        {0}, /* UNI=1065, Hall=407 */
    },
    {
        {0}, /* UNI=1066, Hall=407 */
    },
    {
        {0}, /* UNI=1067, Hall=407 */
    },
    {
        {0}, /* UNI=1068, Hall=407 */
    },
    {
        {0}, /* UNI=1069, Hall=407 */
    },
    {
        {0}, /* UNI=1070, Hall=407 */
    },
    {
        {0}, /* UNI=1071, Hall=408 */
        {0}, /* UNI=1071, Hall=409 */
    },
    {
        {0}, /* UNI=1072, Hall=408 */
        {0}, /* UNI=1072, Hall=409 */
    },
    {
        {0}, /* UNI=1073, Hall=408 */
        {0}, /* UNI=1073, Hall=409 */
    },
    {
        {0}, /* UNI=1074, Hall=408 */
        {0}, /* UNI=1074, Hall=409 */
    },
    {
        {0}, /* UNI=1075, Hall=408 */
        {0}, /* UNI=1075, Hall=409 */
    },
    {
        {0}, /* UNI=1076, Hall=408 */
        {0}, /* UNI=1076, Hall=409 */
    },
    {
        {0}, /* UNI=1077, Hall=408 */
        {0}, /* UNI=1077, Hall=409 */
    },
    {
        {0}, /* UNI=1078, Hall=408 */
        {0}, /* UNI=1078, Hall=409 */
    },
    {
        {0}, /* UNI=1079, Hall=408 */
        {0}, /* UNI=1079, Hall=409 */
    },
    {
        {0}, /* UNI=1080, Hall=408 */
        {0}, /* UNI=1080, Hall=409 */
    },
    {
        {0}, /* UNI=1081, Hall=408 */
        {0}, /* UNI=1081, Hall=409 */
    },
    {
        {0}, /* UNI=1082, Hall=408 */
        {0}, /* UNI=1082, Hall=409 */
    },
    {
        {0}, /* UNI=1083, Hall=410 */
        {0}, /* UNI=1083, Hall=411 */
    },
    {
        {0}, /* UNI=1084, Hall=410 */
        {0}, /* UNI=1084, Hall=411 */
    },
    {
        {0}, /* UNI=1085, Hall=410 */
        {0}, /* UNI=1085, Hall=411 */
    },
    {
        {0}, /* UNI=1086, Hall=410 */
        {0}, /* UNI=1086, Hall=411 */
    },
    {
        {0}, /* UNI=1087, Hall=410 */
        {0}, /* UNI=1087, Hall=411 */
    },
    {
        {0}, /* UNI=1088, Hall=410 */
        {0}, /* UNI=1088, Hall=411 */
    },
    {
        {0}, /* UNI=1089, Hall=410 */
        {0}, /* UNI=1089, Hall=411 */
    },
    {
        {0}, /* UNI=1090, Hall=410 */
        {0}, /* UNI=1090, Hall=411 */
    },
    {
        {0}, /* UNI=1091, Hall=410 */
        {0}, /* UNI=1091, Hall=411 */
    },
    {
        {0}, /* UNI=1092, Hall=410 */
        {0}, /* UNI=1092, Hall=411 */
    },
    {
        {0}, /* UNI=1093, Hall=410 */
        {0}, /* UNI=1093, Hall=411 */
    },
    {
        {0}, /* UNI=1094, Hall=410 */
        {0}, /* UNI=1094, Hall=411 */
    },
    {
        {0}, /* UNI=1095, Hall=412 */
    },
    {
        {0}, /* UNI=1096, Hall=412 */
    },
    {
        {0}, /* UNI=1097, Hall=412 */
    },
    {
        {0}, /* UNI=1098, Hall=412 */
    },
    {
        {0}, /* UNI=1099, Hall=412 */
    },
    {
        {0}, /* UNI=1100, Hall=412 */
    },
    {
        {0}, /* UNI=1101, Hall=412 */
    },
    {
        {0}, /* UNI=1102, Hall=412 */
    },
    {
        {0}, /* UNI=1103, Hall=412 */
    },
    {
        {0}, /* UNI=1104, Hall=412 */
    },
    {
        {0}, /* UNI=1105, Hall=412 */
    },
    {
        {0}, /* UNI=1106, Hall=412 */
    },
    {
        {0}, /* UNI=1107, Hall=413 */
    },
    {
        {0}, /* UNI=1108, Hall=413 */
    },
    {
        {0}, /* UNI=1109, Hall=413 */
    },
    {
        {0}, /* UNI=1110, Hall=413 */
    },
    {
        {0}, /* UNI=1111, Hall=413 */
    },
    {
        {0}, /* UNI=1112, Hall=413 */
    },
    {
        {0}, /* UNI=1113, Hall=413 */
    },
    {
        {0}, /* UNI=1114, Hall=413 */
    },
    {
        {0}, /* UNI=1115, Hall=413 */
    },
    {
        {0}, /* UNI=1116, Hall=413 */
    },
    {
        {0}, /* UNI=1117, Hall=413 */
    },
    {
        {0}, /* UNI=1118, Hall=413 */
    },
    {
        {0}, /* UNI=1119, Hall=414 */
        {0}, /* UNI=1119, Hall=415 */
    },
    {
        {0}, /* UNI=1120, Hall=414 */
        {0}, /* UNI=1120, Hall=415 */
    },
    {
        {0}, /* UNI=1121, Hall=414 */
        {0}, /* UNI=1121, Hall=415 */
    },
    {
        {0}, /* UNI=1122, Hall=414 */
        {0}, /* UNI=1122, Hall=415 */
    },
    {
        {0}, /* UNI=1123, Hall=414 */
        {0}, /* UNI=1123, Hall=415 */
    },
    {
        {0}, /* UNI=1124, Hall=414 */
        {0}, /* UNI=1124, Hall=415 */
    },
    {
        {0}, /* UNI=1125, Hall=414 */
        {0}, /* UNI=1125, Hall=415 */
    },
    {
        {0}, /* UNI=1126, Hall=414 */
        {0}, /* UNI=1126, Hall=415 */
    },
    {
        {0}, /* UNI=1127, Hall=414 */
        {0}, /* UNI=1127, Hall=415 */
    },
    {
        {0}, /* UNI=1128, Hall=414 */
        {0}, /* UNI=1128, Hall=415 */
    },
    {
        {0}, /* UNI=1129, Hall=414 */
        {0}, /* UNI=1129, Hall=415 */
    },
    {
        {0}, /* UNI=1130, Hall=414 */
        {0}, /* UNI=1130, Hall=415 */
    },
    {
        {0}, /* UNI=1131, Hall=416 */
        {0}, /* UNI=1131, Hall=417 */
    },
    {
        {0}, /* UNI=1132, Hall=416 */
        {0}, /* UNI=1132, Hall=417 */
    },
    {
        {0}, /* UNI=1133, Hall=416 */
        {0}, /* UNI=1133, Hall=417 */
    },
    {
        {0}, /* UNI=1134, Hall=416 */
        {0}, /* UNI=1134, Hall=417 */
    },
    {
        {0}, /* UNI=1135, Hall=416 */
        {0}, /* UNI=1135, Hall=417 */
    },
    {
        {0}, /* UNI=1136, Hall=416 */
        {0}, /* UNI=1136, Hall=417 */
    },
    {
        {0}, /* UNI=1137, Hall=416 */
        {0}, /* UNI=1137, Hall=417 */
    },
    {
        {0}, /* UNI=1138, Hall=416 */
        {0}, /* UNI=1138, Hall=417 */
    },
    {
        {0}, /* UNI=1139, Hall=416 */
        {0}, /* UNI=1139, Hall=417 */
    },
    {
        {0}, /* UNI=1140, Hall=416 */
        {0}, /* UNI=1140, Hall=417 */
    },
    {
        {0}, /* UNI=1141, Hall=416 */
        {0}, /* UNI=1141, Hall=417 */
    },
    {
        {0}, /* UNI=1142, Hall=416 */
        {0}, /* UNI=1142, Hall=417 */
    },
    {
        {0}, /* UNI=1143, Hall=418 */
    },
    {
        {0}, /* UNI=1144, Hall=418 */
    },
    {
        {0}, /* UNI=1145, Hall=418 */
    },
    {
        {0}, /* UNI=1146, Hall=418 */
    },
    {
        {0}, /* UNI=1147, Hall=418 */
    },
    {
        {0}, /* UNI=1148, Hall=418 */
    },
    {
        {0}, /* UNI=1149, Hall=418 */
    },
    {
        {0}, /* UNI=1150, Hall=418 */
    },
    {
        {0}, /* UNI=1151, Hall=418 */
    },
    {
        {0}, /* UNI=1152, Hall=418 */
    },
    {
        {0}, /* UNI=1153, Hall=418 */
    },
    {
        {0}, /* UNI=1154, Hall=418 */
    },
    {
        {0}, /* UNI=1155, Hall=419 */
    },
    {
        {0}, /* UNI=1156, Hall=419 */
    },
    {
        {0}, /* UNI=1157, Hall=419 */
    },
    {
        {0}, /* UNI=1158, Hall=419 */
    },
    {
        {0}, /* UNI=1159, Hall=419 */
    },
    {
        {0}, /* UNI=1160, Hall=419 */
    },
    {
        {0}, /* UNI=1161, Hall=419 */
    },
    {
        {0}, /* UNI=1162, Hall=419 */
    },
    {
        {0}, /* UNI=1163, Hall=419 */
    },
    {
        {0}, /* UNI=1164, Hall=419 */
    },
    {
        {0}, /* UNI=1165, Hall=419 */
    },
    {
        {0}, /* UNI=1166, Hall=419 */
    },
    {
        {0}, /* UNI=1167, Hall=420 */
        {0}, /* UNI=1167, Hall=421 */
    },
    {
        {0}, /* UNI=1168, Hall=420 */
        {0}, /* UNI=1168, Hall=421 */
    },
    {
        {0}, /* UNI=1169, Hall=420 */
        {0}, /* UNI=1169, Hall=421 */
    },
    {
        {0}, /* UNI=1170, Hall=420 */
        {0}, /* UNI=1170, Hall=421 */
    },
    {
        {0}, /* UNI=1171, Hall=420 */
        {0}, /* UNI=1171, Hall=421 */
    },
    {
        {0}, /* UNI=1172, Hall=420 */
        {0}, /* UNI=1172, Hall=421 */
    },
    {
        {0}, /* UNI=1173, Hall=420 */
        {0}, /* UNI=1173, Hall=421 */
    },
    {
        {0}, /* UNI=1174, Hall=420 */
        {0}, /* UNI=1174, Hall=421 */
    },
    {
        {0}, /* UNI=1175, Hall=420 */
        {0}, /* UNI=1175, Hall=421 */
    },
    {
        {0}, /* UNI=1176, Hall=420 */
        {0}, /* UNI=1176, Hall=421 */
    },
    {
        {0}, /* UNI=1177, Hall=420 */
        {0}, /* UNI=1177, Hall=421 */
    },
    {
        {0}, /* UNI=1178, Hall=420 */
        {0}, /* UNI=1178, Hall=421 */
    },
    {
        {0}, /* UNI=1179, Hall=422 */
        {0}, /* UNI=1179, Hall=423 */
    },
    {
        {0}, /* UNI=1180, Hall=422 */
        {0}, /* UNI=1180, Hall=423 */
    },
    {
        {0}, /* UNI=1181, Hall=422 */
        {0}, /* UNI=1181, Hall=423 */
    },
    {
        {0}, /* UNI=1182, Hall=422 */
        {0}, /* UNI=1182, Hall=423 */
    },
    {
        {0}, /* UNI=1183, Hall=422 */
        {0}, /* UNI=1183, Hall=423 */
    },
    {
        {0}, /* UNI=1184, Hall=422 */
        {0}, /* UNI=1184, Hall=423 */
    },
    {
        {0}, /* UNI=1185, Hall=422 */
        {0}, /* UNI=1185, Hall=423 */
    },
    {
        {0}, /* UNI=1186, Hall=422 */
        {0}, /* UNI=1186, Hall=423 */
    },
    {
        {0}, /* UNI=1187, Hall=422 */
        {0}, /* UNI=1187, Hall=423 */
    },
    {
        {0}, /* UNI=1188, Hall=422 */
        {0}, /* UNI=1188, Hall=423 */
    },
    {
        {0}, /* UNI=1189, Hall=422 */
        {0}, /* UNI=1189, Hall=423 */
    },
    {
        {0}, /* UNI=1190, Hall=422 */
        {0}, /* UNI=1190, Hall=423 */
    },
    {
        {0}, /* UNI=1191, Hall=424 */
    },
    {
        {0}, /* UNI=1192, Hall=424 */
    },
    {
        {0}, /* UNI=1193, Hall=424 */
    },
    {
        {0}, /* UNI=1194, Hall=424 */
    },
    {
        {0}, /* UNI=1195, Hall=424 */
    },
    {
        {0}, /* UNI=1196, Hall=424 */
    },
    {
        {0}, /* UNI=1197, Hall=424 */
    },
    {
        {0}, /* UNI=1198, Hall=424 */
    },
    {
        {0}, /* UNI=1199, Hall=424 */
    },
    {
        {0}, /* UNI=1200, Hall=424 */
    },
    {
        {0}, /* UNI=1201, Hall=425 */
    },
    {
        {0}, /* UNI=1202, Hall=425 */
    },
    {
        {0}, /* UNI=1203, Hall=425 */
    },
    {
        {0}, /* UNI=1204, Hall=425 */
    },
    {
        {0}, /* UNI=1205, Hall=425 */
    },
    {
        {0}, /* UNI=1206, Hall=425 */
    },
    {
        {0}, /* UNI=1207, Hall=425 */
    },
    {
        {0}, /* UNI=1208, Hall=425 */
    },
    {
        {0}, /* UNI=1209, Hall=425 */
    },
    {
        {0}, /* UNI=1210, Hall=425 */
    },
    {
        {0}, /* UNI=1211, Hall=426 */
        {0}, /* UNI=1211, Hall=427 */
    },
    {
        {0}, /* UNI=1212, Hall=426 */
        {0}, /* UNI=1212, Hall=427 */
    },
    {
        {0}, /* UNI=1213, Hall=426 */
        {0}, /* UNI=1213, Hall=427 */
    },
    {
        {0}, /* UNI=1214, Hall=426 */
        {0}, /* UNI=1214, Hall=427 */
    },
    {
        {0}, /* UNI=1215, Hall=426 */
        {0}, /* UNI=1215, Hall=427 */
    },
    {
        {0}, /* UNI=1216, Hall=426 */
        {0}, /* UNI=1216, Hall=427 */
    },
    {
        {0}, /* UNI=1217, Hall=426 */
        {0}, /* UNI=1217, Hall=427 */
    },
    {
        {0}, /* UNI=1218, Hall=426 */
        {0}, /* UNI=1218, Hall=427 */
    },
    {
        {0}, /* UNI=1219, Hall=426 */
        {0}, /* UNI=1219, Hall=427 */
    },
    {
        {0}, /* UNI=1220, Hall=426 */
        {0}, /* UNI=1220, Hall=427 */
    },
    {
        {0}, /* UNI=1221, Hall=428 */
        {0}, /* UNI=1221, Hall=429 */
    },
    {
        {0}, /* UNI=1222, Hall=428 */
        {0}, /* UNI=1222, Hall=429 */
    },
    {
        {0}, /* UNI=1223, Hall=428 */
        {0}, /* UNI=1223, Hall=429 */
    },
    {
        {0}, /* UNI=1224, Hall=428 */
        {0}, /* UNI=1224, Hall=429 */
    },
    {
        {0}, /* UNI=1225, Hall=428 */
        {0}, /* UNI=1225, Hall=429 */
    },
    {
        {0}, /* UNI=1226, Hall=428 */
        {0}, /* UNI=1226, Hall=429 */
    },
    {
        {0}, /* UNI=1227, Hall=428 */
        {0}, /* UNI=1227, Hall=429 */
    },
    {
        {0}, /* UNI=1228, Hall=428 */
        {0}, /* UNI=1228, Hall=429 */
    },
    {
        {0}, /* UNI=1229, Hall=428 */
        {0}, /* UNI=1229, Hall=429 */
    },
    {
        {0}, /* UNI=1230, Hall=428 */
        {0}, /* UNI=1230, Hall=429 */
    },
    {
        {0}, /* UNI=1231, Hall=430 */
    },
    {
        {0}, /* UNI=1232, Hall=430 */
    },
    {
        {0}, /* UNI=1233, Hall=430 */
    },
    {
        {0}, /* UNI=1234, Hall=431 */
    },
    {
        {0}, /* UNI=1235, Hall=431 */
    },
    {
        {0}, /* UNI=1236, Hall=431 */
    },
    {
        {0}, /* UNI=1237, Hall=432 */
    },
    {
        {0}, /* UNI=1238, Hall=432 */
    },
    {
        {0}, /* UNI=1239, Hall=432 */
    },
    {
        {0}, /* UNI=1240, Hall=433 */
        {0}, /* UNI=1240, Hall=434 */
    },
    {
        {0}, /* UNI=1241, Hall=433 */
        {0}, /* UNI=1241, Hall=434 */
    },
    {
        {0}, /* UNI=1242, Hall=433 */
        {0}, /* UNI=1242, Hall=434 */
    },
    {
        {0}, /* UNI=1243, Hall=435 */
    },
    {
        {0}, /* UNI=1244, Hall=435 */
    },
    {
        {0}, /* UNI=1245, Hall=435 */
    },
    {
        {0}, /* UNI=1246, Hall=435 */
    },
    {
        {0}, /* UNI=1247, Hall=436 */
        {0}, /* UNI=1247, Hall=437 */
    },
    {
        {0}, /* UNI=1248, Hall=436 */
        {0}, /* UNI=1248, Hall=437 */
    },
    {
        {0}, /* UNI=1249, Hall=436 */
        {0}, /* UNI=1249, Hall=437 */
    },
    {
        {0}, /* UNI=1250, Hall=436 */
        {0}, /* UNI=1250, Hall=437 */
    },
    {
        {0}, /* UNI=1251, Hall=438 */
    },
    {
        {0}, /* UNI=1252, Hall=438 */
    },
    {
        {0}, /* UNI=1253, Hall=438 */
    },
    {
        {0}, /* UNI=1254, Hall=438 */
    },
    {
        {0}, /* UNI=1255, Hall=439 */
    },
    {
        {0}, /* UNI=1256, Hall=439 */
    },
    {
        {0}, /* UNI=1257, Hall=439 */
    },
    {
        {0}, /* UNI=1258, Hall=439 */
    },
    {
        {0}, /* UNI=1259, Hall=440 */
    },
    {
        {0}, /* UNI=1260, Hall=440 */
    },
    {
        {0}, /* UNI=1261, Hall=440 */
    },
    {
        {0}, /* UNI=1262, Hall=440 */
    },
    {
        {0}, /* UNI=1263, Hall=441 */
    },
    {
        {0}, /* UNI=1264, Hall=441 */
    },
    {
        {0}, /* UNI=1265, Hall=441 */
    },
    {
        {0}, /* UNI=1266, Hall=441 */
    },
    {
        {0}, /* UNI=1267, Hall=442 */
    },
    {
        {0}, /* UNI=1268, Hall=442 */
    },
    {
        {0}, /* UNI=1269, Hall=442 */
    },
    {
        {0}, /* UNI=1270, Hall=442 */
    },
    {
        {0}, /* UNI=1271, Hall=443 */
    },
    {
        {0}, /* UNI=1272, Hall=443 */
    },
    {
        {0}, /* UNI=1273, Hall=443 */
    },
    {
        {0}, /* UNI=1274, Hall=443 */
    },
    {
        {0}, /* UNI=1275, Hall=444 */
        {0}, /* UNI=1275, Hall=445 */
    },
    {
        {0}, /* UNI=1276, Hall=444 */
        {0}, /* UNI=1276, Hall=445 */
    },
    {
        {0}, /* UNI=1277, Hall=444 */
        {0}, /* UNI=1277, Hall=445 */
    },
    {
        {0}, /* UNI=1278, Hall=444 */
        {0}, /* UNI=1278, Hall=445 */
    },
    {
        {0}, /* UNI=1279, Hall=446 */
    },
    {
        {0}, /* UNI=1280, Hall=446 */
    },
    {
        {0}, /* UNI=1281, Hall=446 */
    },
    {
        {0}, /* UNI=1282, Hall=446 */
    },
    {
        {0}, /* UNI=1283, Hall=447 */
    },
    {
        {0}, /* UNI=1284, Hall=447 */
    },
    {
        {0}, /* UNI=1285, Hall=447 */
    },
    {
        {0}, /* UNI=1286, Hall=447 */
    },
    {
        {0}, /* UNI=1287, Hall=448 */
    },
    {
        {0}, /* UNI=1288, Hall=448 */
    },
    {
        {0}, /* UNI=1289, Hall=448 */
    },
    {
        {0}, /* UNI=1290, Hall=448 */
    },
    {
        {0}, /* UNI=1291, Hall=449 */
    },
    {
        {0}, /* UNI=1292, Hall=449 */
    },
    {
        {0}, /* UNI=1293, Hall=449 */
    },
    {
        {0}, /* UNI=1294, Hall=449 */
    },
    {
        {0}, /* UNI=1295, Hall=450 */
        {0}, /* UNI=1295, Hall=451 */
    },
    {
        {0}, /* UNI=1296, Hall=450 */
        {0}, /* UNI=1296, Hall=451 */
    },
    {
        {0}, /* UNI=1297, Hall=450 */
        {0}, /* UNI=1297, Hall=451 */
    },
    {
        {0}, /* UNI=1298, Hall=450 */
        {0}, /* UNI=1298, Hall=451 */
    },
    {
        {0}, /* UNI=1299, Hall=452 */
        {0}, /* UNI=1299, Hall=453 */
    },
    {
        {0}, /* UNI=1300, Hall=452 */
        {0}, /* UNI=1300, Hall=453 */
    },
    {
        {0}, /* UNI=1301, Hall=452 */
        {0}, /* UNI=1301, Hall=453 */
    },
    {
        {0}, /* UNI=1302, Hall=452 */
        {0}, /* UNI=1302, Hall=453 */
    },
    {
        {0}, /* UNI=1303, Hall=454 */
    },
    {
        {0}, /* UNI=1304, Hall=454 */
    },
    {
        {0}, /* UNI=1305, Hall=454 */
    },
    {
        {0}, /* UNI=1306, Hall=454 */
    },
    {
        {0}, /* UNI=1307, Hall=454 */
    },
    {
        {0}, /* UNI=1308, Hall=454 */
    },
    {
        {0}, /* UNI=1309, Hall=455 */
    },
    {
        {0}, /* UNI=1310, Hall=455 */
    },
    {
        {0}, /* UNI=1311, Hall=455 */
    },
    {
        {0}, /* UNI=1312, Hall=455 */
    },
    {
        {0}, /* UNI=1313, Hall=455 */
    },
    {
        {0}, /* UNI=1314, Hall=455 */
    },
    {
        {0}, /* UNI=1315, Hall=456 */
    },
    {
        {0}, /* UNI=1316, Hall=456 */
    },
    {
        {0}, /* UNI=1317, Hall=456 */
    },
    {
        {0}, /* UNI=1318, Hall=456 */
    },
    {
        {0}, /* UNI=1319, Hall=456 */
    },
    {
        {0}, /* UNI=1320, Hall=456 */
    },
    {
        {0}, /* UNI=1321, Hall=457 */
    },
    {
        {0}, /* UNI=1322, Hall=457 */
    },
    {
        {0}, /* UNI=1323, Hall=457 */
    },
    {
        {0}, /* UNI=1324, Hall=457 */
    },
    {
        {0}, /* UNI=1325, Hall=457 */
    },
    {
        {0}, /* UNI=1326, Hall=457 */
    },
    {
        {0}, /* UNI=1327, Hall=458 */
        {0}, /* UNI=1327, Hall=459 */
    },
    {
        {0}, /* UNI=1328, Hall=458 */
        {0}, /* UNI=1328, Hall=459 */
    },
    {
        {0}, /* UNI=1329, Hall=458 */
        {0}, /* UNI=1329, Hall=459 */
    },
    {
        {0}, /* UNI=1330, Hall=458 */
        {0}, /* UNI=1330, Hall=459 */
    },
    {
        {0}, /* UNI=1331, Hall=458 */
        {0}, /* UNI=1331, Hall=459 */
    },
    {
        {0}, /* UNI=1332, Hall=458 */
        {0}, /* UNI=1332, Hall=459 */
    },
    {
        {0}, /* UNI=1333, Hall=460 */
        {0}, /* UNI=1333, Hall=461 */
    },
    {
        {0}, /* UNI=1334, Hall=460 */
        {0}, /* UNI=1334, Hall=461 */
    },
    {
        {0}, /* UNI=1335, Hall=460 */
        {0}, /* UNI=1335, Hall=461 */
    },
    {
        {0}, /* UNI=1336, Hall=460 */
        {0}, /* UNI=1336, Hall=461 */
    },
    {
        {0}, /* UNI=1337, Hall=460 */
        {0}, /* UNI=1337, Hall=461 */
    },
    {
        {0}, /* UNI=1338, Hall=460 */
        {0}, /* UNI=1338, Hall=461 */
    },
    {
        {0}, /* UNI=1339, Hall=462 */
    },
    {
        {0}, /* UNI=1340, Hall=462 */
    },
    {
        {0}, /* UNI=1341, Hall=462 */
    },
    {
        {0}, /* UNI=1342, Hall=462 */
    },
    {
        {0}, /* UNI=1343, Hall=463 */
    },
    {
        {0}, /* UNI=1344, Hall=463 */
    },
    {
        {0}, /* UNI=1345, Hall=463 */
    },
    {
        {0}, /* UNI=1346, Hall=463 */
    },
    {
        {0}, /* UNI=1347, Hall=464 */
    },
    {
        {0}, /* UNI=1348, Hall=464 */
    },
    {
        {0}, /* UNI=1349, Hall=464 */
    },
    {
        {0}, /* UNI=1350, Hall=464 */
    },
    {
        {0}, /* UNI=1351, Hall=465 */
    },
    {
        {0}, /* UNI=1352, Hall=465 */
    },
    {
        {0}, /* UNI=1353, Hall=465 */
    },
    {
        {0}, /* UNI=1354, Hall=465 */
    },
    {
        {0}, /* UNI=1355, Hall=466 */
    },
    {
        {0}, /* UNI=1356, Hall=466 */
    },
    {
        {0}, /* UNI=1357, Hall=466 */
    },
    {
        {0}, /* UNI=1358, Hall=466 */
    },
    {
        {0}, /* UNI=1359, Hall=467 */
    },
    {
        {0}, /* UNI=1360, Hall=467 */
    },
    {
        {0}, /* UNI=1361, Hall=467 */
    },
    {
        {0}, /* UNI=1362, Hall=467 */
    },
    {
        {0}, /* UNI=1363, Hall=468 */
    },
    {
        {0}, /* UNI=1364, Hall=468 */
    },
    {
        {0}, /* UNI=1365, Hall=468 */
    },
    {
        {0}, /* UNI=1366, Hall=468 */
    },
    {
        {0}, /* UNI=1367, Hall=469 */
    },
    {
        {0}, /* UNI=1368, Hall=469 */
    },
    {
        {0}, /* UNI=1369, Hall=469 */
    },
    {
        {0}, /* UNI=1370, Hall=469 */
    },
    {
        {0}, /* UNI=1371, Hall=469 */
    },
    {
        {0}, /* UNI=1372, Hall=469 */
    },
    {
        {0}, /* UNI=1373, Hall=470 */
    },
    {
        {0}, /* UNI=1374, Hall=470 */
    },
    {
        {0}, /* UNI=1375, Hall=470 */
    },
    {
        {0}, /* UNI=1376, Hall=470 */
    },
    {
        {0}, /* UNI=1377, Hall=470 */
    },
    {
        {0}, /* UNI=1378, Hall=470 */
    },
    {
        {0}, /* UNI=1379, Hall=471 */
    },
    {
        {0}, /* UNI=1380, Hall=471 */
    },
    {
        {0}, /* UNI=1381, Hall=471 */
    },
    {
        {0}, /* UNI=1382, Hall=471 */
    },
    {
        {0}, /* UNI=1383, Hall=471 */
    },
    {
        {0}, /* UNI=1384, Hall=471 */
    },
    {
        {0}, /* UNI=1385, Hall=472 */
    },
    {
        {0}, /* UNI=1386, Hall=472 */
    },
    {
        {0}, /* UNI=1387, Hall=472 */
    },
    {
        {0}, /* UNI=1388, Hall=472 */
    },
    {
        {0}, /* UNI=1389, Hall=472 */
    },
    {
        {0}, /* UNI=1390, Hall=472 */
    },
    {
        {0}, /* UNI=1391, Hall=473 */
    },
    {
        {0}, /* UNI=1392, Hall=473 */
    },
    {
        {0}, /* UNI=1393, Hall=473 */
    },
    {
        {0}, /* UNI=1394, Hall=473 */
    },
    {
        {0}, /* UNI=1395, Hall=473 */
    },
    {
        {0}, /* UNI=1396, Hall=473 */
    },
    {
        {0}, /* UNI=1397, Hall=474 */
    },
    {
        {0}, /* UNI=1398, Hall=474 */
    },
    {
        {0}, /* UNI=1399, Hall=474 */
    },
    {
        {0}, /* UNI=1400, Hall=474 */
    },
    {
        {0}, /* UNI=1401, Hall=474 */
    },
    {
        {0}, /* UNI=1402, Hall=474 */
    },
    {
        {0}, /* UNI=1403, Hall=475 */
    },
    {
        {0}, /* UNI=1404, Hall=475 */
    },
    {
        {0}, /* UNI=1405, Hall=475 */
    },
    {
        {0}, /* UNI=1406, Hall=475 */
    },
    {
        {0}, /* UNI=1407, Hall=475 */
    },
    {
        {0}, /* UNI=1408, Hall=475 */
    },
    {
        {0}, /* UNI=1409, Hall=476 */
    },
    {
        {0}, /* UNI=1410, Hall=476 */
    },
    {
        {0}, /* UNI=1411, Hall=476 */
    },
    {
        {0}, /* UNI=1412, Hall=476 */
    },
    {
        {0}, /* UNI=1413, Hall=476 */
    },
    {
        {0}, /* UNI=1414, Hall=476 */
    },
    {
        {0}, /* UNI=1415, Hall=477 */
    },
    {
        {0}, /* UNI=1416, Hall=477 */
    },
    {
        {0}, /* UNI=1417, Hall=477 */
    },
    {
        {0}, /* UNI=1418, Hall=477 */
    },
    {
        {0}, /* UNI=1419, Hall=477 */
    },
    {
        {0}, /* UNI=1420, Hall=477 */
    },
    {
        {0}, /* UNI=1421, Hall=478 */
    },
    {
        {0}, /* UNI=1422, Hall=478 */
    },
    {
        {0}, /* UNI=1423, Hall=478 */
    },
    {
        {0}, /* UNI=1424, Hall=478 */
    },
    {
        {0}, /* UNI=1425, Hall=478 */
    },
    {
        {0}, /* UNI=1426, Hall=478 */
    },
    {
        {0}, /* UNI=1427, Hall=479 */
    },
    {
        {0}, /* UNI=1428, Hall=479 */
    },
    {
        {0}, /* UNI=1429, Hall=479 */
    },
    {
        {0}, /* UNI=1430, Hall=479 */
    },
    {
        {0}, /* UNI=1431, Hall=479 */
    },
    {
        {0}, /* UNI=1432, Hall=479 */
    },
    {
        {0}, /* UNI=1433, Hall=480 */
    },
    {
        {0}, /* UNI=1434, Hall=480 */
    },
    {
        {0}, /* UNI=1435, Hall=480 */
    },
    {
        {0}, /* UNI=1436, Hall=480 */
    },
    {
        {0}, /* UNI=1437, Hall=480 */
    },
    {
        {0}, /* UNI=1438, Hall=480 */
    },
    {
        {0}, /* UNI=1439, Hall=481 */
    },
    {
        {0}, /* UNI=1440, Hall=481 */
    },
    {
        {0}, /* UNI=1441, Hall=481 */
    },
    {
        {0}, /* UNI=1442, Hall=481 */
    },
    {
        {0}, /* UNI=1443, Hall=481 */
    },
    {
        {0}, /* UNI=1444, Hall=481 */
    },
    {
        {0}, /* UNI=1445, Hall=482 */
    },
    {
        {0}, /* UNI=1446, Hall=482 */
    },
    {
        {0}, /* UNI=1447, Hall=482 */
    },
    {
        {0}, /* UNI=1448, Hall=482 */
    },
    {
        {0}, /* UNI=1449, Hall=482 */
    },
    {
        {0}, /* UNI=1450, Hall=482 */
    },
    {
        {0}, /* UNI=1451, Hall=483 */
    },
    {
        {0}, /* UNI=1452, Hall=483 */
    },
    {
        {0}, /* UNI=1453, Hall=483 */
    },
    {
        {0}, /* UNI=1454, Hall=483 */
    },
    {
        {0}, /* UNI=1455, Hall=483 */
    },
    {
        {0}, /* UNI=1456, Hall=483 */
    },
    {
        {0}, /* UNI=1457, Hall=484 */
    },
    {
        {0}, /* UNI=1458, Hall=484 */
    },
    {
        {0}, /* UNI=1459, Hall=484 */
    },
    {
        {0}, /* UNI=1460, Hall=484 */
    },
    {
        {0}, /* UNI=1461, Hall=484 */
    },
    {
        {0}, /* UNI=1462, Hall=484 */
    },
    {
        {0}, /* UNI=1463, Hall=485 */
    },
    {
        {0}, /* UNI=1464, Hall=485 */
    },
    {
        {0}, /* UNI=1465, Hall=485 */
    },
    {
        {0}, /* UNI=1466, Hall=485 */
    },
    {
        {0}, /* UNI=1467, Hall=485 */
    },
    {
        {0}, /* UNI=1468, Hall=485 */
    },
    {
        {0}, /* UNI=1469, Hall=485 */
    },
    {
        {0}, /* UNI=1470, Hall=485 */
    },
    {
        {0}, /* UNI=1471, Hall=485 */
    },
    {
        {0}, /* UNI=1472, Hall=485 */
    },
    {
        {0}, /* UNI=1473, Hall=486 */
    },
    {
        {0}, /* UNI=1474, Hall=486 */
    },
    {
        {0}, /* UNI=1475, Hall=486 */
    },
    {
        {0}, /* UNI=1476, Hall=486 */
    },
    {
        {0}, /* UNI=1477, Hall=486 */
    },
    {
        {0}, /* UNI=1478, Hall=486 */
    },
    {
        {0}, /* UNI=1479, Hall=486 */
    },
    {
        {0}, /* UNI=1480, Hall=486 */
    },
    {
        {0}, /* UNI=1481, Hall=486 */
    },
    {
        {0}, /* UNI=1482, Hall=486 */
    },
    {
        {0}, /* UNI=1483, Hall=487 */
    },
    {
        {0}, /* UNI=1484, Hall=487 */
    },
    {
        {0}, /* UNI=1485, Hall=487 */
    },
    {
        {0}, /* UNI=1486, Hall=487 */
    },
    {
        {0}, /* UNI=1487, Hall=487 */
    },
    {
        {0}, /* UNI=1488, Hall=487 */
    },
    {
        {0}, /* UNI=1489, Hall=487 */
    },
    {
        {0}, /* UNI=1490, Hall=487 */
    },
    {
        {0}, /* UNI=1491, Hall=487 */
    },
    {
        {0}, /* UNI=1492, Hall=487 */
    },
    {
        {0}, /* UNI=1493, Hall=488 */
    },
    {
        {0}, /* UNI=1494, Hall=488 */
    },
    {
        {0}, /* UNI=1495, Hall=488 */
    },
    {
        {0}, /* UNI=1496, Hall=488 */
    },
    {
        {0}, /* UNI=1497, Hall=488 */
    },
    {
        {0}, /* UNI=1498, Hall=488 */
    },
    {
        {0}, /* UNI=1499, Hall=488 */
    },
    {
        {0}, /* UNI=1500, Hall=488 */
    },
    {
        {0}, /* UNI=1501, Hall=488 */
    },
    {
        {0}, /* UNI=1502, Hall=488 */
    },
    {
        {0}, /* UNI=1503, Hall=489 */
    },
    {
        {0}, /* UNI=1504, Hall=489 */
    },
    {
        {0}, /* UNI=1505, Hall=489 */
    },
    {
        {0}, /* UNI=1506, Hall=490 */
    },
    {
        {0}, /* UNI=1507, Hall=490 */
    },
    {
        {0}, /* UNI=1508, Hall=490 */
    },
    {
        {0}, /* UNI=1509, Hall=491 */
    },
    {
        {0}, /* UNI=1510, Hall=491 */
    },
    {
        {0}, /* UNI=1511, Hall=492 */
    },
    {
        {0}, /* UNI=1512, Hall=492 */
    },
    {
        {0}, /* UNI=1513, Hall=492 */
    },
    {
        {0}, /* UNI=1514, Hall=493 */
    },
    {
        {0}, /* UNI=1515, Hall=493 */
    },
    {
        {0}, /* UNI=1516, Hall=494 */
    },
    {
        {0}, /* UNI=1517, Hall=494 */
    },
    {
        {0}, /* UNI=1518, Hall=494 */
    },
    {
        {0}, /* UNI=1519, Hall=494 */
    },
    {
        {0}, /* UNI=1520, Hall=495 */
        {0}, /* UNI=1520, Hall=496 */
    },
    {
        {0}, /* UNI=1521, Hall=495 */
        {0}, /* UNI=1521, Hall=496 */
    },
    {
        {0}, /* UNI=1522, Hall=495 */
        {0}, /* UNI=1522, Hall=496 */
    },
    {
        {0}, /* UNI=1523, Hall=495 */
        {0}, /* UNI=1523, Hall=496 */
    },
    {
        {0}, /* UNI=1524, Hall=497 */
    },
    {
        {0}, /* UNI=1525, Hall=497 */
    },
    {
        {0}, /* UNI=1526, Hall=497 */
    },
    {
        {0}, /* UNI=1527, Hall=497 */
    },
    {
        {0}, /* UNI=1528, Hall=498 */
        {0}, /* UNI=1528, Hall=499 */
    },
    {
        {0}, /* UNI=1529, Hall=498 */
        {0}, /* UNI=1529, Hall=499 */
    },
    {
        {0}, /* UNI=1530, Hall=498 */
        {0}, /* UNI=1530, Hall=499 */
    },
    {
        {0}, /* UNI=1531, Hall=498 */
        {0}, /* UNI=1531, Hall=499 */
    },
    {
        {0}, /* UNI=1532, Hall=500 */
    },
    {
        {0}, /* UNI=1533, Hall=500 */
    },
    {
        {0}, /* UNI=1534, Hall=500 */
    },
    {
        {0}, /* UNI=1535, Hall=501 */
    },
    {
        {0}, /* UNI=1536, Hall=501 */
    },
    {
        {0}, /* UNI=1537, Hall=501 */
    },
    {
        {0}, /* UNI=1538, Hall=501 */
    },
    {
        {0}, /* UNI=1539, Hall=502 */
    },
    {
        {0}, /* UNI=1540, Hall=502 */
    },
    {
        {0}, /* UNI=1541, Hall=502 */
    },
    {
        {0}, /* UNI=1542, Hall=503 */
    },
    {
        {0}, /* UNI=1543, Hall=503 */
    },
    {
        {0}, /* UNI=1544, Hall=503 */
    },
    {
        {0}, /* UNI=1545, Hall=503 */
    },
    {
        {0}, /* UNI=1546, Hall=504 */
    },
    {
        {0}, /* UNI=1547, Hall=504 */
    },
    {
        {0}, /* UNI=1548, Hall=504 */
    },
    {
        {0}, /* UNI=1549, Hall=504 */
    },
    {
        {0}, /* UNI=1550, Hall=505 */
    },
    {
        {0}, /* UNI=1551, Hall=505 */
    },
    {
        {0}, /* UNI=1552, Hall=505 */
    },
    {
        {0}, /* UNI=1553, Hall=505 */
    },
    {
        {0}, /* UNI=1554, Hall=506 */
    },
    {
        {0}, /* UNI=1555, Hall=506 */
    },
    {
        {0}, /* UNI=1556, Hall=506 */
    },
    {
        {0}, /* UNI=1557, Hall=506 */
    },
    {
        {0}, /* UNI=1558, Hall=507 */
    },
    {
        {0}, /* UNI=1559, Hall=507 */
    },
    {
        {0}, /* UNI=1560, Hall=507 */
    },
    {
        {0}, /* UNI=1561, Hall=508 */
    },
    {
        {0}, /* UNI=1562, Hall=508 */
    },
    {
        {0}, /* UNI=1563, Hall=508 */
    },
    {
        {0}, /* UNI=1564, Hall=508 */
    },
    {
        {0}, /* UNI=1565, Hall=509 */
    },
    {
        {0}, /* UNI=1566, Hall=509 */
    },
    {
        {0}, /* UNI=1567, Hall=509 */
    },
    {
        {0}, /* UNI=1568, Hall=509 */
    },
    {
        {0}, /* UNI=1569, Hall=510 */
    },
    {
        {0}, /* UNI=1570, Hall=510 */
    },
    {
        {0}, /* UNI=1571, Hall=510 */
    },
    {
        {0}, /* UNI=1572, Hall=511 */
    },
    {
        {0}, /* UNI=1573, Hall=511 */
    },
    {
        {0}, /* UNI=1574, Hall=511 */
    },
    {
        {0}, /* UNI=1575, Hall=511 */
    },
    {
        {0}, /* UNI=1576, Hall=512 */
    },
    {
        {0}, /* UNI=1577, Hall=512 */
    },
    {
        {0}, /* UNI=1578, Hall=512 */
    },
    {
        {0}, /* UNI=1579, Hall=512 */
    },
    {
        {0}, /* UNI=1580, Hall=513 */
    },
    {
        {0}, /* UNI=1581, Hall=513 */
    },
    {
        {0}, /* UNI=1582, Hall=513 */
    },
    {
        {0}, /* UNI=1583, Hall=514 */
    },
    {
        {0}, /* UNI=1584, Hall=514 */
    },
    {
        {0}, /* UNI=1585, Hall=514 */
    },
    {
        {0}, /* UNI=1586, Hall=514 */
    },
    {
        {0}, /* UNI=1587, Hall=515 */
    },
    {
        {0}, /* UNI=1588, Hall=515 */
    },
    {
        {0}, /* UNI=1589, Hall=515 */
    },
    {
        {0}, /* UNI=1590, Hall=515 */
    },
    {
        {0}, /* UNI=1591, Hall=516 */
    },
    {
        {0}, /* UNI=1592, Hall=516 */
    },
    {
        {0}, /* UNI=1593, Hall=516 */
    },
    {
        {0}, /* UNI=1594, Hall=517 */
    },
    {
        {0}, /* UNI=1595, Hall=517 */
    },
    {
        {0}, /* UNI=1596, Hall=517 */
    },
    {
        {0}, /* UNI=1597, Hall=517 */
    },
    {
        {0}, /* UNI=1598, Hall=517 */
    },
    {
        {0}, /* UNI=1599, Hall=517 */
    },
    {
        {0}, /* UNI=1600, Hall=518 */
        {0}, /* UNI=1600, Hall=519 */
    },
    {
        {0}, /* UNI=1601, Hall=518 */
        {0}, /* UNI=1601, Hall=519 */
    },
    {
        {0}, /* UNI=1602, Hall=518 */
        {0}, /* UNI=1602, Hall=519 */
    },
    {
        {0}, /* UNI=1603, Hall=518 */
        {0}, /* UNI=1603, Hall=519 */
    },
    {
        {0}, /* UNI=1604, Hall=518 */
        {0}, /* UNI=1604, Hall=519 */
    },
    {
        {0}, /* UNI=1605, Hall=518 */
        {0}, /* UNI=1605, Hall=519 */
    },
    {
        {0}, /* UNI=1606, Hall=520 */
    },
    {
        {0}, /* UNI=1607, Hall=520 */
    },
    {
        {0}, /* UNI=1608, Hall=520 */
    },
    {
        {0}, /* UNI=1609, Hall=520 */
    },
    {
        {0}, /* UNI=1610, Hall=520 */
    },
    {
        {0}, /* UNI=1611, Hall=520 */
    },
    {
        {0}, /* UNI=1612, Hall=521 */
        {0}, /* UNI=1612, Hall=522 */
    },
    {
        {0}, /* UNI=1613, Hall=521 */
        {0}, /* UNI=1613, Hall=522 */
    },
    {
        {0}, /* UNI=1614, Hall=521 */
        {0}, /* UNI=1614, Hall=522 */
    },
    {
        {0}, /* UNI=1615, Hall=521 */
        {0}, /* UNI=1615, Hall=522 */
    },
    {
        {0}, /* UNI=1616, Hall=521 */
        {0}, /* UNI=1616, Hall=522 */
    },
    {
        {0}, /* UNI=1617, Hall=521 */
        {0}, /* UNI=1617, Hall=522 */
    },
    {
        {0}, /* UNI=1618, Hall=523 */
    },
    {
        {0}, /* UNI=1619, Hall=523 */
    },
    {
        {0}, /* UNI=1620, Hall=523 */
    },
    {
        {0}, /* UNI=1621, Hall=523 */
    },
    {
        {0}, /* UNI=1622, Hall=523 */
    },
    {
        {0}, /* UNI=1623, Hall=523 */
    },
    {
        {0}, /* UNI=1624, Hall=524 */
    },
    {
        {0}, /* UNI=1625, Hall=524 */
    },
    {
        {0}, /* UNI=1626, Hall=524 */
    },
    {
        {0}, /* UNI=1627, Hall=524 */
    },
    {
        {0}, /* UNI=1628, Hall=524 */
    },
    {
        {0}, /* UNI=1629, Hall=524 */
    },
    {
        {0}, /* UNI=1630, Hall=525 */
        {0}, /* UNI=1630, Hall=526 */
    },
    {
        {0}, /* UNI=1631, Hall=525 */
        {0}, /* UNI=1631, Hall=526 */
    },
    {
        {0}, /* UNI=1632, Hall=525 */
        {0}, /* UNI=1632, Hall=526 */
    },
    {
        {0}, /* UNI=1633, Hall=525 */
        {0}, /* UNI=1633, Hall=526 */
    },
    {
        {0}, /* UNI=1634, Hall=525 */
        {0}, /* UNI=1634, Hall=526 */
    },
    {
        {0}, /* UNI=1635, Hall=525 */
        {0}, /* UNI=1635, Hall=526 */
    },
    {
        {0}, /* UNI=1636, Hall=527 */
        {0}, /* UNI=1636, Hall=528 */
    },
    {
        {0}, /* UNI=1637, Hall=527 */
        {0}, /* UNI=1637, Hall=528 */
    },
    {
        {0}, /* UNI=1638, Hall=527 */
        {0}, /* UNI=1638, Hall=528 */
    },
    {
        {0}, /* UNI=1639, Hall=527 */
        {0}, /* UNI=1639, Hall=528 */
    },
    {
        {0}, /* UNI=1640, Hall=527 */
        {0}, /* UNI=1640, Hall=528 */
    },
    {
        {0}, /* UNI=1641, Hall=527 */
        {0}, /* UNI=1641, Hall=528 */
    },
    {
        {0}, /* UNI=1642, Hall=529 */
    },
    {
        {0}, /* UNI=1643, Hall=529 */
    },
    {
        {0}, /* UNI=1644, Hall=529 */
    },
    {
        {0}, /* UNI=1645, Hall=529 */
    },
    {
        {0}, /* UNI=1646, Hall=529 */
    },
    {
        {0}, /* UNI=1647, Hall=530 */
    },
    {
        {0}, /* UNI=1648, Hall=530 */
    },
    {
        {0}, /* UNI=1649, Hall=530 */
    },
    {
        {0}, /* UNI=1650, Hall=530 */
    },
    {
        {0}, /* UNI=1651, Hall=530 */
    },
};

/* Return NULL if failed. */
Symmetry *msgdb_get_std_transformations(const int uni_number,
                                        const int hall_number) {
    int hall_number_offset, enc, i, s;
    Symmetry *transformations;
    int identity[3][3] = {{1, 0, 0}, {0, 1, 0}, {0, 0, 1}};

    int tmat[3][3];
    double origin_shift[3];

    hall_number_offset = get_hall_number_offset(uni_number, hall_number);
    if (hall_number_offset == -1) {
        return NULL;
    }

    if ((transformations = sym_alloc_symmetry(7)) == NULL) {
        return NULL;
    }

    /* Identity transformation as first element */
    mat_copy_matrix_i3(transformations->rot[0], identity);
    for (s = 0; s < 3; s++) {
        transformations->trans[0][s] = 0;
    }

    for (i = 0; i < 7; i++) {
        enc = alternative_transformations[uni_number][hall_number_offset][i];
        if (enc == 0) {
            transformations->size = i + 1;
            break;
        };
        spgdb_decode_symmetry(tmat, origin_shift, enc);
        mat_copy_matrix_i3(transformations->rot[i + 1], tmat);
        mat_copy_vector_d3(transformations->trans[i + 1], origin_shift);
    }

    return transformations;
}

/* Return -1 if failed. */
static int get_hall_number_offset(const int uni_number, const int hall_number) {
    int num_halls, first_hall_number;
    int hall_number_offset;

    if (uni_number <= 0 || uni_number > 1651) {
        return -1;
    }

    num_halls = magnetic_spacegroup_uni_mapping[uni_number][0];
    first_hall_number = magnetic_spacegroup_uni_mapping[uni_number][1];

    if (hall_number > 0 && hall_number <= 530) {
        hall_number_offset = hall_number - first_hall_number;
    } else if (hall_number == 0) {
        /* Use the smallest Hall number as default */
        hall_number_offset = 0;
    } else {
        return -1;
    }

    /* check if hall_number_offset is in range. */
    if (hall_number_offset < 0 || hall_number_offset >= num_halls) {
        return -1;
    }

    return hall_number_offset;
}
